/**
 * The _model_module_version/_view_module_version this package implements.
 *
 * The html widget manager assumes that this is the same as the npm package
 * version number.
 */
export declare const MODULE_VERSION: any;
export declare const MODULE_NAME: any;
