#!/usr/bin/env python
# coding: utf-8

# For licensing see accompanying LICENSE file.
# Copyright (C) 2023 Apple Inc. All Rights Reserved.

version_info = (1, 0, 2)
__version__ = ".".join(map(str, version_info))
