#!/usr/bin/env python
# coding: utf-8

# For licensing see accompanying LICENSE file.
# Copyright (C) 2023 Apple Inc. All Rights Reserved.

"""
Information about the frontend package of the widgets.
"""

module_name = "symphony-vega"
module_version = "^1.0.2"
