/*
 * ATTENTION: The "eval" devtool has been used (maybe by default in mode: "development").
 * This devtool is neither made for production nor for readable output files.
 * It uses "eval()" calls to create a separate source file in the browser devtools.
 * If you are trying to read the output file, select a different devtool (https://webpack.js.org/configuration/devtool/)
 * or disable the default devtool with "devtool: false".
 * If you are looking for production-ready output files, see mode: "production" (https://webpack.js.org/configuration/mode/).
 */
define(["@jupyter-widgets/base"], (__WEBPACK_EXTERNAL_MODULE__jupyter_widgets_base__) => { return /******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ "../../node_modules/@fireflysemantics/join/fesm2015/fireflysemantics-join.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/@fireflysemantics/join/fesm2015/fireflysemantics-join.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   join: () => (/* binding */ join)\n/* harmony export */ });\n/**\nMIT License\n\nCopyright (c) Firefly Semantics Corporation\nCopyright (c) 2020 Ole K. Ersoy\nCopyright (c) 2015 José F. Romaniello\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE. */\n/**\n * @param args The components of the URL\n * @throws TypeError if the args URL components are not all of type string\n * @return The URL string\n */\nfunction join(...args) {\n    let components = [];\n    /**\n     * If an empty array is received then\n     * the URL is just ''.\n     */\n    if (args.length === 0) {\n        return '';\n    }\n    /** The args values must be of type string */\n    args.forEach(component => {\n        if (typeof component !== 'string') {\n            throw new TypeError(`Url components must be of type string. \n                    The ${component} component is of type ${typeof component}`);\n        }\n    });\n    /**\n     * If the protocol is specified by itself,\n     * then the protocol is combined with the\n     * subsequent array value.\n     */\n    const protocol = args[0];\n    if (protocol.match(/^[^/:]+:\\/*$/) && args.length > 1) {\n        var first = args.shift();\n        args[0] = first + args[0];\n    }\n    /**\n     * The file protocol should have two or three slashes.\n     * Other protocols should have 2.\n     */\n    if (args[0].match(/^file:\\/\\/\\//)) {\n        args[0] = args[0].replace(/^([^/:]+):\\/*/, '$1:///');\n    }\n    else {\n        args[0] = args[0].replace(/^([^/:]+):\\/*/, '$1://');\n    }\n    /** The args values must be of type string */\n    args.forEach((component, i) => {\n        if (component === '') {\n            return;\n        }\n        /**\n         * Remove starting slashes for all but the first component\n         */\n        if (i > 0) {\n            component = component.replace(/^[\\/]+/, '');\n        }\n        /**\n         * Remove the ending slashes for each component but the last.\n         */\n        if (i < args.length - 1) {\n            component = component.replace(/[\\/]+$/, '');\n        }\n        else {\n            // For the last combine multiple slashes into one.\n            component = component.replace(/[\\/]+$/, '/');\n        }\n        components.push(component);\n    });\n    /**\n     * Separate all the components by a single /\n     */\n    let url = components.join('/');\n    // remove trailing slash before parameters or hash\n    url = url.replace(/\\/(\\?|&|#[^!])/g, '$1');\n    // replace ? in parameters with &\n    var parts = url.split('?');\n    url = parts.shift() + (parts.length > 0 ? '?' : '') + parts.join('&');\n    return url;\n}\n\n/*\n * Public API Surface of join\n */\n\n/**\n * Generated bundle index. Do not edit.\n */\n\n\n//# sourceMappingURL=fireflysemantics-join.js.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fireflysemantics/join/fesm2015/fireflysemantics-join.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-brands-svg-icons/faGithub.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-brands-svg-icons/faGithub.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fab';\nvar iconName = 'github';\nvar width = 496;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f09b';\nvar svgPathData = 'M165.9 397.4c0 2-2.3 3.6-5.2 3.6-3.3.3-5.6-1.3-5.6-3.6 0-2 2.3-3.6 5.2-3.6 3-.3 5.6 1.3 5.6 3.6zm-31.1-4.5c-.7 2 1.3 4.3 4.3 4.9 2.6 1 5.6 0 6.2-2s-1.3-4.3-4.3-5.2c-2.6-.7-5.5.3-6.2 2.3zm44.2-1.7c-2.9.7-4.9 2.6-4.6 4.9.3 2 2.9 3.3 5.9 2.6 2.9-.7 4.9-2.6 4.6-4.6-.3-1.9-3-3.2-5.9-2.9zM244.8 8C106.1 8 0 113.3 0 252c0 110.9 69.8 205.8 169.5 239.2 12.8 2.3 17.3-5.6 17.3-12.1 0-6.2-.3-40.4-.3-61.4 0 0-70 15-84.7-29.8 0 0-11.4-29.1-27.8-36.6 0 0-22.9-15.7 1.6-15.4 0 0 24.9 2 38.6 25.8 21.9 38.6 58.6 27.5 72.9 20.9 2.3-16 8.8-27.1 16-33.7-55.9-6.2-112.3-14.3-112.3-110.5 0-27.5 7.6-41.3 23.6-58.9-2.6-6.5-11.1-33.3 2.6-67.9 20.9-6.5 69 27 69 27 20-5.6 41.5-8.5 62.8-8.5s42.8 2.9 62.8 8.5c0 0 48.1-33.6 69-27 13.7 34.7 5.2 61.4 2.6 67.9 16 17.7 25.8 31.5 25.8 58.9 0 96.5-58.9 104.2-114.8 110.5 9.2 7.9 17 22.9 17 46.4 0 33.7-.3 75.4-.3 83.6 0 6.5 4.6 14.4 17.3 12.1C428.2 457.8 496 362.9 496 252 496 113.3 383.5 8 244.8 8zM97.2 352.9c-1.3 1-1 3.3.7 5.2 1.6 1.6 3.9 2.3 5.2 1 1.3-1 1-3.3-.7-5.2-1.6-1.6-3.9-2.3-5.2-1zm-10.8-8.1c-.7 1.3.3 2.9 2.3 3.9 1.6 1 3.6.7 4.3-.7.7-1.3-.3-2.9-2.3-3.9-2-.6-3.6-.3-4.3.7zm32.4 35.6c-1.6 1.3-1 4.3 1.3 6.2 2.3 2.3 5.2 2.6 6.5 1 1.3-1.3.7-4.3-1.3-6.2-2.2-2.3-5.2-2.6-6.5-1zm-11.4-14.7c-1.6 1-1.6 3.6 0 5.9 1.6 2.3 4.3 3.3 5.6 2.3 1.6-1.3 1.6-3.9 0-6.2-1.4-2.3-4-3.3-5.6-2z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faGithub = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-brands-svg-icons/faGithub.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faChartBar.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faChartBar.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'chart-bar';\nvar width = 512;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f080';\nvar svgPathData = 'M332.8 320h38.4c6.4 0 12.8-6.4 12.8-12.8V172.8c0-6.4-6.4-12.8-12.8-12.8h-38.4c-6.4 0-12.8 6.4-12.8 12.8v134.4c0 6.4 6.4 12.8 12.8 12.8zm96 0h38.4c6.4 0 12.8-6.4 12.8-12.8V76.8c0-6.4-6.4-12.8-12.8-12.8h-38.4c-6.4 0-12.8 6.4-12.8 12.8v230.4c0 6.4 6.4 12.8 12.8 12.8zm-288 0h38.4c6.4 0 12.8-6.4 12.8-12.8v-70.4c0-6.4-6.4-12.8-12.8-12.8h-38.4c-6.4 0-12.8 6.4-12.8 12.8v70.4c0 6.4 6.4 12.8 12.8 12.8zm96 0h38.4c6.4 0 12.8-6.4 12.8-12.8V108.8c0-6.4-6.4-12.8-12.8-12.8h-38.4c-6.4 0-12.8 6.4-12.8 12.8v198.4c0 6.4 6.4 12.8 12.8 12.8zM496 384H64V80c0-8.84-7.16-16-16-16H16C7.16 64 0 71.16 0 80v336c0 17.67 14.33 32 32 32h464c8.84 0 16-7.16 16-16v-32c0-8.84-7.16-16-16-16z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faChartBar = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faChartBar.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faCheckSquare.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faCheckSquare.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'check-square';\nvar width = 448;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f14a';\nvar svgPathData = 'M400 480H48c-26.51 0-48-21.49-48-48V80c0-26.51 21.49-48 48-48h352c26.51 0 48 21.49 48 48v352c0 26.51-21.49 48-48 48zm-204.686-98.059l184-184c6.248-6.248 6.248-16.379 0-22.627l-22.627-22.627c-6.248-6.248-16.379-6.249-22.628 0L184 302.745l-70.059-70.059c-6.248-6.248-16.379-6.248-22.628 0l-22.627 22.627c-6.248 6.248-6.248 16.379 0 22.627l104 104c6.249 6.25 16.379 6.25 22.628.001z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faCheckSquare = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faCheckSquare.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faEye.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faEye.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'eye';\nvar width = 576;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f06e';\nvar svgPathData = 'M572.52 241.4C518.29 135.59 410.93 64 288 64S57.68 135.64 3.48 241.41a32.35 32.35 0 0 0 0 29.19C57.71 376.41 165.07 448 288 448s230.32-71.64 284.52-177.41a32.35 32.35 0 0 0 0-29.19zM288 400a144 144 0 1 1 144-144 143.93 143.93 0 0 1-144 144zm0-240a95.31 95.31 0 0 0-25.31 3.79 47.85 47.85 0 0 1-66.9 66.9A95.78 95.78 0 1 0 288 160z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faEye = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faEye.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faEyeSlash.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faEyeSlash.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'eye-slash';\nvar width = 640;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f070';\nvar svgPathData = 'M320 400c-75.85 0-137.25-58.71-142.9-133.11L72.2 185.82c-13.79 17.3-26.48 35.59-36.72 55.59a32.35 32.35 0 0 0 0 29.19C89.71 376.41 197.07 448 320 448c26.91 0 52.87-4 77.89-10.46L346 397.39a144.13 144.13 0 0 1-26 2.61zm313.82 58.1l-110.55-85.44a331.25 331.25 0 0 0 81.25-102.07 32.35 32.35 0 0 0 0-29.19C550.29 135.59 442.93 64 320 64a308.15 308.15 0 0 0-147.32 37.7L45.46 3.37A16 16 0 0 0 23 6.18L3.37 31.45A16 16 0 0 0 6.18 53.9l588.36 454.73a16 16 0 0 0 22.46-2.81l19.64-25.27a16 16 0 0 0-2.82-22.45zm-183.72-142l-39.3-30.38A94.75 94.75 0 0 0 416 256a94.76 94.76 0 0 0-121.31-92.21A47.65 47.65 0 0 1 304 192a46.64 46.64 0 0 1-1.54 10l-73.61-56.89A142.31 142.31 0 0 1 320 112a143.92 143.92 0 0 1 144 144c0 21.63-5.29 41.79-13.9 60.11z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faEyeSlash = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faEyeSlash.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faImage.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faImage.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'image';\nvar width = 512;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f03e';\nvar svgPathData = 'M464 448H48c-26.51 0-48-21.49-48-48V112c0-26.51 21.49-48 48-48h416c26.51 0 48 21.49 48 48v288c0 26.51-21.49 48-48 48zM112 120c-30.928 0-56 25.072-56 56s25.072 56 56 56 56-25.072 56-56-25.072-56-56-56zM64 384h384V272l-87.515-87.515c-4.686-4.686-12.284-4.686-16.971 0L208 320l-55.515-55.515c-4.686-4.686-12.284-4.686-16.971 0L64 336v48z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faImage = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faImage.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faPause.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faPause.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'pause';\nvar width = 448;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f04c';\nvar svgPathData = 'M144 479H48c-26.5 0-48-21.5-48-48V79c0-26.5 21.5-48 48-48h96c26.5 0 48 21.5 48 48v352c0 26.5-21.5 48-48 48zm304-48V79c0-26.5-21.5-48-48-48h-96c-26.5 0-48 21.5-48 48v352c0 26.5 21.5 48 48 48h96c26.5 0 48-21.5 48-48z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faPause = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faPause.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faPlay.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faPlay.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'play';\nvar width = 448;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f04b';\nvar svgPathData = 'M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faPlay = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faPlay.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faQuestionCircle.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faQuestionCircle.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'question-circle';\nvar width = 512;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f059';\nvar svgPathData = 'M504 256c0 136.997-111.043 248-248 248S8 392.997 8 256C8 119.083 119.043 8 256 8s248 111.083 248 248zM262.655 90c-54.497 0-89.255 22.957-116.549 63.758-3.536 5.286-2.353 12.415 2.715 16.258l34.699 26.31c5.205 3.947 12.621 3.008 16.665-2.122 17.864-22.658 30.113-35.797 57.303-35.797 20.429 0 45.698 13.148 45.698 32.958 0 14.976-12.363 22.667-32.534 33.976C247.128 238.528 216 254.941 216 296v4c0 6.627 5.373 12 12 12h56c6.627 0 12-5.373 12-12v-1.333c0-28.462 83.186-29.647 83.186-106.667 0-58.002-60.165-102-116.531-102zM256 338c-25.365 0-46 20.635-46 46 0 25.364 20.635 46 46 46s46-20.636 46-46c0-25.365-20.635-46-46-46z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faQuestionCircle = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faQuestionCircle.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faTable.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faTable.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'table';\nvar width = 512;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f0ce';\nvar svgPathData = 'M464 32H48C21.49 32 0 53.49 0 80v352c0 26.51 21.49 48 48 48h416c26.51 0 48-21.49 48-48V80c0-26.51-21.49-48-48-48zM224 416H64v-96h160v96zm0-160H64v-96h160v96zm224 160H288v-96h160v96zm0-160H288v-96h160v96z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faTable = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faTable.js?");

/***/ }),

/***/ "../../node_modules/@fortawesome/free-solid-svg-icons/faTimes.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@fortawesome/free-solid-svg-icons/faTimes.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\nObject.defineProperty(exports, \"__esModule\", ({ value: true }));\nvar prefix = 'fas';\nvar iconName = 'times';\nvar width = 352;\nvar height = 512;\nvar ligatures = [];\nvar unicode = 'f00d';\nvar svgPathData = 'M242.72 256l100.07-100.07c12.28-12.28 12.28-32.19 0-44.48l-22.24-22.24c-12.28-12.28-32.19-12.28-44.48 0L176 189.28 75.93 89.21c-12.28-12.28-32.19-12.28-44.48 0L9.21 111.45c-12.28 12.28-12.28 32.19 0 44.48L109.28 256 9.21 356.07c-12.28 12.28-12.28 32.19 0 44.48l22.24 22.24c12.28 12.28 32.2 12.28 44.48 0L176 322.72l100.07 100.07c12.28 12.28 32.2 12.28 44.48 0l22.24-22.24c12.28-12.28 12.28-32.19 0-44.48L242.72 256z';\n\nexports.definition = {\n  prefix: prefix,\n  iconName: iconName,\n  icon: [\n    width,\n    height,\n    ligatures,\n    unicode,\n    svgPathData\n  ]};\n\nexports.faTimes = exports.definition;\nexports.prefix = prefix;\nexports.iconName = iconName;\nexports.width = width;\nexports.height = height;\nexports.ligatures = ligatures;\nexports.unicode = unicode;\nexports.svgPathData = svgPathData;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/@fortawesome/free-solid-svg-icons/faTimes.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/arrow-column.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/arrow-column.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ arrowColumn)\n/* harmony export */ });\n/* harmony import */ var _arrow_dictionary__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrow-dictionary */ \"../../node_modules/arquero/src/arrow/arrow-dictionary.js\");\n/* harmony import */ var _arrow_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./arrow-types */ \"../../node_modules/arquero/src/arrow/arrow-types.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_repeat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/repeat */ \"../../node_modules/arquero/src/util/repeat.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n\n\n\n\n\n\n\nconst isList = id => id === _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].List || id === _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].FixedSizeList;\n\n/**\n * Create an Arquero column that proxies access to an Arrow column.\n * @param {object} arrow An Apache Arrow column.\n * @return {import('../table/column').ColumnType} An Arquero-compatible column.\n */\nfunction arrowColumn(arrow, nested) {\n  if (arrow.dictionary) return (0,_arrow_dictionary__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(arrow);\n  const { typeId, chunks, length, numChildren } = arrow;\n  const vector = chunks && chunks.length === 1 ? chunks[0] : arrow;\n  const get = numChildren && nested ? getNested(vector)\n    : numChildren ? memoize(getNested(vector))\n    : typeId === _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Utf8 ? memoize(row => vector.get(row))\n    : null;\n\n  return get\n    ? { vector, length, get, [Symbol.iterator]: () => iterator(length, get) }\n    : vector;\n}\n\nfunction memoize(get) {\n  const values = [];\n  return row => {\n    const v = values[row];\n    return v !== undefined ? v : (values[row] = get(row));\n  };\n}\n\nfunction* iterator(n, get) {\n  for (let i = 0; i < n; ++i) {\n    yield get(i);\n  }\n}\n\nconst arrayFrom = vector => vector.numChildren\n  ? (0,_util_repeat__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(vector.length, getNested(vector))\n  : vector.nullCount ? [...vector]\n  : vector.toArray();\n\nconst getNested = vector => isList(vector.typeId) ? getList(vector)\n  : vector.typeId === _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Struct ? getStruct(vector)\n  : (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(`Unsupported Arrow type: ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(vector.VectorName)}`);\n\nconst getList = vector => vector.nullCount\n  ? row => vector.isValid(row) ? arrayFrom(vector.get(row)) : null\n  : row => arrayFrom(vector.get(row));\n\nfunction getStruct(vector) {\n  const props = [];\n  const code = [];\n  vector.type.children.forEach((field, i) => {\n    props.push(arrowColumn(vector.getChildAt(i), true));\n    code.push(`${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(field.name)}:_${i}.get(row)`);\n  });\n  const get = (0,_util_unroll__WEBPACK_IMPORTED_MODULE_5__[\"default\"])('row', '({' + code + '})', props);\n\n  return vector.nullCount\n    ? row => vector.isValid(row) ? get(row) : null\n    : get;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/arrow-column.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/arrow-dictionary.js":
/*!****************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/arrow-dictionary.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _op_functions_sequence__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../op/functions/sequence */ \"../../node_modules/arquero/src/op/functions/sequence.js\");\n\n\n/**\n * Create a new Arquero column that proxies access to an\n * Apache Arrow dictionary column.\n * @param {object} vector An Apache Arrow dictionary column.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(vector) {\n  const { chunks, dictionary, length, nullCount } = vector;\n  const size = dictionary.length;\n  const keys = dictKeys(chunks || [vector], length, nullCount, size);\n  const values = Array(size);\n\n  const value = k => k == null || k < 0 || k >= size ? null\n    : values[k] !== undefined ? values[k]\n    : (values[k] = dictionary.get(k));\n\n  return {\n    vector,\n    length,\n\n    get: row => value(keys[row]),\n\n    key: row => keys[row],\n\n    keyFor(value) {\n      if (value === null) return nullCount ? size : -1;\n      for (let i = 0; i < size; ++i) {\n        if (values[i] === undefined) values[i] = dictionary.get(i);\n        if (values[i] === value) return i;\n      }\n      return -1;\n    },\n\n    groups(names) {\n      const s = size + (nullCount ? 1 : 0);\n      return { keys, get: [value], names, rows: (0,_op_functions_sequence__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(0, s), size: s };\n    },\n\n    [Symbol.iterator]() {\n      return vector[Symbol.iterator]();\n    }\n  };\n}\n\n/**\n * Generate a dictionary key array\n * @param {object[]} chunks Arrow column chunks\n * @param {number} length The length of the Arrow column\n * @param {number} nulls The count of column null values\n * @param {number} size The backing dictionary size\n */\nfunction dictKeys(chunks, length, nulls, size) {\n  const v = chunks.length > 1 || nulls\n    ? flatten(chunks, length, chunks[0].type.indices)\n    : chunks[0].values;\n  return nulls ? nullKeys(chunks, v, size) : v;\n}\n\n/**\n * Flatten Arrow column chunks into a single array.\n */\nfunction flatten(chunks, length, type) {\n  const array = new type.ArrayType(length);\n  const n = chunks.length;\n  for (let i = 0, idx = 0, len; i < n; ++i) {\n    len = chunks[i].length;\n    array.set(chunks[i].values.subarray(0, len), idx);\n    idx += len;\n  }\n  return array;\n}\n\n/**\n * Encode null values as an additional dictionary key.\n * Returns a new key array with null values added.\n * TODO: safeguard against integer overflow?\n */\nfunction nullKeys(chunks, keys, key) {\n  // iterate over null bitmaps, encode null values as key\n  const n = chunks.length;\n  for (let i = 0, idx = 0, m, base, bits, byte; i < n; ++i) {\n    bits = chunks[i].nullBitmap;\n    m = chunks[i].length >> 3;\n    if (bits && bits.length) {\n      for (let j = 0; j <= m; ++j) {\n        if ((byte = bits[j]) !== 255) {\n          base = idx + (j << 3);\n          if ((byte & (1 << 0)) === 0) keys[base + 0] = key;\n          if ((byte & (1 << 1)) === 0) keys[base + 1] = key;\n          if ((byte & (1 << 2)) === 0) keys[base + 2] = key;\n          if ((byte & (1 << 3)) === 0) keys[base + 3] = key;\n          if ((byte & (1 << 4)) === 0) keys[base + 4] = key;\n          if ((byte & (1 << 5)) === 0) keys[base + 5] = key;\n          if ((byte & (1 << 6)) === 0) keys[base + 6] = key;\n          if ((byte & (1 << 7)) === 0) keys[base + 7] = key;\n        }\n      }\n    }\n    idx += chunks[i].length;\n  }\n  return keys;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/arrow-dictionary.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/arrow-table.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/arrow-table.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   from: () => (/* binding */ from),\n/* harmony export */   table: () => (/* binding */ table)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n\n\n\nfunction table() {\n  // trap Table access to provide a helpful message\n  // when Apache Arrow has not been imported\n  try {\n    return apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Table;\n  } catch (err) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\n      'Apache Arrow not imported, ' +\n      'see https://github.com/uwdata/arquero#usage'\n    );\n  }\n}\n\nfunction from(arrow) {\n  return arrow && arrow.chunks ? arrow : table().from(arrow);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/arrow-table.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/arrow-types.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/arrow-types.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n// Hardwire Arrow type ids to sidestep dependency\n// https://github.com/apache/arrow/blob/master/js/src/enum.ts\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  /** The default placeholder type */\n  NONE: 0,\n  /** A NULL type having no physical storage */\n  Null: 1,\n  /** Signed or unsigned 8, 16, 32, or 64-bit little-endian integer */\n  Int: 2,\n  /** 2, 4, or 8-byte floating point value */\n  Float: 3,\n  /** Variable-length bytes (no guarantee of UTF8-ness) */\n  Binary: 4,\n  /** UTF8 variable-length string as List<Char> */\n  Utf8: 5,\n  /** Boolean as 1 bit, LSB bit-packed ordering */\n  Bool: 6,\n  /** Precision-and-scale-based decimal type. Storage type depends on the parameters. */\n  Decimal: 7,\n  /** int32_t days or int64_t milliseconds since the UNIX epoch */\n  Date: 8,\n  /** Time as signed 32 or 64-bit integer, representing either seconds, milliseconds, microseconds, or nanoseconds since midnight since midnight */\n  Time: 9,\n  /** Exact timestamp encoded with int64 since UNIX epoch (Default unit millisecond) */\n  Timestamp: 10,\n  /** YEAR_MONTH or DAY_TIME interval in SQL style */\n  Interval: 11,\n  /** A list of some logical data type */\n  List: 12,\n  /** Struct of logical types */\n  Struct: 13,\n  /** Union of logical types */\n  Union: 14,\n  /** Fixed-size binary. Each value occupies the same number of bytes */\n  FixedSizeBinary: 15,\n  /** Fixed-size list. Each value occupies the same number of bytes */\n  FixedSizeList: 16,\n  /** Map of named logical types */\n  Map: 17,\n\n  /** Dictionary aka Category type */\n  Dictionary: -1,\n  Int8: -2,\n  Int16: -3,\n  Int32: -4,\n  Int64: -5,\n  Uint8: -6,\n  Uint16: -7,\n  Uint32: -8,\n  Uint64: -9,\n  Float16: -10,\n  Float32: -11,\n  Float64: -12,\n  DateDay: -13,\n  DateMillisecond: -14,\n  TimestampSecond: -15,\n  TimestampMillisecond: -16,\n  TimestampMicrosecond: -17,\n  TimestampNanosecond: -18,\n  TimeSecond: -19,\n  TimeMillisecond: -20,\n  TimeMicrosecond: -21,\n  TimeNanosecond: -22,\n  DenseUnion: -23,\n  SparseUnion: -24,\n  IntervalDayTime: -25,\n  IntervalYearMonth: -26\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/arrow-types.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/array-builder.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/array-builder.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length) {\n  const data = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(type.ArrayType, length);\n  return {\n    set(value, index) { data[index] = value; },\n    data: () => ({ type, length, buffers: [null, data] })\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/array-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/bool-builder.js":
/*!********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/bool-builder.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length) {\n  const data = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(type.ArrayType, length / 8);\n  return {\n    set(value, index) {\n      if (value) data[index >> 3] |= (1 << (index % 8));\n    },\n    data: () => ({ type, length, buffers: [null, data] })\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/bool-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/date-day-builder.js":
/*!************************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/date-day-builder.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length) {\n  const data = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(type.ArrayType, length);\n  return {\n    set(value, index) { data[index] = (value / 86400000) | 0; },\n    data: () => ({ type, length, buffers: [null, data] })\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/date-day-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/date-millis-builder.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/date-millis-builder.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length) {\n  const data = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(type.ArrayType, length << 1);\n  return {\n    set(value, index) {\n      const i = index << 1;\n      data[  i] = (value % 4294967296) | 0;\n      data[i+1] = (value / 4294967296) | 0;\n    },\n    data: () => ({ type, length, buffers: [null, data] })\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/date-millis-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/default-builder.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/default-builder.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type) {\n  const b = apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Builder.new({\n    type,\n    nullValues: [null, undefined],\n    highWaterMark: Infinity\n  });\n  return {\n    set(value, index) { b.set(index, value); },\n    data: () => b.finish().flush()\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/default-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/dictionary-builder.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/dictionary-builder.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _utf8_builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./utf8-builder */ \"../../node_modules/arquero/src/arrow/builder/utf8-builder.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length) {\n  const values = [];\n  const data = (0,_util__WEBPACK_IMPORTED_MODULE_1__.array)(type.indices.ArrayType, length);\n  const keys = Object.create(null);\n\n  let next = -1;\n  let strlen = 0;\n\n  return {\n    set(value, index) {\n      const v = String(value);\n      let k = keys[v];\n      if (k === undefined) {\n        strlen += v.length;\n        keys[v] = k = ++next;\n        values.push(v);\n      }\n      data[index] = k;\n    },\n    data: () => ({\n      type,\n      length,\n      buffers: [null, data],\n      dict: dictionary(type.dictionary, values, strlen)\n    })\n  };\n}\n\nfunction dictionary(type, values, strlen) {\n  const b = (0,_utf8_builder__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(type, values.length, strlen);\n  values.forEach(b.set);\n  return (0,_util__WEBPACK_IMPORTED_MODULE_1__.arrowVector)(b.data());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/dictionary-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/index.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/index.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _arrow_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../arrow-types */ \"../../node_modules/arquero/src/arrow/arrow-types.js\");\n/* harmony import */ var _array_builder__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./array-builder */ \"../../node_modules/arquero/src/arrow/builder/array-builder.js\");\n/* harmony import */ var _bool_builder__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./bool-builder */ \"../../node_modules/arquero/src/arrow/builder/bool-builder.js\");\n/* harmony import */ var _date_day_builder__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./date-day-builder */ \"../../node_modules/arquero/src/arrow/builder/date-day-builder.js\");\n/* harmony import */ var _date_millis_builder__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./date-millis-builder */ \"../../node_modules/arquero/src/arrow/builder/date-millis-builder.js\");\n/* harmony import */ var _default_builder__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./default-builder */ \"../../node_modules/arquero/src/arrow/builder/default-builder.js\");\n/* harmony import */ var _dictionary_builder__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./dictionary-builder */ \"../../node_modules/arquero/src/arrow/builder/dictionary-builder.js\");\n/* harmony import */ var _valid_builder__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./valid-builder */ \"../../node_modules/arquero/src/arrow/builder/valid-builder.js\");\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, nrows, nullable = true) {\n  let method;\n\n  switch (type.typeId) {\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Int:\n      method = type.bitWidth < 64 ? _array_builder__WEBPACK_IMPORTED_MODULE_1__[\"default\"] : null;\n      break;\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Float:\n      method = type.precision > 0 ? _array_builder__WEBPACK_IMPORTED_MODULE_1__[\"default\"] : null;\n      break;\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Dictionary:\n      // check sub-types against builder assumptions\n      // if check fails, fallback to default builder\n      method = (\n        type.dictionary.typeId === _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Utf8 &&\n        type.indices.typeId === _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Int &&\n        type.indices.bitWidth < 64\n      ) ? _dictionary_builder__WEBPACK_IMPORTED_MODULE_6__[\"default\"] : null;\n      break;\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Bool:\n      method = _bool_builder__WEBPACK_IMPORTED_MODULE_2__[\"default\"];\n      break;\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_0__[\"default\"].Date:\n      method = type.unit ? _date_millis_builder__WEBPACK_IMPORTED_MODULE_4__[\"default\"] : _date_day_builder__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n      break;\n  }\n\n  return method == null ? (0,_default_builder__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(type)\n    : nullable ? (0,_valid_builder__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(method(type, nrows), nrows)\n    : method(type, nrows);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/resolve-type.js":
/*!********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/resolve-type.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n/* harmony import */ var _arrow_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../arrow-types */ \"../../node_modules/arquero/src/arrow/arrow-types.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type) {\n  if (type instanceof apache_arrow__WEBPACK_IMPORTED_MODULE_0__.DataType || type == null) {\n    return type;\n  }\n\n  switch (type) {\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Binary:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Binary();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Bool:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Bool();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].DateDay:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.DateDay();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].DateMillisecond:\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Date:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.DateMillisecond();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Dictionary:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Dictionary(new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Utf8(), new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int32());\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float16:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Float16();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float32:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Float32();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float64:\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Float64();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int8:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int8();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int16:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int16();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int32:\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int32();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int64:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int64();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].IntervalDayTime:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.IntervalDayTime();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Interval:\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].IntervalYearMonth:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.IntervalYearMonth();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Null:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Null();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].TimeMicrosecond:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.TimeMicrosecond();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].TimeMillisecond:\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Time:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.TimeMillisecond();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].TimeNanosecond:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.TimeNanosecond();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].TimeSecond:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.TimeSecond();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint8:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint8();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint16:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint16();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint32:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint32();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint64:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint64();\n    case _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Utf8:\n      return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Utf8();\n    default:\n      (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(\n        `Unsupported type code: ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(type)}. ` +\n        'Use a data type constructor instead?'\n      );\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/resolve-type.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/utf8-builder.js":
/*!********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/utf8-builder.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(type, length, strlen) {\n  const offset = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(Int32Array, length + 1);\n  const buf = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(Uint8Array, 3 * strlen);\n\n  let idx = 0;\n\n  return {\n    set(value, index) {\n      idx += (0,_util__WEBPACK_IMPORTED_MODULE_0__.writeUtf8)(buf, idx, value);\n      offset[index + 1] = idx;\n    },\n    data: () => {\n      // slice utf buffer if over-allocated\n      const dlen = (0,_util__WEBPACK_IMPORTED_MODULE_0__.ceil64Bytes)(idx);\n      const data = buf.length > dlen ? buf.subarray(0, dlen) : buf;\n      return { type, length, buffers: [offset, data] };\n    }\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/utf8-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/util.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/util.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   array: () => (/* binding */ array),\n/* harmony export */   arrowData: () => (/* binding */ arrowData),\n/* harmony export */   arrowVector: () => (/* binding */ arrowVector),\n/* harmony export */   ceil64Bytes: () => (/* binding */ ceil64Bytes),\n/* harmony export */   encode: () => (/* binding */ encode),\n/* harmony export */   encodeInto: () => (/* binding */ encodeInto),\n/* harmony export */   encoder: () => (/* binding */ encoder),\n/* harmony export */   writeUtf8: () => (/* binding */ writeUtf8)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n\n\nfunction ceil64Bytes(length, bpe = 1) {\n  return ((((length * bpe) + 63) & ~63) || 64) / bpe;\n}\n\nfunction array(Type, length, bpe = Type.BYTES_PER_ELEMENT) {\n  return new Type(ceil64Bytes(length, bpe));\n}\n\nfunction arrowData(d) {\n  return d instanceof apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Data\n    ? d\n    : apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Data.new(d.type, 0, d.length, d.nulls, d.buffers, null, d.dict);\n}\n\nfunction arrowVector(data) {\n  return apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Vector.new(arrowData(data));\n}\n\nconst encoder = new TextEncoder();\n\nfunction encode(data, idx, str) {\n  const bytes = encoder.encode(str);\n  data.set(bytes, idx);\n  return bytes.length;\n}\n\nfunction encodeInto(data, idx, str) {\n  return encoder.encodeInto(str, data.subarray(idx)).written;\n}\n\nconst writeUtf8 = encoder.encodeInto ? encodeInto : encode;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/util.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/builder/valid-builder.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/builder/valid-builder.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(builder, length) {\n  const valid = (0,_util__WEBPACK_IMPORTED_MODULE_0__.array)(Uint8Array, length / 8);\n  let nulls = 0;\n\n  return {\n    set(value, index) {\n      if (value == null) {\n        ++nulls;\n      } else {\n        builder.set(value, index);\n        valid[index >> 3] |= (1 << (index % 8));\n      }\n    },\n    data: () => {\n      const d = builder.data();\n      if (nulls) {\n        d.nulls = nulls;\n        d.buffers[2] = valid;\n      }\n      return d;\n    }\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/builder/valid-builder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/data-from-objects.js":
/*!************************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/data-from-objects.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _data_from__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./data-from */ \"../../node_modules/arquero/src/arrow/encode/data-from.js\");\n/* harmony import */ var _profiler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./profiler */ \"../../node_modules/arquero/src/arrow/encode/profiler.js\");\n/* harmony import */ var _builder_resolve_type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder/resolve-type */ \"../../node_modules/arquero/src/arrow/builder/resolve-type.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(data, name, nrows, scan, type, nullable = true) {\n  type = (0,_builder_resolve_type__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(type);\n\n  // perform type inference if needed\n  if (!type) {\n    const p = (0,_profiler__WEBPACK_IMPORTED_MODULE_1__.profile)(scan, name);\n    nullable = p.nulls > 0;\n    type = p.type();\n  }\n\n  return (0,_data_from__WEBPACK_IMPORTED_MODULE_0__.dataFromScan)(nrows, scan, name, type, nullable);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/data-from-objects.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/data-from-table.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/data-from-table.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n/* harmony import */ var _data_from__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./data-from */ \"../../node_modules/arquero/src/arrow/encode/data-from.js\");\n/* harmony import */ var _profiler__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./profiler */ \"../../node_modules/arquero/src/arrow/encode/profiler.js\");\n/* harmony import */ var _builder_resolve_type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../builder/resolve-type */ \"../../node_modules/arquero/src/arrow/builder/resolve-type.js\");\n/* harmony import */ var _util_is_typed_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/is-typed-array */ \"../../node_modules/arquero/src/util/is-typed-array.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, name, nrows, scan, type, nullable = true) {\n  type = (0,_builder_resolve_type__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(type);\n  const column = table.column(name);\n  const reified = !(table.isFiltered() || table.isOrdered());\n\n  // use existing arrow data if types match\n  const vec = arrowVector(column);\n  if (vec && reified && typeCompatible(vec.type, type)) {\n    return vec;\n  }\n\n  // if backing data is a typed array, leverage that\n  const data = column.data;\n  if ((0,_util_is_typed_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(data)) {\n    const dtype = typeFromArray(data);\n    if (reified && dtype && typeCompatible(dtype, type)) {\n      return (0,_data_from__WEBPACK_IMPORTED_MODULE_1__.dataFromArray)(data, dtype);\n    } else {\n      type = type || dtype;\n      nullable = false;\n    }\n  }\n\n  // perform type inference if needed\n  if (!type) {\n    const p = (0,_profiler__WEBPACK_IMPORTED_MODULE_2__.profile)(scan, column);\n    nullable = p.nulls > 0;\n    type = p.type();\n  }\n\n  return (0,_data_from__WEBPACK_IMPORTED_MODULE_1__.dataFromScan)(nrows, scan, column, type, nullable);\n}\n\nfunction arrowVector(value) {\n  return value instanceof apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Vector ? value\n    : value.vector instanceof apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Vector ? value.vector\n    : null;\n}\n\nfunction typeFromArray(data) {\n  const types = {\n    Float32Array:    apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Float32,\n    Float64Array:    apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Float64,\n    Int8Array:       apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int8,\n    Int16Array:      apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int16,\n    Int32Array:      apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int32,\n    Uint8Array:      apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint8,\n    Uint16Array:     apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint16,\n    Uint32Array:     apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint32,\n    BigInt64Array:   apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Int64,\n    BigUint64Array:  apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Uint64\n  };\n  const Type = types[data.constructor.name];\n  return Type ? new Type() : null;\n}\n\nfunction typeCompatible(a, b) {\n  return !a || !b ? true : a.compareTo(b);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/data-from-table.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/data-from.js":
/*!****************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/data-from.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   dataFromArray: () => (/* binding */ dataFromArray),\n/* harmony export */   dataFromScan: () => (/* binding */ dataFromScan)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/arquero/src/arrow/builder/index.js\");\n/* harmony import */ var _builder_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder/util */ \"../../node_modules/arquero/src/arrow/builder/util.js\");\n\n\n\nfunction dataFromArray(array, type) {\n  const length = array.length;\n  const size = (0,_builder_util__WEBPACK_IMPORTED_MODULE_1__.ceil64Bytes)(length, array.BYTES_PER_ELEMENT);\n\n  let data = array;\n  if (length !== size) {\n    data = new array.constructor(size);\n    data.set(array);\n  }\n\n  return (0,_builder_util__WEBPACK_IMPORTED_MODULE_1__.arrowData)({ type, length, buffers: [null, data] });\n}\n\nfunction dataFromScan(nrows, scan, column, type, nullable = true) {\n  const b = (0,_builder__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(type, nrows, nullable);\n  scan(column, b.set);\n  return (0,_builder_util__WEBPACK_IMPORTED_MODULE_1__.arrowData)(b.data());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/data-from.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/index.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/index.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n/* harmony import */ var _data_from_objects__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./data-from-objects */ \"../../node_modules/arquero/src/arrow/encode/data-from-objects.js\");\n/* harmony import */ var _data_from_table__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./data-from-table */ \"../../node_modules/arquero/src/arrow/encode/data-from-table.js\");\n/* harmony import */ var _scan__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./scan */ \"../../node_modules/arquero/src/arrow/encode/scan.js\");\n/* harmony import */ var _arrow_table__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../arrow-table */ \"../../node_modules/arquero/src/arrow/arrow-table.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n\n\n\n\n/**\n * Options for Arrow encoding.\n * @typedef {object} ArrowFormatOptions\n * @property {number} [limit=Infinity] The maximum number of rows to include.\n * @property {number} [offset=0] The row offset indicating how many initial\n *  rows to skip.\n * @property {string[]|(data: object) => string[]} [columns] Ordered list of\n *  column names to include. If function-valued, the function should accept\n *  a dataset as input and return an array of column name strings.\n * @property {object} [types] The Arrow data types to use. If specified,\n *  the input should be an object with column names for keys and Arrow data\n *  types for values. If a column type is not explicitly provided, type\n *  inference will be performed to guess an appropriate type.\n */\n\n/**\n * Create an Apache Arrow table for an input dataset.\n * @param {Array|object} data An input dataset to convert to Arrow format.\n *  If array-valued, the data should consist of an array of objects where\n *  each entry represents a row and named properties represent columns.\n *  Otherwise, the input data should be an Arquero table.\n * @param {ArrowFormatOptions} [options] Encoding options, including\n *  column data types.\n * @return {Table} An Apache Arrow Table instance.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(data, options = {}) {\n  const { types = {} } = options;\n  const { dataFrom, names, nrows, scan } = init(data, options);\n  return (0,_arrow_table__WEBPACK_IMPORTED_MODULE_4__.table)().new(\n    names.map(name => {\n      const col = dataFrom(data, name, nrows, scan, types[name]);\n      return col.length === nrows\n        ? col\n        : (0,_util_error__WEBPACK_IMPORTED_MODULE_5__[\"default\"])('Column length mismatch');\n    }),\n    names\n  );\n}\n\nfunction init(data, options) {\n  const { columns, limit = Infinity, offset = 0 } = options;\n  const names = (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(columns) ? columns(data)\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(columns) ? columns\n    : null;\n  if ((0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(data)) {\n    return {\n      dataFrom: _data_from_objects__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n      names: names || Object.keys(data[0]),\n      nrows: Math.min(limit, data.length - offset),\n      scan: (0,_scan__WEBPACK_IMPORTED_MODULE_3__.scanArray)(data, limit, offset)\n    };\n  } else if (isTable(data)) {\n    return {\n      dataFrom: _data_from_table__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n      names: names || data.columnNames(),\n      nrows: Math.min(limit, data.numRows() - offset),\n      scan: (0,_scan__WEBPACK_IMPORTED_MODULE_3__.scanTable)(data, limit, offset)\n    };\n  } else {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_5__[\"default\"])('Unsupported input data type');\n  }\n}\n\nfunction isTable(data) {\n  return data && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(data.reify);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/profiler.js":
/*!***************************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/profiler.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   profile: () => (/* binding */ profile),\n/* harmony export */   profiler: () => (/* binding */ profiler)\n/* harmony export */ });\n/* harmony import */ var apache_arrow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! apache-arrow */ \"../../node_modules/apache-arrow/Arrow.dom.mjs\");\n/* harmony import */ var _arrow_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../arrow-types */ \"../../node_modules/arquero/src/arrow/arrow-types.js\");\n/* harmony import */ var _builder_resolve_type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder/resolve-type */ \"../../node_modules/arquero/src/arrow/builder/resolve-type.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_array_type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/is-array-type */ \"../../node_modules/arquero/src/util/is-array-type.js\");\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n/* harmony import */ var _util_is_exact_utc_date__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util/is-exact-utc-date */ \"../../node_modules/arquero/src/util/is-exact-utc-date.js\");\n\n\n\n\n\n\n\n\nfunction profile(scan, column) {\n  const p = profiler();\n  scan(column, p.add);\n  return p;\n}\n\nfunction profiler() {\n  const p = {\n    count: 0,\n    nulls: 0,\n    bools: 0,\n    nums: 0,\n    ints: 0,\n    bigints: 0,\n    min: Infinity,\n    max: -Infinity,\n    digits: 0,\n    dates: 0,\n    utcdays: 0,\n    strings: 0,\n    strlen: 0,\n    arrays: 0,\n    minlen: Infinity,\n    maxlen: 0,\n    structs: 0,\n\n    add(value) {\n      ++p.count;\n      if (value == null) {\n        ++p.nulls;\n        return;\n      }\n\n      const type = typeof value;\n      if (type === 'string') {\n        ++p.strings;\n      } else if (type === 'number') {\n        ++p.nums;\n        if (value < p.min) p.min = value;\n        if (value > p.max) p.max = value;\n        if (Number.isInteger(value)) ++p.ints;\n      } else if (type === 'boolean') {\n        ++p.bools;\n      } else if (type === 'object') {\n        if ((0,_util_is_date__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(value)) {\n          ++p.dates;\n          if ((0,_util_is_exact_utc_date__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value)) {\n            ++p.utcdays;\n          }\n        } else if ((0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value)) {\n          ++p.arrays;\n          if (value.length < p.minlen) p.minlen = value.length;\n          if (value.length > p.maxlen) p.maxlen = value.length;\n          const ap = p.array_prof || (p.array_prof = profiler());\n          value.forEach(ap.add);\n        } else {\n          ++p.structs;\n          const sp = p.struct_prof || (p.struct_prof = {});\n          for (const key in value) {\n            const fp = sp[key] || (sp[key] = profiler());\n            fp.add(value[key]);\n          }\n        }\n      } else if (type === 'bigint') {\n        ++p.bigints;\n        if (value < p.min) p.min = value;\n        if (value > p.max) p.max = value;\n      }\n    },\n    type() {\n      return (0,_builder_resolve_type__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(infer(p));\n    }\n  };\n\n  return p;\n}\n\nfunction infer(p) {\n  const valid = p.count - p.nulls;\n\n  if (valid === 0) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Null;\n  }\n  else if (p.ints === valid) {\n    const v = Math.max(Math.abs(p.min) - 1, p.max);\n    return p.min < 0\n      ? v >= 2 ** 31 ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float64\n        : v < (1 << 7) ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int8 : v < (1 << 15) ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int16 : _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int32\n      : v >= 2 ** 32 ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float64\n        : v < (1 << 8) ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint8 : v < (1 << 16) ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint16 : _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint32;\n  }\n  else if (p.nums === valid) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Float64;\n  }\n  else if (p.bigints === valid) {\n    const v = -p.min > p.max ? -p.min - 1n : p.max;\n    return p.min < 0\n      ? v < 2 ** 63 ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Int64\n        : (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(`BigInt exceeds 64 bits: ${v}`)\n      : p.max < 2 ** 64 ? _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Uint64\n        : (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(`BigInt exceeds 64 bits: ${p.max}`);\n  }\n  else if (p.bools === valid) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Bool;\n  }\n  else if (p.utcdays === valid) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].DateDay;\n  }\n  else if (p.dates === valid) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].DateMillisecond;\n  }\n  else if (p.arrays === valid) {\n    const type = apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Field.new('value', p.array_prof.type(), true);\n    return p.minlen === p.maxlen\n      ? new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.FixedSizeList(p.minlen, type)\n      : new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.List(type);\n  }\n  else if (p.structs === valid) {\n    const sp = p.struct_prof;\n    return new apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Struct(\n      Object.keys(sp).map(name => apache_arrow__WEBPACK_IMPORTED_MODULE_0__.Field.new(name, sp[name].type(), true))\n    );\n  }\n  else if (p.strings > 0) {\n    return _arrow_types__WEBPACK_IMPORTED_MODULE_1__[\"default\"].Dictionary;\n  }\n  else {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])('Type inference failure');\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/profiler.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/arrow/encode/scan.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/arrow/encode/scan.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   scanArray: () => (/* binding */ scanArray),\n/* harmony export */   scanTable: () => (/* binding */ scanTable)\n/* harmony export */ });\n/* harmony import */ var _util_is_array_type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/is-array-type */ \"../../node_modules/arquero/src/util/is-array-type.js\");\n\n\nfunction scanArray(data, limit, offset) {\n  const n = Math.min(data.length, offset + limit);\n  return (name, visit) => {\n    for (let i = offset; i < n; ++i) {\n      visit(data[i][name], i);\n    }\n  };\n}\n\nfunction scanTable(table, limit, offset) {\n  const scanAll = offset === 0 && table.numRows() <= limit\n               && !table.isFiltered() && !table.isOrdered();\n\n  return (column, visit) => {\n    let i = -1;\n    scanAll && (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(column.data)\n      ? column.data.forEach(visit)\n      : table.scan(\n          row => visit(column.get(row), ++i),\n          true, limit, offset\n        );\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/arrow/encode/scan.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/concat.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/concat.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, others) {\n  const trows = table.numRows();\n  const nrows = trows + others.reduce((n, t) => n + t.numRows(), 0);\n  if (trows === nrows) return table;\n\n  const tables = [table, ...others];\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_0__[\"default\"])();\n\n  table.columnNames().forEach(name => {\n    const arr = Array(nrows);\n    let row = 0;\n    tables.forEach(table => {\n      const col = table.column(name) || { get: () => _util_null__WEBPACK_IMPORTED_MODULE_1__[\"default\"] };\n      table.scan(trow => arr[row++] = col.get(trow));\n    });\n    cols.add(name, arr);\n  });\n\n  return table.create(cols.new());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/concat.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/derive.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/derive.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _window_window__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./window/window */ \"../../node_modules/arquero/src/engine/window/window.js\");\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../op */ \"../../node_modules/arquero/src/op/index.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_repeat__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/repeat */ \"../../node_modules/arquero/src/util/repeat.js\");\n\n\n\n\n\n\nfunction isWindowed(op) {\n  return (0,_op__WEBPACK_IMPORTED_MODULE_2__.hasWindow)(op.name) ||\n    op.frame && (\n      Number.isFinite(op.frame[0]) ||\n      Number.isFinite(op.frame[1])\n    );\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, { names, exprs, ops }, options = {}) {\n  // instantiate output data\n  const total = table.totalRows();\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(options.drop ? null : table);\n  const data = names.map(name => cols.add(name, Array(total)));\n\n  // analyze operations, compute non-windowed aggregates\n  const [ aggOps, winOps ] = segmentOps(ops);\n\n  const size = table.isGrouped() ? table.groups().size : 1;\n  const result = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_1__.aggregate)(\n    table, aggOps,\n    (0,_util_repeat__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(ops.length, () => Array(size))\n  );\n\n  // perform table scans to generate output values\n  winOps.length\n    ? (0,_window_window__WEBPACK_IMPORTED_MODULE_0__.window)(table, data, exprs, result, winOps)\n    : output(table, data, exprs, result);\n\n  return table.create(cols);\n}\n\nfunction segmentOps(ops) {\n  const aggOps = [];\n  const winOps = [];\n  const n = ops.length;\n\n  for (let i = 0; i < n; ++i) {\n    const op = ops[i];\n    op.id = i;\n    (isWindowed(op) ? winOps : aggOps).push(op);\n  }\n\n  return [aggOps, winOps];\n}\n\nfunction output(table, cols, exprs, result) {\n  const bits = table.mask();\n  const data = table.data();\n  const { keys } = table.groups() || {};\n  const op = keys\n    ? (id, row) => result[id][keys[row]]\n    : id => result[id][0];\n\n  const m = cols.length;\n  for (let j = 0; j < m; ++j) {\n    const get = exprs[j];\n    const col = cols[j];\n\n    // inline the following for performance:\n    // table.scan((i, data) => col[i] = get(i, data, op));\n    if (bits) {\n      for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n        col[i] = get(i, data, op);\n      }\n    } else {\n      const n = table.totalRows();\n      for (let i = 0; i < n; ++i) {\n        col[i] = get(i, data, op);\n      }\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/derive.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/filter.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/filter.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_bit_set__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/bit-set */ \"../../node_modules/arquero/src/table/bit-set.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, predicate) {\n  const n = table.totalRows();\n  const bits = table.mask();\n  const data = table.data();\n  const filter = new _table_bit_set__WEBPACK_IMPORTED_MODULE_0__[\"default\"](n);\n\n  // inline the following for performance:\n  // table.scan((row, data) => { if (predicate(row, data)) filter.set(row); });\n  if (bits) {\n    for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n      if (predicate(i, data)) filter.set(i);\n    }\n  } else {\n    for (let i = 0; i < n; ++i) {\n      if (predicate(i, data)) filter.set(i);\n    }\n  }\n\n  return table.create({ filter });\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/filter.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/fold.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/engine/fold.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _unroll__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./unroll */ \"../../node_modules/arquero/src/engine/unroll.js\");\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, { names = [], exprs = [], ops = [] }, options = {}) {\n  if (names.length === 0) return table;\n\n  const [k = 'key', v = 'value'] = options.as || [];\n  const vals = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_1__.aggregateGet)(table, ops, exprs);\n\n  return (0,_unroll__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    table,\n    {\n      names: [k, v],\n      exprs: [() => names, (row, data) => vals.map(fn => fn(row, data))]\n    },\n    { ...options, drop: names }\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/fold.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/groupby.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/engine/groupby.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _util_key_function__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/key-function */ \"../../node_modules/arquero/src/util/key-function.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, exprs) {\n  return table.create({\n    groups: createGroups(table, exprs)\n  });\n}\n\nfunction createGroups(table, { names = [], exprs = [], ops = [] }) {\n  const n = names.length;\n  if (n === 0) return null;\n\n  // check for optimized path when grouping by a single field\n  // use pre-calculated groups if available\n  if (n === 1 && !table.isFiltered() && exprs[0].field) {\n    const col = table.column(exprs[0].field);\n    if (col.groups) return col.groups(names);\n  }\n\n  let get = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregateGet)(table, ops, exprs);\n  const getKey = (0,_util_key_function__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(get);\n  const nrows = table.totalRows();\n  const keys = new Uint32Array(nrows);\n  const index = {};\n  const rows = [];\n\n  // inline table scan for performance\n  const data = table.data();\n  const bits = table.mask();\n  if (bits) {\n    for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n      const key = getKey(i, data) + '';\n      const val = index[key];\n      keys[i] = val != null ? val : (index[key] = rows.push(i) - 1);\n    }\n  } else {\n    for (let i = 0; i < nrows; ++i) {\n      const key = getKey(i, data) + '';\n      const val = index[key];\n      keys[i] = val != null ? val : (index[key] = rows.push(i) - 1);\n    }\n  }\n\n  if (!ops.length) {\n    // capture data in closure, so no interaction with select\n    get = get.map(f => row => f(row, data));\n  }\n\n  return { keys, get, names, rows, size: rows.length };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/groupby.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/impute.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/impute.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_is_valid__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-valid */ \"../../node_modules/arquero/src/util/is-valid.js\");\n/* harmony import */ var _util_key_function__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/key-function */ \"../../node_modules/arquero/src/util/key-function.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, keys, arrays) {\n  const write = keys && keys.length;\n  return impute(\n    write ? expand(table, keys, arrays) : table,\n    values,\n    write\n  );\n}\n\nfunction impute(table, { names, exprs, ops }, write) {\n  const gets = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregateGet)(table, ops, exprs);\n  const cols = write ? null : (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table);\n  const rows = table.totalRows();\n\n  names.forEach((name, i) => {\n    const col = table.column(name);\n    const out = write ? col.data : cols.add(name, Array(rows));\n    const get = gets[i];\n\n    table.scan(idx => {\n      const v = col.get(idx);\n      out[idx] = !(0,_util_is_valid__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(v) ? get(idx) : v;\n    });\n  });\n\n  return write ? table : table.create(cols);\n}\n\nfunction expand(table, keys, values) {\n  const groups = table.groups();\n  const data = table.data();\n\n  // expansion keys and accessors\n  const keyNames = (groups ? groups.names : []).concat(keys);\n  const keyGet = (groups ? groups.get : [])\n    .concat(keys.map(key => table.getter(key)));\n\n  // build hash of existing rows\n  const hash = new Set();\n  const keyTable = (0,_util_key_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(keyGet);\n  table.scan((idx, data) => hash.add(keyTable(idx, data)));\n\n  // initialize output table data\n  const names = table.columnNames();\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const out = names.map(name => cols.add(name, []));\n  names.forEach((name, i) => {\n    const old = data[name];\n    const col = out[i];\n    table.scan(row => col.push(old.get(row)));\n  });\n\n  // enumerate expanded value sets and augment output table\n  const keyEnum = (0,_util_key_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(keyGet.map((k, i) => a => a[i]));\n  const set = (0,_util_unroll__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(\n    'v',\n    '{' + out.map((_, i) => `_${i}.push(v[$${i}]);`).join('') + '}',\n    out, names.map(name => keyNames.indexOf(name))\n  );\n\n  if (groups) {\n    let row = groups.keys.length;\n    const prod = values.reduce((p, a) => p * a.length, groups.size);\n    const keys = new Uint32Array(prod + (row - hash.size));\n    keys.set(groups.keys);\n    enumerate(groups, values, (vec, idx) => {\n      if (!hash.has(keyEnum(vec))) {\n        set(vec);\n        keys[row++] = idx[0];\n      }\n    });\n    cols.groupby({ ...groups, keys });\n  } else {\n    enumerate(groups, values, vec => {\n      if (!hash.has(keyEnum(vec))) set(vec);\n    });\n  }\n\n  return table.create(cols.new());\n}\n\nfunction enumerate(groups, values, callback) {\n  const offset = groups ? groups.get.length : 0;\n  const pad = groups ? 1 : 0;\n  const len = pad + values.length;\n  const lens = new Int32Array(len);\n  const idxs = new Int32Array(len);\n  const set = [];\n\n  if (groups) {\n    const { get, rows, size } = groups;\n    lens[0] = size;\n    set.push((vec, idx) => {\n      const row = rows[idx];\n      for (let i = 0; i < offset; ++i) {\n        vec[i] = get[i](row);\n      }\n    });\n  }\n\n  values.forEach((a, i) => {\n    const j = i + offset;\n    lens[i + pad] = a.length;\n    set.push((vec, idx) => vec[j] = a[idx]);\n  });\n\n  const vec = Array(offset + values.length);\n\n  // initialize value vector\n  for (let i = 0; i < len; ++i) {\n    set[i](vec, 0);\n  }\n  callback(vec, idxs);\n\n  // enumerate all combinations of values\n  for (let i = len - 1; i >= 0;) {\n    const idx = ++idxs[i];\n    if (idx < lens[i]) {\n      set[i](vec, idx);\n      callback(vec, idxs);\n      i = len - 1;\n    } else {\n      idxs[i] = 0;\n      set[i](vec, 0);\n      --i;\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/impute.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/join-filter.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/join-filter.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _join_lookup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./join/lookup */ \"../../node_modules/arquero/src/engine/join/lookup.js\");\n/* harmony import */ var _table_bit_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/bit-set */ \"../../node_modules/arquero/src/table/bit-set.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, predicate, options = {}) {\n  // calculate semi-join filter mask\n  const filter = new _table_bit_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"](tableL.totalRows());\n  const join = (0,_util_is_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(predicate) ? hashSemiJoin : loopSemiJoin;\n  join(filter, tableL, tableR, predicate);\n\n  // if anti-join, negate the filter\n  if (options.anti) {\n    filter.not().and(tableL.mask());\n  }\n\n  return tableL.create({ filter });\n}\n\nfunction hashSemiJoin(filter, tableL, tableR, [keyL, keyR]) {\n  // build lookup table\n  const lut = (0,_join_lookup__WEBPACK_IMPORTED_MODULE_0__.rowLookup)(tableR, keyR);\n\n  // scan table, update filter with matches\n  tableL.scan((rowL, data) => {\n    const rowR = lut.get(keyL(rowL, data));\n    if (rowR >= 0) filter.set(rowL);\n  });\n}\n\nfunction loopSemiJoin(filter, tableL, tableR, predicate) {\n  const nL = tableL.numRows();\n  const nR = tableR.numRows();\n  const dataL = tableL.data();\n  const dataR = tableR.data();\n\n  if (tableL.isFiltered() || tableR.isFiltered()) {\n    // use indices as at least one table is filtered\n    const idxL = tableL.indices(false);\n    const idxR = tableR.indices(false);\n    for (let i = 0; i < nL; ++i) {\n      const rowL = idxL[i];\n      for (let j = 0; j < nR; ++j) {\n        if (predicate(rowL, dataL, idxR[j], dataR)) {\n          filter.set(rowL);\n          break;\n        }\n      }\n    }\n  } else {\n    // no filters, enumerate row indices directly\n    for (let i = 0; i < nL; ++i) {\n      for (let j = 0; j < nR; ++j) {\n        if (predicate(i, dataL, j, dataR)) {\n          filter.set(i);\n          break;\n        }\n      }\n    }\n  }\n}\n\n// export default function(tableL, tableR, predicate, options = {}) {\n//   const filter = new BitSet(tableL.totalRows());\n//   const nL = tableL.numRows();\n//   const nR = tableR.numRows();\n//   const dataL = tableL.data();\n//   const dataR = tableR.data();\n\n//   if (tableL.isFiltered() || tableR.isFiltered()) {\n//     // use indices as at least one table is filtered\n//     const idxL = tableL.indices(false);\n//     const idxR = tableR.indices(false);\n//     for (let i = 0; i < nL; ++i) {\n//       const rowL = idxL[i];\n//       for (let j = 0; j < nR; ++j) {\n//         if (predicate(rowL, dataL, idxR[j], dataR)) {\n//           filter.set(rowL);\n//           break;\n//         }\n//       }\n//     }\n//   } else {\n//     // no filters, enumerate row indices directly\n//     for (let i = 0; i < nL; ++i) {\n//       for (let j = 0; j < nR; ++j) {\n//         if (predicate(i, dataL, j, dataR)) {\n//           filter.set(i);\n//           break;\n//         }\n//       }\n//     }\n//   }\n\n//   // if anti-join, negate the filter\n//   if (options.anti) {\n//     filter.not().and(tableL.mask());\n//   }\n\n//   return tableL.create({ filter });\n// }\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/join-filter.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/join.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/engine/join.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _join_lookup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./join/lookup */ \"../../node_modules/arquero/src/engine/join/lookup.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/concat */ \"../../node_modules/arquero/src/util/concat.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n\n\n\n\n\n\nfunction emitter(columns, getters) {\n  const args = ['i', 'a', 'j', 'b'];\n  return (0,_util_unroll__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(\n    args,\n    '{' + (0,_util_concat__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(columns, (_, i) => `_${i}.push($${i}(${args}));`) + '}',\n    columns, getters\n  );\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, predicate, { names, exprs }, options = {}) {\n  // initialize data for left table\n  const dataL = tableL.data();\n  const idxL = tableL.indices(false);\n  const nL = idxL.length;\n  const hitL = new Int32Array(nL);\n\n  // initialize data for right table\n  const dataR = tableR.data();\n  const idxR = tableR.indices(false);\n  const nR = idxR.length;\n  const hitR = new Int32Array(nR);\n\n  // initialize output data\n  const ncols = names.length;\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const columns = Array(ncols);\n  const getters = Array(ncols);\n  for (let i = 0; i < names.length; ++i) {\n    columns[i] = cols.add(names[i], []);\n    getters[i] = exprs[i];\n  }\n  const emit = emitter(columns, getters);\n\n  // perform join\n  const join = (0,_util_is_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(predicate) ? hashJoin : loopJoin;\n  join(emit, predicate, dataL, dataR, idxL, idxR, hitL, hitR, nL, nR);\n\n  if (options.left) {\n    for (let i = 0; i < nL; ++i) {\n      if (!hitL[i]) {\n        emit(idxL[i], dataL, -1, dataR);\n      }\n    }\n  }\n\n  if (options.right) {\n    for (let j = 0; j < nR; ++j) {\n      if (!hitR[j]) {\n        emit(-1, dataL, idxR[j], dataR);\n      }\n    }\n  }\n\n  return tableL.create(cols.new());\n}\n\nfunction loopJoin(emit, predicate, dataL, dataR, idxL, idxR, hitL, hitR, nL, nR) {\n  // perform nested-loops join\n  for (let i = 0; i < nL; ++i) {\n    const rowL = idxL[i];\n    for (let j = 0; j < nR; ++j) {\n      const rowR = idxR[j];\n      if (predicate(rowL, dataL, rowR, dataR)) {\n        emit(rowL, dataL, rowR, dataR);\n        hitL[i] = 1;\n        hitR[j] = 1;\n      }\n    }\n  }\n}\n\nfunction hashJoin(emit, [keyL, keyR], dataL, dataR, idxL, idxR, hitL, hitR, nL, nR) {\n  // determine which table to hash\n  let dataScan, keyScan, hitScan, idxScan;\n  let dataHash, keyHash, hitHash, idxHash;\n  let emitScan = emit;\n  if (nL >= nR) {\n    dataScan = dataL; keyScan = keyL; hitScan = hitL; idxScan = idxL;\n    dataHash = dataR; keyHash = keyR; hitHash = hitR; idxHash = idxR;\n  } else {\n    dataScan = dataR; keyScan = keyR; hitScan = hitR; idxScan = idxR;\n    dataHash = dataL; keyHash = keyL; hitHash = hitL; idxHash = idxL;\n    emitScan = (i, a, j, b) => emit(j, b, i, a);\n  }\n\n  // build lookup table\n  const lut = (0,_join_lookup__WEBPACK_IMPORTED_MODULE_0__.indexLookup)(idxHash, dataHash, keyHash);\n\n  // scan other table\n  const m = idxScan.length;\n  for (let j = 0; j < m; ++j) {\n    const rowScan = idxScan[j];\n    const list = lut.get(keyScan(rowScan, dataScan));\n    if (list) {\n      const n = list.length;\n      for (let k = 0; k < n; ++k) {\n        const i = list[k];\n        emitScan(rowScan, dataScan, idxHash[i], dataHash);\n        hitHash[i] = 1;\n      }\n      hitScan[j] = 1;\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/join.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/join/lookup.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/join/lookup.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   indexLookup: () => (/* binding */ indexLookup),\n/* harmony export */   rowLookup: () => (/* binding */ rowLookup)\n/* harmony export */ });\nfunction rowLookup(table, hash) {\n  const lut = new Map();\n  table.scan((row, data) => {\n    const key = hash(row, data);\n    if (key != null && key === key) {\n      lut.set(key, row);\n    }\n  });\n  return lut;\n}\n\nfunction indexLookup(idx, data, hash) {\n  const lut = new Map();\n  const n = idx.length;\n  for (let i = 0; i < n; ++i) {\n    const row = idx[i];\n    const key = hash(row, data);\n    if (key != null && key === key) {\n      lut.has(key)\n        ? lut.get(key).push(i)\n        : lut.set(key, [i]);\n    }\n  }\n  return lut;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/join/lookup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/lookup.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/lookup.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _join_lookup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./join/lookup */ \"../../node_modules/arquero/src/engine/join/lookup.js\");\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _util_concat__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/concat */ \"../../node_modules/arquero/src/util/concat.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, [keyL, keyR], { names, exprs, ops }) {\n  // instantiate output data\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(tableL);\n  const total = tableL.totalRows();\n  names.forEach(name => cols.add(name, Array(total).fill(_util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"])));\n\n  // build lookup table\n  const lut = (0,_join_lookup__WEBPACK_IMPORTED_MODULE_0__.rowLookup)(tableR, keyR);\n\n  // generate setter function for lookup match\n  const set = (0,_util_unroll__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(\n    ['lr', 'rr', 'data'],\n    '{' + (0,_util_concat__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(names, (_, i) => `_[${i}][lr] = $[${i}](rr, data);`) + '}',\n    names.map(name => cols.data[name]),\n    (0,_reduce_util__WEBPACK_IMPORTED_MODULE_1__.aggregateGet)(tableR, ops, exprs)\n  );\n\n  // find matching rows, set values on match\n  const dataR = tableR.data();\n  tableL.scan((lrow, data) => {\n    const rrow = lut.get(keyL(lrow, data));\n    if (rrow >= 0) set(lrow, rrow, dataR);\n  });\n\n  return tableL.create(cols);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/lookup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/orderby.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/engine/orderby.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, comparator) {\n  return table.create({ order: comparator });\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/orderby.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/pivot.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/pivot.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n\n\n\nconst opt = (value, defaultValue) => value != null ? value : defaultValue;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, on, values, options = {}) {\n  const { keys, keyColumn } = pivotKeys(table, on, options);\n  const vsep = opt(options.valueSeparator, '_');\n  const namefn = values.names.length > 1\n    ? (i, name) => name + vsep + keys[i]\n    : i => keys[i];\n\n  // perform separate aggregate operations for each key\n  // if keys do not match, emit NaN so aggregate skips it\n  // use custom toString method for proper field resolution\n  const results = keys.map(\n    k => (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregate)(table, values.ops.map(op => {\n      const fields = op.fields.map(f => {\n        const fn = (r, d) => k === keyColumn[r] ? f(r, d) : NaN;\n        fn.toString = () => k + ':' + f + '';\n        return fn;\n      });\n      return { ...op, fields };\n    }))\n  );\n\n  return table.create(output(values, namefn, table.groups(), results));\n}\n\nfunction pivotKeys(table, on, options) {\n  const limit = options.limit > 0 ? +options.limit : Infinity;\n  const sort = opt(options.sort, true);\n  const ksep = opt(options.keySeparator, '_');\n\n  // construct key accessor function\n  const get = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregateGet)(table, on.ops, on.exprs);\n  const key = get.length === 1\n    ? get[0]\n    : (row, data) => get.map(fn => fn(row, data)).join(ksep);\n\n  // generate vector of per-row key values\n  const kcol = Array(table.totalRows());\n  table.scan((row, data) => kcol[row] = key(row, data));\n\n  // collect unique key values\n  const uniq = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregate)(\n    table.ungroup(),\n    [ {\n      id: 0,\n      name: 'array_agg_distinct',\n      fields: [(row => kcol[row])], params: []\n    } ]\n  )[0][0];\n\n  // get ordered set of unique key values\n  const keys = sort ? uniq.sort() : uniq;\n\n  // return key values\n  return {\n    keys: Number.isFinite(limit) ? keys.slice(0, limit) : keys,\n    keyColumn: kcol\n  };\n}\n\nfunction output({ names, exprs }, namefn, groups, results) {\n  const size = groups ? groups.size : 1;\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const m = results.length;\n  const n = names.length;\n\n  let result;\n  const op = (id, row) => result[id][row];\n\n  // write groupby fields to output\n  if (groups) (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.groupOutput)(cols, groups);\n\n  // write pivot values to output\n  for (let i = 0; i < n; ++i) {\n    const get = exprs[i];\n    if (get.field != null) {\n      // if expression is op only, use aggregates directly\n      for (let j = 0; j < m; ++j) {\n        cols.add(namefn(j, names[i]), results[j][get.field]);\n      }\n    } else if (size > 1) {\n      // if multiple groups, evaluate expression for each\n      for (let j = 0; j < m; ++j) {\n        result = results[j];\n        const col = cols.add(namefn(j, names[i]), Array(size));\n        for (let k = 0; k < size; ++k) {\n          col[k] = get(k, null, op);\n        }\n      }\n    } else {\n      // if only one group, no need to loop\n      for (let j = 0; j < m; ++j) {\n        result = results[j];\n        cols.add(namefn(j, names[i]), [ get(0, null, op) ]);\n      }\n    }\n  }\n\n  return cols.new();\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/pivot.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/reduce.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/reduce.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, reducer) {\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const groups = table.groups();\n\n  // initialize groups\n  const { get, names = [], rows, size = 1 } = groups || {};\n  const counts = new Uint32Array(size + 1);\n  names.forEach(name => cols.add(name, null));\n\n  // compute reduced values\n  const cells = groups\n    ? (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.reduceGroups)(table, reducer, groups)\n    : [ (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.reduceFlat)(table, reducer) ];\n\n  // initialize output columns\n  reducer.outputs().map(name => cols.add(name, []));\n\n  // write reduced values to output columns\n  const n = counts.length - 1;\n  let len = 0;\n  for (let i = 0; i < n; ++i) {\n    len += counts[i + 1] = reducer.write(cells[i], cols.data, counts[i]);\n  }\n\n  // write group values to output columns\n  if (groups) {\n    const data = table.data();\n    names.forEach((name, index) => {\n      const column = cols.data[name] = Array(len);\n      const getter = get[index];\n      for (let i = 0, j = 0; i < size; ++i) {\n        column.fill(getter(rows[i], data), j, j += counts[i + 1]);\n      }\n    });\n  }\n\n  return table.create(cols.new());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/reduce.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/reduce/field-reducer.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/reduce/field-reducer.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reducer */ \"../../node_modules/arquero/src/engine/reduce/reducer.js\");\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../op */ \"../../node_modules/arquero/src/op/index.js\");\n/* harmony import */ var _util_concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/concat */ \"../../node_modules/arquero/src/util/concat.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_valid__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/is-valid */ \"../../node_modules/arquero/src/util/is-valid.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n/* harmony import */ var _util_value_list__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util/value-list */ \"../../node_modules/arquero/src/util/value-list.js\");\n\n\n\n\n\n\n\n\nconst update = (ops, args, fn) => (0,_util_unroll__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(\n  args,\n  '{' + (0,_util_concat__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(ops, (_, i) => `_${i}.${fn}(${args});`) + '}',\n  ops\n);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(oplist, stream) {\n  const { ops, output } = expand(oplist, stream);\n  const fields = oplist[0].fields;\n  const n = fields.length;\n  const cls = n === 0 ? FieldReducer\n    : n === 1 ? Field1Reducer\n    : n === 2 ? Field2Reducer\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])('Unsupported field count: ' + n);\n  return new cls(fields, ops, output, stream);\n}\n\nfunction expand(oplist, stream) {\n  const has = {};\n  const ops = [];\n\n  function add(name, params = []) {\n    // check key\n    const key = name + ':' + params;\n    if (has[key]) return has[key];\n\n    // get op instance\n    const def = (0,_op__WEBPACK_IMPORTED_MODULE_1__.getAggregate)(name);\n    const op = def.create(...params);\n\n    // add required dependencies\n    if (stream < 0 && def.stream) {\n      def.stream.forEach(name => add(name, []));\n    }\n    if (def.req) {\n      def.req.forEach(name => add(name, []));\n    }\n\n    // update state\n    has[key] = op;\n    ops.push(op);\n\n    return op;\n  }\n\n  const output = oplist.map(item => {\n    const op = add(item.name, item.params);\n    op.output = item.id;\n    return op;\n  });\n\n  return { ops, output };\n}\n\nclass FieldReducer extends _reducer__WEBPACK_IMPORTED_MODULE_0__[\"default\"] {\n  constructor(fields, ops, outputs, stream) {\n    super(outputs);\n    this._op = ops;\n    this._fields = fields;\n    this._stream = !!stream;\n  }\n\n  init() {\n    const state = { count: 0, valid: 0, stream: this._stream };\n    this._op.forEach(op => op.init(state));\n\n    // value list requested\n    if (state.values) {\n      state.list = new _util_value_list__WEBPACK_IMPORTED_MODULE_6__[\"default\"]();\n    }\n\n    return state;\n  }\n\n  write(state, values, index) {\n    const op = this._outputs;\n    const n = op.length;\n    for (let i = 0; i < n; ++i) {\n      values[op[i].output][index] = op[i].value(state);\n    }\n    return 1;\n  }\n\n  _add() {\n  }\n\n  _rem() {\n  }\n\n  add(state) {\n    ++state.count;\n  }\n\n  rem(state) {\n    --state.count;\n  }\n}\n\nclass Field1Reducer extends FieldReducer {\n  constructor(fields, ops, outputs, stream) {\n    super(fields, ops, outputs, stream);\n\n    // unroll op invocations for performance\n    const args = ['state', 'v1', 'v2'];\n    this._add = update(ops, args, 'add');\n    this._rem = update(ops, args, 'rem');\n  }\n\n  add(state, row, data) {\n    const value = this._fields[0](row, data);\n    ++state.count;\n    if ((0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value)) {\n      ++state.valid;\n      if (state.list) state.list.add(value);\n      this._add(state, value);\n    }\n  }\n\n  rem(state, row, data) {\n    const value = this._fields[0](row, data);\n    --state.count;\n    if ((0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value)) {\n      --state.valid;\n      if (state.list) state.list.rem();\n      this._rem(state, value);\n    }\n  }\n}\n\nclass Field2Reducer extends FieldReducer {\n  constructor(fields, ops, outputs, stream) {\n    super(fields, ops, outputs, stream);\n\n    // unroll op invocations for performance\n    const args = ['state', 'v1', 'v2'];\n    this._add = update(ops, args, 'add');\n    this._rem = update(ops, args, 'rem');\n  }\n\n  add(state, row, data) {\n    const value1 = this._fields[0](row, data);\n    const value2 = this._fields[1](row, data);\n    ++state.count;\n    if ((0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value1) && (0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value2)) {\n      ++state.valid;\n      if (state.list) state.list.add([value1, value2]);\n      this._add(state, value1, value2);\n    }\n  }\n\n  rem(state, row, data) {\n    const value1 = this._fields[0](row, data);\n    const value2 = this._fields[1](row, data);\n    --state.count;\n    if ((0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value1) && (0,_util_is_valid__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value2)) {\n      --state.valid;\n      if (state.list) state.list.rem();\n      this._rem(state, value1, value2);\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/reduce/field-reducer.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/reduce/reducer.js":
/*!***************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/reduce/reducer.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Reducer)\n/* harmony export */ });\n/**\n * Abstract class for custom aggregation operations.\n */\nclass Reducer {\n  constructor(outputs) {\n    this._outputs = outputs;\n  }\n\n  size() {\n    return this._outputs.length;\n  }\n\n  outputs() {\n    return this._outputs;\n  }\n\n  init(/* columns */) {\n    return {};\n  }\n\n  add(/* state, row, data */) {\n    // no-op, subclasses should override\n  }\n\n  rem(/* state, row, data */) {\n    // no-op, subclasses should override\n  }\n\n  write(/* state, values, index */) {\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/reduce/reducer.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/reduce/util.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/reduce/util.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   aggregate: () => (/* binding */ aggregate),\n/* harmony export */   aggregateGet: () => (/* binding */ aggregateGet),\n/* harmony export */   groupOutput: () => (/* binding */ groupOutput),\n/* harmony export */   reduceFlat: () => (/* binding */ reduceFlat),\n/* harmony export */   reduceGroups: () => (/* binding */ reduceGroups),\n/* harmony export */   reducers: () => (/* binding */ reducers)\n/* harmony export */ });\n/* harmony import */ var _field_reducer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./field-reducer */ \"../../node_modules/arquero/src/engine/reduce/field-reducer.js\");\n/* harmony import */ var _util_repeat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/repeat */ \"../../node_modules/arquero/src/util/repeat.js\");\n\n\n\nfunction aggregateGet(table, ops, get) {\n  if (ops.length) {\n    const data = table.data();\n    const { keys } = table.groups() || {};\n    const result = aggregate(table, ops);\n    const op = keys\n      ? (name, row) => result[name][keys[row]]\n      : name => result[name][0];\n    get = get.map(f => row => f(row, data, op));\n  }\n\n  return get;\n}\n\nfunction aggregate(table, ops, result) {\n  if (!ops.length) return result; // early exit\n\n  // instantiate aggregators and result store\n  const aggrs = reducers(ops);\n  const groups = table.groups();\n  const size = groups ? groups.size : 1;\n  result = result || (0,_util_repeat__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(ops.length, () => Array(size));\n\n  // compute aggregates, extract results\n  if (size > 1) {\n    aggrs.forEach(aggr => {\n      const cells = reduceGroups(table, aggr, groups);\n      for (let i = 0; i < size; ++i) {\n        aggr.write(cells[i], result, i);\n      }\n    });\n  } else {\n    aggrs.forEach(aggr => {\n      const cell = reduceFlat(table, aggr);\n      aggr.write(cell, result, 0);\n    });\n  }\n\n  return result;\n}\n\nfunction reducers(ops, stream) {\n  const aggrs = [];\n  const fields = {};\n\n  // group operators by field inputs\n  for (const op of ops) {\n    const key = op.fields.map(f => f + '').join(',');\n    (fields[key] || (fields[key] = [])).push(op);\n  }\n\n  // generate a field reducer for each field\n  for (const key in fields) {\n    aggrs.push((0,_field_reducer__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(fields[key], stream));\n  }\n\n  return aggrs;\n}\n\nfunction reduceFlat(table, reducer) {\n  // initialize aggregation cell\n  const cell = reducer.init();\n\n  // compute aggregate values\n  // inline the following for performance:\n  // table.scan((row, data) => reducer.add(cell, row, data));\n  const n = table.totalRows();\n  const data = table.data();\n  const bits = table.mask();\n\n  if (table.isOrdered()) {\n    const idx = table.indices();\n    for (let i = 0; i < n; ++i) {\n      reducer.add(cell, idx[i], data);\n    }\n  } else if (bits) {\n    for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n      reducer.add(cell, i, data);\n    }\n  } else {\n    for (let i = 0; i < n; ++i) {\n      reducer.add(cell, i, data);\n    }\n  }\n\n  return cell;\n}\n\nfunction reduceGroups(table, reducer, groups) {\n  const { keys, size } = groups;\n\n  // initialize aggregation cells\n  const cells = (0,_util_repeat__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(size, () => reducer.init());\n\n  // compute aggregate values\n  // inline the following for performance:\n  // table.scan((row, data) => reducer.add(cells[keys[row]], row, data));\n  const data = table.data();\n\n  if (table.isOrdered()) {\n    const idx = table.indices();\n    const m = idx.length;\n    for (let i = 0; i < m; ++i) {\n      const row = idx[i];\n      reducer.add(cells[keys[row]], row, data);\n    }\n  } else if (table.isFiltered()) {\n    const bits = table.mask();\n    for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n      reducer.add(cells[keys[i]], i, data);\n    }\n  } else {\n    const n = table.totalRows();\n    for (let i = 0; i < n; ++i) {\n      reducer.add(cells[keys[i]], i, data);\n    }\n  }\n\n  return cells;\n}\n\nfunction groupOutput(cols, groups) {\n  const { get, names, rows, size } = groups;\n\n  // write group values to output columns\n  const m = names.length;\n  for (let j = 0; j < m; ++j) {\n    const col = cols.add(names[j], Array(size));\n    const val = get[j];\n    for (let i = 0; i < size; ++i) {\n      col[i] = val(rows[i]);\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/reduce/util.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/rollup.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/rollup.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, { names, exprs, ops }) {\n  // output data\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const groups = table.groups();\n\n  // write groupby fields to output\n  if (groups) (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.groupOutput)(cols, groups);\n\n  // compute and write aggregate output\n  output(names, exprs, groups, (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregate)(table, ops), cols);\n\n  // return output table\n  return table.create(cols.new());\n}\n\nfunction output(names, exprs, groups, result = [], cols) {\n  if (!exprs.length) return;\n  const size = groups ? groups.size : 1;\n  const op = (id, row) => result[id][row];\n  const n = names.length;\n\n  for (let i = 0; i < n; ++i) {\n    const get = exprs[i];\n    if (get.field != null) {\n      // if expression is op only, use aggregates directly\n      cols.add(names[i], result[get.field]);\n    } else if (size > 1) {\n      // if multiple groups, evaluate expression for each\n      const col = cols.add(names[i], Array(size));\n      for (let j = 0; j < size; ++j) {\n        col[j] = get(j, null, op);\n      }\n    } else {\n      // if only one group, no need to loop\n      cols.add(names[i], [ get(0, null, op) ]);\n    }\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/rollup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/sample.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/sample.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_sample__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/sample */ \"../../node_modules/arquero/src/util/sample.js\");\n/* harmony import */ var _util_shuffle__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/shuffle */ \"../../node_modules/arquero/src/util/shuffle.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, size, weight, options = {}) {\n  const { replace, shuffle } = options;\n  const parts = table.partitions(false);\n\n  let total = 0;\n  size = parts.map((idx, group) => {\n    let s = size(group);\n    total += (s = (replace ? s : Math.min(idx.length, s)));\n    return s;\n  });\n\n  const samples = new Uint32Array(total);\n  let curr = 0;\n\n  parts.forEach((idx, group) => {\n    const sz = size[group];\n    const buf = samples.subarray(curr, curr += sz);\n\n    if (!replace && sz === idx.length) {\n      // sample size === data size, no replacement\n      // no need to sample, just copy indices\n      buf.set(idx);\n    } else {\n      (0,_util_sample__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(buf, replace, idx, weight);\n    }\n  });\n\n  if (shuffle !== false && (parts.length > 1 || !replace)) {\n    // sampling with replacement methods shuffle, so in\n    // that case a single partition is already good to go\n    (0,_util_shuffle__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(samples);\n  }\n\n  return table.reify(samples);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/sample.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/select.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/select.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, columns) {\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_0__[\"default\"])();\n\n  columns.forEach((value, curr) => {\n    const next = (0,_util_is_string__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(value) ? value : curr;\n    if (next) {\n      const col = table.column(curr) || (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(`Unrecognized column: ${curr}`);\n      cols.add(next, col);\n    }\n  });\n\n  return table.create(cols);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/select.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/spread.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/spread.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, { names, exprs, ops = [] }, options = {}) {\n  if (names.length === 0) return table;\n\n  // ignore 'as' if there are multiple field names\n  const as = (names.length === 1 && options.as) || [];\n  const drop = options.drop == null ? true : !!options.drop;\n  const limit = options.limit == null\n    ? as.length || Infinity\n    : Math.max(1, +options.limit || 1);\n\n  const get = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregateGet)(table, ops, exprs);\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const map = names.reduce((map, name, i) => map.set(name, i), new Map());\n\n  const add = (index, name) => {\n    const columns = spread(table, get[index], limit);\n    const n = columns.length;\n    for (let i = 0; i < n; ++i) {\n      cols.add(as[i] || `${name}_${i + 1}`, columns[i]);\n    }\n  };\n\n  table.columnNames().forEach(name => {\n    if (map.has(name)) {\n      if (!drop) cols.add(name, table.column(name));\n      add(map.get(name), name);\n      map.delete(name);\n    } else {\n      cols.add(name, table.column(name));\n    }\n  });\n\n  map.forEach(add);\n\n  return table.create(cols);\n}\n\nfunction spread(table, get, limit) {\n  const nrows = table.totalRows();\n  const columns = [];\n\n  table.scan((row, data) => {\n    const values = (0,_util_to_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(get(row, data));\n    const n = Math.min(values.length, limit);\n    while (columns.length < n) {\n      columns.push(Array(nrows).fill(_util_null__WEBPACK_IMPORTED_MODULE_2__[\"default\"]));\n    }\n    for (let i = 0; i < n; ++i) {\n      columns[i][row] = values[i];\n    }\n  });\n\n  return columns;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/spread.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/ungroup.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/engine/ungroup.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table) {\n  return table.isGrouped()\n    ? table.create({ groups: null })\n    : table;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/ungroup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/unorder.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/engine/unorder.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table) {\n  return table.isOrdered()\n    ? table.create({ order: null })\n    : table;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/unorder.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/unroll.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/engine/unroll.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, { names = [], exprs = [], ops = [] }, options = {}) {\n  if (!names.length) return table;\n\n  const limit = options.limit > 0 ? +options.limit : Infinity;\n  const index = options.index\n    ? options.index === true ? 'index' : options.index + ''\n    : null;\n  const drop = new Set(options.drop);\n  const get = (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.aggregateGet)(table, ops, exprs);\n\n  // initialize output columns\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n  const nset = new Set(names);\n  const priors = [];\n  const copies = [];\n  const unroll = [];\n\n  // original and copied columns\n  table.columnNames().forEach(name => {\n    if (!drop.has(name)) {\n      const col = cols.add(name, []);\n      if (!nset.has(name)) {\n        priors.push(table.column(name));\n        copies.push(col);\n      }\n    }\n  });\n\n  // unrolled output columns\n  names.forEach(name => {\n    if (!drop.has(name)) {\n      if (!cols.has(name)) cols.add(name, []);\n      unroll.push(cols.data[name]);\n    }\n  });\n\n  // index column, if requested\n  const icol = index ? cols.add(index, []) : null;\n\n  let start = 0;\n  const m = priors.length;\n  const n = unroll.length;\n\n  const copy = (row, maxlen) => {\n    for (let i = 0; i < m; ++i) {\n      copies[i].length = start + maxlen;\n      copies[i].fill(priors[i].get(row), start, start + maxlen);\n    }\n  };\n\n  const indices = icol\n    ? (row, maxlen) => {\n        for (let i = 0; i < maxlen; ++i) {\n          icol[row + i] = i;\n        }\n      }\n    : () => {};\n\n  if (n === 1) {\n    // optimize common case of one array-valued column\n    const fn = get[0];\n    const col = unroll[0];\n\n    table.scan((row, data) => {\n      // extract array data\n      const array = (0,_util_to_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(fn(row, data));\n      const maxlen = Math.min(array.length, limit);\n\n      // copy original table data\n      copy(row, maxlen);\n\n      // copy unrolled array data\n      for (let j = 0; j < maxlen; ++j) {\n        col[start + j] = array[j];\n      }\n\n      // fill in array indices\n      indices(start, maxlen);\n\n      start += maxlen;\n    });\n  } else {\n    table.scan((row, data) => {\n      let maxlen = 0;\n\n      // extract parallel array data\n      const arrays = get.map(fn => {\n        const value = (0,_util_to_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(fn(row, data));\n        maxlen = Math.min(Math.max(maxlen, value.length), limit);\n        return value;\n      });\n\n      // copy original table data\n      copy(row, maxlen);\n\n      // copy unrolled array data\n      for (let i = 0; i < n; ++i) {\n        const col = unroll[i];\n        const arr = arrays[i];\n        for (let j = 0; j < maxlen; ++j) {\n          col[start + j] = arr[j];\n        }\n      }\n\n      // fill in array indices\n      indices(start, maxlen);\n\n      start += maxlen;\n    });\n  }\n\n  return table.create(cols.new());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/unroll.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/window/window-state.js":
/*!********************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/window/window-state.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_ascending__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/ascending */ \"../../node_modules/arquero/src/util/ascending.js\");\n/* harmony import */ var _util_bisector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/bisector */ \"../../node_modules/arquero/src/util/bisector.js\");\n/* harmony import */ var _util_concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/concat */ \"../../node_modules/arquero/src/util/concat.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n\n\n\n\n\nconst bisect = (0,_util_bisector__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(_util_ascending__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(data, frame, adjust, ops, aggrs) {\n  let rows, peer, cells, result, key;\n  const isPeer = index => peer[index - 1] === peer[index];\n  const numOps = ops.length;\n  const numAgg = aggrs.length;\n\n  const evaluate = ops.length\n    ? (0,_util_unroll__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(\n        ['w', 'r', 'k'],\n        '{' + (0,_util_concat__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(ops, (_, i) => `r[_${i}.id][k]=_${i}.value(w,_${i}.get);`) + '}',\n        ops\n      )\n    : () => {};\n\n  const w = {\n    i0: 0,\n    i1: 0,\n    index: 0,\n    size: 0,\n    peer: isPeer,\n\n    init(partition, peers, results, group) {\n      w.index = w.i0 = w.i1 = 0;\n      w.size = peers.length;\n      rows = partition;\n      peer = peers;\n      result = results;\n      key = group;\n\n      // initialize aggregates\n      cells = aggrs ? aggrs.map(aggr => aggr.init()) : null;\n\n      // initialize window ops\n      for (let i = 0; i < numOps; ++i) {\n        ops[i].init();\n      }\n\n      return w;\n    },\n\n    value(index, get) {\n      return get(rows[index], data);\n    },\n\n    step(idx) {\n      const [f0, f1] = frame;\n      const n = w.size;\n      const p0 = w.i0;\n      const p1 = w.i1;\n\n      w.i0 = f0 != null ? Math.max(0, idx - Math.abs(f0)) : 0;\n      w.i1 = f1 != null ? Math.min(n, idx + Math.abs(f1) + 1) : n;\n      w.index = idx;\n\n      if (adjust) {\n        if (w.i0 > 0 && isPeer(w.i0)) {\n          w.i0 = bisect.left(peer, peer[w.i0]);\n        }\n        if (w.i1 < n && isPeer(w.i1)) {\n          w.i1 = bisect.right(peer, peer[w.i1 - 1]);\n        }\n      }\n\n      // evaluate aggregates\n      for (let i = 0; i < numAgg; ++i) {\n        const aggr = aggrs[i];\n        const cell = cells[i];\n        for (let j = p0; j < w.i0; ++j) {\n          aggr.rem(cell, rows[j], data);\n        }\n        for (let j = p1; j < w.i1; ++j) {\n          aggr.add(cell, rows[j], data);\n        }\n        aggr.write(cell, result, key);\n      }\n\n      // evaluate window ops\n      evaluate(w, result, key);\n\n      return result;\n    }\n  };\n\n  return w;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/window/window-state.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/engine/window/window.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/engine/window/window.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   window: () => (/* binding */ window)\n/* harmony export */ });\n/* harmony import */ var _reduce_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../op */ \"../../node_modules/arquero/src/op/index.js\");\n/* harmony import */ var _util_concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/concat */ \"../../node_modules/arquero/src/util/concat.js\");\n/* harmony import */ var _util_unroll__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/unroll */ \"../../node_modules/arquero/src/util/unroll.js\");\n/* harmony import */ var _window_state__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./window-state */ \"../../node_modules/arquero/src/engine/window/window-state.js\");\n\n\n\n\n\n\nconst frameValue = op =>\n  (op.frame || [null, null]).map(v => Number.isFinite(v) ? Math.abs(v) : null);\n\nconst peersValue = op => !!op.peers;\n\nfunction windowOp(spec) {\n  const { id, name, fields = [], params = [] } = spec;\n  const op = (0,_op__WEBPACK_IMPORTED_MODULE_1__.getWindow)(name).create(...params);\n  if (fields.length) op.get = fields[0];\n  op.id = id;\n  return op;\n}\n\nfunction window(table, cols, exprs, result = {}, ops) {\n  // instantiate window states\n  const data = table.data();\n  const states = windowStates(ops, data);\n  const nstate = states.length;\n\n  const write = (0,_util_unroll__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(\n    ['r', 'd', 'op'],\n    '{' + (0,_util_concat__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(cols, (_, i) => `_${i}[r] = $${i}(r, d, op);`) + '}',\n    cols, exprs\n  );\n\n  // scan each ordered partition\n  table.partitions().forEach((rows, key) => {\n    const size = rows.length;\n    const peers = windowPeers(table, rows);\n\n    // initialize window states\n    for (let i = 0; i < nstate; ++i) {\n      states[i].init(rows, peers, result, key);\n    }\n\n    // calculate window values per-row\n    const op = id => result[id][key];\n    for (let index = 0; index < size; ++index) {\n      // advance window frame, updates result object\n      for (let i = 0; i < nstate; ++i) {\n        states[i].step(index);\n      }\n      write(rows[index], data, op);\n    }\n  });\n}\n\nfunction windowStates(ops, data) {\n  const map = {};\n\n  // group operations by window frame parameters\n  ops.forEach(op => {\n    const frame = frameValue(op);\n    const peers = peersValue(op);\n    const key = `${frame},${peers}`;\n    const { aggOps, winOps } = map[key] || (map[key] = {\n      frame,\n      peers,\n      aggOps: [],\n      winOps: []\n    });\n    (0,_op__WEBPACK_IMPORTED_MODULE_1__.hasAggregate)(op.name)\n      ? aggOps.push(op)\n      : winOps.push(windowOp(op));\n  });\n\n  return Object.values(map).map(_ => (0,_window_state__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(\n    data, _.frame, _.peers, _.winOps,\n    (0,_reduce_util__WEBPACK_IMPORTED_MODULE_0__.reducers)(_.aggOps, _.frame[0] != null ? -1 : 1)\n  ));\n}\n\nfunction windowPeers(table, rows) {\n  if (table.isOrdered()) {\n    // generate peer ids for sort equality checking\n    const compare = table.comparator();\n    const data = table.data();\n    const nrows = rows.length;\n    const peers = new Uint32Array(nrows);\n    for (let i = 1, index = 0; i < nrows; ++i) {\n      peers[i] = compare(rows[i - 1], rows[i], data) ? ++index : index;\n    }\n    return peers;\n  } else {\n    // no sort, no peers: reuse row indices as peer ids\n    return rows;\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/engine/window/window.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/ast/clean.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/ast/clean.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _walk__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./walk */ \"../../node_modules/arquero/src/expression/ast/walk.js\");\n\n\nfunction strip(node) {\n  delete node.start;\n  delete node.end;\n  delete node.optional;\n}\n\nfunction stripMember(node) {\n  strip(node);\n  delete node.object;\n  delete node.property;\n  delete node.computed;\n  if (!node.table) delete node.table;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(ast) {\n  (0,_walk__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(ast, null, {\n    Column: stripMember,\n    Constant: stripMember,\n    Default: strip\n  });\n  return ast;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/ast/clean.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/ast/constants.js":
/*!******************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/ast/constants.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ArrayPattern: () => (/* binding */ ArrayPattern),\n/* harmony export */   ArrowFunctionExpression: () => (/* binding */ ArrowFunctionExpression),\n/* harmony export */   Column: () => (/* binding */ Column),\n/* harmony export */   Constant: () => (/* binding */ Constant),\n/* harmony export */   Dictionary: () => (/* binding */ Dictionary),\n/* harmony export */   Function: () => (/* binding */ Function),\n/* harmony export */   FunctionExpression: () => (/* binding */ FunctionExpression),\n/* harmony export */   Identifier: () => (/* binding */ Identifier),\n/* harmony export */   Literal: () => (/* binding */ Literal),\n/* harmony export */   MemberExpression: () => (/* binding */ MemberExpression),\n/* harmony export */   ObjectExpression: () => (/* binding */ ObjectExpression),\n/* harmony export */   ObjectPattern: () => (/* binding */ ObjectPattern),\n/* harmony export */   Op: () => (/* binding */ Op),\n/* harmony export */   Parameter: () => (/* binding */ Parameter),\n/* harmony export */   Property: () => (/* binding */ Property)\n/* harmony export */ });\nconst ArrayPattern = 'ArrayPattern';\nconst ArrowFunctionExpression = 'ArrowFunctionExpression';\nconst FunctionExpression = 'FunctionExpression';\nconst Identifier = 'Identifier';\nconst Literal = 'Literal';\nconst MemberExpression = 'MemberExpression';\nconst ObjectExpression = 'ObjectExpression';\nconst ObjectPattern = 'ObjectPattern';\nconst Property = 'Property';\n\nconst Column = 'Column';\nconst Constant = 'Constant';\nconst Dictionary = 'Dictionary';\nconst Function = 'Function';\nconst Parameter = 'Parameter';\nconst Op = 'Op';\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/ast/constants.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/ast/util.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/ast/util.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   is: () => (/* binding */ is),\n/* harmony export */   isFunctionExpression: () => (/* binding */ isFunctionExpression)\n/* harmony export */ });\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n\n\nfunction is(type, node) {\n  return node && node.type === type;\n}\n\nfunction isFunctionExpression(node) {\n  return is(_constants__WEBPACK_IMPORTED_MODULE_0__.FunctionExpression, node)\n    || is(_constants__WEBPACK_IMPORTED_MODULE_0__.ArrowFunctionExpression, node);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/ast/util.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/ast/walk.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/ast/walk.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ walk)\n/* harmony export */ });\nfunction walk(node, ctx, visitors, parent) {\n  const visit = visitors[node.type] || visitors['Default'];\n  if (visit && visit(node, ctx, parent) === false) return;\n\n  const walker = walkers[node.type];\n  if (walker) walker(node, ctx, visitors);\n}\n\nconst unary = (node, ctx, visitors) => {\n  walk(node.argument, ctx, visitors, node);\n};\n\nconst binary = (node, ctx, visitors) => {\n  walk(node.left, ctx, visitors, node);\n  walk(node.right, ctx, visitors, node);\n};\n\nconst ternary = (node, ctx, visitors) => {\n  walk(node.test, ctx, visitors, node);\n  walk(node.consequent, ctx, visitors, node);\n  if (node.alternate) walk(node.alternate, ctx, visitors, node);\n};\n\nconst func = (node, ctx, visitors) => {\n  list(node.params, ctx, visitors, node);\n  walk(node.body, ctx, visitors, node);\n};\n\nconst call = (node, ctx, visitors) => {\n  walk(node.callee, ctx, visitors, node);\n  list(node.arguments, ctx, visitors, node);\n};\n\nconst list = (nodes, ctx, visitors, node) => {\n  nodes.forEach(item => walk(item, ctx, visitors, node));\n};\n\nconst walkers = {\n  TemplateLiteral: (node, ctx, visitors) => {\n    list(node.expressions, ctx, visitors, node);\n    list(node.quasis, ctx, visitors, node);\n  },\n  MemberExpression: (node, ctx, visitors) => {\n    walk(node.object, ctx, visitors, node);\n    walk(node.property, ctx, visitors, node);\n  },\n  CallExpression: call,\n  NewExpression: call,\n  ArrayExpression: (node, ctx, visitors) => {\n    list(node.elements, ctx, visitors, node);\n  },\n  AssignmentExpression: binary,\n  AwaitExpression: unary,\n  BinaryExpression: binary,\n  LogicalExpression: binary,\n  UnaryExpression: unary,\n  UpdateExpression: unary,\n  ConditionalExpression: ternary,\n  ObjectExpression: (node, ctx, visitors) => {\n    list(node.properties, ctx, visitors, node);\n  },\n  Property: (node, ctx, visitors) => {\n    walk(node.key, ctx, visitors, node);\n    walk(node.value, ctx, visitors, node);\n  },\n\n  ArrowFunctionExpression: func,\n  FunctionExpression: func,\n  FunctionDeclaration: func,\n\n  VariableDeclaration: (node, ctx, visitors) => {\n    list(node.declarations, ctx, visitors, node);\n  },\n  VariableDeclarator: (node, ctx, visitors) => {\n    walk(node.id, ctx, visitors, node);\n    walk(node.init, ctx, visitors, node);\n  },\n  SpreadElement: (node, ctx, visitors) => {\n    walk(node.argument, ctx, visitors, node);\n  },\n\n  BlockStatement: (node, ctx, visitors) => {\n    list(node.body, ctx, visitors, node);\n  },\n  ExpressionStatement: (node, ctx, visitors) => {\n    walk(node.expression, ctx, visitors, node);\n  },\n  IfStatement: ternary,\n  ForStatement: (node, ctx, visitors) => {\n    walk(node.init, ctx, visitors, node);\n    walk(node.test, ctx, visitors, node);\n    walk(node.update, ctx, visitors, node);\n    walk(node.body, ctx, visitors, node);\n  },\n  WhileStatement: (node, ctx, visitors) => {\n    walk(node.test, ctx, visitors, node);\n    walk(node.body, ctx, visitors, node);\n  },\n  DoWhileStatement: (node, ctx, visitors) => {\n    walk(node.body, ctx, visitors, node);\n    walk(node.test, ctx, visitors, node);\n  },\n  SwitchStatement: (node, ctx, visitors) => {\n    walk(node.discriminant, ctx, visitors, node);\n    list(node.cases, ctx, visitors, node);\n  },\n  SwitchCase: (node, ctx, visitors) => {\n    if (node.test) walk(node.test, ctx, visitors, node);\n    list(node.consequent, ctx, visitors, node);\n  },\n  ReturnStatement: unary,\n\n  Program: (node, ctx, visitors) => {\n    walk(node.body[0], ctx, visitors, node);\n  }\n};\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/ast/walk.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/codegen.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/codegen.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\nconst visit = (node, opt) => {\n  const f = visitors[node.type];\n  return f\n    ? f(node, opt)\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(`Unsupported expression construct: ${node.type}`);\n};\n\nconst binary = (node, opt) => {\n  return '(' + visit(node.left, opt) + ' ' + node.operator + ' ' + visit(node.right, opt) + ')';\n};\n\nconst func = (node, opt) => {\n  return '(' + list(node.params, opt) + ')=>' + visit(node.body, opt);\n};\n\nconst call = (node, opt) => {\n  return visit(node.callee, opt) + '(' + list(node.arguments, opt) + ')';\n};\n\nconst list = (array, opt, delim = ',') => {\n  return array.map(node => visit(node, opt)).join(delim);\n};\n\nconst name = node => node.computed\n  ? `[${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(node.name)}]`\n  : `.${node.name}`;\n\nconst ref = (node, opt, method) => {\n  const table = node.table || '';\n  return `data${table}${name(node)}.${method}(${opt.index}${table})`;\n};\n\nconst visitors = {\n  Constant: node => node.raw,\n  Column: (node, opt) => ref(node, opt, 'get'),\n  Dictionary: (node, opt) => ref(node, opt, 'key'),\n  Function: node => `fn.${node.name}`,\n  Parameter: node => `$${name(node)}`,\n  Op: (node, opt) => `op(${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(node.name)},${opt.op || opt.index})`,\n  Literal: node => node.raw,\n  Identifier: node => node.name,\n  TemplateLiteral: (node, opt) => {\n    const { quasis, expressions } = node;\n    const n = expressions.length;\n    let t = quasis[0].value.raw;\n    for (let i = 0; i < n;) {\n      t += '${' + visit(expressions[i], opt) + '}' + quasis[++i].value.raw;\n    }\n    return '`' + t + '`';\n  },\n  MemberExpression: (node, opt) => {\n    const d = !node.computed;\n    const o = visit(node.object, opt);\n    const p = visit(node.property, opt);\n    return o + (d ? '.' + p : '[' + p + ']');\n  },\n  CallExpression: call,\n  NewExpression: (node, opt) => {\n    return 'new ' + call(node, opt);\n  },\n  ArrayExpression: (node, opt) => {\n    return '[' + list(node.elements, opt) + ']';\n  },\n  AssignmentExpression: binary,\n  BinaryExpression: binary,\n  LogicalExpression: binary,\n  UnaryExpression: (node, opt) => {\n    return '(' + node.operator + visit(node.argument, opt) + ')';\n  },\n  ConditionalExpression: (node, opt) => {\n    return '(' + visit(node.test, opt) +\n      '?' + visit(node.consequent, opt) +\n      ':' + visit(node.alternate, opt) + ')';\n  },\n  ObjectExpression: (node, opt) => {\n    return '({' + list(node.properties, opt) + '})';\n  },\n  Property: (node, opt) => {\n    const key = visit(node.key, opt);\n    return (node.computed ? `[${key}]` : key) + ':' + visit(node.value, opt);\n  },\n\n  ArrowFunctionExpression: func,\n  FunctionExpression: func,\n  FunctionDeclaration: func,\n\n  ArrayPattern: (node, opt) => {\n    return '[' + list(node.elements, opt) + ']';\n  },\n  ObjectPattern: (node, opt) => {\n    return '{' + list(node.properties, opt) + '}';\n  },\n  VariableDeclaration: (node, opt) => {\n    return node.kind + ' ' + list(node.declarations, opt, ',');\n  },\n  VariableDeclarator: (node, opt) => {\n    return visit(node.id, opt) + '=' + visit(node.init, opt);\n  },\n  SpreadElement: (node, opt) => {\n    return '...' + visit(node.argument, opt);\n  },\n\n  BlockStatement: (node, opt) => {\n    return '{' + list(node.body, opt, ';') + ';}';\n  },\n  BreakStatement: () => {\n    return 'break';\n  },\n  ExpressionStatement: (node, opt) => {\n    return visit(node.expression, opt);\n  },\n  IfStatement: (node, opt) => {\n    return 'if (' + visit(node.test, opt) + ')'\n      + visit(node.consequent, opt)\n      + (node.alternate ? ' else ' + visit(node.alternate, opt) : '');\n  },\n  SwitchStatement: (node, opt) => {\n    return 'switch (' + visit(node.discriminant, opt) + ') {'\n     + list(node.cases, opt, '')\n     + '}';\n  },\n  SwitchCase: (node, opt) => {\n    return (node.test ? 'case ' + visit(node.test, opt) : 'default')\n      + ': '\n      + list(node.consequent, opt, ';') + ';';\n  },\n  ReturnStatement: (node, opt) => {\n    return 'return ' + visit(node.argument, opt);\n  },\n  Program: (node, opt) => visit(node.body[0], opt)\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(node, opt = { index: 'row' }) {\n  return visit(node, opt);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/codegen.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/compare.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/compare.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _codegen__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./codegen */ \"../../node_modules/arquero/src/expression/codegen.js\");\n/* harmony import */ var _parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _engine_reduce_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../engine/reduce/util */ \"../../node_modules/arquero/src/engine/reduce/util.js\");\n\n\n\n\n// generate code to compare a single field\nconst _compare = (u, v, lt, gt) =>\n  `((u = ${u}) < (v = ${v}) || u == null) && v != null ? ${lt}\n    : (u > v || v == null) && u != null ? ${gt}\n    : ((v = v instanceof Date ? +v : v), (u = u instanceof Date ? +u : u)) !== u && v === v ? ${lt}\n    : v !== v && u === u ? ${gt} : `;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, fields) {\n  // parse expressions, generate code for both a and b values\n  const names = [];\n  const exprs = [];\n  const fn = [];\n  let keys = null, opA = '0', opB = '0';\n  if (table.isGrouped()) {\n    keys = table.groups().keys;\n    opA = 'ka';\n    opB = 'kb';\n  }\n  const { ops } = (0,_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(fields, {\n    table,\n    value: (name, node) => {\n      names.push(name);\n      if (node.escape) {\n        // if an escaped function, invoke it directly\n        const f = i => `fn[${fn.length}](${i}, data)`;\n        exprs.push([f('a'), f('b')]);\n        fn.push(node.escape);\n      } else {\n        // generate code to extract values to compare\n        exprs.push([\n          (0,_codegen__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(node, { index: 'a', op: opA }),\n          (0,_codegen__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(node, { index: 'b', op: opB })\n        ]);\n      }\n    },\n    window: false\n  });\n\n  // calculate aggregate values if needed\n  const result = (0,_engine_reduce_util__WEBPACK_IMPORTED_MODULE_2__.aggregate)(table, ops);\n  const op = (id, row) => result[id][row];\n\n  // generate comparison code for each field\n  const n = names.length;\n  let code = 'return (a, b) => {'\n    + (op && table.isGrouped() ? 'const ka = keys[a], kb = keys[b];' : '')\n    + 'let u, v; return ';\n  for (let i = 0; i < n; ++i) {\n    const o = fields.get(names[i]).desc ? -1 : 1;\n    const [u, v] = exprs[i];\n    code += _compare(u, v, -o, o);\n  }\n  code += '0;};';\n\n  // instantiate and return comparator function\n  return Function('op', 'keys', 'fn', 'data', code)(op, keys, fn, table.data());\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/compare.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/compile.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/compile.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../op */ \"../../node_modules/arquero/src/op/index.js\");\n\n\nfunction compile(code, fn, params) {\n  code = `\"use strict\"; return ${code};`;\n  return (Function('fn', '$', code))(fn, params);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  escape: (code, func, params) => compile(code, func, params),\n  expr:   (code, params) => compile(`(row,data,op)=>${code}`, _op__WEBPACK_IMPORTED_MODULE_0__.functions, params),\n  expr2:  (code, params) => compile(`(row0,data0,row,data)=>${code}`, _op__WEBPACK_IMPORTED_MODULE_0__.functions, params),\n  join:   (code, params) => compile(`(row1,data1,row2,data2)=>${code}`, _op__WEBPACK_IMPORTED_MODULE_0__.functions, params),\n  param:  (code, params) => compile(code, _op__WEBPACK_IMPORTED_MODULE_0__.functions, params)\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/compile.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/constants.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/constants.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  undefined: 'void(0)',\n  Infinity:  'Number.POSITIVE_INFINITY',\n  NaN:       'Number.NaN',\n  E:         'Math.E',\n  LN2:       'Math.LN2',\n  LN10:      'Math.LN10',\n  LOG2E:     'Math.LOG2E',\n  LOG10E:    'Math.LOG10E',\n  PI:        'Math.PI',\n  SQRT1_2:   'Math.SQRT1_2',\n  SQRT2:     'Math.SQRT2'\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/constants.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/parse-escape.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/parse-escape.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _compile__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./compile */ \"../../node_modules/arquero/src/expression/compile.js\");\n/* harmony import */ var _row_object__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./row-object */ \"../../node_modules/arquero/src/expression/row-object.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_to_function__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/to-function */ \"../../node_modules/arquero/src/util/to-function.js\");\n\n\n\n\n\nconst ERROR_ESC_AGGRONLY = 'Escaped functions are not valid as rollup or pivot values.';\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(ctx, spec, params) {\n  if (ctx.aggronly) (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(ERROR_ESC_AGGRONLY);\n\n  // generate escaped function invocation code\n  const code = '(row,data)=>fn('\n    + (0,_row_object__WEBPACK_IMPORTED_MODULE_1__.rowObjectCode)(ctx.table.columnNames())\n    + ',$)';\n\n  return { escape: _compile__WEBPACK_IMPORTED_MODULE_0__[\"default\"].escape(code, (0,_util_to_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(spec.expr), params) };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/parse-escape.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/parse-expression.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/parse-expression.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ parseExpression)\n/* harmony export */ });\n/* harmony import */ var acorn__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! acorn */ \"../../node_modules/acorn/dist/acorn.mjs\");\n/* harmony import */ var _ast_constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ast/constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n/* harmony import */ var _ast_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ast/util */ \"../../node_modules/arquero/src/expression/ast/util.js\");\n/* harmony import */ var _ast_walk__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./ast/walk */ \"../../node_modules/arquero/src/expression/ast/walk.js\");\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/expression/constants.js\");\n/* harmony import */ var _rewrite__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./rewrite */ \"../../node_modules/arquero/src/expression/rewrite.js\");\n/* harmony import */ var _row_object__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./row-object */ \"../../node_modules/arquero/src/expression/row-object.js\");\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../op */ \"../../node_modules/arquero/src/op/index.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../util/has */ \"../../node_modules/arquero/src/util/has.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst PARSER_OPT = { ecmaVersion: 11 };\nconst DEFAULT_PARAM_ID = '$';\nconst DEFAULT_TUPLE_ID = 'd';\nconst DEFAULT_TUPLE_ID1 = 'd1';\nconst DEFAULT_TUPLE_ID2 = 'd2';\n\nconst NO = msg => (node, ctx) => ctx.error(node, msg + ' not allowed');\nconst ERROR_AGGREGATE = NO('Aggregate function');\nconst ERROR_WINDOW = NO('Window function');\nconst ERROR_ARGUMENT = 'Invalid argument';\nconst ERROR_COLUMN = 'Invalid column reference';\nconst ERROR_AGGRONLY = ERROR_COLUMN + ' (must be input to an aggregate function)';\nconst ERROR_FUNCTION = 'Invalid function call';\nconst ERROR_MEMBER = 'Invalid member expression';\nconst ERROR_OP_PARAMETER = 'Invalid operator parameter';\nconst ERROR_PARAM = 'Invalid param reference';\nconst ERROR_VARIABLE = 'Invalid variable reference';\nconst ERROR_VARIABLE_OP = 'Variable not accessible in operator call';\nconst ERROR_DECLARATION = 'Unsupported variable declaration';\nconst ERROR_DESTRUCTURE = 'Unsupported destructuring pattern';\nconst ERROR_CLOSURE = 'Table expressions do not support closures';\nconst ERROR_ESCAPE = 'Use aq.escape(fn) to use a function as-is (including closures)';\nconst ERROR_USE_PARAMS = 'use table.params({ name: value }) to define dynamic parameters';\nconst ERROR_ADD_FUNCTION = 'use aq.addFunction(name, fn) to add new op functions';\nconst ERROR_VARIABLE_NOTE = `\\nNote: ${ERROR_CLOSURE}. ${ERROR_ESCAPE}, or ${ERROR_USE_PARAMS}.`;\nconst ERROR_FUNCTION_NOTE = `\\nNote: ${ERROR_CLOSURE}. ${ERROR_ESCAPE}, or ${ERROR_ADD_FUNCTION}.`;\nconst ERROR_ROW_OBJECT = `The ${_row_object__WEBPACK_IMPORTED_MODULE_6__.ROW_OBJECT} method is not valid in multi-table expressions.`;\n\nfunction parseExpression(ctx, spec) {\n  const ast = parseAST(spec);\n  let node = ctx.root = ast;\n  ctx.spec = spec;\n  ctx.tuple = null;\n  ctx.tuple1 = null;\n  ctx.tuple2 = null;\n  ctx.$param = null;\n  ctx.$op = 0;\n  ctx.scope = new Set();\n  ctx.paramsRef = new Map();\n  ctx.columnRef = new Map();\n\n  // parse input column parameters\n  // if no function def, assume default tuple identifiers\n  if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.isFunctionExpression)(node)) {\n    parseFunction(node, ctx);\n    node = node.body;\n  } else if (ctx.join) {\n    ctx.scope.add(ctx.tuple1 = DEFAULT_TUPLE_ID1);\n    ctx.scope.add(ctx.tuple2 = DEFAULT_TUPLE_ID2);\n    ctx.scope.add(ctx.$param = DEFAULT_PARAM_ID);\n  } else {\n    ctx.scope.add(ctx.tuple = DEFAULT_TUPLE_ID);\n    ctx.scope.add(ctx.$param = DEFAULT_PARAM_ID);\n  }\n\n  // rewrite column references & function calls\n  (0,_ast_walk__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(node, ctx, visitors);\n\n  return ctx.root;\n}\n\nfunction parseAST(expr) {\n  try {\n    const code = expr.field ? fieldRef(expr)\n      : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(expr) ? (0,_util_to_string__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(expr)\n      : expr;\n    return (0,acorn__WEBPACK_IMPORTED_MODULE_0__.parse)(`expr=(${code})`, PARSER_OPT).body[0].expression.right;\n  } catch (err) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(`Expression parse error: ${expr+''}`, err);\n  }\n}\n\nfunction fieldRef(expr) {\n  const col = JSON.stringify(expr+'');\n  return !(expr.table || 0) ? `d=>d[${col}]` : `(a,b)=>b[${col}]`;\n}\n\nconst visitors = {\n  FunctionDeclaration: NO('Function definitions'),\n  ForStatement: NO('For loops'),\n  ForOfStatement: NO('For-of loops'),\n  ForInStatement: NO('For-in loops'),\n  WhileStatement: NO('While loops'),\n  DoWhileStatement: NO('Do-while loops'),\n  AwaitExpression: NO('Await expressions'),\n  ArrowFunctionExpression: NO('Function definitions'),\n  AssignmentExpression: NO('Assignments'),\n  FunctionExpression: NO('Function definitions'),\n  NewExpression: NO('Use of \"new\"'),\n  UpdateExpression: NO('Update expressions'),\n\n  VariableDeclarator(node, ctx) {\n    handleDeclaration(node.id, ctx);\n  },\n  Identifier(node, ctx, parent) {\n    if (handleIdentifier(node, ctx, parent) && !ctx.scope.has(node.name)) {\n      // handle identifier passed responsibility here\n      // raise error if identifier not defined in scope\n      ctx.error(node, ERROR_VARIABLE, ERROR_VARIABLE_NOTE);\n    }\n  },\n  CallExpression(node, ctx) {\n    const name = functionName(node.callee);\n    const def = (0,_op__WEBPACK_IMPORTED_MODULE_7__.getAggregate)(name) || (0,_op__WEBPACK_IMPORTED_MODULE_7__.getWindow)(name);\n\n    // parse operator and rewrite invocation\n    if (def) {\n      if ((ctx.join || ctx.aggregate === false) && (0,_op__WEBPACK_IMPORTED_MODULE_7__.hasAggregate)(def)) {\n        ERROR_AGGREGATE(node, ctx);\n      }\n      if ((ctx.join || ctx.window === false) && (0,_op__WEBPACK_IMPORTED_MODULE_7__.hasWindow)(def)) {\n        ERROR_WINDOW(node, ctx);\n      }\n\n      ctx.$op = 1;\n      if (ctx.ast) {\n        updateFunctionNode(node, name, ctx);\n        node.arguments.forEach(arg => (0,_ast_walk__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(arg, ctx, opVisitors));\n      } else {\n        const op = ctx.op(parseOperator(ctx, def, name, node.arguments));\n        Object.assign(node, { type: _ast_constants__WEBPACK_IMPORTED_MODULE_1__.Op, name: op.id });\n      }\n      ctx.$op = 0;\n      return false;\n    } else if ((0,_op__WEBPACK_IMPORTED_MODULE_7__.hasFunction)(name)) {\n      updateFunctionNode(node, name, ctx);\n    } else {\n      ctx.error(node, ERROR_FUNCTION, ERROR_FUNCTION_NOTE);\n    }\n  },\n  MemberExpression(node, ctx, parent) {\n    const { object, property } = node;\n\n    // bail if left head is not an identifier\n    // in this case we will recurse and handle it later\n    if (!(0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, object)) return;\n    const { name } = object;\n\n    // allow use of Math prefix to access constant values\n    if (isMath(node) && (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, property)\n        && (0,_util_has__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(_constants__WEBPACK_IMPORTED_MODULE_4__[\"default\"], property.name)) {\n      updateConstantNode(node, property.name);\n      return;\n    }\n\n    const index = name === ctx.tuple ? 0\n      : name === ctx.tuple1 ? 1\n      : name === ctx.tuple2 ? 2\n      : -1;\n\n    if (index >= 0) {\n      // replace member expression with column ref\n      return spliceMember(node, index, ctx, checkColumn, parent);\n    } else if (name === ctx.$param) {\n      // replace member expression with param ref\n      return spliceMember(node, index, ctx, checkParam);\n    } else if (ctx.paramsRef.has(name)) {\n      updateParameterNode(node, ctx.paramsRef.get(name));\n    } else if (ctx.columnRef.has(name)) {\n      updateColumnNode(object, name, ctx, node);\n    } else if ((0,_util_has__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(ctx.params, name)) {\n      updateParameterNode(object, name);\n    }\n  }\n};\n\nfunction spliceMember(node, index, ctx, check, parent) {\n  const { property, computed } = node;\n  let name;\n\n  if (!computed) {\n    name = property.name;\n  } else if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Literal, property)) {\n    name = property.value;\n  } else try {\n    name = ctx.param(property);\n  } catch (e) {\n    ctx.error(node, ERROR_MEMBER);\n  }\n\n  check(node, name, index, ctx, parent);\n  return false;\n}\n\nconst opVisitors = {\n  ...visitors,\n  VariableDeclarator: NO('Variable declaration in operator call'),\n  Identifier(node, ctx, parent) {\n    if (handleIdentifier(node, ctx, parent)) {\n      ctx.error(node, ERROR_VARIABLE_OP);\n    }\n  },\n  CallExpression(node, ctx) {\n    const name = functionName(node.callee);\n\n    // rewrite if built-in function\n    if ((0,_op__WEBPACK_IMPORTED_MODULE_7__.hasFunction)(name)) {\n      updateFunctionNode(node, name, ctx);\n    } else {\n      ctx.error(node, ERROR_FUNCTION, ERROR_FUNCTION_NOTE);\n    }\n  }\n};\n\nfunction parseFunction(node, ctx) {\n  if (node.generator) NO('Generator functions')(node, ctx);\n  if (node.async) NO('Async functions')(node, ctx);\n\n  const { params } = node;\n  const len = params.length;\n  const setc = index => (name, key) => ctx.columnRef.set(name, [key, index]);\n  const setp = (name, key) => ctx.paramsRef.set(name, key);\n\n  if (!len) {\n    // do nothing\n  } else if (ctx.join) {\n    parseRef(ctx, params[0], 'tuple1', setc(1));\n    if (len > 1) parseRef(ctx, params[1], 'tuple2', setc(2));\n    if (len > 2) parseRef(ctx, params[2], '$param', setp);\n  } else {\n    parseRef(ctx, params[0], 'tuple', setc(0));\n    if (len > 1) parseRef(ctx, params[1], '$param', setp);\n  }\n\n  ctx.root = node.body;\n}\n\nfunction parseRef(ctx, node, refName, alias) {\n  if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, node)) {\n    ctx.scope.add(node.name);\n    ctx[refName] = node.name;\n  } else if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.ObjectPattern, node)) {\n    node.properties.forEach(p => {\n      const key = (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, p.key) ? p.key.name\n        : (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Literal, p.key) ? p.key.value\n        : ctx.error(p, ERROR_ARGUMENT);\n      if (!(0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, p.value)) {\n        ctx.error(p.value, ERROR_DESTRUCTURE);\n      }\n      alias(p.value.name, key);\n    });\n  }\n}\n\nfunction parseOperator(ctx, def, name, args) {\n  const fields = [];\n  const params = [];\n  const idxFields = def.param[0] || 0;\n  const idxParams = idxFields + (def.param[1] || 0);\n\n  args.forEach((arg, index) => {\n    if (index < idxFields) {\n      (0,_ast_walk__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(arg, ctx, opVisitors);\n      fields.push(ctx.field(arg));\n    } else if (index < idxParams) {\n      (0,_ast_walk__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(arg, ctx, opVisitors);\n      params.push(ctx.param(arg));\n    } else {\n      ctx.error(arg, ERROR_OP_PARAMETER);\n    }\n  });\n\n  return { name, fields, params, ...(ctx.spec.window || {}) };\n}\n\nfunction functionName(node) {\n  return (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, node) ? node.name\n    : !(0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.MemberExpression, node) ? null\n    : isMath(node) ? rewriteMath(node.property.name)\n    : node.property.name;\n}\n\nfunction isMath(node) {\n  return (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, node.object) && node.object.name === 'Math';\n}\n\nfunction rewriteMath(name) {\n  return name === 'max' ? 'greatest'\n    : name === 'min' ? 'least'\n    : name;\n}\n\nfunction handleIdentifier(node, ctx, parent) {\n  const { name } = node;\n\n  if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.MemberExpression, parent) && parent.property === node) {\n    // do nothing: check head node, not nested properties\n  } else if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Property, parent) && parent.key === node) {\n    // do nothing: identifiers allowed in object expressions\n  } else if (ctx.paramsRef.has(name)) {\n    updateParameterNode(node, ctx.paramsRef.get(name));\n  } else if (ctx.columnRef.has(name)) {\n    updateColumnNode(node, name, ctx, parent);\n  } else if ((0,_util_has__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(ctx.params, name)) {\n    updateParameterNode(node, name);\n  } else if ((0,_util_has__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(_constants__WEBPACK_IMPORTED_MODULE_4__[\"default\"], name)) {\n    updateConstantNode(node, name);\n  } else {\n    return true;\n  }\n}\n\nfunction checkColumn(node, name, index, ctx, parent) {\n  // check column existence if we have a backing table\n  const table = index === 0 ? ctx.table\n    : index > 0 ? ctx.join[index - 1]\n    : null;\n  const col = table && table.column(name);\n  if (table && !col) {\n    ctx.error(node, ERROR_COLUMN);\n  }\n\n  // check if column reference is valid in current context\n  if (ctx.aggronly && !ctx.$op) {\n    ctx.error(node, ERROR_AGGRONLY);\n  }\n\n  // rewrite ast node as a column access\n  (0,_rewrite__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(node, name, index, col, parent);\n}\n\nfunction updateColumnNode(node, key, ctx, parent) {\n  const [name, index] = ctx.columnRef.get(key);\n  checkColumn(node, name, index, ctx, parent);\n}\n\nfunction checkParam(node, name, index, ctx) {\n  if (ctx.params && !(0,_util_has__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(ctx.params, name)) {\n    ctx.error(node, ERROR_PARAM);\n  }\n  updateParameterNode(node, name);\n}\n\nfunction updateParameterNode(node, name) {\n  node.type = _ast_constants__WEBPACK_IMPORTED_MODULE_1__.Parameter;\n  node.name = name;\n}\n\nfunction updateConstantNode(node, name) {\n  node.type = _ast_constants__WEBPACK_IMPORTED_MODULE_1__.Constant;\n  node.name = name;\n  node.raw = _constants__WEBPACK_IMPORTED_MODULE_4__[\"default\"][name];\n}\n\nfunction updateFunctionNode(node, name, ctx) {\n  if (name === _row_object__WEBPACK_IMPORTED_MODULE_6__.ROW_OBJECT) {\n    const t = ctx.table;\n    if (!t) ctx.error(node, ERROR_ROW_OBJECT);\n    (0,_row_object__WEBPACK_IMPORTED_MODULE_6__.rowObjectExpression)(node,\n      node.arguments.length\n        ? node.arguments.map(node => {\n            const col = ctx.param(node);\n            const name = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(col) ? t.columnName(col) : col;\n            if (!t.column(name)) ctx.error(node, ERROR_COLUMN);\n            return name;\n          })\n        : t.columnNames()\n    );\n  } else {\n    node.callee = { type: _ast_constants__WEBPACK_IMPORTED_MODULE_1__.Function, name };\n  }\n}\n\nfunction handleDeclaration(node, ctx) {\n  if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.Identifier, node)) {\n    ctx.scope.add(node.name);\n  } else if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.ArrayPattern, node)) {\n    node.elements.forEach(elm => handleDeclaration(elm, ctx));\n  } else if ((0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_1__.ObjectPattern, node)) {\n    node.properties.forEach(prop => handleDeclaration(prop.value, ctx));\n  } else {\n    ctx.error(node.id, ERROR_DECLARATION);\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/parse-expression.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/parse.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/expression/parse.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _ast_constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ast/constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n/* harmony import */ var _ast_clean__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ast/clean */ \"../../node_modules/arquero/src/expression/ast/clean.js\");\n/* harmony import */ var _ast_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ast/util */ \"../../node_modules/arquero/src/expression/ast/util.js\");\n/* harmony import */ var _codegen__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./codegen */ \"../../node_modules/arquero/src/expression/codegen.js\");\n/* harmony import */ var _compile__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./compile */ \"../../node_modules/arquero/src/expression/compile.js\");\n/* harmony import */ var _util_entries__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/entries */ \"../../node_modules/arquero/src/util/entries.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _parse_escape__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./parse-escape */ \"../../node_modules/arquero/src/expression/parse-escape.js\");\n/* harmony import */ var _parse_expression__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./parse-expression */ \"../../node_modules/arquero/src/expression/parse-expression.js\");\n\n\n\n\n\n\n\n\n\n\n\n\nconst ANNOTATE = { [_ast_constants__WEBPACK_IMPORTED_MODULE_0__.Column]: 1, [_ast_constants__WEBPACK_IMPORTED_MODULE_0__.Op]: 1 };\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(input, opt = {}) {\n  const generate = opt.generate || _codegen__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n  const compiler = opt.compiler || _compile__WEBPACK_IMPORTED_MODULE_4__[\"default\"];\n  const params = getParams(opt);\n  const fields = {};\n  const opcall = {};\n  const names = [];\n  const exprs = [];\n  let fieldId = 0;\n  let opId = -1;\n\n  const compileExpr = opt.join ? compiler.join\n    : opt.index == 1 ? compiler.expr2\n    : compiler.expr;\n\n  // parser context\n  const ctx = {\n    op(op) {\n      const key = opKey(op);\n      return opcall[key] || (op.id = ++opId, opcall[key] = op);\n    },\n    field(node) {\n      const code = generate(node);\n      return fields[code] || (fields[code] = ++fieldId);\n    },\n    param(node) {\n      return (0,_ast_util__WEBPACK_IMPORTED_MODULE_2__.is)(_ast_constants__WEBPACK_IMPORTED_MODULE_0__.Literal, node)\n        ? node.value\n        : compiler.param(generate(node), params);\n    },\n    value(name, node) {\n      names.push(name);\n      const e = node.escape || (opt.ast\n        ? (0,_ast_clean__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(node)\n        : compileExpr(generate(node), params));\n      exprs.push(e);\n      // annotate expression if it is a direct column or op access\n      // this permits downstream optimizations\n      if (ANNOTATE[node.type] && e !== node && (0,_util_is_object__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(e)) {\n        e.field = node.name;\n      }\n    },\n    error(node, msg, note = '') {\n      // both expresions and fields are parsed\n      // with added code prefixes of length 6!\n      const i = node.start - 6;\n      const j = node.end - 6;\n      const snippet = String(ctx.spec).slice(i, j);\n      (0,_util_error__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(`${msg}: \"${snippet}\"${note}`);\n    }\n  };\n\n  // copy all options to context, potentially overwriting methods\n  Object.assign(ctx, opt, { params });\n\n  // parse each expression\n  for (const [name, value] of (0,_util_entries__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(input)) {\n    ctx.value(\n      name + '',\n      value.escape\n        ? (0,_parse_escape__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(ctx, value, params)\n        : (0,_parse_expression__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(ctx, value)\n    );\n  }\n\n  // return expression asts if requested\n  if (opt.ast) {\n    return { names, exprs };\n  }\n\n  // compile input field accessors\n  const f = [];\n  for (const key in fields) {\n    f[fields[key]] = compiler.expr(key, params);\n  }\n\n  // resolve input fields to operations\n  const ops = Object.values(opcall);\n  ops.forEach(op => op.fields = op.fields.map(id => f[id]));\n\n  return { names, exprs, ops };\n}\n\nfunction opKey(op) {\n  let key = `${op.name}(${op.fields.concat(op.params).join(',')})`;\n  if (op.frame) {\n    const frame = op.frame.map(v => Number.isFinite(v) ? Math.abs(v) : -1);\n    key += `[${frame},${!!op.peers}]`;\n  }\n  return key;\n}\n\nfunction getParams(opt) {\n  return (opt.table ? getTableParams(opt.table)\n    : opt.join ? {\n        ...getTableParams(opt.join[1]),\n        ...getTableParams(opt.join[0])\n      }\n    : {}) || {};\n}\n\nfunction getTableParams(table) {\n  return table && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(table.params) ? table.params() : {};\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/parse.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/rewrite.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/rewrite.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _ast_constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ast/constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n\n\n\nconst dictOps = {\n  '==': 1,\n  '!=': 1,\n  '===': 1,\n  '!==': 1\n};\n\n/**\n * Rewrite AST node to be a table column reference.\n * Additionally optimizes dictionary column operations.\n * @param {object} ref AST node to rewrite to a column reference.\n * @param {string} name The name of the column.\n * @param {number} index The table index of the column.\n * @param {object} col The actual table column instance.\n * @param {object} op Parent AST node operating on the column reference.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(ref, name, index = 0, col, op) {\n  ref.type = _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Column;\n  ref.name = name;\n  ref.table = index;\n\n  // proceed only if has parent op and is a dictionary column\n  if (op && col && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(col.keyFor)) {\n    // get other arg if op is an optimizeable operation\n    const lit = dictOps[op.operator]\n      ? op.left === ref ? op.right : op.left\n      : op.callee && op.callee.name === 'equal'\n      ? op.arguments[op.arguments[0] === ref ? 1 : 0]\n      : null;\n\n    // rewrite as dictionary lookup if other arg is a literal\n    if (lit && lit.type === _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Literal) {\n      rewriteDictionary(op, ref, lit, col.keyFor(lit.value));\n    }\n  }\n\n  return ref;\n}\n\nfunction rewriteDictionary(op, ref, lit, key) {\n  if (key < 0) {\n    // value not in dictionary, rewrite op as false literal\n    op.type = _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Literal;\n    op.value = false;\n    op.raw = 'false';\n  } else {\n    // rewrite ref as dict key access\n    ref.type = _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Dictionary;\n\n    // rewrite literal as target dict key\n    lit.value = key;\n    lit.raw = key + '';\n  }\n\n  return true;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/rewrite.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/expression/row-object.js":
/*!***************************************************************!*\
  !*** ../../node_modules/arquero/src/expression/row-object.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ROW_OBJECT: () => (/* binding */ ROW_OBJECT),\n/* harmony export */   rowObjectBuilder: () => (/* binding */ rowObjectBuilder),\n/* harmony export */   rowObjectCode: () => (/* binding */ rowObjectCode),\n/* harmony export */   rowObjectExpression: () => (/* binding */ rowObjectExpression)\n/* harmony export */ });\n/* harmony import */ var _ast_constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ast/constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n/* harmony import */ var _codegen__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./codegen */ \"../../node_modules/arquero/src/expression/codegen.js\");\n/* harmony import */ var _compile__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./compile */ \"../../node_modules/arquero/src/expression/compile.js\");\n/* harmony import */ var _rewrite__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./rewrite */ \"../../node_modules/arquero/src/expression/rewrite.js\");\n/* harmony import */ var _util_entries__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/entries */ \"../../node_modules/arquero/src/util/entries.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\nconst ROW_OBJECT = 'row_object';\n\nfunction rowObjectExpression(node, props) {\n  node.type = _ast_constants__WEBPACK_IMPORTED_MODULE_0__.ObjectExpression;\n\n  const p = node.properties = [];\n  for (const prop of (0,_util_entries__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(props)) {\n    const [name, key] = (0,_util_is_array__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(prop) ? prop : [prop, prop];\n    p.push({\n      type: _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Property,\n      key: { type: _ast_constants__WEBPACK_IMPORTED_MODULE_0__.Literal, raw: (0,_util_to_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(key) },\n      value: (0,_rewrite__WEBPACK_IMPORTED_MODULE_3__[\"default\"])({ computed: true }, name)\n    });\n  }\n\n  return node;\n}\n\nfunction rowObjectCode(props) {\n  return (0,_codegen__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(rowObjectExpression({}, props));\n}\n\nfunction rowObjectBuilder(props) {\n  return _compile__WEBPACK_IMPORTED_MODULE_2__[\"default\"].expr(rowObjectCode(props));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/expression/row-object.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/from-arrow.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/format/from-arrow.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _arrow_arrow_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../arrow/arrow-table */ \"../../node_modules/arquero/src/arrow/arrow-table.js\");\n/* harmony import */ var _arrow_arrow_column__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../arrow/arrow-column */ \"../../node_modules/arquero/src/arrow/arrow-column.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _table_bit_set__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../table/bit-set */ \"../../node_modules/arquero/src/table/bit-set.js\");\n/* harmony import */ var _table_column_set__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../table/column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n\n\n\n\n\n\n\n/**\n * Options for Apache Arrow import.\n * @typedef {object} ArrowOptions\n * @property {import('../table/transformable').Select} columns\n *  An ordered set of columns to import. The input may consist of column name\n *  strings, column integer indices, objects with current column names as keys\n *  and new column names as values (for renaming), or selection helper\n *  functions such as {@link all}, {@link not}, or {@link range}.\n */\n\n/**\n * Create a new table backed by an Apache Arrow table instance.\n * @param {object} arrow An Apache Arrow data table or byte buffer.\n * @param {ArrowOptions} options Options for Arrow import.\n * @return {ColumnTable} A new table containing the imported values.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(arrow, options = {}) {\n  arrow = (0,_arrow_arrow_table__WEBPACK_IMPORTED_MODULE_0__.from)(arrow);\n  const { chunks, length, schema } = arrow;\n\n  // resolve column selection\n  const fields = schema.fields.map(f => f.name);\n  const sel = (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_2__[\"default\"])({\n    columnNames: test => test ? fields.filter(test) : fields.slice(),\n    columnIndex: name => fields.indexOf(name)\n  }, options.columns || (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_2__.all)());\n\n  // build Arquero columns for backing Arrow columns\n  const cols = (0,_table_column_set__WEBPACK_IMPORTED_MODULE_4__[\"default\"])();\n  sel.forEach((name, key) => {\n    cols.add(name, (0,_arrow_arrow_column__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(arrow.getColumn(key)));\n  });\n\n  // build row filter bit mask as needed\n  const bits = arrow.count() !== length ? new _table_bit_set__WEBPACK_IMPORTED_MODULE_3__[\"default\"](length) : null;\n  if (bits) {\n    let b = 0;\n    let c = 0;\n    arrow.scan(\n      idx => bits.set(b + idx),\n      batch => { while (chunks[c] !== batch) b += chunks[c++].length; }\n    );\n  }\n\n  return new _table_column_table__WEBPACK_IMPORTED_MODULE_5__[\"default\"](cols.data, cols.names, bits);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/from-arrow.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/from-csv.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/format/from-csv.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _from_text_rows__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./from-text-rows */ \"../../node_modules/arquero/src/format/from-text-rows.js\");\n/* harmony import */ var _parse_parse_delimited__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./parse/parse-delimited */ \"../../node_modules/arquero/src/format/parse/parse-delimited.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n/**\n * Options for CSV parsing.\n * @typedef {object} CSVParseOptions\n * @property {string} [delimiter=','] Single-character delimiter between values.\n * @property {string} [decimal='.'] Single-character numeric decimal separator.\n * @property {boolean} [header=true] Flag to specify presence of header row.\n *  If true, assumes the CSV contains a header row with column names. If false,\n *  indicates the CSV does not contain a header row; columns are given the\n *  names 'col1', 'col2', etc unless the *names* option is specified.\n * @property {string[]} [names] An array of column names to use for header-less\n *  CSV files. This option is ignored if the header option is true.\n * @property {number} [skip=0] The number of lines to skip before reading data.\n * @property {string} [comment] A string used to identify comment lines. Any\n *  lines that start with the comment pattern are skipped.\n * @property {boolean} [autoType=true] Flag for automatic type inference.\n * @property {number} [autoMax=1000] Maximum number of initial values to use\n *  for type inference.\n * @property {Object.<string, (value: string) => any>} [parse] Object of\n *  column parsing options. The object keys should be column names. The object\n *  values should be parsing functions that transform values upon input.\n */\n\n/**\n * Parse a comma-separated values (CSV) string into a table. Other\n * delimiters, such as tabs or pipes ('|'), can be specified using\n * the options argument. By default, automatic type inference is performed\n * for input values; string values that match the ISO standard\n * date format are parsed into JavaScript Date objects. To disable this\n * behavior, set the autoType option to false. To perform custom parsing\n * of input column values, use the parse option.\n * @param {string} text A string in a delimited-value format.\n * @param {CSVParseOptions} options The formatting options.\n * @return {ColumnTable} A new table containing the parsed values.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(text, options = {}) {\n  const next = (0,_parse_parse_delimited__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(text, options);\n  return (0,_from_text_rows__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\n    next,\n    options.header !== false ? next() : options.names,\n    options\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/from-csv.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/from-fixed.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/format/from-fixed.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _from_text_rows__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./from-text-rows */ \"../../node_modules/arquero/src/format/from-text-rows.js\");\n/* harmony import */ var _parse_parse_lines__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./parse/parse-lines */ \"../../node_modules/arquero/src/format/parse/parse-lines.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n/**\n * Options for fixed width file parsing.\n * @typedef {object} FixedParseOptions\n * @property {[number, number][]} [positions] Array of start, end indices for\n *  fixed-width columns.\n * @property {number[]} [widths] Array of fixed column widths. This option is\n *  ignored if the positions property is specified.\n * @property {string[]} [names] An array of column names. The array length\n *  should match the length of the positions array. If not specified or\n *  shorter than the positions array, default column names are generated.\n * @property {string} [decimal='.'] Single-character numeric decimal separator.\n * @property {number} [skip=0] The number of lines to skip before reading data.\n * @property {string} [comment] A string used to identify comment lines. Any\n *  lines that start with the comment pattern are skipped.\n * @property {boolean} [autoType=true] Flag for automatic type inference.\n * @property {number} [autoMax=1000] Maximum number of initial values to use\n *  for type inference.\n * @property {Object.<string, (value: string) => any>} [parse] Object of\n *  column parsing options. The object keys should be column names. The object\n *  values should be parsing functions that transform values upon input.\n */\n\n/**\n * Parse a fixed-width file (FWF) string into a table. By default, automatic\n * type inference is performed for input values; string values that match the\n * ISO standard date format are parsed into JavaScript Date objects. To\n * disable this behavior, set the autoType option to false. To perform custom\n * parsing of input column values, use the parse option.\n * @param {string} text A string in a fixed-width file format.\n * @param {FixedParseOptions} options The formatting options.\n * @return {ColumnTable} A new table containing the parsed values.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(text, options = {}) {\n  const read = (0,_parse_parse_lines__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(text, options);\n  const p = positions(options);\n  return (0,_from_text_rows__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\n    () => {\n      const line = read();\n      if (line) {\n        return p.map(([i, j]) => line.slice(i, j).trim());\n      }\n    },\n    options.names,\n    options\n  );\n}\n\nfunction positions({ positions, widths }) {\n  if (!positions && !widths) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])('Fixed width files require a \"positions\" or \"widths\" option');\n  }\n  let i = 0;\n  return positions || widths.map(w => [i, i += w]);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/from-fixed.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/from-json.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/format/from-json.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _util_default_true__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/default-true */ \"../../node_modules/arquero/src/util/default-true.js\");\n/* harmony import */ var _util_is_array_type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-array-type */ \"../../node_modules/arquero/src/util/is-array-type.js\");\n/* harmony import */ var _util_is_digit_string__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-digit-string */ \"../../node_modules/arquero/src/util/is-digit-string.js\");\n/* harmony import */ var _util_is_iso_date_string__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-iso-date-string */ \"../../node_modules/arquero/src/util/is-iso-date-string.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n\n\n\n\n/**\n * Options for JSON parsing.\n * @typedef {object} JSONParseOptions\n * @property {boolean} [autoType=true] Flag controlling automatic type\n *  inference. If false, date parsing for input JSON strings is disabled.\n * @property {Object.<string, (value: any) => any>} [parse] Object of column\n *  parsing options. The object keys should be column names. The object values\n *  should be parsing functions that transform values upon input.\n */\n\n/**\n * Parse JavaScript Object Notation (JSON) data into a table.\n * The expected JSON data format is an object with column names for keys\n * and column value arrays for values. By default string values that match\n * the ISO standard date format are parsed into JavaScript Date objects.\n * To disable this behavior, set the autoType option to false. To perform\n * custom parsing of input column values, use the parse option. Auto-type\n * parsing is not performed for columns with custom parse options.\n * The data payload can also be provided as the \"data\" property of an\n * enclosing object, with an optional \"schema\" property containing table\n * metadata such as a \"fields\" array of ordered column information.\n * @param {string|object} data A string in JSON format, or pre-parsed object.\n * @param {JSONParseOptions} options The formatting options.\n * @return {ColumnTable} A new table containing the parsed values.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(json, options = {}) {\n  const autoType = (0,_util_default_true__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(options.autoType);\n\n  // parse string input\n  if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(json)) {\n    json = JSON.parse(json);\n  }\n\n  // separate schema and data, as needed\n  let data = json.data, names;\n  if ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(data) && !(0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(data)) {\n    if (json.schema && json.schema.fields) {\n      names = json.schema.fields.map(f => f.name);\n    }\n  } else {\n    data = json;\n  }\n\n  // parse values as necessary\n  if (autoType || options.parse) {\n    const parsers = options.parse || {};\n    for (const name in data) {\n      const col = data[name];\n      const len = col.length;\n      if (parsers[name]) {\n        // apply custom parser\n        for (let i = 0; i < len; ++i) {\n          col[i] = parsers[name](col[i]);\n        }\n      } else if (autoType) {\n        // apply autoType parser\n        for (let i = 0; i < len; ++i) {\n          const val = col[i];\n          if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(val) && (0,_util_is_iso_date_string__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(val) && !(0,_util_is_digit_string__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(val)) {\n            col[i] = new Date(val);\n          }\n        }\n      }\n    }\n  }\n\n  return new _table_column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"](data, names);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/from-json.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/from-text-rows.js":
/*!***************************************************************!*\
  !*** ../../node_modules/arquero/src/format/from-text-rows.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/identity */ \"../../node_modules/arquero/src/util/identity.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_repeat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/repeat */ \"../../node_modules/arquero/src/util/repeat.js\");\n/* harmony import */ var _util_parse_values__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/parse-values */ \"../../node_modules/arquero/src/util/parse-values.js\");\n\n\n\n\n\n\nfunction defaultNames(n, off = 0) {\n  return (0,_util_repeat__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(n - off, i => `col${i + off + 1}`);\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(next, names, options) {\n  let row = next();\n  const n = row.length;\n  const automax = +options.autoMax || 1000;\n  const values = (0,_util_repeat__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(n, () => []);\n  names = names\n    ? names.length < n ? [...names, defaultNames(n, names.length)] : names\n    : defaultNames(n);\n\n  // read in initial rows to guess types\n  let idx = 0;\n  for (; idx < automax && row; ++idx, row = next()) {\n    for (let i = 0; i < n; ++i) {\n      values[i].push(row[i] === '' ? null : row[i]);\n    }\n  }\n\n  // initialize parsers\n  const parsers = getParsers(names, values, options);\n\n  // apply parsers\n  parsers.forEach((parse, i) => {\n    if (parse === _util_identity__WEBPACK_IMPORTED_MODULE_1__[\"default\"]) return;\n    const v = values[i];\n    for (let r = 0; r < idx; ++r) {\n      if (v[r] != null) v[r] = parse(v[r]);\n    }\n  });\n\n  // parse remainder of file\n  for (; row; row = next()) {\n    for (let i = 0; i < n; ++i) {\n      values[i].push(row[i] ? parsers[i](row[i]) : null);\n    }\n  }\n\n  const columns = {};\n  names.forEach((name, i) => columns[name] = values[i]);\n  return new _table_column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"](columns, names);\n}\n\nfunction getParsers(names, values, options) {\n  const { parse = {} } = options;\n  const noParse = options.autoType === false;\n\n  return names.map(\n    (name, i) => (0,_util_is_function__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(parse[name]) ? parse[name]\n      : noParse ? _util_identity__WEBPACK_IMPORTED_MODULE_1__[\"default\"]\n      : (0,_util_parse_values__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(values[i], options)\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/from-text-rows.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/infer.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/format/infer.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n\n\nfunction isExactDateUTC(d) {\n  return d.getUTCHours() === 0\n    && d.getUTCMinutes() === 0\n    && d.getUTCSeconds() === 0\n    && d.getUTCMilliseconds() === 0;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(scan, options = {}) {\n  let count = 0;\n  let nulls = 0;\n  let dates = 0;\n  let dutcs = 0;\n  let nums = 0;\n  let digits = 0;\n\n  scan(value => {\n    ++count;\n    if (value == null) {\n      ++nulls;\n      return;\n    }\n\n    const type = typeof value;\n    if (type === 'object' && (0,_util_is_date__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value)) {\n      ++dates;\n      if (isExactDateUTC(value)) ++dutcs;\n    } else if (type === 'number') {\n      ++nums;\n      if (value === value &&  (value | 0) !== value) {\n        const s = value + '';\n        const p = s.indexOf('.');\n        if (p >= 0) {\n          const e = s.indexOf('e');\n          const l = e > 0 ? e : s.length;\n          digits = Math.max(digits, l - p - 1);\n        }\n      }\n    }\n  });\n\n  return {\n    align:  (nulls + nums + dates) / count > 0.5 ? 'r' : 'l',\n    format: {\n      utc:    dates === dutcs,\n      digits: Math.min(digits, options.maxdigits || 6)\n    }\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/infer.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/load-url.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/format/load-url.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   load: () => (/* binding */ load),\n/* harmony export */   loadArrow: () => (/* binding */ loadArrow),\n/* harmony export */   loadCSV: () => (/* binding */ loadCSV),\n/* harmony export */   loadFixed: () => (/* binding */ loadFixed),\n/* harmony export */   loadJSON: () => (/* binding */ loadJSON)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _from_arrow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./from-arrow */ \"../../node_modules/arquero/src/format/from-arrow.js\");\n/* harmony import */ var _from_csv__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./from-csv */ \"../../node_modules/arquero/src/format/from-csv.js\");\n/* harmony import */ var _from_fixed__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./from-fixed */ \"../../node_modules/arquero/src/format/from-fixed.js\");\n/* harmony import */ var _from_json__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./from-json */ \"../../node_modules/arquero/src/format/from-json.js\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../table */ \"../../node_modules/arquero/src/table/index.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n\n\n\n/**\n * Options for file loading.\n * @typedef {object} LoadOptions\n * @property {'arrayBuffer'|'text'|'json'} [as='text'] A string indicating\n *  the data type of the file. One of 'arrayBuffer', 'json', or 'text'.\n * @property {(data: *, options?: object) => ColumnTable} [using] A function\n *  that accepts a data payload (e.g., string or buffer) and an options object\n *  as input and returns an Arquero table (such as fromCSV or fromJSON).\n * @property {object} [fetch] Options to pass to the HTTP fetch method\n *  when loading a URL.\n */\n\n/**\n * Load data from a file and return a Promise for an Arquero table.\n * A specific format parser can be provided with the *using* option,\n * otherwise CSV format is assumed. The options to this method are\n * passed as the second argument to the format parser.\n * @param {string} url The URL to load.\n * @param {LoadOptions & object} options The loading and formatting options.\n * @return {Promise<ColumnTable>} A Promise for an Arquero table.\n * @example aq.load('data/table.csv')\n * @example aq.load('data/table.json', { using: aq.fromJSON })\n * @example aq.load('data/table.json', { using: aq.from })\n */\nfunction load(url, options = {}) {\n  const parse = options.using || _from_csv__WEBPACK_IMPORTED_MODULE_2__[\"default\"];\n  return fetch(url, options.fetch)\n    .then(res => res[options.as || 'text']())\n    .then(data => parse(data, options));\n}\n\n/**\n * Load an Arrow file from a URL and return a Promise for an Arquero table.\n * @param {string} url The URL to load.\n * @param {LoadOptions & import('./from-arrow').ArrowOptions} options Arrow format options.\n * @return {Promise<ColumnTable>} A Promise for an Arquero table.\n * @example aq.loadArrow('data/table.arrow')\n */\nfunction loadArrow(url, options) {\n  return load(url, { ...options, as: 'arrayBuffer', using: _from_arrow__WEBPACK_IMPORTED_MODULE_1__[\"default\"] });\n}\n\n/**\n * Load a CSV file from a URL and return a Promise for an Arquero table.\n * @param {string} url The URL to load.\n * @param {LoadOptions & import('./from-csv').CSVParseOptions} options CSV format options.\n * @return {Promise<ColumnTable>} A Promise for an Arquero table.\n * @example aq.loadCSV('data/table.csv')\n * @example aq.loadTSV('data/table.tsv', { delimiter: '\\t' })\n */\nfunction loadCSV(url, options) {\n  return load(url, { ...options, as: 'text', using: _from_csv__WEBPACK_IMPORTED_MODULE_2__[\"default\"] });\n}\n\n/**\n * Load a fixed width file from a URL and return a Promise for an Arquero table.\n * @param {string} url The URL to load.\n * @param {LoadOptions & import('./from-fixed').FixedParseOptions} options Fixed width format options.\n * @return {Promise<ColumnTable>} A Promise for an Arquero table.\n * @example aq.loadFixedWidth('data/table.txt', { names: ['name', 'city', state'], widths: [10, 20, 2] })\n */\n function loadFixed(url, options) {\n  return load(url, { ...options, as: 'text', using: _from_fixed__WEBPACK_IMPORTED_MODULE_3__[\"default\"] });\n}\n\n/**\n * Load a JSON file from a URL and return a Promise for an Arquero table.\n * If the loaded JSON is array-valued, an array-of-objects format is assumed\n * and the aq.from method is used to construct the table. Otherwise, a\n * column object format is assumed and aq.fromJSON is applied.\n * @param {string} url The URL to load.\n * @param {LoadOptions & import('./from-json').JSONParseOptions} options JSON format options.\n * @return {Promise<ColumnTable>} A Promise for an Arquero table.\n * @example aq.loadJSON('data/table.json')\n */\nfunction loadJSON(url, options) {\n  return load(url, { ...options, as: 'json', using: parseJSON });\n}\n\nfunction parseJSON(data, options) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(data) ? (0,_table__WEBPACK_IMPORTED_MODULE_5__.from)(data) : (0,_from_json__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(data, options);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/load-url.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/parse/constants.js":
/*!****************************************************************!*\
  !*** ../../node_modules/arquero/src/format/parse/constants.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   EOF: () => (/* binding */ EOF),\n/* harmony export */   EOL: () => (/* binding */ EOL),\n/* harmony export */   NEWLINE: () => (/* binding */ NEWLINE),\n/* harmony export */   QUOTE: () => (/* binding */ QUOTE),\n/* harmony export */   RETURN: () => (/* binding */ RETURN)\n/* harmony export */ });\nconst EOL = {};\nconst EOF = {};\nconst QUOTE = 34;\nconst NEWLINE = 10;\nconst RETURN = 13;\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/parse/constants.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/parse/parse-delimited.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/arquero/src/format/parse/parse-delimited.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/format/parse/constants.js\");\n/* harmony import */ var _text_filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./text-filter */ \"../../node_modules/arquero/src/format/parse/text-filter.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n\n\n\n\n// Adapted from d3-dsv: https://github.com/d3/d3-dsv/blob/master/src/dsv.js\n// Copyright 2013-2016 Mike Bostock\n// All rights reserved.\n// Redistribution and use in source and binary forms, with or without modification,\n// are permitted provided that the following conditions are met:\n// * Redistributions of source code must retain the above copyright notice, this\n//   list of conditions and the following disclaimer.\n// * Redistributions in binary form must reproduce the above copyright notice,\n//   this list of conditions and the following disclaimer in the documentation\n//   and/or other materials provided with the distribution.\n// * Neither the name of the author nor the names of contributors may be used to\n//   endorse or promote products derived from this software without specific prior\n//   written permission.\n// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\" AND\n// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED\n// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\n// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR\n// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES\n// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;\n// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON\n// ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(text, { delimiter = ',', skip, comment }) {\n  if (delimiter.length !== 1) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(`Text \"delimiter\" should be a single character, found \"${delimiter}\"`);\n  }\n  const delimCode = delimiter.charCodeAt(0);\n\n  let N = text.length;\n  let I = 0; // current character index\n  let t; // current token\n  let eof = N <= 0; // current token followed by EOF?\n  let eol = false; // current token followed by EOL?\n\n  // Strip the trailing newline.\n  if (text.charCodeAt(N - 1) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) --N;\n  if (text.charCodeAt(N - 1) === _constants__WEBPACK_IMPORTED_MODULE_0__.RETURN) --N;\n\n  function token() {\n    if (eof) return _constants__WEBPACK_IMPORTED_MODULE_0__.EOF;\n    if (eol) return eol = false, _constants__WEBPACK_IMPORTED_MODULE_0__.EOL;\n\n    // Unescape quotes.\n    const j = I;\n    let i, c;\n    if (text.charCodeAt(j) === _constants__WEBPACK_IMPORTED_MODULE_0__.QUOTE) {\n      while (I++ < N && text.charCodeAt(I) !== _constants__WEBPACK_IMPORTED_MODULE_0__.QUOTE || text.charCodeAt(++I) === _constants__WEBPACK_IMPORTED_MODULE_0__.QUOTE);\n      if ((i = I) >= N) eof = true;\n      else if ((c = text.charCodeAt(I++)) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) eol = true;\n      else if (c === _constants__WEBPACK_IMPORTED_MODULE_0__.RETURN) { eol = true; if (text.charCodeAt(I) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) ++I; }\n      return text.slice(j + 1, i - 1).replace(/\"\"/g, '\"');\n    }\n\n    // Find next delimiter or newline.\n    while (I < N) {\n      if ((c = text.charCodeAt(i = I++)) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) eol = true;\n      else if (c === _constants__WEBPACK_IMPORTED_MODULE_0__.RETURN) { eol = true; if (text.charCodeAt(I) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) ++I; }\n      else if (c !== delimCode) continue;\n      return text.slice(j, i);\n    }\n\n    // Return last token before EOF.\n    return eof = true, text.slice(j, N);\n  }\n\n  function next() {\n    if ((t = token()) !== _constants__WEBPACK_IMPORTED_MODULE_0__.EOF) {\n      const row = [];\n      while (t !== _constants__WEBPACK_IMPORTED_MODULE_0__.EOL && t !== _constants__WEBPACK_IMPORTED_MODULE_0__.EOF) row.push(t), t = token();\n      return row;\n    }\n  }\n\n  return (0,_text_filter__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\n    next, skip,\n    comment && (x => (x && x[0] || '').startsWith(comment))\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/parse/parse-delimited.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/parse/parse-lines.js":
/*!******************************************************************!*\
  !*** ../../node_modules/arquero/src/format/parse/parse-lines.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/format/parse/constants.js\");\n/* harmony import */ var _text_filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./text-filter */ \"../../node_modules/arquero/src/format/parse/text-filter.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(text, { skip, comment }) {\n  let N = text.length;\n  let I = 0; // current character index\n\n  // Strip the trailing newline.\n  if (text.charCodeAt(N - 1) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) --N;\n  if (text.charCodeAt(N - 1) === _constants__WEBPACK_IMPORTED_MODULE_0__.RETURN) --N;\n\n  function read() {\n    if (I >= N) return;\n\n    const j = I;\n    let eol = false;\n    let i, c;\n\n    // Find next newline.\n    while (I < N) {\n      if ((c = text.charCodeAt(i = I++)) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) eol = true;\n      else if (c === _constants__WEBPACK_IMPORTED_MODULE_0__.RETURN) { eol = true; if (text.charCodeAt(I) === _constants__WEBPACK_IMPORTED_MODULE_0__.NEWLINE) ++I; }\n      if (eol) return text.slice(j, i);\n    }\n\n    // Return last line before EOF.\n    return text.slice(j, N);\n  }\n\n  return (0,_text_filter__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\n    read, skip,\n    comment && (x => (x || '').startsWith(comment))\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/parse/parse-lines.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/parse/text-filter.js":
/*!******************************************************************!*\
  !*** ../../node_modules/arquero/src/format/parse/text-filter.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(read, skip, drop) {\n  // skip initial lines, if requested\n  let s = +skip || 0;\n  while (--s >= 0) read();\n\n  // return filtered stream\n  return drop ? () => {\n    let line;\n    while (!line) {\n      if (drop(line = read())) line = null;\n      else return line;\n    }\n  } : read;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/parse/text-filter.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/to-arrow.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/format/to-arrow.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _arrow_encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../arrow/encode */ \"../../node_modules/arquero/src/arrow/encode/index.js\");\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_arrow_encode__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/to-arrow.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/to-csv.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/format/to-csv.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/format/util.js\");\n/* harmony import */ var _util_format_date__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/format-date */ \"../../node_modules/arquero/src/util/format-date.js\");\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n/**\n * Options for CSV formatting.\n * @typedef {object} CSVFormatOptions\n * @property {string} [delimiter=','] The delimiter between values.\n * @property {number} [limit=Infinity] The maximum number of rows to print.\n * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n * @property {import('./util').ColumnSelectOptions} [columns] Ordered list\n *  of column names to include. If function-valued, the function should\n *  accept a table as input and return an array of column name strings.\n * @property {Object.<string, (value: any) => any>} [format] Object of column\n *  format options. The object keys should be column names. The object values\n *  should be formatting functions to invoke to transform column values prior\n *  to output. If specified, these override automatically inferred options.\n */\n\n/**\n * Format a table as a comma-separated values (CSV) string. Other\n * delimiters, such as tabs or pipes ('|'), can be specified using\n * the options argument.\n * @param {ColumnTable} table The table to format.\n * @param {CSVFormatOptions} options The formatting options.\n * @return {string} A delimited-value format string.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, options = {}) {\n  const names = (0,_util__WEBPACK_IMPORTED_MODULE_1__.columns)(table, options.columns);\n  const format = options.format || {};\n  const delim = options.delimiter || ',';\n  const reFormat = new RegExp(`[\"${delim}\\n\\r]`);\n\n  const formatValue = value => value == null ? ''\n    : (0,_util_is_date__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(value) ? (0,_util_format_date__WEBPACK_IMPORTED_MODULE_2__.formatUTCDate)(value, true)\n    : reFormat.test(value += '') ? '\"' + value.replace(/\"/g, '\"\"') + '\"'\n    : value;\n\n  const vals = names.map(formatValue);\n  let text = '';\n\n  (0,_util__WEBPACK_IMPORTED_MODULE_1__.scan)(table, names, options.limit || Infinity, options.offset, {\n    row() {\n      text += vals.join(delim) + '\\n';\n    },\n    cell(value, name, index) {\n      vals[index] = formatValue(format[name] ? format[name](value) : value);\n    }\n  });\n\n  return text + vals.join(delim);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/to-csv.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/to-html.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/format/to-html.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _value__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./value */ \"../../node_modules/arquero/src/format/value.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/format/util.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_map_object__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/map-object */ \"../../node_modules/arquero/src/util/map-object.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n\n/**\n * Null format function.\n * @callback NullFormat\n * @param {null|undefined} [value] The value to format.\n * @return {string} The formatted HTML string.\n */\n\n/**\n * CSS style function.\n * @callback StyleFunction\n * @param {string} name The column name.\n * @param {number} row The table row index.\n * @return {string} A CSS style string.\n */\n\n/**\n * CSS style options.\n * @typedef {Object.<string, string | StyleFunction>} StyleOptions\n */\n\n/**\n * Options for HTML formatting.\n * @typedef {object} HTMLFormatOptions\n * @property {number} [limit=Infinity] The maximum number of rows to print.\n * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n * @property {import('./util').ColumnSelectOptions} [columns] Ordered list\n *  of column names to include. If function-valued, the function should\n *  accept a table as input and return an array of column name strings.\n * @property {import('./util').ColumnAlignOptions} [align] Object of column\n *  alignment options. The object keys should be column names. The object\n *  values should be aligment strings, one of 'l' (left), 'c' (center), or\n *  'r' (right). If specified, these override automatically inferred options.\n * @property {import('./util').ColumnFormatOptions} [format] Object of column\n *  format options. The object keys should be column names. The object values\n *  should be formatting functions or specification objects. If specified,\n *  these override automatically inferred options.\n * @property {NullFormat} [null] Format function for null or undefined values.\n *  If specified, this function will be invoked with the null or undefined\n *  value as the sole input, and the return value will be used as the HTML\n *  output for the value.\n * @property {StyleOptions} [style] CSS styles to include in HTML output.\n *  The object keys should be HTML table tag names: 'table', 'thead',\n *  'tbody', 'tr', 'th', or 'td'. The object values should be strings of\n *  valid CSS style directives (such as \"font-weight: bold;\") or functions\n *  that take a column name and row as inputs and return a CSS string.\n * @property {number} [maxdigits=6] The maximum number of fractional digits\n *  to include when formatting numbers. This option is passed to the format\n *  inference method and is overridden by any explicit format options.\n */\n\n/**\n * Format a table as an HTML table string.\n * @param {ColumnTable} table The table to format.\n * @param {HTMLFormatOptions} options The formatting options.\n * @return {string} An HTML table string.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, options = {}) {\n  const names = (0,_util__WEBPACK_IMPORTED_MODULE_2__.columns)(table, options.columns);\n  const { align, format } = (0,_util__WEBPACK_IMPORTED_MODULE_2__.formats)(table, names, options);\n  const style = styles(options);\n  const nullish = options.null;\n\n  const alignValue = a => a === 'c' ? 'center' : a === 'r' ? 'right' : 'left';\n  const escape = s => s.replace(/&/g, '&amp;')\n    .replace(/</g, '&lt;')\n    .replace(/>/g, '&gt;');\n  const baseFormat = (value, opt) => escape((0,_value__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value, opt));\n  const formatter = nullish\n    ? (value, opt) => value == null ? nullish(value) : baseFormat(value, opt)\n    : baseFormat;\n\n  let r = -1;\n  let idx = -1;\n\n  const tag = (tag, name, shouldAlign) => {\n    const a = shouldAlign ? alignValue(align[name]) : '';\n    const s = style[tag] ? (style[tag](name, idx, r) || '') : '';\n    const css = (a ? (`text-align: ${a};` + (s ? ' ' : '')) : '') + s;\n    return `<${tag}${css ? ` style=\"${css}\"` : ''}>`;\n  };\n\n  let text = tag('table')\n    + tag('thead')\n    + tag('tr', r)\n    + names.map(name => `${tag('th', name, 1)}${name}</th>`).join('')\n    + '</tr></thead>'\n    + tag('tbody');\n\n  (0,_util__WEBPACK_IMPORTED_MODULE_2__.scan)(table, names, options.limit, options.offset, {\n    row(row) {\n      r = row;\n      text += (++idx ? '</tr>' : '') + tag('tr');\n    },\n    cell(value, name) {\n      text += tag('td', name, 1)\n        + formatter(value, format[name])\n        + '</td>';\n    }\n  });\n\n  return text + '</tr></tbody></table>';\n}\n\nfunction styles(options) {\n  return (0,_util_map_object__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(\n    options.style,\n    value => (0,_util_is_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(value) ? value : () => value\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/to-html.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/to-json.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/format/to-json.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/format/util.js\");\n/* harmony import */ var _util_format_date__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/format-date */ \"../../node_modules/arquero/src/util/format-date.js\");\n/* harmony import */ var _util_default_true__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/default-true */ \"../../node_modules/arquero/src/util/default-true.js\");\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n\n/**\n * Options for JSON formatting.\n * @typedef {object} JSONFormatOptions\n * @property {number} [limit=Infinity] The maximum number of rows to print.\n * @property {number} [offset=0] The row offset indicating how many initial\n *  rows to skip.\n * @property {boolean} [schema=true] Flag indicating if table schema metadata\n *  should be included in the JSON output. If false, only the data payload\n *  is included.\n * @property {import('./util').ColumnSelectOptions} [columns] Ordered list\n *  of column names to include. If function-valued, the function should\n *  accept a table as input and return an array of column name strings.\n * @property {Object.<string, (value: any) => any>} [format] Object of column\n *  format options. The object keys should be column names. The object values\n *  should be formatting functions to invoke to transform column values prior\n *  to output. If specified, these override automatically inferred options.\n */\n\nconst defaultFormatter = value => (0,_util_is_date__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(value)\n  ? (0,_util_format_date__WEBPACK_IMPORTED_MODULE_2__.formatUTCDate)(value, true)\n  : value;\n\n/**\n * Format a table as a JavaScript Object Notation (JSON) string.\n * @param {ColumnTable} table The table to format.\n * @param {JSONFormatOptions} options The formatting options.\n * @return {string} A JSON string.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, options = {}) {\n  const schema = (0,_util_default_true__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(options.schema);\n  const format = options.format || {};\n  const names = (0,_util__WEBPACK_IMPORTED_MODULE_1__.columns)(table, options.columns);\n  let text = '{';\n\n  if (schema) {\n    text += '\"schema\":{\"fields\":'\n      + JSON.stringify(names.map(name => ({ name })))\n      + '},\"data\":{';\n  }\n\n  names.forEach((name, i) => {\n    text += (i ? ',' : '') + JSON.stringify(name) + ':[';\n\n    const column = table.column(name);\n    const formatter = format[name] || defaultFormatter;\n    let r = -1;\n    table.scan(row => {\n      const value = column.get(row);\n      text += (++r ? ',' : '') + JSON.stringify(formatter(value));\n    }, true, options.limit, options.offset);\n\n    text += ']';\n  });\n\n  return text + '}' + (schema ? '}' : '');\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/to-json.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/to-markdown.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/format/to-markdown.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _value__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./value */ \"../../node_modules/arquero/src/format/value.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/format/util.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n/**\n * Options for Markdown formatting.\n * @typedef {object} MarkdownFormatOptions\n * @property {number} [limit=Infinity] The maximum number of rows to print.\n * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n * @property {import('./util').ColumnSelectOptions} [columns] Ordered list\n *  of column names to include. If function-valued, the function should\n *  accept a table as input and return an array of column name strings.\n * @property {import('./util').ColumnAlignOptions} [align] Object of column\n *  alignment options. The object keys should be column names. The object\n *  values should be aligment strings, one of 'l' (left), 'c' (center), or\n *  'r' (right). If specified, these override automatically inferred options.\n * @property {import('./util').ColumnFormatOptions} [format] Object of column\n *  format options. The object keys should be column names. The object values\n *  should be formatting functions or specification objects. If specified,\n *  these override automatically inferred options.\n * @property {number} [maxdigits=6] The maximum number of fractional digits\n *  to include when formatting numbers. This option is passed to the format\n *  inference method and is overridden by any explicit format options.\n */\n\n/**\n * Format a table as a GitHub-Flavored Markdown table string.\n * @param {ColumnTable} table The table to format.\n * @param {MarkdownFormatOptions} options The formatting options.\n * @return {string} A GitHub-Flavored Markdown table string.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, options = {}) {\n  const names = (0,_util__WEBPACK_IMPORTED_MODULE_2__.columns)(table, options.columns);\n  const { align, format } = (0,_util__WEBPACK_IMPORTED_MODULE_2__.formats)(table, names, options);\n\n  const alignValue = a => a === 'c' ? ':-:' : a === 'r' ? '-:' : ':-';\n  const escape = s => s.replace(/\\|/g, '\\\\|');\n\n  let text = '|'\n    + names.map(escape).join('|')\n    + '|\\n|'\n    + names.map(name => alignValue(align[name])).join('|')\n    + '|';\n\n  (0,_util__WEBPACK_IMPORTED_MODULE_2__.scan)(table, names, options.limit, options.offset, {\n    row() {\n      text += '\\n|';\n    },\n    cell(value, name) {\n      text += escape((0,_value__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value, format[name])) + '|';\n    }\n  });\n\n  return text + '\\n';\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/to-markdown.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/util.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/format/util.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   columns: () => (/* binding */ columns),\n/* harmony export */   formats: () => (/* binding */ formats),\n/* harmony export */   scan: () => (/* binding */ scan)\n/* harmony export */ });\n/* harmony import */ var _table_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/table */ \"../../node_modules/arquero/src/table/table.js\");\n/* harmony import */ var _infer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./infer */ \"../../node_modules/arquero/src/format/infer.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n // eslint-disable-line no-unused-vars\n\n\n\n\n/**\n * Column selection function.\n * @typedef {(table: Table) => string[]} ColumnSelectFunction\n */\n\n/**\n * Column selection options.\n * @typedef {string[]|ColumnSelectFunction} ColumnSelectOptions\n */\n\n/**\n * Column format options. The object keys should be column names.\n * The object values should be formatting functions or objects.\n * If specified, these override any automatically inferred options.\n * @typedef {Object.<string, import('./value').ValueFormatOptions} ColumnFormatOptions\n */\n\n/**\n * Column alignment options. The object keys should be column names.\n * The object values should be aligment strings, one of 'l' (left),\n * 'c' (center), or 'r' (right).\n * If specified, these override any automatically inferred options.\n * @typedef {Object.<string, 'l'|'c'|'r'>} ColumnAlignOptions\n */\n\nfunction columns(table, names) {\n  return (0,_util_is_function__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(names)\n    ? names(table)\n    : names || table.columnNames();\n}\n\nfunction formats(table, names, options) {\n  const formatOpt = options.format || {};\n  const alignOpt = options.align || {};\n  const format = {};\n  const align = {};\n\n  names.forEach(name => {\n    const auto = (0,_infer__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values(table, name), options);\n    align[name] = alignOpt[name] || auto.align;\n    format[name] = formatOpt[name] || auto.format;\n  });\n\n  return { align, format };\n}\n\nfunction values(table, columnName) {\n  const column = table.column(columnName);\n  return fn => table.scan(row => fn(column.get(row)));\n}\n\nfunction scan(table, names, limit = 100, offset, ctx) {\n  const data = table.data();\n  const n = names.length;\n  table.scan(row => {\n    ctx.row(row);\n    for (let i = 0; i < n; ++i) {\n      const name = names[i];\n      ctx.cell(data[names[i]].get(row), name, i);\n    }\n  }, true, limit, offset);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/util.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/format/value.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/format/value.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_format_date__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/format-date */ \"../../node_modules/arquero/src/util/format-date.js\");\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_typed_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-typed-array */ \"../../node_modules/arquero/src/util/is-typed-array.js\");\n\n\n\n\n\n/**\n * Column format object.\n * @typedef {object} ValueFormatObject\n * @property {boolean} [utc=false] If true, format dates in UTC time.\n * @property {number} [digits=0] The number of fractional digits to include\n *  when formatting numbers.\n * @property {number} [maxlen=30] The maximum string length for formatting\n *  nested object or array values.\n */\n\n/**\n * @callback ValueFormatFunction\n * @param {*} value The value to format.\n * @return {*} A string-coercible or JSON-compatible formatted value.\n */\n\n/**\n * Value format options.\n * @typedef {ValueFormatObject|ValueFormatFunction} ValueFormatOptions\n */\n\n/**\n * Format a value as a string.\n * @param {*} v The value to format.\n * @param {ValueFormatOptions} options Formatting options.\n * @return {string} The formatted string.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(v, options = {}) {\n  if ((0,_util_is_function__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(options)) {\n    return options(v) + '';\n  }\n\n  const type = typeof v;\n\n  if (type === 'object') {\n    if ((0,_util_is_date__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(v)) {\n      return options.utc ? (0,_util_format_date__WEBPACK_IMPORTED_MODULE_0__.formatUTCDate)(v) : (0,_util_format_date__WEBPACK_IMPORTED_MODULE_0__.formatDate)(v);\n    } else {\n      const s = JSON.stringify(\n        v,\n        (k, v) => (0,_util_is_typed_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(v) ? Array.from(v) : v\n      );\n      const maxlen = options.maxlen || 30;\n      return s.length > maxlen\n        ? s.slice(0, 28) + '\\u2026' + (s[0] === '[' ? ']' : '}')\n        : s;\n    }\n  } else if (type === 'number') {\n    const digits = options.digits || 0;\n    let a;\n    return v !== 0 && ((a = Math.abs(v)) >= 1e18 || a < Math.pow(10, -digits))\n      ? v.toExponential(digits)\n      : v.toFixed(digits);\n  } else {\n    return v + '';\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/format/value.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/bin.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/bin.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Options for binning number values.\n * @typedef {object} BinOptions\n * @property {number} [maxbins] The maximum number of bins.\n * @property {number} [minstep] The minimum step size between bins.\n * @property {number} [step] The exact step size to use between bins.\n *  If specified, the maxbins and minstep options are ignored.\n * @property {boolean} [nice=true] Flag indicating if bins should\n *  snap to \"nice\" human-friendly values such as multiples of ten.\n * @property {number} [offset=0] Step offset for bin boundaries.\n *  The default floors to the lower bin boundary. A value of 1 snaps\n *  one step higher to the upper bin boundary, and so on.\n */\n\n/**\n * Generate a table expression that performs uniform binning of\n * number values. The resulting string can be used as part of the\n * input to table transformation verbs.\n * @param {string} name The name of the column to bin.\n * @param {BinOptions} [options] Binning scheme options.\n * @return {string} A table expression string for binned values.\n * @example bin('colA', { maxbins: 20 })\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(name, options = {}) {\n  const field = `d[${JSON.stringify(name)}]`;\n  const { maxbins, nice, minstep, step, offset } = options;\n  const args = [maxbins, nice, minstep, step];\n\n  let n = args.length;\n  while (n && args[--n] == null) args.pop();\n  const a = args.length ? ', ' + args.map(a => a + '').join(', ') : '';\n\n  return `d => op.bin(${field}, ...op.bins(${field}${a}), ${offset || 0})`;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/bin.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/desc.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/desc.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _wrap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./wrap */ \"../../node_modules/arquero/src/helpers/wrap.js\");\n\n\n/**\n * Annotate a table expression to indicate descending sort order.\n * @param {string|Function|object} expr The table expression to annotate.\n * @return {object} A wrapped expression indicating descending sort.\n * @example desc('colA')\n * @example desc(d => d.colA)\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(expr) {\n  return (0,_wrap__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(expr, { desc: true });\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/desc.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/escape.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/escape.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _wrap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./wrap */ \"../../node_modules/arquero/src/helpers/wrap.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n\n\n\n/**\n * Escape a function or value to prevent it from being parsed and recompiled.\n * This helper can be used in lieu of single-table table expressions (which\n * are internally parsed and rewritten) to apply a JavaScript function as-is,\n * including support for closures. It can also be used to pass a constant,\n * literal value as a table expression, bypassing the parser.\n * @param {*} value A function or value to escape.\n * @return {object} A wrapper object representing the escaped value.\n * @example escape(d => d.a.toFixed(2))\n * @example escape(d => d.a * -d.b)\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return (0,_wrap__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value, {\n    escape: true,\n    toString() { (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Escaped values can not be serialized.'); }\n  });\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/escape.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/field.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/field.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _wrap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./wrap */ \"../../node_modules/arquero/src/helpers/wrap.js\");\n\n\n/**\n * Annotate an expression to indicate it is a string field reference.\n * @param {string|object} expr The column name, or an existing wrapped\n *  expression for a column name.\n * @param {string} [name] The column name to use. If provided, will\n *  overwrite the input expression value.\n * @param {number} [table=0] The table index of the field, in case of\n *  expressions over multiple tables.\n * @return A wrapped expression for a named column.\n * @example field('colA')\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(expr, name, table = 0) {\n  const props = table ? { field: true, table } : { field: true };\n  return (0,_wrap__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    expr,\n    name ? { expr: name, ...props } : props\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/field.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/frac.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/frac.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Generate a table expression that computes the number of rows\n * corresponding to a given fraction for each group. The resulting\n * string can be used as part of the input to the sample verb.\n * @param {number} fraction The fractional value.\n * @return {string} A table expression string for computing row counts.\n * @example frac(0.5)\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(fraction) {\n  return `() => op.round(${+fraction} * op.count())`;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/frac.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/names.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/names.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Select columns by index and rename them to the provided names. Returns a\n * selection helper function that takes a table as input and produces a\n * rename map as output. If the number of provided names is less than the\n * number of table columns, the rename map will only include entries for the\n * provided names. If the number of table columns is less than then number of\n * provided names, only the rename map will only include entries that cover\n * the existing columns.\n * @param {...(string|string[])} names An ordered list of column names.\n * @return {Function} Selection function compatible with {@link Table#select}.\n * @example table.rename(aq.names('a', 'b', 'c'))\n * @example table.select(aq.names(['a', 'b', 'c']))\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(...names) {\n  names = names.flat();\n  return table => {\n    const m = new Map();\n    const n = Math.min(names.length, table.numCols());\n    for (let i = 0; i < n; ++i) {\n      m.set(table.columnName(i), names[i]);\n    }\n    return m;\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/names.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/rolling.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/rolling.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _wrap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./wrap */ \"../../node_modules/arquero/src/helpers/wrap.js\");\n\n\n/**\n * Annotate a table expression to compute rolling aggregate or window\n * functions within a sliding window frame. For example, to specify a\n * rolling 7-day average centered on the current day, use rolling with\n * a frame value of [-3, 3].\n * @param {string|Function|object} expr The table expression to annotate.\n * @param {[number?, number?]} [frame=[-Infinity, 0]] The sliding window frame\n *  offsets. Each entry indicates an offset from the current value. If an\n *  entry is non-finite, the frame will be unbounded in that direction,\n *  including all preceding or following values. If unspecified, the frame\n *  will include the current values and all preceding values.\n * @param {boolean} [includePeers=false] Indicates if the sliding window frame\n *  should ignore peer (tied) values. If false (the default), the window frame\n *  boundaries are insensitive to peer values. If `true`, the window frame\n *  expands to include all peers. This parameter only affects operations that\n *  depend on the window frame: aggregate functions and the first_value,\n *  last_value, and nth_value window functions.\n * @return A new wrapped expression annotated with rolling window parameters.\n * @example rolling(d => mean(d.colA), [-3, 3])\n * @example rolling(d => last_value(d.colA), null, true)\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(expr, frame, includePeers) {\n  return (0,_wrap__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(expr, {\n    window: {\n      frame: frame || [-Infinity, 0],\n      peers: !!includePeers\n    }\n  });\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/rolling.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/selection.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/selection.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   all: () => (/* binding */ all),\n/* harmony export */   \"default\": () => (/* binding */ resolve),\n/* harmony export */   endswith: () => (/* binding */ endswith),\n/* harmony export */   matches: () => (/* binding */ matches),\n/* harmony export */   not: () => (/* binding */ not),\n/* harmony export */   range: () => (/* binding */ range),\n/* harmony export */   startswith: () => (/* binding */ startswith)\n/* harmony export */ });\n/* harmony import */ var _util_assign__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/assign */ \"../../node_modules/arquero/src/util/assign.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_escape_regexp__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/escape-regexp */ \"../../node_modules/arquero/src/util/escape-regexp.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\n\n\nfunction resolve(table, sel, map = new Map()) {\n  sel = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(sel) ? table.columnName(sel) : sel;\n\n  if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(sel)) {\n    map.set(sel, sel);\n  } else if ((0,_util_is_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(sel)) {\n    sel.forEach(r => resolve(table, r, map));\n  } else if ((0,_util_is_function__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(sel)) {\n    resolve(table, sel(table), map);\n  } else if ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(sel)) {\n    (0,_util_assign__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(map, sel);\n  } else {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(`Invalid column selection: ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(sel)}`);\n  }\n\n  return map;\n}\n\nfunction decorate(value, toObject) {\n  value.toObject = toObject;\n  return value;\n}\n\nfunction toObject(value) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(value) ? value.map(toObject)\n    : value && value.toObject ? value.toObject()\n    : value;\n}\n\n/**\n * Proxy type for SelectHelper function.\n * @typedef {import('../table/transformable').SelectHelper} SelectHelper\n */\n\n/**\n * Select all columns in a table.\n * Returns a function-valued selection compatible with {@link Table#select}.\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction all() {\n  return decorate(\n    table => table.columnNames(),\n    () => ({ all: [] })\n  );\n}\n\n/**\n * Negate a column selection, selecting all other columns in a table.\n * Returns a function-valued selection compatible with {@link Table#select}.\n * @param {...any} selection The selection to negate. May be a column name,\n *  column index, array of either, or a selection function (e.g., from range).\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction not(...selection) {\n  selection = selection.flat();\n  return decorate(\n    table => {\n      const drop = resolve(table, selection);\n      return table.columnNames(name => !drop.has(name));\n    },\n    () => ({ not: toObject(selection) })\n  );\n}\n\n/**\n * Select a contiguous range of columns.\n * @param {string|number} start The name/index of the first selected column.\n * @param {string|number} end The name/index of the last selected column.\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction range(start, end) {\n  return decorate(\n    table => {\n      let i = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(start) ? start : table.columnIndex(start);\n      let j = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(end) ? end : table.columnIndex(end);\n      if (j < i) { const t = j; j = i; i = t; }\n      return table.columnNames().slice(i, j + 1);\n    },\n    () => ({ range: [start, end] })\n  );\n}\n\n/**\n * Select all columns whose names match a pattern.\n * @param {string|RegExp} pattern A string or regular expression pattern to match.\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction matches(pattern) {\n  if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(pattern)) pattern = RegExp((0,_util_escape_regexp__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(pattern));\n  return decorate(\n    table => table.columnNames(name => pattern.test(name)),\n    () => ({ matches: [pattern.source, pattern.flags] })\n  );\n}\n\n/**\n * Select all columns whose names start with a string.\n * @param {string} string The string to match at the start of the column name.\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction startswith(string) {\n  return matches(RegExp('^' + (0,_util_escape_regexp__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(string)));\n}\n\n/**\n * Select all columns whose names end with a string.\n * @param {string} string The string to match at the end of the column name.\n * @return {SelectHelper} Selection function compatible with select().\n */\nfunction endswith(string) {\n  return matches(RegExp((0,_util_escape_regexp__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(string) + '$'));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/selection.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/slice.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/slice.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Generate a table expression that filters a table based on ordered row\n * indices from start to end (end not included), where start and end\n * represent per-group ordered row numbers in the table. The resulting\n * string can be used as the input to the filter verb.\n * @param {number} [start] Zero-based index at which to start extraction.\n *  A negative index indicates an offset from the end of the group.\n *  If start is undefined, slice starts from the index 0.\n * @param {number} [end] Zero-based index before which to end extraction.\n *  A negative index indicates an offset from the end of the group.\n *  If end is omitted, slice extracts through the end of the group.\n * @return {string} A table expression string for slicing values.\n * @example slice(1, -1)\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(start = 0, end = Infinity) {\n  return `${prep(start)} < row_number() && row_number() <= ${prep(end)}`;\n}\n\nfunction prep(index) {\n  return index < 0 ? `count() + ${index}` : index;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/slice.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/helpers/wrap.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/helpers/wrap.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n\n\n/**\n * Annotate an expression in an object wrapper.\n * @param {string|Function|object} expr An expression to annotate.\n * @param {object} properties The properties to annotate with.\n * @return {object} A new wrapped expression object.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(expr, properties) {\n  return expr && expr.expr\n    ? new Wrapper({ ...expr, ...properties })\n    : new Wrapper(properties, expr);\n}\n\nclass Wrapper {\n  constructor(properties, expr) {\n    this.expr = expr;\n    Object.assign(this, properties);\n  }\n  toString() {\n    return String(this.expr);\n  }\n  toObject() {\n    return {\n      ...this,\n      expr: this.toString(),\n      ...((0,_util_is_function__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(this.expr) ? { func: true } : {})\n    };\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/helpers/wrap.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/index.js":
/*!***********************************************!*\
  !*** ../../node_modules/arquero/src/index.js ***!
  \***********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Type: () => (/* reexport safe */ _arrow_arrow_types__WEBPACK_IMPORTED_MODULE_11__[\"default\"]),\n/* harmony export */   addAggregateFunction: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addAggregateFunction),\n/* harmony export */   addFunction: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addFunction),\n/* harmony export */   addPackage: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addPackage),\n/* harmony export */   addTableMethod: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addTableMethod),\n/* harmony export */   addVerb: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addVerb),\n/* harmony export */   addWindowFunction: () => (/* reexport safe */ _register__WEBPACK_IMPORTED_MODULE_28__.addWindowFunction),\n/* harmony export */   agg: () => (/* reexport safe */ _verbs_helpers_agg__WEBPACK_IMPORTED_MODULE_26__[\"default\"]),\n/* harmony export */   all: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.all),\n/* harmony export */   bin: () => (/* reexport safe */ _helpers_bin__WEBPACK_IMPORTED_MODULE_18__[\"default\"]),\n/* harmony export */   desc: () => (/* reexport safe */ _helpers_desc__WEBPACK_IMPORTED_MODULE_20__[\"default\"]),\n/* harmony export */   endswith: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.endswith),\n/* harmony export */   escape: () => (/* reexport safe */ _helpers_escape__WEBPACK_IMPORTED_MODULE_19__[\"default\"]),\n/* harmony export */   field: () => (/* reexport safe */ _helpers_field__WEBPACK_IMPORTED_MODULE_21__[\"default\"]),\n/* harmony export */   frac: () => (/* reexport safe */ _helpers_frac__WEBPACK_IMPORTED_MODULE_22__[\"default\"]),\n/* harmony export */   from: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_29__.from),\n/* harmony export */   fromArrow: () => (/* reexport safe */ _format_from_arrow__WEBPACK_IMPORTED_MODULE_12__[\"default\"]),\n/* harmony export */   fromCSV: () => (/* reexport safe */ _format_from_csv__WEBPACK_IMPORTED_MODULE_13__[\"default\"]),\n/* harmony export */   fromFixed: () => (/* reexport safe */ _format_from_fixed__WEBPACK_IMPORTED_MODULE_14__[\"default\"]),\n/* harmony export */   fromJSON: () => (/* reexport safe */ _format_from_json__WEBPACK_IMPORTED_MODULE_15__[\"default\"]),\n/* harmony export */   internal: () => (/* binding */ internal),\n/* harmony export */   load: () => (/* reexport safe */ _format_load_url__WEBPACK_IMPORTED_MODULE_16__.load),\n/* harmony export */   loadArrow: () => (/* reexport safe */ _format_load_url__WEBPACK_IMPORTED_MODULE_16__.loadArrow),\n/* harmony export */   loadCSV: () => (/* reexport safe */ _format_load_url__WEBPACK_IMPORTED_MODULE_16__.loadCSV),\n/* harmony export */   loadFixed: () => (/* reexport safe */ _format_load_url__WEBPACK_IMPORTED_MODULE_16__.loadFixed),\n/* harmony export */   loadJSON: () => (/* reexport safe */ _format_load_url__WEBPACK_IMPORTED_MODULE_16__.loadJSON),\n/* harmony export */   matches: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.matches),\n/* harmony export */   names: () => (/* reexport safe */ _helpers_names__WEBPACK_IMPORTED_MODULE_23__[\"default\"]),\n/* harmony export */   not: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.not),\n/* harmony export */   op: () => (/* reexport safe */ _op_op_api__WEBPACK_IMPORTED_MODULE_27__[\"default\"]),\n/* harmony export */   query: () => (/* reexport safe */ _query_query__WEBPACK_IMPORTED_MODULE_7__.query),\n/* harmony export */   queryFrom: () => (/* reexport safe */ _query_query__WEBPACK_IMPORTED_MODULE_7__.queryFrom),\n/* harmony export */   range: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.range),\n/* harmony export */   rolling: () => (/* reexport safe */ _helpers_rolling__WEBPACK_IMPORTED_MODULE_24__[\"default\"]),\n/* harmony export */   seed: () => (/* reexport safe */ _util_random__WEBPACK_IMPORTED_MODULE_10__.seed),\n/* harmony export */   startswith: () => (/* reexport safe */ _helpers_selection__WEBPACK_IMPORTED_MODULE_25__.startswith),\n/* harmony export */   table: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_29__.table),\n/* harmony export */   toArrow: () => (/* reexport safe */ _arrow_encode__WEBPACK_IMPORTED_MODULE_17__[\"default\"]),\n/* harmony export */   version: () => (/* binding */ version)\n/* harmony export */ });\n/* harmony import */ var _table_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./table/table */ \"../../node_modules/arquero/src/table/table.js\");\n/* harmony import */ var _table_column__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./table/column */ \"../../node_modules/arquero/src/table/column.js\");\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _table_transformable__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./table/transformable */ \"../../node_modules/arquero/src/table/transformable.js\");\n/* harmony import */ var _engine_reduce_reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./engine/reduce/reducer */ \"../../node_modules/arquero/src/engine/reduce/reducer.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _expression_ast_walk__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./expression/ast/walk */ \"../../node_modules/arquero/src/expression/ast/walk.js\");\n/* harmony import */ var _query_query__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./query/query */ \"../../node_modules/arquero/src/query/query.js\");\n/* harmony import */ var _query_verb__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./query/verb */ \"../../node_modules/arquero/src/query/verb.js\");\n/* harmony import */ var _package_json__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../package.json */ \"../../node_modules/arquero/package.json\");\n/* harmony import */ var _util_random__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./util/random */ \"../../node_modules/arquero/src/util/random.js\");\n/* harmony import */ var _arrow_arrow_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./arrow/arrow-types */ \"../../node_modules/arquero/src/arrow/arrow-types.js\");\n/* harmony import */ var _format_from_arrow__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./format/from-arrow */ \"../../node_modules/arquero/src/format/from-arrow.js\");\n/* harmony import */ var _format_from_csv__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./format/from-csv */ \"../../node_modules/arquero/src/format/from-csv.js\");\n/* harmony import */ var _format_from_fixed__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./format/from-fixed */ \"../../node_modules/arquero/src/format/from-fixed.js\");\n/* harmony import */ var _format_from_json__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./format/from-json */ \"../../node_modules/arquero/src/format/from-json.js\");\n/* harmony import */ var _format_load_url__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./format/load-url */ \"../../node_modules/arquero/src/format/load-url.js\");\n/* harmony import */ var _arrow_encode__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./arrow/encode */ \"../../node_modules/arquero/src/arrow/encode/index.js\");\n/* harmony import */ var _helpers_bin__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./helpers/bin */ \"../../node_modules/arquero/src/helpers/bin.js\");\n/* harmony import */ var _helpers_escape__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./helpers/escape */ \"../../node_modules/arquero/src/helpers/escape.js\");\n/* harmony import */ var _helpers_desc__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./helpers/desc */ \"../../node_modules/arquero/src/helpers/desc.js\");\n/* harmony import */ var _helpers_field__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./helpers/field */ \"../../node_modules/arquero/src/helpers/field.js\");\n/* harmony import */ var _helpers_frac__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./helpers/frac */ \"../../node_modules/arquero/src/helpers/frac.js\");\n/* harmony import */ var _helpers_names__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./helpers/names */ \"../../node_modules/arquero/src/helpers/names.js\");\n/* harmony import */ var _helpers_rolling__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./helpers/rolling */ \"../../node_modules/arquero/src/helpers/rolling.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _verbs_helpers_agg__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./verbs/helpers/agg */ \"../../node_modules/arquero/src/verbs/helpers/agg.js\");\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n/* harmony import */ var _register__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./register */ \"../../node_modules/arquero/src/register.js\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./table */ \"../../node_modules/arquero/src/table/index.js\");\n// export internal class definitions\n\n\n\n\n\n\n\n\n\n\nconst internal = {\n  Table: _table_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  ColumnTable: _table_column_table__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  Transformable: _table_transformable__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  Query: _query_query__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  Reducer: _engine_reduce_reducer__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  Verb: _query_verb__WEBPACK_IMPORTED_MODULE_8__.Verb,\n  Verbs: _query_verb__WEBPACK_IMPORTED_MODULE_8__.Verbs,\n  columnFactory: _table_column__WEBPACK_IMPORTED_MODULE_1__.columnFactory,\n  parse: _expression_parse__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  walk_ast: _expression_ast_walk__WEBPACK_IMPORTED_MODULE_6__[\"default\"]\n};\n\n// export public API\n\nconst version = _package_json__WEBPACK_IMPORTED_MODULE_9__.version;\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/aggregate-functions.js":
/*!****************************************************************!*\
  !*** ../../node_modules/arquero/src/op/aggregate-functions.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_bins__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/bins */ \"../../node_modules/arquero/src/util/bins.js\");\n/* harmony import */ var _util_distinct_map__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/distinct-map */ \"../../node_modules/arquero/src/util/distinct-map.js\");\n/* harmony import */ var _util_is_bigint__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-bigint */ \"../../node_modules/arquero/src/util/is-bigint.js\");\n/* harmony import */ var _util_no_op__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/no-op */ \"../../node_modules/arquero/src/util/no-op.js\");\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _util_product__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/product */ \"../../node_modules/arquero/src/util/product.js\");\n\n\n\n\n\n\n\n/**\n * Initialize an aggregate operator.\n */\nfunction initOp(op) {\n  op.init = op.init || _util_no_op__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n  op.add = op.add || _util_no_op__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n  op.rem = op.rem || _util_no_op__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n  return op;\n}\n\nfunction initProduct(s, value) {\n  s.product_v = false;\n  return s.product = value;\n}\n\n/**\n * Initialize an aggregate operator.\n * @callback AggregateInit\n * @param {object} state The aggregate state object.\n * @return {void}\n */\n\n/**\n * Add a value to an aggregate operator.\n * @callback AggregateAdd\n * @param {object} state The aggregate state object.\n * @param {*} value The value to add.\n * @return {void}\n */\n\n/**\n * Remove a value from an aggregate operator.\n * @callback AggregateRem\n * @param {object} state The aggregate state object.\n * @param {*} value The value to remove.\n * @return {void}\n */\n\n/**\n * Retrive an output value from an aggregate operator.\n * @callback AggregateValue\n * @param {object} state The aggregate state object.\n * @return {*} The output value.\n */\n\n/**\n * An operator instance for an aggregate function.\n * @typedef {object} AggregateOperator\n * @property {AggregateInit} init Initialize the operator.\n * @property {AggregateAdd} add Add a value to the operator state.\n * @property {AggregateRem} rem Remove a value from the operator state.\n * @property {AggregateValue} value Retrieve an output value.\n */\n\n/**\n * Create a new aggregate operator instance.\n * @callback AggregateCreate\n * @param {...any} params The aggregate operator parameters.\n * @return {AggregateOperator} The instantiated aggregate operator.\n */\n\n/**\n * An operator definition for an aggregate function.\n * @typedef {object} AggregateDef\n * @property {AggregateCreate} create Create a new operator instance.\n * @property {number[]} param Two-element array containing the\n *  counts of input fields and additional parameters.\n * @property {string[]} [req] Names of operators required by this one.\n * @property {string[]} [stream] Names of operators required by this one\n *  for streaming operations (value removes).\n */\n\n/**\n * Aggregate operator definitions.\n */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  /** @type {AggregateDef} */\n  count: {\n    create: () => initOp({\n      value: s => s.count\n    }),\n    param: []\n  },\n\n  /** @type {AggregateDef} */\n  array_agg: {\n    create: () => initOp({\n      init: s => s.values = true,\n      value: s => s.list.values(s.stream)\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  object_agg: {\n    create: () => initOp({\n      init:  s => s.values = true,\n      value: s => Object.fromEntries(s.list.values())\n    }),\n    param: [2]\n  },\n\n  /** @type {AggregateDef} */\n  map_agg: {\n    create: () => initOp({\n      init:  s => s.values = true,\n      value: s => new Map(s.list.values())\n    }),\n    param: [2]\n  },\n\n  /** @type {AggregateDef} */\n  entries_agg: {\n    create: () => initOp({\n      init:  s => s.values = true,\n      value: s => s.list.values(s.stream)\n    }),\n    param: [2]\n  },\n\n  /** @type {AggregateDef} */\n  any: {\n    create: () => initOp({\n      add: (s, v) => { if (s.any == null) s.any = v; },\n      value: s => s.valid ? s.any : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  valid: {\n    create: () => initOp({\n      value: s => s.valid\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  invalid: {\n    create: () => initOp({\n      value: s => s.count - s.valid\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  distinct: {\n    create: () => ({\n      init: s => s.distinct = (0,_util_distinct_map__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(),\n      value: s => s.distinct.count() + (s.valid === s.count ? 0 : 1),\n      add: (s, v) => s.distinct.increment(v),\n      rem: (s, v) => s.distinct.decrement(v)\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  array_agg_distinct: {\n    create: () => initOp({\n      value: s => s.distinct.values()\n    }),\n    param: [1],\n    req: ['distinct']\n  },\n\n  /** @type {AggregateDef} */\n  mode: {\n    create: () => initOp({\n      value: s => {\n        let mode = _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"];\n        let max = 0;\n        s.distinct.forEach((value, count) => {\n          if (count > max) {\n            max = count;\n            mode = value;\n          }\n        });\n        return mode;\n      }\n    }),\n    param: [1],\n    req: ['distinct']\n  },\n\n  /** @type {AggregateDef} */\n  sum: {\n    create: () => ({\n      init:  s => s.sum = 0,\n      value: s => s.valid ? s.sum : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      add: (s, v) => (0,_util_is_bigint__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(v)\n        ? (s.sum === 0 ? s.sum = v : s.sum += v)\n        : s.sum += +v,\n      rem: (s, v) => s.sum -= v\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  product: {\n    create: () => ({\n      init:  s => initProduct(s, 1),\n      value: s => s.valid\n        ? (\n            s.product_v\n              ? initProduct(s, (0,_util_product__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(s.list.values()))\n              : s.product\n          )\n        : undefined,\n      add: (s, v) => (0,_util_is_bigint__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(v)\n        ? (s.product === 1 ? s.product = v : s.product *= v)\n        : s.product *= v,\n      rem: (s, v) => (v == 0 || v === Infinity || v === -Infinity)\n        ? s.product_v = true\n        : s.product /= v\n    }),\n    param: [1],\n    stream: ['array_agg']\n  },\n\n  /** @type {AggregateDef} */\n  mean: {\n    create: () => ({\n      init: s => s.mean = 0,\n      value: s => s.valid ? s.mean : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      add: (s, v) => {\n        s.mean_d = v - s.mean;\n        s.mean += s.mean_d / s.valid;\n      },\n      rem: (s, v) => {\n        s.mean_d = v - s.mean;\n        s.mean -= s.valid ? s.mean_d / s.valid : s.mean;\n      }\n    }),\n    param: [1]\n  },\n\n  /** @type {AggregateDef} */\n  average: {\n    create: () => initOp({\n      value: s => s.valid ? s.mean : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [1],\n    req: ['mean']\n  },\n\n  /** @type {AggregateDef} */\n  variance: {\n    create: () => ({\n      init:  s => s.dev = 0,\n      value: s => s.valid > 1 ? s.dev / (s.valid - 1) : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      add: (s, v) => s.dev += s.mean_d * (v - s.mean),\n      rem: (s, v) => s.dev -= s.mean_d * (v - s.mean)\n    }),\n    param: [1],\n    req: ['mean']\n  },\n\n  /** @type {AggregateDef} */\n  variancep: {\n    create: () => initOp({\n      value: s => s.valid > 1 ? s.dev / s.valid : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [1],\n    req: ['variance']\n  },\n\n  /** @type {AggregateDef} */\n  stdev: {\n    create: () => initOp({\n      value: s => s.valid > 1 ? Math.sqrt(s.dev / (s.valid - 1)) : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [1],\n    req: ['variance']\n  },\n\n  /** @type {AggregateDef} */\n  stdevp: {\n    create: () => initOp({\n      value: s => s.valid > 1 ? Math.sqrt(s.dev / s.valid) : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [1],\n    req: ['variance']\n  },\n\n  /** @type {AggregateDef} */\n  min: {\n    create: () => ({\n      init:  s => s.min = _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      value: s => s.min = (Number.isNaN(s.min) ? s.list.min() : s.min),\n      add: (s, v) => { if (v < s.min || s.min === _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]) s.min = v; },\n      rem: (s, v) => { if (v <= s.min) s.min = NaN; }\n    }),\n    param: [1],\n    stream: ['array_agg']\n  },\n\n  /** @type {AggregateDef} */\n  max: {\n    create: () => ({\n      init:  s => s.max = _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      value: s => s.max = (Number.isNaN(s.max) ? s.list.max() : s.max),\n      add: (s, v) => { if (v > s.max || s.max === _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]) s.max = v; },\n      rem: (s, v) => { if (v >= s.max) s.max = NaN; }\n    }),\n    param: [1],\n    stream: ['array_agg']\n  },\n\n  /** @type {AggregateDef} */\n  quantile: {\n    create: (p) => initOp({\n      value: s => s.list.quantile(p)\n    }),\n    param: [1, 1],\n    req: ['array_agg']\n  },\n\n  /** @type {AggregateDef} */\n  median: {\n    create: () => initOp({\n      value: s => s.list.quantile(0.5)\n    }),\n    param: [1],\n    req: ['array_agg']\n  },\n\n  /** @type {AggregateDef} */\n  covariance: {\n    create: () => ({\n      init:  s => {\n        s.cov = s.mean_x = s.mean_y = s.dev_x = s.dev_y = 0;\n      },\n      value: s => s.valid > 1 ? s.cov / (s.valid - 1) : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n      add: (s, x, y) => {\n        const dx = x - s.mean_x;\n        const dy = y - s.mean_y;\n        s.mean_x += dx / s.valid;\n        s.mean_y += dy / s.valid;\n        const dy2 = y - s.mean_y;\n        s.dev_x += dx * (x - s.mean_x);\n        s.dev_y += dy * dy2;\n        s.cov += dx * dy2;\n      },\n      rem: (s, x, y) => {\n        const dx = x - s.mean_x;\n        const dy = y - s.mean_y;\n        s.mean_x -= s.valid ? dx / s.valid : s.mean_x;\n        s.mean_y -= s.valid ? dy / s.valid : s.mean_y;\n        const dy2 = y - s.mean_y;\n        s.dev_x -= dx * (x - s.mean_x);\n        s.dev_y -= dy * dy2;\n        s.cov -= dx * dy2;\n      }\n    }),\n    param: [2]\n  },\n\n  /** @type {AggregateDef} */\n  covariancep: {\n    create: () => initOp({\n      value: s => s.valid > 1 ? s.cov / s.valid : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [2],\n    req: ['covariance']\n  },\n\n  /** @type {AggregateDef} */\n  corr: {\n    create: () => initOp({\n      value: s => s.valid > 1\n        ? s.cov / (Math.sqrt(s.dev_x) * Math.sqrt(s.dev_y))\n        : _util_null__WEBPACK_IMPORTED_MODULE_4__[\"default\"]\n    }),\n    param: [2],\n    req: ['covariance']\n  },\n\n  /** @type {AggregateDef} */\n  bins: {\n    create: (maxbins, nice, minstep, step) => initOp({\n      value: s => (0,_util_bins__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(s.min, s.max, maxbins, nice, minstep, step)\n    }),\n    param: [1, 4],\n    req: ['min', 'max']\n  }\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/aggregate-functions.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/array.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/array.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _util_is_array_type__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/is-array-type */ \"../../node_modules/arquero/src/util/is-array-type.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_is_valid__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/is-valid */ \"../../node_modules/arquero/src/util/is-valid.js\");\n\n\n\n\n\nconst isSeq = (seq) => (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(seq) || (0,_util_is_string__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(seq);\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  compact:      (arr) => (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(arr) ? arr.filter(v => (0,_util_is_valid__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(v)) : arr,\n  concat:       (...values) => [].concat(...values),\n  includes:     (seq, value, index) => isSeq(seq)\n                  ? seq.includes(value, index)\n                  : false,\n  indexof:      (seq, value) => isSeq(seq) ? seq.indexOf(value) : -1,\n  join:         (arr, delim) => (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(arr) ? arr.join(delim) : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lastindexof:  (seq, value) => isSeq(seq) ? seq.lastIndexOf(value) : -1,\n  length:       (seq) => isSeq(seq) ? seq.length : 0,\n  pluck:        (arr, prop) => (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(arr)\n                  ? arr.map(v => (0,_util_is_valid__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(v) ? v[prop] : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"])\n                  : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  reverse:      (seq) => (0,_util_is_array_type__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(seq) ? seq.slice().reverse()\n                  : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(seq) ? seq.split('').reverse().join('')\n                  : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  slice:        (seq, start, end) => isSeq(seq) ? seq.slice(start, end) : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"]\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/array.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/bin.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/bin.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Truncate a value to a bin boundary.\n * Useful for creating equal-width histograms.\n * Values outside the [min, max] range will be mapped to\n * -Infinity (< min) or +Infinity (> max).\n * @param {number} value - The value to bin.\n * @param {number} min - The minimum bin boundary.\n * @param {number} max - The maximum bin boundary.\n * @param {number} step - The step size between bin boundaries.\n * @param {number} [offset=0] - Offset in steps by which to adjust\n *  the bin value. An offset of 1 will return the next boundary.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, min, max, step, offset) {\n  return value == null ? null\n    : value < min ? -Infinity\n    : value > max ? +Infinity\n    : (\n        value = Math.max(min, Math.min(value, max)),\n        min + step * Math.floor(1e-14 + (value - min) / step + (offset || 0))\n      );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/bin.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/date.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/date.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_format_date__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/format-date */ \"../../node_modules/arquero/src/util/format-date.js\");\n/* harmony import */ var _util_parse_iso_date__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/parse-iso-date */ \"../../node_modules/arquero/src/util/parse-iso-date.js\");\n\n\n\nconst msMinute = 6e4;\nconst msDay = 864e5;\nconst msWeek = 6048e5;\n\nconst t0 = new Date();\nconst t1 = new Date();\nconst t = d => (\n  t0.setTime(typeof d === 'string' ? (0,_util_parse_iso_date__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(d) : d),\n  t0\n);\n\n/**\n * Function to create a new Date value.\n * If no arguments are provided, the current time is used.\n * @param {number} [year] The year.\n * @param {number} [month=0] The (zero-based) month.\n * @param {number} [date=1] The date within the month.\n * @param {number} [hours=0] The hour within the day.\n * @param {number} [minutes=0] The minute within the hour.\n * @param {number} [seconds=0] The second within the minute.\n * @param {number} [milliseconds=0] The milliseconds within the second.\n * @return {date} The resuting Date value.\n */\nfunction datetime(year, month, date, hours, minutes, seconds, milliseconds) {\n  return !arguments.length\n    ? new Date(Date.now())\n    : new Date(\n        year,\n        month || 0,\n        date == null ? 1 : date,\n        hours || 0,\n        minutes || 0,\n        seconds || 0,\n        milliseconds || 0\n      );\n}\n\n/**\n * Function to create a new Date value according to UTC time.\n * If no arguments are provided, the current time is used.\n * @param {number} [year] The year.\n * @param {number} [month=0] The (zero-based) month.\n * @param {number} [date=1] The date within the month.\n * @param {number} [hours=0] The hour within the day.\n * @param {number} [minutes=0] The minute within the hour.\n * @param {number} [seconds=0] The second within the minute.\n * @param {number} [milliseconds=0] The milliseconds within the second.\n * @return {date} The resuting Date value.\n */\nfunction utcdatetime(year, month, date, hours, minutes, seconds, milliseconds) {\n  return !arguments.length\n    ? new Date(Date.now())\n    : new Date(Date.UTC(\n        year,\n        month || 0,\n        date == null ? 1 : date,\n        hours || 0,\n        minutes || 0,\n        seconds || 0,\n        milliseconds || 0\n      ));\n}\n\nfunction dayofyear(date) {\n  t1.setTime(+date);\n  t1.setHours(0, 0, 0, 0);\n  t0.setTime(+t1);\n  t0.setMonth(0);\n  t0.setDate(1);\n  const tz = (t1.getTimezoneOffset() - t0.getTimezoneOffset()) * msMinute;\n  return Math.floor(1 + ((t1 - t0) - tz) / msDay);\n}\n\nfunction utcdayofyear(date) {\n  t1.setTime(+date);\n  t1.setUTCHours(0, 0, 0, 0);\n  const t0 = Date.UTC(t1.getUTCFullYear(), 0, 1);\n  return Math.floor(1 + (t1 - t0) / msDay);\n}\n\nfunction week(date, firstday) {\n  const i = firstday || 0;\n  t1.setTime(+date);\n  t1.setDate(t1.getDate() - (t1.getDay() + 7 - i) % 7);\n  t1.setHours(0, 0, 0, 0);\n  t0.setTime(+date);\n  t0.setMonth(0);\n  t0.setDate(1);\n  t0.setDate(1 - (t0.getDay() + 7 - i) % 7);\n  t0.setHours(0, 0, 0, 0);\n  const tz = (t1.getTimezoneOffset() - t0.getTimezoneOffset()) * msMinute;\n  return Math.floor((1 + (t1 - t0) - tz) / msWeek);\n}\n\nfunction utcweek(date, firstday) {\n  const i = firstday || 0;\n  t1.setTime(+date);\n  t1.setUTCDate(t1.getUTCDate() - (t1.getUTCDay() + 7 - i) % 7);\n  t1.setUTCHours(0, 0, 0, 0);\n  t0.setTime(+date);\n  t0.setUTCMonth(0);\n  t0.setUTCDate(1);\n  t0.setUTCDate(1 - (t0.getUTCDay() + 7 - i) % 7);\n  t0.setUTCHours(0, 0, 0, 0);\n  return Math.floor((1 + (t1 - t0)) / msWeek);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  format_date:     (date, shorten) => (0,_util_format_date__WEBPACK_IMPORTED_MODULE_0__.formatDate)(t(date), !shorten),\n  format_utcdate:  (date, shorten) => (0,_util_format_date__WEBPACK_IMPORTED_MODULE_0__.formatUTCDate)(t(date), !shorten),\n  timestamp:       (date) => +t(date),\n  year:            (date) => t(date).getFullYear(),\n  quarter:         (date) => Math.floor(t(date).getMonth() / 3),\n  month:           (date) => t(date).getMonth(),\n  date:            (date) => t(date).getDate(),\n  dayofweek:       (date) => t(date).getDay(),\n  hours:           (date) => t(date).getHours(),\n  minutes:         (date) => t(date).getMinutes(),\n  seconds:         (date) => t(date).getSeconds(),\n  milliseconds:    (date) => t(date).getMilliseconds(),\n  utcyear:         (date) => t(date).getUTCFullYear(),\n  utcquarter:      (date) => Math.floor(t(date).getUTCMonth() / 3),\n  utcmonth:        (date) => t(date).getUTCMonth(),\n  utcdate:         (date) => t(date).getUTCDate(),\n  utcdayofweek:    (date) => t(date).getUTCDay(),\n  utchours:        (date) => t(date).getUTCHours(),\n  utcminutes:      (date) => t(date).getUTCMinutes(),\n  utcseconds:      (date) => t(date).getUTCSeconds(),\n  utcmilliseconds: (date) => t(date).getUTCMilliseconds(),\n  datetime,\n  dayofyear,\n  week,\n  utcdatetime,\n  utcdayofyear,\n  utcweek,\n  now: Date.now\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/date.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/equal.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/equal.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ equal)\n/* harmony export */ });\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n/* harmony import */ var _util_is_regexp__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/is-regexp */ \"../../node_modules/arquero/src/util/is-regexp.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n\n\n\n\n/**\n * Compare two values for equality, using join semantics in which null\n * !== null. If the inputs are object-valued, a deep equality check\n * of array entries or object key-value pairs is performed.\n * @param {*} a The first input.\n * @param {*} b The second input.\n * @return {boolean} True if equal, false if not.\n */\nfunction equal(a, b) {\n  return (a == null || b == null || a !== a || b !== b) ? false\n    : a === b ? true\n    : ((0,_util_is_date__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(a) || (0,_util_is_date__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(b)) ? +a === +b\n    : ((0,_util_is_regexp__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(a) && (0,_util_is_regexp__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(b)) ? a + '' === b + ''\n    : ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(a) && (0,_util_is_object__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(b)) ? deepEqual(a, b)\n    : false;\n}\n\nfunction deepEqual(a, b) {\n  if (Object.getPrototypeOf(a) !== Object.getPrototypeOf(b)) {\n    return false;\n  }\n\n  if (a.length || b.length) {\n    return arrayEqual(a, b);\n  }\n\n  const keysA = Object.keys(a);\n  const keysB = Object.keys(b);\n  if (keysA.length !== keysB.length) {\n    return false;\n  }\n  keysA.sort();\n  keysB.sort();\n\n  if (!arrayEqual(keysA, keysB, (a, b) => a === b)) {\n    return false;\n  }\n\n  const n = keysA.length;\n  for (let i = 0; i < n; ++i) {\n    const k = keysA[i];\n    if (!equal(a[k], b[k])) {\n      return false;\n    }\n  }\n\n  return true;\n}\n\nfunction arrayEqual(a, b, test = equal) {\n  const n = a.length;\n  if (n !== b.length) return false;\n\n  for (let i = 0; i < n; ++i) {\n    if (!test(a[i], b[i])) {\n      return false;\n    }\n  }\n\n  return true;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/equal.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/index.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/index.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./array */ \"../../node_modules/arquero/src/op/functions/array.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./bin */ \"../../node_modules/arquero/src/op/functions/bin.js\");\n/* harmony import */ var _date__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./date */ \"../../node_modules/arquero/src/op/functions/date.js\");\n/* harmony import */ var _equal__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./equal */ \"../../node_modules/arquero/src/op/functions/equal.js\");\n/* harmony import */ var _json__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./json */ \"../../node_modules/arquero/src/op/functions/json.js\");\n/* harmony import */ var _math__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./math */ \"../../node_modules/arquero/src/op/functions/math.js\");\n/* harmony import */ var _object__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./object */ \"../../node_modules/arquero/src/op/functions/object.js\");\n/* harmony import */ var _recode__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./recode */ \"../../node_modules/arquero/src/op/functions/recode.js\");\n/* harmony import */ var _sequence__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./sequence */ \"../../node_modules/arquero/src/op/functions/sequence.js\");\n/* harmony import */ var _string__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./string */ \"../../node_modules/arquero/src/op/functions/string.js\");\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  bin: _bin__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  equal: _equal__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  recode: _recode__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  sequence: _sequence__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  ..._array__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  ..._date__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  ..._json__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  ..._math__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  ..._object__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  ..._string__WEBPACK_IMPORTED_MODULE_9__[\"default\"]\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/json.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/json.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  parse_json: (str) => JSON.parse(str),\n  to_json:    (val) => JSON.stringify(val)\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/json.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/math.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/math.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_random__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/random */ \"../../node_modules/arquero/src/util/random.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  random: _util_random__WEBPACK_IMPORTED_MODULE_0__.random,\n  is_nan:    Number.isNaN,\n  is_finite: Number.isFinite,\n\n  abs:      Math.abs,\n  cbrt:     Math.cbrt,\n  ceil:     Math.ceil,\n  clz32:    Math.clz32,\n  exp:      Math.exp,\n  expm1:    Math.expm1,\n  floor:    Math.floor,\n  fround:   Math.fround,\n  greatest: Math.max,\n  least:    Math.min,\n  log:      Math.log,\n  log10:    Math.log10,\n  log1p:    Math.log1p,\n  log2:     Math.log2,\n  pow:      Math.pow,\n  round:    Math.round,\n  sign:     Math.sign,\n  sqrt:     Math.sqrt,\n  trunc:    Math.trunc,\n\n  degrees:  (rad) => 180 * rad / Math.PI,\n  radians:  (deg) => Math.PI * deg / 180,\n  acos:     Math.acos,\n  acosh:    Math.acosh,\n  asin:     Math.asin,\n  asinh:    Math.asinh,\n  atan:     Math.atan,\n  atan2:    Math.atan2,\n  atanh:    Math.atanh,\n  cos:      Math.cos,\n  cosh:     Math.cosh,\n  sin:      Math.sin,\n  sinh:     Math.sinh,\n  tan:      Math.tan,\n  tanh:     Math.tanh\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/math.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/object.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/object.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/has */ \"../../node_modules/arquero/src/util/has.js\");\n/* harmony import */ var _util_is_map__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/is-map */ \"../../node_modules/arquero/src/util/is-map.js\");\n/* harmony import */ var _util_is_map_or_set__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/is-map-or-set */ \"../../node_modules/arquero/src/util/is-map-or-set.js\");\n\n\n\n\n\nfunction array(iter) {\n  return Array.from(iter);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  has:      (obj, key) => (0,_util_is_map_or_set__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(obj) ? obj.has(key)\n              : obj != null ? (0,_util_has__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(obj, key)\n              : false,\n  keys:     (obj) => (0,_util_is_map__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(obj) ? array(obj.keys())\n              : obj != null ? Object.keys(obj)\n              : [],\n  values:   (obj) => (0,_util_is_map_or_set__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(obj) ? array(obj.values())\n              : obj != null ? Object.values(obj)\n              : [],\n  entries:  (obj) => (0,_util_is_map_or_set__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(obj) ? array(obj.entries())\n              : obj != null ? Object.entries(obj)\n              : [],\n  object:   (entries) => entries ? Object.fromEntries(entries) : _util_null__WEBPACK_IMPORTED_MODULE_0__[\"default\"]\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/object.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/recode.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/recode.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/has */ \"../../node_modules/arquero/src/util/has.js\");\n\n\n/**\n * Recodes an input value to an alternative value, based on a provided\n * value map. If a fallback value is specified, it will be returned when\n * a matching value is not found in the map; otherwise, the input value\n * is returned unchanged.\n * @param {*} value The value to recode. The value must be safely\n *  coercible to a string for lookup against the value map.\n * @param {object|Map} map An object or Map with input values for keys and\n *  output recoded values as values. If a non-Map object, only the object's\n *  own properties will be considered.\n * @param {*} [fallback] A default fallback value to use if the input\n *  value is not found in the value map.\n * @return {*} The recoded value.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, map, fallback) {\n  if (map instanceof Map) {\n    if (map.has(value)) return map.get(value);\n  } else if ((0,_util_has__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(map, value)) {\n    return map[value];\n  }\n  return fallback !== undefined ? fallback : value;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/recode.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/sequence.js":
/*!***************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/sequence.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Returns an array containing an arithmetic sequence from the start value\n * to the stop value, in step increments. If step is positive, the last\n * element is the largest start + i * step less than stop; if step is\n * negative, the last element is the smallest start + i * step greater\n * than stop. If the returned array would contain an infinite number of\n * values, an empty range is returned.\n * @param {number} [start=0] The starting value of the sequence.\n * @param {number} [stop] The stopping value of the sequence.\n *  The stop value is exclusive; it is not included in the result.\n * @param {number} [step=1] The step increment between sequence values.\n * @return {number[]} The generated sequence.\n */\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(start, stop, step) {\n  let n = arguments.length;\n  start = +start;\n  stop = +stop;\n  step = n < 2\n    ? (stop = start, start = 0, 1)\n    : n < 3 ? 1 : +step;\n\n  n = Math.max(0, Math.ceil((stop - start) / step)) | 0;\n  const seq = new Array(n);\n\n  for (let i = 0; i < n; ++i) {\n    seq[i] = start + i * step;\n  }\n\n  return seq;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/sequence.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/functions/string.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/op/functions/string.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  parse_date:   (str) => str == null ? str : new Date(str),\n  parse_float:  (str) => str == null ? str : Number.parseFloat(str),\n  parse_int:    (str, radix) => str == null ? str : Number.parseInt(str, radix),\n  endswith:     (str, search, length) => str == null ? false\n                  : String(str).endsWith(search, length),\n  match:        (str, regexp, index) => {\n                  const m = str == null ? str : String(str).match(regexp);\n                  return index == null || m == null ? m\n                    : typeof index === 'number' ? m[index]\n                    : m.groups ? m.groups[index]\n                    : null;\n                },\n  normalize:    (str, form) => str == null ? str\n                  : String(str).normalize(form),\n  padend:       (str, len, fill) => str == null ? str\n                  : String(str).padEnd(len, fill),\n  padstart:     (str, len, fill) => str == null ? str\n                  : String(str).padStart(len, fill),\n  upper:        (str) => str == null ? str\n                  : String(str).toUpperCase(),\n  lower:        (str) => str == null ? str\n                  : String(str).toLowerCase(),\n  repeat:       (str, num) => str == null ? str\n                  : String(str).repeat(num),\n  replace:      (str, pattern, replacement) => str == null ? str\n                  : String(str).replace(pattern, String(replacement)),\n  substring:    (str, start, end) => str == null ? str\n                  : String(str).substring(start, end),\n  split:        (str, separator, limit) => str == null ? []\n                  : String(str).split(separator, limit),\n  startswith:   (str, search, length) => str == null ? false\n                  : String(str).startsWith(search, length),\n  trim:         (str) => str == null ? str\n                  : String(str).trim()\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/functions/string.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/index.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/op/index.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   aggregateFunctions: () => (/* reexport safe */ _aggregate_functions__WEBPACK_IMPORTED_MODULE_0__[\"default\"]),\n/* harmony export */   functions: () => (/* reexport safe */ _functions__WEBPACK_IMPORTED_MODULE_2__[\"default\"]),\n/* harmony export */   getAggregate: () => (/* binding */ getAggregate),\n/* harmony export */   getFunction: () => (/* binding */ getFunction),\n/* harmony export */   getWindow: () => (/* binding */ getWindow),\n/* harmony export */   hasAggregate: () => (/* binding */ hasAggregate),\n/* harmony export */   hasFunction: () => (/* binding */ hasFunction),\n/* harmony export */   hasWindow: () => (/* binding */ hasWindow),\n/* harmony export */   windowFunctions: () => (/* reexport safe */ _window_functions__WEBPACK_IMPORTED_MODULE_1__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _aggregate_functions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./aggregate-functions */ \"../../node_modules/arquero/src/op/aggregate-functions.js\");\n/* harmony import */ var _window_functions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./window-functions */ \"../../node_modules/arquero/src/op/window-functions.js\");\n/* harmony import */ var _functions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./functions */ \"../../node_modules/arquero/src/op/functions/index.js\");\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/has */ \"../../node_modules/arquero/src/util/has.js\");\n\n\n\n\n\n\n\n/**\n * Check if an aggregate function with the given name exists.\n * @param {string} name The name of the aggregate function.\n * @return {boolean} True if found, false otherwise.\n */\nfunction hasAggregate(name) {\n  return (0,_util_has__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(_aggregate_functions__WEBPACK_IMPORTED_MODULE_0__[\"default\"], name);\n}\n\n/**\n * Check if a window function with the given name exists.\n * @param {string} name The name of the window function.\n * @return {boolean} True if found, false otherwise.\n */\nfunction hasWindow(name) {\n  return (0,_util_has__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(_window_functions__WEBPACK_IMPORTED_MODULE_1__[\"default\"], name);\n}\n\n/**\n * Check if an expression function with the given name exists.\n * @param {string} name The name of the function.\n * @return {boolean} True if found, false otherwise.\n */\n function hasFunction(name) {\n  return (0,_util_has__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(_functions__WEBPACK_IMPORTED_MODULE_2__[\"default\"], name) || name === 'row_object';\n}\n\n/**\n * Get an aggregate function definition.\n * @param {string} name The name of the aggregate function.\n * @return {AggregateDef} The aggregate function definition,\n *  or undefined if not found.\n */\nfunction getAggregate(name) {\n  return hasAggregate(name) && _aggregate_functions__WEBPACK_IMPORTED_MODULE_0__[\"default\"][name];\n}\n\n/**\n * Get a window function definition.\n * @param {string} name The name of the window function.\n * @return {WindowDef} The window function definition,\n *  or undefined if not found.\n */\nfunction getWindow(name) {\n  return hasWindow(name) && _window_functions__WEBPACK_IMPORTED_MODULE_1__[\"default\"][name];\n}\n\n/**\n * Get an expression function definition.\n * @param {string} name The name of the function.\n * @return {Function} The function instance, or undefined if not found.\n */\nfunction getFunction(name) {\n  return hasFunction(name) && _functions__WEBPACK_IMPORTED_MODULE_2__[\"default\"][name];\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/op-api.js":
/*!***************************************************!*\
  !*** ../../node_modules/arquero/src/op/op-api.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   any: () => (/* binding */ any),\n/* harmony export */   array_agg: () => (/* binding */ array_agg),\n/* harmony export */   array_agg_distinct: () => (/* binding */ array_agg_distinct),\n/* harmony export */   count: () => (/* binding */ count),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   entries_agg: () => (/* binding */ entries_agg),\n/* harmony export */   map_agg: () => (/* binding */ map_agg),\n/* harmony export */   object_agg: () => (/* binding */ object_agg)\n/* harmony export */ });\n/* harmony import */ var _functions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./functions */ \"../../node_modules/arquero/src/op/functions/index.js\");\n/* harmony import */ var _op__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./op */ \"../../node_modules/arquero/src/op/op.js\");\n\n\n\nconst any = (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('any', field);\nconst count = () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('count');\nconst array_agg = (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('array_agg', field);\nconst array_agg_distinct = (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('array_agg_distinct', field);\nconst map_agg = (key, value) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('map_agg', [key, value]);\nconst object_agg = (key, value) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('object_agg', [key, value]);\nconst entries_agg = (key, value) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('entries_agg', [key, value]);\n\n/**\n * @typedef {import('../table/transformable').Struct} Struct\n */\n\n/**\n * All table expression operations including normal functions,\n * aggregate functions, and window functions.\n */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  ..._functions__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n\n  /**\n   * Generate an object representing the current table row.\n   * @param {...string} names The column names to include in the object.\n   *  If unspecified, all columns are included.\n   * @return {Struct} The generated row object.\n   */\n  row_object: (...names) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('row_object', null, names.flat()),\n\n  /**\n   * Aggregate function to count the number of records (rows).\n   * @returns {number} The count of records.\n   */\n  count,\n\n  /**\n   * Aggregate function returning an arbitrary observed value.\n   * @param {*} field The data field.\n   * @return {*} An arbitrary observed value.\n   */\n  any,\n\n  /**\n   * Aggregate function to collect an array of values.\n   * @param {*} field The data field.\n   * @return {Array} A list of values.\n   */\n  array_agg,\n\n  /**\n   * Aggregate function to collect an array of distinct (unique) values.\n   * @param {*} field The data field.\n   * @return {Array} An array of unique values.\n   */\n  array_agg_distinct,\n\n  /**\n   * Aggregate function to create an object given input key and value fields.\n   * @param {*} key The object key field.\n   * @param {*} value The object value field.\n   * @return {Struct} An object of key-value pairs.\n   */\n  object_agg,\n\n  /**\n   * Aggregate function to create a Map given input key and value fields.\n   * @param {*} key The object key field.\n   * @param {*} value The object value field.\n   * @return {Map} A Map of key-value pairs.\n   */\n  map_agg,\n\n  /**\n   * Aggregate function to create an array in the style of Object.entries()\n   * given input key and value fields.\n   * @param {*} key The object key field.\n   * @param {*} value The object value field.\n   * @return {[[any, any]]} An array of [key, value] arrays.\n   */\n  entries_agg,\n\n  /**\n   * Aggregate function to count the number of valid values.\n   * Invalid values are null, undefined, or NaN.\n   * @param {*} field The data field.\n   * @return {number} The count of valid values.\n   */\n  valid: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('valid', field),\n\n  /**\n   * Aggregate function to count the number of invalid values.\n   * Invalid values are null, undefined, or NaN.\n   * @param {*} field The data field.\n   * @return {number} The count of invalid values.\n   */\n  invalid: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('invalid', field),\n\n  /**\n   * Aggregate function to count the number of distinct values.\n   * @param {*} field The data field.\n   * @return {number} The count of distinct values.\n   */\n  distinct: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('distinct', field),\n\n  /**\n   * Aggregate function to determine the mode (most frequent) value.\n   * @param {*} field The data field.\n   * @return {number} The mode value.\n   */\n  mode: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('mode', field),\n\n  /**\n   * Aggregate function to sum values.\n   * @param {string} field The data field.\n   * @return {number} The sum of the values.\n   */\n  sum: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('sum', field),\n\n  /**\n   * Aggregate function to multiply values.\n   * @param {*} field The data field.\n   * @return {number} The product of the values.\n   */\n  product: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('product', field),\n\n  /**\n   * Aggregate function for the mean (average) value.\n   * @param {*} field The data field.\n   * @return {number} The mean (average) of the values.\n   */\n  mean: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('mean', field),\n\n  /**\n   * Aggregate function for the average (mean) value.\n   * @param {*} field The data field.\n   * @return {number} The average (mean) of the values.\n   */\n  average: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('average', field),\n\n  /**\n   * Aggregate function for the sample variance.\n   * @param {*} field The data field.\n   * @return {number} The sample variance of the values.\n   */\n  variance: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('variance', field),\n\n  /**\n   * Aggregate function for the population variance.\n   * @param {*} field The data field.\n   * @return {number} The population variance of the values.\n   */\n  variancep: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('variancep', field),\n\n  /**\n   * Aggregate function for the sample standard deviation.\n   * @param {*} field The data field.\n   * @return {number} The sample standard deviation of the values.\n   */\n  stdev: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('stdev', field),\n\n  /**\n   * Aggregate function for the population standard deviation.\n   * @param {*} field The data field.\n   * @return {number} The population standard deviation of the values.\n   */\n  stdevp: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('stdevp', field),\n\n  /**\n   * Aggregate function for the minimum value.\n   * @param {*} field The data field.\n   * @return {number} The minimum value.\n   */\n  min: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('min', field),\n\n  /**\n   * Aggregate function for the maximum value.\n   * @param {*} field The data field.\n   * @return {number} The maximum value.\n   */\n  max: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('max', field),\n\n  /**\n   * Aggregate function to compute the quantile boundary\n   * of a data field for a probability threshold.\n   * @param {*} field The data field.\n   * @param {number} p The probability threshold.\n   * @return {number} The quantile value.\n   */\n  quantile: (field, p) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('quantile', field, p),\n\n  /**\n   * Aggregate function for the median value.\n   * This is a shorthand for the 0.5 quantile value.\n   * @param {*} field The data field.\n   * @return {number} The median value.\n   */\n  median: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('median', field),\n\n  /**\n   * Aggregate function for the sample covariance between two variables.\n   * @param {*} field1 The first data field.\n   * @param {*} field2 The second data field.\n   * @return {number} The sample covariance of the values.\n   */\n  covariance: (field1, field2) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('covariance', [field1, field2]),\n\n  /**\n   * Aggregate function for the population covariance between two variables.\n   * @param {*} field1 The first data field.\n   * @param {*} field2 The second data field.\n   * @return {number} The population covariance of the values.\n   */\n  covariancep: (field1, field2) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('covariancep', [field1, field2]),\n\n  /**\n   * Aggregate function for the product-moment correlation between two variables.\n   * To instead compute a rank correlation, compute the average ranks for each\n   * variable and then apply this function to the result.\n   * @param {*} field1 The first data field.\n   * @param {*} field2 The second data field.\n   * @return {number} The correlation between the field values.\n   */\n  corr: (field1, field2) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('corr', [field1, field2]),\n\n  /**\n   * Aggregate function for calculating a binning scheme in terms of\n   * the minimum bin boundary, maximum bin boundary, and step size.\n   * @param {*} field The data field.\n   * @param {number} [maxbins=15] The maximum number of allowed bins.\n   * @param {boolean} [nice=true] Flag indicating if the bin min and max\n   *  should snap to \"nice\" human-friendly values.\n   * @param {number} [minstep] The minimum allowed step size between bins.\n   * @param {number} [step] The exact step size to use between bins.\n   *  If specified, the maxbins and minstep arguments are ignored.\n   * @return {[number, number, number]} The bin [min, max, and step] values.\n   */\n  bins: (field, maxbins, nice, minstep) =>\n    (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('bins', field, [maxbins, nice, minstep]),\n\n  /**\n   * Window function to assign consecutive row numbers, starting from 1.\n   * @return {number} The row number value.\n   */\n  row_number: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('row_number'),\n\n  /**\n   * Window function to assign a rank to each value in a group, starting\n   * from 1. Peer values are assigned the same rank. Subsequent ranks\n   * reflect the number of prior values: if the first two values tie for\n   * rank 1, the third value is assigned rank 3.\n   * @return {number} The rank value.\n   */\n  rank: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('rank'),\n\n  /**\n   * Window function to assign a fractional (average) rank to each value in\n   * a group, starting from 1. Peer values are assigned the average of their\n   * indices: if the first two values tie, both will be assigned rank 1.5.\n   * @return {number} The peer-averaged rank value.\n   */\n  avg_rank: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('avg_rank'),\n\n  /**\n   * Window function to assign a dense rank to each value in a group,\n   * starting from 1. Peer values are assigned the same rank. Subsequent\n   * ranks do not reflect the number of prior values: if the first two\n   * values tie for rank 1, the third value is assigned rank 2.\n   * @return {number} The dense rank value.\n   */\n  dense_rank: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('dense_rank'),\n\n  /**\n   * Window function to assign a percentage rank to each value in a group.\n   * The percent is calculated as (rank - 1) / (group_size - 1).\n   * @return {number} The percentage rank value.\n   */\n  percent_rank: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('percent_rank'),\n\n  /**\n   * Window function to assign a cumulative distribution value between 0 and 1\n   * to each value in a group.\n   * @return {number} The cumulative distribution value.\n   */\n  cume_dist: () => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('cume_dist'),\n\n  /**\n   * Window function to assign a quantile (e.g., percentile) value to each\n   * value in a group. Accepts an integer parameter indicating the number of\n   * buckets to use (e.g., 100 for percentiles, 5 for quintiles).\n   * @param {number} num The number of buckets for ntile calculation.\n   * @return {number} The quantile value.\n   */\n  ntile: (num) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('ntile', null, num),\n\n  /**\n   * Window function to assign a value that precedes the current value by\n   * a specified number of positions. If no such value exists, returns a\n   * default value instead.\n   * @param {*} field The data field.\n   * @param {number} [offset=1] The lag offset from the current value.\n   * @param {*} [defaultValue=undefined] The default value.\n   * @return {*} The lagging value.\n   */\n  lag: (field, offset, defaultValue) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('lag', field, [offset, defaultValue]),\n\n  /**\n   * Window function to assign a value that follows the current value by\n   * a specified number of positions. If no such value exists, returns a\n   * default value instead.\n   * @param {*} field The data field.\n   * @param {number} [offset=1] The lead offset from the current value.\n   * @param {*} [defaultValue=undefined] The default value.\n   * @return {*} The leading value.\n   */\n  lead: (field, offset, defaultValue) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('lead', field, [offset, defaultValue]),\n\n  /**\n   * Window function to assign the first value in a sliding window frame.\n   * @param {*} field The data field.\n   * @return {*} The first value in the current frame.\n   */\n  first_value: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('first_value', field),\n\n  /**\n   * Window function to assign the last value in a sliding window frame.\n   * @param {*} field The data field.\n   * @return {*} The last value in the current frame.\n   */\n  last_value: (field) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('last_value', field),\n\n  /**\n   * Window function to assign the nth value in a sliding window frame\n   * (counting from 1), or undefined if no such value exists.\n   * @param {*} field The data field.\n   * @param {number} nth The nth position, starting from 1.\n   * @return {*} The nth value in the current frame.\n   */\n  nth_value: (field, nth) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('nth_value', field, nth),\n\n  /**\n   * Window function to fill in missing values with preceding values.\n   * @param {*} field The data field.\n   * @param {*} [defaultValue=undefined] The default value.\n   * @return {*} The current value if valid, otherwise the first preceding\n   *  valid value. If no such value exists, returns the default value.\n   */\n  fill_down: (field, defaultValue) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('fill_down', field, defaultValue),\n\n  /**\n   * Window function to fill in missing values with subsequent values.\n   * @param {*} field The data field.\n   * @param {*} [defaultValue=undefined] The default value.\n   * @return {*} The current value if valid, otherwise the first subsequent\n   *  valid value. If no such value exists, returns the default value.\n   */\n  fill_up: (field, defaultValue) => (0,_op__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('fill_up', field, defaultValue)\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/op-api.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/op.js":
/*!***********************************************!*\
  !*** ../../node_modules/arquero/src/op/op.js ***!
  \***********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Op: () => (/* binding */ Op),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(name, fields = [], params = []) {\n  return new Op(name, (0,_util_to_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(fields), (0,_util_to_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(params));\n}\n\nclass Op {\n  constructor(name, fields, params) {\n    this.name = name;\n    this.fields = fields;\n    this.params = params;\n  }\n  toString() {\n    const args = [\n      ...this.fields.map(f => `d[${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(f)}]`),\n      ...this.params.map(_util_to_string__WEBPACK_IMPORTED_MODULE_1__[\"default\"])\n    ];\n    return `d => op.${this.name}(${args})`;\n  }\n  toObject() {\n    return { expr: this.toString(), func: true };\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/op.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/op/window-functions.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/op/window-functions.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_valid__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/is-valid */ \"../../node_modules/arquero/src/util/is-valid.js\");\n/* harmony import */ var _util_no_op__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/no-op */ \"../../node_modules/arquero/src/util/no-op.js\");\n/* harmony import */ var _util_null__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/null */ \"../../node_modules/arquero/src/util/null.js\");\n\n\n\n\n\n/**\n * Initialize a window operator.\n * @callback WindowInit\n * @return {void}\n */\n\n/**\n * Retrieve an output value from a window operator.\n * @callback WindowValue\n * @param {WindowState} state The window state object.\n * @return {*} The output value.\n */\n\n/**\n * An operator instance for a window function.\n * @typedef {object} WindowOperator\n * @property {AggregateInit} init Initialize the operator.\n * @property {AggregateValue} value Retrieve an output value.\n */\n\n/**\n * Create a new window operator instance.\n * @callback WindowCreate\n * @param {...any} params The aggregate operator parameters.\n * @return {WindowOperator} The instantiated window operator.\n */\n\n/**\n * An operator definition for a window function.\n * @typedef {object} WindowDef\n * @property {AggregateCreate} create Create a new operator instance.\n * @property {number[]} param Two-element array containing the\n *  counts of input fields and additional parameters.\n */\n\nconst rank = {\n  create() {\n    let rank;\n    return {\n      init: () => rank = 1,\n      value: w => {\n        const i = w.index;\n        return (i && !w.peer(i)) ? (rank = i + 1) : rank;\n      }\n    };\n  },\n  param: []\n};\n\nconst cume_dist = {\n  create() {\n    let cume;\n    return {\n      init: () => cume = 0,\n      value: w => {\n        const { index, peer, size } = w;\n        let i = index;\n        if (cume < i) {\n          while (i + 1 < size && peer(i + 1)) ++i;\n          cume = i;\n        }\n        return (1 + cume) / size;\n      }\n    };\n  },\n  param: []\n};\n\n/**\n * Window operator definitions.\n */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  /** @type {WindowDef} */\n  row_number: {\n    create() {\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: w => w.index + 1\n      };\n    },\n    param: []\n  },\n\n  /** @type {WindowDef} */\n  rank,\n\n  /** @type {WindowDef} */\n  avg_rank: {\n    create() {\n      let j, rank;\n      return {\n        init: () => (j = -1, rank = 1),\n        value: w => {\n          const i = w.index;\n          if (i >= j) {\n            for (rank = j = i + 1; w.peer(j); rank += ++j);\n            rank /= (j - i);\n          }\n          return rank;\n        }\n      };\n    },\n    param: []\n  },\n\n  /** @type {WindowDef} */\n  dense_rank: {\n    create() {\n      let drank;\n      return {\n        init: () => drank = 1,\n        value: w => {\n          const i = w.index;\n          return (i && !w.peer(i)) ? ++drank : drank;\n        }\n      };\n    },\n    param: []\n  },\n\n  /** @type {WindowDef} */\n  percent_rank: {\n    create() {\n      const { init, value } = rank.create();\n      return {\n        init,\n        value: w => (value(w) - 1) / (w.size - 1)\n      };\n    },\n    param: []\n  },\n\n  /** @type {WindowDef} */\n  cume_dist,\n\n  /** @type {WindowDef} */\n  ntile: {\n    create(num) {\n      num = +num;\n      if (!(num > 0)) (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('ntile num must be greater than zero.');\n      const { init, value } = cume_dist.create();\n      return {\n        init,\n        value: w => Math.ceil(num * value(w))\n      };\n    },\n    param: [0, 1]\n  },\n\n  /** @type {WindowDef} */\n  lag: {\n    create(offset, defaultValue = _util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) {\n      offset = +offset || 1;\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: (w, f) => {\n          const i = w.index - offset;\n          return i >= 0 ? w.value(i, f) : defaultValue;\n        }\n      };\n    },\n    param: [1, 2]\n  },\n\n  /** @type {WindowDef} */\n  lead: {\n    create(offset, defaultValue = _util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) {\n      offset = +offset || 1;\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: (w, f) => {\n          const i = w.index + offset;\n          return i < w.size ? w.value(i, f) : defaultValue;\n        }\n      };\n    },\n    param: [1, 2]\n  },\n\n  /** @type {WindowDef} */\n  first_value: {\n    create() {\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: (w, f) => w.value(w.i0, f)\n      };\n    },\n    param: [1]\n  },\n\n  /** @type {WindowDef} */\n  last_value: {\n    create() {\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: (w, f) => w.value(w.i1 - 1, f)\n      };\n    },\n    param: [1]\n  },\n\n  /** @type {WindowDef} */\n  nth_value: {\n    create(nth) {\n      nth = +nth;\n      if (!(nth > 0)) (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('nth_value nth must be greater than zero.');\n      return {\n        init: _util_no_op__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n        value: (w, f) => {\n          const i = w.i0 + (nth - 1);\n          return i < w.i1 ? w.value(i, f) : _util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n        }\n      };\n    },\n    param: [1, 1]\n  },\n\n  /** @type {WindowDef} */\n  fill_down: {\n    create(defaultValue = _util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) {\n      let value;\n      return {\n        init: () => value = defaultValue,\n        value: (w, f) => {\n          const v = w.value(w.index, f);\n          return (0,_util_is_valid__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(v) ? (value = v) : value;\n        }\n      };\n    },\n    param: [1, 1]\n  },\n\n  /** @type {WindowDef} */\n  fill_up: {\n    create(defaultValue = _util_null__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) {\n      let value, idx;\n      return {\n        init: () => (value = defaultValue, idx = -1),\n        value: (w, f) => w.index <= idx ? value\n          : (idx = find(w, f, w.index)) >= 0 ? (value = w.value(idx, f))\n          : (idx = w.size, value = defaultValue)\n      };\n    },\n    param: [1, 1]\n  }\n});\n\nfunction find(w, f, i) {\n  for (const n = w.size; i < n; ++i) {\n    if ((0,_util_is_valid__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(w.value(i, f))) return i;\n  }\n  return -1;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/op/window-functions.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/query/constants.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/query/constants.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Descending: () => (/* binding */ Descending),\n/* harmony export */   Expr: () => (/* binding */ Expr),\n/* harmony export */   ExprList: () => (/* binding */ ExprList),\n/* harmony export */   ExprNumber: () => (/* binding */ ExprNumber),\n/* harmony export */   ExprObject: () => (/* binding */ ExprObject),\n/* harmony export */   JoinKeys: () => (/* binding */ JoinKeys),\n/* harmony export */   JoinValues: () => (/* binding */ JoinValues),\n/* harmony export */   Options: () => (/* binding */ Options),\n/* harmony export */   OrderbyKeys: () => (/* binding */ OrderbyKeys),\n/* harmony export */   Query: () => (/* binding */ Query),\n/* harmony export */   Selection: () => (/* binding */ Selection),\n/* harmony export */   SelectionList: () => (/* binding */ SelectionList),\n/* harmony export */   TableRef: () => (/* binding */ TableRef),\n/* harmony export */   TableRefList: () => (/* binding */ TableRefList),\n/* harmony export */   Verb: () => (/* binding */ Verb),\n/* harmony export */   Window: () => (/* binding */ Window)\n/* harmony export */ });\nconst Expr = 'Expr';\nconst ExprList = 'ExprList';\nconst ExprNumber = 'ExprNumber';\nconst ExprObject = 'ExprObject';\nconst JoinKeys = 'JoinKeys';\nconst JoinValues = 'JoinValues';\nconst Options = 'Options';\nconst OrderbyKeys = 'OrderKeys';\nconst SelectionList = 'SelectionList';\nconst TableRef = 'TableRef';\nconst TableRefList = 'TableRefList';\n\nconst Descending = 'Descending';\nconst Query = 'Query';\nconst Selection = 'Selection';\nconst Verb = 'Verb';\nconst Window = 'Window';\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/query/constants.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/query/query.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/query/query.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   addQueryVerb: () => (/* binding */ addQueryVerb),\n/* harmony export */   \"default\": () => (/* binding */ Query),\n/* harmony export */   query: () => (/* binding */ query),\n/* harmony export */   queryFrom: () => (/* binding */ queryFrom)\n/* harmony export */ });\n/* harmony import */ var _table_transformable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table/transformable */ \"../../node_modules/arquero/src/table/transformable.js\");\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/query/constants.js\");\n/* harmony import */ var _verb__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./verb */ \"../../node_modules/arquero/src/query/verb.js\");\n\n\n\n\n/**\n * Create a new query instance. The query interface provides\n * a table-like verb API to construct a query that can be\n * serialized or evaluated against Arquero tables.\n * @param {string} [tableName] The name of the table to query. If\n *  provided, will be used as the default input table to pull from\n *  a provided catalog to run the query against.\n * @return {Query} A new builder instance.\n */\nfunction query(tableName) {\n  return new Query(null, null, tableName);\n}\n\n/**\n * Create a new query instance from a serialized object.\n * @param {object} object A serialized query representation, such as\n *  those generated by query(...).toObject().\n * @returns {Query} The instantiated query instance.\n */\nfunction queryFrom(object) {\n  return Query.from(object);\n}\n\n/**\n * Model a query as a collection of serializble verbs.\n * Provides a table-like interface for constructing queries.\n */\nclass Query extends _table_transformable__WEBPACK_IMPORTED_MODULE_0__[\"default\"] {\n\n  /**\n   * Construct a new query instance.\n   * @param {Verb[]} verbs An array of verb instances.\n   * @param {object} [params] Optional query parameters, corresponding\n   *  to parameter references in table expressions.\n   * @param {string} [table] Optional name of the table to query.\n   */\n  constructor(verbs, params, table) {\n    super(params);\n    this._verbs = verbs || [];\n    this._table = table;\n  }\n\n  /**\n   * Create a new query instance from the given serialized object.\n   * @param {QueryObject} object A serialized query representation, such as\n   *  those generated by Query.toObject.\n   * @returns {Query} The instantiated query.\n   */\n  static from({ verbs, table, params }) {\n    return new Query(verbs.map(_verb__WEBPACK_IMPORTED_MODULE_2__.Verb.from), params, table);\n  }\n\n  /**\n   * Provide an informative object string tag.\n   */\n  get [Symbol.toStringTag]() {\n    if (!this._verbs) return 'Object'; // bail if called on prototype\n    const ns = this._verbs.length;\n    return `Query: ${ns} verbs` + (this._table ? ` on '${this._table}'` : '');\n  }\n\n  /**\n   * Return the number of verbs in this query.\n   */\n  get length() {\n    return this._verbs.length;\n  }\n\n  /**\n   * Return the name of the table this query applies to.\n   * @return {string} The name of the source table, or undefined.\n   */\n  get tableName() {\n    return this._table;\n  }\n\n  /**\n   * Get or set table expression parameter values.\n   * If called with no arguments, returns the current parameter values\n   * as an object. Otherwise, adds the provided parameters to this\n   * query's parameter set and returns the table. Any prior parameters\n   * with names matching the input parameters are overridden.\n   * @param {object} values The parameter values.\n   * @return {Query|object} The current parameter values (if called\n   *  with no arguments) or this query.\n   */\n  params(values) {\n    if (arguments.length) {\n      this._params = { ...this._params, ...values };\n      return this;\n    } else {\n      return this._params;\n    }\n  }\n\n  /**\n   * Evaluate this query against a given table and catalog.\n   * @param {Table} table The Arquero table to process.\n   * @param {Function} catalog A table lookup function that accepts a table\n   *  name string as input and returns a corresponding Arquero table.\n   * @returns {Table} The resulting Arquero table.\n   */\n  evaluate(table, catalog) {\n    table = table || catalog(this._table);\n    for (const verb of this._verbs) {\n      table = verb.evaluate(table.params(this._params), catalog);\n    }\n    return table;\n  }\n\n  /**\n   * Serialize this query as a JSON-compatible object. The resulting\n   * object can be passed to Query.from to re-instantiate this query.\n   * @returns {object} A JSON-compatible object representing this query.\n   */\n  toObject() {\n    return serialize(this, 'toObject');\n  }\n\n  /**\n   * Serialize this query as a JSON-compatible object. The resulting\n   * object can be passed to Query.from to re-instantiate this query.\n   * This method simply returns the result of toObject, but is provided\n   * as a separate method to allow later customization of JSON export.\n   * @returns {object} A JSON-compatible object representing this query.\n   */\n  toJSON() {\n    return this.toObject();\n  }\n\n  /**\n   * Serialize this query to a JSON-compatible abstract syntax tree.\n   * All table expressions will be parsed and represented as AST instances\n   * using a modified form of the Mozilla JavaScript AST format.\n   * This method can be used to output parsed and serialized representations\n   * to translate Arquero queries to alternative data processing platforms.\n   * @returns {object} A JSON-compatible abstract syntax tree object.\n   */\n  toAST() {\n    return serialize(this, 'toAST', { type: _constants__WEBPACK_IMPORTED_MODULE_1__.Query });\n  }\n}\n\n/**\n * Serialized object representation of a query.\n * @typedef {object} QueryObject\n * @property {object[]} verbs An array of verb definitions.\n * @property {object} [params] An object of parameter values.\n * @property {string} [table] The name of the table to query.\n */\n\nfunction serialize(query, method, props) {\n  return {\n    ...props,\n    verbs: query._verbs.map(verb => verb[method]()),\n    ...(query._params ? { params: query._params } : null),\n    ...(query._table ? { table: query._table } : null)\n  };\n}\n\nfunction append(qb, verb) {\n  return new Query(\n    qb._verbs.concat(verb),\n    qb._params,\n    qb._table\n  );\n}\n\nfunction addQueryVerb(name, verb) {\n  Query.prototype[name] = function(...args) {\n    return append(this, verb(...args));\n  };\n}\n\n// Internal verb handlers\nfor (const name in _verb__WEBPACK_IMPORTED_MODULE_2__.Verbs) {\n  const verb = _verb__WEBPACK_IMPORTED_MODULE_2__.Verbs[name];\n  Query.prototype['__' + name] = function(qb, ...args) {\n    return append(qb, verb(...args));\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/query/query.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/query/to-ast.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/query/to-ast.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/query/util.js\");\n/* harmony import */ var _expression_ast_constants__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../expression/ast/constants */ \"../../node_modules/arquero/src/expression/ast/constants.js\");\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/query/constants.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst Methods = {\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.Expr]: astExpr,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.ExprList]: astExprList,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.ExprNumber]: astExprNumber,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.ExprObject]: astExprObject,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.JoinKeys]: astJoinKeys,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.JoinValues]: astJoinValues,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.OrderbyKeys]: astExprList,\n  [_constants__WEBPACK_IMPORTED_MODULE_10__.SelectionList]: astSelectionList\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, type, propTypes) {\n  return type === _constants__WEBPACK_IMPORTED_MODULE_10__.TableRef ? astTableRef(value)\n    : type === _constants__WEBPACK_IMPORTED_MODULE_10__.TableRefList ? value.map(astTableRef)\n    : ast((0,_util__WEBPACK_IMPORTED_MODULE_8__.toObject)(value), type, propTypes);\n}\n\nfunction ast(value, type, propTypes) {\n  return type === _constants__WEBPACK_IMPORTED_MODULE_10__.Options\n    ? (value ? astOptions(value, propTypes) : value)\n    : Methods[type](value);\n}\n\nfunction astOptions(value, types = {}) {\n  const output = {};\n  for (const key in value) {\n    const prop = value[key];\n    output[key] = types[key] ? ast(prop, types[key]) : prop;\n  }\n  return output;\n}\n\nfunction astParse(expr, opt) {\n  return (0,_expression_parse__WEBPACK_IMPORTED_MODULE_7__[\"default\"])({ expr }, { ...opt, ast: true }).exprs[0];\n}\n\nfunction astColumn(name) {\n  return { type: _expression_ast_constants__WEBPACK_IMPORTED_MODULE_9__.Column, name };\n}\n\nfunction astColumnIndex(index) {\n  return { type: _expression_ast_constants__WEBPACK_IMPORTED_MODULE_9__.Column, index };\n}\n\nfunction astExprObject(obj, opt) {\n  if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(obj)) {\n    return astParse(obj, opt);\n  }\n\n  if (obj.expr) {\n    let ast;\n    if (obj.field === true) {\n      ast = astColumn(obj.expr);\n    } else if (obj.func === true) {\n      ast = astExprObject(obj.expr, opt);\n    }\n    if (ast) {\n      if (obj.desc) {\n        ast = { type: _constants__WEBPACK_IMPORTED_MODULE_10__.Descending, expr: ast };\n      }\n      if (obj.window) {\n        ast = { type: _constants__WEBPACK_IMPORTED_MODULE_10__.Window, expr: ast, ...obj.window };\n      }\n      return ast;\n    }\n  }\n\n  return Object.keys(obj)\n    .map(key => ({\n      ...astExprObject(obj[key], opt),\n      as: key\n    }));\n}\n\nfunction astSelection(sel) {\n  const type = _constants__WEBPACK_IMPORTED_MODULE_10__.Selection;\n  return sel.all ? { type, operator: 'all' }\n    : sel.not ? { type, operator: 'not', arguments: astExprList(sel.not) }\n    : sel.range ? { type, operator: 'range', arguments: astExprList(sel.range) }\n    : sel.matches ? { type, operator: 'matches', arguments: sel.matches }\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('Invalid input');\n}\n\nfunction astSelectionList(arr) {\n  return (0,_util_to_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(arr).map(astSelectionItem).flat();\n}\n\nfunction astSelectionItem(val) {\n  return (0,_util__WEBPACK_IMPORTED_MODULE_8__.isSelection)(val) ? astSelection(val)\n    : (0,_util_is_number__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(val) ? astColumnIndex(val)\n    : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(val) ? astColumn(val)\n    : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(val) ? Object.keys(val)\n      .map(name => ({ type: _expression_ast_constants__WEBPACK_IMPORTED_MODULE_9__.Column, name, as: val[name] }))\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('Invalid input');\n}\n\nfunction astExpr(val) {\n  return (0,_util__WEBPACK_IMPORTED_MODULE_8__.isSelection)(val) ? astSelection(val)\n    : (0,_util_is_number__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(val) ? astColumnIndex(val)\n    : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(val) ? astColumn(val)\n    : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(val) ? astExprObject(val)\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('Invalid input');\n}\n\nfunction astExprList(arr) {\n  return (0,_util_to_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(arr).map(astExpr).flat();\n}\n\nfunction astExprNumber(val) {\n  return (0,_util_is_number__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(val) ? val : astExprObject(val);\n}\n\nfunction astJoinKeys(val) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(val)\n    ? val.map(astExprList)\n    : astExprObject(val, { join: true });\n}\n\nfunction astJoinValues(val) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(val)\n    ? val.map((v, i) => i < 2\n        ? astExprList(v)\n        : astExprObject(v, { join: true })\n      )\n    : astExprObject(val, { join: true });\n}\n\nfunction astTableRef(value) {\n  return value && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(value.toAST)\n    ? value.toAST()\n    : value;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/query/to-ast.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/query/util.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/query/util.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   fromObject: () => (/* binding */ fromObject),\n/* harmony export */   getTable: () => (/* binding */ getTable),\n/* harmony export */   isSelection: () => (/* binding */ isSelection),\n/* harmony export */   joinKeys: () => (/* binding */ joinKeys),\n/* harmony export */   joinValues: () => (/* binding */ joinValues),\n/* harmony export */   orderbyKeys: () => (/* binding */ orderbyKeys),\n/* harmony export */   toObject: () => (/* binding */ toObject)\n/* harmony export */ });\n/* harmony import */ var _helpers_desc__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../helpers/desc */ \"../../node_modules/arquero/src/helpers/desc.js\");\n/* harmony import */ var _helpers_field__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../helpers/field */ \"../../node_modules/arquero/src/helpers/field.js\");\n/* harmony import */ var _helpers_rolling__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../helpers/rolling */ \"../../node_modules/arquero/src/helpers/rolling.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _query__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./query */ \"../../node_modules/arquero/src/query/query.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_map_object__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util/map-object */ \"../../node_modules/arquero/src/util/map-object.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction func(expr) {\n  const f = d => d;\n  f.toString = () => expr;\n  return f;\n}\n\nfunction getTable(catalog, ref) {\n  ref = ref && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(ref.query) ? ref.query() : ref;\n  return ref && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(ref.evaluate)\n    ? ref.evaluate(null, catalog)\n    : catalog(ref);\n}\n\nfunction isSelection(value) {\n  return (0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(value) && (\n    (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.all) ||\n    (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.matches) ||\n    (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.not) ||\n    (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.range)\n  );\n}\n\nfunction toObject(value) {\n  return value && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(value.toObject) ? value.toObject()\n    : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(value) ? { expr: String(value), func: true }\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value) ? value.map(toObject)\n    : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(value) ? (0,_util_map_object__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(value, _ => toObject(_))\n    : value;\n}\n\nfunction fromObject(value) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value) ? value.map(fromObject)\n    : !(0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(value) ? value\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.verbs) ? _query__WEBPACK_IMPORTED_MODULE_4__[\"default\"].from(value)\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.all) ? (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_3__.all)()\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.range) ? (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_3__.range)(...value.range)\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.match) ? (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_3__.matches)(RegExp(...value.match))\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(value.not) ? (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_3__.not)(value.not.map(toObject))\n    : fromExprObject(value);\n}\n\nfunction fromExprObject(value) {\n  let output = value;\n  let expr = value.expr;\n\n  if (expr != null) {\n    if (value.field === true) {\n      output = expr = (0,_helpers_field__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(expr);\n    } else if (value.func === true) {\n      output = expr = func(expr);\n    }\n\n    if ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(value.window)) {\n      const { frame, peers } = value.window;\n      output = expr = (0,_helpers_rolling__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(expr, frame, peers);\n    }\n\n    if (value.desc === true) {\n      output = (0,_helpers_desc__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(expr);\n    }\n  }\n\n  return value === output\n    ? (0,_util_map_object__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(value, _ => fromObject(_))\n    : output;\n}\n\nfunction joinKeys(keys) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(keys) ? keys.map(parseJoinKeys)\n    : keys;\n}\n\nfunction parseJoinKeys(keys) {\n  const list = [];\n\n  (0,_util_to_array__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(keys).forEach(param => {\n    (0,_util_is_number__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(param) ? list.push(param)\n      : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(param) ? list.push((0,_helpers_field__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(param, null))\n      : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(param) && param.expr ? list.push(param)\n      : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(param) ? list.push(param)\n      : (0,_util_error__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(`Invalid key value: ${param+''}`);\n  });\n\n  return list;\n}\n\nfunction joinValues(values) {\n  return (0,_util_is_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(values)\n    ? values.map(parseJoinValues)\n    : values;\n}\n\nfunction parseJoinValues(values, index) {\n  return index < 2 ? (0,_util_to_array__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(values) : values;\n}\n\nfunction orderbyKeys(keys) {\n  const list = [];\n\n  keys.forEach(param => {\n    const expr = param.expr != null ? param.expr : param;\n    if ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(expr) && !(0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(expr)) {\n      for (const key in expr) {\n        list.push(expr[key]);\n      }\n    } else {\n      param = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(expr) ? expr\n        : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(expr) ? (0,_helpers_field__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(param)\n        : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(expr) ? param\n        : (0,_util_error__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(`Invalid orderby field: ${param+''}`);\n      list.push(param);\n    }\n  });\n\n  return list;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/query/util.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/query/verb.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/query/verb.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Verb: () => (/* binding */ Verb),\n/* harmony export */   Verbs: () => (/* binding */ Verbs),\n/* harmony export */   createVerb: () => (/* binding */ createVerb)\n/* harmony export */ });\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constants */ \"../../node_modules/arquero/src/query/constants.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/arquero/src/query/util.js\");\n/* harmony import */ var _to_ast__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./to-ast */ \"../../node_modules/arquero/src/query/to-ast.js\");\n\n\n\n\n\n\n\n\n/**\n * Model an Arquero verb as a serializable object.\n */\nclass Verb {\n\n  /**\n   * Construct a new verb instance.\n   * @param {string} verb The verb name.\n   * @param {object[]} schema Schema describing verb parameters.\n   * @param {any[]} params Array of parameter values.\n   */\n  constructor(verb, schema = [], params = []) {\n    this.verb = verb;\n    this.schema = schema;\n    schema.forEach((s, index) => {\n      const type = s.type;\n      const param = params[index];\n      const value = type === _constants__WEBPACK_IMPORTED_MODULE_0__.JoinKeys ? (0,_util__WEBPACK_IMPORTED_MODULE_1__.joinKeys)(param)\n        : type === _constants__WEBPACK_IMPORTED_MODULE_0__.JoinValues ? (0,_util__WEBPACK_IMPORTED_MODULE_1__.joinValues)(param)\n        : type === _constants__WEBPACK_IMPORTED_MODULE_0__.OrderbyKeys ? (0,_util__WEBPACK_IMPORTED_MODULE_1__.orderbyKeys)(param)\n        : param;\n      this[s.name] = value !== undefined ? value : s.default;\n    });\n  }\n\n  /**\n   * Create new verb instance from the given serialized object.\n   * @param {object} object A serialized verb representation, such as\n   *  those generated by Verb.toObject.\n   * @returns {Verb} The instantiated verb.\n   */\n  static from(object) {\n    const verb = Verbs[object.verb];\n    const params = (verb.schema || [])\n      .map(({ name }) => (0,_util__WEBPACK_IMPORTED_MODULE_1__.fromObject)(object[name]));\n    return verb(...params);\n  }\n\n  /**\n   * Evaluate this verb against a given table and catalog.\n   * @param {Table} table The Arquero table to process.\n   * @param {Function} catalog A table lookup function that accepts a table\n   *  name string as input and returns a corresponding Arquero table.\n   * @returns {Table} The resulting Arquero table.\n   */\n  evaluate(table, catalog) {\n    const params = this.schema.map(({ name, type }) => {\n      const value = this[name];\n      return type === _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef ? (0,_util__WEBPACK_IMPORTED_MODULE_1__.getTable)(catalog, value)\n        : type === _constants__WEBPACK_IMPORTED_MODULE_0__.TableRefList ? value.map(t => (0,_util__WEBPACK_IMPORTED_MODULE_1__.getTable)(catalog, t))\n        : value;\n    });\n    return table[this.verb](...params);\n  }\n\n  /**\n   * Serialize this verb as a JSON-compatible object. The resulting\n   * object can be passed to Verb.from to re-instantiate this verb.\n   * @returns {object} A JSON-compatible object representing this verb.\n   */\n  toObject() {\n    const obj = { verb: this.verb };\n    this.schema.forEach(({ name }) => {\n      obj[name] = (0,_util__WEBPACK_IMPORTED_MODULE_1__.toObject)(this[name]);\n    });\n    return obj;\n  }\n\n  /**\n   * Serialize this verb to a JSON-compatible abstract syntax tree.\n   * All table expressions will be parsed and represented as AST instances\n   * using a modified form of the Mozilla JavaScript AST format.\n   * This method can be used to output parsed and serialized representations\n   * to translate Arquero verbs to alternative data processing platforms.\n   * @returns {object} A JSON-compatible abstract syntax tree object.\n   */\n  toAST() {\n    const obj = { type: _constants__WEBPACK_IMPORTED_MODULE_0__.Verb, verb: this.verb };\n    this.schema.forEach(({ name, type, props }) => {\n      obj[name] = (0,_to_ast__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(this[name], type, props);\n    });\n    return obj;\n  }\n}\n\n/**\n * Verb parameter type.\n * @typedef {Expr|ExprList|ExprNumber|ExprObject|JoinKeys|JoinValues|Options|OrderbyKeys|SelectionList|TableRef|TableRefList} ParamType\n */\n\n/**\n * Verb parameter schema.\n * @typedef {object} ParamDef\n * @property {string} name The name of the parameter.\n * @property {ParamType} type The type of the parameter.\n * @property {{ [key: string]: ParamType }} [props] Types for non-literal properties.\n */\n\n/**\n * Create a new constructors.\n * @param {string} name The name of the verb.\n * @param {ParamDef[]} schema The verb parameter schema.\n * @return {Function} A verb constructor function.\n */\nfunction createVerb(name, schema) {\n  return Object.assign(\n    (...params) => new Verb(name, schema, params),\n    { schema }\n  );\n}\n\n/**\n * A lookup table of verb classes.\n */\nconst Verbs = {\n  count:      createVerb('count', [\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  derive:     createVerb('derive', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprObject },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options,\n                  props: { before: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList, after: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList }\n                }\n              ]),\n  filter:     createVerb('filter', [\n                { name: 'criteria', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprObject }\n              ]),\n  groupby:    createVerb('groupby', [\n                { name: 'keys', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList }\n              ]),\n  orderby:    createVerb('orderby', [\n                { name: 'keys', type: _constants__WEBPACK_IMPORTED_MODULE_0__.OrderbyKeys }\n              ]),\n  relocate:   createVerb('relocate', [\n                { name: 'columns', type: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options,\n                  props: { before: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList, after: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList }\n                }\n              ]),\n  rename:     createVerb('rename', [\n                { name: 'columns', type: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList }\n              ]),\n  rollup:     createVerb('rollup', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprObject }\n              ]),\n  sample:     createVerb('sample', [\n                { name: 'size', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprNumber },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options, props: { weight: _constants__WEBPACK_IMPORTED_MODULE_0__.Expr } }\n              ]),\n  select:     createVerb('select', [\n                { name: 'columns', type: _constants__WEBPACK_IMPORTED_MODULE_0__.SelectionList }\n              ]),\n  ungroup:    createVerb('ungroup'),\n  unorder:    createVerb('unorder'),\n  reify:      createVerb('reify'),\n  dedupe:     createVerb('dedupe', [\n                { name: 'keys', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList, default: [] }\n              ]),\n  impute:     createVerb('impute', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprObject },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options, props: { expand: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList } }\n              ]),\n  fold:       createVerb('fold', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  pivot:      createVerb('pivot', [\n                { name: 'keys', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList },\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  spread:     createVerb('spread', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  unroll:     createVerb('unroll', [\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options, props: { drop: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList } }\n              ]),\n  lookup:     createVerb('lookup', [\n                { name: 'table', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef },\n                { name: 'on', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinKeys },\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.ExprList }\n              ]),\n  join:       createVerb('join', [\n                { name: 'table', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef },\n                { name: 'on', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinKeys },\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinValues },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  cross:      createVerb('cross', [\n                { name: 'table', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef },\n                { name: 'values', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinValues },\n                { name: 'options', type: _constants__WEBPACK_IMPORTED_MODULE_0__.Options }\n              ]),\n  semijoin:   createVerb('semijoin', [\n                { name: 'table', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef },\n                { name: 'on', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinKeys }\n              ]),\n  antijoin:   createVerb('antijoin', [\n                { name: 'table', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRef },\n                { name: 'on', type: _constants__WEBPACK_IMPORTED_MODULE_0__.JoinKeys }\n              ]),\n  concat:     createVerb('concat', [\n                { name: 'tables', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRefList }\n              ]),\n  union:      createVerb('union', [\n                { name: 'tables', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRefList }\n              ]),\n  intersect:  createVerb('intersect', [\n                { name: 'tables', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRefList }\n              ]),\n  except:     createVerb('except', [\n                { name: 'tables', type: _constants__WEBPACK_IMPORTED_MODULE_0__.TableRefList }\n              ])\n};\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/query/verb.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/register.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/register.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   addAggregateFunction: () => (/* binding */ addAggregateFunction),\n/* harmony export */   addFunction: () => (/* binding */ addFunction),\n/* harmony export */   addPackage: () => (/* binding */ addPackage),\n/* harmony export */   addTableMethod: () => (/* binding */ addTableMethod),\n/* harmony export */   addVerb: () => (/* binding */ addVerb),\n/* harmony export */   addWindowFunction: () => (/* binding */ addWindowFunction)\n/* harmony export */ });\n/* harmony import */ var _table_column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./table/column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _op_aggregate_functions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./op/aggregate-functions */ \"../../node_modules/arquero/src/op/aggregate-functions.js\");\n/* harmony import */ var _op_window_functions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./op/window-functions */ \"../../node_modules/arquero/src/op/window-functions.js\");\n/* harmony import */ var _op_functions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./op/functions */ \"../../node_modules/arquero/src/op/functions/index.js\");\n/* harmony import */ var _op_op__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./op/op */ \"../../node_modules/arquero/src/op/op.js\");\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n/* harmony import */ var _query_query__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./query/query */ \"../../node_modules/arquero/src/query/query.js\");\n/* harmony import */ var _query_verb__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./query/verb */ \"../../node_modules/arquero/src/query/verb.js\");\n/* harmony import */ var _expression_row_object__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./expression/row-object */ \"../../node_modules/arquero/src/expression/row-object.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./util/has */ \"../../node_modules/arquero/src/util/has.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst onIllegal = (name, type) =>\n  (0,_util_error__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(`Illegal ${type} name: ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(name)}`);\n\nconst onDefined = (name, type) =>\n  (0,_util_error__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(`The ${type} ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(name)} is already defined. Use override option?`);\n\nconst onReserve = (name, type) =>\n  (0,_util_error__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(`The ${type} name ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(name)} is reserved and can not be overridden.`);\n\nfunction check(name, options, obj = _op_op_api__WEBPACK_IMPORTED_MODULE_5__[\"default\"], type = 'function') {\n  if (!name) onIllegal(name, type);\n  if (!options.override && (0,_util_has__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(obj, name)) onDefined(name, type);\n}\n\n// -- Op Functions --------------------------------------------------\n\nfunction verifyFunction(name, def, object, options) {\n  return object[name] === def || check(name, options);\n}\n\n/**\n * Register an aggregate or window operation.\n * @param {string} name The name of the operation\n * @param {AggregateDef|WindowDef} def The operation definition.\n * @param {object} object The registry object to add the definition to.\n * @param {RegisterOptions} [options] Registration options.\n */\nfunction addOp(name, def, object, options = {}) {\n  if (verifyFunction(name, def, object, options)) return;\n  const [nf = 0, np = 0] = def.param;\n  object[name] = def;\n  _op_op_api__WEBPACK_IMPORTED_MODULE_5__[\"default\"][name] = (...params) => (0,_op_op__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(\n    name,\n    params.slice(0, nf),\n    params.slice(nf, nf + np)\n  );\n}\n\n/**\n * Register a custom aggregate function.\n * @param {string} name The name to use for the aggregate function.\n * @param {AggregateDef} def The aggregate operator definition.\n * @param {RegisterOptions} [options] Function registration options.\n * @throws If a function with the same name is already registered and\n *  the override option is not specified.\n */\nfunction addAggregateFunction(name, def, options) {\n  addOp(name, def, _op_aggregate_functions__WEBPACK_IMPORTED_MODULE_1__[\"default\"], options);\n}\n\n/**\n * Register a custom window function.\n * @param {string} name The name to use for the window function.\n * @param {WindowDef} def The window operator definition.\n * @param {RegisterOptions} [options] Function registration options.\n * @throws If a function with the same name is already registered and\n *  the override option is not specified.\n */\nfunction addWindowFunction(name, def, options) {\n  addOp(name, def, _op_window_functions__WEBPACK_IMPORTED_MODULE_2__[\"default\"], options);\n}\n\n/**\n * Register a function for use within table expressions.\n * If only a single argument is provided, it will be assumed to be a\n * function and the system will try to extract its name.\n * @param {string} name The name to use for the function.\n * @param {Function} fn A standard JavaScript function.\n * @param {RegisterOptions} [options] Function registration options.\n * @throws If a function with the same name is already registered and\n *  the override option is not specified, or if no name is provided\n *  and the input function is anonymous.\n */\nfunction addFunction(name, fn, options = {}) {\n  if (arguments.length === 1) {\n    fn = name;\n    name = fn.name;\n    if (name === '' || name === 'anonymous') {\n      (0,_util_error__WEBPACK_IMPORTED_MODULE_9__[\"default\"])('Anonymous function provided, please include a name argument.');\n    } else if (name === _expression_row_object__WEBPACK_IMPORTED_MODULE_8__.ROW_OBJECT) {\n      onReserve(_expression_row_object__WEBPACK_IMPORTED_MODULE_8__.ROW_OBJECT, 'function');\n    }\n  }\n  if (verifyFunction(name, fn, _op_functions__WEBPACK_IMPORTED_MODULE_3__[\"default\"], options)) return;\n  _op_functions__WEBPACK_IMPORTED_MODULE_3__[\"default\"][name] = fn;\n  _op_op_api__WEBPACK_IMPORTED_MODULE_5__[\"default\"][name] = fn;\n}\n\n// -- Table Methods and Verbs ---------------------------------------\n\nconst proto = _table_column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"].prototype;\n\n/**\n * Reserved table/query methods that must not be overwritten.\n */\nlet RESERVED;\n\nfunction addReserved(obj) {\n  for (; obj; obj = Object.getPrototypeOf(obj)) {\n    Object.getOwnPropertyNames(obj).forEach(name => RESERVED[name] = 1);\n  }\n}\n\nfunction verifyTableMethod(name, fn, options) {\n  const type = 'method';\n\n  // exit early if duplicate re-assignment\n  if (proto[name] && proto[name].fn === fn) return true;\n\n  // initialize reserved properties to avoid overriding internals\n  if (!RESERVED) {\n    RESERVED = {};\n    addReserved(proto);\n    addReserved(_query_query__WEBPACK_IMPORTED_MODULE_6__[\"default\"].prototype);\n  }\n\n  // perform name checks\n  if (RESERVED[name]) onReserve(name, type);\n  if ((name + '')[0] === '_') onIllegal(name, type);\n  check(name, options, proto, type);\n}\n\n/**\n * Register a new table method. A new method will be added to the column\n * table prototype. When invoked from a table, the registered method will\n * be invoked with the table as the first argument, followed by all the\n * provided arguments.\n * @param {string} name The name of the table method.\n * @param {Function} method The table method.\n * @param {RegisterOptions} options\n */\nfunction addTableMethod(name, method, options = {}) {\n  if (verifyTableMethod(name, method, options)) return;\n  proto[name] = function(...args) { return method(this, ...args); };\n  proto[name].fn = method;\n}\n\n/**\n * Register a new transformation verb.\n * @param {string} name The name of the verb.\n * @param {Function} method The verb implementation.\n * @param {ParamDef[]} params The verb parameter schema.\n * @param {RegisterOptions} options Function registration options.\n */\nfunction addVerb(name, method, params, options = {}) {\n  // register table method first\n  // if that doesn't throw, add serializable verb entry\n  addTableMethod(name, method, options);\n  (0,_query_query__WEBPACK_IMPORTED_MODULE_6__.addQueryVerb)(name, _query_verb__WEBPACK_IMPORTED_MODULE_7__.Verbs[name] = (0,_query_verb__WEBPACK_IMPORTED_MODULE_7__.createVerb)(name, params));\n}\n\n// -- Package Bundles -----------------------------------------------\n\nconst PACKAGE = 'arquero_package';\n\n/**\n * Add an extension package of functions, table methods, and/or verbs.\n * @param {Package|PackageBundle} bundle The package of extensions.\n * @throws If package validation fails.\n */\nfunction addPackage(bundle, options = {}) {\n  const pkg = bundle && bundle[PACKAGE] || bundle;\n  const parts = {\n    functions: [\n      (name, def, opt) => verifyFunction(name, def, _op_functions__WEBPACK_IMPORTED_MODULE_3__[\"default\"], opt),\n      addFunction\n    ],\n    aggregateFunctions: [\n      (name, def, opt) => verifyFunction(name, def, _op_aggregate_functions__WEBPACK_IMPORTED_MODULE_1__[\"default\"], opt),\n      addAggregateFunction\n    ],\n    windowFunctions: [\n      (name, def, opt) => verifyFunction(name, def, _op_window_functions__WEBPACK_IMPORTED_MODULE_2__[\"default\"], opt),\n      addWindowFunction\n    ],\n    tableMethods: [\n      verifyTableMethod,\n      addTableMethod\n    ],\n    verbs: [\n      (name, obj, opt) => verifyTableMethod(name, obj.method, opt),\n      (name, obj, opt) => addVerb(name, obj.method, obj.params, opt)\n    ]\n  };\n\n  function scan(index) {\n    for (const key in parts) {\n      const part = parts[key];\n      const p = pkg[key];\n      for (const name in p) part[index](name, p[name], options);\n    }\n  }\n  scan(0); // first validate package, throw if validation fails\n  scan(1); // then add package content\n}\n\n/**\n * Aggregate function definition.\n * @typedef {import('./op/aggregate-functions').AggregateDef} AggregateDef\n */\n\n/**\n * Window function definition.\n * @typedef {import('./op/window-functions').WindowDef} WindowDef\n */\n\n/**\n * Verb parameter definition.\n * @typedef {import('./query/verb').ParamDef} ParamDef\n */\n\n/**\n * Verb definition.\n * @typedef {object} VerbDef\n * @property {Function} method A function implementing the verb.\n * @property {ParamDef[]} params The verb parameter schema.\n */\n\n/**\n * Verb parameter definition.\n * @typedef {object} ParamDef\n * @property {string} name The verb parameter name.\n * @property {ParamType} type The verb parameter type.\n */\n\n/**\n * A package of op function and table method definitions.\n * @typedef {object} Package\n * @property {{[name: string]: Function}} [functions] Standard function entries.\n * @property {{[name: string]: AggregateDef}} [aggregateFunctions] Aggregate function entries.\n * @property {{[name: string]: WindowDef}} [windowFunctions] Window function entries.\n * @property {{[name: string]: Function}} [tableMethods] Table method entries.\n * @property {{[name: string]: VerbDef}} [verbs] Verb entries.\n */\n\n/**\n * An object containing an extension package.\n * @typedef {object} PackageBundle\n * @property {Package} arquero.package The package bundle.\n */\n\n/**\n * Options for registering new functions.\n * @typedef {object} RegisterOptions\n * @property {boolean} [override=false] Flag indicating if the added\n *  function can override an existing function with the same name.\n */\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/register.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/bit-set.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/table/bit-set.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ BitSet)\n/* harmony export */ });\nconst ONE = 0x80000000;\nconst ALL = 0xFFFFFFFF;\n\n/**\n * Represent an indexable set of bits.\n */\nclass BitSet {\n  /**\n   * Instantiate a new BitSet instance.\n   * @param {number} size The number of bits.\n   */\n  constructor(size) {\n    this._size = size;\n    this._bits = new Uint32Array(Math.ceil(size / 32));\n  }\n\n  /**\n   * The number of bits.\n   * @return {number}\n   */\n  get length() {\n    return this._size;\n  }\n\n  /**\n   * The number of bits set to one.\n   * https://graphics.stanford.edu/~seander/bithacks.html#CountBitsSetKernighan\n   * @return {number}\n   */\n  count() {\n    const n = this._bits.length;\n    let count = 0;\n    for (let i = 0; i < n; ++i) {\n      for (let b = this._bits[i]; b; ++count) {\n        b &= b - 1;\n      }\n    }\n    return count;\n  }\n\n  /**\n   * Get the bit at a given index.\n   * @param {number} i The bit index.\n   */\n  get(i) {\n    return this._bits[i >> 5] & (ONE >>> i);\n  }\n\n  /**\n   * Set the bit at a given index to one.\n   * @param {number} i The bit index.\n   */\n  set(i) {\n    this._bits[i >> 5] |= (ONE >>> i);\n  }\n\n  /**\n   * Clear the bit at a given index to zero.\n   * @param {number} i The bit index.\n   */\n  clear(i) {\n    this._bits[i >> 5] &= ~(ONE >>> i);\n  }\n\n  /**\n   * Scan the bits, invoking a callback function with the index of\n   * each non-zero bit.\n   * @param {(i: number) => void} fn A callback function.\n   */\n  scan(fn) {\n    for (let i = this.next(0); i >= 0; i = this.next(i + 1)) {\n      fn(i);\n    }\n  }\n\n  /**\n   * Get the next non-zero bit starting from a given index.\n   * @param {number} i The bit index.\n   */\n  next(i) {\n    const bits = this._bits;\n    const n = bits.length;\n\n    let index = i >> 5;\n    let curr = bits[index] & (ALL >>> i);\n\n    for (; index < n; curr = bits[++index]) {\n      if (curr !== 0) {\n        return (index << 5) + Math.clz32(curr);\n      }\n    }\n\n    return -1;\n  }\n\n  /**\n   * Return the index of the nth non-zero bit.\n   * @param {number} n The number of non-zero bits to advance.\n   * @return {number} The index of the nth non-zero bit.\n   */\n  nth(n) {\n    let i = this.next(0);\n    while (n-- && i >= 0) i = this.next(i + 1);\n    return i;\n  }\n\n  /**\n   * Negate all bits in this bitset.\n   * Modifies this BitSet in place.\n   * @return {this}\n   */\n  not() {\n    const bits = this._bits;\n    const n = bits.length;\n\n    // invert all bits\n    for (let i = 0; i < n; ++i) {\n      bits[i] = ~bits[i];\n    }\n\n    // unset extraneous trailing bits\n    const tail = this._size % 32;\n    if (tail) {\n      bits[n - 1] &= ONE >> (tail - 1);\n    }\n\n    return this;\n  }\n\n  /**\n   * Compute the logical AND of this BitSet and another.\n   * @param {BitSet} bitset The BitSet to combine with.\n   * @return {BitSet} This BitSet updated with the logical AND.\n   */\n  and(bitset) {\n    if (bitset) {\n      const a = this._bits;\n      const b = bitset._bits;\n      const n = a.length;\n\n      for (let i = 0; i < n; ++i) {\n        a[i] &= b[i];\n      }\n    }\n    return this;\n  }\n\n  /**\n   * Compute the logical OR of this BitSet and another.\n   * @param {BitSet} bitset The BitSet to combine with.\n   * @return {BitSet} This BitSet updated with the logical OR.\n   */\n  or(bitset) {\n    if (bitset) {\n      const a = this._bits;\n      const b = bitset._bits;\n      const n = a.length;\n\n      for (let i = 0; i < n; ++i) {\n        a[i] |= b[i];\n      }\n    }\n    return this;\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/bit-set.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/column-set.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/table/column-set.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_has__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/has */ \"../../node_modules/arquero/src/util/has.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table) {\n  return table\n    ? new ColumnSet({ ...table.data() }, table.columnNames())\n    : new ColumnSet();\n}\n\nclass ColumnSet {\n  constructor(data, names) {\n    this.data = data || {};\n    this.names = names || [];\n  }\n\n  add(name, values) {\n    if (!this.has(name)) this.names.push(name + '');\n    return this.data[name] = values;\n  }\n\n  has(name) {\n    return (0,_util_has__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(this.data, name);\n  }\n\n  new() {\n    this.filter = null;\n    this.groups = this.groups || null;\n    this.order = null;\n    return this;\n  }\n\n  groupby(groups) {\n    this.groups = groups;\n    return this;\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/column-set.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/column-table.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/table/column-table.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ColumnTable)\n/* harmony export */ });\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./column */ \"../../node_modules/arquero/src/table/column.js\");\n/* harmony import */ var _columns_from__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./columns-from */ \"../../node_modules/arquero/src/table/columns-from.js\");\n/* harmony import */ var _column_set__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./column-set */ \"../../node_modules/arquero/src/table/column-set.js\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./table */ \"../../node_modules/arquero/src/table/table.js\");\n/* harmony import */ var _regroup__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./regroup */ \"../../node_modules/arquero/src/table/regroup.js\");\n/* harmony import */ var _expression_row_object__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../expression/row-object */ \"../../node_modules/arquero/src/expression/row-object.js\");\n/* harmony import */ var _format_to_arrow__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../format/to-arrow */ \"../../node_modules/arquero/src/format/to-arrow.js\");\n/* harmony import */ var _format_to_csv__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../format/to-csv */ \"../../node_modules/arquero/src/format/to-csv.js\");\n/* harmony import */ var _format_to_html__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../format/to-html */ \"../../node_modules/arquero/src/format/to-html.js\");\n/* harmony import */ var _format_to_json__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../format/to-json */ \"../../node_modules/arquero/src/format/to-json.js\");\n/* harmony import */ var _format_to_markdown__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../format/to-markdown */ \"../../node_modules/arquero/src/format/to-markdown.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _util_array_type__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../util/array-type */ \"../../node_modules/arquero/src/util/array-type.js\");\n/* harmony import */ var _util_entries__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../util/entries */ \"../../node_modules/arquero/src/util/entries.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_map_object__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../util/map-object */ \"../../node_modules/arquero/src/util/map-object.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * Class representing a table backed by a named set of columns.\n */\nclass ColumnTable extends _table__WEBPACK_IMPORTED_MODULE_3__[\"default\"] {\n\n  /**\n   * Create a new ColumnTable from existing input data.\n   * @param {object[]|Iterable<object>|object|Map} values The backing table data values.\n   *  If array-valued, should be a list of JavaScript objects with\n   *  key-value properties for each column value.\n   *  If object- or Map-valued, a table with two columns (one for keys,\n   *  one for values) will be created.\n   * @param {string[]} [names] The named columns to include.\n   * @return {ColumnTable} A new ColumnTable instance.\n   */\n  static from(values, names) {\n    return new ColumnTable((0,_columns_from__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values, names), names);\n  }\n\n  /**\n   * Create a new table for a set of named columns.\n   * @param {object|Map} columns\n   *  The set of named column arrays. Keys are column names.\n   *  The enumeration order of the keys determines the column indices,\n   *  unless the names parameter is specified.\n   *  Values must be arrays (or array-like values) of identical length.\n   * @param {string[]} [names] Ordered list of column names. If specified,\n   *  this array determines the column indices. If not specified, the\n   *  key enumeration order of the columns object is used.\n   * @return {ColumnTable} the instantiated ColumnTable instance.\n   */\n  static new(columns, names) {\n    if (columns instanceof ColumnTable) return columns;\n    const data = {};\n    const keys = [];\n    for (const [key, value] of (0,_util_entries__WEBPACK_IMPORTED_MODULE_13__[\"default\"])(columns)) {\n      data[key] = value;\n      keys.push(key);\n    }\n    return new ColumnTable(data, names || keys);\n  }\n\n  /**\n   * Instantiate a new ColumnTable instance.\n   * @param {object} columns An object mapping column names to values.\n   * @param {string[]} [names] An ordered list of column names.\n   * @param {BitSet} [filter] A filtering BitSet.\n   * @param {GroupBySpec} [group] A groupby specification.\n   * @param {RowComparator} [order] A row comparator function.\n   * @param {Params} [params] An object mapping parameter names to values.\n   */\n  constructor(columns, names, filter, group, order, params) {\n    (0,_util_map_object__WEBPACK_IMPORTED_MODULE_15__[\"default\"])(columns, _column__WEBPACK_IMPORTED_MODULE_0__.defaultColumnFactory, columns);\n    names = names || Object.keys(columns);\n    const nrows = names.length ? columns[names[0]].length : 0;\n    super(names, nrows, columns, filter, group, order, params);\n  }\n\n  /**\n   * Create a new table with the same type as this table.\n   * The new table may have different data, filter, grouping, or ordering\n   * based on the values of the optional configuration argument. If a\n   * setting is not specified, it is inherited from the current table.\n   * @param {CreateOptions} [options] Creation options for the new table.\n   * @return {ColumnTable} A newly created table.\n   */\n  create({ data, names, filter, groups, order }) {\n    const f = filter !== undefined ? filter : this.mask();\n\n    return new ColumnTable(\n      data || this._data,\n      names || (!data ? this._names : null),\n      f,\n      groups !== undefined ? groups : (0,_regroup__WEBPACK_IMPORTED_MODULE_4__.regroup)(this._group, filter && f),\n      order !== undefined ? order : this._order,\n      this._params\n    );\n  }\n\n  /**\n   * Create a new table with additional columns drawn from one or more input\n   * tables. All tables must have the same numer of rows and are reified\n   * prior to assignment. In the case of repeated column names, input table\n   * columns overwrite existing columns.\n   * @param {...ColumnTable} tables The tables to merge with this table.\n   * @return {ColumnTable} A new table with merged columns.\n   * @example table.assign(table1, table2)\n   */\n  assign(...tables) {\n    const nrows = this.numRows();\n    const base = this.reify();\n    const cset = (0,_column_set__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(base).groupby(base.groups());\n    tables.forEach(input => {\n      input = ColumnTable.new(input);\n      if (input.numRows() !== nrows) (0,_util_error__WEBPACK_IMPORTED_MODULE_14__[\"default\"])('Assign row counts do not match');\n      input = input.reify();\n      input.columnNames(name => cset.add(name, input.column(name)));\n    });\n    return this.create(cset.new());\n  }\n\n  /**\n   * Get the backing set of columns for this table.\n   * @return {ColumnData} Object of named column instances.\n   */\n  columns() {\n    return this._data;\n  }\n\n  /**\n   * Get the column instance with the given name.\n   * @param {string} name The column name.\n   * @return {ColumnType | undefined} The named column, or undefined if it does not exist.\n   */\n  column(name) {\n    return this._data[name];\n  }\n\n  /**\n   * Get the column instance at the given index position.\n   * @param {number} index The zero-based column index.\n   * @return {ColumnType | undefined} The column, or undefined if it does not exist.\n   */\n  columnAt(index) {\n    return this._data[this._names[index]];\n  }\n\n  /**\n   * Get an array of values contained in a column. The resulting array\n   * respects any table filter or orderby criteria.\n   * @param {string} name The column name.\n   * @param {ArrayConstructor|import('./table').TypedArrayConstructor} [constructor=Array]\n   *  The array constructor for instantiating the output array.\n   * @return {import('./table').DataValue[]|import('./table).TypedArray} The array of column values.\n   */\n  array(name, constructor = Array) {\n    const column = this.column(name);\n    const array = new constructor(this.numRows());\n    let idx = -1;\n    this.scan(row => array[++idx] = column.get(row), true);\n    return array;\n  }\n\n  /**\n   * Get the value for the given column and row.\n   * @param {string} name The column name.\n   * @param {number} [row=0] The row index, defaults to zero if not specified.\n   * @return {import('./table').DataValue} The table value at (column, row).\n   */\n  get(name, row = 0) {\n    const column = this.column(name);\n    return this.isFiltered() || this.isOrdered()\n      ? column.get(this.indices()[row])\n      : column.get(row);\n  }\n\n  /**\n   * Returns an accessor (\"getter\") function for a column. The returned\n   * function takes a row index as its single argument and returns the\n   * corresponding column value.\n   * @param {string} name The column name.\n   * @return {import('./table').ColumnGetter} The column getter function.\n   */\n  getter(name) {\n    const column = this.column(name);\n    const indices = this.isFiltered() || this.isOrdered() ? this.indices() : null;\n    return indices ? row => column.get(indices[row])\n      : column ? row => column.get(row)\n      : (0,_util_error__WEBPACK_IMPORTED_MODULE_14__[\"default\"])(`Unrecognized column: ${name}`);\n  }\n\n  /**\n   * Returns an object representing a table row.\n   * @param {number} [row=0] The row index, defaults to zero if not specified.\n   * @return {object} A row object with named properties for each column.\n   */\n  object(row = 0) {\n    return objectBuilder(this)(row);\n  }\n\n  /**\n   * Returns an array of objects representing table rows.\n   * @param {ObjectsOptions} [options] The options for row object generation.\n   * @return {object[]} An array of row objects.\n   */\n  objects(options = {}) {\n    const { grouped, limit, offset } = options;\n\n    // generate array of row objects\n    const names = (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_11__[\"default\"])(this, options.columns || (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_11__.all)());\n    const create = (0,_expression_row_object__WEBPACK_IMPORTED_MODULE_5__.rowObjectBuilder)(names);\n    const obj = [];\n    this.scan(\n      (row, data) => obj.push(create(row, data)),\n      true, limit, offset\n    );\n\n    // produce nested output as requested\n    if (grouped && this.isGrouped()) {\n      const idx = [];\n      this.scan(row => idx.push(row), true, limit, offset);\n      return (0,_regroup__WEBPACK_IMPORTED_MODULE_4__.nest)(this, idx, obj, grouped);\n    }\n\n    return obj;\n  }\n\n  /**\n   * Returns an iterator over objects representing table rows.\n   * @return {Iterator<object>} An iterator over row objects.\n   */\n  *[Symbol.iterator]() {\n    const create = objectBuilder(this);\n    const n = this.numRows();\n    for (let i = 0; i < n; ++i) {\n      yield create(i);\n    }\n  }\n\n  /**\n   * Create a new fully-materialized instance of this table.\n   * All filter and orderby settings are removed from the new table.\n   * Instead, the backing data itself is filtered and ordered as needed.\n   * @param {number[]} [indices] Ordered row indices to materialize.\n   *  If unspecified, all rows passing the table filter are used.\n   * @return {ColumnTable} A reified table.\n   */\n  reify(indices) {\n    const nrows = indices ? indices.length : this.numRows();\n    const names = this._names;\n    let data, groups;\n\n    if (!indices && !this.isOrdered()) {\n      if (!this.isFiltered()) {\n        return this; // data already reified\n      } else if (nrows === this.totalRows()) {\n        data = this.data(); // all rows pass filter, skip copy\n      }\n    }\n\n    if (!data) {\n      const scan = indices ? f => indices.forEach(f) : f => this.scan(f, true);\n      const ncols = names.length;\n      data = {};\n\n      for (let i = 0; i < ncols; ++i) {\n        const name = names[i];\n        const prev = this.column(name);\n        const curr = data[name] = new ((0,_util_array_type__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(prev))(nrows);\n        let r = -1;\n        scan(row => curr[++r] = prev.get(row));\n      }\n\n      if (this.isGrouped()) {\n        groups = (0,_regroup__WEBPACK_IMPORTED_MODULE_4__.reindex)(this.groups(), scan, !!indices, nrows);\n      }\n    }\n\n    return this.create({ data, names, groups, filter: null, order: null });\n  }\n\n  /**\n   * Apply a sequence of transformations to this table. The output\n   * of each transform is passed as input to the next transform, and\n   * the output of the last transform is then returned.\n   * @param {...(Transform|Transform[])} transforms Transformation\n   *  functions to apply to the table in sequence. Each function should\n   *  take a single table as input and return a table as output.\n   * @return {ColumnTable} The output of the last transform.\n   */\n  transform(...transforms) {\n    return transforms.flat().reduce((t, f) => f(t), this);\n  }\n\n  /**\n   * Format this table as an Apache Arrow table.\n   * @param {ArrowFormatOptions} [options] The formatting options.\n   * @return {import('apache-arrow').Table} An Apache Arrow table.\n   */\n  toArrow(options) {\n    return (0,_format_to_arrow__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(this, options);\n  }\n\n  /**\n   * Format this table as binary data in the Apache Arrow IPC format.\n   * @param {ArrowFormatOptions} [options] The formatting options.\n   * @return {Uint8Array} A new Uint8Array of Arrow-encoded binary data.\n   */\n  toArrowBuffer(options) {\n    return (0,_format_to_arrow__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(this, options).serialize();\n  }\n\n  /**\n   * Format this table as a comma-separated values (CSV) string. Other\n   * delimiters, such as tabs or pipes ('|'), can be specified using\n   * the options argument.\n   * @param {CSVFormatOptions} [options] The formatting options.\n   * @return {string} A delimited value string.\n   */\n  toCSV(options) {\n    return (0,_format_to_csv__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(this, options);\n  }\n\n  /**\n   * Format this table as an HTML table string.\n   * @param {HTMLFormatOptions} [options] The formatting options.\n   * @return {string} An HTML table string.\n   */\n  toHTML(options) {\n    return (0,_format_to_html__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(this, options);\n  }\n\n  /**\n   * Format this table as a JavaScript Object Notation (JSON) string.\n   * @param {JSONFormatOptions} [options] The formatting options.\n   * @return {string} A JSON string.\n   */\n  toJSON(options) {\n    return (0,_format_to_json__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(this, options);\n  }\n\n  /**\n   * Format this table as a GitHub-Flavored Markdown table string.\n   * @param {MarkdownFormatOptions} [options] The formatting options.\n   * @return {string} A GitHub-Flavored Markdown table string.\n   */\n  toMarkdown(options) {\n    return (0,_format_to_markdown__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(this, options);\n  }\n}\n\nfunction objectBuilder(table) {\n  let b = table._builder;\n\n  if (!b) {\n    const create = (0,_expression_row_object__WEBPACK_IMPORTED_MODULE_5__.rowObjectBuilder)(table.columnNames());\n    const data = table.data();\n    if (table.isOrdered() || table.isFiltered()) {\n      const indices = table.indices();\n      b = row => create(indices[row], data);\n    } else {\n      b = row => create(row, data);\n    }\n    table._builder = b;\n  }\n\n  return b;\n}\n\n/**\n * A table transformation.\n * @typedef {(table: ColumnTable) => ColumnTable} Transform\n */\n\n/**\n * Proxy type for BitSet class.\n * @typedef {import('./table').BitSet} BitSet\n */\n\n/**\n * Proxy type for ColumnType interface.\n * @typedef {import('./column').ColumnType} ColumnType\n */\n\n/**\n * A named collection of columns.\n * @typedef {{[key: string]: ColumnType}} ColumnData\n */\n\n/**\n * Proxy type for GroupBySpec.\n * @typedef {import('./table').GroupBySpec} GroupBySpec\n */\n\n/**\n * Proxy type for RowComparator.\n * @typedef {import('./table').RowComparator} RowComparator\n */\n\n/**\n * Proxy type for Params.\n * @typedef {import('./table').Params} Params\n */\n\n/**\n * Options for Arrow formatting.\n * @typedef {import('../arrow/encode').ArrowFormatOptions} ArrowFormatOptions\n */\n\n/**\n * Options for CSV formatting.\n * @typedef {import('../format/to-csv').CSVFormatOptions} CSVFormatOptions\n */\n\n/**\n * Options for HTML formatting.\n * @typedef {import('../format/to-html').HTMLFormatOptions} HTMLFormatOptions\n */\n\n/**\n * Options for JSON formatting.\n * @typedef {import('../format/to-json').JSONFormatOptions} JSONFormatOptions\n */\n\n/**\n * Options for Markdown formatting.\n * @typedef {import('../format/to-markdown').MarkdownFormatOptions} MarkdownFormatOptions\n */\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/column-table.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/column.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/table/column.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   columnFactory: () => (/* binding */ columnFactory),\n/* harmony export */   \"default\": () => (/* binding */ Column),\n/* harmony export */   defaultColumnFactory: () => (/* binding */ defaultColumnFactory)\n/* harmony export */ });\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n\n\n/**\n * Class representing an array-backed data column.\n */\nclass Column {\n  /**\n   * Create a new column instance.\n   * @param {Array} data The backing array (or array-like object)\n   *  containing the column data.\n   */\n  constructor(data) {\n    this.data = data;\n  }\n\n  /**\n   * Get the length (number of rows) of the column.\n   * @return {number} The length of the column array.\n   */\n  get length() {\n    return this.data.length;\n  }\n\n  /**\n   * Get the column value at the given row index.\n   * @param {number} row The row index of the value to retrieve.\n   * @return {import('./table').DataValue} The column value.\n   */\n  get(row) {\n    return this.data[row];\n  }\n\n  /**\n   * Returns an iterator over the column values.\n   * @return {Iterator<object>} An iterator over column values.\n   */\n  [Symbol.iterator]() {\n    return this.data[Symbol.iterator]();\n  }\n}\n\n/**\n * Column interface. Any object that adheres to this interface\n * can be used as a data column within a {@link ColumnTable}.\n * @typedef {object} ColumnType\n * @property {number} length\n *  The length (number of rows) of the column.\n * @property {import('./table').ColumnGetter} get\n *  Column value getter.\n */\n\n/**\n * Column factory function interface.\n * @callback ColumnFactory\n * @param {*} data The input column data.\n * @return {ColumnType} A column instance.\n */\n\n/**\n * Create a new column from the given input data.\n * @param {any} data The backing column data. If the value conforms to\n *  the Column interface it is returned directly. If the value is an\n *  array, it will be wrapped in a new Column instance.\n * @return {ColumnType} A compatible column instance.\n */\nlet defaultColumnFactory = function(data) {\n  return data && (0,_util_is_function__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(data.get) ? data : new Column(data);\n};\n\n/**\n * Get or set the default factory function for instantiating table columns.\n * @param {ColumnFactory} [factory] The new default factory.\n * @return {ColumnFactory} The current default column factory.\n */\nfunction columnFactory(factory) {\n  return arguments.length\n    ? (defaultColumnFactory = factory)\n    : defaultColumnFactory;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/column.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/columns-from.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/table/columns-from.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_date__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_regexp__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-regexp */ \"../../node_modules/arquero/src/util/is-regexp.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values, names) {\n  const raise = type => (0,_util_error__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(`Illegal argument type: ${type || typeof values}`);\n  return values instanceof Map ? fromKeyValuePairs(values.entries(), names)\n    : (0,_util_is_date__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values) ? raise('Date')\n    : (0,_util_is_regexp__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(values) ? raise('RegExp')\n    : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(values) ? raise()\n    : (0,_util_is_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values) ? fromArray(values, names)\n    : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values[Symbol.iterator]) ? fromIterable(values, names)\n    : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(values) ? fromKeyValuePairs(Object.entries(values), names)\n    : raise();\n}\n\nfunction fromKeyValuePairs(entries, names = ['key', 'value']) {\n  const keys = [];\n  const vals = [];\n\n  for (const [key, val] of entries) {\n    keys.push(key);\n    vals.push(val);\n  }\n\n  const columns = {};\n  if (names[0]) columns[names[0]] = keys;\n  if (names[1]) columns[names[1]] = vals;\n  return columns;\n}\n\nfunction fromArray(values, names) {\n  const len = values.length;\n  const columns = {};\n  const add = name => columns[name] = Array(len);\n\n  if (len) {\n    names = names || Object.keys(values[0]);\n    const cols = names.map(add);\n    const n = cols.length;\n    for (let idx = 0; idx < len; ++idx) {\n      const row = values[idx];\n      for (let i = 0; i < n; ++i) {\n        cols[i][idx] = row[names[i]];\n      }\n    }\n  } else if (names) {\n    names.forEach(add);\n  }\n\n  return columns;\n}\n\nfunction fromIterable(values, names) {\n  const columns = {};\n  const add = name => columns[name] = [];\n\n  let cols;\n  let n;\n  for (const row of values) {\n    if (!cols) {\n      names = names || Object.keys(row);\n      cols = names.map(add);\n      n = cols.length;\n    }\n    for (let i = 0; i < n; ++i) {\n      cols[i].push(row[names[i]]);\n    }\n  }\n\n  if (!cols && names) {\n    names.forEach(add);\n  }\n\n  return columns;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/columns-from.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/index.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/table/index.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   from: () => (/* binding */ from),\n/* harmony export */   table: () => (/* binding */ table)\n/* harmony export */ });\n/* harmony import */ var _column_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./column-table */ \"../../node_modules/arquero/src/table/column-table.js\");\n/* harmony import */ var _verbs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../verbs */ \"../../node_modules/arquero/src/verbs/index.js\");\n\n\n\n// Add verb implementations to ColumnTable prototype\nObject.assign(_column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"].prototype, _verbs__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n/**\n * Create a new table for a set of named columns.\n * @param {object|Map} columns\n *  The set of named column arrays. Keys are column names.\n *  The enumeration order of the keys determines the column indices,\n *  unless the names parameter is specified.\n *  Values must be arrays (or array-like values) of identical length.\n * @param {string[]} [names] Ordered list of column names. If specified,\n *  this array determines the column indices. If not specified, the\n *  key enumeration order of the columns object is used.\n * @return {ColumnTable} the instantiated table\n * @example table({ colA: ['a', 'b', 'c'], colB: [3, 4, 5] })\n */\nfunction table(columns, names) {\n  return _column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"].new(columns, names);\n}\n\n/**\n * Create a new table from an existing object, such as an array of\n * objects or a set of key-value pairs.\n * @param {object|Array|Map} values Data values to populate the table.\n *  If array-valued or iterable, imports rows for each non-null value,\n *  using the provided column names as keys for each row object. If no\n *  names are provided, the first non-null object's own keys are used.\n *  If object- or Map-valued, create columns for the keys and values.\n * @param {string[]} [names] Column names to include.\n *  For object or Map values, specifies the key and value column names.\n *  Otherwise, specifies the keys to look up on each row object.\n * @return {ColumnTable} the instantiated table.\n * @example from([ { colA: 1, colB: 2 }, { colA: 3, colB: 4 } ])\n */\nfunction from(values, names) {\n  return _column_table__WEBPACK_IMPORTED_MODULE_0__[\"default\"].from(values, names);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/regroup.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/table/regroup.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   nest: () => (/* binding */ nest),\n/* harmony export */   regroup: () => (/* binding */ regroup),\n/* harmony export */   reindex: () => (/* binding */ reindex)\n/* harmony export */ });\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_unique_name__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/unique-name */ \"../../node_modules/arquero/src/util/unique-name.js\");\n\n\n\n\n/**\n * Regroup table rows in response to a BitSet filter.\n * @param {GroupBySpec} groups The current groupby specification.\n * @param {BitSet} filter The filter to apply.\n */\nfunction regroup(groups, filter) {\n  if (!groups || !filter) return groups;\n\n  // check for presence of rows for each group\n  const { keys, rows, size } = groups;\n  const map = new Int32Array(size);\n  filter.scan(row => map[keys[row]] = 1);\n\n  // check sum, exit early if all groups occur\n  const sum = map.reduce((sum, val) => sum + val, 0);\n  if (sum === size) return groups;\n\n  // create group index map, filter exemplar rows\n  const _rows = Array(sum);\n  let _size = 0;\n  for (let i = 0; i < size; ++i) {\n    if (map[i]) _rows[map[i] = _size++] = rows[i];\n  }\n\n  // re-index the group keys\n  const _keys = new Uint32Array(keys.length);\n  filter.scan(row => _keys[row] = map[keys[row]]);\n\n  return { ...groups, keys: _keys, rows: _rows, size: _size };\n}\n\n/**\n * Regroup table rows in response to a re-indexing.\n * This operation may or may not involve filtering of rows.\n * @param {GroupBySpec} groups The current groupby specification.\n * @param {Function} scan Function to scan new row indices.\n * @param {boolean} filter Flag indicating if filtering may occur.\n * @param {number} nrows The number of rows in the new table.\n */\nfunction reindex(groups, scan, filter, nrows) {\n  const { keys, rows, size } = groups;\n  let _rows = rows;\n  let _size = size;\n  let map = null;\n\n  if (filter) {\n    // check for presence of rows for each group\n    map = new Int32Array(size);\n    scan(row => map[keys[row]] = 1);\n\n    // check sum, regroup if not all groups occur\n    const sum = map.reduce((sum, val) => sum + val, 0);\n    if (sum !== size) {\n      // create group index map, filter exemplar rows\n      _rows = Array(sum);\n      _size = 0;\n      for (let i = 0; i < size; ++i) {\n        if (map[i]) _rows[map[i] = _size++] = rows[i];\n      }\n    }\n  }\n\n  // re-index the group keys\n  let r = -1;\n  const _keys = new Uint32Array(nrows);\n  const fn = _size !== size\n    ? row => _keys[++r] = map[keys[row]]\n    : row => _keys[++r] = keys[row];\n  scan(fn);\n\n  return { ...groups, keys: _keys, rows: _rows, size: _size };\n}\n\nfunction nest(table, idx, obj, type) {\n  const agg = type === 'map' || type === true ? _op_op_api__WEBPACK_IMPORTED_MODULE_0__.map_agg\n    : type === 'entries' ? _op_op_api__WEBPACK_IMPORTED_MODULE_0__.entries_agg\n    : type === 'object' ? _op_op_api__WEBPACK_IMPORTED_MODULE_0__.object_agg\n    : (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('groups option must be \"map\", \"entries\", or \"object\".');\n\n  const { names } = table.groups();\n  const col = (0,_util_unique_name__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(table.columnNames(), '_');\n\n  // create table with one column of row objects\n  // then aggregate into per-group arrays\n  let t = table\n    .select()\n    .reify(idx)\n    .create({ data: { [col]: obj } })\n    .rollup({ [col]: (0,_op_op_api__WEBPACK_IMPORTED_MODULE_0__.array_agg)(col) });\n\n  // create nested structures for each level of grouping\n  for (let i = names.length; --i >= 0;) {\n    t = t\n      .groupby(names.slice(0, i))\n      .rollup({ [col]: agg(names[i], col) });\n  }\n\n  // return the final aggregated structure\n  return t.get(col);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/regroup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/table.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/table/table.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Table)\n/* harmony export */ });\n/* harmony import */ var _transformable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./transformable */ \"../../node_modules/arquero/src/table/transformable.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_repeat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/repeat */ \"../../node_modules/arquero/src/util/repeat.js\");\n\n\n\n\n\n/**\n * Abstract class representing a data table.\n */\nclass Table extends _transformable__WEBPACK_IMPORTED_MODULE_0__[\"default\"] {\n\n  /**\n   * Instantiate a new Table instance.\n   * @param {string[]} names An ordered list of column names.\n   * @param {number} nrows The number of rows.\n   * @param {TableData} data The backing data, which can vary by implementation.\n   * @param {BitSet} [filter] A bit mask for which rows to include.\n   * @param {GroupBySpec} [groups] A groupby specification for grouping ows.\n   * @param {RowComparator} [order] A comparator function for sorting rows.\n   * @param {Params} [params] Parameter values for table expressions.\n   */\n  constructor(names, nrows, data, filter, groups, order, params) {\n    super(params);\n    this._names = Object.freeze(names);\n    this._data = data;\n    this._total = nrows;\n    this._nrows = filter ? filter.count() : nrows;\n    this._mask = (nrows !== this._nrows && filter) || null;\n    this._group = groups || null;\n    this._order = order || null;\n  }\n\n  /**\n   * Create a new table with the same type as this table.\n   * The new table may have different data, filter, grouping, or ordering\n   * based on the values of the optional configuration argument. If a\n   * setting is not specified, it is inherited from the current table.\n   * @param {CreateOptions} [options] Creation options for the new table.\n   * @return {this} A newly created table.\n   */\n  create(options) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Provide an informative object string tag.\n   */\n  get [Symbol.toStringTag]() {\n    if (!this._names) return 'Object'; // bail if called on prototype\n    const nr = this.numRows() + ' row' + (this.numRows() !== 1 ? 's' : '');\n    const nc = this.numCols() + ' col' + (this.numCols() !== 1 ? 's' : '');\n    return `Table: ${nc} x ${nr}`\n      + (this.isFiltered() ? ` (${this.totalRows()} backing)` : '')\n      + (this.isGrouped() ? `, ${this._group.size} groups` : '')\n      + (this.isOrdered() ? ', ordered' : '');\n  }\n\n  /**\n   * Indicates if the table has a filter applied.\n   * @return {boolean} True if filtered, false otherwise.\n   */\n  isFiltered() {\n    return !!this._mask;\n  }\n\n  /**\n   * Indicates if the table has a groupby specification.\n   * @return {boolean} True if grouped, false otherwise.\n   */\n  isGrouped() {\n    return !!this._group;\n  }\n\n  /**\n   * Indicates if the table has a row order comparator.\n   * @return {boolean} True if ordered, false otherwise.\n   */\n  isOrdered() {\n    return !!this._order;\n  }\n\n  /**\n   * Returns the internal table storage data structure.\n   * @return {TableData} The backing table storage data structure.\n   */\n  data() {\n    return this._data;\n  }\n\n  /**\n   * Returns the filter bitset mask, if defined.\n   * @return {BitSet} The filter bitset mask.\n   */\n  mask() {\n    return this._mask;\n  }\n\n  /**\n   * Returns the groupby specification, if defined.\n   * @return {GroupBySpec} The groupby specification.\n   */\n  groups() {\n    return this._group;\n  }\n\n  /**\n   * Returns the row order comparator function, if specified.\n   * @return {RowComparator} The row order comparator function.\n   */\n  comparator() {\n    return this._order;\n  }\n\n  /**\n   * The total number of rows in this table, counting both\n   * filtered and unfiltered rows.\n   * @return {number} The number of total rows.\n   */\n  totalRows() {\n    return this._total;\n  }\n\n  /**\n   * The number of active rows in this table. This number may be\n   * less than the total rows if the table has been filtered.\n   * @see Table.totalRows\n   * @return {number} The number of rows.\n   */\n  numRows() {\n    return this._nrows;\n  }\n\n  /**\n   * The number of active rows in this table. This number may be\n   * less than the total rows if the table has been filtered.\n   * @see Table.totalRows\n   * @return {number} The number of rows.\n   */\n  get size() {\n    return this._nrows;\n  }\n\n  /**\n   * The number of columns in this table.\n   * @return {number} The number of columns.\n   */\n  numCols() {\n    return this._names.length;\n  }\n\n  /**\n   * Filter function invoked for each column name.\n   * @callback NameFilter\n   * @param {string} name The column name.\n   * @param {number} index The column index.\n   * @param {string[]} array The array of names.\n   * @return {boolean} Returns true to retain the column name.\n   */\n\n  /**\n   * The table column names, optionally filtered.\n   * @param {NameFilter} [filter] An optional filter function.\n   *  If unspecified, all column names are returned.\n   * @return {string[]} An array of matching column names.\n   */\n  columnNames(filter) {\n    return filter ? this._names.filter(filter) : this._names.slice();\n  }\n\n  /**\n   * The column name at the given index.\n   * @param {number} index The column index.\n   * @return {string} The column name,\n   *  or undefined if the index is out of range.\n   */\n  columnName(index) {\n    return this._names[index];\n  }\n\n  /**\n   * The column index for the given name.\n   * @param {string} name The column name.\n   * @return {number} The column index, or -1 if the name is not found.\n   */\n  columnIndex(name) {\n    return this._names.indexOf(name);\n  }\n\n  /**\n   * Deprecated alias for the table array() method: use table.array()\n   * instead. Get an array of values contained in a column. The resulting\n   * array respects any table filter or orderby criteria.\n   * @param {string} name The column name.\n   * @param {ArrayConstructor|TypedArrayConstructor} [constructor=Array]\n   *  The array constructor for instantiating the output array.\n   * @return {DataValue[]|TypedArray} The array of column values.\n   */\n  columnArray(name, constructor) {\n    return this.array(name, constructor);\n  }\n\n  /**\n   * Get an array of values contained in a column. The resulting array\n   * respects any table filter or orderby criteria.\n   * @param {string} name The column name.\n   * @param {ArrayConstructor|TypedArrayConstructor} [constructor=Array]\n   *  The array constructor for instantiating the output array.\n   * @return {DataValue[]|TypedArray} The array of column values.\n   */\n  array(name, constructor) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Returns an iterator over column values.\n   * @return {Iterator<object>} An iterator over row objects.\n   */\n  *values(name) {\n    const get = this.getter(name);\n    const n = this.numRows();\n    for (let i = 0; i < n; ++i) {\n      yield get(i);\n    }\n  }\n\n  /**\n   * Get the value for the given column and row.\n   * @param {string} name The column name.\n   * @param {number} [row=0] The row index, defaults to zero if not specified.\n   * @return {DataValue} The data value at (column, row).\n   */\n  get(name, row = 0) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Returns an accessor (\"getter\") function for a column. The returned\n   * function takes a row index as its single argument and returns the\n   * corresponding column value.\n   * @param {string} name The column name.\n   * @return {ColumnGetter} The column getter function.\n   */\n  getter(name) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Returns an array of objects representing table rows.\n   * @param {ObjectsOptions} [options] The options for row object generation.\n   * @return {RowObject[]} An array of row objects.\n   */\n  objects(options) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Returns an object representing a table row.\n   * @param {number} [row=0] The row index, defaults to zero if not specified.\n   * @return {object} A row object with named properties for each column.\n   */\n   object(row) { // eslint-disable-line no-unused-vars\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Returns an iterator over objects representing table rows.\n   * @return {Iterator<object>} An iterator over row objects.\n   */\n  [Symbol.iterator]() {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Not implemented');\n  }\n\n  /**\n   * Print the contents of this table using the console.table() method.\n   * @param {PrintOptions|number} options The options for row object\n   *  generation, determining which rows and columns are printed. If\n   *  number-valued, specifies the row limit.\n   */\n  print(options = {}) {\n    if ((0,_util_is_number__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(options)) {\n      options = { limit: options };\n    } else if (options.limit == null) {\n      options.limit = 10;\n    }\n\n    const obj = this.objects({ ...options, grouped: false });\n    const msg = `${this[Symbol.toStringTag]}. Showing ${obj.length} rows.`;\n\n    console.log(msg);   // eslint-disable-line no-console\n    console.table(obj); // eslint-disable-line no-console\n  }\n\n  /**\n   * Returns an array of indices for all rows passing the table filter.\n   * @param {boolean} [order=true] A flag indicating if the returned\n   *  indices should be sorted if this table is ordered. If false, the\n   *  returned indices may or may not be sorted.\n   * @return {Uint32Array} An array of row indices.\n   */\n  indices(order = true) {\n    if (this._index) return this._index;\n\n    const n = this.numRows();\n    const index = new Uint32Array(n);\n    const ordered = this.isOrdered();\n    const bits = this.mask();\n    let row = -1;\n\n    // inline the following for performance:\n    // this.scan(row => index[++i] = row);\n    if (bits) {\n      for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n        index[++row] = i;\n      }\n    } else {\n      for (let i = 0; i < n; ++i) {\n        index[++row] = i;\n      }\n    }\n\n    // sort index vector\n    if (order && ordered) {\n      const compare = this._order;\n      const data = this._data;\n      index.sort((a, b) => compare(a, b, data));\n    }\n\n    // save indices if they reflect table metadata\n    if (order || !ordered) {\n      this._index = index;\n    }\n\n    return index;\n  }\n\n  /**\n   * Returns an array of indices for each group in the table.\n   * If the table is not grouped, the result is the same as\n   * {@link indices}, but wrapped within an array.\n   * @param {boolean} [order=true] A flag indicating if the returned\n   *  indices should be sorted if this table is ordered. If false, the\n   *  returned indices may or may not be sorted.\n   * @return {number[][]} An array of row index arrays, one per group.\n   *  The indices will be filtered if the table is filtered.\n   */\n  partitions(order = true) {\n    // return partitions if already generated\n    if (this._partitions) {\n      return this._partitions;\n    }\n\n    // if not grouped, return a single partition\n    if (!this.isGrouped()) {\n      return [ this.indices(order) ];\n    }\n\n    // generate partitions\n    const { keys, size } = this._group;\n    const part = (0,_util_repeat__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(size, () => []);\n\n    // populate partitions, don't sort if indices don't exist\n    // inline the following for performance:\n    // this.scan(row => part[keys[row]].push(row), sort);\n    const sort = this._index;\n    const bits = this.mask();\n    const n = this.numRows();\n    if (sort && this.isOrdered()) {\n      for (let i = 0, r; i < n; ++i) {\n        r = sort[i];\n        part[keys[r]].push(r);\n      }\n    } else if (bits) {\n      for (let i = bits.next(0); i >= 0; i = bits.next(i + 1)) {\n        part[keys[i]].push(i);\n      }\n    } else {\n      for (let i = 0; i < n; ++i) {\n        part[keys[i]].push(i);\n      }\n    }\n\n    // if ordered but not yet sorted, sort partitions directly\n    if (order && !sort && this.isOrdered()) {\n      const compare = this._order;\n      const data = this._data;\n      for (let i = 0; i < size; ++i) {\n        part[i].sort((a, b) => compare(a, b, data));\n      }\n    }\n\n    // save partitions if they reflect table metadata\n    if (order || !this.isOrdered()) {\n      this._partitions = part;\n    }\n\n    return part;\n  }\n\n  /**\n   * Callback function to cancel a table scan.\n   * @callback ScanStop\n   * @return {void}\n   */\n\n  /**\n   * Callback function invoked for each row of a table scan.\n   * @callback ScanVisitor\n   * @param {number} [row] The table row index.\n   * @param {TableData} [data] The backing table data store.\n   * @param {ScanStop} [stop] Function to stop the scan early.\n   *  Callees can invoke this function to prevent future calls.\n   * @return {void}\n   */\n\n  /**\n   * Perform a table scan, visiting each row of the table.\n   * If this table is filtered, only rows passing the filter are visited.\n   * @param {ScanVisitor} fn Callback invoked for each row of the table.\n   * @param {boolean} [order=false] Indicates if the table should be\n   *  scanned in the order determined by {@link Table#orderby}. This\n   *  argument has no effect if the table is unordered.\n   * @property {number} [limit=Infinity] The maximum number of objects to create.\n   * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n   */\n  scan(fn, order, limit = Infinity, offset = 0) {\n    const filter = this._mask;\n    const nrows = this._nrows;\n    const data = this._data;\n\n    let i = offset || 0;\n    if (i > nrows) return;\n\n    const n = Math.min(nrows, i + limit);\n    const stop = () => i = this._total;\n\n    if (order && this.isOrdered() || filter && this._index) {\n      const index = this.indices();\n      const data = this._data;\n      for (; i < n; ++i) {\n        fn(index[i], data, stop);\n      }\n    } else if (filter) {\n      let c = n - i + 1;\n      for (i = filter.nth(i); --c && i > -1; i = filter.next(i + 1)) {\n        fn(i, data, stop);\n      }\n    } else {\n      for (; i < n; ++i) {\n        fn(i, data, stop);\n      }\n    }\n  }\n\n  /**\n   * Extract rows with indices from start to end (end not included), where\n   * start and end represent per-group ordered row numbers in the table.\n   * @param {number} [start] Zero-based index at which to start extraction.\n   *  A negative index indicates an offset from the end of the group.\n   *  If start is undefined, slice starts from the index 0.\n   * @param {number} [end] Zero-based index before which to end extraction.\n   *  A negative index indicates an offset from the end of the group.\n   *  If end is omitted, slice extracts through the end of the group.\n   * @return {this} A new table with sliced rows.\n   * @example table.slice(1, -1)\n   */\n  slice(start = 0, end = Infinity) {\n    if (this.isGrouped()) return super.slice(start, end);\n\n    // if not grouped, scan table directly\n    const indices = [];\n    const nrows = this.numRows();\n    start = Math.max(0, start + (start < 0 ? nrows : 0));\n    end = Math.min(nrows, Math.max(0, end + (end < 0 ? nrows : 0)));\n    this.scan(row => indices.push(row), true, end - start, start);\n    return this.reify(indices);\n  }\n\n  /**\n   * Reduce a table, processing all rows to produce a new table.\n   * To produce standard aggregate summaries, use {@link rollup}.\n   * This method allows the use of custom reducer implementations,\n   * for example to produce multiple rows for an aggregate.\n   * @param {Reducer} reducer The reducer to apply.\n   * @return {Table} A new table of reducer outputs.\n   */\n  reduce(reducer) {\n    return this.__reduce(this, reducer);\n  }\n}\n\n/**\n * A typed array constructor.\n * @typedef {Uint8ArrayConstructor|Uint16ArrayConstructor|Uint32ArrayConstructor|BigUint64ArrayConstructor|Int8ArrayConstructor|Int16ArrayConstructor|Int32ArrayConstructor|BigInt64ArrayConstructor|Float32ArrayConstructor|Float64ArrayConstructor} TypedArrayConstructor\n */\n\n/**\n * A typed array instance.\n * @typedef {Uint8Array|Uint16Array|Uint32Array|BigUint64Array|Int8Array|Int16Array|Int32Array|BigInt64Array|Float32Array|Float64Array} TypedArray\n */\n\n/**\n * Backing table data.\n * @typedef {object|Array} TableData\n */\n\n/**\n * Table value.\n * @typedef {*} DataValue\n */\n\n/**\n * Table row object.\n * @typedef {Object.<string, DataValue>} RowObject\n */\n\n/**\n * Table expression parameters.\n * @typedef {import('./transformable').Params} Params\n */\n\n/**\n * Proxy type for BitSet class.\n * @typedef {import('./bit-set').default} BitSet\n */\n\n/**\n * A table groupby specification.\n * @typedef {object} GroupBySpec\n * @property {number} size The number of groups.\n * @property {string[]} names Column names for each group.\n * @property {RowExpression[]} get Value accessor functions for each group.\n * @property {number[]} rows Indices of an example table row for each group.\n * @property {number[]} keys Per-row group indices, length is total rows of table.\n */\n\n/**\n * Column value accessor.\n * @callback ColumnGetter\n * @param {number} [row] The table row.\n * @return {DataValue}\n */\n\n/**\n * An expression evaluated over a table row.\n * @callback RowExpression\n * @param {number} [row] The table row.\n * @param {TableData} [data] The backing table data store.\n * @return {DataValue}\n */\n\n/**\n * Comparator function for sorting table rows.\n * @callback RowComparator\n * @param {number} rowA The table row index for the first row.\n * @param {number} rowB The table row index for the second row.\n * @param {TableData} data The backing table data store.\n * @return {number} Negative if rowA < rowB, positive if\n *  rowA > rowB, otherwise zero.\n */\n\n/**\n * Options for derived table creation.\n * @typedef {object} CreateOptions\n * @property {TableData} [data] The backing column data.\n * @property {string[]} [names] An ordered list of column names.\n * @property {BitSet} [filter] An additional filter BitSet to apply.\n * @property {GroupBySpec} [groups] The groupby specification to use, or null for no groups.\n * @property {RowComparator} [order] The orderby comparator function to use, or null for no order.\n */\n\n/**\n * Options for generating row objects.\n * @typedef {object} PrintOptions\n * @property {number} [limit=Infinity] The maximum number of objects to create.\n * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n * @property {import('../table/transformable').Select} [columns]\n *  An ordered set of columns to include. The input may consist of column name\n *  strings, column integer indices, objects with current column names as keys\n *  and new column names as values (for renaming), or selection helper\n *  functions such as {@link all}, {@link not}, or {@link range}.\n */\n\n/**\n * Options for generating row objects.\n * @typedef {object} ObjectsOptions\n * @property {number} [limit=Infinity] The maximum number of objects to create.\n * @property {number} [offset=0] The row offset indicating how many initial rows to skip.\n * @property {import('../table/transformable').Select} [columns]\n *  An ordered set of columns to include. The input may consist of column name\n *  strings, column integer indices, objects with current column names as keys\n *  and new column names as values (for renaming), or selection helper\n *  functions such as {@link all}, {@link not}, or {@link range}.\n * @property {'map'|'entries'|'object'|boolean} [grouped=false]\n *  The export format for groups of rows. The default (false) is to ignore\n *  groups, returning a flat array of objects. The valid values are 'map' or\n *  true (for Map instances), 'object' (for standard objects), or 'entries'\n *  (for arrays in the style of Object.entries). For the 'object' format,\n *  groupby keys are coerced to strings to use as object property names; note\n *  that this can lead to undesirable behavior if the groupby keys are object\n *  values. The 'map' and 'entries' options preserve the groupby key values.\n */\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/table.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/table/transformable.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/table/transformable.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Transformable)\n/* harmony export */ });\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n/* harmony import */ var _helpers_slice__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../helpers/slice */ \"../../node_modules/arquero/src/helpers/slice.js\");\n\n\n\n/**\n * Abstract base class for transforming data.\n */\nclass Transformable {\n\n  /**\n   * Instantiate a new Transformable instance.\n   * @param {Params} [params] The parameter values.\n   */\n  constructor(params) {\n    if (params) this._params = params;\n  }\n\n  /**\n   * Get or set table expression parameter values.\n   * If called with no arguments, returns the current parameter values\n   * as an object. Otherwise, adds the provided parameters to this\n   * table's parameter set and returns the table. Any prior parameters\n   * with names matching the input parameters are overridden.\n   * @param {Params} [values] The parameter values.\n   * @return {this|Params} The current parameters values (if called with\n   *  no arguments) or this table.\n   */\n  params(values) {\n    if (arguments.length) {\n      if (values) {\n        this._params = { ...this._params, ...values };\n      }\n      return this;\n    } else {\n      return this._params;\n    }\n  }\n\n  /**\n   * Create a new fully-materialized instance of this table.\n   * All filter and orderby settings are removed from the new table.\n   * Instead, the backing data itself is filtered and ordered as needed.\n   * @param {number[]} [indices] Ordered row indices to materialize.\n   *  If unspecified, all rows passing the table filter are used.\n   * @return {this} A reified table.\n   */\n  reify(indices) {\n    return this.__reify(this, indices);\n  }\n\n  // -- Transformation Verbs ------------------------------------------------\n\n  /**\n   * Count the number of values in a group. This method is a shorthand\n   * for {@link Transformable#rollup} with a count aggregate function.\n   * @param {CountOptions} [options] Options for the count.\n   * @return {this} A new table with groupby and count columns.\n   * @example table.groupby('colA').count()\n   * @example table.groupby('colA').count({ as: 'num' })\n   */\n  count(options) {\n    return this.__count(this, options);\n  }\n\n  /**\n   * Derive new column values based on the provided expressions. By default,\n   * new columns are added after (higher indices than) existing columns. Use\n   * the before or after options to place new columns elsewhere.\n   * @param {ExprObject} values Object of name-value pairs defining the\n   *  columns to derive. The input object should have output column\n   *  names for keys and table expressions for values.\n   * @param {DeriveOptions} [options] Options for dropping or relocating\n   *  derived columns. Use either a before or after property to indicate\n   *  where to place derived columns. Specifying both before and after is an\n   *  error. Unlike the relocate verb, this option affects only new columns;\n   *  updated columns with existing names are excluded from relocation.\n   * @return {this} A new table with derived columns added.\n   * @example table.derive({ sumXY: d => d.x + d.y })\n   * @example table.derive({ z: d => d.x * d.y }, { before: 'x' })\n   */\n  derive(values, options) {\n    return this.__derive(this, values, options);\n  }\n\n  /**\n   * Filter a table to a subset of rows based on the input criteria.\n   * The resulting table provides a filtered view over the original data; no\n   * data copy is made. To create a table that copies only filtered data to\n   * new data structures, call {@link Transformable#reify} on the output table.\n   * @param {TableExpr} criteria Filter criteria as a table expression.\n   *  Both aggregate and window functions are permitted, taking into account\n   *  {@link Transformable#groupby} or {@link Transformable#orderby} settings.\n   * @return {this} A new table with filtered rows.\n   * @example table.filter(d => abs(d.value) < 5)\n   */\n  filter(criteria) {\n    return this.__filter(this, criteria);\n  }\n\n  /**\n   * Extract rows with indices from start to end (end not included), where\n   * start and end represent per-group ordered row numbers in the table.\n   * @param {number} [start] Zero-based index at which to start extraction.\n   *  A negative index indicates an offset from the end of the group.\n   *  If start is undefined, slice starts from the index 0.\n   * @param {number} [end] Zero-based index before which to end extraction.\n   *  A negative index indicates an offset from the end of the group.\n   *  If end is omitted, slice extracts through the end of the group.\n   * @return {this} A new table with sliced rows.\n   * @example table.slice(1, -1)\n   */\n  slice(start, end) {\n    return this.filter((0,_helpers_slice__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start, end)).reify();\n  }\n\n  /**\n   * Group table rows based on a set of column values.\n   * Subsequent operations that are sensitive to grouping (such as\n   * aggregate functions) will operate over the grouped rows.\n   * To undo grouping, use {@link Transformable#ungroup}.\n   * @param  {...ExprList} keys Key column values to group by.\n   *  The keys may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @return {this} A new table with grouped rows.\n   * @example table.groupby('colA', 'colB')\n   * @example table.groupby({ key: d => d.colA + d.colB })\n   */\n  groupby(...keys) {\n    return this.__groupby(this, keys.flat());\n  }\n\n  /**\n   * Order table rows based on a set of column values.\n   * Subsequent operations sensitive to ordering (such as window functions)\n   * will operate over sorted values.\n   * The resulting table provides an view over the original data, without\n   * any copying. To create a table with sorted data copied to new data\n   * strucures, call {@link Transformable#reify} on the result of this method.\n   * To undo ordering, use {@link Transformable#unorder}.\n   * @param  {...OrderKeys} keys Key values to sort by, in precedence order.\n   *  By default, sorting is done in ascending order.\n   *  To sort in descending order, wrap values using {@link desc}.\n   *  If a string, order by the column with that name.\n   *  If a number, order by the column with that index.\n   *  If a function, must be a valid table expression; aggregate functions\n   *  are permitted, but window functions are not.\n   *  If an object, object values must be valid values parameters\n   *  with output column names for keys and table expressions\n   *  for values (the output names will be ignored).\n   *  If an array, array values must be valid key parameters.\n   * @return {this} A new ordered table.\n   * @example table.orderby('a', desc('b'))\n   * @example table.orderby({ a: 'a', b: desc('b') )})\n   * @example table.orderby(desc(d => d.a))\n   */\n  orderby(...keys) {\n    return this.__orderby(this, keys.flat());\n  }\n\n  /**\n   * Relocate a subset of columns to change their positions, also\n   * potentially renaming them.\n   * @param {Selection} columns An ordered selection of columns to relocate.\n   *  The input may consist of column name strings, column integer indices,\n   *  rename objects with current column names as keys and new column names\n   *  as values, or functions that take a table as input and returns a valid\n   *  selection parameter (typically the output of selection helper functions\n   *  such as {@link all}, {@link not}, or {@link range}).\n   * @param {RelocateOptions} options Options for relocating. Must include\n   *  either the before or after property to indicate where to place the\n   *  relocated columns. Specifying both before and after is an error.\n   * @return {this} A new table with relocated columns.\n   * @example table.relocate(['colY', 'colZ'], { after: 'colX' })\n   * @example table.relocate(not('colB', 'colC'), { before: 'colA' })\n   * @example table.relocate({ colA: 'newA', colB: 'newB' }, { after: 'colC' })\n   */\n  relocate(columns, options) {\n    return this.__relocate(this, (0,_util_to_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(columns), options);\n  }\n\n  /**\n   * Rename one or more columns, preserving column order.\n   * @param {...Select} columns One or more rename objects with current\n   *  column names as keys and new column names as values.\n   * @return {this} A new table with renamed columns.\n   * @example table.rename({ oldName: 'newName' })\n   * @example table.rename({ a: 'a2', b: 'b2' })\n   */\n  rename(...columns) {\n    return this.__rename(this, columns.flat());\n  }\n\n  /**\n   * Rollup a table to produce an aggregate summary.\n   * Often used in conjunction with {@link Transformable#groupby}.\n   * To produce counts only, {@link Transformable#count} is a shortcut.\n   * @param {ExprObject} [values] Object of name-value pairs defining aggregate\n   *  output columns. The input object should have output column names for\n   *  keys and table expressions for values. The expressions must be valid\n   *  aggregate expressions: window functions are not allowed and column\n   *  references must be arguments to aggregate functions.\n   * @return {this} A new table of aggregate summary values.\n   * @example table.groupby('colA').rollup({ mean: d => mean(d.colB) })\n   * @example table.groupby('colA').rollup({ mean: op.median('colB') })\n   */\n  rollup(values) {\n    return this.__rollup(this, values);\n  }\n\n  /**\n   * Generate a table from a random sample of rows.\n   * If the table is grouped, performs a stratified sample by\n   * sampling from each group separately.\n   * @param {number|TableExpr} size The number of samples to draw per group.\n   *  If number-valued, the same sample size is used for each group.\n   *  If function-valued, the input should be an aggregate table\n   *  expression compatible with {@link Transformable#rollup}.\n   * @param {SampleOptions} [options] Options for sampling.\n   * @return {this} A new table with sampled rows.\n   * @example table.sample(50)\n   * @example table.sample(100, { replace: true })\n   * @example table.groupby('colA').sample(() => op.floor(0.5 * op.count()))\n   */\n  sample(size, options) {\n    return this.__sample(this, size, options);\n  }\n\n  /**\n   * Select a subset of columns into a new table, potentially renaming them.\n   * @param {...Select} columns An ordered selection of columns.\n   *  The input may consist of column name strings, column integer indices,\n   *  rename objects with current column names as keys and new column names\n   *  as values, or functions that take a table as input and returns a valid\n   *  selection parameter (typically the output of selection helper functions\n   *  such as {@link all}, {@link not}, or {@link range}).\n   * @return {this} A new table of selected columns.\n   * @example table.select('colA', 'colB')\n   * @example table.select(not('colB', 'colC'))\n   * @example table.select({ colA: 'newA', colB: 'newB' })\n   */\n  select(...columns) {\n    return this.__select(this, columns.flat());\n  }\n\n  /**\n   * Ungroup a table, removing any grouping criteria.\n   * Undoes the effects of {@link Transformable#groupby}.\n   * @return {this} A new ungrouped table, or this table if not grouped.\n   * @example table.ungroup()\n   */\n  ungroup() {\n    return this.__ungroup(this);\n  }\n\n  /**\n   * Unorder a table, removing any sorting criteria.\n   * Undoes the effects of {@link Transformable#orderby}.\n   * @return {this} A new unordered table, or this table if not ordered.\n   * @example table.unorder()\n   */\n  unorder() {\n    return this.__unorder(this);\n  }\n\n  // -- Cleaning Verbs ------------------------------------------------------\n\n  /**\n   * De-duplicate table rows by removing repeated row values.\n   * @param {...ExprList} keys Key columns to check for duplicates.\n   *  Two rows are considered duplicates if they have matching values for\n   *  all keys. If keys are unspecified, all columns are used.\n   *  The keys may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @return {this} A new de-duplicated table.\n   * @example table.dedupe()\n   * @example table.dedupe('a', 'b')\n   * @example table.dedupe({ abs: d => op.abs(d.a) })\n   */\n  dedupe(...keys) {\n    return this.__dedupe(this, keys.flat());\n  }\n\n  /**\n   * Impute missing values or rows. Accepts a set of column-expression pairs\n   * and evaluates the expressions to replace any missing (null, undefined,\n   * or NaN) values in the original column.\n   * If the expand option is specified, imputes new rows for missing\n   * combinations of values. All combinations of key values (a full cross\n   * product) are considered for each level of grouping (specified by\n   * {@link Transformable#groupby}). New rows will be added for any combination\n   * of key and groupby values not already contained in the table. For all\n   * non-key and non-group columns the new rows are populated with imputation\n   * values (first argument) if specified, otherwise undefined.\n   * If the expand option is specified, any filter or orderby settings are\n   * removed from the output table, but groupby settings persist.\n   * @param {ExprObject} values Object of name-value pairs for the column values\n   *  to impute. The input object should have existing column names for keys\n   *  and table expressions for values. The expressions will be evaluated to\n   *  determine replacements for any missing values.\n   * @param {ImputeOptions} [options] Imputation options. The expand\n   *  property specifies a set of column values to consider for imputing\n   *  missing rows. All combinations of expanded values are considered, and\n   *  new rows are added for each combination that does not appear in the\n   *  input table.\n   * @return {this} A new table with imputed values and/or rows.\n   * @example table.impute({ v: () => 0 })\n   * @example table.impute({ v: d => op.mean(d.v) })\n   * @example table.impute({ v: () => 0 }, { expand: ['x', 'y'] })\n   */\n  impute(values, options) {\n    return this.__impute(this, values, options);\n  }\n\n  // -- Reshaping Verbs -----------------------------------------------------\n\n  /**\n   * Fold one or more columns into two key-value pair columns.\n   * The fold transform is an inverse of the {@link Transformable#pivot} transform.\n   * The resulting table has two new columns, one containing the column\n   * names (named \"key\") and the other the column values (named \"value\").\n   * The number of output rows equals the original row count multiplied\n   * by the number of folded columns.\n   * @param {ExprList} values The columns to fold.\n   *  The columns may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @param {FoldOptions} [options] Options for folding.\n   * @return {this} A new folded table.\n   * @example table.fold('colA')\n   * @example table.fold(['colA', 'colB'])\n   * @example table.fold(range(5, 8))\n   */\n  fold(values, options) {\n    return this.__fold(this, values, options);\n  }\n\n  /**\n   * Pivot columns into a cross-tabulation.\n   * The pivot transform is an inverse of the {@link Transformable#fold} transform.\n   * The resulting table has new columns for each unique combination\n   * of the provided *keys*, populated with the provided *values*.\n   * The provided *values* must be aggregates, as a single set of keys may\n   * include more than one row. If string-valued, the *any* aggregate is used.\n   * If only one *values* column is defined, the new pivoted columns will\n   * be named using key values directly. Otherwise, input value column names\n   * will be included as a component of the output column names.\n   * @param {ExprList} keys Key values to map to new column names.\n   *  The keys may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @param {ExprList} values Output values for pivoted columns.\n   *  Column references will be wrapped in an *any* aggregate.\n   *  If object-valued, the input object should have output value\n   *  names for keys and aggregate table expressions for values.\n   * @param {PivotOptions} [options] Options for pivoting.\n   * @return {this} A new pivoted table.\n   * @example table.pivot('key', 'value')\n   * @example table.pivot(['keyA', 'keyB'], ['valueA', 'valueB'])\n   * @example table.pivot({ key: d => d.key }, { value: d => sum(d.value) })\n   */\n  pivot(keys, values, options) {\n    return this.__pivot(this, keys, values, options);\n  }\n\n  /**\n   * Spread array elements into a set of new columns.\n   * Output columns are named based on the value key and array index.\n   * @param {ExprList} values The column values to spread.\n   *  The values may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @param {SpreadOptions} [options] Options for spreading.\n   * @return {this} A new table with the spread columns added.\n   * @example table.spread({ a: split(d.text, '') })\n   * @example table.spread('arrayCol', { limit: 100 })\n   */\n  spread(values, options) {\n    return this.__spread(this, values, options);\n  }\n\n  /**\n   * Unroll one or more array-valued columns into new rows.\n   * If more than one array value is used, the number of new rows\n   * is the smaller of the limit and the largest length.\n   * Values for all other columns are copied over.\n   * @param {ExprList} values The column values to unroll.\n   *  The values may be specified using column name strings, column index\n   *  numbers, value objects with output column names for keys and table\n   *  expressions for values, or selection helper functions.\n   * @param {UnrollOptions} [options] Options for unrolling.\n   * @return {this} A new unrolled table.\n   * @example table.unroll('colA', { limit: 1000 })\n   */\n  unroll(values, options) {\n    return this.__unroll(this, values, options);\n  }\n\n  // -- Joins ---------------------------------------------------------------\n\n  /**\n   * Lookup values from a secondary table and add them as new columns.\n   * A lookup occurs upon matching key values for rows in both tables.\n   * If the secondary table has multiple rows with the same key, only\n   * the last observed instance will be considered in the lookup.\n   * Lookup is similar to {@link Transformable#join_left}, but with a simpler\n   * syntax and the added constraint of allowing at most one match only.\n   * @param {TableRef} other The secondary table to look up values from.\n   * @param {JoinKeys} [on] Lookup keys (column name strings or table\n   *  expressions) for this table and the secondary table, respectively.\n   * @param {...ExprList} values The column values to add from the\n   *  secondary table. Can be column name strings or objects with column\n   *  names as keys and table expressions as values.\n   * @return {this} A new table with lookup values added.\n   * @example table.lookup(other, ['key1', 'key2'], 'value1', 'value2')\n   */\n  lookup(other, on, ...values) {\n    return this.__lookup(this, other, on, values.flat());\n  }\n\n  /**\n   * Join two tables, extending the columns of one table with\n   * values from the other table. The current table is considered\n   * the \"left\" table in the join, and the new table input is\n   * considered the \"right\" table in the join. By default an inner\n   * join is performed, removing all rows that do not match the\n   * join criteria. To perform left, right, or full outer joins, use\n   * the {@link Transformable#join_left}, {@link Transformable#join_right}, or\n   * {@link Transformable#join_full} methods, or provide an options argument.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @param {JoinValues} [values] The columns to include in the join output.\n   *  If unspecified, all columns from both tables are included; paired\n   *  join keys sharing the same column name are included only once.\n   *  If array-valued, a two element array should be provided, containing\n   *  the columns to include for the left and right tables, respectively.\n   *  Array input may consist of column name strings, objects with output\n   *  names as keys and single-table table expressions as values, or the\n   *  selection helper functions {@link all}, {@link not}, or {@link range}.\n   *  If object-valued, specifies the key-value pairs for each output,\n   *  defined using two-table table expressions.\n   * @param {JoinOptions} [options] Options for the join.\n   * @return {this} A new joined table.\n   * @example table.join(other, ['keyL', 'keyR'])\n   * @example table.join(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  join(other, on, values, options) {\n    return this.__join(this, other, on, values, options);\n  }\n\n  /**\n   * Perform a left outer join on two tables. Rows in the left table\n   * that do not match a row in the right table will be preserved.\n   * This is a convenience method with fixed options for {@link Transformable#join}.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @param {JoinValues} [values] The columns to include in the join output.\n   *  If unspecified, all columns from both tables are included; paired\n   *  join keys sharing the same column name are included only once.\n   *  If array-valued, a two element array should be provided, containing\n   *  the columns to include for the left and right tables, respectively.\n   *  Array input may consist of column name strings, objects with output\n   *  names as keys and single-table table expressions as values, or the\n   *  selection helper functions {@link all}, {@link not}, or {@link range}.\n   *  If object-valued, specifies the key-value pairs for each output,\n   *  defined using two-table table expressions.\n   * @param {JoinOptions} [options] Options for the join. With this method,\n   *  any options will be overridden with {left: true, right: false}.\n   * @return {this} A new joined table.\n   * @example table.join_left(other, ['keyL', 'keyR'])\n   * @example table.join_left(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  join_left(other, on, values, options) {\n    const opt = { ...options, left: true, right: false };\n    return this.__join(this, other, on, values, opt);\n  }\n\n  /**\n   * Perform a right outer join on two tables. Rows in the right table\n   * that do not match a row in the left table will be preserved.\n   * This is a convenience method with fixed options for {@link Transformable#join}.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @param {JoinValues} [values] The columns to include in the join output.\n   *  If unspecified, all columns from both tables are included; paired\n   *  join keys sharing the same column name are included only once.\n   *  If array-valued, a two element array should be provided, containing\n   *  the columns to include for the left and right tables, respectively.\n   *  Array input may consist of column name strings, objects with output\n   *  names as keys and single-table table expressions as values, or the\n   *  selection helper functions {@link all}, {@link not}, or {@link range}.\n   *  If object-valued, specifies the key-value pairs for each output,\n   *  defined using two-table table expressions.\n   * @param {JoinOptions} [options] Options for the join. With this method,\n   *  any options will be overridden with {left: false, right: true}.\n   * @return {this} A new joined table.\n   * @example table.join_right(other, ['keyL', 'keyR'])\n   * @example table.join_right(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  join_right(other, on, values, options) {\n    const opt = { ...options, left: false, right: true };\n    return this.__join(this, other, on, values, opt);\n  }\n\n  /**\n   * Perform a full outer join on two tables. Rows in either the left or\n   * right table that do not match a row in the other will be preserved.\n   * This is a convenience method with fixed options for {@link Transformable#join}.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @param {JoinValues} [values] The columns to include in the join output.\n   *  If unspecified, all columns from both tables are included; paired\n   *  join keys sharing the same column name are included only once.\n   *  If array-valued, a two element array should be provided, containing\n   *  the columns to include for the left and right tables, respectively.\n   *  Array input may consist of column name strings, objects with output\n   *  names as keys and single-table table expressions as values, or the\n   *  selection helper functions {@link all}, {@link not}, or {@link range}.\n   *  If object-valued, specifies the key-value pairs for each output,\n   *  defined using two-table table expressions.\n   * @param {JoinOptions} [options] Options for the join. With this method,\n   *  any options will be overridden with {left: true, right: true}.\n   * @return {this} A new joined table.\n   * @example table.join_full(other, ['keyL', 'keyR'])\n   * @example table.join_full(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  join_full(other, on, values, options) {\n    const opt = { ...options, left: true, right: true };\n    return this.__join(this, other, on, values, opt);\n  }\n\n  /**\n   * Produce the Cartesian cross product of two tables. The output table\n   * has one row for every pair of input table rows. Beware that outputs\n   * may be quite large, as the number of output rows is the product of\n   * the input row counts.\n   * This is a convenience method for {@link Transformable#join} in which the\n   * join criteria is always true.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinValues} [values] The columns to include in the output.\n   *  If unspecified, all columns from both tables are included.\n   *  If array-valued, a two element array should be provided, containing\n   *  the columns to include for the left and right tables, respectively.\n   *  Array input may consist of column name strings, objects with output\n   *  names as keys and single-table table expressions as values, or the\n   *  selection helper functions {@link all}, {@link not}, or {@link range}.\n   *  If object-valued, specifies the key-value pairs for each output,\n   *  defined using two-table table expressions.\n   * @param {JoinOptions} [options] Options for the join.\n   * @return {this} A new joined table.\n   * @example table.cross(other)\n   * @example table.cross(other, [['leftKey', 'leftVal'], ['rightVal']])\n   */\n  cross(other, values, options) {\n    return this.__cross(this, other, values, options);\n  }\n\n  /**\n   * Perform a semi-join, filtering the left table to only rows that\n   * match a row in the right table.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @return {this} A new filtered table.\n   * @example table.semijoin(other)\n   * @example table.semijoin(other, ['keyL', 'keyR'])\n   * @example table.semijoin(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  semijoin(other, on) {\n    return this.__semijoin(this, other, on);\n  }\n\n  /**\n   * Perform an anti-join, filtering the left table to only rows that\n   * do *not* match a row in the right table.\n   * @param {TableRef} other The other (right) table to join with.\n   * @param {JoinPredicate} [on] The join criteria for matching table rows.\n   *  If unspecified, the values of all columns with matching names\n   *  are compared.\n   *  If array-valued, a two-element array should be provided, containing\n   *  the columns to compare for the left and right tables, respectively.\n   *  If a one-element array or a string value is provided, the same\n   *  column names will be drawn from both tables.\n   *  If function-valued, should be a two-table table expression that\n   *  returns a boolean value. When providing a custom predicate, note that\n   *  join key values can be arrays or objects, and that normal join\n   *  semantics do not consider null or undefined values to be equal (that is,\n   *  null !== null). Use the op.equal function to handle these cases.\n   * @return {this} A new filtered table.\n   * @example table.antijoin(other)\n   * @example table.antijoin(other, ['keyL', 'keyR'])\n   * @example table.antijoin(other, (a, b) => equal(a.keyL, b.keyR))\n   */\n  antijoin(other, on) {\n    return this.__antijoin(this, other, on);\n  }\n\n  // -- Set Operations ------------------------------------------------------\n\n  /**\n   * Concatenate multiple tables into a single table, preserving all rows.\n   * This transformation mirrors the UNION_ALL operation in SQL.\n   * Only named columns in this table are included in the output.\n   * @see Transformable#union\n   * @param  {...TableRef} tables A list of tables to concatenate.\n   * @return {this} A new concatenated table.\n   * @example table.concat(other)\n   * @example table.concat(other1, other2)\n   * @example table.concat([other1, other2])\n   */\n  concat(...tables) {\n    return this.__concat(this, tables.flat());\n  }\n\n  /**\n   * Union multiple tables into a single table, deduplicating all rows.\n   * This transformation mirrors the UNION operation in SQL. It is\n   * similar to {@link Transformable#concat} but suppresses duplicate rows with\n   * values identical to another row.\n   * Only named columns in this table are included in the output.\n   * @see Transformable#concat\n   * @param  {...TableRef} tables A list of tables to union.\n   * @return {this} A new unioned table.\n   * @example table.union(other)\n   * @example table.union(other1, other2)\n   * @example table.union([other1, other2])\n   */\n  union(...tables) {\n    return this.__union(this, tables.flat());\n  }\n\n  /**\n   * Intersect multiple tables, keeping only rows whose with identical\n   * values for all columns in all tables, and deduplicates the rows.\n   * This transformation is similar to a series of {@link Transformable#semijoin}\n   * calls, but additionally suppresses duplicate rows.\n   * @see Transformable#semijoin\n   * @param  {...TableRef} tables A list of tables to intersect.\n   * @return {this} A new filtered table.\n   * @example table.intersect(other)\n   * @example table.intersect(other1, other2)\n   * @example table.intersect([other1, other2])\n   */\n  intersect(...tables) {\n    return this.__intersect(this, tables.flat());\n  }\n\n  /**\n   * Compute the set difference with multiple tables, keeping only rows in\n   * this table that whose values do not occur in the other tables.\n   * This transformation is similar to a series of {@link Transformable#antijoin}\n   * calls, but additionally suppresses duplicate rows.\n   * @see Transformable#antijoin\n   * @param  {...TableRef} tables A list of tables to difference.\n   * @return {this} A new filtered table.\n   * @example table.except(other)\n   * @example table.except(other1, other2)\n   * @example table.except([other1, other2])\n   */\n  except(...tables) {\n    return this.__except(this, tables.flat());\n  }\n}\n\n// -- Parameter Types -------------------------------------------------------\n\n/**\n * Table expression parameters.\n * @typedef {Object.<string, *>} Params\n */\n\n/**\n * A reference to a column by string name or integer index.\n * @typedef {string|number} ColumnRef\n */\n\n/**\n * A value that can be coerced to a string.\n * @typedef {object} Stringable\n * @property {() => string} toString String coercion method.\n */\n\n/**\n * A table expression provided as a string or string-coercible value.\n * @typedef {string|Stringable} TableExprString\n */\n\n/**\n * A struct object with arbitraty named properties.\n * @typedef {Object.<string, *>} Struct\n */\n\n/**\n * A function defined over a table row.\n * @typedef {(d?: Struct, $?: Params) => any} TableExprFunc\n */\n\n/**\n * A table expression defined over a single table.\n * @typedef {TableExprFunc|TableExprString} TableExpr\n */\n\n/**\n * A function defined over rows from two tables.\n * @typedef {(a?: Struct, b?: Struct, $?: Params) => any} TableFunc2\n */\n\n/**\n * A table expression defined over two tables.\n * @typedef {TableExprFunc2|TableExprString} TableExpr2\n */\n\n/**\n * An object that maps current column names to new column names.\n * @typedef {{ [name: string]: string }} RenameMap\n */\n\n/**\n * A selection helper function.\n * @typedef {(table: any) => string[]} SelectHelper\n */\n\n/**\n * One or more column selections, potentially with renaming.\n * The input may consist of a column name string, column integer index, a\n * rename map object with current column names as keys and new column names\n * as values, or a select helper function that takes a table as input and\n * returns a valid selection parameter.\n * @typedef {ColumnRef|RenameMap|SelectHelper} SelectEntry\n */\n\n/**\n * An ordered set of column selections, potentially with renaming.\n * @typedef {SelectEntry|SelectEntry[]} Select\n */\n\n/**\n * An object of column name / table expression pairs.\n * @typedef {{ [name: string]: TableExpr }} ExprObject\n */\n\n/**\n * An object of column name / two-table expression pairs.\n * @typedef {{ [name: string]: TableExpr2 }} Expr2Object\n */\n\n/**\n * An ordered set of one or more column values.\n * @typedef {ColumnRef|SelectHelper|ExprObject} ListEntry\n */\n\n/**\n * An ordered set of column values.\n * Entries may be column name strings, column index numbers, value objects\n * with output column names for keys and table expressions for values,\n * or a selection helper function.\n * @typedef {ListEntry|ListEntry[]} ExprList\n */\n\n/**\n * A reference to a data table or transformable instance.\n * @typedef {Transformable|string} TableRef\n */\n\n/**\n * One or more orderby sort criteria.\n * If a string, order by the column with that name.\n * If a number, order by the column with that index.\n * If a function, must be a valid table expression; aggregate functions\n *  are permitted, but window functions are not.\n * If an object, object values must be valid values parameters\n *  with output column names for keys and table expressions\n *  for values. The output name keys will subsequently be ignored.\n * @typedef {ColumnRef|TableExpr|ExprObject} OrderKey\n */\n\n/**\n * An ordered set of orderby sort criteria, in precedence order.\n * @typedef {OrderKey|OrderKey[]} OrderKeys\n */\n\n/**\n * Column values to use as a join key.\n * @typedef {ColumnRef|TableExprFunc} JoinKey\n */\n\n/**\n * An ordered set of join keys.\n * @typedef {JoinKey|[JoinKey[]]|[JoinKey[], JoinKey[]]} JoinKeys\n */\n\n/**\n * A predicate specification for joining two tables.\n * @typedef {JoinKeys|TableExprFunc2|null} JoinPredicate\n */\n\n/**\n * An array of per-table join values to extract.\n * @typedef {[ExprList]|[ExprList, ExprList]|[ExprList, ExprList, Expr2Object]} JoinList\n */\n\n/**\n * A specification of join values to extract.\n * @typedef {JoinList|Expr2Object} JoinValues\n */\n\n// -- Transform Options -----------------------------------------------------\n\n/**\n * Options for count transformations.\n * @typedef {object} CountOptions\n * @property {string} [as='count'] The name of the output count column.\n */\n\n/**\n * Options for derive transformations.\n * @typedef {object} DeriveOptions\n * @property {boolean} [drop=false] A flag indicating if the original\n *  columns should be dropped, leaving only the derived columns. If true,\n *  the before and after options are ignored.\n * @property {Select} [before]\n *  An anchor column that relocated columns should be placed before.\n *  The value can be any legal column selection. If multiple columns are\n *  selected, only the first column will be used as an anchor.\n *  It is an error to specify both before and after options.\n * @property {Select} [after]\n *  An anchor column that relocated columns should be placed after.\n *  The value can be any legal column selection. If multiple columns are\n *  selected, only the last column will be used as an anchor.\n *  It is an error to specify both before and after options.\n */\n\n/**\n * Options for relocate transformations.\n * @typedef {object} RelocateOptions\n * @property {Selection} [before]\n *  An anchor column that relocated columns should be placed before.\n *  The value can be any legal column selection. If multiple columns are\n *  selected, only the first column will be used as an anchor.\n *  It is an error to specify both before and after options.\n * @property {Selection} [after]\n *  An anchor column that relocated columns should be placed after.\n *  The value can be any legal column selection. If multiple columns are\n *  selected, only the last column will be used as an anchor.\n *  It is an error to specify both before and after options.\n */\n\n/**\n * Options for sample transformations.\n * @typedef {object} SampleOptions\n * @property {boolean} [replace=false] Flag for sampling with replacement.\n * @property {boolean} [shuffle=true] Flag to ensure randomly ordered rows.\n * @property {string|TableExprFunc} [weight] Column values to use as weights\n *  for sampling. Rows will be sampled with probability proportional to\n *  their relative weight. The input should be a column name string or\n *  a table expression compatible with {@link Transformable#derive}.\n */\n\n/**\n * Options for impute transformations.\n * @typedef {object} ImputeOptions\n * @property {ExprList} [expand] Column values to combine to impute missing\n *  rows. For column names and indices, all unique column values are\n *  considered. Otherwise, each entry should be an object of name-expresion\n *  pairs, with valid table expressions for {@link Transformable#rollup}.\n *  All combinations of values are checked for each set of unique groupby\n *  values.\n */\n\n/**\n * Options for fold transformations.\n * @typedef {object} FoldOptions\n * @property {string[]} [as=['key', 'value']] An array indicating the\n *  output column names to use for the key and value columns, respectively.\n */\n\n/**\n * Options for pivot transformations.\n * @typedef {object} PivotOptions\n * @property {number} [limit=Infinity] The maximum number of new columns to generate.\n * @property {string} [keySeparator='_'] A string to place between multiple key names.\n * @property {string} [valueSeparator='_'] A string to place between key and value names.\n * @property {boolean} [sort=true] Flag for alphabetical sorting of new column names.\n */\n\n/**\n * Options for spread transformations.\n * @typedef {object} SpreadOptions\n * @property {boolean} [drop=true] Flag indicating if input columns to the\n *  spread operation should be dropped in the output table.\n * @property {number} [limit=Infinity] The maximum number of new columns to\n *  generate.\n * @property {string[]} [as] Output column names to use. This option only\n *  applies when a single column is spread. If the given array of names is\n *  shorter than the number of generated columns and no limit option is\n *  specified, the additional generated columns will be dropped.\n */\n\n/**\n * Options for unroll transformations.\n * @typedef {object} UnrollOptions\n * @property {number} [limit=Infinity] The maximum number of new rows\n *  to generate per array value.\n * @property {boolean|string} [index=false] Flag or column name for adding\n *  zero-based array index values as an output column. If true, a new column\n *  named \"index\" will be included. If string-valued, a new column with\n *  the given name will be added.\n * @property {Select} [drop] Columns to drop from the output. The input may\n *  consist of column name strings, column integer indices, objects with\n *  column names as keys, or functions that take a table as input and\n *  return a valid selection parameter (typically the output of selection\n *  helper functions such as {@link all}, {@link not}, or {@link range}).\n */\n\n/**\n * Options for join transformations.\n * @typedef {object} JoinOptions\n * @property {boolean} [left=false] Flag indicating a left outer join.\n *  If both the *left* and *right* are true, indicates a full outer join.\n * @property {boolean} [right=false] Flag indicating a right outer join.\n *  If both the *left* and *right* are true, indicates a full outer join.\n * @property {string[]} [suffix=['_1', '_2']] Column name suffixes to\n *  append if two columns with the same name are produced by the join.\n */\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/table/transformable.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/array-type.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/util/array-type.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_typed_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-typed-array */ \"../../node_modules/arquero/src/util/is-typed-array.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(column) {\n  return (0,_is_typed_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(column.data) ? column.data.constructor : Array;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/array-type.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/ascending.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/ascending.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  return a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/ascending.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/assign.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/assign.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _entries__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./entries */ \"../../node_modules/arquero/src/util/entries.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(map, pairs) {\n  for (const [key, value] of (0,_entries__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(pairs)) {\n    map.set(key, value);\n  }\n  return map;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/assign.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/bins.js":
/*!***************************************************!*\
  !*** ../../node_modules/arquero/src/util/bins.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(min, max, maxbins = 15, nice = true, minstep = 0, step) {\n  const base = 10;\n  const logb = Math.LN10;\n\n  if (step == null) {\n    const level = Math.ceil(Math.log(maxbins) / logb);\n    const span = (max - min) || Math.abs(min) || 1;\n    const div = [5, 2];\n\n    step = Math.max(\n      minstep,\n      Math.pow(base, Math.round(Math.log(span) / logb) - level)\n    );\n\n    // increase step size if too many bins\n    while (Math.ceil(span / step) > maxbins) {\n      step *= base;\n    }\n\n    // decrease step size if it stays within maxbins\n    const n = div.length;\n    for (let i = 0; i < n; ++i) {\n      const v = step / div[i];\n      if (v >= minstep && span / v <= maxbins) {\n        step = v;\n      }\n    }\n  }\n\n  // snap to \"nice\" boundaries\n  if (nice) {\n    let v = Math.log(step);\n    const precision = v >= 0 ? 0 : ~~(-v / logb) + 1;\n    const eps = Math.pow(base, -precision - 1);\n    v = Math.floor(min / step + eps) * step;\n    min = min < v ? v - step : v;\n    max = Math.ceil(max / step) * step;\n  }\n\n  return [\n    min,\n    max === min ? min + step : max,\n    step\n  ];\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/bins.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/bisector.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/bisector.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(compare) {\n  return {\n    left(a, x, lo, hi) {\n      if (lo == null) lo = 0;\n      if (hi == null) hi = a.length;\n      while (lo < hi) {\n        const mid = lo + hi >>> 1;\n        if (compare(a[mid], x) < 0) lo = mid + 1;\n        else hi = mid;\n      }\n      return lo;\n    },\n    right(a, x, lo, hi) {\n      if (lo == null) lo = 0;\n      if (hi == null) hi = a.length;\n      while (lo < hi) {\n        const mid = lo + hi >>> 1;\n        if (compare(a[mid], x) > 0) hi = mid;\n        else lo = mid + 1;\n      }\n      return lo;\n    }\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/bisector.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/concat.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/concat.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(list, fn = (x => x), delim = '') {\n  const n = list.length;\n  if (!n) return '';\n\n  let s = fn(list[0], 0);\n  for (let i = 1; i < n; ++i) {\n    s += delim + fn(list[i], i);\n  }\n\n  return s;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/concat.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/default-true.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/util/default-true.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, trueValue = true, falseValue = false) {\n  return (value === undefined || value) ? trueValue : falseValue;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/default-true.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/distinct-map.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/util/distinct-map.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _key_function__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./key-function */ \"../../node_modules/arquero/src/util/key-function.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  const map = new Map();\n  return {\n    count() {\n      return map.size;\n    },\n    values() {\n      return Array.from(map.values(), _ => _.v);\n    },\n    increment(v) {\n      const k = (0,_key_function__WEBPACK_IMPORTED_MODULE_0__.key)(v);\n      const e = map.get(k);\n      e ? ++e.n : map.set(k, { v, n: 1 });\n    },\n    decrement(v) {\n      const k = (0,_key_function__WEBPACK_IMPORTED_MODULE_0__.key)(v);\n      const e = map.get(k);\n      e.n === 1 ? map.delete(k) : --e.n;\n    },\n    forEach(fn) {\n      map.forEach(({ v, n }) => fn(v, n));\n    }\n  };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/distinct-map.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/entries.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/util/entries.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _is_map__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is-map */ \"../../node_modules/arquero/src/util/is-map.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return (0,_is_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) ? value\n    : (0,_is_map__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value) ? value.entries()\n    : value ? Object.entries(value)\n    : [];\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/entries.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/error.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/util/error.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(message) {\n  throw Error(message);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/error.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/escape-regexp.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/util/escape-regexp.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(str) {\n  return str.replace(/[.*+\\-?^${}()|[\\]\\\\]/g, '\\\\$&');\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/escape-regexp.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/format-date.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/util/format-date.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   formatDate: () => (/* binding */ formatDate),\n/* harmony export */   formatISO: () => (/* binding */ formatISO),\n/* harmony export */   formatUTCDate: () => (/* binding */ formatUTCDate)\n/* harmony export */ });\n/* harmony import */ var _pad__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./pad */ \"../../node_modules/arquero/src/util/pad.js\");\n\n\nconst pad2 = v => (v < 10 ? '0' : '') + v;\n\nconst formatYear = year => year < 0 ? '-' + (0,_pad__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(-year, 6)\n  : year > 9999 ? '+' + (0,_pad__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(year, 6)\n  : (0,_pad__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(year, 4);\n\nfunction formatISO(year, month, date, hours, min, sec, ms, utc, short) {\n  const suffix = utc ? 'Z' : '';\n  return formatYear(year) + '-' + pad2(month + 1) + '-' + pad2(date) + (\n    !short || ms ? 'T' + pad2(hours) + ':' + pad2(min) + ':' + pad2(sec) + '.' + (0,_pad__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(ms, 3) + suffix\n    : sec ? 'T' + pad2(hours) + ':' + pad2(min) + ':' + pad2(sec) + suffix\n    : min || hours || !utc ? 'T' + pad2(hours) + ':' + pad2(min) + suffix\n    : ''\n  );\n}\n\nfunction formatDate(d, short) {\n  return isNaN(d)\n    ? 'Invalid Date'\n    : formatISO(\n      d.getFullYear(),\n      d.getMonth(),\n      d.getDate(),\n      d.getHours(),\n      d.getMinutes(),\n      d.getSeconds(),\n      d.getMilliseconds(),\n      false, short\n    );\n}\n\nfunction formatUTCDate(d, short) {\n  return isNaN(d)\n    ? 'Invalid Date'\n    : formatISO(\n      d.getUTCFullYear(),\n      d.getUTCMonth(),\n      d.getUTCDate(),\n      d.getUTCHours(),\n      d.getUTCMinutes(),\n      d.getUTCSeconds(),\n      d.getUTCMilliseconds(),\n      true, short\n    );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/format-date.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/has.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/util/has.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nconst { hasOwnProperty } = Object.prototype;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(object, property) {\n  return hasOwnProperty.call(object, property);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/has.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/identity.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/identity.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (x => x);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/identity.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/intersect.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/intersect.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ intersect)\n/* harmony export */ });\nfunction intersect(a, b) {\n  const set = new Set(b);\n  return a.filter(x => set.has(x));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/intersect.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-array-type.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-array-type.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ isArrayType)\n/* harmony export */ });\n/* harmony import */ var _is_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _is_typed_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is-typed-array */ \"../../node_modules/arquero/src/util/is-typed-array.js\");\n\n\n\nfunction isArrayType(value) {\n  return (0,_is_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) || (0,_is_typed_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-array-type.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-array.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-array.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Array.isArray);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-array.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-bigint.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-bigint.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return typeof value === 'bigint';\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-bigint.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-date.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-date.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value instanceof Date;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-date.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-digit-string.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-digit-string.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  const n = value.length;\n  for (let i = 0; i < n; ++i) {\n    const c = value.charCodeAt(i);\n    if (c < 48 || c > 57) return false;\n  }\n  return true;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-digit-string.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-exact-utc-date.js":
/*!****************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-exact-utc-date.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(d) {\n  return d.getUTCHours() === 0\n    && d.getUTCMinutes() === 0\n    && d.getUTCSeconds() === 0\n    && d.getUTCMilliseconds() === 0;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-exact-utc-date.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-function.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-function.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return typeof value === 'function';\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-function.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-iso-date-string.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-iso-date-string.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nconst iso_re = /^([-+]\\d{2})?\\d{4}(-\\d{2}(-\\d{2})?)?(T\\d{2}:\\d{2}(:\\d{2}(\\.\\d{3})?)?(Z|[-+]\\d{2}:\\d{2})?)?$/;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value.match(iso_re);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-iso-date-string.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-map-or-set.js":
/*!************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-map-or-set.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_map__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-map */ \"../../node_modules/arquero/src/util/is-map.js\");\n/* harmony import */ var _is_set__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is-set */ \"../../node_modules/arquero/src/util/is-set.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return (0,_is_map__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) || (0,_is_set__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-map-or-set.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-map.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-map.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value instanceof Map;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-map.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-number.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-number.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return typeof value === 'number';\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-number.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-object.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-object.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value === Object(value);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-object.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-regexp.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-regexp.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value instanceof RegExp;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-regexp.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-set.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-set.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value instanceof Set;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-set.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-string.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-string.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return typeof value === 'string';\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-string.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-typed-array.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-typed-array.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nconst TypedArray = Object.getPrototypeOf(Int8Array);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value instanceof TypedArray;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-typed-array.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/is-valid.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/is-valid.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value != null && value === value;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/is-valid.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/key-function.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/util/key-function.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   key: () => (/* binding */ key)\n/* harmony export */ });\n/* harmony import */ var _is_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _is_date__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is-date */ \"../../node_modules/arquero/src/util/is-date.js\");\n/* harmony import */ var _is_regexp__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./is-regexp */ \"../../node_modules/arquero/src/util/is-regexp.js\");\n/* harmony import */ var _is_typed_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./is-typed-array */ \"../../node_modules/arquero/src/util/is-typed-array.js\");\n\n\n\n\n\nfunction key(value) {\n  const type = typeof value;\n  return type === 'string' ? `\"${value}\"`\n    : type !== 'object' || !value ? value\n    : (0,_is_date__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(value) ? +value\n    : (0,_is_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) || (0,_is_typed_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(value) ? `[${value.map(key)}]`\n    : (0,_is_regexp__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(value) ? value + ''\n    : objectKey(value);\n}\n\nfunction objectKey(value) {\n  let s = '{';\n  let i = -1;\n  for (const k in value) {\n    if (++i > 0) s += ',';\n    s += `\"${k}\":${key(value[k])}`;\n  }\n  s += '}';\n  return s;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(get, nulls) {\n  const n = get.length;\n  return n === 1\n    ? (row, data) => key(get[0](row, data))\n    : (row, data) => {\n        let s = '';\n        for (let i = 0; i < n; ++i) {\n          if (i > 0) s += '|';\n          const v = get[i](row, data);\n          if (nulls && (v == null || v !== v)) return null;\n          s += key(v);\n        }\n        return s;\n      };\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/key-function.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/map-object.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/util/map-object.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(obj, fn, output = {}) {\n  for (const key in obj) {\n    output[key] = fn(obj[key], key);\n  }\n  return output;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/map-object.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/max.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/util/max.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _null__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./null */ \"../../node_modules/arquero/src/util/null.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values, start = 0, stop = values.length) {\n  let max = stop ? values[start++] : _null__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n\n  for (let i = start; i < stop; ++i) {\n    if (max < values[i]) {\n      max = values[i];\n    }\n  }\n\n  return max;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/max.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/min.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/util/min.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _null__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./null */ \"../../node_modules/arquero/src/util/null.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values, start = 0, stop = values.length) {\n  let min = stop ? values[start++] : _null__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n\n  for (let i = start; i < stop; ++i) {\n    if (min > values[i]) {\n      min = values[i];\n    }\n  }\n\n  return min;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/min.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/no-op.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/util/no-op.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/no-op.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/null.js":
/*!***************************************************!*\
  !*** ../../node_modules/arquero/src/util/null.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/**\n * Default NULL (missing) value to use.\n */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (undefined);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/null.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/pad.js":
/*!**************************************************!*\
  !*** ../../node_modules/arquero/src/util/pad.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, width, char = '0') {\n  const s = value + '';\n  const len = s.length;\n  return len < width ? Array(width - len + 1).join(char) + s : s;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/pad.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/parse-iso-date.js":
/*!*************************************************************!*\
  !*** ../../node_modules/arquero/src/util/parse-iso-date.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_iso_date_string__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-iso-date-string */ \"../../node_modules/arquero/src/util/is-iso-date-string.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value, parse = Date.parse) {\n  return (0,_is_iso_date_string__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) ? parse(value) : value;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/parse-iso-date.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/parse-values.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/util/parse-values.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _identity__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity */ \"../../node_modules/arquero/src/util/identity.js\");\n/* harmony import */ var _is_iso_date_string__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is-iso-date-string */ \"../../node_modules/arquero/src/util/is-iso-date-string.js\");\n\n\n\nconst parseBoolean = [ // boolean\n  v => (v === 'true') || (v === 'false'),\n  v => v === 'false' ? false : true\n];\n\nconst parseNumber = [ // number\n  v => v === 'NaN' || (v = +v) === v,\n  v => +v\n];\n\nconst parseDate = [ // iso date\n  _is_iso_date_string__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  v => new Date(Date.parse(v))\n];\n\nfunction numberParser(options) {\n  const { decimal } = options;\n  return decimal && decimal !== '.'\n    ? parseNumber.map(f => s => f(s && s.replace(decimal, '.')))\n    : parseNumber;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values, options) {\n  const types = [parseBoolean, numberParser(options), parseDate];\n  const n = types.length;\n  for (let i = 0; i < n; ++i) {\n    const [test, parser] = types[i];\n    if (check(values, test)) {\n      return parser;\n    }\n  }\n  return _identity__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n}\n\nfunction check(values, test) {\n  const n = values.length;\n  for (let i = 0; i < n; ++i) {\n    const v = values[i];\n    if (v != null && !test(v)) {\n      return false;\n    }\n  }\n  return true;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/parse-values.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/product.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/util/product.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values, start = 0, stop = values.length) {\n  let prod = values[start++];\n\n  for (let i = start; i < stop; ++i) {\n    prod *= values[i];\n  }\n\n  return prod;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/product.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/quantile.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/quantile.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quantile)\n/* harmony export */ });\n/* harmony import */ var _is_bigint__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-bigint */ \"../../node_modules/arquero/src/util/is-bigint.js\");\n/* harmony import */ var _null__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./null */ \"../../node_modules/arquero/src/util/null.js\");\n/* harmony import */ var _to_numeric__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./to-numeric */ \"../../node_modules/arquero/src/util/to-numeric.js\");\n\n\n\n\nfunction quantile(values, p) {\n  const n = values.length;\n\n  if (!n) return _null__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n  if ((p = +p) <= 0 || n < 2) return (0,_to_numeric__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values[0]);\n  if (p >= 1) return (0,_to_numeric__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values[n - 1]);\n\n  const i = (n - 1) * p;\n  const i0 = Math.floor(i);\n  const v0 = (0,_to_numeric__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values[i0]);\n  return (0,_is_bigint__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(v0)\n    ? v0\n    : v0 + ((0,_to_numeric__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values[i0 + 1]) - v0) * (i - i0);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/quantile.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/random.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/random.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   random: () => (/* binding */ random),\n/* harmony export */   seed: () => (/* binding */ seed)\n/* harmony export */ });\n/* harmony import */ var _is_valid__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-valid */ \"../../node_modules/arquero/src/util/is-valid.js\");\n\n\nlet source = Math.random;\n\nfunction random() {\n  return source();\n}\n\n/**\n * Set a seed value for random number generation.\n * If the seed is a valid number, a 32-bit linear congruential generator\n * with the given seed will be used to generate random values.\n * If the seed is null, undefined, or not a valid number, the random\n * number generator will revert to Math.random.\n * @param {number} seed The random seed value. Should either be an\n *  integer or a fraction between 0 and 1.\n */\nfunction seed(seed) {\n  source = (0,_is_valid__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(seed) && isFinite(seed = +seed) ? lcg(seed) : Math.random;\n}\n\nfunction lcg(seed) {\n  const a = 0x19660D;\n  const c = 0x3C6EF35F;\n  const m = 1 / 0x100000000;\n  seed = (0 <= seed && seed < 1 ? seed / m : Math.abs(seed)) | 0;\n\n  // Random numbers using a Linear Congruential Generator with seed value\n  // https://en.wikipedia.org/wiki/Linear_congruential_generator\n  return () => (seed = a * seed + c | 0, m * (seed >>> 0));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/random.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/repeat.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/repeat.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_function__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(reps, value) {\n  const result = Array(reps);\n  if ((0,_is_function__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value)) {\n    for (let i = 0; i < reps; ++i) {\n      result[i] = value(i);\n    }\n  } else {\n    result.fill(value);\n  }\n  return result;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/repeat.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/sample.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/sample.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _ascending__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ascending */ \"../../node_modules/arquero/src/util/ascending.js\");\n/* harmony import */ var _bisector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./bisector */ \"../../node_modules/arquero/src/util/bisector.js\");\n/* harmony import */ var _random__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./random */ \"../../node_modules/arquero/src/util/random.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(buffer, replace, index, weight) {\n  return (\n    replace\n      ? (weight ? sampleRW : sampleRU)\n      : (weight ? sampleNW : sampleNU)\n  )(buffer.length, buffer, index, weight);\n}\n\n// uniform sampling with replacement\n// uses straightforward uniform sampling\nfunction sampleRU(size, buffer, index) {\n  const n = index.length;\n  for (let i = 0; i < size; ++i) {\n    buffer[i] = index[(n * (0,_random__WEBPACK_IMPORTED_MODULE_2__.random)()) | 0];\n  }\n  return buffer;\n}\n\n// weighted sampling with replacement\n// uses binary search lookup against cumulative weight\nfunction sampleRW(size, buffer, index, weight) {\n  const n = index.length;\n  const w = new Float64Array(n);\n\n  let sum = 0;\n  for (let i = 0; i < n; ++i) {\n    w[i] = (sum += weight(index[i]));\n  }\n\n  const bisect = (0,_bisector__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(_ascending__WEBPACK_IMPORTED_MODULE_0__[\"default\"]).right;\n  for (let i = 0; i < size; ++i) {\n    buffer[i] = index[bisect(w, sum * (0,_random__WEBPACK_IMPORTED_MODULE_2__.random)())];\n  }\n  return buffer;\n}\n\n// uniform sampling without replacement\n// uses reservoir sampling to build out the sample\n// https://en.wikipedia.org/wiki/Reservoir_sampling\nfunction sampleNU(size, buffer, index) {\n  const n = index.length;\n  if (size >= n) return index;\n\n  for (let i = 0; i < size; ++i) {\n    buffer[i] = index[i];\n  }\n\n  for (let i = size; i < n; ++i) {\n    const j = i * (0,_random__WEBPACK_IMPORTED_MODULE_2__.random)();\n    if (j < size) {\n      buffer[j | 0] = index[i];\n    }\n  }\n\n  return buffer;\n}\n\n// weighted sample without replacement\n// uses method of Efraimidis and Spirakis\n// TODO: could use min-heap to improve efficiency\nfunction sampleNW(size, buffer, index, weight) {\n  const n = index.length;\n  if (size >= n) return index;\n\n  const w = new Float32Array(n);\n  const k = new Uint32Array(n);\n  for (let i = 0; i < n; ++i) {\n    k[i] = i;\n    w[i] = -Math.log((0,_random__WEBPACK_IMPORTED_MODULE_2__.random)()) / weight(index[i]);\n  }\n\n  k.sort((a, b) => w[a] - w[b]);\n  for (let i = 0; i < size; ++i) {\n    buffer[i] = index[k[i]];\n  }\n  return buffer;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/sample.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/shuffle.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/util/shuffle.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _random__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./random */ \"../../node_modules/arquero/src/util/random.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(array, lo = 0, hi = array.length) {\n  let n = hi - (lo = +lo);\n\n  while (n) {\n    const i = (0,_random__WEBPACK_IMPORTED_MODULE_0__.random)() * n-- | 0;\n    const v = array[n + lo];\n    array[n + lo] = array[i + lo];\n    array[i + lo] = v;\n  }\n\n  return array;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/shuffle.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/to-array.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/util/to-array.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return value != null\n    ? ((0,_is_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) ? value : [value])\n    : [];\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/to-array.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/to-function.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/util/to-function.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_function__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return (0,_is_function__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) ? value : () => value;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/to-function.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/to-numeric.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/util/to-numeric.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_bigint__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-bigint */ \"../../node_modules/arquero/src/util/is-bigint.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return (0,_is_bigint__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) ? value : +value;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/to-numeric.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/to-string.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/util/to-string.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_bigint__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-bigint */ \"../../node_modules/arquero/src/util/is-bigint.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(v) {\n  return v === undefined ? v + ''\n    : (0,_is_bigint__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(v) ? v + 'n'\n    : JSON.stringify(v);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/to-string.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/unique-name.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/util/unique-name.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _is_map_or_set__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./is-map-or-set */ \"../../node_modules/arquero/src/util/is-map-or-set.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(names, name) {\n  names = (0,_is_map_or_set__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(names) ? names : new Set(names);\n  let uname = name;\n  let index = 0;\n\n  while (names.has(uname)) {\n    uname = name + ++index;\n  }\n\n  return uname;\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/unique-name.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/unroll.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/util/unroll.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(args, code, ...lists) {\n  const v = ['_', '$'];\n  const a = v.slice(0, lists.length);\n  a.push('\"use strict\"; const '\n    + lists\n        .map((l, j) => l.map((_, i) => `${v[j]}${i} = ${v[j]}[${i}]`).join(', '))\n        .join(', ')\n    + `; return (${args}) => ${code};`\n  );\n  return Function(...a)(...lists);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/unroll.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/util/value-list.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/util/value-list.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ValueList)\n/* harmony export */ });\n/* harmony import */ var _ascending__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ascending */ \"../../node_modules/arquero/src/util/ascending.js\");\n/* harmony import */ var _min__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./min */ \"../../node_modules/arquero/src/util/min.js\");\n/* harmony import */ var _max__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./max */ \"../../node_modules/arquero/src/util/max.js\");\n/* harmony import */ var _quantile__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./quantile */ \"../../node_modules/arquero/src/util/quantile.js\");\n\n\n\n\n\nclass ValueList {\n  constructor(values) {\n    this._values = values || [];\n    this._sorted = null;\n    this._start = 0;\n  }\n\n  values(copy) {\n    if (this._start) {\n      this._values = this._values.slice(this._start);\n      this._start = 0;\n    }\n    return copy\n      ? this._values.slice()\n      : this._values;\n  }\n\n  add(value) {\n    this._values.push(value);\n    this._sorted = null;\n  }\n\n  rem() {\n    this._start += 1;\n    this._sorted = null;\n  }\n\n  min() {\n    return this._sorted && this._sorted.length\n      ? this._sorted[0]\n      : (0,_min__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(this._values, this._start);\n  }\n\n  max() {\n    return this._sorted && this._sorted.length\n      ? this._sorted[this._sorted.length - 1]\n      : (0,_max__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(this._values, this._start);\n  }\n\n  quantile(p) {\n    if (!this._sorted) {\n      this._sorted = this.values(true);\n      this._sorted.sort(_ascending__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n    }\n    return (0,_quantile__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(this._sorted, p);\n  }\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/util/value-list.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/dedupe.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/dedupe.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, keys = []) {\n  return table\n    .groupby(keys.length ? keys : table.columnNames())\n    .filter('row_number() === 1')\n    .ungroup()\n    .reify();\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/dedupe.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/derive.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/derive.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _relocate__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./relocate */ \"../../node_modules/arquero/src/verbs/relocate.js\");\n/* harmony import */ var _engine_derive__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../engine/derive */ \"../../node_modules/arquero/src/engine/derive.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, options = {}) {\n  const dt = (0,_engine_derive__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, (0,_expression_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values, { table }), options);\n\n  return options.drop || (options.before == null && options.after == null)\n    ? dt\n    : (0,_relocate__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(dt,\n        Object.keys(values).filter(name => !table.column(name)),\n        options\n      );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/derive.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/except.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/except.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, others) {\n  if (others.length === 0) return table;\n  const names = table.columnNames();\n  return others.reduce((a, b) => a.antijoin(b.select(names)), table).dedupe();\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/except.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/filter.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/filter.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_derive__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/derive */ \"../../node_modules/arquero/src/engine/derive.js\");\n/* harmony import */ var _engine_filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../engine/filter */ \"../../node_modules/arquero/src/engine/filter.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, criteria) {\n  const test = (0,_expression_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])({ p: criteria }, { table });\n  let predicate = test.exprs[0];\n  if (test.ops.length) {\n    const { data } = (0,_engine_derive__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, test, { drop: true }).column('p');\n    predicate = row => data[row];\n  }\n  return (0,_engine_filter__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, predicate);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/filter.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/fold.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/fold.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_fold__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/fold */ \"../../node_modules/arquero/src/engine/fold.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, options) {\n  return (0,_engine_fold__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_util_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('fold', table, values), options);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/fold.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/groupby.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/groupby.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_groupby__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/groupby */ \"../../node_modules/arquero/src/engine/groupby.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values) {\n  return (0,_engine_groupby__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_util_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('groupby', table, values));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/groupby.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/helpers/agg.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/helpers/agg.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ agg)\n/* harmony export */ });\n/* harmony import */ var _table_table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../table/table */ \"../../node_modules/arquero/src/table/table.js\");\n // eslint-disable-line no-unused-vars\n\n/**\n * Convenience function for computing a single aggregate value for\n * a table. Equivalent to ungrouping a table, applying a rollup verb\n * for a single aggregate, and extracting the resulting value.\n * @param {Table} table A table instance.\n * @param {import('../../table/transformable').TableExpr} expr An\n *   aggregate table expression to evaluate.\n * @return {import('../../table/table').DataValue} The aggregate value.\n * @example agg(table, op.max('colA'))\n * @example agg(table, d => [op.min('colA'), op.max('colA')])\n */\nfunction agg(table, expr) {\n  return table.ungroup().rollup({ _: expr }).get('_');\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/helpers/agg.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/impute.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/impute.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_impute__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/impute */ \"../../node_modules/arquero/src/engine/impute.js\");\n/* harmony import */ var _engine_rollup__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../engine/rollup */ \"../../node_modules/arquero/src/engine/rollup.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, options = {}) {\n  values = (0,_expression_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values, { table });\n\n  values.names.forEach(name =>\n    table.column(name) ? 0 : (0,_util_error__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(`Invalid impute column ${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(name)}`)\n  );\n\n  if (options.expand) {\n    const opt = { preparse, aggronly: true };\n    const params = (0,_util_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])('impute', table, options.expand, opt);\n    const result = (0,_engine_rollup__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table.ungroup(), params);\n    return (0,_engine_impute__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n      table, values, params.names,\n      params.names.map(name => result.get(name, 0))\n    );\n  } else {\n    return (0,_engine_impute__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, values);\n  }\n}\n\n// map direct field reference to \"unique\" aggregate\nfunction preparse(map) {\n  map.forEach((value, key) =>\n    value.field ? map.set(key, (0,_op_op_api__WEBPACK_IMPORTED_MODULE_4__.array_agg_distinct)(value + '')) : 0\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/impute.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/index.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/index.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _dedupe__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dedupe */ \"../../node_modules/arquero/src/verbs/dedupe.js\");\n/* harmony import */ var _derive__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./derive */ \"../../node_modules/arquero/src/verbs/derive.js\");\n/* harmony import */ var _except__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./except */ \"../../node_modules/arquero/src/verbs/except.js\");\n/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./filter */ \"../../node_modules/arquero/src/verbs/filter.js\");\n/* harmony import */ var _fold__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./fold */ \"../../node_modules/arquero/src/verbs/fold.js\");\n/* harmony import */ var _impute__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./impute */ \"../../node_modules/arquero/src/verbs/impute.js\");\n/* harmony import */ var _intersect__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./intersect */ \"../../node_modules/arquero/src/verbs/intersect.js\");\n/* harmony import */ var _join__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./join */ \"../../node_modules/arquero/src/verbs/join.js\");\n/* harmony import */ var _join_filter__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./join-filter */ \"../../node_modules/arquero/src/verbs/join-filter.js\");\n/* harmony import */ var _lookup__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./lookup */ \"../../node_modules/arquero/src/verbs/lookup.js\");\n/* harmony import */ var _pivot__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./pivot */ \"../../node_modules/arquero/src/verbs/pivot.js\");\n/* harmony import */ var _relocate__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./relocate */ \"../../node_modules/arquero/src/verbs/relocate.js\");\n/* harmony import */ var _rename__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./rename */ \"../../node_modules/arquero/src/verbs/rename.js\");\n/* harmony import */ var _rollup__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./rollup */ \"../../node_modules/arquero/src/verbs/rollup.js\");\n/* harmony import */ var _sample__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./sample */ \"../../node_modules/arquero/src/verbs/sample.js\");\n/* harmony import */ var _select__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./select */ \"../../node_modules/arquero/src/verbs/select.js\");\n/* harmony import */ var _spread__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./spread */ \"../../node_modules/arquero/src/verbs/spread.js\");\n/* harmony import */ var _union__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./union */ \"../../node_modules/arquero/src/verbs/union.js\");\n/* harmony import */ var _unroll__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./unroll */ \"../../node_modules/arquero/src/verbs/unroll.js\");\n/* harmony import */ var _groupby__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./groupby */ \"../../node_modules/arquero/src/verbs/groupby.js\");\n/* harmony import */ var _orderby__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./orderby */ \"../../node_modules/arquero/src/verbs/orderby.js\");\n/* harmony import */ var _engine_concat__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../engine/concat */ \"../../node_modules/arquero/src/engine/concat.js\");\n/* harmony import */ var _engine_reduce__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../engine/reduce */ \"../../node_modules/arquero/src/engine/reduce.js\");\n/* harmony import */ var _engine_ungroup__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ../engine/ungroup */ \"../../node_modules/arquero/src/engine/ungroup.js\");\n/* harmony import */ var _engine_unorder__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../engine/unorder */ \"../../node_modules/arquero/src/engine/unorder.js\");\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ../op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  __antijoin: (table, other, on) =>\n    (0,_join_filter__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(table, other, on, { anti: true }),\n  __count: (table, options = {}) =>\n    (0,_rollup__WEBPACK_IMPORTED_MODULE_13__[\"default\"])(table, { [options.as || 'count']: (0,_op_op_api__WEBPACK_IMPORTED_MODULE_25__.count)() }),\n  __cross: (table, other, values, options) =>\n    (0,_join__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(table, other, () => true, values, {\n      ...options, left: true, right: true\n    }),\n  __concat: _engine_concat__WEBPACK_IMPORTED_MODULE_21__[\"default\"],\n  __dedupe: _dedupe__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  __derive: _derive__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  __except: _except__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  __filter: _filter__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  __fold: _fold__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  __impute: _impute__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  __intersect: _intersect__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  __join: _join__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  __lookup: _lookup__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n  __pivot: _pivot__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n  __relocate: _relocate__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n  __rename: _rename__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n  __rollup: _rollup__WEBPACK_IMPORTED_MODULE_13__[\"default\"],\n  __sample: _sample__WEBPACK_IMPORTED_MODULE_14__[\"default\"],\n  __select: _select__WEBPACK_IMPORTED_MODULE_15__[\"default\"],\n  __semijoin: _join_filter__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  __spread: _spread__WEBPACK_IMPORTED_MODULE_16__[\"default\"],\n  __union: _union__WEBPACK_IMPORTED_MODULE_17__[\"default\"],\n  __unroll: _unroll__WEBPACK_IMPORTED_MODULE_18__[\"default\"],\n  __groupby: _groupby__WEBPACK_IMPORTED_MODULE_19__[\"default\"],\n  __orderby: _orderby__WEBPACK_IMPORTED_MODULE_20__[\"default\"],\n  __ungroup: _engine_ungroup__WEBPACK_IMPORTED_MODULE_23__[\"default\"],\n  __unorder: _engine_unorder__WEBPACK_IMPORTED_MODULE_24__[\"default\"],\n  __reduce: _engine_reduce__WEBPACK_IMPORTED_MODULE_22__[\"default\"]\n});\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/index.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/intersect.js":
/*!*********************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/intersect.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, others) {\n  const names = table.columnNames();\n  return others.length\n    ? others.reduce((a, b) => a.semijoin(b.select(names)), table).dedupe()\n    : table.reify([]);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/intersect.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/join-filter.js":
/*!***********************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/join-filter.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_join_filter__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/join-filter */ \"../../node_modules/arquero/src/engine/join-filter.js\");\n/* harmony import */ var _util_join_keys__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/join-keys */ \"../../node_modules/arquero/src/verbs/util/join-keys.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, on, options) {\n  on = (0,_util_join_keys__WEBPACK_IMPORTED_MODULE_1__.inferKeys)(tableL, tableR, on);\n\n  const predicate = (0,_util_is_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(on)\n    ? (0,_util_join_keys__WEBPACK_IMPORTED_MODULE_1__.keyPredicate)(tableL, tableR, ...on.map(_util_to_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"]))\n    : (0,_expression_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])({ on }, { join: [tableL, tableR] }).exprs[0];\n\n  return (0,_engine_join_filter__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(tableL, tableR, predicate, options);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/join-filter.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/join.js":
/*!****************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/join.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_join__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/join */ \"../../node_modules/arquero/src/engine/join.js\");\n/* harmony import */ var _util_join_keys__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/join-keys */ \"../../node_modules/arquero/src/verbs/util/join-keys.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n/* harmony import */ var _util_to_string__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/to-string */ \"../../node_modules/arquero/src/util/to-string.js\");\n\n\n\n\n\n\n\n\n\n\nconst OPT_L = { aggregate: false, window: false };\nconst OPT_R = { ...OPT_L, index: 1 };\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, on, values, options = {}) {\n  on = (0,_util_join_keys__WEBPACK_IMPORTED_MODULE_1__.inferKeys)(tableL, tableR, on);\n  const optParse = { join: [tableL, tableR] };\n  let predicate;\n\n  if ((0,_util_is_array__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(on)) {\n    const [onL, onR] = on.map(_util_to_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"]);\n    predicate = (0,_util_join_keys__WEBPACK_IMPORTED_MODULE_1__.keyPredicate)(tableL, tableR, onL, onR);\n\n    if (!values) {\n      // infer output columns, suppress duplicated key columns\n      values = inferValues(tableL, onL, onR, options);\n    }\n  } else {\n    predicate = (0,_expression_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])({ on }, optParse).exprs[0];\n\n    if (!values) {\n      // include all table columns if values not provided\n      values = [(0,_helpers_selection__WEBPACK_IMPORTED_MODULE_4__.all)(), (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_4__.all)()];\n    }\n  }\n\n  return (0,_engine_join__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    tableL, tableR, predicate,\n    parseValues(tableL, tableR, values, optParse, options && options.suffix),\n    options\n  );\n}\n\nfunction inferValues(tableL, onL, onR, options) {\n  const isect = [];\n  onL.forEach((s, i) => (0,_util_is_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(s) && s === onR[i] ? isect.push(s) : 0);\n  const vR = (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_4__.not)(isect);\n\n  if (options.left && options.right) {\n    // for full join, merge shared key columns together\n    const shared = new Set(isect);\n    return [\n      tableL.columnNames().map(s => {\n        const c = `[${(0,_util_to_string__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(s)}]`;\n        return shared.has(s)\n          ? { [s]: `(a, b) => a${c} == null ? b${c} : a${c}` }\n          : s;\n      }),\n      vR\n    ];\n  }\n\n  return options.right ? [vR, (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_4__.all)()] : [(0,_helpers_selection__WEBPACK_IMPORTED_MODULE_4__.all)(), vR];\n}\n\nfunction parseValues(tableL, tableR, values, optParse, suffix = []) {\n  if ((0,_util_is_array__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(values)) {\n    let vL, vR, vJ, n = values.length;\n    vL = vR = vJ = { names: [], exprs: [] };\n\n    if (n--) {\n      vL = (0,_util_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('join', tableL, values[0], optParse);\n    }\n    if (n--) {\n      vR = (0,_util_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('join', tableR, values[1], OPT_R);\n    }\n    if (n--) {\n      vJ = (0,_expression_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values[2], optParse);\n    }\n\n    // handle name collisions\n    const rename = new Set();\n    const namesL = new Set(vL.names);\n    vR.names.forEach(name => {\n      if (namesL.has(name)) {\n        rename.add(name);\n      }\n    });\n    if (rename.size) {\n      rekey(vL.names, rename, suffix[0] || '_1');\n      rekey(vR.names, rename, suffix[1] || '_2');\n    }\n\n    return {\n      names: vL.names.concat(vR.names, vJ.names),\n      exprs: vL.exprs.concat(vR.exprs, vJ.exprs)\n    };\n  } else {\n    return (0,_expression_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values, optParse);\n  }\n}\n\nfunction rekey(names, rename, suffix) {\n  names.forEach((name, i) => rename.has(name)\n    ? (names[i] = name + suffix)\n    : 0);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/join.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/lookup.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/lookup.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_lookup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/lookup */ \"../../node_modules/arquero/src/engine/lookup.js\");\n/* harmony import */ var _util_join_keys__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/join-keys */ \"../../node_modules/arquero/src/verbs/util/join-keys.js\");\n/* harmony import */ var _util_parse_key__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util/parse-key */ \"../../node_modules/arquero/src/verbs/util/parse-key.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(tableL, tableR, on, values) {\n  on = (0,_util_join_keys__WEBPACK_IMPORTED_MODULE_1__.inferKeys)(tableL, tableR, on);\n  return (0,_engine_lookup__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    tableL,\n    tableR,\n    [ (0,_util_parse_key__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('lookup', tableL, on[0]), (0,_util_parse_key__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('lookup', tableR, on[1]) ],\n    (0,_util_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])('lookup', tableR, values)\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/lookup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/orderby.js":
/*!*******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/orderby.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_orderby__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/orderby */ \"../../node_modules/arquero/src/engine/orderby.js\");\n/* harmony import */ var _expression_compare__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../expression/compare */ \"../../node_modules/arquero/src/expression/compare.js\");\n/* harmony import */ var _helpers_field__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../helpers/field */ \"../../node_modules/arquero/src/helpers/field.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values) {\n  return (0,_engine_orderby__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, parseValues(table, values));\n}\n\nfunction parseValues(table, params) {\n  let index = -1;\n  const exprs = new Map();\n  const add = val => exprs.set(++index + '', val);\n\n  params.forEach(param => {\n    const expr = param.expr != null ? param.expr : param;\n\n    if ((0,_util_is_object__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(expr) && !(0,_util_is_function__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(expr)) {\n      for (const key in expr) add(expr[key]);\n    } else {\n      add(\n        (0,_util_is_number__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(expr) ? (0,_helpers_field__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(param, table.columnName(expr))\n          : (0,_util_is_string__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(expr) ? (0,_helpers_field__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(param)\n          : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(expr) ? param\n          : (0,_util_error__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(`Invalid orderby field: ${param+''}`)\n      );\n    }\n  });\n\n  return (0,_expression_compare__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, exprs);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/orderby.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/pivot.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/pivot.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_pivot__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/pivot */ \"../../node_modules/arquero/src/engine/pivot.js\");\n/* harmony import */ var _op_op_api__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../op/op-api */ \"../../node_modules/arquero/src/op/op-api.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n\n// TODO: enforce aggregates only (no output changes) for values\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, on, values, options) {\n  return (0,_engine_pivot__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    table,\n    (0,_util_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('fold', table, on),\n    (0,_util_parse__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('fold', table, values, { preparse, aggronly: true }),\n    options\n  );\n}\n\n// map direct field reference to \"any\" aggregate\nfunction preparse(map) {\n  map.forEach((value, key) =>\n    value.field ? map.set(key, (0,_op_op_api__WEBPACK_IMPORTED_MODULE_1__.any)(value + '')) : 0\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/pivot.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/relocate.js":
/*!********************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/relocate.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_select__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/select */ \"../../node_modules/arquero/src/engine/select.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, columns, { before, after } = {}) {\n  const bef = before != null;\n  const aft = after != null;\n\n  if (!(bef || aft)) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('relocate requires a before or after option.');\n  }\n  if (bef && aft) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])('relocate accepts only one of the before or after options.');\n  }\n\n  columns = (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, columns);\n  const anchors = [...(0,_helpers_selection__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, bef ? before : after).keys()];\n  const anchor = bef ? anchors[0] : anchors.pop();\n  const select = new Map();\n\n  // marshal inputs to select in desired order\n  table.columnNames().forEach(name => {\n    // check if we should assign the current column\n    const assign = !columns.has(name);\n\n    // at anchor column, insert relocated columns\n    if (name === anchor) {\n      if (aft && assign) select.set(name, name);\n      for (const [key, value] of columns) {\n        select.set(key, value);\n      }\n      if (aft) return; // exit if current column has been handled\n    }\n\n    if (assign) select.set(name, name);\n  });\n\n  return (0,_engine_select__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, select);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/relocate.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/rename.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/rename.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_select__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/select */ \"../../node_modules/arquero/src/engine/select.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, columns) {\n  const map = new Map();\n  table.columnNames(x => (map.set(x, x), 0));\n  return (0,_engine_select__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, columns, map));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/rename.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/rollup.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/rollup.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_rollup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/rollup */ \"../../node_modules/arquero/src/engine/rollup.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values) {\n  return (0,_engine_rollup__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_expression_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values, { table, aggronly: true }));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/rollup.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/sample.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/sample.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_derive__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/derive */ \"../../node_modules/arquero/src/engine/derive.js\");\n/* harmony import */ var _engine_rollup__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../engine/rollup */ \"../../node_modules/arquero/src/engine/rollup.js\");\n/* harmony import */ var _engine_sample__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../engine/sample */ \"../../node_modules/arquero/src/engine/sample.js\");\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, size, options = {}) {\n  return (0,_engine_sample__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(\n    table,\n    parseSize(table, size),\n    parseWeight(table, options.weight),\n    options\n  );\n}\n\nconst get = col => row => col.get(row) || 0;\n\nfunction parseSize(table, size) {\n  return (0,_util_is_number__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(size)\n    ? () => size\n    : get((0,_engine_rollup__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, (0,_expression_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])({ size }, { table })).column('size'));\n}\n\nfunction parseWeight(table, w) {\n  if (w == null) return null;\n  w = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(w) ? table.columnName(w) : w;\n  return get(\n    (0,_util_is_string__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(w)\n      ? table.column(w)\n      : (0,_engine_derive__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_expression_parse__WEBPACK_IMPORTED_MODULE_3__[\"default\"])({ w }, { table }), { drop: true }).column('w')\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/sample.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/select.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/select.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_select__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/select */ \"../../node_modules/arquero/src/engine/select.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, columns) {\n  return (0,_engine_select__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(table, columns));\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/select.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/spread.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/spread.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_spread__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/spread */ \"../../node_modules/arquero/src/engine/spread.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, options) {\n  return (0,_engine_spread__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(table, (0,_util_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('spread', table, values), options);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/spread.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/union.js":
/*!*****************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/union.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, others) {\n  return table.concat(others).dedupe();\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/union.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/unroll.js":
/*!******************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/unroll.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _engine_unroll__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../engine/unroll */ \"../../node_modules/arquero/src/engine/unroll.js\");\n/* harmony import */ var _util_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/parse */ \"../../node_modules/arquero/src/verbs/util/parse.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(table, values, options) {\n  return (0,_engine_unroll__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n    table,\n    (0,_util_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('unroll', table, values),\n    options && options.drop\n      ? { ...options, drop: (0,_util_parse__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('unroll', table, options.drop).names }\n      : options\n  );\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/unroll.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/util/join-keys.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/util/join-keys.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   inferKeys: () => (/* binding */ inferKeys),\n/* harmony export */   keyPredicate: () => (/* binding */ keyPredicate)\n/* harmony export */ });\n/* harmony import */ var _parse_key__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./parse-key */ \"../../node_modules/arquero/src/verbs/util/parse-key.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_intersect__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/intersect */ \"../../node_modules/arquero/src/util/intersect.js\");\n/* harmony import */ var _util_is_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/is-array */ \"../../node_modules/arquero/src/util/is-array.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n\n\n\n\n\n\nfunction inferKeys(tableL, tableR, on) {\n  if (!on) {\n    // perform natural join if join condition not provided\n    const isect = (0,_util_intersect__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(tableL.columnNames(), tableR.columnNames());\n    if (!isect.length) (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Natural join requires shared column names.');\n    on = [isect, isect];\n  } else if ((0,_util_is_string__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(on)) {\n    on = [on, on];\n  } else if ((0,_util_is_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(on) && on.length === 1) {\n    on = [on[0], on[0]];\n  }\n\n  return on;\n}\n\nfunction keyPredicate(tableL, tableR, onL, onR) {\n  if (onL.length !== onR.length) {\n    (0,_util_error__WEBPACK_IMPORTED_MODULE_1__[\"default\"])('Mismatched number of join keys');\n  }\n  return [\n    (0,_parse_key__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('join', tableL, onL),\n    (0,_parse_key__WEBPACK_IMPORTED_MODULE_0__[\"default\"])('join', tableR, onR)\n  ];\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/util/join-keys.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/util/parse-key.js":
/*!**************************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/util/parse-key.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _helpers_field__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../helpers/field */ \"../../node_modules/arquero/src/helpers/field.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_key_function__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util/key-function */ \"../../node_modules/arquero/src/util/key-function.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(name, table, params) {\n  const exprs = new Map();\n\n  (0,_util_to_array__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(params).forEach((param, i) => {\n    param = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(param) ? table.columnName(param) : param;\n    (0,_util_is_string__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(param) ? exprs.set(i, (0,_helpers_field__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(param))\n      : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(param) || (0,_util_is_object__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(param) && param.expr ? exprs.set(i, param)\n      : (0,_util_error__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(`Invalid ${name} key value: ${param+''}`);\n  });\n\n  const fn = (0,_expression_parse__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(exprs, { table, aggregate: false, window: false });\n  return (0,_util_key_function__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(fn.exprs, true);\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/util/parse-key.js?");

/***/ }),

/***/ "../../node_modules/arquero/src/verbs/util/parse.js":
/*!**********************************************************!*\
  !*** ../../node_modules/arquero/src/verbs/util/parse.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _expression_parse__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../expression/parse */ \"../../node_modules/arquero/src/expression/parse.js\");\n/* harmony import */ var _helpers_field__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../helpers/field */ \"../../node_modules/arquero/src/helpers/field.js\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../helpers/selection */ \"../../node_modules/arquero/src/helpers/selection.js\");\n/* harmony import */ var _util_assign__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util/assign */ \"../../node_modules/arquero/src/util/assign.js\");\n/* harmony import */ var _util_error__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/error */ \"../../node_modules/arquero/src/util/error.js\");\n/* harmony import */ var _util_is_number__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util/is-number */ \"../../node_modules/arquero/src/util/is-number.js\");\n/* harmony import */ var _util_is_object__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util/is-object */ \"../../node_modules/arquero/src/util/is-object.js\");\n/* harmony import */ var _util_is_string__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util/is-string */ \"../../node_modules/arquero/src/util/is-string.js\");\n/* harmony import */ var _util_is_function__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../util/is-function */ \"../../node_modules/arquero/src/util/is-function.js\");\n/* harmony import */ var _util_to_array__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../util/to-array */ \"../../node_modules/arquero/src/util/to-array.js\");\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(name, table, params, options = { window: false }) {\n  const exprs = new Map();\n\n  const marshal = param => {\n    param = (0,_util_is_number__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(param) ? table.columnName(param) : param;\n    (0,_util_is_string__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(param) ? exprs.set(param, (0,_helpers_field__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(param))\n      : (0,_util_is_function__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(param) ? (0,_helpers_selection__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(table, param).forEach(marshal)\n      : (0,_util_is_object__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(param) ? (0,_util_assign__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(exprs, param)\n      : (0,_util_error__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(`Invalid ${name} value: ${param+''}`);\n  };\n\n  (0,_util_to_array__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(params).forEach(marshal);\n\n  if (options.preparse) {\n    options.preparse(exprs);\n  }\n\n  return (0,_expression_parse__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(exprs, { table, ...options });\n}\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/src/verbs/util/parse.js?");

/***/ }),

/***/ "../../node_modules/fast-deep-equal/index.js":
/*!***************************************************!*\
  !*** ../../node_modules/fast-deep-equal/index.js ***!
  \***************************************************/
/***/ ((module) => {

"use strict";
eval("\n\n// do not edit .js files directly - edit src/index.jst\n\n\n\nmodule.exports = function equal(a, b) {\n  if (a === b) return true;\n\n  if (a && b && typeof a == 'object' && typeof b == 'object') {\n    if (a.constructor !== b.constructor) return false;\n\n    var length, i, keys;\n    if (Array.isArray(a)) {\n      length = a.length;\n      if (length != b.length) return false;\n      for (i = length; i-- !== 0;)\n        if (!equal(a[i], b[i])) return false;\n      return true;\n    }\n\n\n\n    if (a.constructor === RegExp) return a.source === b.source && a.flags === b.flags;\n    if (a.valueOf !== Object.prototype.valueOf) return a.valueOf() === b.valueOf();\n    if (a.toString !== Object.prototype.toString) return a.toString() === b.toString();\n\n    keys = Object.keys(a);\n    length = keys.length;\n    if (length !== Object.keys(b).length) return false;\n\n    for (i = length; i-- !== 0;)\n      if (!Object.prototype.hasOwnProperty.call(b, keys[i])) return false;\n\n    for (i = length; i-- !== 0;) {\n      var key = keys[i];\n\n      if (!equal(a[key], b[key])) return false;\n    }\n\n    return true;\n  }\n\n  // true if both NaN, false otherwise\n  return a!==a && b!==b;\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-deep-equal/index.js?");

/***/ }),

/***/ "../../node_modules/fast-json-stable-stringify/index.js":
/*!**************************************************************!*\
  !*** ../../node_modules/fast-json-stable-stringify/index.js ***!
  \**************************************************************/
/***/ ((module) => {

"use strict";
eval("\n\nmodule.exports = function (data, opts) {\n    if (!opts) opts = {};\n    if (typeof opts === 'function') opts = { cmp: opts };\n    var cycles = (typeof opts.cycles === 'boolean') ? opts.cycles : false;\n\n    var cmp = opts.cmp && (function (f) {\n        return function (node) {\n            return function (a, b) {\n                var aobj = { key: a, value: node[a] };\n                var bobj = { key: b, value: node[b] };\n                return f(aobj, bobj);\n            };\n        };\n    })(opts.cmp);\n\n    var seen = [];\n    return (function stringify (node) {\n        if (node && node.toJSON && typeof node.toJSON === 'function') {\n            node = node.toJSON();\n        }\n\n        if (node === undefined) return;\n        if (typeof node == 'number') return isFinite(node) ? '' + node : 'null';\n        if (typeof node !== 'object') return JSON.stringify(node);\n\n        var i, out;\n        if (Array.isArray(node)) {\n            out = '[';\n            for (i = 0; i < node.length; i++) {\n                if (i) out += ',';\n                out += stringify(node[i]) || 'null';\n            }\n            return out + ']';\n        }\n\n        if (node === null) return 'null';\n\n        if (seen.indexOf(node) !== -1) {\n            if (cycles) return JSON.stringify('__cycle__');\n            throw new TypeError('Converting circular structure to JSON');\n        }\n\n        var seenIndex = seen.push(node) - 1;\n        var keys = Object.keys(node).sort(cmp && cmp(node));\n        out = '';\n        for (i = 0; i < keys.length; i++) {\n            var key = keys[i];\n            var value = stringify(node[key]);\n\n            if (!value) continue;\n            if (out) out += ',';\n            out += JSON.stringify(key) + ':' + value;\n        }\n        seen.splice(seenIndex, 1);\n        return '{' + out + '}';\n    })(data);\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-json-stable-stringify/index.js?");

/***/ }),

/***/ "../../node_modules/html2canvas/dist/html2canvas.js":
/*!**********************************************************!*\
  !*** ../../node_modules/html2canvas/dist/html2canvas.js ***!
  \**********************************************************/
/***/ (function(module) {

eval("/*!\n * html2canvas 1.4.1 <https://html2canvas.hertzen.com>\n * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n * Released under MIT License\n */\n(function (global, factory) {\n     true ? module.exports = factory() :\n    0;\n}(this, (function () { 'use strict';\n\n    /*! *****************************************************************************\r\n    Copyright (c) Microsoft Corporation.\r\n\r\n    Permission to use, copy, modify, and/or distribute this software for any\r\n    purpose with or without fee is hereby granted.\r\n\r\n    THE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\n    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\n    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\n    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\n    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\n    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\n    PERFORMANCE OF THIS SOFTWARE.\r\n    ***************************************************************************** */\r\n    /* global Reflect, Promise */\r\n\r\n    var extendStatics = function(d, b) {\r\n        extendStatics = Object.setPrototypeOf ||\r\n            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };\r\n        return extendStatics(d, b);\r\n    };\r\n\r\n    function __extends(d, b) {\r\n        if (typeof b !== \"function\" && b !== null)\r\n            throw new TypeError(\"Class extends value \" + String(b) + \" is not a constructor or null\");\r\n        extendStatics(d, b);\r\n        function __() { this.constructor = d; }\r\n        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n    }\r\n\r\n    var __assign = function() {\r\n        __assign = Object.assign || function __assign(t) {\r\n            for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n                s = arguments[i];\r\n                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n            }\r\n            return t;\r\n        };\r\n        return __assign.apply(this, arguments);\r\n    };\r\n\r\n    function __awaiter(thisArg, _arguments, P, generator) {\r\n        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }\r\n        return new (P || (P = Promise))(function (resolve, reject) {\r\n            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }\r\n            function rejected(value) { try { step(generator[\"throw\"](value)); } catch (e) { reject(e); } }\r\n            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }\r\n            step((generator = generator.apply(thisArg, _arguments || [])).next());\r\n        });\r\n    }\r\n\r\n    function __generator(thisArg, body) {\r\n        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;\r\n        return g = { next: verb(0), \"throw\": verb(1), \"return\": verb(2) }, typeof Symbol === \"function\" && (g[Symbol.iterator] = function() { return this; }), g;\r\n        function verb(n) { return function (v) { return step([n, v]); }; }\r\n        function step(op) {\r\n            if (f) throw new TypeError(\"Generator is already executing.\");\r\n            while (_) try {\r\n                if (f = 1, y && (t = op[0] & 2 ? y[\"return\"] : op[0] ? y[\"throw\"] || ((t = y[\"return\"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;\r\n                if (y = 0, t) op = [op[0] & 2, t.value];\r\n                switch (op[0]) {\r\n                    case 0: case 1: t = op; break;\r\n                    case 4: _.label++; return { value: op[1], done: false };\r\n                    case 5: _.label++; y = op[1]; op = [0]; continue;\r\n                    case 7: op = _.ops.pop(); _.trys.pop(); continue;\r\n                    default:\r\n                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }\r\n                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }\r\n                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }\r\n                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }\r\n                        if (t[2]) _.ops.pop();\r\n                        _.trys.pop(); continue;\r\n                }\r\n                op = body.call(thisArg, _);\r\n            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }\r\n            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };\r\n        }\r\n    }\r\n\r\n    function __spreadArray(to, from, pack) {\r\n        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {\r\n            if (ar || !(i in from)) {\r\n                if (!ar) ar = Array.prototype.slice.call(from, 0, i);\r\n                ar[i] = from[i];\r\n            }\r\n        }\r\n        return to.concat(ar || from);\r\n    }\n\n    var Bounds = /** @class */ (function () {\n        function Bounds(left, top, width, height) {\n            this.left = left;\n            this.top = top;\n            this.width = width;\n            this.height = height;\n        }\n        Bounds.prototype.add = function (x, y, w, h) {\n            return new Bounds(this.left + x, this.top + y, this.width + w, this.height + h);\n        };\n        Bounds.fromClientRect = function (context, clientRect) {\n            return new Bounds(clientRect.left + context.windowBounds.left, clientRect.top + context.windowBounds.top, clientRect.width, clientRect.height);\n        };\n        Bounds.fromDOMRectList = function (context, domRectList) {\n            var domRect = Array.from(domRectList).find(function (rect) { return rect.width !== 0; });\n            return domRect\n                ? new Bounds(domRect.left + context.windowBounds.left, domRect.top + context.windowBounds.top, domRect.width, domRect.height)\n                : Bounds.EMPTY;\n        };\n        Bounds.EMPTY = new Bounds(0, 0, 0, 0);\n        return Bounds;\n    }());\n    var parseBounds = function (context, node) {\n        return Bounds.fromClientRect(context, node.getBoundingClientRect());\n    };\n    var parseDocumentSize = function (document) {\n        var body = document.body;\n        var documentElement = document.documentElement;\n        if (!body || !documentElement) {\n            throw new Error(\"Unable to get document size\");\n        }\n        var width = Math.max(Math.max(body.scrollWidth, documentElement.scrollWidth), Math.max(body.offsetWidth, documentElement.offsetWidth), Math.max(body.clientWidth, documentElement.clientWidth));\n        var height = Math.max(Math.max(body.scrollHeight, documentElement.scrollHeight), Math.max(body.offsetHeight, documentElement.offsetHeight), Math.max(body.clientHeight, documentElement.clientHeight));\n        return new Bounds(0, 0, width, height);\n    };\n\n    /*\n     * css-line-break 2.1.0 <https://github.com/niklasvh/css-line-break#readme>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var toCodePoints$1 = function (str) {\n        var codePoints = [];\n        var i = 0;\n        var length = str.length;\n        while (i < length) {\n            var value = str.charCodeAt(i++);\n            if (value >= 0xd800 && value <= 0xdbff && i < length) {\n                var extra = str.charCodeAt(i++);\n                if ((extra & 0xfc00) === 0xdc00) {\n                    codePoints.push(((value & 0x3ff) << 10) + (extra & 0x3ff) + 0x10000);\n                }\n                else {\n                    codePoints.push(value);\n                    i--;\n                }\n            }\n            else {\n                codePoints.push(value);\n            }\n        }\n        return codePoints;\n    };\n    var fromCodePoint$1 = function () {\n        var codePoints = [];\n        for (var _i = 0; _i < arguments.length; _i++) {\n            codePoints[_i] = arguments[_i];\n        }\n        if (String.fromCodePoint) {\n            return String.fromCodePoint.apply(String, codePoints);\n        }\n        var length = codePoints.length;\n        if (!length) {\n            return '';\n        }\n        var codeUnits = [];\n        var index = -1;\n        var result = '';\n        while (++index < length) {\n            var codePoint = codePoints[index];\n            if (codePoint <= 0xffff) {\n                codeUnits.push(codePoint);\n            }\n            else {\n                codePoint -= 0x10000;\n                codeUnits.push((codePoint >> 10) + 0xd800, (codePoint % 0x400) + 0xdc00);\n            }\n            if (index + 1 === length || codeUnits.length > 0x4000) {\n                result += String.fromCharCode.apply(String, codeUnits);\n                codeUnits.length = 0;\n            }\n        }\n        return result;\n    };\n    var chars$2 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';\n    // Use a lookup table to find the index.\n    var lookup$2 = typeof Uint8Array === 'undefined' ? [] : new Uint8Array(256);\n    for (var i$2 = 0; i$2 < chars$2.length; i$2++) {\n        lookup$2[chars$2.charCodeAt(i$2)] = i$2;\n    }\n\n    /*\n     * utrie 1.0.2 <https://github.com/niklasvh/utrie>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var chars$1$1 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';\n    // Use a lookup table to find the index.\n    var lookup$1$1 = typeof Uint8Array === 'undefined' ? [] : new Uint8Array(256);\n    for (var i$1$1 = 0; i$1$1 < chars$1$1.length; i$1$1++) {\n        lookup$1$1[chars$1$1.charCodeAt(i$1$1)] = i$1$1;\n    }\n    var decode$1 = function (base64) {\n        var bufferLength = base64.length * 0.75, len = base64.length, i, p = 0, encoded1, encoded2, encoded3, encoded4;\n        if (base64[base64.length - 1] === '=') {\n            bufferLength--;\n            if (base64[base64.length - 2] === '=') {\n                bufferLength--;\n            }\n        }\n        var buffer = typeof ArrayBuffer !== 'undefined' &&\n            typeof Uint8Array !== 'undefined' &&\n            typeof Uint8Array.prototype.slice !== 'undefined'\n            ? new ArrayBuffer(bufferLength)\n            : new Array(bufferLength);\n        var bytes = Array.isArray(buffer) ? buffer : new Uint8Array(buffer);\n        for (i = 0; i < len; i += 4) {\n            encoded1 = lookup$1$1[base64.charCodeAt(i)];\n            encoded2 = lookup$1$1[base64.charCodeAt(i + 1)];\n            encoded3 = lookup$1$1[base64.charCodeAt(i + 2)];\n            encoded4 = lookup$1$1[base64.charCodeAt(i + 3)];\n            bytes[p++] = (encoded1 << 2) | (encoded2 >> 4);\n            bytes[p++] = ((encoded2 & 15) << 4) | (encoded3 >> 2);\n            bytes[p++] = ((encoded3 & 3) << 6) | (encoded4 & 63);\n        }\n        return buffer;\n    };\n    var polyUint16Array$1 = function (buffer) {\n        var length = buffer.length;\n        var bytes = [];\n        for (var i = 0; i < length; i += 2) {\n            bytes.push((buffer[i + 1] << 8) | buffer[i]);\n        }\n        return bytes;\n    };\n    var polyUint32Array$1 = function (buffer) {\n        var length = buffer.length;\n        var bytes = [];\n        for (var i = 0; i < length; i += 4) {\n            bytes.push((buffer[i + 3] << 24) | (buffer[i + 2] << 16) | (buffer[i + 1] << 8) | buffer[i]);\n        }\n        return bytes;\n    };\n\n    /** Shift size for getting the index-2 table offset. */\n    var UTRIE2_SHIFT_2$1 = 5;\n    /** Shift size for getting the index-1 table offset. */\n    var UTRIE2_SHIFT_1$1 = 6 + 5;\n    /**\n     * Shift size for shifting left the index array values.\n     * Increases possible data size with 16-bit index values at the cost\n     * of compactability.\n     * This requires data blocks to be aligned by UTRIE2_DATA_GRANULARITY.\n     */\n    var UTRIE2_INDEX_SHIFT$1 = 2;\n    /**\n     * Difference between the two shift sizes,\n     * for getting an index-1 offset from an index-2 offset. 6=11-5\n     */\n    var UTRIE2_SHIFT_1_2$1 = UTRIE2_SHIFT_1$1 - UTRIE2_SHIFT_2$1;\n    /**\n     * The part of the index-2 table for U+D800..U+DBFF stores values for\n     * lead surrogate code _units_ not code _points_.\n     * Values for lead surrogate code _points_ are indexed with this portion of the table.\n     * Length=32=0x20=0x400>>UTRIE2_SHIFT_2. (There are 1024=0x400 lead surrogates.)\n     */\n    var UTRIE2_LSCP_INDEX_2_OFFSET$1 = 0x10000 >> UTRIE2_SHIFT_2$1;\n    /** Number of entries in a data block. 32=0x20 */\n    var UTRIE2_DATA_BLOCK_LENGTH$1 = 1 << UTRIE2_SHIFT_2$1;\n    /** Mask for getting the lower bits for the in-data-block offset. */\n    var UTRIE2_DATA_MASK$1 = UTRIE2_DATA_BLOCK_LENGTH$1 - 1;\n    var UTRIE2_LSCP_INDEX_2_LENGTH$1 = 0x400 >> UTRIE2_SHIFT_2$1;\n    /** Count the lengths of both BMP pieces. 2080=0x820 */\n    var UTRIE2_INDEX_2_BMP_LENGTH$1 = UTRIE2_LSCP_INDEX_2_OFFSET$1 + UTRIE2_LSCP_INDEX_2_LENGTH$1;\n    /**\n     * The 2-byte UTF-8 version of the index-2 table follows at offset 2080=0x820.\n     * Length 32=0x20 for lead bytes C0..DF, regardless of UTRIE2_SHIFT_2.\n     */\n    var UTRIE2_UTF8_2B_INDEX_2_OFFSET$1 = UTRIE2_INDEX_2_BMP_LENGTH$1;\n    var UTRIE2_UTF8_2B_INDEX_2_LENGTH$1 = 0x800 >> 6; /* U+0800 is the first code point after 2-byte UTF-8 */\n    /**\n     * The index-1 table, only used for supplementary code points, at offset 2112=0x840.\n     * Variable length, for code points up to highStart, where the last single-value range starts.\n     * Maximum length 512=0x200=0x100000>>UTRIE2_SHIFT_1.\n     * (For 0x100000 supplementary code points U+10000..U+10ffff.)\n     *\n     * The part of the index-2 table for supplementary code points starts\n     * after this index-1 table.\n     *\n     * Both the index-1 table and the following part of the index-2 table\n     * are omitted completely if there is only BMP data.\n     */\n    var UTRIE2_INDEX_1_OFFSET$1 = UTRIE2_UTF8_2B_INDEX_2_OFFSET$1 + UTRIE2_UTF8_2B_INDEX_2_LENGTH$1;\n    /**\n     * Number of index-1 entries for the BMP. 32=0x20\n     * This part of the index-1 table is omitted from the serialized form.\n     */\n    var UTRIE2_OMITTED_BMP_INDEX_1_LENGTH$1 = 0x10000 >> UTRIE2_SHIFT_1$1;\n    /** Number of entries in an index-2 block. 64=0x40 */\n    var UTRIE2_INDEX_2_BLOCK_LENGTH$1 = 1 << UTRIE2_SHIFT_1_2$1;\n    /** Mask for getting the lower bits for the in-index-2-block offset. */\n    var UTRIE2_INDEX_2_MASK$1 = UTRIE2_INDEX_2_BLOCK_LENGTH$1 - 1;\n    var slice16$1 = function (view, start, end) {\n        if (view.slice) {\n            return view.slice(start, end);\n        }\n        return new Uint16Array(Array.prototype.slice.call(view, start, end));\n    };\n    var slice32$1 = function (view, start, end) {\n        if (view.slice) {\n            return view.slice(start, end);\n        }\n        return new Uint32Array(Array.prototype.slice.call(view, start, end));\n    };\n    var createTrieFromBase64$1 = function (base64, _byteLength) {\n        var buffer = decode$1(base64);\n        var view32 = Array.isArray(buffer) ? polyUint32Array$1(buffer) : new Uint32Array(buffer);\n        var view16 = Array.isArray(buffer) ? polyUint16Array$1(buffer) : new Uint16Array(buffer);\n        var headerLength = 24;\n        var index = slice16$1(view16, headerLength / 2, view32[4] / 2);\n        var data = view32[5] === 2\n            ? slice16$1(view16, (headerLength + view32[4]) / 2)\n            : slice32$1(view32, Math.ceil((headerLength + view32[4]) / 4));\n        return new Trie$1(view32[0], view32[1], view32[2], view32[3], index, data);\n    };\n    var Trie$1 = /** @class */ (function () {\n        function Trie(initialValue, errorValue, highStart, highValueIndex, index, data) {\n            this.initialValue = initialValue;\n            this.errorValue = errorValue;\n            this.highStart = highStart;\n            this.highValueIndex = highValueIndex;\n            this.index = index;\n            this.data = data;\n        }\n        /**\n         * Get the value for a code point as stored in the Trie.\n         *\n         * @param codePoint the code point\n         * @return the value\n         */\n        Trie.prototype.get = function (codePoint) {\n            var ix;\n            if (codePoint >= 0) {\n                if (codePoint < 0x0d800 || (codePoint > 0x0dbff && codePoint <= 0x0ffff)) {\n                    // Ordinary BMP code point, excluding leading surrogates.\n                    // BMP uses a single level lookup.  BMP index starts at offset 0 in the Trie2 index.\n                    // 16 bit data is stored in the index array itself.\n                    ix = this.index[codePoint >> UTRIE2_SHIFT_2$1];\n                    ix = (ix << UTRIE2_INDEX_SHIFT$1) + (codePoint & UTRIE2_DATA_MASK$1);\n                    return this.data[ix];\n                }\n                if (codePoint <= 0xffff) {\n                    // Lead Surrogate Code Point.  A Separate index section is stored for\n                    // lead surrogate code units and code points.\n                    //   The main index has the code unit data.\n                    //   For this function, we need the code point data.\n                    // Note: this expression could be refactored for slightly improved efficiency, but\n                    //       surrogate code points will be so rare in practice that it's not worth it.\n                    ix = this.index[UTRIE2_LSCP_INDEX_2_OFFSET$1 + ((codePoint - 0xd800) >> UTRIE2_SHIFT_2$1)];\n                    ix = (ix << UTRIE2_INDEX_SHIFT$1) + (codePoint & UTRIE2_DATA_MASK$1);\n                    return this.data[ix];\n                }\n                if (codePoint < this.highStart) {\n                    // Supplemental code point, use two-level lookup.\n                    ix = UTRIE2_INDEX_1_OFFSET$1 - UTRIE2_OMITTED_BMP_INDEX_1_LENGTH$1 + (codePoint >> UTRIE2_SHIFT_1$1);\n                    ix = this.index[ix];\n                    ix += (codePoint >> UTRIE2_SHIFT_2$1) & UTRIE2_INDEX_2_MASK$1;\n                    ix = this.index[ix];\n                    ix = (ix << UTRIE2_INDEX_SHIFT$1) + (codePoint & UTRIE2_DATA_MASK$1);\n                    return this.data[ix];\n                }\n                if (codePoint <= 0x10ffff) {\n                    return this.data[this.highValueIndex];\n                }\n            }\n            // Fall through.  The code point is outside of the legal range of 0..0x10ffff.\n            return this.errorValue;\n        };\n        return Trie;\n    }());\n\n    /*\n     * base64-arraybuffer 1.0.2 <https://github.com/niklasvh/base64-arraybuffer>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var chars$3 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';\n    // Use a lookup table to find the index.\n    var lookup$3 = typeof Uint8Array === 'undefined' ? [] : new Uint8Array(256);\n    for (var i$3 = 0; i$3 < chars$3.length; i$3++) {\n        lookup$3[chars$3.charCodeAt(i$3)] = i$3;\n    }\n\n    var base64$1 = ' ';\n\n    var LETTER_NUMBER_MODIFIER = 50;\n    // Non-tailorable Line Breaking Classes\n    var BK = 1; //  Cause a line break (after)\n    var CR$1 = 2; //  Cause a line break (after), except between CR and LF\n    var LF$1 = 3; //  Cause a line break (after)\n    var CM = 4; //  Prohibit a line break between the character and the preceding character\n    var NL = 5; //  Cause a line break (after)\n    var WJ = 7; //  Prohibit line breaks before and after\n    var ZW = 8; //  Provide a break opportunity\n    var GL = 9; //  Prohibit line breaks before and after\n    var SP = 10; // Enable indirect line breaks\n    var ZWJ$1 = 11; // Prohibit line breaks within joiner sequences\n    // Break Opportunities\n    var B2 = 12; //  Provide a line break opportunity before and after the character\n    var BA = 13; //  Generally provide a line break opportunity after the character\n    var BB = 14; //  Generally provide a line break opportunity before the character\n    var HY = 15; //  Provide a line break opportunity after the character, except in numeric context\n    var CB = 16; //   Provide a line break opportunity contingent on additional information\n    // Characters Prohibiting Certain Breaks\n    var CL = 17; //  Prohibit line breaks before\n    var CP = 18; //  Prohibit line breaks before\n    var EX = 19; //  Prohibit line breaks before\n    var IN = 20; //  Allow only indirect line breaks between pairs\n    var NS = 21; //  Allow only indirect line breaks before\n    var OP = 22; //  Prohibit line breaks after\n    var QU = 23; //  Act like they are both opening and closing\n    // Numeric Context\n    var IS = 24; //  Prevent breaks after any and before numeric\n    var NU = 25; //  Form numeric expressions for line breaking purposes\n    var PO = 26; //  Do not break following a numeric expression\n    var PR = 27; //  Do not break in front of a numeric expression\n    var SY = 28; //  Prevent a break before; and allow a break after\n    // Other Characters\n    var AI = 29; //  Act like AL when the resolvedEAW is N; otherwise; act as ID\n    var AL = 30; //  Are alphabetic characters or symbols that are used with alphabetic characters\n    var CJ = 31; //  Treat as NS or ID for strict or normal breaking.\n    var EB = 32; //  Do not break from following Emoji Modifier\n    var EM = 33; //  Do not break from preceding Emoji Base\n    var H2 = 34; //  Form Korean syllable blocks\n    var H3 = 35; //  Form Korean syllable blocks\n    var HL = 36; //  Do not break around a following hyphen; otherwise act as Alphabetic\n    var ID = 37; //  Break before or after; except in some numeric context\n    var JL = 38; //  Form Korean syllable blocks\n    var JV = 39; //  Form Korean syllable blocks\n    var JT = 40; //  Form Korean syllable blocks\n    var RI$1 = 41; //  Keep pairs together. For pairs; break before and after other classes\n    var SA = 42; //  Provide a line break opportunity contingent on additional, language-specific context analysis\n    var XX = 43; //  Have as yet unknown line breaking behavior or unassigned code positions\n    var ea_OP = [0x2329, 0xff08];\n    var BREAK_MANDATORY = '!';\n    var BREAK_NOT_ALLOWED$1 = '×';\n    var BREAK_ALLOWED$1 = '÷';\n    var UnicodeTrie$1 = createTrieFromBase64$1(base64$1);\n    var ALPHABETICS = [AL, HL];\n    var HARD_LINE_BREAKS = [BK, CR$1, LF$1, NL];\n    var SPACE$1 = [SP, ZW];\n    var PREFIX_POSTFIX = [PR, PO];\n    var LINE_BREAKS = HARD_LINE_BREAKS.concat(SPACE$1);\n    var KOREAN_SYLLABLE_BLOCK = [JL, JV, JT, H2, H3];\n    var HYPHEN = [HY, BA];\n    var codePointsToCharacterClasses = function (codePoints, lineBreak) {\n        if (lineBreak === void 0) { lineBreak = 'strict'; }\n        var types = [];\n        var indices = [];\n        var categories = [];\n        codePoints.forEach(function (codePoint, index) {\n            var classType = UnicodeTrie$1.get(codePoint);\n            if (classType > LETTER_NUMBER_MODIFIER) {\n                categories.push(true);\n                classType -= LETTER_NUMBER_MODIFIER;\n            }\n            else {\n                categories.push(false);\n            }\n            if (['normal', 'auto', 'loose'].indexOf(lineBreak) !== -1) {\n                // U+2010, – U+2013, 〜 U+301C, ゠ U+30A0\n                if ([0x2010, 0x2013, 0x301c, 0x30a0].indexOf(codePoint) !== -1) {\n                    indices.push(index);\n                    return types.push(CB);\n                }\n            }\n            if (classType === CM || classType === ZWJ$1) {\n                // LB10 Treat any remaining combining mark or ZWJ as AL.\n                if (index === 0) {\n                    indices.push(index);\n                    return types.push(AL);\n                }\n                // LB9 Do not break a combining character sequence; treat it as if it has the line breaking class of\n                // the base character in all of the following rules. Treat ZWJ as if it were CM.\n                var prev = types[index - 1];\n                if (LINE_BREAKS.indexOf(prev) === -1) {\n                    indices.push(indices[index - 1]);\n                    return types.push(prev);\n                }\n                indices.push(index);\n                return types.push(AL);\n            }\n            indices.push(index);\n            if (classType === CJ) {\n                return types.push(lineBreak === 'strict' ? NS : ID);\n            }\n            if (classType === SA) {\n                return types.push(AL);\n            }\n            if (classType === AI) {\n                return types.push(AL);\n            }\n            // For supplementary characters, a useful default is to treat characters in the range 10000..1FFFD as AL\n            // and characters in the ranges 20000..2FFFD and 30000..3FFFD as ID, until the implementation can be revised\n            // to take into account the actual line breaking properties for these characters.\n            if (classType === XX) {\n                if ((codePoint >= 0x20000 && codePoint <= 0x2fffd) || (codePoint >= 0x30000 && codePoint <= 0x3fffd)) {\n                    return types.push(ID);\n                }\n                else {\n                    return types.push(AL);\n                }\n            }\n            types.push(classType);\n        });\n        return [indices, types, categories];\n    };\n    var isAdjacentWithSpaceIgnored = function (a, b, currentIndex, classTypes) {\n        var current = classTypes[currentIndex];\n        if (Array.isArray(a) ? a.indexOf(current) !== -1 : a === current) {\n            var i = currentIndex;\n            while (i <= classTypes.length) {\n                i++;\n                var next = classTypes[i];\n                if (next === b) {\n                    return true;\n                }\n                if (next !== SP) {\n                    break;\n                }\n            }\n        }\n        if (current === SP) {\n            var i = currentIndex;\n            while (i > 0) {\n                i--;\n                var prev = classTypes[i];\n                if (Array.isArray(a) ? a.indexOf(prev) !== -1 : a === prev) {\n                    var n = currentIndex;\n                    while (n <= classTypes.length) {\n                        n++;\n                        var next = classTypes[n];\n                        if (next === b) {\n                            return true;\n                        }\n                        if (next !== SP) {\n                            break;\n                        }\n                    }\n                }\n                if (prev !== SP) {\n                    break;\n                }\n            }\n        }\n        return false;\n    };\n    var previousNonSpaceClassType = function (currentIndex, classTypes) {\n        var i = currentIndex;\n        while (i >= 0) {\n            var type = classTypes[i];\n            if (type === SP) {\n                i--;\n            }\n            else {\n                return type;\n            }\n        }\n        return 0;\n    };\n    var _lineBreakAtIndex = function (codePoints, classTypes, indicies, index, forbiddenBreaks) {\n        if (indicies[index] === 0) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        var currentIndex = index - 1;\n        if (Array.isArray(forbiddenBreaks) && forbiddenBreaks[currentIndex] === true) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        var beforeIndex = currentIndex - 1;\n        var afterIndex = currentIndex + 1;\n        var current = classTypes[currentIndex];\n        // LB4 Always break after hard line breaks.\n        // LB5 Treat CR followed by LF, as well as CR, LF, and NL as hard line breaks.\n        var before = beforeIndex >= 0 ? classTypes[beforeIndex] : 0;\n        var next = classTypes[afterIndex];\n        if (current === CR$1 && next === LF$1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        if (HARD_LINE_BREAKS.indexOf(current) !== -1) {\n            return BREAK_MANDATORY;\n        }\n        // LB6 Do not break before hard line breaks.\n        if (HARD_LINE_BREAKS.indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB7 Do not break before spaces or zero width space.\n        if (SPACE$1.indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB8 Break before any character following a zero-width space, even if one or more spaces intervene.\n        if (previousNonSpaceClassType(currentIndex, classTypes) === ZW) {\n            return BREAK_ALLOWED$1;\n        }\n        // LB8a Do not break after a zero width joiner.\n        if (UnicodeTrie$1.get(codePoints[currentIndex]) === ZWJ$1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // zwj emojis\n        if ((current === EB || current === EM) && UnicodeTrie$1.get(codePoints[afterIndex]) === ZWJ$1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB11 Do not break before or after Word joiner and related characters.\n        if (current === WJ || next === WJ) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB12 Do not break after NBSP and related characters.\n        if (current === GL) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB12a Do not break before NBSP and related characters, except after spaces and hyphens.\n        if ([SP, BA, HY].indexOf(current) === -1 && next === GL) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB13 Do not break before ‘]’ or ‘!’ or ‘;’ or ‘/’, even after spaces.\n        if ([CL, CP, EX, IS, SY].indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB14 Do not break after ‘[’, even after spaces.\n        if (previousNonSpaceClassType(currentIndex, classTypes) === OP) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB15 Do not break within ‘”[’, even with intervening spaces.\n        if (isAdjacentWithSpaceIgnored(QU, OP, currentIndex, classTypes)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB16 Do not break between closing punctuation and a nonstarter (lb=NS), even with intervening spaces.\n        if (isAdjacentWithSpaceIgnored([CL, CP], NS, currentIndex, classTypes)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB17 Do not break within ‘——’, even with intervening spaces.\n        if (isAdjacentWithSpaceIgnored(B2, B2, currentIndex, classTypes)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB18 Break after spaces.\n        if (current === SP) {\n            return BREAK_ALLOWED$1;\n        }\n        // LB19 Do not break before or after quotation marks, such as ‘ ” ’.\n        if (current === QU || next === QU) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB20 Break before and after unresolved CB.\n        if (next === CB || current === CB) {\n            return BREAK_ALLOWED$1;\n        }\n        // LB21 Do not break before hyphen-minus, other hyphens, fixed-width spaces, small kana, and other non-starters, or after acute accents.\n        if ([BA, HY, NS].indexOf(next) !== -1 || current === BB) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB21a Don't break after Hebrew + Hyphen.\n        if (before === HL && HYPHEN.indexOf(current) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB21b Don’t break between Solidus and Hebrew letters.\n        if (current === SY && next === HL) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB22 Do not break before ellipsis.\n        if (next === IN) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB23 Do not break between digits and letters.\n        if ((ALPHABETICS.indexOf(next) !== -1 && current === NU) || (ALPHABETICS.indexOf(current) !== -1 && next === NU)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB23a Do not break between numeric prefixes and ideographs, or between ideographs and numeric postfixes.\n        if ((current === PR && [ID, EB, EM].indexOf(next) !== -1) ||\n            ([ID, EB, EM].indexOf(current) !== -1 && next === PO)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB24 Do not break between numeric prefix/postfix and letters, or between letters and prefix/postfix.\n        if ((ALPHABETICS.indexOf(current) !== -1 && PREFIX_POSTFIX.indexOf(next) !== -1) ||\n            (PREFIX_POSTFIX.indexOf(current) !== -1 && ALPHABETICS.indexOf(next) !== -1)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB25 Do not break between the following pairs of classes relevant to numbers:\n        if (\n        // (PR | PO) × ( OP | HY )? NU\n        ([PR, PO].indexOf(current) !== -1 &&\n            (next === NU || ([OP, HY].indexOf(next) !== -1 && classTypes[afterIndex + 1] === NU))) ||\n            // ( OP | HY ) × NU\n            ([OP, HY].indexOf(current) !== -1 && next === NU) ||\n            // NU ×\t(NU | SY | IS)\n            (current === NU && [NU, SY, IS].indexOf(next) !== -1)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // NU (NU | SY | IS)* × (NU | SY | IS | CL | CP)\n        if ([NU, SY, IS, CL, CP].indexOf(next) !== -1) {\n            var prevIndex = currentIndex;\n            while (prevIndex >= 0) {\n                var type = classTypes[prevIndex];\n                if (type === NU) {\n                    return BREAK_NOT_ALLOWED$1;\n                }\n                else if ([SY, IS].indexOf(type) !== -1) {\n                    prevIndex--;\n                }\n                else {\n                    break;\n                }\n            }\n        }\n        // NU (NU | SY | IS)* (CL | CP)? × (PO | PR))\n        if ([PR, PO].indexOf(next) !== -1) {\n            var prevIndex = [CL, CP].indexOf(current) !== -1 ? beforeIndex : currentIndex;\n            while (prevIndex >= 0) {\n                var type = classTypes[prevIndex];\n                if (type === NU) {\n                    return BREAK_NOT_ALLOWED$1;\n                }\n                else if ([SY, IS].indexOf(type) !== -1) {\n                    prevIndex--;\n                }\n                else {\n                    break;\n                }\n            }\n        }\n        // LB26 Do not break a Korean syllable.\n        if ((JL === current && [JL, JV, H2, H3].indexOf(next) !== -1) ||\n            ([JV, H2].indexOf(current) !== -1 && [JV, JT].indexOf(next) !== -1) ||\n            ([JT, H3].indexOf(current) !== -1 && next === JT)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB27 Treat a Korean Syllable Block the same as ID.\n        if ((KOREAN_SYLLABLE_BLOCK.indexOf(current) !== -1 && [IN, PO].indexOf(next) !== -1) ||\n            (KOREAN_SYLLABLE_BLOCK.indexOf(next) !== -1 && current === PR)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB28 Do not break between alphabetics (“at”).\n        if (ALPHABETICS.indexOf(current) !== -1 && ALPHABETICS.indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB29 Do not break between numeric punctuation and alphabetics (“e.g.”).\n        if (current === IS && ALPHABETICS.indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB30 Do not break between letters, numbers, or ordinary symbols and opening or closing parentheses.\n        if ((ALPHABETICS.concat(NU).indexOf(current) !== -1 &&\n            next === OP &&\n            ea_OP.indexOf(codePoints[afterIndex]) === -1) ||\n            (ALPHABETICS.concat(NU).indexOf(next) !== -1 && current === CP)) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        // LB30a Break between two regional indicator symbols if and only if there are an even number of regional\n        // indicators preceding the position of the break.\n        if (current === RI$1 && next === RI$1) {\n            var i = indicies[currentIndex];\n            var count = 1;\n            while (i > 0) {\n                i--;\n                if (classTypes[i] === RI$1) {\n                    count++;\n                }\n                else {\n                    break;\n                }\n            }\n            if (count % 2 !== 0) {\n                return BREAK_NOT_ALLOWED$1;\n            }\n        }\n        // LB30b Do not break between an emoji base and an emoji modifier.\n        if (current === EB && next === EM) {\n            return BREAK_NOT_ALLOWED$1;\n        }\n        return BREAK_ALLOWED$1;\n    };\n    var cssFormattedClasses = function (codePoints, options) {\n        if (!options) {\n            options = { lineBreak: 'normal', wordBreak: 'normal' };\n        }\n        var _a = codePointsToCharacterClasses(codePoints, options.lineBreak), indicies = _a[0], classTypes = _a[1], isLetterNumber = _a[2];\n        if (options.wordBreak === 'break-all' || options.wordBreak === 'break-word') {\n            classTypes = classTypes.map(function (type) { return ([NU, AL, SA].indexOf(type) !== -1 ? ID : type); });\n        }\n        var forbiddenBreakpoints = options.wordBreak === 'keep-all'\n            ? isLetterNumber.map(function (letterNumber, i) {\n                return letterNumber && codePoints[i] >= 0x4e00 && codePoints[i] <= 0x9fff;\n            })\n            : undefined;\n        return [indicies, classTypes, forbiddenBreakpoints];\n    };\n    var Break = /** @class */ (function () {\n        function Break(codePoints, lineBreak, start, end) {\n            this.codePoints = codePoints;\n            this.required = lineBreak === BREAK_MANDATORY;\n            this.start = start;\n            this.end = end;\n        }\n        Break.prototype.slice = function () {\n            return fromCodePoint$1.apply(void 0, this.codePoints.slice(this.start, this.end));\n        };\n        return Break;\n    }());\n    var LineBreaker = function (str, options) {\n        var codePoints = toCodePoints$1(str);\n        var _a = cssFormattedClasses(codePoints, options), indicies = _a[0], classTypes = _a[1], forbiddenBreakpoints = _a[2];\n        var length = codePoints.length;\n        var lastEnd = 0;\n        var nextIndex = 0;\n        return {\n            next: function () {\n                if (nextIndex >= length) {\n                    return { done: true, value: null };\n                }\n                var lineBreak = BREAK_NOT_ALLOWED$1;\n                while (nextIndex < length &&\n                    (lineBreak = _lineBreakAtIndex(codePoints, classTypes, indicies, ++nextIndex, forbiddenBreakpoints)) ===\n                        BREAK_NOT_ALLOWED$1) { }\n                if (lineBreak !== BREAK_NOT_ALLOWED$1 || nextIndex === length) {\n                    var value = new Break(codePoints, lineBreak, lastEnd, nextIndex);\n                    lastEnd = nextIndex;\n                    return { value: value, done: false };\n                }\n                return { done: true, value: null };\n            },\n        };\n    };\n\n    // https://www.w3.org/TR/css-syntax-3\n    var FLAG_UNRESTRICTED = 1 << 0;\n    var FLAG_ID = 1 << 1;\n    var FLAG_INTEGER = 1 << 2;\n    var FLAG_NUMBER = 1 << 3;\n    var LINE_FEED = 0x000a;\n    var SOLIDUS = 0x002f;\n    var REVERSE_SOLIDUS = 0x005c;\n    var CHARACTER_TABULATION = 0x0009;\n    var SPACE = 0x0020;\n    var QUOTATION_MARK = 0x0022;\n    var EQUALS_SIGN = 0x003d;\n    var NUMBER_SIGN = 0x0023;\n    var DOLLAR_SIGN = 0x0024;\n    var PERCENTAGE_SIGN = 0x0025;\n    var APOSTROPHE = 0x0027;\n    var LEFT_PARENTHESIS = 0x0028;\n    var RIGHT_PARENTHESIS = 0x0029;\n    var LOW_LINE = 0x005f;\n    var HYPHEN_MINUS = 0x002d;\n    var EXCLAMATION_MARK = 0x0021;\n    var LESS_THAN_SIGN = 0x003c;\n    var GREATER_THAN_SIGN = 0x003e;\n    var COMMERCIAL_AT = 0x0040;\n    var LEFT_SQUARE_BRACKET = 0x005b;\n    var RIGHT_SQUARE_BRACKET = 0x005d;\n    var CIRCUMFLEX_ACCENT = 0x003d;\n    var LEFT_CURLY_BRACKET = 0x007b;\n    var QUESTION_MARK = 0x003f;\n    var RIGHT_CURLY_BRACKET = 0x007d;\n    var VERTICAL_LINE = 0x007c;\n    var TILDE = 0x007e;\n    var CONTROL = 0x0080;\n    var REPLACEMENT_CHARACTER = 0xfffd;\n    var ASTERISK = 0x002a;\n    var PLUS_SIGN = 0x002b;\n    var COMMA = 0x002c;\n    var COLON = 0x003a;\n    var SEMICOLON = 0x003b;\n    var FULL_STOP = 0x002e;\n    var NULL = 0x0000;\n    var BACKSPACE = 0x0008;\n    var LINE_TABULATION = 0x000b;\n    var SHIFT_OUT = 0x000e;\n    var INFORMATION_SEPARATOR_ONE = 0x001f;\n    var DELETE = 0x007f;\n    var EOF = -1;\n    var ZERO = 0x0030;\n    var a = 0x0061;\n    var e = 0x0065;\n    var f = 0x0066;\n    var u = 0x0075;\n    var z = 0x007a;\n    var A = 0x0041;\n    var E = 0x0045;\n    var F = 0x0046;\n    var U = 0x0055;\n    var Z = 0x005a;\n    var isDigit = function (codePoint) { return codePoint >= ZERO && codePoint <= 0x0039; };\n    var isSurrogateCodePoint = function (codePoint) { return codePoint >= 0xd800 && codePoint <= 0xdfff; };\n    var isHex = function (codePoint) {\n        return isDigit(codePoint) || (codePoint >= A && codePoint <= F) || (codePoint >= a && codePoint <= f);\n    };\n    var isLowerCaseLetter = function (codePoint) { return codePoint >= a && codePoint <= z; };\n    var isUpperCaseLetter = function (codePoint) { return codePoint >= A && codePoint <= Z; };\n    var isLetter = function (codePoint) { return isLowerCaseLetter(codePoint) || isUpperCaseLetter(codePoint); };\n    var isNonASCIICodePoint = function (codePoint) { return codePoint >= CONTROL; };\n    var isWhiteSpace = function (codePoint) {\n        return codePoint === LINE_FEED || codePoint === CHARACTER_TABULATION || codePoint === SPACE;\n    };\n    var isNameStartCodePoint = function (codePoint) {\n        return isLetter(codePoint) || isNonASCIICodePoint(codePoint) || codePoint === LOW_LINE;\n    };\n    var isNameCodePoint = function (codePoint) {\n        return isNameStartCodePoint(codePoint) || isDigit(codePoint) || codePoint === HYPHEN_MINUS;\n    };\n    var isNonPrintableCodePoint = function (codePoint) {\n        return ((codePoint >= NULL && codePoint <= BACKSPACE) ||\n            codePoint === LINE_TABULATION ||\n            (codePoint >= SHIFT_OUT && codePoint <= INFORMATION_SEPARATOR_ONE) ||\n            codePoint === DELETE);\n    };\n    var isValidEscape = function (c1, c2) {\n        if (c1 !== REVERSE_SOLIDUS) {\n            return false;\n        }\n        return c2 !== LINE_FEED;\n    };\n    var isIdentifierStart = function (c1, c2, c3) {\n        if (c1 === HYPHEN_MINUS) {\n            return isNameStartCodePoint(c2) || isValidEscape(c2, c3);\n        }\n        else if (isNameStartCodePoint(c1)) {\n            return true;\n        }\n        else if (c1 === REVERSE_SOLIDUS && isValidEscape(c1, c2)) {\n            return true;\n        }\n        return false;\n    };\n    var isNumberStart = function (c1, c2, c3) {\n        if (c1 === PLUS_SIGN || c1 === HYPHEN_MINUS) {\n            if (isDigit(c2)) {\n                return true;\n            }\n            return c2 === FULL_STOP && isDigit(c3);\n        }\n        if (c1 === FULL_STOP) {\n            return isDigit(c2);\n        }\n        return isDigit(c1);\n    };\n    var stringToNumber = function (codePoints) {\n        var c = 0;\n        var sign = 1;\n        if (codePoints[c] === PLUS_SIGN || codePoints[c] === HYPHEN_MINUS) {\n            if (codePoints[c] === HYPHEN_MINUS) {\n                sign = -1;\n            }\n            c++;\n        }\n        var integers = [];\n        while (isDigit(codePoints[c])) {\n            integers.push(codePoints[c++]);\n        }\n        var int = integers.length ? parseInt(fromCodePoint$1.apply(void 0, integers), 10) : 0;\n        if (codePoints[c] === FULL_STOP) {\n            c++;\n        }\n        var fraction = [];\n        while (isDigit(codePoints[c])) {\n            fraction.push(codePoints[c++]);\n        }\n        var fracd = fraction.length;\n        var frac = fracd ? parseInt(fromCodePoint$1.apply(void 0, fraction), 10) : 0;\n        if (codePoints[c] === E || codePoints[c] === e) {\n            c++;\n        }\n        var expsign = 1;\n        if (codePoints[c] === PLUS_SIGN || codePoints[c] === HYPHEN_MINUS) {\n            if (codePoints[c] === HYPHEN_MINUS) {\n                expsign = -1;\n            }\n            c++;\n        }\n        var exponent = [];\n        while (isDigit(codePoints[c])) {\n            exponent.push(codePoints[c++]);\n        }\n        var exp = exponent.length ? parseInt(fromCodePoint$1.apply(void 0, exponent), 10) : 0;\n        return sign * (int + frac * Math.pow(10, -fracd)) * Math.pow(10, expsign * exp);\n    };\n    var LEFT_PARENTHESIS_TOKEN = {\n        type: 2 /* LEFT_PARENTHESIS_TOKEN */\n    };\n    var RIGHT_PARENTHESIS_TOKEN = {\n        type: 3 /* RIGHT_PARENTHESIS_TOKEN */\n    };\n    var COMMA_TOKEN = { type: 4 /* COMMA_TOKEN */ };\n    var SUFFIX_MATCH_TOKEN = { type: 13 /* SUFFIX_MATCH_TOKEN */ };\n    var PREFIX_MATCH_TOKEN = { type: 8 /* PREFIX_MATCH_TOKEN */ };\n    var COLUMN_TOKEN = { type: 21 /* COLUMN_TOKEN */ };\n    var DASH_MATCH_TOKEN = { type: 9 /* DASH_MATCH_TOKEN */ };\n    var INCLUDE_MATCH_TOKEN = { type: 10 /* INCLUDE_MATCH_TOKEN */ };\n    var LEFT_CURLY_BRACKET_TOKEN = {\n        type: 11 /* LEFT_CURLY_BRACKET_TOKEN */\n    };\n    var RIGHT_CURLY_BRACKET_TOKEN = {\n        type: 12 /* RIGHT_CURLY_BRACKET_TOKEN */\n    };\n    var SUBSTRING_MATCH_TOKEN = { type: 14 /* SUBSTRING_MATCH_TOKEN */ };\n    var BAD_URL_TOKEN = { type: 23 /* BAD_URL_TOKEN */ };\n    var BAD_STRING_TOKEN = { type: 1 /* BAD_STRING_TOKEN */ };\n    var CDO_TOKEN = { type: 25 /* CDO_TOKEN */ };\n    var CDC_TOKEN = { type: 24 /* CDC_TOKEN */ };\n    var COLON_TOKEN = { type: 26 /* COLON_TOKEN */ };\n    var SEMICOLON_TOKEN = { type: 27 /* SEMICOLON_TOKEN */ };\n    var LEFT_SQUARE_BRACKET_TOKEN = {\n        type: 28 /* LEFT_SQUARE_BRACKET_TOKEN */\n    };\n    var RIGHT_SQUARE_BRACKET_TOKEN = {\n        type: 29 /* RIGHT_SQUARE_BRACKET_TOKEN */\n    };\n    var WHITESPACE_TOKEN = { type: 31 /* WHITESPACE_TOKEN */ };\n    var EOF_TOKEN = { type: 32 /* EOF_TOKEN */ };\n    var Tokenizer = /** @class */ (function () {\n        function Tokenizer() {\n            this._value = [];\n        }\n        Tokenizer.prototype.write = function (chunk) {\n            this._value = this._value.concat(toCodePoints$1(chunk));\n        };\n        Tokenizer.prototype.read = function () {\n            var tokens = [];\n            var token = this.consumeToken();\n            while (token !== EOF_TOKEN) {\n                tokens.push(token);\n                token = this.consumeToken();\n            }\n            return tokens;\n        };\n        Tokenizer.prototype.consumeToken = function () {\n            var codePoint = this.consumeCodePoint();\n            switch (codePoint) {\n                case QUOTATION_MARK:\n                    return this.consumeStringToken(QUOTATION_MARK);\n                case NUMBER_SIGN:\n                    var c1 = this.peekCodePoint(0);\n                    var c2 = this.peekCodePoint(1);\n                    var c3 = this.peekCodePoint(2);\n                    if (isNameCodePoint(c1) || isValidEscape(c2, c3)) {\n                        var flags = isIdentifierStart(c1, c2, c3) ? FLAG_ID : FLAG_UNRESTRICTED;\n                        var value = this.consumeName();\n                        return { type: 5 /* HASH_TOKEN */, value: value, flags: flags };\n                    }\n                    break;\n                case DOLLAR_SIGN:\n                    if (this.peekCodePoint(0) === EQUALS_SIGN) {\n                        this.consumeCodePoint();\n                        return SUFFIX_MATCH_TOKEN;\n                    }\n                    break;\n                case APOSTROPHE:\n                    return this.consumeStringToken(APOSTROPHE);\n                case LEFT_PARENTHESIS:\n                    return LEFT_PARENTHESIS_TOKEN;\n                case RIGHT_PARENTHESIS:\n                    return RIGHT_PARENTHESIS_TOKEN;\n                case ASTERISK:\n                    if (this.peekCodePoint(0) === EQUALS_SIGN) {\n                        this.consumeCodePoint();\n                        return SUBSTRING_MATCH_TOKEN;\n                    }\n                    break;\n                case PLUS_SIGN:\n                    if (isNumberStart(codePoint, this.peekCodePoint(0), this.peekCodePoint(1))) {\n                        this.reconsumeCodePoint(codePoint);\n                        return this.consumeNumericToken();\n                    }\n                    break;\n                case COMMA:\n                    return COMMA_TOKEN;\n                case HYPHEN_MINUS:\n                    var e1 = codePoint;\n                    var e2 = this.peekCodePoint(0);\n                    var e3 = this.peekCodePoint(1);\n                    if (isNumberStart(e1, e2, e3)) {\n                        this.reconsumeCodePoint(codePoint);\n                        return this.consumeNumericToken();\n                    }\n                    if (isIdentifierStart(e1, e2, e3)) {\n                        this.reconsumeCodePoint(codePoint);\n                        return this.consumeIdentLikeToken();\n                    }\n                    if (e2 === HYPHEN_MINUS && e3 === GREATER_THAN_SIGN) {\n                        this.consumeCodePoint();\n                        this.consumeCodePoint();\n                        return CDC_TOKEN;\n                    }\n                    break;\n                case FULL_STOP:\n                    if (isNumberStart(codePoint, this.peekCodePoint(0), this.peekCodePoint(1))) {\n                        this.reconsumeCodePoint(codePoint);\n                        return this.consumeNumericToken();\n                    }\n                    break;\n                case SOLIDUS:\n                    if (this.peekCodePoint(0) === ASTERISK) {\n                        this.consumeCodePoint();\n                        while (true) {\n                            var c = this.consumeCodePoint();\n                            if (c === ASTERISK) {\n                                c = this.consumeCodePoint();\n                                if (c === SOLIDUS) {\n                                    return this.consumeToken();\n                                }\n                            }\n                            if (c === EOF) {\n                                return this.consumeToken();\n                            }\n                        }\n                    }\n                    break;\n                case COLON:\n                    return COLON_TOKEN;\n                case SEMICOLON:\n                    return SEMICOLON_TOKEN;\n                case LESS_THAN_SIGN:\n                    if (this.peekCodePoint(0) === EXCLAMATION_MARK &&\n                        this.peekCodePoint(1) === HYPHEN_MINUS &&\n                        this.peekCodePoint(2) === HYPHEN_MINUS) {\n                        this.consumeCodePoint();\n                        this.consumeCodePoint();\n                        return CDO_TOKEN;\n                    }\n                    break;\n                case COMMERCIAL_AT:\n                    var a1 = this.peekCodePoint(0);\n                    var a2 = this.peekCodePoint(1);\n                    var a3 = this.peekCodePoint(2);\n                    if (isIdentifierStart(a1, a2, a3)) {\n                        var value = this.consumeName();\n                        return { type: 7 /* AT_KEYWORD_TOKEN */, value: value };\n                    }\n                    break;\n                case LEFT_SQUARE_BRACKET:\n                    return LEFT_SQUARE_BRACKET_TOKEN;\n                case REVERSE_SOLIDUS:\n                    if (isValidEscape(codePoint, this.peekCodePoint(0))) {\n                        this.reconsumeCodePoint(codePoint);\n                        return this.consumeIdentLikeToken();\n                    }\n                    break;\n                case RIGHT_SQUARE_BRACKET:\n                    return RIGHT_SQUARE_BRACKET_TOKEN;\n                case CIRCUMFLEX_ACCENT:\n                    if (this.peekCodePoint(0) === EQUALS_SIGN) {\n                        this.consumeCodePoint();\n                        return PREFIX_MATCH_TOKEN;\n                    }\n                    break;\n                case LEFT_CURLY_BRACKET:\n                    return LEFT_CURLY_BRACKET_TOKEN;\n                case RIGHT_CURLY_BRACKET:\n                    return RIGHT_CURLY_BRACKET_TOKEN;\n                case u:\n                case U:\n                    var u1 = this.peekCodePoint(0);\n                    var u2 = this.peekCodePoint(1);\n                    if (u1 === PLUS_SIGN && (isHex(u2) || u2 === QUESTION_MARK)) {\n                        this.consumeCodePoint();\n                        this.consumeUnicodeRangeToken();\n                    }\n                    this.reconsumeCodePoint(codePoint);\n                    return this.consumeIdentLikeToken();\n                case VERTICAL_LINE:\n                    if (this.peekCodePoint(0) === EQUALS_SIGN) {\n                        this.consumeCodePoint();\n                        return DASH_MATCH_TOKEN;\n                    }\n                    if (this.peekCodePoint(0) === VERTICAL_LINE) {\n                        this.consumeCodePoint();\n                        return COLUMN_TOKEN;\n                    }\n                    break;\n                case TILDE:\n                    if (this.peekCodePoint(0) === EQUALS_SIGN) {\n                        this.consumeCodePoint();\n                        return INCLUDE_MATCH_TOKEN;\n                    }\n                    break;\n                case EOF:\n                    return EOF_TOKEN;\n            }\n            if (isWhiteSpace(codePoint)) {\n                this.consumeWhiteSpace();\n                return WHITESPACE_TOKEN;\n            }\n            if (isDigit(codePoint)) {\n                this.reconsumeCodePoint(codePoint);\n                return this.consumeNumericToken();\n            }\n            if (isNameStartCodePoint(codePoint)) {\n                this.reconsumeCodePoint(codePoint);\n                return this.consumeIdentLikeToken();\n            }\n            return { type: 6 /* DELIM_TOKEN */, value: fromCodePoint$1(codePoint) };\n        };\n        Tokenizer.prototype.consumeCodePoint = function () {\n            var value = this._value.shift();\n            return typeof value === 'undefined' ? -1 : value;\n        };\n        Tokenizer.prototype.reconsumeCodePoint = function (codePoint) {\n            this._value.unshift(codePoint);\n        };\n        Tokenizer.prototype.peekCodePoint = function (delta) {\n            if (delta >= this._value.length) {\n                return -1;\n            }\n            return this._value[delta];\n        };\n        Tokenizer.prototype.consumeUnicodeRangeToken = function () {\n            var digits = [];\n            var codePoint = this.consumeCodePoint();\n            while (isHex(codePoint) && digits.length < 6) {\n                digits.push(codePoint);\n                codePoint = this.consumeCodePoint();\n            }\n            var questionMarks = false;\n            while (codePoint === QUESTION_MARK && digits.length < 6) {\n                digits.push(codePoint);\n                codePoint = this.consumeCodePoint();\n                questionMarks = true;\n            }\n            if (questionMarks) {\n                var start_1 = parseInt(fromCodePoint$1.apply(void 0, digits.map(function (digit) { return (digit === QUESTION_MARK ? ZERO : digit); })), 16);\n                var end = parseInt(fromCodePoint$1.apply(void 0, digits.map(function (digit) { return (digit === QUESTION_MARK ? F : digit); })), 16);\n                return { type: 30 /* UNICODE_RANGE_TOKEN */, start: start_1, end: end };\n            }\n            var start = parseInt(fromCodePoint$1.apply(void 0, digits), 16);\n            if (this.peekCodePoint(0) === HYPHEN_MINUS && isHex(this.peekCodePoint(1))) {\n                this.consumeCodePoint();\n                codePoint = this.consumeCodePoint();\n                var endDigits = [];\n                while (isHex(codePoint) && endDigits.length < 6) {\n                    endDigits.push(codePoint);\n                    codePoint = this.consumeCodePoint();\n                }\n                var end = parseInt(fromCodePoint$1.apply(void 0, endDigits), 16);\n                return { type: 30 /* UNICODE_RANGE_TOKEN */, start: start, end: end };\n            }\n            else {\n                return { type: 30 /* UNICODE_RANGE_TOKEN */, start: start, end: start };\n            }\n        };\n        Tokenizer.prototype.consumeIdentLikeToken = function () {\n            var value = this.consumeName();\n            if (value.toLowerCase() === 'url' && this.peekCodePoint(0) === LEFT_PARENTHESIS) {\n                this.consumeCodePoint();\n                return this.consumeUrlToken();\n            }\n            else if (this.peekCodePoint(0) === LEFT_PARENTHESIS) {\n                this.consumeCodePoint();\n                return { type: 19 /* FUNCTION_TOKEN */, value: value };\n            }\n            return { type: 20 /* IDENT_TOKEN */, value: value };\n        };\n        Tokenizer.prototype.consumeUrlToken = function () {\n            var value = [];\n            this.consumeWhiteSpace();\n            if (this.peekCodePoint(0) === EOF) {\n                return { type: 22 /* URL_TOKEN */, value: '' };\n            }\n            var next = this.peekCodePoint(0);\n            if (next === APOSTROPHE || next === QUOTATION_MARK) {\n                var stringToken = this.consumeStringToken(this.consumeCodePoint());\n                if (stringToken.type === 0 /* STRING_TOKEN */) {\n                    this.consumeWhiteSpace();\n                    if (this.peekCodePoint(0) === EOF || this.peekCodePoint(0) === RIGHT_PARENTHESIS) {\n                        this.consumeCodePoint();\n                        return { type: 22 /* URL_TOKEN */, value: stringToken.value };\n                    }\n                }\n                this.consumeBadUrlRemnants();\n                return BAD_URL_TOKEN;\n            }\n            while (true) {\n                var codePoint = this.consumeCodePoint();\n                if (codePoint === EOF || codePoint === RIGHT_PARENTHESIS) {\n                    return { type: 22 /* URL_TOKEN */, value: fromCodePoint$1.apply(void 0, value) };\n                }\n                else if (isWhiteSpace(codePoint)) {\n                    this.consumeWhiteSpace();\n                    if (this.peekCodePoint(0) === EOF || this.peekCodePoint(0) === RIGHT_PARENTHESIS) {\n                        this.consumeCodePoint();\n                        return { type: 22 /* URL_TOKEN */, value: fromCodePoint$1.apply(void 0, value) };\n                    }\n                    this.consumeBadUrlRemnants();\n                    return BAD_URL_TOKEN;\n                }\n                else if (codePoint === QUOTATION_MARK ||\n                    codePoint === APOSTROPHE ||\n                    codePoint === LEFT_PARENTHESIS ||\n                    isNonPrintableCodePoint(codePoint)) {\n                    this.consumeBadUrlRemnants();\n                    return BAD_URL_TOKEN;\n                }\n                else if (codePoint === REVERSE_SOLIDUS) {\n                    if (isValidEscape(codePoint, this.peekCodePoint(0))) {\n                        value.push(this.consumeEscapedCodePoint());\n                    }\n                    else {\n                        this.consumeBadUrlRemnants();\n                        return BAD_URL_TOKEN;\n                    }\n                }\n                else {\n                    value.push(codePoint);\n                }\n            }\n        };\n        Tokenizer.prototype.consumeWhiteSpace = function () {\n            while (isWhiteSpace(this.peekCodePoint(0))) {\n                this.consumeCodePoint();\n            }\n        };\n        Tokenizer.prototype.consumeBadUrlRemnants = function () {\n            while (true) {\n                var codePoint = this.consumeCodePoint();\n                if (codePoint === RIGHT_PARENTHESIS || codePoint === EOF) {\n                    return;\n                }\n                if (isValidEscape(codePoint, this.peekCodePoint(0))) {\n                    this.consumeEscapedCodePoint();\n                }\n            }\n        };\n        Tokenizer.prototype.consumeStringSlice = function (count) {\n            var SLICE_STACK_SIZE = 50000;\n            var value = '';\n            while (count > 0) {\n                var amount = Math.min(SLICE_STACK_SIZE, count);\n                value += fromCodePoint$1.apply(void 0, this._value.splice(0, amount));\n                count -= amount;\n            }\n            this._value.shift();\n            return value;\n        };\n        Tokenizer.prototype.consumeStringToken = function (endingCodePoint) {\n            var value = '';\n            var i = 0;\n            do {\n                var codePoint = this._value[i];\n                if (codePoint === EOF || codePoint === undefined || codePoint === endingCodePoint) {\n                    value += this.consumeStringSlice(i);\n                    return { type: 0 /* STRING_TOKEN */, value: value };\n                }\n                if (codePoint === LINE_FEED) {\n                    this._value.splice(0, i);\n                    return BAD_STRING_TOKEN;\n                }\n                if (codePoint === REVERSE_SOLIDUS) {\n                    var next = this._value[i + 1];\n                    if (next !== EOF && next !== undefined) {\n                        if (next === LINE_FEED) {\n                            value += this.consumeStringSlice(i);\n                            i = -1;\n                            this._value.shift();\n                        }\n                        else if (isValidEscape(codePoint, next)) {\n                            value += this.consumeStringSlice(i);\n                            value += fromCodePoint$1(this.consumeEscapedCodePoint());\n                            i = -1;\n                        }\n                    }\n                }\n                i++;\n            } while (true);\n        };\n        Tokenizer.prototype.consumeNumber = function () {\n            var repr = [];\n            var type = FLAG_INTEGER;\n            var c1 = this.peekCodePoint(0);\n            if (c1 === PLUS_SIGN || c1 === HYPHEN_MINUS) {\n                repr.push(this.consumeCodePoint());\n            }\n            while (isDigit(this.peekCodePoint(0))) {\n                repr.push(this.consumeCodePoint());\n            }\n            c1 = this.peekCodePoint(0);\n            var c2 = this.peekCodePoint(1);\n            if (c1 === FULL_STOP && isDigit(c2)) {\n                repr.push(this.consumeCodePoint(), this.consumeCodePoint());\n                type = FLAG_NUMBER;\n                while (isDigit(this.peekCodePoint(0))) {\n                    repr.push(this.consumeCodePoint());\n                }\n            }\n            c1 = this.peekCodePoint(0);\n            c2 = this.peekCodePoint(1);\n            var c3 = this.peekCodePoint(2);\n            if ((c1 === E || c1 === e) && (((c2 === PLUS_SIGN || c2 === HYPHEN_MINUS) && isDigit(c3)) || isDigit(c2))) {\n                repr.push(this.consumeCodePoint(), this.consumeCodePoint());\n                type = FLAG_NUMBER;\n                while (isDigit(this.peekCodePoint(0))) {\n                    repr.push(this.consumeCodePoint());\n                }\n            }\n            return [stringToNumber(repr), type];\n        };\n        Tokenizer.prototype.consumeNumericToken = function () {\n            var _a = this.consumeNumber(), number = _a[0], flags = _a[1];\n            var c1 = this.peekCodePoint(0);\n            var c2 = this.peekCodePoint(1);\n            var c3 = this.peekCodePoint(2);\n            if (isIdentifierStart(c1, c2, c3)) {\n                var unit = this.consumeName();\n                return { type: 15 /* DIMENSION_TOKEN */, number: number, flags: flags, unit: unit };\n            }\n            if (c1 === PERCENTAGE_SIGN) {\n                this.consumeCodePoint();\n                return { type: 16 /* PERCENTAGE_TOKEN */, number: number, flags: flags };\n            }\n            return { type: 17 /* NUMBER_TOKEN */, number: number, flags: flags };\n        };\n        Tokenizer.prototype.consumeEscapedCodePoint = function () {\n            var codePoint = this.consumeCodePoint();\n            if (isHex(codePoint)) {\n                var hex = fromCodePoint$1(codePoint);\n                while (isHex(this.peekCodePoint(0)) && hex.length < 6) {\n                    hex += fromCodePoint$1(this.consumeCodePoint());\n                }\n                if (isWhiteSpace(this.peekCodePoint(0))) {\n                    this.consumeCodePoint();\n                }\n                var hexCodePoint = parseInt(hex, 16);\n                if (hexCodePoint === 0 || isSurrogateCodePoint(hexCodePoint) || hexCodePoint > 0x10ffff) {\n                    return REPLACEMENT_CHARACTER;\n                }\n                return hexCodePoint;\n            }\n            if (codePoint === EOF) {\n                return REPLACEMENT_CHARACTER;\n            }\n            return codePoint;\n        };\n        Tokenizer.prototype.consumeName = function () {\n            var result = '';\n            while (true) {\n                var codePoint = this.consumeCodePoint();\n                if (isNameCodePoint(codePoint)) {\n                    result += fromCodePoint$1(codePoint);\n                }\n                else if (isValidEscape(codePoint, this.peekCodePoint(0))) {\n                    result += fromCodePoint$1(this.consumeEscapedCodePoint());\n                }\n                else {\n                    this.reconsumeCodePoint(codePoint);\n                    return result;\n                }\n            }\n        };\n        return Tokenizer;\n    }());\n\n    var Parser = /** @class */ (function () {\n        function Parser(tokens) {\n            this._tokens = tokens;\n        }\n        Parser.create = function (value) {\n            var tokenizer = new Tokenizer();\n            tokenizer.write(value);\n            return new Parser(tokenizer.read());\n        };\n        Parser.parseValue = function (value) {\n            return Parser.create(value).parseComponentValue();\n        };\n        Parser.parseValues = function (value) {\n            return Parser.create(value).parseComponentValues();\n        };\n        Parser.prototype.parseComponentValue = function () {\n            var token = this.consumeToken();\n            while (token.type === 31 /* WHITESPACE_TOKEN */) {\n                token = this.consumeToken();\n            }\n            if (token.type === 32 /* EOF_TOKEN */) {\n                throw new SyntaxError(\"Error parsing CSS component value, unexpected EOF\");\n            }\n            this.reconsumeToken(token);\n            var value = this.consumeComponentValue();\n            do {\n                token = this.consumeToken();\n            } while (token.type === 31 /* WHITESPACE_TOKEN */);\n            if (token.type === 32 /* EOF_TOKEN */) {\n                return value;\n            }\n            throw new SyntaxError(\"Error parsing CSS component value, multiple values found when expecting only one\");\n        };\n        Parser.prototype.parseComponentValues = function () {\n            var values = [];\n            while (true) {\n                var value = this.consumeComponentValue();\n                if (value.type === 32 /* EOF_TOKEN */) {\n                    return values;\n                }\n                values.push(value);\n                values.push();\n            }\n        };\n        Parser.prototype.consumeComponentValue = function () {\n            var token = this.consumeToken();\n            switch (token.type) {\n                case 11 /* LEFT_CURLY_BRACKET_TOKEN */:\n                case 28 /* LEFT_SQUARE_BRACKET_TOKEN */:\n                case 2 /* LEFT_PARENTHESIS_TOKEN */:\n                    return this.consumeSimpleBlock(token.type);\n                case 19 /* FUNCTION_TOKEN */:\n                    return this.consumeFunction(token);\n            }\n            return token;\n        };\n        Parser.prototype.consumeSimpleBlock = function (type) {\n            var block = { type: type, values: [] };\n            var token = this.consumeToken();\n            while (true) {\n                if (token.type === 32 /* EOF_TOKEN */ || isEndingTokenFor(token, type)) {\n                    return block;\n                }\n                this.reconsumeToken(token);\n                block.values.push(this.consumeComponentValue());\n                token = this.consumeToken();\n            }\n        };\n        Parser.prototype.consumeFunction = function (functionToken) {\n            var cssFunction = {\n                name: functionToken.value,\n                values: [],\n                type: 18 /* FUNCTION */\n            };\n            while (true) {\n                var token = this.consumeToken();\n                if (token.type === 32 /* EOF_TOKEN */ || token.type === 3 /* RIGHT_PARENTHESIS_TOKEN */) {\n                    return cssFunction;\n                }\n                this.reconsumeToken(token);\n                cssFunction.values.push(this.consumeComponentValue());\n            }\n        };\n        Parser.prototype.consumeToken = function () {\n            var token = this._tokens.shift();\n            return typeof token === 'undefined' ? EOF_TOKEN : token;\n        };\n        Parser.prototype.reconsumeToken = function (token) {\n            this._tokens.unshift(token);\n        };\n        return Parser;\n    }());\n    var isDimensionToken = function (token) { return token.type === 15 /* DIMENSION_TOKEN */; };\n    var isNumberToken = function (token) { return token.type === 17 /* NUMBER_TOKEN */; };\n    var isIdentToken = function (token) { return token.type === 20 /* IDENT_TOKEN */; };\n    var isStringToken = function (token) { return token.type === 0 /* STRING_TOKEN */; };\n    var isIdentWithValue = function (token, value) {\n        return isIdentToken(token) && token.value === value;\n    };\n    var nonWhiteSpace = function (token) { return token.type !== 31 /* WHITESPACE_TOKEN */; };\n    var nonFunctionArgSeparator = function (token) {\n        return token.type !== 31 /* WHITESPACE_TOKEN */ && token.type !== 4 /* COMMA_TOKEN */;\n    };\n    var parseFunctionArgs = function (tokens) {\n        var args = [];\n        var arg = [];\n        tokens.forEach(function (token) {\n            if (token.type === 4 /* COMMA_TOKEN */) {\n                if (arg.length === 0) {\n                    throw new Error(\"Error parsing function args, zero tokens for arg\");\n                }\n                args.push(arg);\n                arg = [];\n                return;\n            }\n            if (token.type !== 31 /* WHITESPACE_TOKEN */) {\n                arg.push(token);\n            }\n        });\n        if (arg.length) {\n            args.push(arg);\n        }\n        return args;\n    };\n    var isEndingTokenFor = function (token, type) {\n        if (type === 11 /* LEFT_CURLY_BRACKET_TOKEN */ && token.type === 12 /* RIGHT_CURLY_BRACKET_TOKEN */) {\n            return true;\n        }\n        if (type === 28 /* LEFT_SQUARE_BRACKET_TOKEN */ && token.type === 29 /* RIGHT_SQUARE_BRACKET_TOKEN */) {\n            return true;\n        }\n        return type === 2 /* LEFT_PARENTHESIS_TOKEN */ && token.type === 3 /* RIGHT_PARENTHESIS_TOKEN */;\n    };\n\n    var isLength = function (token) {\n        return token.type === 17 /* NUMBER_TOKEN */ || token.type === 15 /* DIMENSION_TOKEN */;\n    };\n\n    var isLengthPercentage = function (token) {\n        return token.type === 16 /* PERCENTAGE_TOKEN */ || isLength(token);\n    };\n    var parseLengthPercentageTuple = function (tokens) {\n        return tokens.length > 1 ? [tokens[0], tokens[1]] : [tokens[0]];\n    };\n    var ZERO_LENGTH = {\n        type: 17 /* NUMBER_TOKEN */,\n        number: 0,\n        flags: FLAG_INTEGER\n    };\n    var FIFTY_PERCENT = {\n        type: 16 /* PERCENTAGE_TOKEN */,\n        number: 50,\n        flags: FLAG_INTEGER\n    };\n    var HUNDRED_PERCENT = {\n        type: 16 /* PERCENTAGE_TOKEN */,\n        number: 100,\n        flags: FLAG_INTEGER\n    };\n    var getAbsoluteValueForTuple = function (tuple, width, height) {\n        var x = tuple[0], y = tuple[1];\n        return [getAbsoluteValue(x, width), getAbsoluteValue(typeof y !== 'undefined' ? y : x, height)];\n    };\n    var getAbsoluteValue = function (token, parent) {\n        if (token.type === 16 /* PERCENTAGE_TOKEN */) {\n            return (token.number / 100) * parent;\n        }\n        if (isDimensionToken(token)) {\n            switch (token.unit) {\n                case 'rem':\n                case 'em':\n                    return 16 * token.number; // TODO use correct font-size\n                case 'px':\n                default:\n                    return token.number;\n            }\n        }\n        return token.number;\n    };\n\n    var DEG = 'deg';\n    var GRAD = 'grad';\n    var RAD = 'rad';\n    var TURN = 'turn';\n    var angle = {\n        name: 'angle',\n        parse: function (_context, value) {\n            if (value.type === 15 /* DIMENSION_TOKEN */) {\n                switch (value.unit) {\n                    case DEG:\n                        return (Math.PI * value.number) / 180;\n                    case GRAD:\n                        return (Math.PI / 200) * value.number;\n                    case RAD:\n                        return value.number;\n                    case TURN:\n                        return Math.PI * 2 * value.number;\n                }\n            }\n            throw new Error(\"Unsupported angle type\");\n        }\n    };\n    var isAngle = function (value) {\n        if (value.type === 15 /* DIMENSION_TOKEN */) {\n            if (value.unit === DEG || value.unit === GRAD || value.unit === RAD || value.unit === TURN) {\n                return true;\n            }\n        }\n        return false;\n    };\n    var parseNamedSide = function (tokens) {\n        var sideOrCorner = tokens\n            .filter(isIdentToken)\n            .map(function (ident) { return ident.value; })\n            .join(' ');\n        switch (sideOrCorner) {\n            case 'to bottom right':\n            case 'to right bottom':\n            case 'left top':\n            case 'top left':\n                return [ZERO_LENGTH, ZERO_LENGTH];\n            case 'to top':\n            case 'bottom':\n                return deg(0);\n            case 'to bottom left':\n            case 'to left bottom':\n            case 'right top':\n            case 'top right':\n                return [ZERO_LENGTH, HUNDRED_PERCENT];\n            case 'to right':\n            case 'left':\n                return deg(90);\n            case 'to top left':\n            case 'to left top':\n            case 'right bottom':\n            case 'bottom right':\n                return [HUNDRED_PERCENT, HUNDRED_PERCENT];\n            case 'to bottom':\n            case 'top':\n                return deg(180);\n            case 'to top right':\n            case 'to right top':\n            case 'left bottom':\n            case 'bottom left':\n                return [HUNDRED_PERCENT, ZERO_LENGTH];\n            case 'to left':\n            case 'right':\n                return deg(270);\n        }\n        return 0;\n    };\n    var deg = function (deg) { return (Math.PI * deg) / 180; };\n\n    var color$1 = {\n        name: 'color',\n        parse: function (context, value) {\n            if (value.type === 18 /* FUNCTION */) {\n                var colorFunction = SUPPORTED_COLOR_FUNCTIONS[value.name];\n                if (typeof colorFunction === 'undefined') {\n                    throw new Error(\"Attempting to parse an unsupported color function \\\"\" + value.name + \"\\\"\");\n                }\n                return colorFunction(context, value.values);\n            }\n            if (value.type === 5 /* HASH_TOKEN */) {\n                if (value.value.length === 3) {\n                    var r = value.value.substring(0, 1);\n                    var g = value.value.substring(1, 2);\n                    var b = value.value.substring(2, 3);\n                    return pack(parseInt(r + r, 16), parseInt(g + g, 16), parseInt(b + b, 16), 1);\n                }\n                if (value.value.length === 4) {\n                    var r = value.value.substring(0, 1);\n                    var g = value.value.substring(1, 2);\n                    var b = value.value.substring(2, 3);\n                    var a = value.value.substring(3, 4);\n                    return pack(parseInt(r + r, 16), parseInt(g + g, 16), parseInt(b + b, 16), parseInt(a + a, 16) / 255);\n                }\n                if (value.value.length === 6) {\n                    var r = value.value.substring(0, 2);\n                    var g = value.value.substring(2, 4);\n                    var b = value.value.substring(4, 6);\n                    return pack(parseInt(r, 16), parseInt(g, 16), parseInt(b, 16), 1);\n                }\n                if (value.value.length === 8) {\n                    var r = value.value.substring(0, 2);\n                    var g = value.value.substring(2, 4);\n                    var b = value.value.substring(4, 6);\n                    var a = value.value.substring(6, 8);\n                    return pack(parseInt(r, 16), parseInt(g, 16), parseInt(b, 16), parseInt(a, 16) / 255);\n                }\n            }\n            if (value.type === 20 /* IDENT_TOKEN */) {\n                var namedColor = COLORS[value.value.toUpperCase()];\n                if (typeof namedColor !== 'undefined') {\n                    return namedColor;\n                }\n            }\n            return COLORS.TRANSPARENT;\n        }\n    };\n    var isTransparent = function (color) { return (0xff & color) === 0; };\n    var asString = function (color) {\n        var alpha = 0xff & color;\n        var blue = 0xff & (color >> 8);\n        var green = 0xff & (color >> 16);\n        var red = 0xff & (color >> 24);\n        return alpha < 255 ? \"rgba(\" + red + \",\" + green + \",\" + blue + \",\" + alpha / 255 + \")\" : \"rgb(\" + red + \",\" + green + \",\" + blue + \")\";\n    };\n    var pack = function (r, g, b, a) {\n        return ((r << 24) | (g << 16) | (b << 8) | (Math.round(a * 255) << 0)) >>> 0;\n    };\n    var getTokenColorValue = function (token, i) {\n        if (token.type === 17 /* NUMBER_TOKEN */) {\n            return token.number;\n        }\n        if (token.type === 16 /* PERCENTAGE_TOKEN */) {\n            var max = i === 3 ? 1 : 255;\n            return i === 3 ? (token.number / 100) * max : Math.round((token.number / 100) * max);\n        }\n        return 0;\n    };\n    var rgb = function (_context, args) {\n        var tokens = args.filter(nonFunctionArgSeparator);\n        if (tokens.length === 3) {\n            var _a = tokens.map(getTokenColorValue), r = _a[0], g = _a[1], b = _a[2];\n            return pack(r, g, b, 1);\n        }\n        if (tokens.length === 4) {\n            var _b = tokens.map(getTokenColorValue), r = _b[0], g = _b[1], b = _b[2], a = _b[3];\n            return pack(r, g, b, a);\n        }\n        return 0;\n    };\n    function hue2rgb(t1, t2, hue) {\n        if (hue < 0) {\n            hue += 1;\n        }\n        if (hue >= 1) {\n            hue -= 1;\n        }\n        if (hue < 1 / 6) {\n            return (t2 - t1) * hue * 6 + t1;\n        }\n        else if (hue < 1 / 2) {\n            return t2;\n        }\n        else if (hue < 2 / 3) {\n            return (t2 - t1) * 6 * (2 / 3 - hue) + t1;\n        }\n        else {\n            return t1;\n        }\n    }\n    var hsl = function (context, args) {\n        var tokens = args.filter(nonFunctionArgSeparator);\n        var hue = tokens[0], saturation = tokens[1], lightness = tokens[2], alpha = tokens[3];\n        var h = (hue.type === 17 /* NUMBER_TOKEN */ ? deg(hue.number) : angle.parse(context, hue)) / (Math.PI * 2);\n        var s = isLengthPercentage(saturation) ? saturation.number / 100 : 0;\n        var l = isLengthPercentage(lightness) ? lightness.number / 100 : 0;\n        var a = typeof alpha !== 'undefined' && isLengthPercentage(alpha) ? getAbsoluteValue(alpha, 1) : 1;\n        if (s === 0) {\n            return pack(l * 255, l * 255, l * 255, 1);\n        }\n        var t2 = l <= 0.5 ? l * (s + 1) : l + s - l * s;\n        var t1 = l * 2 - t2;\n        var r = hue2rgb(t1, t2, h + 1 / 3);\n        var g = hue2rgb(t1, t2, h);\n        var b = hue2rgb(t1, t2, h - 1 / 3);\n        return pack(r * 255, g * 255, b * 255, a);\n    };\n    var SUPPORTED_COLOR_FUNCTIONS = {\n        hsl: hsl,\n        hsla: hsl,\n        rgb: rgb,\n        rgba: rgb\n    };\n    var parseColor = function (context, value) {\n        return color$1.parse(context, Parser.create(value).parseComponentValue());\n    };\n    var COLORS = {\n        ALICEBLUE: 0xf0f8ffff,\n        ANTIQUEWHITE: 0xfaebd7ff,\n        AQUA: 0x00ffffff,\n        AQUAMARINE: 0x7fffd4ff,\n        AZURE: 0xf0ffffff,\n        BEIGE: 0xf5f5dcff,\n        BISQUE: 0xffe4c4ff,\n        BLACK: 0x000000ff,\n        BLANCHEDALMOND: 0xffebcdff,\n        BLUE: 0x0000ffff,\n        BLUEVIOLET: 0x8a2be2ff,\n        BROWN: 0xa52a2aff,\n        BURLYWOOD: 0xdeb887ff,\n        CADETBLUE: 0x5f9ea0ff,\n        CHARTREUSE: 0x7fff00ff,\n        CHOCOLATE: 0xd2691eff,\n        CORAL: 0xff7f50ff,\n        CORNFLOWERBLUE: 0x6495edff,\n        CORNSILK: 0xfff8dcff,\n        CRIMSON: 0xdc143cff,\n        CYAN: 0x00ffffff,\n        DARKBLUE: 0x00008bff,\n        DARKCYAN: 0x008b8bff,\n        DARKGOLDENROD: 0xb886bbff,\n        DARKGRAY: 0xa9a9a9ff,\n        DARKGREEN: 0x006400ff,\n        DARKGREY: 0xa9a9a9ff,\n        DARKKHAKI: 0xbdb76bff,\n        DARKMAGENTA: 0x8b008bff,\n        DARKOLIVEGREEN: 0x556b2fff,\n        DARKORANGE: 0xff8c00ff,\n        DARKORCHID: 0x9932ccff,\n        DARKRED: 0x8b0000ff,\n        DARKSALMON: 0xe9967aff,\n        DARKSEAGREEN: 0x8fbc8fff,\n        DARKSLATEBLUE: 0x483d8bff,\n        DARKSLATEGRAY: 0x2f4f4fff,\n        DARKSLATEGREY: 0x2f4f4fff,\n        DARKTURQUOISE: 0x00ced1ff,\n        DARKVIOLET: 0x9400d3ff,\n        DEEPPINK: 0xff1493ff,\n        DEEPSKYBLUE: 0x00bfffff,\n        DIMGRAY: 0x696969ff,\n        DIMGREY: 0x696969ff,\n        DODGERBLUE: 0x1e90ffff,\n        FIREBRICK: 0xb22222ff,\n        FLORALWHITE: 0xfffaf0ff,\n        FORESTGREEN: 0x228b22ff,\n        FUCHSIA: 0xff00ffff,\n        GAINSBORO: 0xdcdcdcff,\n        GHOSTWHITE: 0xf8f8ffff,\n        GOLD: 0xffd700ff,\n        GOLDENROD: 0xdaa520ff,\n        GRAY: 0x808080ff,\n        GREEN: 0x008000ff,\n        GREENYELLOW: 0xadff2fff,\n        GREY: 0x808080ff,\n        HONEYDEW: 0xf0fff0ff,\n        HOTPINK: 0xff69b4ff,\n        INDIANRED: 0xcd5c5cff,\n        INDIGO: 0x4b0082ff,\n        IVORY: 0xfffff0ff,\n        KHAKI: 0xf0e68cff,\n        LAVENDER: 0xe6e6faff,\n        LAVENDERBLUSH: 0xfff0f5ff,\n        LAWNGREEN: 0x7cfc00ff,\n        LEMONCHIFFON: 0xfffacdff,\n        LIGHTBLUE: 0xadd8e6ff,\n        LIGHTCORAL: 0xf08080ff,\n        LIGHTCYAN: 0xe0ffffff,\n        LIGHTGOLDENRODYELLOW: 0xfafad2ff,\n        LIGHTGRAY: 0xd3d3d3ff,\n        LIGHTGREEN: 0x90ee90ff,\n        LIGHTGREY: 0xd3d3d3ff,\n        LIGHTPINK: 0xffb6c1ff,\n        LIGHTSALMON: 0xffa07aff,\n        LIGHTSEAGREEN: 0x20b2aaff,\n        LIGHTSKYBLUE: 0x87cefaff,\n        LIGHTSLATEGRAY: 0x778899ff,\n        LIGHTSLATEGREY: 0x778899ff,\n        LIGHTSTEELBLUE: 0xb0c4deff,\n        LIGHTYELLOW: 0xffffe0ff,\n        LIME: 0x00ff00ff,\n        LIMEGREEN: 0x32cd32ff,\n        LINEN: 0xfaf0e6ff,\n        MAGENTA: 0xff00ffff,\n        MAROON: 0x800000ff,\n        MEDIUMAQUAMARINE: 0x66cdaaff,\n        MEDIUMBLUE: 0x0000cdff,\n        MEDIUMORCHID: 0xba55d3ff,\n        MEDIUMPURPLE: 0x9370dbff,\n        MEDIUMSEAGREEN: 0x3cb371ff,\n        MEDIUMSLATEBLUE: 0x7b68eeff,\n        MEDIUMSPRINGGREEN: 0x00fa9aff,\n        MEDIUMTURQUOISE: 0x48d1ccff,\n        MEDIUMVIOLETRED: 0xc71585ff,\n        MIDNIGHTBLUE: 0x191970ff,\n        MINTCREAM: 0xf5fffaff,\n        MISTYROSE: 0xffe4e1ff,\n        MOCCASIN: 0xffe4b5ff,\n        NAVAJOWHITE: 0xffdeadff,\n        NAVY: 0x000080ff,\n        OLDLACE: 0xfdf5e6ff,\n        OLIVE: 0x808000ff,\n        OLIVEDRAB: 0x6b8e23ff,\n        ORANGE: 0xffa500ff,\n        ORANGERED: 0xff4500ff,\n        ORCHID: 0xda70d6ff,\n        PALEGOLDENROD: 0xeee8aaff,\n        PALEGREEN: 0x98fb98ff,\n        PALETURQUOISE: 0xafeeeeff,\n        PALEVIOLETRED: 0xdb7093ff,\n        PAPAYAWHIP: 0xffefd5ff,\n        PEACHPUFF: 0xffdab9ff,\n        PERU: 0xcd853fff,\n        PINK: 0xffc0cbff,\n        PLUM: 0xdda0ddff,\n        POWDERBLUE: 0xb0e0e6ff,\n        PURPLE: 0x800080ff,\n        REBECCAPURPLE: 0x663399ff,\n        RED: 0xff0000ff,\n        ROSYBROWN: 0xbc8f8fff,\n        ROYALBLUE: 0x4169e1ff,\n        SADDLEBROWN: 0x8b4513ff,\n        SALMON: 0xfa8072ff,\n        SANDYBROWN: 0xf4a460ff,\n        SEAGREEN: 0x2e8b57ff,\n        SEASHELL: 0xfff5eeff,\n        SIENNA: 0xa0522dff,\n        SILVER: 0xc0c0c0ff,\n        SKYBLUE: 0x87ceebff,\n        SLATEBLUE: 0x6a5acdff,\n        SLATEGRAY: 0x708090ff,\n        SLATEGREY: 0x708090ff,\n        SNOW: 0xfffafaff,\n        SPRINGGREEN: 0x00ff7fff,\n        STEELBLUE: 0x4682b4ff,\n        TAN: 0xd2b48cff,\n        TEAL: 0x008080ff,\n        THISTLE: 0xd8bfd8ff,\n        TOMATO: 0xff6347ff,\n        TRANSPARENT: 0x00000000,\n        TURQUOISE: 0x40e0d0ff,\n        VIOLET: 0xee82eeff,\n        WHEAT: 0xf5deb3ff,\n        WHITE: 0xffffffff,\n        WHITESMOKE: 0xf5f5f5ff,\n        YELLOW: 0xffff00ff,\n        YELLOWGREEN: 0x9acd32ff\n    };\n\n    var backgroundClip = {\n        name: 'background-clip',\n        initialValue: 'border-box',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return tokens.map(function (token) {\n                if (isIdentToken(token)) {\n                    switch (token.value) {\n                        case 'padding-box':\n                            return 1 /* PADDING_BOX */;\n                        case 'content-box':\n                            return 2 /* CONTENT_BOX */;\n                    }\n                }\n                return 0 /* BORDER_BOX */;\n            });\n        }\n    };\n\n    var backgroundColor = {\n        name: \"background-color\",\n        initialValue: 'transparent',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'color'\n    };\n\n    var parseColorStop = function (context, args) {\n        var color = color$1.parse(context, args[0]);\n        var stop = args[1];\n        return stop && isLengthPercentage(stop) ? { color: color, stop: stop } : { color: color, stop: null };\n    };\n    var processColorStops = function (stops, lineLength) {\n        var first = stops[0];\n        var last = stops[stops.length - 1];\n        if (first.stop === null) {\n            first.stop = ZERO_LENGTH;\n        }\n        if (last.stop === null) {\n            last.stop = HUNDRED_PERCENT;\n        }\n        var processStops = [];\n        var previous = 0;\n        for (var i = 0; i < stops.length; i++) {\n            var stop_1 = stops[i].stop;\n            if (stop_1 !== null) {\n                var absoluteValue = getAbsoluteValue(stop_1, lineLength);\n                if (absoluteValue > previous) {\n                    processStops.push(absoluteValue);\n                }\n                else {\n                    processStops.push(previous);\n                }\n                previous = absoluteValue;\n            }\n            else {\n                processStops.push(null);\n            }\n        }\n        var gapBegin = null;\n        for (var i = 0; i < processStops.length; i++) {\n            var stop_2 = processStops[i];\n            if (stop_2 === null) {\n                if (gapBegin === null) {\n                    gapBegin = i;\n                }\n            }\n            else if (gapBegin !== null) {\n                var gapLength = i - gapBegin;\n                var beforeGap = processStops[gapBegin - 1];\n                var gapValue = (stop_2 - beforeGap) / (gapLength + 1);\n                for (var g = 1; g <= gapLength; g++) {\n                    processStops[gapBegin + g - 1] = gapValue * g;\n                }\n                gapBegin = null;\n            }\n        }\n        return stops.map(function (_a, i) {\n            var color = _a.color;\n            return { color: color, stop: Math.max(Math.min(1, processStops[i] / lineLength), 0) };\n        });\n    };\n    var getAngleFromCorner = function (corner, width, height) {\n        var centerX = width / 2;\n        var centerY = height / 2;\n        var x = getAbsoluteValue(corner[0], width) - centerX;\n        var y = centerY - getAbsoluteValue(corner[1], height);\n        return (Math.atan2(y, x) + Math.PI * 2) % (Math.PI * 2);\n    };\n    var calculateGradientDirection = function (angle, width, height) {\n        var radian = typeof angle === 'number' ? angle : getAngleFromCorner(angle, width, height);\n        var lineLength = Math.abs(width * Math.sin(radian)) + Math.abs(height * Math.cos(radian));\n        var halfWidth = width / 2;\n        var halfHeight = height / 2;\n        var halfLineLength = lineLength / 2;\n        var yDiff = Math.sin(radian - Math.PI / 2) * halfLineLength;\n        var xDiff = Math.cos(radian - Math.PI / 2) * halfLineLength;\n        return [lineLength, halfWidth - xDiff, halfWidth + xDiff, halfHeight - yDiff, halfHeight + yDiff];\n    };\n    var distance = function (a, b) { return Math.sqrt(a * a + b * b); };\n    var findCorner = function (width, height, x, y, closest) {\n        var corners = [\n            [0, 0],\n            [0, height],\n            [width, 0],\n            [width, height]\n        ];\n        return corners.reduce(function (stat, corner) {\n            var cx = corner[0], cy = corner[1];\n            var d = distance(x - cx, y - cy);\n            if (closest ? d < stat.optimumDistance : d > stat.optimumDistance) {\n                return {\n                    optimumCorner: corner,\n                    optimumDistance: d\n                };\n            }\n            return stat;\n        }, {\n            optimumDistance: closest ? Infinity : -Infinity,\n            optimumCorner: null\n        }).optimumCorner;\n    };\n    var calculateRadius = function (gradient, x, y, width, height) {\n        var rx = 0;\n        var ry = 0;\n        switch (gradient.size) {\n            case 0 /* CLOSEST_SIDE */:\n                // The ending shape is sized so that that it exactly meets the side of the gradient box closest to the gradient’s center.\n                // If the shape is an ellipse, it exactly meets the closest side in each dimension.\n                if (gradient.shape === 0 /* CIRCLE */) {\n                    rx = ry = Math.min(Math.abs(x), Math.abs(x - width), Math.abs(y), Math.abs(y - height));\n                }\n                else if (gradient.shape === 1 /* ELLIPSE */) {\n                    rx = Math.min(Math.abs(x), Math.abs(x - width));\n                    ry = Math.min(Math.abs(y), Math.abs(y - height));\n                }\n                break;\n            case 2 /* CLOSEST_CORNER */:\n                // The ending shape is sized so that that it passes through the corner of the gradient box closest to the gradient’s center.\n                // If the shape is an ellipse, the ending shape is given the same aspect-ratio it would have if closest-side were specified.\n                if (gradient.shape === 0 /* CIRCLE */) {\n                    rx = ry = Math.min(distance(x, y), distance(x, y - height), distance(x - width, y), distance(x - width, y - height));\n                }\n                else if (gradient.shape === 1 /* ELLIPSE */) {\n                    // Compute the ratio ry/rx (which is to be the same as for \"closest-side\")\n                    var c = Math.min(Math.abs(y), Math.abs(y - height)) / Math.min(Math.abs(x), Math.abs(x - width));\n                    var _a = findCorner(width, height, x, y, true), cx = _a[0], cy = _a[1];\n                    rx = distance(cx - x, (cy - y) / c);\n                    ry = c * rx;\n                }\n                break;\n            case 1 /* FARTHEST_SIDE */:\n                // Same as closest-side, except the ending shape is sized based on the farthest side(s)\n                if (gradient.shape === 0 /* CIRCLE */) {\n                    rx = ry = Math.max(Math.abs(x), Math.abs(x - width), Math.abs(y), Math.abs(y - height));\n                }\n                else if (gradient.shape === 1 /* ELLIPSE */) {\n                    rx = Math.max(Math.abs(x), Math.abs(x - width));\n                    ry = Math.max(Math.abs(y), Math.abs(y - height));\n                }\n                break;\n            case 3 /* FARTHEST_CORNER */:\n                // Same as closest-corner, except the ending shape is sized based on the farthest corner.\n                // If the shape is an ellipse, the ending shape is given the same aspect ratio it would have if farthest-side were specified.\n                if (gradient.shape === 0 /* CIRCLE */) {\n                    rx = ry = Math.max(distance(x, y), distance(x, y - height), distance(x - width, y), distance(x - width, y - height));\n                }\n                else if (gradient.shape === 1 /* ELLIPSE */) {\n                    // Compute the ratio ry/rx (which is to be the same as for \"farthest-side\")\n                    var c = Math.max(Math.abs(y), Math.abs(y - height)) / Math.max(Math.abs(x), Math.abs(x - width));\n                    var _b = findCorner(width, height, x, y, false), cx = _b[0], cy = _b[1];\n                    rx = distance(cx - x, (cy - y) / c);\n                    ry = c * rx;\n                }\n                break;\n        }\n        if (Array.isArray(gradient.size)) {\n            rx = getAbsoluteValue(gradient.size[0], width);\n            ry = gradient.size.length === 2 ? getAbsoluteValue(gradient.size[1], height) : rx;\n        }\n        return [rx, ry];\n    };\n\n    var linearGradient = function (context, tokens) {\n        var angle$1 = deg(180);\n        var stops = [];\n        parseFunctionArgs(tokens).forEach(function (arg, i) {\n            if (i === 0) {\n                var firstToken = arg[0];\n                if (firstToken.type === 20 /* IDENT_TOKEN */ && firstToken.value === 'to') {\n                    angle$1 = parseNamedSide(arg);\n                    return;\n                }\n                else if (isAngle(firstToken)) {\n                    angle$1 = angle.parse(context, firstToken);\n                    return;\n                }\n            }\n            var colorStop = parseColorStop(context, arg);\n            stops.push(colorStop);\n        });\n        return { angle: angle$1, stops: stops, type: 1 /* LINEAR_GRADIENT */ };\n    };\n\n    var prefixLinearGradient = function (context, tokens) {\n        var angle$1 = deg(180);\n        var stops = [];\n        parseFunctionArgs(tokens).forEach(function (arg, i) {\n            if (i === 0) {\n                var firstToken = arg[0];\n                if (firstToken.type === 20 /* IDENT_TOKEN */ &&\n                    ['top', 'left', 'right', 'bottom'].indexOf(firstToken.value) !== -1) {\n                    angle$1 = parseNamedSide(arg);\n                    return;\n                }\n                else if (isAngle(firstToken)) {\n                    angle$1 = (angle.parse(context, firstToken) + deg(270)) % deg(360);\n                    return;\n                }\n            }\n            var colorStop = parseColorStop(context, arg);\n            stops.push(colorStop);\n        });\n        return {\n            angle: angle$1,\n            stops: stops,\n            type: 1 /* LINEAR_GRADIENT */\n        };\n    };\n\n    var webkitGradient = function (context, tokens) {\n        var angle = deg(180);\n        var stops = [];\n        var type = 1 /* LINEAR_GRADIENT */;\n        var shape = 0 /* CIRCLE */;\n        var size = 3 /* FARTHEST_CORNER */;\n        var position = [];\n        parseFunctionArgs(tokens).forEach(function (arg, i) {\n            var firstToken = arg[0];\n            if (i === 0) {\n                if (isIdentToken(firstToken) && firstToken.value === 'linear') {\n                    type = 1 /* LINEAR_GRADIENT */;\n                    return;\n                }\n                else if (isIdentToken(firstToken) && firstToken.value === 'radial') {\n                    type = 2 /* RADIAL_GRADIENT */;\n                    return;\n                }\n            }\n            if (firstToken.type === 18 /* FUNCTION */) {\n                if (firstToken.name === 'from') {\n                    var color = color$1.parse(context, firstToken.values[0]);\n                    stops.push({ stop: ZERO_LENGTH, color: color });\n                }\n                else if (firstToken.name === 'to') {\n                    var color = color$1.parse(context, firstToken.values[0]);\n                    stops.push({ stop: HUNDRED_PERCENT, color: color });\n                }\n                else if (firstToken.name === 'color-stop') {\n                    var values = firstToken.values.filter(nonFunctionArgSeparator);\n                    if (values.length === 2) {\n                        var color = color$1.parse(context, values[1]);\n                        var stop_1 = values[0];\n                        if (isNumberToken(stop_1)) {\n                            stops.push({\n                                stop: { type: 16 /* PERCENTAGE_TOKEN */, number: stop_1.number * 100, flags: stop_1.flags },\n                                color: color\n                            });\n                        }\n                    }\n                }\n            }\n        });\n        return type === 1 /* LINEAR_GRADIENT */\n            ? {\n                angle: (angle + deg(180)) % deg(360),\n                stops: stops,\n                type: type\n            }\n            : { size: size, shape: shape, stops: stops, position: position, type: type };\n    };\n\n    var CLOSEST_SIDE = 'closest-side';\n    var FARTHEST_SIDE = 'farthest-side';\n    var CLOSEST_CORNER = 'closest-corner';\n    var FARTHEST_CORNER = 'farthest-corner';\n    var CIRCLE = 'circle';\n    var ELLIPSE = 'ellipse';\n    var COVER = 'cover';\n    var CONTAIN = 'contain';\n    var radialGradient = function (context, tokens) {\n        var shape = 0 /* CIRCLE */;\n        var size = 3 /* FARTHEST_CORNER */;\n        var stops = [];\n        var position = [];\n        parseFunctionArgs(tokens).forEach(function (arg, i) {\n            var isColorStop = true;\n            if (i === 0) {\n                var isAtPosition_1 = false;\n                isColorStop = arg.reduce(function (acc, token) {\n                    if (isAtPosition_1) {\n                        if (isIdentToken(token)) {\n                            switch (token.value) {\n                                case 'center':\n                                    position.push(FIFTY_PERCENT);\n                                    return acc;\n                                case 'top':\n                                case 'left':\n                                    position.push(ZERO_LENGTH);\n                                    return acc;\n                                case 'right':\n                                case 'bottom':\n                                    position.push(HUNDRED_PERCENT);\n                                    return acc;\n                            }\n                        }\n                        else if (isLengthPercentage(token) || isLength(token)) {\n                            position.push(token);\n                        }\n                    }\n                    else if (isIdentToken(token)) {\n                        switch (token.value) {\n                            case CIRCLE:\n                                shape = 0 /* CIRCLE */;\n                                return false;\n                            case ELLIPSE:\n                                shape = 1 /* ELLIPSE */;\n                                return false;\n                            case 'at':\n                                isAtPosition_1 = true;\n                                return false;\n                            case CLOSEST_SIDE:\n                                size = 0 /* CLOSEST_SIDE */;\n                                return false;\n                            case COVER:\n                            case FARTHEST_SIDE:\n                                size = 1 /* FARTHEST_SIDE */;\n                                return false;\n                            case CONTAIN:\n                            case CLOSEST_CORNER:\n                                size = 2 /* CLOSEST_CORNER */;\n                                return false;\n                            case FARTHEST_CORNER:\n                                size = 3 /* FARTHEST_CORNER */;\n                                return false;\n                        }\n                    }\n                    else if (isLength(token) || isLengthPercentage(token)) {\n                        if (!Array.isArray(size)) {\n                            size = [];\n                        }\n                        size.push(token);\n                        return false;\n                    }\n                    return acc;\n                }, isColorStop);\n            }\n            if (isColorStop) {\n                var colorStop = parseColorStop(context, arg);\n                stops.push(colorStop);\n            }\n        });\n        return { size: size, shape: shape, stops: stops, position: position, type: 2 /* RADIAL_GRADIENT */ };\n    };\n\n    var prefixRadialGradient = function (context, tokens) {\n        var shape = 0 /* CIRCLE */;\n        var size = 3 /* FARTHEST_CORNER */;\n        var stops = [];\n        var position = [];\n        parseFunctionArgs(tokens).forEach(function (arg, i) {\n            var isColorStop = true;\n            if (i === 0) {\n                isColorStop = arg.reduce(function (acc, token) {\n                    if (isIdentToken(token)) {\n                        switch (token.value) {\n                            case 'center':\n                                position.push(FIFTY_PERCENT);\n                                return false;\n                            case 'top':\n                            case 'left':\n                                position.push(ZERO_LENGTH);\n                                return false;\n                            case 'right':\n                            case 'bottom':\n                                position.push(HUNDRED_PERCENT);\n                                return false;\n                        }\n                    }\n                    else if (isLengthPercentage(token) || isLength(token)) {\n                        position.push(token);\n                        return false;\n                    }\n                    return acc;\n                }, isColorStop);\n            }\n            else if (i === 1) {\n                isColorStop = arg.reduce(function (acc, token) {\n                    if (isIdentToken(token)) {\n                        switch (token.value) {\n                            case CIRCLE:\n                                shape = 0 /* CIRCLE */;\n                                return false;\n                            case ELLIPSE:\n                                shape = 1 /* ELLIPSE */;\n                                return false;\n                            case CONTAIN:\n                            case CLOSEST_SIDE:\n                                size = 0 /* CLOSEST_SIDE */;\n                                return false;\n                            case FARTHEST_SIDE:\n                                size = 1 /* FARTHEST_SIDE */;\n                                return false;\n                            case CLOSEST_CORNER:\n                                size = 2 /* CLOSEST_CORNER */;\n                                return false;\n                            case COVER:\n                            case FARTHEST_CORNER:\n                                size = 3 /* FARTHEST_CORNER */;\n                                return false;\n                        }\n                    }\n                    else if (isLength(token) || isLengthPercentage(token)) {\n                        if (!Array.isArray(size)) {\n                            size = [];\n                        }\n                        size.push(token);\n                        return false;\n                    }\n                    return acc;\n                }, isColorStop);\n            }\n            if (isColorStop) {\n                var colorStop = parseColorStop(context, arg);\n                stops.push(colorStop);\n            }\n        });\n        return { size: size, shape: shape, stops: stops, position: position, type: 2 /* RADIAL_GRADIENT */ };\n    };\n\n    var isLinearGradient = function (background) {\n        return background.type === 1 /* LINEAR_GRADIENT */;\n    };\n    var isRadialGradient = function (background) {\n        return background.type === 2 /* RADIAL_GRADIENT */;\n    };\n    var image = {\n        name: 'image',\n        parse: function (context, value) {\n            if (value.type === 22 /* URL_TOKEN */) {\n                var image_1 = { url: value.value, type: 0 /* URL */ };\n                context.cache.addImage(value.value);\n                return image_1;\n            }\n            if (value.type === 18 /* FUNCTION */) {\n                var imageFunction = SUPPORTED_IMAGE_FUNCTIONS[value.name];\n                if (typeof imageFunction === 'undefined') {\n                    throw new Error(\"Attempting to parse an unsupported image function \\\"\" + value.name + \"\\\"\");\n                }\n                return imageFunction(context, value.values);\n            }\n            throw new Error(\"Unsupported image type \" + value.type);\n        }\n    };\n    function isSupportedImage(value) {\n        return (!(value.type === 20 /* IDENT_TOKEN */ && value.value === 'none') &&\n            (value.type !== 18 /* FUNCTION */ || !!SUPPORTED_IMAGE_FUNCTIONS[value.name]));\n    }\n    var SUPPORTED_IMAGE_FUNCTIONS = {\n        'linear-gradient': linearGradient,\n        '-moz-linear-gradient': prefixLinearGradient,\n        '-ms-linear-gradient': prefixLinearGradient,\n        '-o-linear-gradient': prefixLinearGradient,\n        '-webkit-linear-gradient': prefixLinearGradient,\n        'radial-gradient': radialGradient,\n        '-moz-radial-gradient': prefixRadialGradient,\n        '-ms-radial-gradient': prefixRadialGradient,\n        '-o-radial-gradient': prefixRadialGradient,\n        '-webkit-radial-gradient': prefixRadialGradient,\n        '-webkit-gradient': webkitGradient\n    };\n\n    var backgroundImage = {\n        name: 'background-image',\n        initialValue: 'none',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (context, tokens) {\n            if (tokens.length === 0) {\n                return [];\n            }\n            var first = tokens[0];\n            if (first.type === 20 /* IDENT_TOKEN */ && first.value === 'none') {\n                return [];\n            }\n            return tokens\n                .filter(function (value) { return nonFunctionArgSeparator(value) && isSupportedImage(value); })\n                .map(function (value) { return image.parse(context, value); });\n        }\n    };\n\n    var backgroundOrigin = {\n        name: 'background-origin',\n        initialValue: 'border-box',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return tokens.map(function (token) {\n                if (isIdentToken(token)) {\n                    switch (token.value) {\n                        case 'padding-box':\n                            return 1 /* PADDING_BOX */;\n                        case 'content-box':\n                            return 2 /* CONTENT_BOX */;\n                    }\n                }\n                return 0 /* BORDER_BOX */;\n            });\n        }\n    };\n\n    var backgroundPosition = {\n        name: 'background-position',\n        initialValue: '0% 0%',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (_context, tokens) {\n            return parseFunctionArgs(tokens)\n                .map(function (values) { return values.filter(isLengthPercentage); })\n                .map(parseLengthPercentageTuple);\n        }\n    };\n\n    var backgroundRepeat = {\n        name: 'background-repeat',\n        initialValue: 'repeat',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return parseFunctionArgs(tokens)\n                .map(function (values) {\n                return values\n                    .filter(isIdentToken)\n                    .map(function (token) { return token.value; })\n                    .join(' ');\n            })\n                .map(parseBackgroundRepeat);\n        }\n    };\n    var parseBackgroundRepeat = function (value) {\n        switch (value) {\n            case 'no-repeat':\n                return 1 /* NO_REPEAT */;\n            case 'repeat-x':\n            case 'repeat no-repeat':\n                return 2 /* REPEAT_X */;\n            case 'repeat-y':\n            case 'no-repeat repeat':\n                return 3 /* REPEAT_Y */;\n            case 'repeat':\n            default:\n                return 0 /* REPEAT */;\n        }\n    };\n\n    var BACKGROUND_SIZE;\n    (function (BACKGROUND_SIZE) {\n        BACKGROUND_SIZE[\"AUTO\"] = \"auto\";\n        BACKGROUND_SIZE[\"CONTAIN\"] = \"contain\";\n        BACKGROUND_SIZE[\"COVER\"] = \"cover\";\n    })(BACKGROUND_SIZE || (BACKGROUND_SIZE = {}));\n    var backgroundSize = {\n        name: 'background-size',\n        initialValue: '0',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return parseFunctionArgs(tokens).map(function (values) { return values.filter(isBackgroundSizeInfoToken); });\n        }\n    };\n    var isBackgroundSizeInfoToken = function (value) {\n        return isIdentToken(value) || isLengthPercentage(value);\n    };\n\n    var borderColorForSide = function (side) { return ({\n        name: \"border-\" + side + \"-color\",\n        initialValue: 'transparent',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'color'\n    }); };\n    var borderTopColor = borderColorForSide('top');\n    var borderRightColor = borderColorForSide('right');\n    var borderBottomColor = borderColorForSide('bottom');\n    var borderLeftColor = borderColorForSide('left');\n\n    var borderRadiusForSide = function (side) { return ({\n        name: \"border-radius-\" + side,\n        initialValue: '0 0',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return parseLengthPercentageTuple(tokens.filter(isLengthPercentage));\n        }\n    }); };\n    var borderTopLeftRadius = borderRadiusForSide('top-left');\n    var borderTopRightRadius = borderRadiusForSide('top-right');\n    var borderBottomRightRadius = borderRadiusForSide('bottom-right');\n    var borderBottomLeftRadius = borderRadiusForSide('bottom-left');\n\n    var borderStyleForSide = function (side) { return ({\n        name: \"border-\" + side + \"-style\",\n        initialValue: 'solid',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, style) {\n            switch (style) {\n                case 'none':\n                    return 0 /* NONE */;\n                case 'dashed':\n                    return 2 /* DASHED */;\n                case 'dotted':\n                    return 3 /* DOTTED */;\n                case 'double':\n                    return 4 /* DOUBLE */;\n            }\n            return 1 /* SOLID */;\n        }\n    }); };\n    var borderTopStyle = borderStyleForSide('top');\n    var borderRightStyle = borderStyleForSide('right');\n    var borderBottomStyle = borderStyleForSide('bottom');\n    var borderLeftStyle = borderStyleForSide('left');\n\n    var borderWidthForSide = function (side) { return ({\n        name: \"border-\" + side + \"-width\",\n        initialValue: '0',\n        type: 0 /* VALUE */,\n        prefix: false,\n        parse: function (_context, token) {\n            if (isDimensionToken(token)) {\n                return token.number;\n            }\n            return 0;\n        }\n    }); };\n    var borderTopWidth = borderWidthForSide('top');\n    var borderRightWidth = borderWidthForSide('right');\n    var borderBottomWidth = borderWidthForSide('bottom');\n    var borderLeftWidth = borderWidthForSide('left');\n\n    var color = {\n        name: \"color\",\n        initialValue: 'transparent',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'color'\n    };\n\n    var direction = {\n        name: 'direction',\n        initialValue: 'ltr',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, direction) {\n            switch (direction) {\n                case 'rtl':\n                    return 1 /* RTL */;\n                case 'ltr':\n                default:\n                    return 0 /* LTR */;\n            }\n        }\n    };\n\n    var display = {\n        name: 'display',\n        initialValue: 'inline-block',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return tokens.filter(isIdentToken).reduce(function (bit, token) {\n                return bit | parseDisplayValue(token.value);\n            }, 0 /* NONE */);\n        }\n    };\n    var parseDisplayValue = function (display) {\n        switch (display) {\n            case 'block':\n            case '-webkit-box':\n                return 2 /* BLOCK */;\n            case 'inline':\n                return 4 /* INLINE */;\n            case 'run-in':\n                return 8 /* RUN_IN */;\n            case 'flow':\n                return 16 /* FLOW */;\n            case 'flow-root':\n                return 32 /* FLOW_ROOT */;\n            case 'table':\n                return 64 /* TABLE */;\n            case 'flex':\n            case '-webkit-flex':\n                return 128 /* FLEX */;\n            case 'grid':\n            case '-ms-grid':\n                return 256 /* GRID */;\n            case 'ruby':\n                return 512 /* RUBY */;\n            case 'subgrid':\n                return 1024 /* SUBGRID */;\n            case 'list-item':\n                return 2048 /* LIST_ITEM */;\n            case 'table-row-group':\n                return 4096 /* TABLE_ROW_GROUP */;\n            case 'table-header-group':\n                return 8192 /* TABLE_HEADER_GROUP */;\n            case 'table-footer-group':\n                return 16384 /* TABLE_FOOTER_GROUP */;\n            case 'table-row':\n                return 32768 /* TABLE_ROW */;\n            case 'table-cell':\n                return 65536 /* TABLE_CELL */;\n            case 'table-column-group':\n                return 131072 /* TABLE_COLUMN_GROUP */;\n            case 'table-column':\n                return 262144 /* TABLE_COLUMN */;\n            case 'table-caption':\n                return 524288 /* TABLE_CAPTION */;\n            case 'ruby-base':\n                return 1048576 /* RUBY_BASE */;\n            case 'ruby-text':\n                return 2097152 /* RUBY_TEXT */;\n            case 'ruby-base-container':\n                return 4194304 /* RUBY_BASE_CONTAINER */;\n            case 'ruby-text-container':\n                return 8388608 /* RUBY_TEXT_CONTAINER */;\n            case 'contents':\n                return 16777216 /* CONTENTS */;\n            case 'inline-block':\n                return 33554432 /* INLINE_BLOCK */;\n            case 'inline-list-item':\n                return 67108864 /* INLINE_LIST_ITEM */;\n            case 'inline-table':\n                return 134217728 /* INLINE_TABLE */;\n            case 'inline-flex':\n                return 268435456 /* INLINE_FLEX */;\n            case 'inline-grid':\n                return 536870912 /* INLINE_GRID */;\n        }\n        return 0 /* NONE */;\n    };\n\n    var float = {\n        name: 'float',\n        initialValue: 'none',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, float) {\n            switch (float) {\n                case 'left':\n                    return 1 /* LEFT */;\n                case 'right':\n                    return 2 /* RIGHT */;\n                case 'inline-start':\n                    return 3 /* INLINE_START */;\n                case 'inline-end':\n                    return 4 /* INLINE_END */;\n            }\n            return 0 /* NONE */;\n        }\n    };\n\n    var letterSpacing = {\n        name: 'letter-spacing',\n        initialValue: '0',\n        prefix: false,\n        type: 0 /* VALUE */,\n        parse: function (_context, token) {\n            if (token.type === 20 /* IDENT_TOKEN */ && token.value === 'normal') {\n                return 0;\n            }\n            if (token.type === 17 /* NUMBER_TOKEN */) {\n                return token.number;\n            }\n            if (token.type === 15 /* DIMENSION_TOKEN */) {\n                return token.number;\n            }\n            return 0;\n        }\n    };\n\n    var LINE_BREAK;\n    (function (LINE_BREAK) {\n        LINE_BREAK[\"NORMAL\"] = \"normal\";\n        LINE_BREAK[\"STRICT\"] = \"strict\";\n    })(LINE_BREAK || (LINE_BREAK = {}));\n    var lineBreak = {\n        name: 'line-break',\n        initialValue: 'normal',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, lineBreak) {\n            switch (lineBreak) {\n                case 'strict':\n                    return LINE_BREAK.STRICT;\n                case 'normal':\n                default:\n                    return LINE_BREAK.NORMAL;\n            }\n        }\n    };\n\n    var lineHeight = {\n        name: 'line-height',\n        initialValue: 'normal',\n        prefix: false,\n        type: 4 /* TOKEN_VALUE */\n    };\n    var computeLineHeight = function (token, fontSize) {\n        if (isIdentToken(token) && token.value === 'normal') {\n            return 1.2 * fontSize;\n        }\n        else if (token.type === 17 /* NUMBER_TOKEN */) {\n            return fontSize * token.number;\n        }\n        else if (isLengthPercentage(token)) {\n            return getAbsoluteValue(token, fontSize);\n        }\n        return fontSize;\n    };\n\n    var listStyleImage = {\n        name: 'list-style-image',\n        initialValue: 'none',\n        type: 0 /* VALUE */,\n        prefix: false,\n        parse: function (context, token) {\n            if (token.type === 20 /* IDENT_TOKEN */ && token.value === 'none') {\n                return null;\n            }\n            return image.parse(context, token);\n        }\n    };\n\n    var listStylePosition = {\n        name: 'list-style-position',\n        initialValue: 'outside',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, position) {\n            switch (position) {\n                case 'inside':\n                    return 0 /* INSIDE */;\n                case 'outside':\n                default:\n                    return 1 /* OUTSIDE */;\n            }\n        }\n    };\n\n    var listStyleType = {\n        name: 'list-style-type',\n        initialValue: 'none',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, type) {\n            switch (type) {\n                case 'disc':\n                    return 0 /* DISC */;\n                case 'circle':\n                    return 1 /* CIRCLE */;\n                case 'square':\n                    return 2 /* SQUARE */;\n                case 'decimal':\n                    return 3 /* DECIMAL */;\n                case 'cjk-decimal':\n                    return 4 /* CJK_DECIMAL */;\n                case 'decimal-leading-zero':\n                    return 5 /* DECIMAL_LEADING_ZERO */;\n                case 'lower-roman':\n                    return 6 /* LOWER_ROMAN */;\n                case 'upper-roman':\n                    return 7 /* UPPER_ROMAN */;\n                case 'lower-greek':\n                    return 8 /* LOWER_GREEK */;\n                case 'lower-alpha':\n                    return 9 /* LOWER_ALPHA */;\n                case 'upper-alpha':\n                    return 10 /* UPPER_ALPHA */;\n                case 'arabic-indic':\n                    return 11 /* ARABIC_INDIC */;\n                case 'armenian':\n                    return 12 /* ARMENIAN */;\n                case 'bengali':\n                    return 13 /* BENGALI */;\n                case 'cambodian':\n                    return 14 /* CAMBODIAN */;\n                case 'cjk-earthly-branch':\n                    return 15 /* CJK_EARTHLY_BRANCH */;\n                case 'cjk-heavenly-stem':\n                    return 16 /* CJK_HEAVENLY_STEM */;\n                case 'cjk-ideographic':\n                    return 17 /* CJK_IDEOGRAPHIC */;\n                case 'devanagari':\n                    return 18 /* DEVANAGARI */;\n                case 'ethiopic-numeric':\n                    return 19 /* ETHIOPIC_NUMERIC */;\n                case 'georgian':\n                    return 20 /* GEORGIAN */;\n                case 'gujarati':\n                    return 21 /* GUJARATI */;\n                case 'gurmukhi':\n                    return 22 /* GURMUKHI */;\n                case 'hebrew':\n                    return 22 /* HEBREW */;\n                case 'hiragana':\n                    return 23 /* HIRAGANA */;\n                case 'hiragana-iroha':\n                    return 24 /* HIRAGANA_IROHA */;\n                case 'japanese-formal':\n                    return 25 /* JAPANESE_FORMAL */;\n                case 'japanese-informal':\n                    return 26 /* JAPANESE_INFORMAL */;\n                case 'kannada':\n                    return 27 /* KANNADA */;\n                case 'katakana':\n                    return 28 /* KATAKANA */;\n                case 'katakana-iroha':\n                    return 29 /* KATAKANA_IROHA */;\n                case 'khmer':\n                    return 30 /* KHMER */;\n                case 'korean-hangul-formal':\n                    return 31 /* KOREAN_HANGUL_FORMAL */;\n                case 'korean-hanja-formal':\n                    return 32 /* KOREAN_HANJA_FORMAL */;\n                case 'korean-hanja-informal':\n                    return 33 /* KOREAN_HANJA_INFORMAL */;\n                case 'lao':\n                    return 34 /* LAO */;\n                case 'lower-armenian':\n                    return 35 /* LOWER_ARMENIAN */;\n                case 'malayalam':\n                    return 36 /* MALAYALAM */;\n                case 'mongolian':\n                    return 37 /* MONGOLIAN */;\n                case 'myanmar':\n                    return 38 /* MYANMAR */;\n                case 'oriya':\n                    return 39 /* ORIYA */;\n                case 'persian':\n                    return 40 /* PERSIAN */;\n                case 'simp-chinese-formal':\n                    return 41 /* SIMP_CHINESE_FORMAL */;\n                case 'simp-chinese-informal':\n                    return 42 /* SIMP_CHINESE_INFORMAL */;\n                case 'tamil':\n                    return 43 /* TAMIL */;\n                case 'telugu':\n                    return 44 /* TELUGU */;\n                case 'thai':\n                    return 45 /* THAI */;\n                case 'tibetan':\n                    return 46 /* TIBETAN */;\n                case 'trad-chinese-formal':\n                    return 47 /* TRAD_CHINESE_FORMAL */;\n                case 'trad-chinese-informal':\n                    return 48 /* TRAD_CHINESE_INFORMAL */;\n                case 'upper-armenian':\n                    return 49 /* UPPER_ARMENIAN */;\n                case 'disclosure-open':\n                    return 50 /* DISCLOSURE_OPEN */;\n                case 'disclosure-closed':\n                    return 51 /* DISCLOSURE_CLOSED */;\n                case 'none':\n                default:\n                    return -1 /* NONE */;\n            }\n        }\n    };\n\n    var marginForSide = function (side) { return ({\n        name: \"margin-\" + side,\n        initialValue: '0',\n        prefix: false,\n        type: 4 /* TOKEN_VALUE */\n    }); };\n    var marginTop = marginForSide('top');\n    var marginRight = marginForSide('right');\n    var marginBottom = marginForSide('bottom');\n    var marginLeft = marginForSide('left');\n\n    var overflow = {\n        name: 'overflow',\n        initialValue: 'visible',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return tokens.filter(isIdentToken).map(function (overflow) {\n                switch (overflow.value) {\n                    case 'hidden':\n                        return 1 /* HIDDEN */;\n                    case 'scroll':\n                        return 2 /* SCROLL */;\n                    case 'clip':\n                        return 3 /* CLIP */;\n                    case 'auto':\n                        return 4 /* AUTO */;\n                    case 'visible':\n                    default:\n                        return 0 /* VISIBLE */;\n                }\n            });\n        }\n    };\n\n    var overflowWrap = {\n        name: 'overflow-wrap',\n        initialValue: 'normal',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, overflow) {\n            switch (overflow) {\n                case 'break-word':\n                    return \"break-word\" /* BREAK_WORD */;\n                case 'normal':\n                default:\n                    return \"normal\" /* NORMAL */;\n            }\n        }\n    };\n\n    var paddingForSide = function (side) { return ({\n        name: \"padding-\" + side,\n        initialValue: '0',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'length-percentage'\n    }); };\n    var paddingTop = paddingForSide('top');\n    var paddingRight = paddingForSide('right');\n    var paddingBottom = paddingForSide('bottom');\n    var paddingLeft = paddingForSide('left');\n\n    var textAlign = {\n        name: 'text-align',\n        initialValue: 'left',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, textAlign) {\n            switch (textAlign) {\n                case 'right':\n                    return 2 /* RIGHT */;\n                case 'center':\n                case 'justify':\n                    return 1 /* CENTER */;\n                case 'left':\n                default:\n                    return 0 /* LEFT */;\n            }\n        }\n    };\n\n    var position = {\n        name: 'position',\n        initialValue: 'static',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, position) {\n            switch (position) {\n                case 'relative':\n                    return 1 /* RELATIVE */;\n                case 'absolute':\n                    return 2 /* ABSOLUTE */;\n                case 'fixed':\n                    return 3 /* FIXED */;\n                case 'sticky':\n                    return 4 /* STICKY */;\n            }\n            return 0 /* STATIC */;\n        }\n    };\n\n    var textShadow = {\n        name: 'text-shadow',\n        initialValue: 'none',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (context, tokens) {\n            if (tokens.length === 1 && isIdentWithValue(tokens[0], 'none')) {\n                return [];\n            }\n            return parseFunctionArgs(tokens).map(function (values) {\n                var shadow = {\n                    color: COLORS.TRANSPARENT,\n                    offsetX: ZERO_LENGTH,\n                    offsetY: ZERO_LENGTH,\n                    blur: ZERO_LENGTH\n                };\n                var c = 0;\n                for (var i = 0; i < values.length; i++) {\n                    var token = values[i];\n                    if (isLength(token)) {\n                        if (c === 0) {\n                            shadow.offsetX = token;\n                        }\n                        else if (c === 1) {\n                            shadow.offsetY = token;\n                        }\n                        else {\n                            shadow.blur = token;\n                        }\n                        c++;\n                    }\n                    else {\n                        shadow.color = color$1.parse(context, token);\n                    }\n                }\n                return shadow;\n            });\n        }\n    };\n\n    var textTransform = {\n        name: 'text-transform',\n        initialValue: 'none',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, textTransform) {\n            switch (textTransform) {\n                case 'uppercase':\n                    return 2 /* UPPERCASE */;\n                case 'lowercase':\n                    return 1 /* LOWERCASE */;\n                case 'capitalize':\n                    return 3 /* CAPITALIZE */;\n            }\n            return 0 /* NONE */;\n        }\n    };\n\n    var transform$1 = {\n        name: 'transform',\n        initialValue: 'none',\n        prefix: true,\n        type: 0 /* VALUE */,\n        parse: function (_context, token) {\n            if (token.type === 20 /* IDENT_TOKEN */ && token.value === 'none') {\n                return null;\n            }\n            if (token.type === 18 /* FUNCTION */) {\n                var transformFunction = SUPPORTED_TRANSFORM_FUNCTIONS[token.name];\n                if (typeof transformFunction === 'undefined') {\n                    throw new Error(\"Attempting to parse an unsupported transform function \\\"\" + token.name + \"\\\"\");\n                }\n                return transformFunction(token.values);\n            }\n            return null;\n        }\n    };\n    var matrix = function (args) {\n        var values = args.filter(function (arg) { return arg.type === 17 /* NUMBER_TOKEN */; }).map(function (arg) { return arg.number; });\n        return values.length === 6 ? values : null;\n    };\n    // doesn't support 3D transforms at the moment\n    var matrix3d = function (args) {\n        var values = args.filter(function (arg) { return arg.type === 17 /* NUMBER_TOKEN */; }).map(function (arg) { return arg.number; });\n        var a1 = values[0], b1 = values[1]; values[2]; values[3]; var a2 = values[4], b2 = values[5]; values[6]; values[7]; values[8]; values[9]; values[10]; values[11]; var a4 = values[12], b4 = values[13]; values[14]; values[15];\n        return values.length === 16 ? [a1, b1, a2, b2, a4, b4] : null;\n    };\n    var SUPPORTED_TRANSFORM_FUNCTIONS = {\n        matrix: matrix,\n        matrix3d: matrix3d\n    };\n\n    var DEFAULT_VALUE = {\n        type: 16 /* PERCENTAGE_TOKEN */,\n        number: 50,\n        flags: FLAG_INTEGER\n    };\n    var DEFAULT = [DEFAULT_VALUE, DEFAULT_VALUE];\n    var transformOrigin = {\n        name: 'transform-origin',\n        initialValue: '50% 50%',\n        prefix: true,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            var origins = tokens.filter(isLengthPercentage);\n            if (origins.length !== 2) {\n                return DEFAULT;\n            }\n            return [origins[0], origins[1]];\n        }\n    };\n\n    var visibility = {\n        name: 'visible',\n        initialValue: 'none',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, visibility) {\n            switch (visibility) {\n                case 'hidden':\n                    return 1 /* HIDDEN */;\n                case 'collapse':\n                    return 2 /* COLLAPSE */;\n                case 'visible':\n                default:\n                    return 0 /* VISIBLE */;\n            }\n        }\n    };\n\n    var WORD_BREAK;\n    (function (WORD_BREAK) {\n        WORD_BREAK[\"NORMAL\"] = \"normal\";\n        WORD_BREAK[\"BREAK_ALL\"] = \"break-all\";\n        WORD_BREAK[\"KEEP_ALL\"] = \"keep-all\";\n    })(WORD_BREAK || (WORD_BREAK = {}));\n    var wordBreak = {\n        name: 'word-break',\n        initialValue: 'normal',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, wordBreak) {\n            switch (wordBreak) {\n                case 'break-all':\n                    return WORD_BREAK.BREAK_ALL;\n                case 'keep-all':\n                    return WORD_BREAK.KEEP_ALL;\n                case 'normal':\n                default:\n                    return WORD_BREAK.NORMAL;\n            }\n        }\n    };\n\n    var zIndex = {\n        name: 'z-index',\n        initialValue: 'auto',\n        prefix: false,\n        type: 0 /* VALUE */,\n        parse: function (_context, token) {\n            if (token.type === 20 /* IDENT_TOKEN */) {\n                return { auto: true, order: 0 };\n            }\n            if (isNumberToken(token)) {\n                return { auto: false, order: token.number };\n            }\n            throw new Error(\"Invalid z-index number parsed\");\n        }\n    };\n\n    var time = {\n        name: 'time',\n        parse: function (_context, value) {\n            if (value.type === 15 /* DIMENSION_TOKEN */) {\n                switch (value.unit.toLowerCase()) {\n                    case 's':\n                        return 1000 * value.number;\n                    case 'ms':\n                        return value.number;\n                }\n            }\n            throw new Error(\"Unsupported time type\");\n        }\n    };\n\n    var opacity = {\n        name: 'opacity',\n        initialValue: '1',\n        type: 0 /* VALUE */,\n        prefix: false,\n        parse: function (_context, token) {\n            if (isNumberToken(token)) {\n                return token.number;\n            }\n            return 1;\n        }\n    };\n\n    var textDecorationColor = {\n        name: \"text-decoration-color\",\n        initialValue: 'transparent',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'color'\n    };\n\n    var textDecorationLine = {\n        name: 'text-decoration-line',\n        initialValue: 'none',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            return tokens\n                .filter(isIdentToken)\n                .map(function (token) {\n                switch (token.value) {\n                    case 'underline':\n                        return 1 /* UNDERLINE */;\n                    case 'overline':\n                        return 2 /* OVERLINE */;\n                    case 'line-through':\n                        return 3 /* LINE_THROUGH */;\n                    case 'none':\n                        return 4 /* BLINK */;\n                }\n                return 0 /* NONE */;\n            })\n                .filter(function (line) { return line !== 0 /* NONE */; });\n        }\n    };\n\n    var fontFamily = {\n        name: \"font-family\",\n        initialValue: '',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            var accumulator = [];\n            var results = [];\n            tokens.forEach(function (token) {\n                switch (token.type) {\n                    case 20 /* IDENT_TOKEN */:\n                    case 0 /* STRING_TOKEN */:\n                        accumulator.push(token.value);\n                        break;\n                    case 17 /* NUMBER_TOKEN */:\n                        accumulator.push(token.number.toString());\n                        break;\n                    case 4 /* COMMA_TOKEN */:\n                        results.push(accumulator.join(' '));\n                        accumulator.length = 0;\n                        break;\n                }\n            });\n            if (accumulator.length) {\n                results.push(accumulator.join(' '));\n            }\n            return results.map(function (result) { return (result.indexOf(' ') === -1 ? result : \"'\" + result + \"'\"); });\n        }\n    };\n\n    var fontSize = {\n        name: \"font-size\",\n        initialValue: '0',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'length'\n    };\n\n    var fontWeight = {\n        name: 'font-weight',\n        initialValue: 'normal',\n        type: 0 /* VALUE */,\n        prefix: false,\n        parse: function (_context, token) {\n            if (isNumberToken(token)) {\n                return token.number;\n            }\n            if (isIdentToken(token)) {\n                switch (token.value) {\n                    case 'bold':\n                        return 700;\n                    case 'normal':\n                    default:\n                        return 400;\n                }\n            }\n            return 400;\n        }\n    };\n\n    var fontVariant = {\n        name: 'font-variant',\n        initialValue: 'none',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (_context, tokens) {\n            return tokens.filter(isIdentToken).map(function (token) { return token.value; });\n        }\n    };\n\n    var fontStyle = {\n        name: 'font-style',\n        initialValue: 'normal',\n        prefix: false,\n        type: 2 /* IDENT_VALUE */,\n        parse: function (_context, overflow) {\n            switch (overflow) {\n                case 'oblique':\n                    return \"oblique\" /* OBLIQUE */;\n                case 'italic':\n                    return \"italic\" /* ITALIC */;\n                case 'normal':\n                default:\n                    return \"normal\" /* NORMAL */;\n            }\n        }\n    };\n\n    var contains = function (bit, value) { return (bit & value) !== 0; };\n\n    var content = {\n        name: 'content',\n        initialValue: 'none',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (_context, tokens) {\n            if (tokens.length === 0) {\n                return [];\n            }\n            var first = tokens[0];\n            if (first.type === 20 /* IDENT_TOKEN */ && first.value === 'none') {\n                return [];\n            }\n            return tokens;\n        }\n    };\n\n    var counterIncrement = {\n        name: 'counter-increment',\n        initialValue: 'none',\n        prefix: true,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            if (tokens.length === 0) {\n                return null;\n            }\n            var first = tokens[0];\n            if (first.type === 20 /* IDENT_TOKEN */ && first.value === 'none') {\n                return null;\n            }\n            var increments = [];\n            var filtered = tokens.filter(nonWhiteSpace);\n            for (var i = 0; i < filtered.length; i++) {\n                var counter = filtered[i];\n                var next = filtered[i + 1];\n                if (counter.type === 20 /* IDENT_TOKEN */) {\n                    var increment = next && isNumberToken(next) ? next.number : 1;\n                    increments.push({ counter: counter.value, increment: increment });\n                }\n            }\n            return increments;\n        }\n    };\n\n    var counterReset = {\n        name: 'counter-reset',\n        initialValue: 'none',\n        prefix: true,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            if (tokens.length === 0) {\n                return [];\n            }\n            var resets = [];\n            var filtered = tokens.filter(nonWhiteSpace);\n            for (var i = 0; i < filtered.length; i++) {\n                var counter = filtered[i];\n                var next = filtered[i + 1];\n                if (isIdentToken(counter) && counter.value !== 'none') {\n                    var reset = next && isNumberToken(next) ? next.number : 0;\n                    resets.push({ counter: counter.value, reset: reset });\n                }\n            }\n            return resets;\n        }\n    };\n\n    var duration = {\n        name: 'duration',\n        initialValue: '0s',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (context, tokens) {\n            return tokens.filter(isDimensionToken).map(function (token) { return time.parse(context, token); });\n        }\n    };\n\n    var quotes = {\n        name: 'quotes',\n        initialValue: 'none',\n        prefix: true,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            if (tokens.length === 0) {\n                return null;\n            }\n            var first = tokens[0];\n            if (first.type === 20 /* IDENT_TOKEN */ && first.value === 'none') {\n                return null;\n            }\n            var quotes = [];\n            var filtered = tokens.filter(isStringToken);\n            if (filtered.length % 2 !== 0) {\n                return null;\n            }\n            for (var i = 0; i < filtered.length; i += 2) {\n                var open_1 = filtered[i].value;\n                var close_1 = filtered[i + 1].value;\n                quotes.push({ open: open_1, close: close_1 });\n            }\n            return quotes;\n        }\n    };\n    var getQuote = function (quotes, depth, open) {\n        if (!quotes) {\n            return '';\n        }\n        var quote = quotes[Math.min(depth, quotes.length - 1)];\n        if (!quote) {\n            return '';\n        }\n        return open ? quote.open : quote.close;\n    };\n\n    var boxShadow = {\n        name: 'box-shadow',\n        initialValue: 'none',\n        type: 1 /* LIST */,\n        prefix: false,\n        parse: function (context, tokens) {\n            if (tokens.length === 1 && isIdentWithValue(tokens[0], 'none')) {\n                return [];\n            }\n            return parseFunctionArgs(tokens).map(function (values) {\n                var shadow = {\n                    color: 0x000000ff,\n                    offsetX: ZERO_LENGTH,\n                    offsetY: ZERO_LENGTH,\n                    blur: ZERO_LENGTH,\n                    spread: ZERO_LENGTH,\n                    inset: false\n                };\n                var c = 0;\n                for (var i = 0; i < values.length; i++) {\n                    var token = values[i];\n                    if (isIdentWithValue(token, 'inset')) {\n                        shadow.inset = true;\n                    }\n                    else if (isLength(token)) {\n                        if (c === 0) {\n                            shadow.offsetX = token;\n                        }\n                        else if (c === 1) {\n                            shadow.offsetY = token;\n                        }\n                        else if (c === 2) {\n                            shadow.blur = token;\n                        }\n                        else {\n                            shadow.spread = token;\n                        }\n                        c++;\n                    }\n                    else {\n                        shadow.color = color$1.parse(context, token);\n                    }\n                }\n                return shadow;\n            });\n        }\n    };\n\n    var paintOrder = {\n        name: 'paint-order',\n        initialValue: 'normal',\n        prefix: false,\n        type: 1 /* LIST */,\n        parse: function (_context, tokens) {\n            var DEFAULT_VALUE = [0 /* FILL */, 1 /* STROKE */, 2 /* MARKERS */];\n            var layers = [];\n            tokens.filter(isIdentToken).forEach(function (token) {\n                switch (token.value) {\n                    case 'stroke':\n                        layers.push(1 /* STROKE */);\n                        break;\n                    case 'fill':\n                        layers.push(0 /* FILL */);\n                        break;\n                    case 'markers':\n                        layers.push(2 /* MARKERS */);\n                        break;\n                }\n            });\n            DEFAULT_VALUE.forEach(function (value) {\n                if (layers.indexOf(value) === -1) {\n                    layers.push(value);\n                }\n            });\n            return layers;\n        }\n    };\n\n    var webkitTextStrokeColor = {\n        name: \"-webkit-text-stroke-color\",\n        initialValue: 'currentcolor',\n        prefix: false,\n        type: 3 /* TYPE_VALUE */,\n        format: 'color'\n    };\n\n    var webkitTextStrokeWidth = {\n        name: \"-webkit-text-stroke-width\",\n        initialValue: '0',\n        type: 0 /* VALUE */,\n        prefix: false,\n        parse: function (_context, token) {\n            if (isDimensionToken(token)) {\n                return token.number;\n            }\n            return 0;\n        }\n    };\n\n    var CSSParsedDeclaration = /** @class */ (function () {\n        function CSSParsedDeclaration(context, declaration) {\n            var _a, _b;\n            this.animationDuration = parse(context, duration, declaration.animationDuration);\n            this.backgroundClip = parse(context, backgroundClip, declaration.backgroundClip);\n            this.backgroundColor = parse(context, backgroundColor, declaration.backgroundColor);\n            this.backgroundImage = parse(context, backgroundImage, declaration.backgroundImage);\n            this.backgroundOrigin = parse(context, backgroundOrigin, declaration.backgroundOrigin);\n            this.backgroundPosition = parse(context, backgroundPosition, declaration.backgroundPosition);\n            this.backgroundRepeat = parse(context, backgroundRepeat, declaration.backgroundRepeat);\n            this.backgroundSize = parse(context, backgroundSize, declaration.backgroundSize);\n            this.borderTopColor = parse(context, borderTopColor, declaration.borderTopColor);\n            this.borderRightColor = parse(context, borderRightColor, declaration.borderRightColor);\n            this.borderBottomColor = parse(context, borderBottomColor, declaration.borderBottomColor);\n            this.borderLeftColor = parse(context, borderLeftColor, declaration.borderLeftColor);\n            this.borderTopLeftRadius = parse(context, borderTopLeftRadius, declaration.borderTopLeftRadius);\n            this.borderTopRightRadius = parse(context, borderTopRightRadius, declaration.borderTopRightRadius);\n            this.borderBottomRightRadius = parse(context, borderBottomRightRadius, declaration.borderBottomRightRadius);\n            this.borderBottomLeftRadius = parse(context, borderBottomLeftRadius, declaration.borderBottomLeftRadius);\n            this.borderTopStyle = parse(context, borderTopStyle, declaration.borderTopStyle);\n            this.borderRightStyle = parse(context, borderRightStyle, declaration.borderRightStyle);\n            this.borderBottomStyle = parse(context, borderBottomStyle, declaration.borderBottomStyle);\n            this.borderLeftStyle = parse(context, borderLeftStyle, declaration.borderLeftStyle);\n            this.borderTopWidth = parse(context, borderTopWidth, declaration.borderTopWidth);\n            this.borderRightWidth = parse(context, borderRightWidth, declaration.borderRightWidth);\n            this.borderBottomWidth = parse(context, borderBottomWidth, declaration.borderBottomWidth);\n            this.borderLeftWidth = parse(context, borderLeftWidth, declaration.borderLeftWidth);\n            this.boxShadow = parse(context, boxShadow, declaration.boxShadow);\n            this.color = parse(context, color, declaration.color);\n            this.direction = parse(context, direction, declaration.direction);\n            this.display = parse(context, display, declaration.display);\n            this.float = parse(context, float, declaration.cssFloat);\n            this.fontFamily = parse(context, fontFamily, declaration.fontFamily);\n            this.fontSize = parse(context, fontSize, declaration.fontSize);\n            this.fontStyle = parse(context, fontStyle, declaration.fontStyle);\n            this.fontVariant = parse(context, fontVariant, declaration.fontVariant);\n            this.fontWeight = parse(context, fontWeight, declaration.fontWeight);\n            this.letterSpacing = parse(context, letterSpacing, declaration.letterSpacing);\n            this.lineBreak = parse(context, lineBreak, declaration.lineBreak);\n            this.lineHeight = parse(context, lineHeight, declaration.lineHeight);\n            this.listStyleImage = parse(context, listStyleImage, declaration.listStyleImage);\n            this.listStylePosition = parse(context, listStylePosition, declaration.listStylePosition);\n            this.listStyleType = parse(context, listStyleType, declaration.listStyleType);\n            this.marginTop = parse(context, marginTop, declaration.marginTop);\n            this.marginRight = parse(context, marginRight, declaration.marginRight);\n            this.marginBottom = parse(context, marginBottom, declaration.marginBottom);\n            this.marginLeft = parse(context, marginLeft, declaration.marginLeft);\n            this.opacity = parse(context, opacity, declaration.opacity);\n            var overflowTuple = parse(context, overflow, declaration.overflow);\n            this.overflowX = overflowTuple[0];\n            this.overflowY = overflowTuple[overflowTuple.length > 1 ? 1 : 0];\n            this.overflowWrap = parse(context, overflowWrap, declaration.overflowWrap);\n            this.paddingTop = parse(context, paddingTop, declaration.paddingTop);\n            this.paddingRight = parse(context, paddingRight, declaration.paddingRight);\n            this.paddingBottom = parse(context, paddingBottom, declaration.paddingBottom);\n            this.paddingLeft = parse(context, paddingLeft, declaration.paddingLeft);\n            this.paintOrder = parse(context, paintOrder, declaration.paintOrder);\n            this.position = parse(context, position, declaration.position);\n            this.textAlign = parse(context, textAlign, declaration.textAlign);\n            this.textDecorationColor = parse(context, textDecorationColor, (_a = declaration.textDecorationColor) !== null && _a !== void 0 ? _a : declaration.color);\n            this.textDecorationLine = parse(context, textDecorationLine, (_b = declaration.textDecorationLine) !== null && _b !== void 0 ? _b : declaration.textDecoration);\n            this.textShadow = parse(context, textShadow, declaration.textShadow);\n            this.textTransform = parse(context, textTransform, declaration.textTransform);\n            this.transform = parse(context, transform$1, declaration.transform);\n            this.transformOrigin = parse(context, transformOrigin, declaration.transformOrigin);\n            this.visibility = parse(context, visibility, declaration.visibility);\n            this.webkitTextStrokeColor = parse(context, webkitTextStrokeColor, declaration.webkitTextStrokeColor);\n            this.webkitTextStrokeWidth = parse(context, webkitTextStrokeWidth, declaration.webkitTextStrokeWidth);\n            this.wordBreak = parse(context, wordBreak, declaration.wordBreak);\n            this.zIndex = parse(context, zIndex, declaration.zIndex);\n        }\n        CSSParsedDeclaration.prototype.isVisible = function () {\n            return this.display > 0 && this.opacity > 0 && this.visibility === 0 /* VISIBLE */;\n        };\n        CSSParsedDeclaration.prototype.isTransparent = function () {\n            return isTransparent(this.backgroundColor);\n        };\n        CSSParsedDeclaration.prototype.isTransformed = function () {\n            return this.transform !== null;\n        };\n        CSSParsedDeclaration.prototype.isPositioned = function () {\n            return this.position !== 0 /* STATIC */;\n        };\n        CSSParsedDeclaration.prototype.isPositionedWithZIndex = function () {\n            return this.isPositioned() && !this.zIndex.auto;\n        };\n        CSSParsedDeclaration.prototype.isFloating = function () {\n            return this.float !== 0 /* NONE */;\n        };\n        CSSParsedDeclaration.prototype.isInlineLevel = function () {\n            return (contains(this.display, 4 /* INLINE */) ||\n                contains(this.display, 33554432 /* INLINE_BLOCK */) ||\n                contains(this.display, 268435456 /* INLINE_FLEX */) ||\n                contains(this.display, 536870912 /* INLINE_GRID */) ||\n                contains(this.display, 67108864 /* INLINE_LIST_ITEM */) ||\n                contains(this.display, 134217728 /* INLINE_TABLE */));\n        };\n        return CSSParsedDeclaration;\n    }());\n    var CSSParsedPseudoDeclaration = /** @class */ (function () {\n        function CSSParsedPseudoDeclaration(context, declaration) {\n            this.content = parse(context, content, declaration.content);\n            this.quotes = parse(context, quotes, declaration.quotes);\n        }\n        return CSSParsedPseudoDeclaration;\n    }());\n    var CSSParsedCounterDeclaration = /** @class */ (function () {\n        function CSSParsedCounterDeclaration(context, declaration) {\n            this.counterIncrement = parse(context, counterIncrement, declaration.counterIncrement);\n            this.counterReset = parse(context, counterReset, declaration.counterReset);\n        }\n        return CSSParsedCounterDeclaration;\n    }());\n    // eslint-disable-next-line @typescript-eslint/no-explicit-any\n    var parse = function (context, descriptor, style) {\n        var tokenizer = new Tokenizer();\n        var value = style !== null && typeof style !== 'undefined' ? style.toString() : descriptor.initialValue;\n        tokenizer.write(value);\n        var parser = new Parser(tokenizer.read());\n        switch (descriptor.type) {\n            case 2 /* IDENT_VALUE */:\n                var token = parser.parseComponentValue();\n                return descriptor.parse(context, isIdentToken(token) ? token.value : descriptor.initialValue);\n            case 0 /* VALUE */:\n                return descriptor.parse(context, parser.parseComponentValue());\n            case 1 /* LIST */:\n                return descriptor.parse(context, parser.parseComponentValues());\n            case 4 /* TOKEN_VALUE */:\n                return parser.parseComponentValue();\n            case 3 /* TYPE_VALUE */:\n                switch (descriptor.format) {\n                    case 'angle':\n                        return angle.parse(context, parser.parseComponentValue());\n                    case 'color':\n                        return color$1.parse(context, parser.parseComponentValue());\n                    case 'image':\n                        return image.parse(context, parser.parseComponentValue());\n                    case 'length':\n                        var length_1 = parser.parseComponentValue();\n                        return isLength(length_1) ? length_1 : ZERO_LENGTH;\n                    case 'length-percentage':\n                        var value_1 = parser.parseComponentValue();\n                        return isLengthPercentage(value_1) ? value_1 : ZERO_LENGTH;\n                    case 'time':\n                        return time.parse(context, parser.parseComponentValue());\n                }\n                break;\n        }\n    };\n\n    var elementDebuggerAttribute = 'data-html2canvas-debug';\n    var getElementDebugType = function (element) {\n        var attribute = element.getAttribute(elementDebuggerAttribute);\n        switch (attribute) {\n            case 'all':\n                return 1 /* ALL */;\n            case 'clone':\n                return 2 /* CLONE */;\n            case 'parse':\n                return 3 /* PARSE */;\n            case 'render':\n                return 4 /* RENDER */;\n            default:\n                return 0 /* NONE */;\n        }\n    };\n    var isDebugging = function (element, type) {\n        var elementType = getElementDebugType(element);\n        return elementType === 1 /* ALL */ || type === elementType;\n    };\n\n    var ElementContainer = /** @class */ (function () {\n        function ElementContainer(context, element) {\n            this.context = context;\n            this.textNodes = [];\n            this.elements = [];\n            this.flags = 0;\n            if (isDebugging(element, 3 /* PARSE */)) {\n                debugger;\n            }\n            this.styles = new CSSParsedDeclaration(context, window.getComputedStyle(element, null));\n            if (isHTMLElementNode(element)) {\n                if (this.styles.animationDuration.some(function (duration) { return duration > 0; })) {\n                    element.style.animationDuration = '0s';\n                }\n                if (this.styles.transform !== null) {\n                    // getBoundingClientRect takes transforms into account\n                    element.style.transform = 'none';\n                }\n            }\n            this.bounds = parseBounds(this.context, element);\n            if (isDebugging(element, 4 /* RENDER */)) {\n                this.flags |= 16 /* DEBUG_RENDER */;\n            }\n        }\n        return ElementContainer;\n    }());\n\n    /*\n     * text-segmentation 1.0.3 <https://github.com/niklasvh/text-segmentation>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var base64 = ' ';\n\n    /*\n     * utrie 1.0.2 <https://github.com/niklasvh/utrie>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var chars$1 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';\n    // Use a lookup table to find the index.\n    var lookup$1 = typeof Uint8Array === 'undefined' ? [] : new Uint8Array(256);\n    for (var i$1 = 0; i$1 < chars$1.length; i$1++) {\n        lookup$1[chars$1.charCodeAt(i$1)] = i$1;\n    }\n    var decode = function (base64) {\n        var bufferLength = base64.length * 0.75, len = base64.length, i, p = 0, encoded1, encoded2, encoded3, encoded4;\n        if (base64[base64.length - 1] === '=') {\n            bufferLength--;\n            if (base64[base64.length - 2] === '=') {\n                bufferLength--;\n            }\n        }\n        var buffer = typeof ArrayBuffer !== 'undefined' &&\n            typeof Uint8Array !== 'undefined' &&\n            typeof Uint8Array.prototype.slice !== 'undefined'\n            ? new ArrayBuffer(bufferLength)\n            : new Array(bufferLength);\n        var bytes = Array.isArray(buffer) ? buffer : new Uint8Array(buffer);\n        for (i = 0; i < len; i += 4) {\n            encoded1 = lookup$1[base64.charCodeAt(i)];\n            encoded2 = lookup$1[base64.charCodeAt(i + 1)];\n            encoded3 = lookup$1[base64.charCodeAt(i + 2)];\n            encoded4 = lookup$1[base64.charCodeAt(i + 3)];\n            bytes[p++] = (encoded1 << 2) | (encoded2 >> 4);\n            bytes[p++] = ((encoded2 & 15) << 4) | (encoded3 >> 2);\n            bytes[p++] = ((encoded3 & 3) << 6) | (encoded4 & 63);\n        }\n        return buffer;\n    };\n    var polyUint16Array = function (buffer) {\n        var length = buffer.length;\n        var bytes = [];\n        for (var i = 0; i < length; i += 2) {\n            bytes.push((buffer[i + 1] << 8) | buffer[i]);\n        }\n        return bytes;\n    };\n    var polyUint32Array = function (buffer) {\n        var length = buffer.length;\n        var bytes = [];\n        for (var i = 0; i < length; i += 4) {\n            bytes.push((buffer[i + 3] << 24) | (buffer[i + 2] << 16) | (buffer[i + 1] << 8) | buffer[i]);\n        }\n        return bytes;\n    };\n\n    /** Shift size for getting the index-2 table offset. */\n    var UTRIE2_SHIFT_2 = 5;\n    /** Shift size for getting the index-1 table offset. */\n    var UTRIE2_SHIFT_1 = 6 + 5;\n    /**\n     * Shift size for shifting left the index array values.\n     * Increases possible data size with 16-bit index values at the cost\n     * of compactability.\n     * This requires data blocks to be aligned by UTRIE2_DATA_GRANULARITY.\n     */\n    var UTRIE2_INDEX_SHIFT = 2;\n    /**\n     * Difference between the two shift sizes,\n     * for getting an index-1 offset from an index-2 offset. 6=11-5\n     */\n    var UTRIE2_SHIFT_1_2 = UTRIE2_SHIFT_1 - UTRIE2_SHIFT_2;\n    /**\n     * The part of the index-2 table for U+D800..U+DBFF stores values for\n     * lead surrogate code _units_ not code _points_.\n     * Values for lead surrogate code _points_ are indexed with this portion of the table.\n     * Length=32=0x20=0x400>>UTRIE2_SHIFT_2. (There are 1024=0x400 lead surrogates.)\n     */\n    var UTRIE2_LSCP_INDEX_2_OFFSET = 0x10000 >> UTRIE2_SHIFT_2;\n    /** Number of entries in a data block. 32=0x20 */\n    var UTRIE2_DATA_BLOCK_LENGTH = 1 << UTRIE2_SHIFT_2;\n    /** Mask for getting the lower bits for the in-data-block offset. */\n    var UTRIE2_DATA_MASK = UTRIE2_DATA_BLOCK_LENGTH - 1;\n    var UTRIE2_LSCP_INDEX_2_LENGTH = 0x400 >> UTRIE2_SHIFT_2;\n    /** Count the lengths of both BMP pieces. 2080=0x820 */\n    var UTRIE2_INDEX_2_BMP_LENGTH = UTRIE2_LSCP_INDEX_2_OFFSET + UTRIE2_LSCP_INDEX_2_LENGTH;\n    /**\n     * The 2-byte UTF-8 version of the index-2 table follows at offset 2080=0x820.\n     * Length 32=0x20 for lead bytes C0..DF, regardless of UTRIE2_SHIFT_2.\n     */\n    var UTRIE2_UTF8_2B_INDEX_2_OFFSET = UTRIE2_INDEX_2_BMP_LENGTH;\n    var UTRIE2_UTF8_2B_INDEX_2_LENGTH = 0x800 >> 6; /* U+0800 is the first code point after 2-byte UTF-8 */\n    /**\n     * The index-1 table, only used for supplementary code points, at offset 2112=0x840.\n     * Variable length, for code points up to highStart, where the last single-value range starts.\n     * Maximum length 512=0x200=0x100000>>UTRIE2_SHIFT_1.\n     * (For 0x100000 supplementary code points U+10000..U+10ffff.)\n     *\n     * The part of the index-2 table for supplementary code points starts\n     * after this index-1 table.\n     *\n     * Both the index-1 table and the following part of the index-2 table\n     * are omitted completely if there is only BMP data.\n     */\n    var UTRIE2_INDEX_1_OFFSET = UTRIE2_UTF8_2B_INDEX_2_OFFSET + UTRIE2_UTF8_2B_INDEX_2_LENGTH;\n    /**\n     * Number of index-1 entries for the BMP. 32=0x20\n     * This part of the index-1 table is omitted from the serialized form.\n     */\n    var UTRIE2_OMITTED_BMP_INDEX_1_LENGTH = 0x10000 >> UTRIE2_SHIFT_1;\n    /** Number of entries in an index-2 block. 64=0x40 */\n    var UTRIE2_INDEX_2_BLOCK_LENGTH = 1 << UTRIE2_SHIFT_1_2;\n    /** Mask for getting the lower bits for the in-index-2-block offset. */\n    var UTRIE2_INDEX_2_MASK = UTRIE2_INDEX_2_BLOCK_LENGTH - 1;\n    var slice16 = function (view, start, end) {\n        if (view.slice) {\n            return view.slice(start, end);\n        }\n        return new Uint16Array(Array.prototype.slice.call(view, start, end));\n    };\n    var slice32 = function (view, start, end) {\n        if (view.slice) {\n            return view.slice(start, end);\n        }\n        return new Uint32Array(Array.prototype.slice.call(view, start, end));\n    };\n    var createTrieFromBase64 = function (base64, _byteLength) {\n        var buffer = decode(base64);\n        var view32 = Array.isArray(buffer) ? polyUint32Array(buffer) : new Uint32Array(buffer);\n        var view16 = Array.isArray(buffer) ? polyUint16Array(buffer) : new Uint16Array(buffer);\n        var headerLength = 24;\n        var index = slice16(view16, headerLength / 2, view32[4] / 2);\n        var data = view32[5] === 2\n            ? slice16(view16, (headerLength + view32[4]) / 2)\n            : slice32(view32, Math.ceil((headerLength + view32[4]) / 4));\n        return new Trie(view32[0], view32[1], view32[2], view32[3], index, data);\n    };\n    var Trie = /** @class */ (function () {\n        function Trie(initialValue, errorValue, highStart, highValueIndex, index, data) {\n            this.initialValue = initialValue;\n            this.errorValue = errorValue;\n            this.highStart = highStart;\n            this.highValueIndex = highValueIndex;\n            this.index = index;\n            this.data = data;\n        }\n        /**\n         * Get the value for a code point as stored in the Trie.\n         *\n         * @param codePoint the code point\n         * @return the value\n         */\n        Trie.prototype.get = function (codePoint) {\n            var ix;\n            if (codePoint >= 0) {\n                if (codePoint < 0x0d800 || (codePoint > 0x0dbff && codePoint <= 0x0ffff)) {\n                    // Ordinary BMP code point, excluding leading surrogates.\n                    // BMP uses a single level lookup.  BMP index starts at offset 0 in the Trie2 index.\n                    // 16 bit data is stored in the index array itself.\n                    ix = this.index[codePoint >> UTRIE2_SHIFT_2];\n                    ix = (ix << UTRIE2_INDEX_SHIFT) + (codePoint & UTRIE2_DATA_MASK);\n                    return this.data[ix];\n                }\n                if (codePoint <= 0xffff) {\n                    // Lead Surrogate Code Point.  A Separate index section is stored for\n                    // lead surrogate code units and code points.\n                    //   The main index has the code unit data.\n                    //   For this function, we need the code point data.\n                    // Note: this expression could be refactored for slightly improved efficiency, but\n                    //       surrogate code points will be so rare in practice that it's not worth it.\n                    ix = this.index[UTRIE2_LSCP_INDEX_2_OFFSET + ((codePoint - 0xd800) >> UTRIE2_SHIFT_2)];\n                    ix = (ix << UTRIE2_INDEX_SHIFT) + (codePoint & UTRIE2_DATA_MASK);\n                    return this.data[ix];\n                }\n                if (codePoint < this.highStart) {\n                    // Supplemental code point, use two-level lookup.\n                    ix = UTRIE2_INDEX_1_OFFSET - UTRIE2_OMITTED_BMP_INDEX_1_LENGTH + (codePoint >> UTRIE2_SHIFT_1);\n                    ix = this.index[ix];\n                    ix += (codePoint >> UTRIE2_SHIFT_2) & UTRIE2_INDEX_2_MASK;\n                    ix = this.index[ix];\n                    ix = (ix << UTRIE2_INDEX_SHIFT) + (codePoint & UTRIE2_DATA_MASK);\n                    return this.data[ix];\n                }\n                if (codePoint <= 0x10ffff) {\n                    return this.data[this.highValueIndex];\n                }\n            }\n            // Fall through.  The code point is outside of the legal range of 0..0x10ffff.\n            return this.errorValue;\n        };\n        return Trie;\n    }());\n\n    /*\n     * base64-arraybuffer 1.0.2 <https://github.com/niklasvh/base64-arraybuffer>\n     * Copyright (c) 2022 Niklas von Hertzen <https://hertzen.com>\n     * Released under MIT License\n     */\n    var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';\n    // Use a lookup table to find the index.\n    var lookup = typeof Uint8Array === 'undefined' ? [] : new Uint8Array(256);\n    for (var i = 0; i < chars.length; i++) {\n        lookup[chars.charCodeAt(i)] = i;\n    }\n\n    var Prepend = 1;\n    var CR = 2;\n    var LF = 3;\n    var Control = 4;\n    var Extend = 5;\n    var SpacingMark = 7;\n    var L = 8;\n    var V = 9;\n    var T = 10;\n    var LV = 11;\n    var LVT = 12;\n    var ZWJ = 13;\n    var Extended_Pictographic = 14;\n    var RI = 15;\n    var toCodePoints = function (str) {\n        var codePoints = [];\n        var i = 0;\n        var length = str.length;\n        while (i < length) {\n            var value = str.charCodeAt(i++);\n            if (value >= 0xd800 && value <= 0xdbff && i < length) {\n                var extra = str.charCodeAt(i++);\n                if ((extra & 0xfc00) === 0xdc00) {\n                    codePoints.push(((value & 0x3ff) << 10) + (extra & 0x3ff) + 0x10000);\n                }\n                else {\n                    codePoints.push(value);\n                    i--;\n                }\n            }\n            else {\n                codePoints.push(value);\n            }\n        }\n        return codePoints;\n    };\n    var fromCodePoint = function () {\n        var codePoints = [];\n        for (var _i = 0; _i < arguments.length; _i++) {\n            codePoints[_i] = arguments[_i];\n        }\n        if (String.fromCodePoint) {\n            return String.fromCodePoint.apply(String, codePoints);\n        }\n        var length = codePoints.length;\n        if (!length) {\n            return '';\n        }\n        var codeUnits = [];\n        var index = -1;\n        var result = '';\n        while (++index < length) {\n            var codePoint = codePoints[index];\n            if (codePoint <= 0xffff) {\n                codeUnits.push(codePoint);\n            }\n            else {\n                codePoint -= 0x10000;\n                codeUnits.push((codePoint >> 10) + 0xd800, (codePoint % 0x400) + 0xdc00);\n            }\n            if (index + 1 === length || codeUnits.length > 0x4000) {\n                result += String.fromCharCode.apply(String, codeUnits);\n                codeUnits.length = 0;\n            }\n        }\n        return result;\n    };\n    var UnicodeTrie = createTrieFromBase64(base64);\n    var BREAK_NOT_ALLOWED = '×';\n    var BREAK_ALLOWED = '÷';\n    var codePointToClass = function (codePoint) { return UnicodeTrie.get(codePoint); };\n    var _graphemeBreakAtIndex = function (_codePoints, classTypes, index) {\n        var prevIndex = index - 2;\n        var prev = classTypes[prevIndex];\n        var current = classTypes[index - 1];\n        var next = classTypes[index];\n        // GB3 Do not break between a CR and LF\n        if (current === CR && next === LF) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB4 Otherwise, break before and after controls.\n        if (current === CR || current === LF || current === Control) {\n            return BREAK_ALLOWED;\n        }\n        // GB5\n        if (next === CR || next === LF || next === Control) {\n            return BREAK_ALLOWED;\n        }\n        // Do not break Hangul syllable sequences.\n        // GB6\n        if (current === L && [L, V, LV, LVT].indexOf(next) !== -1) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB7\n        if ((current === LV || current === V) && (next === V || next === T)) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB8\n        if ((current === LVT || current === T) && next === T) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB9 Do not break before extending characters or ZWJ.\n        if (next === ZWJ || next === Extend) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // Do not break before SpacingMarks, or after Prepend characters.\n        // GB9a\n        if (next === SpacingMark) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB9a\n        if (current === Prepend) {\n            return BREAK_NOT_ALLOWED;\n        }\n        // GB11 Do not break within emoji modifier sequences or emoji zwj sequences.\n        if (current === ZWJ && next === Extended_Pictographic) {\n            while (prev === Extend) {\n                prev = classTypes[--prevIndex];\n            }\n            if (prev === Extended_Pictographic) {\n                return BREAK_NOT_ALLOWED;\n            }\n        }\n        // GB12 Do not break within emoji flag sequences.\n        // That is, do not break between regional indicator (RI) symbols\n        // if there is an odd number of RI characters before the break point.\n        if (current === RI && next === RI) {\n            var countRI = 0;\n            while (prev === RI) {\n                countRI++;\n                prev = classTypes[--prevIndex];\n            }\n            if (countRI % 2 === 0) {\n                return BREAK_NOT_ALLOWED;\n            }\n        }\n        return BREAK_ALLOWED;\n    };\n    var GraphemeBreaker = function (str) {\n        var codePoints = toCodePoints(str);\n        var length = codePoints.length;\n        var index = 0;\n        var lastEnd = 0;\n        var classTypes = codePoints.map(codePointToClass);\n        return {\n            next: function () {\n                if (index >= length) {\n                    return { done: true, value: null };\n                }\n                var graphemeBreak = BREAK_NOT_ALLOWED;\n                while (index < length &&\n                    (graphemeBreak = _graphemeBreakAtIndex(codePoints, classTypes, ++index)) === BREAK_NOT_ALLOWED) { }\n                if (graphemeBreak !== BREAK_NOT_ALLOWED || index === length) {\n                    var value = fromCodePoint.apply(null, codePoints.slice(lastEnd, index));\n                    lastEnd = index;\n                    return { value: value, done: false };\n                }\n                return { done: true, value: null };\n            },\n        };\n    };\n    var splitGraphemes = function (str) {\n        var breaker = GraphemeBreaker(str);\n        var graphemes = [];\n        var bk;\n        while (!(bk = breaker.next()).done) {\n            if (bk.value) {\n                graphemes.push(bk.value.slice());\n            }\n        }\n        return graphemes;\n    };\n\n    var testRangeBounds = function (document) {\n        var TEST_HEIGHT = 123;\n        if (document.createRange) {\n            var range = document.createRange();\n            if (range.getBoundingClientRect) {\n                var testElement = document.createElement('boundtest');\n                testElement.style.height = TEST_HEIGHT + \"px\";\n                testElement.style.display = 'block';\n                document.body.appendChild(testElement);\n                range.selectNode(testElement);\n                var rangeBounds = range.getBoundingClientRect();\n                var rangeHeight = Math.round(rangeBounds.height);\n                document.body.removeChild(testElement);\n                if (rangeHeight === TEST_HEIGHT) {\n                    return true;\n                }\n            }\n        }\n        return false;\n    };\n    var testIOSLineBreak = function (document) {\n        var testElement = document.createElement('boundtest');\n        testElement.style.width = '50px';\n        testElement.style.display = 'block';\n        testElement.style.fontSize = '12px';\n        testElement.style.letterSpacing = '0px';\n        testElement.style.wordSpacing = '0px';\n        document.body.appendChild(testElement);\n        var range = document.createRange();\n        testElement.innerHTML = typeof ''.repeat === 'function' ? '&#128104;'.repeat(10) : '';\n        var node = testElement.firstChild;\n        var textList = toCodePoints$1(node.data).map(function (i) { return fromCodePoint$1(i); });\n        var offset = 0;\n        var prev = {};\n        // ios 13 does not handle range getBoundingClientRect line changes correctly #2177\n        var supports = textList.every(function (text, i) {\n            range.setStart(node, offset);\n            range.setEnd(node, offset + text.length);\n            var rect = range.getBoundingClientRect();\n            offset += text.length;\n            var boundAhead = rect.x > prev.x || rect.y > prev.y;\n            prev = rect;\n            if (i === 0) {\n                return true;\n            }\n            return boundAhead;\n        });\n        document.body.removeChild(testElement);\n        return supports;\n    };\n    var testCORS = function () { return typeof new Image().crossOrigin !== 'undefined'; };\n    var testResponseType = function () { return typeof new XMLHttpRequest().responseType === 'string'; };\n    var testSVG = function (document) {\n        var img = new Image();\n        var canvas = document.createElement('canvas');\n        var ctx = canvas.getContext('2d');\n        if (!ctx) {\n            return false;\n        }\n        img.src = \"data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg'></svg>\";\n        try {\n            ctx.drawImage(img, 0, 0);\n            canvas.toDataURL();\n        }\n        catch (e) {\n            return false;\n        }\n        return true;\n    };\n    var isGreenPixel = function (data) {\n        return data[0] === 0 && data[1] === 255 && data[2] === 0 && data[3] === 255;\n    };\n    var testForeignObject = function (document) {\n        var canvas = document.createElement('canvas');\n        var size = 100;\n        canvas.width = size;\n        canvas.height = size;\n        var ctx = canvas.getContext('2d');\n        if (!ctx) {\n            return Promise.reject(false);\n        }\n        ctx.fillStyle = 'rgb(0, 255, 0)';\n        ctx.fillRect(0, 0, size, size);\n        var img = new Image();\n        var greenImageSrc = canvas.toDataURL();\n        img.src = greenImageSrc;\n        var svg = createForeignObjectSVG(size, size, 0, 0, img);\n        ctx.fillStyle = 'red';\n        ctx.fillRect(0, 0, size, size);\n        return loadSerializedSVG$1(svg)\n            .then(function (img) {\n            ctx.drawImage(img, 0, 0);\n            var data = ctx.getImageData(0, 0, size, size).data;\n            ctx.fillStyle = 'red';\n            ctx.fillRect(0, 0, size, size);\n            var node = document.createElement('div');\n            node.style.backgroundImage = \"url(\" + greenImageSrc + \")\";\n            node.style.height = size + \"px\";\n            // Firefox 55 does not render inline <img /> tags\n            return isGreenPixel(data)\n                ? loadSerializedSVG$1(createForeignObjectSVG(size, size, 0, 0, node))\n                : Promise.reject(false);\n        })\n            .then(function (img) {\n            ctx.drawImage(img, 0, 0);\n            // Edge does not render background-images\n            return isGreenPixel(ctx.getImageData(0, 0, size, size).data);\n        })\n            .catch(function () { return false; });\n    };\n    var createForeignObjectSVG = function (width, height, x, y, node) {\n        var xmlns = 'http://www.w3.org/2000/svg';\n        var svg = document.createElementNS(xmlns, 'svg');\n        var foreignObject = document.createElementNS(xmlns, 'foreignObject');\n        svg.setAttributeNS(null, 'width', width.toString());\n        svg.setAttributeNS(null, 'height', height.toString());\n        foreignObject.setAttributeNS(null, 'width', '100%');\n        foreignObject.setAttributeNS(null, 'height', '100%');\n        foreignObject.setAttributeNS(null, 'x', x.toString());\n        foreignObject.setAttributeNS(null, 'y', y.toString());\n        foreignObject.setAttributeNS(null, 'externalResourcesRequired', 'true');\n        svg.appendChild(foreignObject);\n        foreignObject.appendChild(node);\n        return svg;\n    };\n    var loadSerializedSVG$1 = function (svg) {\n        return new Promise(function (resolve, reject) {\n            var img = new Image();\n            img.onload = function () { return resolve(img); };\n            img.onerror = reject;\n            img.src = \"data:image/svg+xml;charset=utf-8,\" + encodeURIComponent(new XMLSerializer().serializeToString(svg));\n        });\n    };\n    var FEATURES = {\n        get SUPPORT_RANGE_BOUNDS() {\n            var value = testRangeBounds(document);\n            Object.defineProperty(FEATURES, 'SUPPORT_RANGE_BOUNDS', { value: value });\n            return value;\n        },\n        get SUPPORT_WORD_BREAKING() {\n            var value = FEATURES.SUPPORT_RANGE_BOUNDS && testIOSLineBreak(document);\n            Object.defineProperty(FEATURES, 'SUPPORT_WORD_BREAKING', { value: value });\n            return value;\n        },\n        get SUPPORT_SVG_DRAWING() {\n            var value = testSVG(document);\n            Object.defineProperty(FEATURES, 'SUPPORT_SVG_DRAWING', { value: value });\n            return value;\n        },\n        get SUPPORT_FOREIGNOBJECT_DRAWING() {\n            var value = typeof Array.from === 'function' && typeof window.fetch === 'function'\n                ? testForeignObject(document)\n                : Promise.resolve(false);\n            Object.defineProperty(FEATURES, 'SUPPORT_FOREIGNOBJECT_DRAWING', { value: value });\n            return value;\n        },\n        get SUPPORT_CORS_IMAGES() {\n            var value = testCORS();\n            Object.defineProperty(FEATURES, 'SUPPORT_CORS_IMAGES', { value: value });\n            return value;\n        },\n        get SUPPORT_RESPONSE_TYPE() {\n            var value = testResponseType();\n            Object.defineProperty(FEATURES, 'SUPPORT_RESPONSE_TYPE', { value: value });\n            return value;\n        },\n        get SUPPORT_CORS_XHR() {\n            var value = 'withCredentials' in new XMLHttpRequest();\n            Object.defineProperty(FEATURES, 'SUPPORT_CORS_XHR', { value: value });\n            return value;\n        },\n        get SUPPORT_NATIVE_TEXT_SEGMENTATION() {\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            var value = !!(typeof Intl !== 'undefined' && Intl.Segmenter);\n            Object.defineProperty(FEATURES, 'SUPPORT_NATIVE_TEXT_SEGMENTATION', { value: value });\n            return value;\n        }\n    };\n\n    var TextBounds = /** @class */ (function () {\n        function TextBounds(text, bounds) {\n            this.text = text;\n            this.bounds = bounds;\n        }\n        return TextBounds;\n    }());\n    var parseTextBounds = function (context, value, styles, node) {\n        var textList = breakText(value, styles);\n        var textBounds = [];\n        var offset = 0;\n        textList.forEach(function (text) {\n            if (styles.textDecorationLine.length || text.trim().length > 0) {\n                if (FEATURES.SUPPORT_RANGE_BOUNDS) {\n                    var clientRects = createRange(node, offset, text.length).getClientRects();\n                    if (clientRects.length > 1) {\n                        var subSegments = segmentGraphemes(text);\n                        var subOffset_1 = 0;\n                        subSegments.forEach(function (subSegment) {\n                            textBounds.push(new TextBounds(subSegment, Bounds.fromDOMRectList(context, createRange(node, subOffset_1 + offset, subSegment.length).getClientRects())));\n                            subOffset_1 += subSegment.length;\n                        });\n                    }\n                    else {\n                        textBounds.push(new TextBounds(text, Bounds.fromDOMRectList(context, clientRects)));\n                    }\n                }\n                else {\n                    var replacementNode = node.splitText(text.length);\n                    textBounds.push(new TextBounds(text, getWrapperBounds(context, node)));\n                    node = replacementNode;\n                }\n            }\n            else if (!FEATURES.SUPPORT_RANGE_BOUNDS) {\n                node = node.splitText(text.length);\n            }\n            offset += text.length;\n        });\n        return textBounds;\n    };\n    var getWrapperBounds = function (context, node) {\n        var ownerDocument = node.ownerDocument;\n        if (ownerDocument) {\n            var wrapper = ownerDocument.createElement('html2canvaswrapper');\n            wrapper.appendChild(node.cloneNode(true));\n            var parentNode = node.parentNode;\n            if (parentNode) {\n                parentNode.replaceChild(wrapper, node);\n                var bounds = parseBounds(context, wrapper);\n                if (wrapper.firstChild) {\n                    parentNode.replaceChild(wrapper.firstChild, wrapper);\n                }\n                return bounds;\n            }\n        }\n        return Bounds.EMPTY;\n    };\n    var createRange = function (node, offset, length) {\n        var ownerDocument = node.ownerDocument;\n        if (!ownerDocument) {\n            throw new Error('Node has no owner document');\n        }\n        var range = ownerDocument.createRange();\n        range.setStart(node, offset);\n        range.setEnd(node, offset + length);\n        return range;\n    };\n    var segmentGraphemes = function (value) {\n        if (FEATURES.SUPPORT_NATIVE_TEXT_SEGMENTATION) {\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            var segmenter = new Intl.Segmenter(void 0, { granularity: 'grapheme' });\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            return Array.from(segmenter.segment(value)).map(function (segment) { return segment.segment; });\n        }\n        return splitGraphemes(value);\n    };\n    var segmentWords = function (value, styles) {\n        if (FEATURES.SUPPORT_NATIVE_TEXT_SEGMENTATION) {\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            var segmenter = new Intl.Segmenter(void 0, {\n                granularity: 'word'\n            });\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            return Array.from(segmenter.segment(value)).map(function (segment) { return segment.segment; });\n        }\n        return breakWords(value, styles);\n    };\n    var breakText = function (value, styles) {\n        return styles.letterSpacing !== 0 ? segmentGraphemes(value) : segmentWords(value, styles);\n    };\n    // https://drafts.csswg.org/css-text/#word-separator\n    var wordSeparators = [0x0020, 0x00a0, 0x1361, 0x10100, 0x10101, 0x1039, 0x1091];\n    var breakWords = function (str, styles) {\n        var breaker = LineBreaker(str, {\n            lineBreak: styles.lineBreak,\n            wordBreak: styles.overflowWrap === \"break-word\" /* BREAK_WORD */ ? 'break-word' : styles.wordBreak\n        });\n        var words = [];\n        var bk;\n        var _loop_1 = function () {\n            if (bk.value) {\n                var value = bk.value.slice();\n                var codePoints = toCodePoints$1(value);\n                var word_1 = '';\n                codePoints.forEach(function (codePoint) {\n                    if (wordSeparators.indexOf(codePoint) === -1) {\n                        word_1 += fromCodePoint$1(codePoint);\n                    }\n                    else {\n                        if (word_1.length) {\n                            words.push(word_1);\n                        }\n                        words.push(fromCodePoint$1(codePoint));\n                        word_1 = '';\n                    }\n                });\n                if (word_1.length) {\n                    words.push(word_1);\n                }\n            }\n        };\n        while (!(bk = breaker.next()).done) {\n            _loop_1();\n        }\n        return words;\n    };\n\n    var TextContainer = /** @class */ (function () {\n        function TextContainer(context, node, styles) {\n            this.text = transform(node.data, styles.textTransform);\n            this.textBounds = parseTextBounds(context, this.text, styles, node);\n        }\n        return TextContainer;\n    }());\n    var transform = function (text, transform) {\n        switch (transform) {\n            case 1 /* LOWERCASE */:\n                return text.toLowerCase();\n            case 3 /* CAPITALIZE */:\n                return text.replace(CAPITALIZE, capitalize);\n            case 2 /* UPPERCASE */:\n                return text.toUpperCase();\n            default:\n                return text;\n        }\n    };\n    var CAPITALIZE = /(^|\\s|:|-|\\(|\\))([a-z])/g;\n    var capitalize = function (m, p1, p2) {\n        if (m.length > 0) {\n            return p1 + p2.toUpperCase();\n        }\n        return m;\n    };\n\n    var ImageElementContainer = /** @class */ (function (_super) {\n        __extends(ImageElementContainer, _super);\n        function ImageElementContainer(context, img) {\n            var _this = _super.call(this, context, img) || this;\n            _this.src = img.currentSrc || img.src;\n            _this.intrinsicWidth = img.naturalWidth;\n            _this.intrinsicHeight = img.naturalHeight;\n            _this.context.cache.addImage(_this.src);\n            return _this;\n        }\n        return ImageElementContainer;\n    }(ElementContainer));\n\n    var CanvasElementContainer = /** @class */ (function (_super) {\n        __extends(CanvasElementContainer, _super);\n        function CanvasElementContainer(context, canvas) {\n            var _this = _super.call(this, context, canvas) || this;\n            _this.canvas = canvas;\n            _this.intrinsicWidth = canvas.width;\n            _this.intrinsicHeight = canvas.height;\n            return _this;\n        }\n        return CanvasElementContainer;\n    }(ElementContainer));\n\n    var SVGElementContainer = /** @class */ (function (_super) {\n        __extends(SVGElementContainer, _super);\n        function SVGElementContainer(context, img) {\n            var _this = _super.call(this, context, img) || this;\n            var s = new XMLSerializer();\n            var bounds = parseBounds(context, img);\n            img.setAttribute('width', bounds.width + \"px\");\n            img.setAttribute('height', bounds.height + \"px\");\n            _this.svg = \"data:image/svg+xml,\" + encodeURIComponent(s.serializeToString(img));\n            _this.intrinsicWidth = img.width.baseVal.value;\n            _this.intrinsicHeight = img.height.baseVal.value;\n            _this.context.cache.addImage(_this.svg);\n            return _this;\n        }\n        return SVGElementContainer;\n    }(ElementContainer));\n\n    var LIElementContainer = /** @class */ (function (_super) {\n        __extends(LIElementContainer, _super);\n        function LIElementContainer(context, element) {\n            var _this = _super.call(this, context, element) || this;\n            _this.value = element.value;\n            return _this;\n        }\n        return LIElementContainer;\n    }(ElementContainer));\n\n    var OLElementContainer = /** @class */ (function (_super) {\n        __extends(OLElementContainer, _super);\n        function OLElementContainer(context, element) {\n            var _this = _super.call(this, context, element) || this;\n            _this.start = element.start;\n            _this.reversed = typeof element.reversed === 'boolean' && element.reversed === true;\n            return _this;\n        }\n        return OLElementContainer;\n    }(ElementContainer));\n\n    var CHECKBOX_BORDER_RADIUS = [\n        {\n            type: 15 /* DIMENSION_TOKEN */,\n            flags: 0,\n            unit: 'px',\n            number: 3\n        }\n    ];\n    var RADIO_BORDER_RADIUS = [\n        {\n            type: 16 /* PERCENTAGE_TOKEN */,\n            flags: 0,\n            number: 50\n        }\n    ];\n    var reformatInputBounds = function (bounds) {\n        if (bounds.width > bounds.height) {\n            return new Bounds(bounds.left + (bounds.width - bounds.height) / 2, bounds.top, bounds.height, bounds.height);\n        }\n        else if (bounds.width < bounds.height) {\n            return new Bounds(bounds.left, bounds.top + (bounds.height - bounds.width) / 2, bounds.width, bounds.width);\n        }\n        return bounds;\n    };\n    var getInputValue = function (node) {\n        var value = node.type === PASSWORD ? new Array(node.value.length + 1).join('\\u2022') : node.value;\n        return value.length === 0 ? node.placeholder || '' : value;\n    };\n    var CHECKBOX = 'checkbox';\n    var RADIO = 'radio';\n    var PASSWORD = 'password';\n    var INPUT_COLOR = 0x2a2a2aff;\n    var InputElementContainer = /** @class */ (function (_super) {\n        __extends(InputElementContainer, _super);\n        function InputElementContainer(context, input) {\n            var _this = _super.call(this, context, input) || this;\n            _this.type = input.type.toLowerCase();\n            _this.checked = input.checked;\n            _this.value = getInputValue(input);\n            if (_this.type === CHECKBOX || _this.type === RADIO) {\n                _this.styles.backgroundColor = 0xdededeff;\n                _this.styles.borderTopColor =\n                    _this.styles.borderRightColor =\n                        _this.styles.borderBottomColor =\n                            _this.styles.borderLeftColor =\n                                0xa5a5a5ff;\n                _this.styles.borderTopWidth =\n                    _this.styles.borderRightWidth =\n                        _this.styles.borderBottomWidth =\n                            _this.styles.borderLeftWidth =\n                                1;\n                _this.styles.borderTopStyle =\n                    _this.styles.borderRightStyle =\n                        _this.styles.borderBottomStyle =\n                            _this.styles.borderLeftStyle =\n                                1 /* SOLID */;\n                _this.styles.backgroundClip = [0 /* BORDER_BOX */];\n                _this.styles.backgroundOrigin = [0 /* BORDER_BOX */];\n                _this.bounds = reformatInputBounds(_this.bounds);\n            }\n            switch (_this.type) {\n                case CHECKBOX:\n                    _this.styles.borderTopRightRadius =\n                        _this.styles.borderTopLeftRadius =\n                            _this.styles.borderBottomRightRadius =\n                                _this.styles.borderBottomLeftRadius =\n                                    CHECKBOX_BORDER_RADIUS;\n                    break;\n                case RADIO:\n                    _this.styles.borderTopRightRadius =\n                        _this.styles.borderTopLeftRadius =\n                            _this.styles.borderBottomRightRadius =\n                                _this.styles.borderBottomLeftRadius =\n                                    RADIO_BORDER_RADIUS;\n                    break;\n            }\n            return _this;\n        }\n        return InputElementContainer;\n    }(ElementContainer));\n\n    var SelectElementContainer = /** @class */ (function (_super) {\n        __extends(SelectElementContainer, _super);\n        function SelectElementContainer(context, element) {\n            var _this = _super.call(this, context, element) || this;\n            var option = element.options[element.selectedIndex || 0];\n            _this.value = option ? option.text || '' : '';\n            return _this;\n        }\n        return SelectElementContainer;\n    }(ElementContainer));\n\n    var TextareaElementContainer = /** @class */ (function (_super) {\n        __extends(TextareaElementContainer, _super);\n        function TextareaElementContainer(context, element) {\n            var _this = _super.call(this, context, element) || this;\n            _this.value = element.value;\n            return _this;\n        }\n        return TextareaElementContainer;\n    }(ElementContainer));\n\n    var IFrameElementContainer = /** @class */ (function (_super) {\n        __extends(IFrameElementContainer, _super);\n        function IFrameElementContainer(context, iframe) {\n            var _this = _super.call(this, context, iframe) || this;\n            _this.src = iframe.src;\n            _this.width = parseInt(iframe.width, 10) || 0;\n            _this.height = parseInt(iframe.height, 10) || 0;\n            _this.backgroundColor = _this.styles.backgroundColor;\n            try {\n                if (iframe.contentWindow &&\n                    iframe.contentWindow.document &&\n                    iframe.contentWindow.document.documentElement) {\n                    _this.tree = parseTree(context, iframe.contentWindow.document.documentElement);\n                    // http://www.w3.org/TR/css3-background/#special-backgrounds\n                    var documentBackgroundColor = iframe.contentWindow.document.documentElement\n                        ? parseColor(context, getComputedStyle(iframe.contentWindow.document.documentElement).backgroundColor)\n                        : COLORS.TRANSPARENT;\n                    var bodyBackgroundColor = iframe.contentWindow.document.body\n                        ? parseColor(context, getComputedStyle(iframe.contentWindow.document.body).backgroundColor)\n                        : COLORS.TRANSPARENT;\n                    _this.backgroundColor = isTransparent(documentBackgroundColor)\n                        ? isTransparent(bodyBackgroundColor)\n                            ? _this.styles.backgroundColor\n                            : bodyBackgroundColor\n                        : documentBackgroundColor;\n                }\n            }\n            catch (e) { }\n            return _this;\n        }\n        return IFrameElementContainer;\n    }(ElementContainer));\n\n    var LIST_OWNERS = ['OL', 'UL', 'MENU'];\n    var parseNodeTree = function (context, node, parent, root) {\n        for (var childNode = node.firstChild, nextNode = void 0; childNode; childNode = nextNode) {\n            nextNode = childNode.nextSibling;\n            if (isTextNode(childNode) && childNode.data.trim().length > 0) {\n                parent.textNodes.push(new TextContainer(context, childNode, parent.styles));\n            }\n            else if (isElementNode(childNode)) {\n                if (isSlotElement(childNode) && childNode.assignedNodes) {\n                    childNode.assignedNodes().forEach(function (childNode) { return parseNodeTree(context, childNode, parent, root); });\n                }\n                else {\n                    var container = createContainer(context, childNode);\n                    if (container.styles.isVisible()) {\n                        if (createsRealStackingContext(childNode, container, root)) {\n                            container.flags |= 4 /* CREATES_REAL_STACKING_CONTEXT */;\n                        }\n                        else if (createsStackingContext(container.styles)) {\n                            container.flags |= 2 /* CREATES_STACKING_CONTEXT */;\n                        }\n                        if (LIST_OWNERS.indexOf(childNode.tagName) !== -1) {\n                            container.flags |= 8 /* IS_LIST_OWNER */;\n                        }\n                        parent.elements.push(container);\n                        childNode.slot;\n                        if (childNode.shadowRoot) {\n                            parseNodeTree(context, childNode.shadowRoot, container, root);\n                        }\n                        else if (!isTextareaElement(childNode) &&\n                            !isSVGElement(childNode) &&\n                            !isSelectElement(childNode)) {\n                            parseNodeTree(context, childNode, container, root);\n                        }\n                    }\n                }\n            }\n        }\n    };\n    var createContainer = function (context, element) {\n        if (isImageElement(element)) {\n            return new ImageElementContainer(context, element);\n        }\n        if (isCanvasElement(element)) {\n            return new CanvasElementContainer(context, element);\n        }\n        if (isSVGElement(element)) {\n            return new SVGElementContainer(context, element);\n        }\n        if (isLIElement(element)) {\n            return new LIElementContainer(context, element);\n        }\n        if (isOLElement(element)) {\n            return new OLElementContainer(context, element);\n        }\n        if (isInputElement(element)) {\n            return new InputElementContainer(context, element);\n        }\n        if (isSelectElement(element)) {\n            return new SelectElementContainer(context, element);\n        }\n        if (isTextareaElement(element)) {\n            return new TextareaElementContainer(context, element);\n        }\n        if (isIFrameElement(element)) {\n            return new IFrameElementContainer(context, element);\n        }\n        return new ElementContainer(context, element);\n    };\n    var parseTree = function (context, element) {\n        var container = createContainer(context, element);\n        container.flags |= 4 /* CREATES_REAL_STACKING_CONTEXT */;\n        parseNodeTree(context, element, container, container);\n        return container;\n    };\n    var createsRealStackingContext = function (node, container, root) {\n        return (container.styles.isPositionedWithZIndex() ||\n            container.styles.opacity < 1 ||\n            container.styles.isTransformed() ||\n            (isBodyElement(node) && root.styles.isTransparent()));\n    };\n    var createsStackingContext = function (styles) { return styles.isPositioned() || styles.isFloating(); };\n    var isTextNode = function (node) { return node.nodeType === Node.TEXT_NODE; };\n    var isElementNode = function (node) { return node.nodeType === Node.ELEMENT_NODE; };\n    var isHTMLElementNode = function (node) {\n        return isElementNode(node) && typeof node.style !== 'undefined' && !isSVGElementNode(node);\n    };\n    var isSVGElementNode = function (element) {\n        return typeof element.className === 'object';\n    };\n    var isLIElement = function (node) { return node.tagName === 'LI'; };\n    var isOLElement = function (node) { return node.tagName === 'OL'; };\n    var isInputElement = function (node) { return node.tagName === 'INPUT'; };\n    var isHTMLElement = function (node) { return node.tagName === 'HTML'; };\n    var isSVGElement = function (node) { return node.tagName === 'svg'; };\n    var isBodyElement = function (node) { return node.tagName === 'BODY'; };\n    var isCanvasElement = function (node) { return node.tagName === 'CANVAS'; };\n    var isVideoElement = function (node) { return node.tagName === 'VIDEO'; };\n    var isImageElement = function (node) { return node.tagName === 'IMG'; };\n    var isIFrameElement = function (node) { return node.tagName === 'IFRAME'; };\n    var isStyleElement = function (node) { return node.tagName === 'STYLE'; };\n    var isScriptElement = function (node) { return node.tagName === 'SCRIPT'; };\n    var isTextareaElement = function (node) { return node.tagName === 'TEXTAREA'; };\n    var isSelectElement = function (node) { return node.tagName === 'SELECT'; };\n    var isSlotElement = function (node) { return node.tagName === 'SLOT'; };\n    // https://html.spec.whatwg.org/multipage/custom-elements.html#valid-custom-element-name\n    var isCustomElement = function (node) { return node.tagName.indexOf('-') > 0; };\n\n    var CounterState = /** @class */ (function () {\n        function CounterState() {\n            this.counters = {};\n        }\n        CounterState.prototype.getCounterValue = function (name) {\n            var counter = this.counters[name];\n            if (counter && counter.length) {\n                return counter[counter.length - 1];\n            }\n            return 1;\n        };\n        CounterState.prototype.getCounterValues = function (name) {\n            var counter = this.counters[name];\n            return counter ? counter : [];\n        };\n        CounterState.prototype.pop = function (counters) {\n            var _this = this;\n            counters.forEach(function (counter) { return _this.counters[counter].pop(); });\n        };\n        CounterState.prototype.parse = function (style) {\n            var _this = this;\n            var counterIncrement = style.counterIncrement;\n            var counterReset = style.counterReset;\n            var canReset = true;\n            if (counterIncrement !== null) {\n                counterIncrement.forEach(function (entry) {\n                    var counter = _this.counters[entry.counter];\n                    if (counter && entry.increment !== 0) {\n                        canReset = false;\n                        if (!counter.length) {\n                            counter.push(1);\n                        }\n                        counter[Math.max(0, counter.length - 1)] += entry.increment;\n                    }\n                });\n            }\n            var counterNames = [];\n            if (canReset) {\n                counterReset.forEach(function (entry) {\n                    var counter = _this.counters[entry.counter];\n                    counterNames.push(entry.counter);\n                    if (!counter) {\n                        counter = _this.counters[entry.counter] = [];\n                    }\n                    counter.push(entry.reset);\n                });\n            }\n            return counterNames;\n        };\n        return CounterState;\n    }());\n    var ROMAN_UPPER = {\n        integers: [1000, 900, 500, 400, 100, 90, 50, 40, 10, 9, 5, 4, 1],\n        values: ['M', 'CM', 'D', 'CD', 'C', 'XC', 'L', 'XL', 'X', 'IX', 'V', 'IV', 'I']\n    };\n    var ARMENIAN = {\n        integers: [\n            9000, 8000, 7000, 6000, 5000, 4000, 3000, 2000, 1000, 900, 800, 700, 600, 500, 400, 300, 200, 100, 90, 80, 70,\n            60, 50, 40, 30, 20, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1\n        ],\n        values: [\n            'Ք',\n            'Փ',\n            'Ւ',\n            'Ց',\n            'Ր',\n            'Տ',\n            'Վ',\n            'Ս',\n            'Ռ',\n            'Ջ',\n            'Պ',\n            'Չ',\n            'Ո',\n            'Շ',\n            'Ն',\n            'Յ',\n            'Մ',\n            'Ճ',\n            'Ղ',\n            'Ձ',\n            'Հ',\n            'Կ',\n            'Ծ',\n            'Խ',\n            'Լ',\n            'Ի',\n            'Ժ',\n            'Թ',\n            'Ը',\n            'Է',\n            'Զ',\n            'Ե',\n            'Դ',\n            'Գ',\n            'Բ',\n            'Ա'\n        ]\n    };\n    var HEBREW = {\n        integers: [\n            10000, 9000, 8000, 7000, 6000, 5000, 4000, 3000, 2000, 1000, 400, 300, 200, 100, 90, 80, 70, 60, 50, 40, 30, 20,\n            19, 18, 17, 16, 15, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1\n        ],\n        values: [\n            'י׳',\n            'ט׳',\n            'ח׳',\n            'ז׳',\n            'ו׳',\n            'ה׳',\n            'ד׳',\n            'ג׳',\n            'ב׳',\n            'א׳',\n            'ת',\n            'ש',\n            'ר',\n            'ק',\n            'צ',\n            'פ',\n            'ע',\n            'ס',\n            'נ',\n            'מ',\n            'ל',\n            'כ',\n            'יט',\n            'יח',\n            'יז',\n            'טז',\n            'טו',\n            'י',\n            'ט',\n            'ח',\n            'ז',\n            'ו',\n            'ה',\n            'ד',\n            'ג',\n            'ב',\n            'א'\n        ]\n    };\n    var GEORGIAN = {\n        integers: [\n            10000, 9000, 8000, 7000, 6000, 5000, 4000, 3000, 2000, 1000, 900, 800, 700, 600, 500, 400, 300, 200, 100, 90,\n            80, 70, 60, 50, 40, 30, 20, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1\n        ],\n        values: [\n            'ჵ',\n            'ჰ',\n            'ჯ',\n            'ჴ',\n            'ხ',\n            'ჭ',\n            'წ',\n            'ძ',\n            'ც',\n            'ჩ',\n            'შ',\n            'ყ',\n            'ღ',\n            'ქ',\n            'ფ',\n            'ჳ',\n            'ტ',\n            'ს',\n            'რ',\n            'ჟ',\n            'პ',\n            'ო',\n            'ჲ',\n            'ნ',\n            'მ',\n            'ლ',\n            'კ',\n            'ი',\n            'თ',\n            'ჱ',\n            'ზ',\n            'ვ',\n            'ე',\n            'დ',\n            'გ',\n            'ბ',\n            'ა'\n        ]\n    };\n    var createAdditiveCounter = function (value, min, max, symbols, fallback, suffix) {\n        if (value < min || value > max) {\n            return createCounterText(value, fallback, suffix.length > 0);\n        }\n        return (symbols.integers.reduce(function (string, integer, index) {\n            while (value >= integer) {\n                value -= integer;\n                string += symbols.values[index];\n            }\n            return string;\n        }, '') + suffix);\n    };\n    var createCounterStyleWithSymbolResolver = function (value, codePointRangeLength, isNumeric, resolver) {\n        var string = '';\n        do {\n            if (!isNumeric) {\n                value--;\n            }\n            string = resolver(value) + string;\n            value /= codePointRangeLength;\n        } while (value * codePointRangeLength >= codePointRangeLength);\n        return string;\n    };\n    var createCounterStyleFromRange = function (value, codePointRangeStart, codePointRangeEnd, isNumeric, suffix) {\n        var codePointRangeLength = codePointRangeEnd - codePointRangeStart + 1;\n        return ((value < 0 ? '-' : '') +\n            (createCounterStyleWithSymbolResolver(Math.abs(value), codePointRangeLength, isNumeric, function (codePoint) {\n                return fromCodePoint$1(Math.floor(codePoint % codePointRangeLength) + codePointRangeStart);\n            }) +\n                suffix));\n    };\n    var createCounterStyleFromSymbols = function (value, symbols, suffix) {\n        if (suffix === void 0) { suffix = '. '; }\n        var codePointRangeLength = symbols.length;\n        return (createCounterStyleWithSymbolResolver(Math.abs(value), codePointRangeLength, false, function (codePoint) { return symbols[Math.floor(codePoint % codePointRangeLength)]; }) + suffix);\n    };\n    var CJK_ZEROS = 1 << 0;\n    var CJK_TEN_COEFFICIENTS = 1 << 1;\n    var CJK_TEN_HIGH_COEFFICIENTS = 1 << 2;\n    var CJK_HUNDRED_COEFFICIENTS = 1 << 3;\n    var createCJKCounter = function (value, numbers, multipliers, negativeSign, suffix, flags) {\n        if (value < -9999 || value > 9999) {\n            return createCounterText(value, 4 /* CJK_DECIMAL */, suffix.length > 0);\n        }\n        var tmp = Math.abs(value);\n        var string = suffix;\n        if (tmp === 0) {\n            return numbers[0] + string;\n        }\n        for (var digit = 0; tmp > 0 && digit <= 4; digit++) {\n            var coefficient = tmp % 10;\n            if (coefficient === 0 && contains(flags, CJK_ZEROS) && string !== '') {\n                string = numbers[coefficient] + string;\n            }\n            else if (coefficient > 1 ||\n                (coefficient === 1 && digit === 0) ||\n                (coefficient === 1 && digit === 1 && contains(flags, CJK_TEN_COEFFICIENTS)) ||\n                (coefficient === 1 && digit === 1 && contains(flags, CJK_TEN_HIGH_COEFFICIENTS) && value > 100) ||\n                (coefficient === 1 && digit > 1 && contains(flags, CJK_HUNDRED_COEFFICIENTS))) {\n                string = numbers[coefficient] + (digit > 0 ? multipliers[digit - 1] : '') + string;\n            }\n            else if (coefficient === 1 && digit > 0) {\n                string = multipliers[digit - 1] + string;\n            }\n            tmp = Math.floor(tmp / 10);\n        }\n        return (value < 0 ? negativeSign : '') + string;\n    };\n    var CHINESE_INFORMAL_MULTIPLIERS = '十百千萬';\n    var CHINESE_FORMAL_MULTIPLIERS = '拾佰仟萬';\n    var JAPANESE_NEGATIVE = 'マイナス';\n    var KOREAN_NEGATIVE = '마이너스';\n    var createCounterText = function (value, type, appendSuffix) {\n        var defaultSuffix = appendSuffix ? '. ' : '';\n        var cjkSuffix = appendSuffix ? '、' : '';\n        var koreanSuffix = appendSuffix ? ', ' : '';\n        var spaceSuffix = appendSuffix ? ' ' : '';\n        switch (type) {\n            case 0 /* DISC */:\n                return '•' + spaceSuffix;\n            case 1 /* CIRCLE */:\n                return '◦' + spaceSuffix;\n            case 2 /* SQUARE */:\n                return '◾' + spaceSuffix;\n            case 5 /* DECIMAL_LEADING_ZERO */:\n                var string = createCounterStyleFromRange(value, 48, 57, true, defaultSuffix);\n                return string.length < 4 ? \"0\" + string : string;\n            case 4 /* CJK_DECIMAL */:\n                return createCounterStyleFromSymbols(value, '〇一二三四五六七八九', cjkSuffix);\n            case 6 /* LOWER_ROMAN */:\n                return createAdditiveCounter(value, 1, 3999, ROMAN_UPPER, 3 /* DECIMAL */, defaultSuffix).toLowerCase();\n            case 7 /* UPPER_ROMAN */:\n                return createAdditiveCounter(value, 1, 3999, ROMAN_UPPER, 3 /* DECIMAL */, defaultSuffix);\n            case 8 /* LOWER_GREEK */:\n                return createCounterStyleFromRange(value, 945, 969, false, defaultSuffix);\n            case 9 /* LOWER_ALPHA */:\n                return createCounterStyleFromRange(value, 97, 122, false, defaultSuffix);\n            case 10 /* UPPER_ALPHA */:\n                return createCounterStyleFromRange(value, 65, 90, false, defaultSuffix);\n            case 11 /* ARABIC_INDIC */:\n                return createCounterStyleFromRange(value, 1632, 1641, true, defaultSuffix);\n            case 12 /* ARMENIAN */:\n            case 49 /* UPPER_ARMENIAN */:\n                return createAdditiveCounter(value, 1, 9999, ARMENIAN, 3 /* DECIMAL */, defaultSuffix);\n            case 35 /* LOWER_ARMENIAN */:\n                return createAdditiveCounter(value, 1, 9999, ARMENIAN, 3 /* DECIMAL */, defaultSuffix).toLowerCase();\n            case 13 /* BENGALI */:\n                return createCounterStyleFromRange(value, 2534, 2543, true, defaultSuffix);\n            case 14 /* CAMBODIAN */:\n            case 30 /* KHMER */:\n                return createCounterStyleFromRange(value, 6112, 6121, true, defaultSuffix);\n            case 15 /* CJK_EARTHLY_BRANCH */:\n                return createCounterStyleFromSymbols(value, '子丑寅卯辰巳午未申酉戌亥', cjkSuffix);\n            case 16 /* CJK_HEAVENLY_STEM */:\n                return createCounterStyleFromSymbols(value, '甲乙丙丁戊己庚辛壬癸', cjkSuffix);\n            case 17 /* CJK_IDEOGRAPHIC */:\n            case 48 /* TRAD_CHINESE_INFORMAL */:\n                return createCJKCounter(value, '零一二三四五六七八九', CHINESE_INFORMAL_MULTIPLIERS, '負', cjkSuffix, CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS | CJK_HUNDRED_COEFFICIENTS);\n            case 47 /* TRAD_CHINESE_FORMAL */:\n                return createCJKCounter(value, '零壹貳參肆伍陸柒捌玖', CHINESE_FORMAL_MULTIPLIERS, '負', cjkSuffix, CJK_ZEROS | CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS | CJK_HUNDRED_COEFFICIENTS);\n            case 42 /* SIMP_CHINESE_INFORMAL */:\n                return createCJKCounter(value, '零一二三四五六七八九', CHINESE_INFORMAL_MULTIPLIERS, '负', cjkSuffix, CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS | CJK_HUNDRED_COEFFICIENTS);\n            case 41 /* SIMP_CHINESE_FORMAL */:\n                return createCJKCounter(value, '零壹贰叁肆伍陆柒捌玖', CHINESE_FORMAL_MULTIPLIERS, '负', cjkSuffix, CJK_ZEROS | CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS | CJK_HUNDRED_COEFFICIENTS);\n            case 26 /* JAPANESE_INFORMAL */:\n                return createCJKCounter(value, '〇一二三四五六七八九', '十百千万', JAPANESE_NEGATIVE, cjkSuffix, 0);\n            case 25 /* JAPANESE_FORMAL */:\n                return createCJKCounter(value, '零壱弐参四伍六七八九', '拾百千万', JAPANESE_NEGATIVE, cjkSuffix, CJK_ZEROS | CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS);\n            case 31 /* KOREAN_HANGUL_FORMAL */:\n                return createCJKCounter(value, '영일이삼사오육칠팔구', '십백천만', KOREAN_NEGATIVE, koreanSuffix, CJK_ZEROS | CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS);\n            case 33 /* KOREAN_HANJA_INFORMAL */:\n                return createCJKCounter(value, '零一二三四五六七八九', '十百千萬', KOREAN_NEGATIVE, koreanSuffix, 0);\n            case 32 /* KOREAN_HANJA_FORMAL */:\n                return createCJKCounter(value, '零壹貳參四五六七八九', '拾百千', KOREAN_NEGATIVE, koreanSuffix, CJK_ZEROS | CJK_TEN_COEFFICIENTS | CJK_TEN_HIGH_COEFFICIENTS);\n            case 18 /* DEVANAGARI */:\n                return createCounterStyleFromRange(value, 0x966, 0x96f, true, defaultSuffix);\n            case 20 /* GEORGIAN */:\n                return createAdditiveCounter(value, 1, 19999, GEORGIAN, 3 /* DECIMAL */, defaultSuffix);\n            case 21 /* GUJARATI */:\n                return createCounterStyleFromRange(value, 0xae6, 0xaef, true, defaultSuffix);\n            case 22 /* GURMUKHI */:\n                return createCounterStyleFromRange(value, 0xa66, 0xa6f, true, defaultSuffix);\n            case 22 /* HEBREW */:\n                return createAdditiveCounter(value, 1, 10999, HEBREW, 3 /* DECIMAL */, defaultSuffix);\n            case 23 /* HIRAGANA */:\n                return createCounterStyleFromSymbols(value, 'あいうえおかきくけこさしすせそたちつてとなにぬねのはひふへほまみむめもやゆよらりるれろわゐゑをん');\n            case 24 /* HIRAGANA_IROHA */:\n                return createCounterStyleFromSymbols(value, 'いろはにほへとちりぬるをわかよたれそつねならむうゐのおくやまけふこえてあさきゆめみしゑひもせす');\n            case 27 /* KANNADA */:\n                return createCounterStyleFromRange(value, 0xce6, 0xcef, true, defaultSuffix);\n            case 28 /* KATAKANA */:\n                return createCounterStyleFromSymbols(value, 'アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヰヱヲン', cjkSuffix);\n            case 29 /* KATAKANA_IROHA */:\n                return createCounterStyleFromSymbols(value, 'イロハニホヘトチリヌルヲワカヨタレソツネナラムウヰノオクヤマケフコエテアサキユメミシヱヒモセス', cjkSuffix);\n            case 34 /* LAO */:\n                return createCounterStyleFromRange(value, 0xed0, 0xed9, true, defaultSuffix);\n            case 37 /* MONGOLIAN */:\n                return createCounterStyleFromRange(value, 0x1810, 0x1819, true, defaultSuffix);\n            case 38 /* MYANMAR */:\n                return createCounterStyleFromRange(value, 0x1040, 0x1049, true, defaultSuffix);\n            case 39 /* ORIYA */:\n                return createCounterStyleFromRange(value, 0xb66, 0xb6f, true, defaultSuffix);\n            case 40 /* PERSIAN */:\n                return createCounterStyleFromRange(value, 0x6f0, 0x6f9, true, defaultSuffix);\n            case 43 /* TAMIL */:\n                return createCounterStyleFromRange(value, 0xbe6, 0xbef, true, defaultSuffix);\n            case 44 /* TELUGU */:\n                return createCounterStyleFromRange(value, 0xc66, 0xc6f, true, defaultSuffix);\n            case 45 /* THAI */:\n                return createCounterStyleFromRange(value, 0xe50, 0xe59, true, defaultSuffix);\n            case 46 /* TIBETAN */:\n                return createCounterStyleFromRange(value, 0xf20, 0xf29, true, defaultSuffix);\n            case 3 /* DECIMAL */:\n            default:\n                return createCounterStyleFromRange(value, 48, 57, true, defaultSuffix);\n        }\n    };\n\n    var IGNORE_ATTRIBUTE = 'data-html2canvas-ignore';\n    var DocumentCloner = /** @class */ (function () {\n        function DocumentCloner(context, element, options) {\n            this.context = context;\n            this.options = options;\n            this.scrolledElements = [];\n            this.referenceElement = element;\n            this.counters = new CounterState();\n            this.quoteDepth = 0;\n            if (!element.ownerDocument) {\n                throw new Error('Cloned element does not have an owner document');\n            }\n            this.documentElement = this.cloneNode(element.ownerDocument.documentElement, false);\n        }\n        DocumentCloner.prototype.toIFrame = function (ownerDocument, windowSize) {\n            var _this = this;\n            var iframe = createIFrameContainer(ownerDocument, windowSize);\n            if (!iframe.contentWindow) {\n                return Promise.reject(\"Unable to find iframe window\");\n            }\n            var scrollX = ownerDocument.defaultView.pageXOffset;\n            var scrollY = ownerDocument.defaultView.pageYOffset;\n            var cloneWindow = iframe.contentWindow;\n            var documentClone = cloneWindow.document;\n            /* Chrome doesn't detect relative background-images assigned in inline <style> sheets when fetched through getComputedStyle\n             if window url is about:blank, we can assign the url to current by writing onto the document\n             */\n            var iframeLoad = iframeLoader(iframe).then(function () { return __awaiter(_this, void 0, void 0, function () {\n                var onclone, referenceElement;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            this.scrolledElements.forEach(restoreNodeScroll);\n                            if (cloneWindow) {\n                                cloneWindow.scrollTo(windowSize.left, windowSize.top);\n                                if (/(iPad|iPhone|iPod)/g.test(navigator.userAgent) &&\n                                    (cloneWindow.scrollY !== windowSize.top || cloneWindow.scrollX !== windowSize.left)) {\n                                    this.context.logger.warn('Unable to restore scroll position for cloned document');\n                                    this.context.windowBounds = this.context.windowBounds.add(cloneWindow.scrollX - windowSize.left, cloneWindow.scrollY - windowSize.top, 0, 0);\n                                }\n                            }\n                            onclone = this.options.onclone;\n                            referenceElement = this.clonedReferenceElement;\n                            if (typeof referenceElement === 'undefined') {\n                                return [2 /*return*/, Promise.reject(\"Error finding the \" + this.referenceElement.nodeName + \" in the cloned document\")];\n                            }\n                            if (!(documentClone.fonts && documentClone.fonts.ready)) return [3 /*break*/, 2];\n                            return [4 /*yield*/, documentClone.fonts.ready];\n                        case 1:\n                            _a.sent();\n                            _a.label = 2;\n                        case 2:\n                            if (!/(AppleWebKit)/g.test(navigator.userAgent)) return [3 /*break*/, 4];\n                            return [4 /*yield*/, imagesReady(documentClone)];\n                        case 3:\n                            _a.sent();\n                            _a.label = 4;\n                        case 4:\n                            if (typeof onclone === 'function') {\n                                return [2 /*return*/, Promise.resolve()\n                                        .then(function () { return onclone(documentClone, referenceElement); })\n                                        .then(function () { return iframe; })];\n                            }\n                            return [2 /*return*/, iframe];\n                    }\n                });\n            }); });\n            documentClone.open();\n            documentClone.write(serializeDoctype(document.doctype) + \"<html></html>\");\n            // Chrome scrolls the parent document for some reason after the write to the cloned window???\n            restoreOwnerScroll(this.referenceElement.ownerDocument, scrollX, scrollY);\n            documentClone.replaceChild(documentClone.adoptNode(this.documentElement), documentClone.documentElement);\n            documentClone.close();\n            return iframeLoad;\n        };\n        DocumentCloner.prototype.createElementClone = function (node) {\n            if (isDebugging(node, 2 /* CLONE */)) {\n                debugger;\n            }\n            if (isCanvasElement(node)) {\n                return this.createCanvasClone(node);\n            }\n            if (isVideoElement(node)) {\n                return this.createVideoClone(node);\n            }\n            if (isStyleElement(node)) {\n                return this.createStyleClone(node);\n            }\n            var clone = node.cloneNode(false);\n            if (isImageElement(clone)) {\n                if (isImageElement(node) && node.currentSrc && node.currentSrc !== node.src) {\n                    clone.src = node.currentSrc;\n                    clone.srcset = '';\n                }\n                if (clone.loading === 'lazy') {\n                    clone.loading = 'eager';\n                }\n            }\n            if (isCustomElement(clone)) {\n                return this.createCustomElementClone(clone);\n            }\n            return clone;\n        };\n        DocumentCloner.prototype.createCustomElementClone = function (node) {\n            var clone = document.createElement('html2canvascustomelement');\n            copyCSSStyles(node.style, clone);\n            return clone;\n        };\n        DocumentCloner.prototype.createStyleClone = function (node) {\n            try {\n                var sheet = node.sheet;\n                if (sheet && sheet.cssRules) {\n                    var css = [].slice.call(sheet.cssRules, 0).reduce(function (css, rule) {\n                        if (rule && typeof rule.cssText === 'string') {\n                            return css + rule.cssText;\n                        }\n                        return css;\n                    }, '');\n                    var style = node.cloneNode(false);\n                    style.textContent = css;\n                    return style;\n                }\n            }\n            catch (e) {\n                // accessing node.sheet.cssRules throws a DOMException\n                this.context.logger.error('Unable to access cssRules property', e);\n                if (e.name !== 'SecurityError') {\n                    throw e;\n                }\n            }\n            return node.cloneNode(false);\n        };\n        DocumentCloner.prototype.createCanvasClone = function (canvas) {\n            var _a;\n            if (this.options.inlineImages && canvas.ownerDocument) {\n                var img = canvas.ownerDocument.createElement('img');\n                try {\n                    img.src = canvas.toDataURL();\n                    return img;\n                }\n                catch (e) {\n                    this.context.logger.info(\"Unable to inline canvas contents, canvas is tainted\", canvas);\n                }\n            }\n            var clonedCanvas = canvas.cloneNode(false);\n            try {\n                clonedCanvas.width = canvas.width;\n                clonedCanvas.height = canvas.height;\n                var ctx = canvas.getContext('2d');\n                var clonedCtx = clonedCanvas.getContext('2d');\n                if (clonedCtx) {\n                    if (!this.options.allowTaint && ctx) {\n                        clonedCtx.putImageData(ctx.getImageData(0, 0, canvas.width, canvas.height), 0, 0);\n                    }\n                    else {\n                        var gl = (_a = canvas.getContext('webgl2')) !== null && _a !== void 0 ? _a : canvas.getContext('webgl');\n                        if (gl) {\n                            var attribs = gl.getContextAttributes();\n                            if ((attribs === null || attribs === void 0 ? void 0 : attribs.preserveDrawingBuffer) === false) {\n                                this.context.logger.warn('Unable to clone WebGL context as it has preserveDrawingBuffer=false', canvas);\n                            }\n                        }\n                        clonedCtx.drawImage(canvas, 0, 0);\n                    }\n                }\n                return clonedCanvas;\n            }\n            catch (e) {\n                this.context.logger.info(\"Unable to clone canvas as it is tainted\", canvas);\n            }\n            return clonedCanvas;\n        };\n        DocumentCloner.prototype.createVideoClone = function (video) {\n            var canvas = video.ownerDocument.createElement('canvas');\n            canvas.width = video.offsetWidth;\n            canvas.height = video.offsetHeight;\n            var ctx = canvas.getContext('2d');\n            try {\n                if (ctx) {\n                    ctx.drawImage(video, 0, 0, canvas.width, canvas.height);\n                    if (!this.options.allowTaint) {\n                        ctx.getImageData(0, 0, canvas.width, canvas.height);\n                    }\n                }\n                return canvas;\n            }\n            catch (e) {\n                this.context.logger.info(\"Unable to clone video as it is tainted\", video);\n            }\n            var blankCanvas = video.ownerDocument.createElement('canvas');\n            blankCanvas.width = video.offsetWidth;\n            blankCanvas.height = video.offsetHeight;\n            return blankCanvas;\n        };\n        DocumentCloner.prototype.appendChildNode = function (clone, child, copyStyles) {\n            if (!isElementNode(child) ||\n                (!isScriptElement(child) &&\n                    !child.hasAttribute(IGNORE_ATTRIBUTE) &&\n                    (typeof this.options.ignoreElements !== 'function' || !this.options.ignoreElements(child)))) {\n                if (!this.options.copyStyles || !isElementNode(child) || !isStyleElement(child)) {\n                    clone.appendChild(this.cloneNode(child, copyStyles));\n                }\n            }\n        };\n        DocumentCloner.prototype.cloneChildNodes = function (node, clone, copyStyles) {\n            var _this = this;\n            for (var child = node.shadowRoot ? node.shadowRoot.firstChild : node.firstChild; child; child = child.nextSibling) {\n                if (isElementNode(child) && isSlotElement(child) && typeof child.assignedNodes === 'function') {\n                    var assignedNodes = child.assignedNodes();\n                    if (assignedNodes.length) {\n                        assignedNodes.forEach(function (assignedNode) { return _this.appendChildNode(clone, assignedNode, copyStyles); });\n                    }\n                }\n                else {\n                    this.appendChildNode(clone, child, copyStyles);\n                }\n            }\n        };\n        DocumentCloner.prototype.cloneNode = function (node, copyStyles) {\n            if (isTextNode(node)) {\n                return document.createTextNode(node.data);\n            }\n            if (!node.ownerDocument) {\n                return node.cloneNode(false);\n            }\n            var window = node.ownerDocument.defaultView;\n            if (window && isElementNode(node) && (isHTMLElementNode(node) || isSVGElementNode(node))) {\n                var clone = this.createElementClone(node);\n                clone.style.transitionProperty = 'none';\n                var style = window.getComputedStyle(node);\n                var styleBefore = window.getComputedStyle(node, ':before');\n                var styleAfter = window.getComputedStyle(node, ':after');\n                if (this.referenceElement === node && isHTMLElementNode(clone)) {\n                    this.clonedReferenceElement = clone;\n                }\n                if (isBodyElement(clone)) {\n                    createPseudoHideStyles(clone);\n                }\n                var counters = this.counters.parse(new CSSParsedCounterDeclaration(this.context, style));\n                var before = this.resolvePseudoContent(node, clone, styleBefore, PseudoElementType.BEFORE);\n                if (isCustomElement(node)) {\n                    copyStyles = true;\n                }\n                if (!isVideoElement(node)) {\n                    this.cloneChildNodes(node, clone, copyStyles);\n                }\n                if (before) {\n                    clone.insertBefore(before, clone.firstChild);\n                }\n                var after = this.resolvePseudoContent(node, clone, styleAfter, PseudoElementType.AFTER);\n                if (after) {\n                    clone.appendChild(after);\n                }\n                this.counters.pop(counters);\n                if ((style && (this.options.copyStyles || isSVGElementNode(node)) && !isIFrameElement(node)) ||\n                    copyStyles) {\n                    copyCSSStyles(style, clone);\n                }\n                if (node.scrollTop !== 0 || node.scrollLeft !== 0) {\n                    this.scrolledElements.push([clone, node.scrollLeft, node.scrollTop]);\n                }\n                if ((isTextareaElement(node) || isSelectElement(node)) &&\n                    (isTextareaElement(clone) || isSelectElement(clone))) {\n                    clone.value = node.value;\n                }\n                return clone;\n            }\n            return node.cloneNode(false);\n        };\n        DocumentCloner.prototype.resolvePseudoContent = function (node, clone, style, pseudoElt) {\n            var _this = this;\n            if (!style) {\n                return;\n            }\n            var value = style.content;\n            var document = clone.ownerDocument;\n            if (!document || !value || value === 'none' || value === '-moz-alt-content' || style.display === 'none') {\n                return;\n            }\n            this.counters.parse(new CSSParsedCounterDeclaration(this.context, style));\n            var declaration = new CSSParsedPseudoDeclaration(this.context, style);\n            var anonymousReplacedElement = document.createElement('html2canvaspseudoelement');\n            copyCSSStyles(style, anonymousReplacedElement);\n            declaration.content.forEach(function (token) {\n                if (token.type === 0 /* STRING_TOKEN */) {\n                    anonymousReplacedElement.appendChild(document.createTextNode(token.value));\n                }\n                else if (token.type === 22 /* URL_TOKEN */) {\n                    var img = document.createElement('img');\n                    img.src = token.value;\n                    img.style.opacity = '1';\n                    anonymousReplacedElement.appendChild(img);\n                }\n                else if (token.type === 18 /* FUNCTION */) {\n                    if (token.name === 'attr') {\n                        var attr = token.values.filter(isIdentToken);\n                        if (attr.length) {\n                            anonymousReplacedElement.appendChild(document.createTextNode(node.getAttribute(attr[0].value) || ''));\n                        }\n                    }\n                    else if (token.name === 'counter') {\n                        var _a = token.values.filter(nonFunctionArgSeparator), counter = _a[0], counterStyle = _a[1];\n                        if (counter && isIdentToken(counter)) {\n                            var counterState = _this.counters.getCounterValue(counter.value);\n                            var counterType = counterStyle && isIdentToken(counterStyle)\n                                ? listStyleType.parse(_this.context, counterStyle.value)\n                                : 3 /* DECIMAL */;\n                            anonymousReplacedElement.appendChild(document.createTextNode(createCounterText(counterState, counterType, false)));\n                        }\n                    }\n                    else if (token.name === 'counters') {\n                        var _b = token.values.filter(nonFunctionArgSeparator), counter = _b[0], delim = _b[1], counterStyle = _b[2];\n                        if (counter && isIdentToken(counter)) {\n                            var counterStates = _this.counters.getCounterValues(counter.value);\n                            var counterType_1 = counterStyle && isIdentToken(counterStyle)\n                                ? listStyleType.parse(_this.context, counterStyle.value)\n                                : 3 /* DECIMAL */;\n                            var separator = delim && delim.type === 0 /* STRING_TOKEN */ ? delim.value : '';\n                            var text = counterStates\n                                .map(function (value) { return createCounterText(value, counterType_1, false); })\n                                .join(separator);\n                            anonymousReplacedElement.appendChild(document.createTextNode(text));\n                        }\n                    }\n                    else ;\n                }\n                else if (token.type === 20 /* IDENT_TOKEN */) {\n                    switch (token.value) {\n                        case 'open-quote':\n                            anonymousReplacedElement.appendChild(document.createTextNode(getQuote(declaration.quotes, _this.quoteDepth++, true)));\n                            break;\n                        case 'close-quote':\n                            anonymousReplacedElement.appendChild(document.createTextNode(getQuote(declaration.quotes, --_this.quoteDepth, false)));\n                            break;\n                        default:\n                            // safari doesn't parse string tokens correctly because of lack of quotes\n                            anonymousReplacedElement.appendChild(document.createTextNode(token.value));\n                    }\n                }\n            });\n            anonymousReplacedElement.className = PSEUDO_HIDE_ELEMENT_CLASS_BEFORE + \" \" + PSEUDO_HIDE_ELEMENT_CLASS_AFTER;\n            var newClassName = pseudoElt === PseudoElementType.BEFORE\n                ? \" \" + PSEUDO_HIDE_ELEMENT_CLASS_BEFORE\n                : \" \" + PSEUDO_HIDE_ELEMENT_CLASS_AFTER;\n            if (isSVGElementNode(clone)) {\n                clone.className.baseValue += newClassName;\n            }\n            else {\n                clone.className += newClassName;\n            }\n            return anonymousReplacedElement;\n        };\n        DocumentCloner.destroy = function (container) {\n            if (container.parentNode) {\n                container.parentNode.removeChild(container);\n                return true;\n            }\n            return false;\n        };\n        return DocumentCloner;\n    }());\n    var PseudoElementType;\n    (function (PseudoElementType) {\n        PseudoElementType[PseudoElementType[\"BEFORE\"] = 0] = \"BEFORE\";\n        PseudoElementType[PseudoElementType[\"AFTER\"] = 1] = \"AFTER\";\n    })(PseudoElementType || (PseudoElementType = {}));\n    var createIFrameContainer = function (ownerDocument, bounds) {\n        var cloneIframeContainer = ownerDocument.createElement('iframe');\n        cloneIframeContainer.className = 'html2canvas-container';\n        cloneIframeContainer.style.visibility = 'hidden';\n        cloneIframeContainer.style.position = 'fixed';\n        cloneIframeContainer.style.left = '-10000px';\n        cloneIframeContainer.style.top = '0px';\n        cloneIframeContainer.style.border = '0';\n        cloneIframeContainer.width = bounds.width.toString();\n        cloneIframeContainer.height = bounds.height.toString();\n        cloneIframeContainer.scrolling = 'no'; // ios won't scroll without it\n        cloneIframeContainer.setAttribute(IGNORE_ATTRIBUTE, 'true');\n        ownerDocument.body.appendChild(cloneIframeContainer);\n        return cloneIframeContainer;\n    };\n    var imageReady = function (img) {\n        return new Promise(function (resolve) {\n            if (img.complete) {\n                resolve();\n                return;\n            }\n            if (!img.src) {\n                resolve();\n                return;\n            }\n            img.onload = resolve;\n            img.onerror = resolve;\n        });\n    };\n    var imagesReady = function (document) {\n        return Promise.all([].slice.call(document.images, 0).map(imageReady));\n    };\n    var iframeLoader = function (iframe) {\n        return new Promise(function (resolve, reject) {\n            var cloneWindow = iframe.contentWindow;\n            if (!cloneWindow) {\n                return reject(\"No window assigned for iframe\");\n            }\n            var documentClone = cloneWindow.document;\n            cloneWindow.onload = iframe.onload = function () {\n                cloneWindow.onload = iframe.onload = null;\n                var interval = setInterval(function () {\n                    if (documentClone.body.childNodes.length > 0 && documentClone.readyState === 'complete') {\n                        clearInterval(interval);\n                        resolve(iframe);\n                    }\n                }, 50);\n            };\n        });\n    };\n    var ignoredStyleProperties = [\n        'all',\n        'd',\n        'content' // Safari shows pseudoelements if content is set\n    ];\n    var copyCSSStyles = function (style, target) {\n        // Edge does not provide value for cssText\n        for (var i = style.length - 1; i >= 0; i--) {\n            var property = style.item(i);\n            if (ignoredStyleProperties.indexOf(property) === -1) {\n                target.style.setProperty(property, style.getPropertyValue(property));\n            }\n        }\n        return target;\n    };\n    var serializeDoctype = function (doctype) {\n        var str = '';\n        if (doctype) {\n            str += '<!DOCTYPE ';\n            if (doctype.name) {\n                str += doctype.name;\n            }\n            if (doctype.internalSubset) {\n                str += doctype.internalSubset;\n            }\n            if (doctype.publicId) {\n                str += \"\\\"\" + doctype.publicId + \"\\\"\";\n            }\n            if (doctype.systemId) {\n                str += \"\\\"\" + doctype.systemId + \"\\\"\";\n            }\n            str += '>';\n        }\n        return str;\n    };\n    var restoreOwnerScroll = function (ownerDocument, x, y) {\n        if (ownerDocument &&\n            ownerDocument.defaultView &&\n            (x !== ownerDocument.defaultView.pageXOffset || y !== ownerDocument.defaultView.pageYOffset)) {\n            ownerDocument.defaultView.scrollTo(x, y);\n        }\n    };\n    var restoreNodeScroll = function (_a) {\n        var element = _a[0], x = _a[1], y = _a[2];\n        element.scrollLeft = x;\n        element.scrollTop = y;\n    };\n    var PSEUDO_BEFORE = ':before';\n    var PSEUDO_AFTER = ':after';\n    var PSEUDO_HIDE_ELEMENT_CLASS_BEFORE = '___html2canvas___pseudoelement_before';\n    var PSEUDO_HIDE_ELEMENT_CLASS_AFTER = '___html2canvas___pseudoelement_after';\n    var PSEUDO_HIDE_ELEMENT_STYLE = \"{\\n    content: \\\"\\\" !important;\\n    display: none !important;\\n}\";\n    var createPseudoHideStyles = function (body) {\n        createStyles(body, \".\" + PSEUDO_HIDE_ELEMENT_CLASS_BEFORE + PSEUDO_BEFORE + PSEUDO_HIDE_ELEMENT_STYLE + \"\\n         .\" + PSEUDO_HIDE_ELEMENT_CLASS_AFTER + PSEUDO_AFTER + PSEUDO_HIDE_ELEMENT_STYLE);\n    };\n    var createStyles = function (body, styles) {\n        var document = body.ownerDocument;\n        if (document) {\n            var style = document.createElement('style');\n            style.textContent = styles;\n            body.appendChild(style);\n        }\n    };\n\n    var CacheStorage = /** @class */ (function () {\n        function CacheStorage() {\n        }\n        CacheStorage.getOrigin = function (url) {\n            var link = CacheStorage._link;\n            if (!link) {\n                return 'about:blank';\n            }\n            link.href = url;\n            link.href = link.href; // IE9, LOL! - http://jsfiddle.net/niklasvh/2e48b/\n            return link.protocol + link.hostname + link.port;\n        };\n        CacheStorage.isSameOrigin = function (src) {\n            return CacheStorage.getOrigin(src) === CacheStorage._origin;\n        };\n        CacheStorage.setContext = function (window) {\n            CacheStorage._link = window.document.createElement('a');\n            CacheStorage._origin = CacheStorage.getOrigin(window.location.href);\n        };\n        CacheStorage._origin = 'about:blank';\n        return CacheStorage;\n    }());\n    var Cache = /** @class */ (function () {\n        function Cache(context, _options) {\n            this.context = context;\n            this._options = _options;\n            // eslint-disable-next-line @typescript-eslint/no-explicit-any\n            this._cache = {};\n        }\n        Cache.prototype.addImage = function (src) {\n            var result = Promise.resolve();\n            if (this.has(src)) {\n                return result;\n            }\n            if (isBlobImage(src) || isRenderable(src)) {\n                (this._cache[src] = this.loadImage(src)).catch(function () {\n                    // prevent unhandled rejection\n                });\n                return result;\n            }\n            return result;\n        };\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        Cache.prototype.match = function (src) {\n            return this._cache[src];\n        };\n        Cache.prototype.loadImage = function (key) {\n            return __awaiter(this, void 0, void 0, function () {\n                var isSameOrigin, useCORS, useProxy, src;\n                var _this = this;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            isSameOrigin = CacheStorage.isSameOrigin(key);\n                            useCORS = !isInlineImage(key) && this._options.useCORS === true && FEATURES.SUPPORT_CORS_IMAGES && !isSameOrigin;\n                            useProxy = !isInlineImage(key) &&\n                                !isSameOrigin &&\n                                !isBlobImage(key) &&\n                                typeof this._options.proxy === 'string' &&\n                                FEATURES.SUPPORT_CORS_XHR &&\n                                !useCORS;\n                            if (!isSameOrigin &&\n                                this._options.allowTaint === false &&\n                                !isInlineImage(key) &&\n                                !isBlobImage(key) &&\n                                !useProxy &&\n                                !useCORS) {\n                                return [2 /*return*/];\n                            }\n                            src = key;\n                            if (!useProxy) return [3 /*break*/, 2];\n                            return [4 /*yield*/, this.proxy(src)];\n                        case 1:\n                            src = _a.sent();\n                            _a.label = 2;\n                        case 2:\n                            this.context.logger.debug(\"Added image \" + key.substring(0, 256));\n                            return [4 /*yield*/, new Promise(function (resolve, reject) {\n                                    var img = new Image();\n                                    img.onload = function () { return resolve(img); };\n                                    img.onerror = reject;\n                                    //ios safari 10.3 taints canvas with data urls unless crossOrigin is set to anonymous\n                                    if (isInlineBase64Image(src) || useCORS) {\n                                        img.crossOrigin = 'anonymous';\n                                    }\n                                    img.src = src;\n                                    if (img.complete === true) {\n                                        // Inline XML images may fail to parse, throwing an Error later on\n                                        setTimeout(function () { return resolve(img); }, 500);\n                                    }\n                                    if (_this._options.imageTimeout > 0) {\n                                        setTimeout(function () { return reject(\"Timed out (\" + _this._options.imageTimeout + \"ms) loading image\"); }, _this._options.imageTimeout);\n                                    }\n                                })];\n                        case 3: return [2 /*return*/, _a.sent()];\n                    }\n                });\n            });\n        };\n        Cache.prototype.has = function (key) {\n            return typeof this._cache[key] !== 'undefined';\n        };\n        Cache.prototype.keys = function () {\n            return Promise.resolve(Object.keys(this._cache));\n        };\n        Cache.prototype.proxy = function (src) {\n            var _this = this;\n            var proxy = this._options.proxy;\n            if (!proxy) {\n                throw new Error('No proxy defined');\n            }\n            var key = src.substring(0, 256);\n            return new Promise(function (resolve, reject) {\n                var responseType = FEATURES.SUPPORT_RESPONSE_TYPE ? 'blob' : 'text';\n                var xhr = new XMLHttpRequest();\n                xhr.onload = function () {\n                    if (xhr.status === 200) {\n                        if (responseType === 'text') {\n                            resolve(xhr.response);\n                        }\n                        else {\n                            var reader_1 = new FileReader();\n                            reader_1.addEventListener('load', function () { return resolve(reader_1.result); }, false);\n                            reader_1.addEventListener('error', function (e) { return reject(e); }, false);\n                            reader_1.readAsDataURL(xhr.response);\n                        }\n                    }\n                    else {\n                        reject(\"Failed to proxy resource \" + key + \" with status code \" + xhr.status);\n                    }\n                };\n                xhr.onerror = reject;\n                var queryString = proxy.indexOf('?') > -1 ? '&' : '?';\n                xhr.open('GET', \"\" + proxy + queryString + \"url=\" + encodeURIComponent(src) + \"&responseType=\" + responseType);\n                if (responseType !== 'text' && xhr instanceof XMLHttpRequest) {\n                    xhr.responseType = responseType;\n                }\n                if (_this._options.imageTimeout) {\n                    var timeout_1 = _this._options.imageTimeout;\n                    xhr.timeout = timeout_1;\n                    xhr.ontimeout = function () { return reject(\"Timed out (\" + timeout_1 + \"ms) proxying \" + key); };\n                }\n                xhr.send();\n            });\n        };\n        return Cache;\n    }());\n    var INLINE_SVG = /^data:image\\/svg\\+xml/i;\n    var INLINE_BASE64 = /^data:image\\/.*;base64,/i;\n    var INLINE_IMG = /^data:image\\/.*/i;\n    var isRenderable = function (src) { return FEATURES.SUPPORT_SVG_DRAWING || !isSVG(src); };\n    var isInlineImage = function (src) { return INLINE_IMG.test(src); };\n    var isInlineBase64Image = function (src) { return INLINE_BASE64.test(src); };\n    var isBlobImage = function (src) { return src.substr(0, 4) === 'blob'; };\n    var isSVG = function (src) { return src.substr(-3).toLowerCase() === 'svg' || INLINE_SVG.test(src); };\n\n    var Vector = /** @class */ (function () {\n        function Vector(x, y) {\n            this.type = 0 /* VECTOR */;\n            this.x = x;\n            this.y = y;\n        }\n        Vector.prototype.add = function (deltaX, deltaY) {\n            return new Vector(this.x + deltaX, this.y + deltaY);\n        };\n        return Vector;\n    }());\n\n    var lerp = function (a, b, t) {\n        return new Vector(a.x + (b.x - a.x) * t, a.y + (b.y - a.y) * t);\n    };\n    var BezierCurve = /** @class */ (function () {\n        function BezierCurve(start, startControl, endControl, end) {\n            this.type = 1 /* BEZIER_CURVE */;\n            this.start = start;\n            this.startControl = startControl;\n            this.endControl = endControl;\n            this.end = end;\n        }\n        BezierCurve.prototype.subdivide = function (t, firstHalf) {\n            var ab = lerp(this.start, this.startControl, t);\n            var bc = lerp(this.startControl, this.endControl, t);\n            var cd = lerp(this.endControl, this.end, t);\n            var abbc = lerp(ab, bc, t);\n            var bccd = lerp(bc, cd, t);\n            var dest = lerp(abbc, bccd, t);\n            return firstHalf ? new BezierCurve(this.start, ab, abbc, dest) : new BezierCurve(dest, bccd, cd, this.end);\n        };\n        BezierCurve.prototype.add = function (deltaX, deltaY) {\n            return new BezierCurve(this.start.add(deltaX, deltaY), this.startControl.add(deltaX, deltaY), this.endControl.add(deltaX, deltaY), this.end.add(deltaX, deltaY));\n        };\n        BezierCurve.prototype.reverse = function () {\n            return new BezierCurve(this.end, this.endControl, this.startControl, this.start);\n        };\n        return BezierCurve;\n    }());\n    var isBezierCurve = function (path) { return path.type === 1 /* BEZIER_CURVE */; };\n\n    var BoundCurves = /** @class */ (function () {\n        function BoundCurves(element) {\n            var styles = element.styles;\n            var bounds = element.bounds;\n            var _a = getAbsoluteValueForTuple(styles.borderTopLeftRadius, bounds.width, bounds.height), tlh = _a[0], tlv = _a[1];\n            var _b = getAbsoluteValueForTuple(styles.borderTopRightRadius, bounds.width, bounds.height), trh = _b[0], trv = _b[1];\n            var _c = getAbsoluteValueForTuple(styles.borderBottomRightRadius, bounds.width, bounds.height), brh = _c[0], brv = _c[1];\n            var _d = getAbsoluteValueForTuple(styles.borderBottomLeftRadius, bounds.width, bounds.height), blh = _d[0], blv = _d[1];\n            var factors = [];\n            factors.push((tlh + trh) / bounds.width);\n            factors.push((blh + brh) / bounds.width);\n            factors.push((tlv + blv) / bounds.height);\n            factors.push((trv + brv) / bounds.height);\n            var maxFactor = Math.max.apply(Math, factors);\n            if (maxFactor > 1) {\n                tlh /= maxFactor;\n                tlv /= maxFactor;\n                trh /= maxFactor;\n                trv /= maxFactor;\n                brh /= maxFactor;\n                brv /= maxFactor;\n                blh /= maxFactor;\n                blv /= maxFactor;\n            }\n            var topWidth = bounds.width - trh;\n            var rightHeight = bounds.height - brv;\n            var bottomWidth = bounds.width - brh;\n            var leftHeight = bounds.height - blv;\n            var borderTopWidth = styles.borderTopWidth;\n            var borderRightWidth = styles.borderRightWidth;\n            var borderBottomWidth = styles.borderBottomWidth;\n            var borderLeftWidth = styles.borderLeftWidth;\n            var paddingTop = getAbsoluteValue(styles.paddingTop, element.bounds.width);\n            var paddingRight = getAbsoluteValue(styles.paddingRight, element.bounds.width);\n            var paddingBottom = getAbsoluteValue(styles.paddingBottom, element.bounds.width);\n            var paddingLeft = getAbsoluteValue(styles.paddingLeft, element.bounds.width);\n            this.topLeftBorderDoubleOuterBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth / 3, bounds.top + borderTopWidth / 3, tlh - borderLeftWidth / 3, tlv - borderTopWidth / 3, CORNER.TOP_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth / 3, bounds.top + borderTopWidth / 3);\n            this.topRightBorderDoubleOuterBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + topWidth, bounds.top + borderTopWidth / 3, trh - borderRightWidth / 3, trv - borderTopWidth / 3, CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth / 3, bounds.top + borderTopWidth / 3);\n            this.bottomRightBorderDoubleOuterBox =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + bottomWidth, bounds.top + rightHeight, brh - borderRightWidth / 3, brv - borderBottomWidth / 3, CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth / 3, bounds.top + bounds.height - borderBottomWidth / 3);\n            this.bottomLeftBorderDoubleOuterBox =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth / 3, bounds.top + leftHeight, blh - borderLeftWidth / 3, blv - borderBottomWidth / 3, CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth / 3, bounds.top + bounds.height - borderBottomWidth / 3);\n            this.topLeftBorderDoubleInnerBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + (borderLeftWidth * 2) / 3, bounds.top + (borderTopWidth * 2) / 3, tlh - (borderLeftWidth * 2) / 3, tlv - (borderTopWidth * 2) / 3, CORNER.TOP_LEFT)\n                    : new Vector(bounds.left + (borderLeftWidth * 2) / 3, bounds.top + (borderTopWidth * 2) / 3);\n            this.topRightBorderDoubleInnerBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + topWidth, bounds.top + (borderTopWidth * 2) / 3, trh - (borderRightWidth * 2) / 3, trv - (borderTopWidth * 2) / 3, CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width - (borderRightWidth * 2) / 3, bounds.top + (borderTopWidth * 2) / 3);\n            this.bottomRightBorderDoubleInnerBox =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + bottomWidth, bounds.top + rightHeight, brh - (borderRightWidth * 2) / 3, brv - (borderBottomWidth * 2) / 3, CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width - (borderRightWidth * 2) / 3, bounds.top + bounds.height - (borderBottomWidth * 2) / 3);\n            this.bottomLeftBorderDoubleInnerBox =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left + (borderLeftWidth * 2) / 3, bounds.top + leftHeight, blh - (borderLeftWidth * 2) / 3, blv - (borderBottomWidth * 2) / 3, CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left + (borderLeftWidth * 2) / 3, bounds.top + bounds.height - (borderBottomWidth * 2) / 3);\n            this.topLeftBorderStroke =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth / 2, bounds.top + borderTopWidth / 2, tlh - borderLeftWidth / 2, tlv - borderTopWidth / 2, CORNER.TOP_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth / 2, bounds.top + borderTopWidth / 2);\n            this.topRightBorderStroke =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + topWidth, bounds.top + borderTopWidth / 2, trh - borderRightWidth / 2, trv - borderTopWidth / 2, CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth / 2, bounds.top + borderTopWidth / 2);\n            this.bottomRightBorderStroke =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + bottomWidth, bounds.top + rightHeight, brh - borderRightWidth / 2, brv - borderBottomWidth / 2, CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth / 2, bounds.top + bounds.height - borderBottomWidth / 2);\n            this.bottomLeftBorderStroke =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth / 2, bounds.top + leftHeight, blh - borderLeftWidth / 2, blv - borderBottomWidth / 2, CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth / 2, bounds.top + bounds.height - borderBottomWidth / 2);\n            this.topLeftBorderBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left, bounds.top, tlh, tlv, CORNER.TOP_LEFT)\n                    : new Vector(bounds.left, bounds.top);\n            this.topRightBorderBox =\n                trh > 0 || trv > 0\n                    ? getCurvePoints(bounds.left + topWidth, bounds.top, trh, trv, CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width, bounds.top);\n            this.bottomRightBorderBox =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + bottomWidth, bounds.top + rightHeight, brh, brv, CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width, bounds.top + bounds.height);\n            this.bottomLeftBorderBox =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left, bounds.top + leftHeight, blh, blv, CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left, bounds.top + bounds.height);\n            this.topLeftPaddingBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth, bounds.top + borderTopWidth, Math.max(0, tlh - borderLeftWidth), Math.max(0, tlv - borderTopWidth), CORNER.TOP_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth, bounds.top + borderTopWidth);\n            this.topRightPaddingBox =\n                trh > 0 || trv > 0\n                    ? getCurvePoints(bounds.left + Math.min(topWidth, bounds.width - borderRightWidth), bounds.top + borderTopWidth, topWidth > bounds.width + borderRightWidth ? 0 : Math.max(0, trh - borderRightWidth), Math.max(0, trv - borderTopWidth), CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth, bounds.top + borderTopWidth);\n            this.bottomRightPaddingBox =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + Math.min(bottomWidth, bounds.width - borderLeftWidth), bounds.top + Math.min(rightHeight, bounds.height - borderBottomWidth), Math.max(0, brh - borderRightWidth), Math.max(0, brv - borderBottomWidth), CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width - borderRightWidth, bounds.top + bounds.height - borderBottomWidth);\n            this.bottomLeftPaddingBox =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth, bounds.top + Math.min(leftHeight, bounds.height - borderBottomWidth), Math.max(0, blh - borderLeftWidth), Math.max(0, blv - borderBottomWidth), CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth, bounds.top + bounds.height - borderBottomWidth);\n            this.topLeftContentBox =\n                tlh > 0 || tlv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth + paddingLeft, bounds.top + borderTopWidth + paddingTop, Math.max(0, tlh - (borderLeftWidth + paddingLeft)), Math.max(0, tlv - (borderTopWidth + paddingTop)), CORNER.TOP_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth + paddingLeft, bounds.top + borderTopWidth + paddingTop);\n            this.topRightContentBox =\n                trh > 0 || trv > 0\n                    ? getCurvePoints(bounds.left + Math.min(topWidth, bounds.width + borderLeftWidth + paddingLeft), bounds.top + borderTopWidth + paddingTop, topWidth > bounds.width + borderLeftWidth + paddingLeft ? 0 : trh - borderLeftWidth + paddingLeft, trv - (borderTopWidth + paddingTop), CORNER.TOP_RIGHT)\n                    : new Vector(bounds.left + bounds.width - (borderRightWidth + paddingRight), bounds.top + borderTopWidth + paddingTop);\n            this.bottomRightContentBox =\n                brh > 0 || brv > 0\n                    ? getCurvePoints(bounds.left + Math.min(bottomWidth, bounds.width - (borderLeftWidth + paddingLeft)), bounds.top + Math.min(rightHeight, bounds.height + borderTopWidth + paddingTop), Math.max(0, brh - (borderRightWidth + paddingRight)), brv - (borderBottomWidth + paddingBottom), CORNER.BOTTOM_RIGHT)\n                    : new Vector(bounds.left + bounds.width - (borderRightWidth + paddingRight), bounds.top + bounds.height - (borderBottomWidth + paddingBottom));\n            this.bottomLeftContentBox =\n                blh > 0 || blv > 0\n                    ? getCurvePoints(bounds.left + borderLeftWidth + paddingLeft, bounds.top + leftHeight, Math.max(0, blh - (borderLeftWidth + paddingLeft)), blv - (borderBottomWidth + paddingBottom), CORNER.BOTTOM_LEFT)\n                    : new Vector(bounds.left + borderLeftWidth + paddingLeft, bounds.top + bounds.height - (borderBottomWidth + paddingBottom));\n        }\n        return BoundCurves;\n    }());\n    var CORNER;\n    (function (CORNER) {\n        CORNER[CORNER[\"TOP_LEFT\"] = 0] = \"TOP_LEFT\";\n        CORNER[CORNER[\"TOP_RIGHT\"] = 1] = \"TOP_RIGHT\";\n        CORNER[CORNER[\"BOTTOM_RIGHT\"] = 2] = \"BOTTOM_RIGHT\";\n        CORNER[CORNER[\"BOTTOM_LEFT\"] = 3] = \"BOTTOM_LEFT\";\n    })(CORNER || (CORNER = {}));\n    var getCurvePoints = function (x, y, r1, r2, position) {\n        var kappa = 4 * ((Math.sqrt(2) - 1) / 3);\n        var ox = r1 * kappa; // control point offset horizontal\n        var oy = r2 * kappa; // control point offset vertical\n        var xm = x + r1; // x-middle\n        var ym = y + r2; // y-middle\n        switch (position) {\n            case CORNER.TOP_LEFT:\n                return new BezierCurve(new Vector(x, ym), new Vector(x, ym - oy), new Vector(xm - ox, y), new Vector(xm, y));\n            case CORNER.TOP_RIGHT:\n                return new BezierCurve(new Vector(x, y), new Vector(x + ox, y), new Vector(xm, ym - oy), new Vector(xm, ym));\n            case CORNER.BOTTOM_RIGHT:\n                return new BezierCurve(new Vector(xm, y), new Vector(xm, y + oy), new Vector(x + ox, ym), new Vector(x, ym));\n            case CORNER.BOTTOM_LEFT:\n            default:\n                return new BezierCurve(new Vector(xm, ym), new Vector(xm - ox, ym), new Vector(x, y + oy), new Vector(x, y));\n        }\n    };\n    var calculateBorderBoxPath = function (curves) {\n        return [curves.topLeftBorderBox, curves.topRightBorderBox, curves.bottomRightBorderBox, curves.bottomLeftBorderBox];\n    };\n    var calculateContentBoxPath = function (curves) {\n        return [\n            curves.topLeftContentBox,\n            curves.topRightContentBox,\n            curves.bottomRightContentBox,\n            curves.bottomLeftContentBox\n        ];\n    };\n    var calculatePaddingBoxPath = function (curves) {\n        return [\n            curves.topLeftPaddingBox,\n            curves.topRightPaddingBox,\n            curves.bottomRightPaddingBox,\n            curves.bottomLeftPaddingBox\n        ];\n    };\n\n    var TransformEffect = /** @class */ (function () {\n        function TransformEffect(offsetX, offsetY, matrix) {\n            this.offsetX = offsetX;\n            this.offsetY = offsetY;\n            this.matrix = matrix;\n            this.type = 0 /* TRANSFORM */;\n            this.target = 2 /* BACKGROUND_BORDERS */ | 4 /* CONTENT */;\n        }\n        return TransformEffect;\n    }());\n    var ClipEffect = /** @class */ (function () {\n        function ClipEffect(path, target) {\n            this.path = path;\n            this.target = target;\n            this.type = 1 /* CLIP */;\n        }\n        return ClipEffect;\n    }());\n    var OpacityEffect = /** @class */ (function () {\n        function OpacityEffect(opacity) {\n            this.opacity = opacity;\n            this.type = 2 /* OPACITY */;\n            this.target = 2 /* BACKGROUND_BORDERS */ | 4 /* CONTENT */;\n        }\n        return OpacityEffect;\n    }());\n    var isTransformEffect = function (effect) {\n        return effect.type === 0 /* TRANSFORM */;\n    };\n    var isClipEffect = function (effect) { return effect.type === 1 /* CLIP */; };\n    var isOpacityEffect = function (effect) { return effect.type === 2 /* OPACITY */; };\n\n    var equalPath = function (a, b) {\n        if (a.length === b.length) {\n            return a.some(function (v, i) { return v === b[i]; });\n        }\n        return false;\n    };\n    var transformPath = function (path, deltaX, deltaY, deltaW, deltaH) {\n        return path.map(function (point, index) {\n            switch (index) {\n                case 0:\n                    return point.add(deltaX, deltaY);\n                case 1:\n                    return point.add(deltaX + deltaW, deltaY);\n                case 2:\n                    return point.add(deltaX + deltaW, deltaY + deltaH);\n                case 3:\n                    return point.add(deltaX, deltaY + deltaH);\n            }\n            return point;\n        });\n    };\n\n    var StackingContext = /** @class */ (function () {\n        function StackingContext(container) {\n            this.element = container;\n            this.inlineLevel = [];\n            this.nonInlineLevel = [];\n            this.negativeZIndex = [];\n            this.zeroOrAutoZIndexOrTransformedOrOpacity = [];\n            this.positiveZIndex = [];\n            this.nonPositionedFloats = [];\n            this.nonPositionedInlineLevel = [];\n        }\n        return StackingContext;\n    }());\n    var ElementPaint = /** @class */ (function () {\n        function ElementPaint(container, parent) {\n            this.container = container;\n            this.parent = parent;\n            this.effects = [];\n            this.curves = new BoundCurves(this.container);\n            if (this.container.styles.opacity < 1) {\n                this.effects.push(new OpacityEffect(this.container.styles.opacity));\n            }\n            if (this.container.styles.transform !== null) {\n                var offsetX = this.container.bounds.left + this.container.styles.transformOrigin[0].number;\n                var offsetY = this.container.bounds.top + this.container.styles.transformOrigin[1].number;\n                var matrix = this.container.styles.transform;\n                this.effects.push(new TransformEffect(offsetX, offsetY, matrix));\n            }\n            if (this.container.styles.overflowX !== 0 /* VISIBLE */) {\n                var borderBox = calculateBorderBoxPath(this.curves);\n                var paddingBox = calculatePaddingBoxPath(this.curves);\n                if (equalPath(borderBox, paddingBox)) {\n                    this.effects.push(new ClipEffect(borderBox, 2 /* BACKGROUND_BORDERS */ | 4 /* CONTENT */));\n                }\n                else {\n                    this.effects.push(new ClipEffect(borderBox, 2 /* BACKGROUND_BORDERS */));\n                    this.effects.push(new ClipEffect(paddingBox, 4 /* CONTENT */));\n                }\n            }\n        }\n        ElementPaint.prototype.getEffects = function (target) {\n            var inFlow = [2 /* ABSOLUTE */, 3 /* FIXED */].indexOf(this.container.styles.position) === -1;\n            var parent = this.parent;\n            var effects = this.effects.slice(0);\n            while (parent) {\n                var croplessEffects = parent.effects.filter(function (effect) { return !isClipEffect(effect); });\n                if (inFlow || parent.container.styles.position !== 0 /* STATIC */ || !parent.parent) {\n                    effects.unshift.apply(effects, croplessEffects);\n                    inFlow = [2 /* ABSOLUTE */, 3 /* FIXED */].indexOf(parent.container.styles.position) === -1;\n                    if (parent.container.styles.overflowX !== 0 /* VISIBLE */) {\n                        var borderBox = calculateBorderBoxPath(parent.curves);\n                        var paddingBox = calculatePaddingBoxPath(parent.curves);\n                        if (!equalPath(borderBox, paddingBox)) {\n                            effects.unshift(new ClipEffect(paddingBox, 2 /* BACKGROUND_BORDERS */ | 4 /* CONTENT */));\n                        }\n                    }\n                }\n                else {\n                    effects.unshift.apply(effects, croplessEffects);\n                }\n                parent = parent.parent;\n            }\n            return effects.filter(function (effect) { return contains(effect.target, target); });\n        };\n        return ElementPaint;\n    }());\n    var parseStackTree = function (parent, stackingContext, realStackingContext, listItems) {\n        parent.container.elements.forEach(function (child) {\n            var treatAsRealStackingContext = contains(child.flags, 4 /* CREATES_REAL_STACKING_CONTEXT */);\n            var createsStackingContext = contains(child.flags, 2 /* CREATES_STACKING_CONTEXT */);\n            var paintContainer = new ElementPaint(child, parent);\n            if (contains(child.styles.display, 2048 /* LIST_ITEM */)) {\n                listItems.push(paintContainer);\n            }\n            var listOwnerItems = contains(child.flags, 8 /* IS_LIST_OWNER */) ? [] : listItems;\n            if (treatAsRealStackingContext || createsStackingContext) {\n                var parentStack = treatAsRealStackingContext || child.styles.isPositioned() ? realStackingContext : stackingContext;\n                var stack = new StackingContext(paintContainer);\n                if (child.styles.isPositioned() || child.styles.opacity < 1 || child.styles.isTransformed()) {\n                    var order_1 = child.styles.zIndex.order;\n                    if (order_1 < 0) {\n                        var index_1 = 0;\n                        parentStack.negativeZIndex.some(function (current, i) {\n                            if (order_1 > current.element.container.styles.zIndex.order) {\n                                index_1 = i;\n                                return false;\n                            }\n                            else if (index_1 > 0) {\n                                return true;\n                            }\n                            return false;\n                        });\n                        parentStack.negativeZIndex.splice(index_1, 0, stack);\n                    }\n                    else if (order_1 > 0) {\n                        var index_2 = 0;\n                        parentStack.positiveZIndex.some(function (current, i) {\n                            if (order_1 >= current.element.container.styles.zIndex.order) {\n                                index_2 = i + 1;\n                                return false;\n                            }\n                            else if (index_2 > 0) {\n                                return true;\n                            }\n                            return false;\n                        });\n                        parentStack.positiveZIndex.splice(index_2, 0, stack);\n                    }\n                    else {\n                        parentStack.zeroOrAutoZIndexOrTransformedOrOpacity.push(stack);\n                    }\n                }\n                else {\n                    if (child.styles.isFloating()) {\n                        parentStack.nonPositionedFloats.push(stack);\n                    }\n                    else {\n                        parentStack.nonPositionedInlineLevel.push(stack);\n                    }\n                }\n                parseStackTree(paintContainer, stack, treatAsRealStackingContext ? stack : realStackingContext, listOwnerItems);\n            }\n            else {\n                if (child.styles.isInlineLevel()) {\n                    stackingContext.inlineLevel.push(paintContainer);\n                }\n                else {\n                    stackingContext.nonInlineLevel.push(paintContainer);\n                }\n                parseStackTree(paintContainer, stackingContext, realStackingContext, listOwnerItems);\n            }\n            if (contains(child.flags, 8 /* IS_LIST_OWNER */)) {\n                processListItems(child, listOwnerItems);\n            }\n        });\n    };\n    var processListItems = function (owner, elements) {\n        var numbering = owner instanceof OLElementContainer ? owner.start : 1;\n        var reversed = owner instanceof OLElementContainer ? owner.reversed : false;\n        for (var i = 0; i < elements.length; i++) {\n            var item = elements[i];\n            if (item.container instanceof LIElementContainer &&\n                typeof item.container.value === 'number' &&\n                item.container.value !== 0) {\n                numbering = item.container.value;\n            }\n            item.listValue = createCounterText(numbering, item.container.styles.listStyleType, true);\n            numbering += reversed ? -1 : 1;\n        }\n    };\n    var parseStackingContexts = function (container) {\n        var paintContainer = new ElementPaint(container, null);\n        var root = new StackingContext(paintContainer);\n        var listItems = [];\n        parseStackTree(paintContainer, root, root, listItems);\n        processListItems(paintContainer.container, listItems);\n        return root;\n    };\n\n    var parsePathForBorder = function (curves, borderSide) {\n        switch (borderSide) {\n            case 0:\n                return createPathFromCurves(curves.topLeftBorderBox, curves.topLeftPaddingBox, curves.topRightBorderBox, curves.topRightPaddingBox);\n            case 1:\n                return createPathFromCurves(curves.topRightBorderBox, curves.topRightPaddingBox, curves.bottomRightBorderBox, curves.bottomRightPaddingBox);\n            case 2:\n                return createPathFromCurves(curves.bottomRightBorderBox, curves.bottomRightPaddingBox, curves.bottomLeftBorderBox, curves.bottomLeftPaddingBox);\n            case 3:\n            default:\n                return createPathFromCurves(curves.bottomLeftBorderBox, curves.bottomLeftPaddingBox, curves.topLeftBorderBox, curves.topLeftPaddingBox);\n        }\n    };\n    var parsePathForBorderDoubleOuter = function (curves, borderSide) {\n        switch (borderSide) {\n            case 0:\n                return createPathFromCurves(curves.topLeftBorderBox, curves.topLeftBorderDoubleOuterBox, curves.topRightBorderBox, curves.topRightBorderDoubleOuterBox);\n            case 1:\n                return createPathFromCurves(curves.topRightBorderBox, curves.topRightBorderDoubleOuterBox, curves.bottomRightBorderBox, curves.bottomRightBorderDoubleOuterBox);\n            case 2:\n                return createPathFromCurves(curves.bottomRightBorderBox, curves.bottomRightBorderDoubleOuterBox, curves.bottomLeftBorderBox, curves.bottomLeftBorderDoubleOuterBox);\n            case 3:\n            default:\n                return createPathFromCurves(curves.bottomLeftBorderBox, curves.bottomLeftBorderDoubleOuterBox, curves.topLeftBorderBox, curves.topLeftBorderDoubleOuterBox);\n        }\n    };\n    var parsePathForBorderDoubleInner = function (curves, borderSide) {\n        switch (borderSide) {\n            case 0:\n                return createPathFromCurves(curves.topLeftBorderDoubleInnerBox, curves.topLeftPaddingBox, curves.topRightBorderDoubleInnerBox, curves.topRightPaddingBox);\n            case 1:\n                return createPathFromCurves(curves.topRightBorderDoubleInnerBox, curves.topRightPaddingBox, curves.bottomRightBorderDoubleInnerBox, curves.bottomRightPaddingBox);\n            case 2:\n                return createPathFromCurves(curves.bottomRightBorderDoubleInnerBox, curves.bottomRightPaddingBox, curves.bottomLeftBorderDoubleInnerBox, curves.bottomLeftPaddingBox);\n            case 3:\n            default:\n                return createPathFromCurves(curves.bottomLeftBorderDoubleInnerBox, curves.bottomLeftPaddingBox, curves.topLeftBorderDoubleInnerBox, curves.topLeftPaddingBox);\n        }\n    };\n    var parsePathForBorderStroke = function (curves, borderSide) {\n        switch (borderSide) {\n            case 0:\n                return createStrokePathFromCurves(curves.topLeftBorderStroke, curves.topRightBorderStroke);\n            case 1:\n                return createStrokePathFromCurves(curves.topRightBorderStroke, curves.bottomRightBorderStroke);\n            case 2:\n                return createStrokePathFromCurves(curves.bottomRightBorderStroke, curves.bottomLeftBorderStroke);\n            case 3:\n            default:\n                return createStrokePathFromCurves(curves.bottomLeftBorderStroke, curves.topLeftBorderStroke);\n        }\n    };\n    var createStrokePathFromCurves = function (outer1, outer2) {\n        var path = [];\n        if (isBezierCurve(outer1)) {\n            path.push(outer1.subdivide(0.5, false));\n        }\n        else {\n            path.push(outer1);\n        }\n        if (isBezierCurve(outer2)) {\n            path.push(outer2.subdivide(0.5, true));\n        }\n        else {\n            path.push(outer2);\n        }\n        return path;\n    };\n    var createPathFromCurves = function (outer1, inner1, outer2, inner2) {\n        var path = [];\n        if (isBezierCurve(outer1)) {\n            path.push(outer1.subdivide(0.5, false));\n        }\n        else {\n            path.push(outer1);\n        }\n        if (isBezierCurve(outer2)) {\n            path.push(outer2.subdivide(0.5, true));\n        }\n        else {\n            path.push(outer2);\n        }\n        if (isBezierCurve(inner2)) {\n            path.push(inner2.subdivide(0.5, true).reverse());\n        }\n        else {\n            path.push(inner2);\n        }\n        if (isBezierCurve(inner1)) {\n            path.push(inner1.subdivide(0.5, false).reverse());\n        }\n        else {\n            path.push(inner1);\n        }\n        return path;\n    };\n\n    var paddingBox = function (element) {\n        var bounds = element.bounds;\n        var styles = element.styles;\n        return bounds.add(styles.borderLeftWidth, styles.borderTopWidth, -(styles.borderRightWidth + styles.borderLeftWidth), -(styles.borderTopWidth + styles.borderBottomWidth));\n    };\n    var contentBox = function (element) {\n        var styles = element.styles;\n        var bounds = element.bounds;\n        var paddingLeft = getAbsoluteValue(styles.paddingLeft, bounds.width);\n        var paddingRight = getAbsoluteValue(styles.paddingRight, bounds.width);\n        var paddingTop = getAbsoluteValue(styles.paddingTop, bounds.width);\n        var paddingBottom = getAbsoluteValue(styles.paddingBottom, bounds.width);\n        return bounds.add(paddingLeft + styles.borderLeftWidth, paddingTop + styles.borderTopWidth, -(styles.borderRightWidth + styles.borderLeftWidth + paddingLeft + paddingRight), -(styles.borderTopWidth + styles.borderBottomWidth + paddingTop + paddingBottom));\n    };\n\n    var calculateBackgroundPositioningArea = function (backgroundOrigin, element) {\n        if (backgroundOrigin === 0 /* BORDER_BOX */) {\n            return element.bounds;\n        }\n        if (backgroundOrigin === 2 /* CONTENT_BOX */) {\n            return contentBox(element);\n        }\n        return paddingBox(element);\n    };\n    var calculateBackgroundPaintingArea = function (backgroundClip, element) {\n        if (backgroundClip === 0 /* BORDER_BOX */) {\n            return element.bounds;\n        }\n        if (backgroundClip === 2 /* CONTENT_BOX */) {\n            return contentBox(element);\n        }\n        return paddingBox(element);\n    };\n    var calculateBackgroundRendering = function (container, index, intrinsicSize) {\n        var backgroundPositioningArea = calculateBackgroundPositioningArea(getBackgroundValueForIndex(container.styles.backgroundOrigin, index), container);\n        var backgroundPaintingArea = calculateBackgroundPaintingArea(getBackgroundValueForIndex(container.styles.backgroundClip, index), container);\n        var backgroundImageSize = calculateBackgroundSize(getBackgroundValueForIndex(container.styles.backgroundSize, index), intrinsicSize, backgroundPositioningArea);\n        var sizeWidth = backgroundImageSize[0], sizeHeight = backgroundImageSize[1];\n        var position = getAbsoluteValueForTuple(getBackgroundValueForIndex(container.styles.backgroundPosition, index), backgroundPositioningArea.width - sizeWidth, backgroundPositioningArea.height - sizeHeight);\n        var path = calculateBackgroundRepeatPath(getBackgroundValueForIndex(container.styles.backgroundRepeat, index), position, backgroundImageSize, backgroundPositioningArea, backgroundPaintingArea);\n        var offsetX = Math.round(backgroundPositioningArea.left + position[0]);\n        var offsetY = Math.round(backgroundPositioningArea.top + position[1]);\n        return [path, offsetX, offsetY, sizeWidth, sizeHeight];\n    };\n    var isAuto = function (token) { return isIdentToken(token) && token.value === BACKGROUND_SIZE.AUTO; };\n    var hasIntrinsicValue = function (value) { return typeof value === 'number'; };\n    var calculateBackgroundSize = function (size, _a, bounds) {\n        var intrinsicWidth = _a[0], intrinsicHeight = _a[1], intrinsicProportion = _a[2];\n        var first = size[0], second = size[1];\n        if (!first) {\n            return [0, 0];\n        }\n        if (isLengthPercentage(first) && second && isLengthPercentage(second)) {\n            return [getAbsoluteValue(first, bounds.width), getAbsoluteValue(second, bounds.height)];\n        }\n        var hasIntrinsicProportion = hasIntrinsicValue(intrinsicProportion);\n        if (isIdentToken(first) && (first.value === BACKGROUND_SIZE.CONTAIN || first.value === BACKGROUND_SIZE.COVER)) {\n            if (hasIntrinsicValue(intrinsicProportion)) {\n                var targetRatio = bounds.width / bounds.height;\n                return targetRatio < intrinsicProportion !== (first.value === BACKGROUND_SIZE.COVER)\n                    ? [bounds.width, bounds.width / intrinsicProportion]\n                    : [bounds.height * intrinsicProportion, bounds.height];\n            }\n            return [bounds.width, bounds.height];\n        }\n        var hasIntrinsicWidth = hasIntrinsicValue(intrinsicWidth);\n        var hasIntrinsicHeight = hasIntrinsicValue(intrinsicHeight);\n        var hasIntrinsicDimensions = hasIntrinsicWidth || hasIntrinsicHeight;\n        // If the background-size is auto or auto auto:\n        if (isAuto(first) && (!second || isAuto(second))) {\n            // If the image has both horizontal and vertical intrinsic dimensions, it's rendered at that size.\n            if (hasIntrinsicWidth && hasIntrinsicHeight) {\n                return [intrinsicWidth, intrinsicHeight];\n            }\n            // If the image has no intrinsic dimensions and has no intrinsic proportions,\n            // it's rendered at the size of the background positioning area.\n            if (!hasIntrinsicProportion && !hasIntrinsicDimensions) {\n                return [bounds.width, bounds.height];\n            }\n            // TODO If the image has no intrinsic dimensions but has intrinsic proportions, it's rendered as if contain had been specified instead.\n            // If the image has only one intrinsic dimension and has intrinsic proportions, it's rendered at the size corresponding to that one dimension.\n            // The other dimension is computed using the specified dimension and the intrinsic proportions.\n            if (hasIntrinsicDimensions && hasIntrinsicProportion) {\n                var width_1 = hasIntrinsicWidth\n                    ? intrinsicWidth\n                    : intrinsicHeight * intrinsicProportion;\n                var height_1 = hasIntrinsicHeight\n                    ? intrinsicHeight\n                    : intrinsicWidth / intrinsicProportion;\n                return [width_1, height_1];\n            }\n            // If the image has only one intrinsic dimension but has no intrinsic proportions,\n            // it's rendered using the specified dimension and the other dimension of the background positioning area.\n            var width_2 = hasIntrinsicWidth ? intrinsicWidth : bounds.width;\n            var height_2 = hasIntrinsicHeight ? intrinsicHeight : bounds.height;\n            return [width_2, height_2];\n        }\n        // If the image has intrinsic proportions, it's stretched to the specified dimension.\n        // The unspecified dimension is computed using the specified dimension and the intrinsic proportions.\n        if (hasIntrinsicProportion) {\n            var width_3 = 0;\n            var height_3 = 0;\n            if (isLengthPercentage(first)) {\n                width_3 = getAbsoluteValue(first, bounds.width);\n            }\n            else if (isLengthPercentage(second)) {\n                height_3 = getAbsoluteValue(second, bounds.height);\n            }\n            if (isAuto(first)) {\n                width_3 = height_3 * intrinsicProportion;\n            }\n            else if (!second || isAuto(second)) {\n                height_3 = width_3 / intrinsicProportion;\n            }\n            return [width_3, height_3];\n        }\n        // If the image has no intrinsic proportions, it's stretched to the specified dimension.\n        // The unspecified dimension is computed using the image's corresponding intrinsic dimension,\n        // if there is one. If there is no such intrinsic dimension,\n        // it becomes the corresponding dimension of the background positioning area.\n        var width = null;\n        var height = null;\n        if (isLengthPercentage(first)) {\n            width = getAbsoluteValue(first, bounds.width);\n        }\n        else if (second && isLengthPercentage(second)) {\n            height = getAbsoluteValue(second, bounds.height);\n        }\n        if (width !== null && (!second || isAuto(second))) {\n            height =\n                hasIntrinsicWidth && hasIntrinsicHeight\n                    ? (width / intrinsicWidth) * intrinsicHeight\n                    : bounds.height;\n        }\n        if (height !== null && isAuto(first)) {\n            width =\n                hasIntrinsicWidth && hasIntrinsicHeight\n                    ? (height / intrinsicHeight) * intrinsicWidth\n                    : bounds.width;\n        }\n        if (width !== null && height !== null) {\n            return [width, height];\n        }\n        throw new Error(\"Unable to calculate background-size for element\");\n    };\n    var getBackgroundValueForIndex = function (values, index) {\n        var value = values[index];\n        if (typeof value === 'undefined') {\n            return values[0];\n        }\n        return value;\n    };\n    var calculateBackgroundRepeatPath = function (repeat, _a, _b, backgroundPositioningArea, backgroundPaintingArea) {\n        var x = _a[0], y = _a[1];\n        var width = _b[0], height = _b[1];\n        switch (repeat) {\n            case 2 /* REPEAT_X */:\n                return [\n                    new Vector(Math.round(backgroundPositioningArea.left), Math.round(backgroundPositioningArea.top + y)),\n                    new Vector(Math.round(backgroundPositioningArea.left + backgroundPositioningArea.width), Math.round(backgroundPositioningArea.top + y)),\n                    new Vector(Math.round(backgroundPositioningArea.left + backgroundPositioningArea.width), Math.round(height + backgroundPositioningArea.top + y)),\n                    new Vector(Math.round(backgroundPositioningArea.left), Math.round(height + backgroundPositioningArea.top + y))\n                ];\n            case 3 /* REPEAT_Y */:\n                return [\n                    new Vector(Math.round(backgroundPositioningArea.left + x), Math.round(backgroundPositioningArea.top)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x + width), Math.round(backgroundPositioningArea.top)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x + width), Math.round(backgroundPositioningArea.height + backgroundPositioningArea.top)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x), Math.round(backgroundPositioningArea.height + backgroundPositioningArea.top))\n                ];\n            case 1 /* NO_REPEAT */:\n                return [\n                    new Vector(Math.round(backgroundPositioningArea.left + x), Math.round(backgroundPositioningArea.top + y)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x + width), Math.round(backgroundPositioningArea.top + y)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x + width), Math.round(backgroundPositioningArea.top + y + height)),\n                    new Vector(Math.round(backgroundPositioningArea.left + x), Math.round(backgroundPositioningArea.top + y + height))\n                ];\n            default:\n                return [\n                    new Vector(Math.round(backgroundPaintingArea.left), Math.round(backgroundPaintingArea.top)),\n                    new Vector(Math.round(backgroundPaintingArea.left + backgroundPaintingArea.width), Math.round(backgroundPaintingArea.top)),\n                    new Vector(Math.round(backgroundPaintingArea.left + backgroundPaintingArea.width), Math.round(backgroundPaintingArea.height + backgroundPaintingArea.top)),\n                    new Vector(Math.round(backgroundPaintingArea.left), Math.round(backgroundPaintingArea.height + backgroundPaintingArea.top))\n                ];\n        }\n    };\n\n    var SMALL_IMAGE = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';\n\n    var SAMPLE_TEXT = 'Hidden Text';\n    var FontMetrics = /** @class */ (function () {\n        function FontMetrics(document) {\n            this._data = {};\n            this._document = document;\n        }\n        FontMetrics.prototype.parseMetrics = function (fontFamily, fontSize) {\n            var container = this._document.createElement('div');\n            var img = this._document.createElement('img');\n            var span = this._document.createElement('span');\n            var body = this._document.body;\n            container.style.visibility = 'hidden';\n            container.style.fontFamily = fontFamily;\n            container.style.fontSize = fontSize;\n            container.style.margin = '0';\n            container.style.padding = '0';\n            container.style.whiteSpace = 'nowrap';\n            body.appendChild(container);\n            img.src = SMALL_IMAGE;\n            img.width = 1;\n            img.height = 1;\n            img.style.margin = '0';\n            img.style.padding = '0';\n            img.style.verticalAlign = 'baseline';\n            span.style.fontFamily = fontFamily;\n            span.style.fontSize = fontSize;\n            span.style.margin = '0';\n            span.style.padding = '0';\n            span.appendChild(this._document.createTextNode(SAMPLE_TEXT));\n            container.appendChild(span);\n            container.appendChild(img);\n            var baseline = img.offsetTop - span.offsetTop + 2;\n            container.removeChild(span);\n            container.appendChild(this._document.createTextNode(SAMPLE_TEXT));\n            container.style.lineHeight = 'normal';\n            img.style.verticalAlign = 'super';\n            var middle = img.offsetTop - container.offsetTop + 2;\n            body.removeChild(container);\n            return { baseline: baseline, middle: middle };\n        };\n        FontMetrics.prototype.getMetrics = function (fontFamily, fontSize) {\n            var key = fontFamily + \" \" + fontSize;\n            if (typeof this._data[key] === 'undefined') {\n                this._data[key] = this.parseMetrics(fontFamily, fontSize);\n            }\n            return this._data[key];\n        };\n        return FontMetrics;\n    }());\n\n    var Renderer = /** @class */ (function () {\n        function Renderer(context, options) {\n            this.context = context;\n            this.options = options;\n        }\n        return Renderer;\n    }());\n\n    var MASK_OFFSET = 10000;\n    var CanvasRenderer = /** @class */ (function (_super) {\n        __extends(CanvasRenderer, _super);\n        function CanvasRenderer(context, options) {\n            var _this = _super.call(this, context, options) || this;\n            _this._activeEffects = [];\n            _this.canvas = options.canvas ? options.canvas : document.createElement('canvas');\n            _this.ctx = _this.canvas.getContext('2d');\n            if (!options.canvas) {\n                _this.canvas.width = Math.floor(options.width * options.scale);\n                _this.canvas.height = Math.floor(options.height * options.scale);\n                _this.canvas.style.width = options.width + \"px\";\n                _this.canvas.style.height = options.height + \"px\";\n            }\n            _this.fontMetrics = new FontMetrics(document);\n            _this.ctx.scale(_this.options.scale, _this.options.scale);\n            _this.ctx.translate(-options.x, -options.y);\n            _this.ctx.textBaseline = 'bottom';\n            _this._activeEffects = [];\n            _this.context.logger.debug(\"Canvas renderer initialized (\" + options.width + \"x\" + options.height + \") with scale \" + options.scale);\n            return _this;\n        }\n        CanvasRenderer.prototype.applyEffects = function (effects) {\n            var _this = this;\n            while (this._activeEffects.length) {\n                this.popEffect();\n            }\n            effects.forEach(function (effect) { return _this.applyEffect(effect); });\n        };\n        CanvasRenderer.prototype.applyEffect = function (effect) {\n            this.ctx.save();\n            if (isOpacityEffect(effect)) {\n                this.ctx.globalAlpha = effect.opacity;\n            }\n            if (isTransformEffect(effect)) {\n                this.ctx.translate(effect.offsetX, effect.offsetY);\n                this.ctx.transform(effect.matrix[0], effect.matrix[1], effect.matrix[2], effect.matrix[3], effect.matrix[4], effect.matrix[5]);\n                this.ctx.translate(-effect.offsetX, -effect.offsetY);\n            }\n            if (isClipEffect(effect)) {\n                this.path(effect.path);\n                this.ctx.clip();\n            }\n            this._activeEffects.push(effect);\n        };\n        CanvasRenderer.prototype.popEffect = function () {\n            this._activeEffects.pop();\n            this.ctx.restore();\n        };\n        CanvasRenderer.prototype.renderStack = function (stack) {\n            return __awaiter(this, void 0, void 0, function () {\n                var styles;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            styles = stack.element.container.styles;\n                            if (!styles.isVisible()) return [3 /*break*/, 2];\n                            return [4 /*yield*/, this.renderStackContent(stack)];\n                        case 1:\n                            _a.sent();\n                            _a.label = 2;\n                        case 2: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderNode = function (paint) {\n            return __awaiter(this, void 0, void 0, function () {\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            if (contains(paint.container.flags, 16 /* DEBUG_RENDER */)) {\n                                debugger;\n                            }\n                            if (!paint.container.styles.isVisible()) return [3 /*break*/, 3];\n                            return [4 /*yield*/, this.renderNodeBackgroundAndBorders(paint)];\n                        case 1:\n                            _a.sent();\n                            return [4 /*yield*/, this.renderNodeContent(paint)];\n                        case 2:\n                            _a.sent();\n                            _a.label = 3;\n                        case 3: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderTextWithLetterSpacing = function (text, letterSpacing, baseline) {\n            var _this = this;\n            if (letterSpacing === 0) {\n                this.ctx.fillText(text.text, text.bounds.left, text.bounds.top + baseline);\n            }\n            else {\n                var letters = segmentGraphemes(text.text);\n                letters.reduce(function (left, letter) {\n                    _this.ctx.fillText(letter, left, text.bounds.top + baseline);\n                    return left + _this.ctx.measureText(letter).width;\n                }, text.bounds.left);\n            }\n        };\n        CanvasRenderer.prototype.createFontStyle = function (styles) {\n            var fontVariant = styles.fontVariant\n                .filter(function (variant) { return variant === 'normal' || variant === 'small-caps'; })\n                .join('');\n            var fontFamily = fixIOSSystemFonts(styles.fontFamily).join(', ');\n            var fontSize = isDimensionToken(styles.fontSize)\n                ? \"\" + styles.fontSize.number + styles.fontSize.unit\n                : styles.fontSize.number + \"px\";\n            return [\n                [styles.fontStyle, fontVariant, styles.fontWeight, fontSize, fontFamily].join(' '),\n                fontFamily,\n                fontSize\n            ];\n        };\n        CanvasRenderer.prototype.renderTextNode = function (text, styles) {\n            return __awaiter(this, void 0, void 0, function () {\n                var _a, font, fontFamily, fontSize, _b, baseline, middle, paintOrder;\n                var _this = this;\n                return __generator(this, function (_c) {\n                    _a = this.createFontStyle(styles), font = _a[0], fontFamily = _a[1], fontSize = _a[2];\n                    this.ctx.font = font;\n                    this.ctx.direction = styles.direction === 1 /* RTL */ ? 'rtl' : 'ltr';\n                    this.ctx.textAlign = 'left';\n                    this.ctx.textBaseline = 'alphabetic';\n                    _b = this.fontMetrics.getMetrics(fontFamily, fontSize), baseline = _b.baseline, middle = _b.middle;\n                    paintOrder = styles.paintOrder;\n                    text.textBounds.forEach(function (text) {\n                        paintOrder.forEach(function (paintOrderLayer) {\n                            switch (paintOrderLayer) {\n                                case 0 /* FILL */:\n                                    _this.ctx.fillStyle = asString(styles.color);\n                                    _this.renderTextWithLetterSpacing(text, styles.letterSpacing, baseline);\n                                    var textShadows = styles.textShadow;\n                                    if (textShadows.length && text.text.trim().length) {\n                                        textShadows\n                                            .slice(0)\n                                            .reverse()\n                                            .forEach(function (textShadow) {\n                                            _this.ctx.shadowColor = asString(textShadow.color);\n                                            _this.ctx.shadowOffsetX = textShadow.offsetX.number * _this.options.scale;\n                                            _this.ctx.shadowOffsetY = textShadow.offsetY.number * _this.options.scale;\n                                            _this.ctx.shadowBlur = textShadow.blur.number;\n                                            _this.renderTextWithLetterSpacing(text, styles.letterSpacing, baseline);\n                                        });\n                                        _this.ctx.shadowColor = '';\n                                        _this.ctx.shadowOffsetX = 0;\n                                        _this.ctx.shadowOffsetY = 0;\n                                        _this.ctx.shadowBlur = 0;\n                                    }\n                                    if (styles.textDecorationLine.length) {\n                                        _this.ctx.fillStyle = asString(styles.textDecorationColor || styles.color);\n                                        styles.textDecorationLine.forEach(function (textDecorationLine) {\n                                            switch (textDecorationLine) {\n                                                case 1 /* UNDERLINE */:\n                                                    // Draws a line at the baseline of the font\n                                                    // TODO As some browsers display the line as more than 1px if the font-size is big,\n                                                    // need to take that into account both in position and size\n                                                    _this.ctx.fillRect(text.bounds.left, Math.round(text.bounds.top + baseline), text.bounds.width, 1);\n                                                    break;\n                                                case 2 /* OVERLINE */:\n                                                    _this.ctx.fillRect(text.bounds.left, Math.round(text.bounds.top), text.bounds.width, 1);\n                                                    break;\n                                                case 3 /* LINE_THROUGH */:\n                                                    // TODO try and find exact position for line-through\n                                                    _this.ctx.fillRect(text.bounds.left, Math.ceil(text.bounds.top + middle), text.bounds.width, 1);\n                                                    break;\n                                            }\n                                        });\n                                    }\n                                    break;\n                                case 1 /* STROKE */:\n                                    if (styles.webkitTextStrokeWidth && text.text.trim().length) {\n                                        _this.ctx.strokeStyle = asString(styles.webkitTextStrokeColor);\n                                        _this.ctx.lineWidth = styles.webkitTextStrokeWidth;\n                                        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n                                        _this.ctx.lineJoin = !!window.chrome ? 'miter' : 'round';\n                                        _this.ctx.strokeText(text.text, text.bounds.left, text.bounds.top + baseline);\n                                    }\n                                    _this.ctx.strokeStyle = '';\n                                    _this.ctx.lineWidth = 0;\n                                    _this.ctx.lineJoin = 'miter';\n                                    break;\n                            }\n                        });\n                    });\n                    return [2 /*return*/];\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderReplacedElement = function (container, curves, image) {\n            if (image && container.intrinsicWidth > 0 && container.intrinsicHeight > 0) {\n                var box = contentBox(container);\n                var path = calculatePaddingBoxPath(curves);\n                this.path(path);\n                this.ctx.save();\n                this.ctx.clip();\n                this.ctx.drawImage(image, 0, 0, container.intrinsicWidth, container.intrinsicHeight, box.left, box.top, box.width, box.height);\n                this.ctx.restore();\n            }\n        };\n        CanvasRenderer.prototype.renderNodeContent = function (paint) {\n            return __awaiter(this, void 0, void 0, function () {\n                var container, curves, styles, _i, _a, child, image, image, iframeRenderer, canvas, size, _b, fontFamily, fontSize, baseline, bounds, x, textBounds, img, image, url, fontFamily, bounds;\n                return __generator(this, function (_c) {\n                    switch (_c.label) {\n                        case 0:\n                            this.applyEffects(paint.getEffects(4 /* CONTENT */));\n                            container = paint.container;\n                            curves = paint.curves;\n                            styles = container.styles;\n                            _i = 0, _a = container.textNodes;\n                            _c.label = 1;\n                        case 1:\n                            if (!(_i < _a.length)) return [3 /*break*/, 4];\n                            child = _a[_i];\n                            return [4 /*yield*/, this.renderTextNode(child, styles)];\n                        case 2:\n                            _c.sent();\n                            _c.label = 3;\n                        case 3:\n                            _i++;\n                            return [3 /*break*/, 1];\n                        case 4:\n                            if (!(container instanceof ImageElementContainer)) return [3 /*break*/, 8];\n                            _c.label = 5;\n                        case 5:\n                            _c.trys.push([5, 7, , 8]);\n                            return [4 /*yield*/, this.context.cache.match(container.src)];\n                        case 6:\n                            image = _c.sent();\n                            this.renderReplacedElement(container, curves, image);\n                            return [3 /*break*/, 8];\n                        case 7:\n                            _c.sent();\n                            this.context.logger.error(\"Error loading image \" + container.src);\n                            return [3 /*break*/, 8];\n                        case 8:\n                            if (container instanceof CanvasElementContainer) {\n                                this.renderReplacedElement(container, curves, container.canvas);\n                            }\n                            if (!(container instanceof SVGElementContainer)) return [3 /*break*/, 12];\n                            _c.label = 9;\n                        case 9:\n                            _c.trys.push([9, 11, , 12]);\n                            return [4 /*yield*/, this.context.cache.match(container.svg)];\n                        case 10:\n                            image = _c.sent();\n                            this.renderReplacedElement(container, curves, image);\n                            return [3 /*break*/, 12];\n                        case 11:\n                            _c.sent();\n                            this.context.logger.error(\"Error loading svg \" + container.svg.substring(0, 255));\n                            return [3 /*break*/, 12];\n                        case 12:\n                            if (!(container instanceof IFrameElementContainer && container.tree)) return [3 /*break*/, 14];\n                            iframeRenderer = new CanvasRenderer(this.context, {\n                                scale: this.options.scale,\n                                backgroundColor: container.backgroundColor,\n                                x: 0,\n                                y: 0,\n                                width: container.width,\n                                height: container.height\n                            });\n                            return [4 /*yield*/, iframeRenderer.render(container.tree)];\n                        case 13:\n                            canvas = _c.sent();\n                            if (container.width && container.height) {\n                                this.ctx.drawImage(canvas, 0, 0, container.width, container.height, container.bounds.left, container.bounds.top, container.bounds.width, container.bounds.height);\n                            }\n                            _c.label = 14;\n                        case 14:\n                            if (container instanceof InputElementContainer) {\n                                size = Math.min(container.bounds.width, container.bounds.height);\n                                if (container.type === CHECKBOX) {\n                                    if (container.checked) {\n                                        this.ctx.save();\n                                        this.path([\n                                            new Vector(container.bounds.left + size * 0.39363, container.bounds.top + size * 0.79),\n                                            new Vector(container.bounds.left + size * 0.16, container.bounds.top + size * 0.5549),\n                                            new Vector(container.bounds.left + size * 0.27347, container.bounds.top + size * 0.44071),\n                                            new Vector(container.bounds.left + size * 0.39694, container.bounds.top + size * 0.5649),\n                                            new Vector(container.bounds.left + size * 0.72983, container.bounds.top + size * 0.23),\n                                            new Vector(container.bounds.left + size * 0.84, container.bounds.top + size * 0.34085),\n                                            new Vector(container.bounds.left + size * 0.39363, container.bounds.top + size * 0.79)\n                                        ]);\n                                        this.ctx.fillStyle = asString(INPUT_COLOR);\n                                        this.ctx.fill();\n                                        this.ctx.restore();\n                                    }\n                                }\n                                else if (container.type === RADIO) {\n                                    if (container.checked) {\n                                        this.ctx.save();\n                                        this.ctx.beginPath();\n                                        this.ctx.arc(container.bounds.left + size / 2, container.bounds.top + size / 2, size / 4, 0, Math.PI * 2, true);\n                                        this.ctx.fillStyle = asString(INPUT_COLOR);\n                                        this.ctx.fill();\n                                        this.ctx.restore();\n                                    }\n                                }\n                            }\n                            if (isTextInputElement(container) && container.value.length) {\n                                _b = this.createFontStyle(styles), fontFamily = _b[0], fontSize = _b[1];\n                                baseline = this.fontMetrics.getMetrics(fontFamily, fontSize).baseline;\n                                this.ctx.font = fontFamily;\n                                this.ctx.fillStyle = asString(styles.color);\n                                this.ctx.textBaseline = 'alphabetic';\n                                this.ctx.textAlign = canvasTextAlign(container.styles.textAlign);\n                                bounds = contentBox(container);\n                                x = 0;\n                                switch (container.styles.textAlign) {\n                                    case 1 /* CENTER */:\n                                        x += bounds.width / 2;\n                                        break;\n                                    case 2 /* RIGHT */:\n                                        x += bounds.width;\n                                        break;\n                                }\n                                textBounds = bounds.add(x, 0, 0, -bounds.height / 2 + 1);\n                                this.ctx.save();\n                                this.path([\n                                    new Vector(bounds.left, bounds.top),\n                                    new Vector(bounds.left + bounds.width, bounds.top),\n                                    new Vector(bounds.left + bounds.width, bounds.top + bounds.height),\n                                    new Vector(bounds.left, bounds.top + bounds.height)\n                                ]);\n                                this.ctx.clip();\n                                this.renderTextWithLetterSpacing(new TextBounds(container.value, textBounds), styles.letterSpacing, baseline);\n                                this.ctx.restore();\n                                this.ctx.textBaseline = 'alphabetic';\n                                this.ctx.textAlign = 'left';\n                            }\n                            if (!contains(container.styles.display, 2048 /* LIST_ITEM */)) return [3 /*break*/, 20];\n                            if (!(container.styles.listStyleImage !== null)) return [3 /*break*/, 19];\n                            img = container.styles.listStyleImage;\n                            if (!(img.type === 0 /* URL */)) return [3 /*break*/, 18];\n                            image = void 0;\n                            url = img.url;\n                            _c.label = 15;\n                        case 15:\n                            _c.trys.push([15, 17, , 18]);\n                            return [4 /*yield*/, this.context.cache.match(url)];\n                        case 16:\n                            image = _c.sent();\n                            this.ctx.drawImage(image, container.bounds.left - (image.width + 10), container.bounds.top);\n                            return [3 /*break*/, 18];\n                        case 17:\n                            _c.sent();\n                            this.context.logger.error(\"Error loading list-style-image \" + url);\n                            return [3 /*break*/, 18];\n                        case 18: return [3 /*break*/, 20];\n                        case 19:\n                            if (paint.listValue && container.styles.listStyleType !== -1 /* NONE */) {\n                                fontFamily = this.createFontStyle(styles)[0];\n                                this.ctx.font = fontFamily;\n                                this.ctx.fillStyle = asString(styles.color);\n                                this.ctx.textBaseline = 'middle';\n                                this.ctx.textAlign = 'right';\n                                bounds = new Bounds(container.bounds.left, container.bounds.top + getAbsoluteValue(container.styles.paddingTop, container.bounds.width), container.bounds.width, computeLineHeight(styles.lineHeight, styles.fontSize.number) / 2 + 1);\n                                this.renderTextWithLetterSpacing(new TextBounds(paint.listValue, bounds), styles.letterSpacing, computeLineHeight(styles.lineHeight, styles.fontSize.number) / 2 + 2);\n                                this.ctx.textBaseline = 'bottom';\n                                this.ctx.textAlign = 'left';\n                            }\n                            _c.label = 20;\n                        case 20: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderStackContent = function (stack) {\n            return __awaiter(this, void 0, void 0, function () {\n                var _i, _a, child, _b, _c, child, _d, _e, child, _f, _g, child, _h, _j, child, _k, _l, child, _m, _o, child;\n                return __generator(this, function (_p) {\n                    switch (_p.label) {\n                        case 0:\n                            if (contains(stack.element.container.flags, 16 /* DEBUG_RENDER */)) {\n                                debugger;\n                            }\n                            // https://www.w3.org/TR/css-position-3/#painting-order\n                            // 1. the background and borders of the element forming the stacking context.\n                            return [4 /*yield*/, this.renderNodeBackgroundAndBorders(stack.element)];\n                        case 1:\n                            // https://www.w3.org/TR/css-position-3/#painting-order\n                            // 1. the background and borders of the element forming the stacking context.\n                            _p.sent();\n                            _i = 0, _a = stack.negativeZIndex;\n                            _p.label = 2;\n                        case 2:\n                            if (!(_i < _a.length)) return [3 /*break*/, 5];\n                            child = _a[_i];\n                            return [4 /*yield*/, this.renderStack(child)];\n                        case 3:\n                            _p.sent();\n                            _p.label = 4;\n                        case 4:\n                            _i++;\n                            return [3 /*break*/, 2];\n                        case 5: \n                        // 3. For all its in-flow, non-positioned, block-level descendants in tree order:\n                        return [4 /*yield*/, this.renderNodeContent(stack.element)];\n                        case 6:\n                            // 3. For all its in-flow, non-positioned, block-level descendants in tree order:\n                            _p.sent();\n                            _b = 0, _c = stack.nonInlineLevel;\n                            _p.label = 7;\n                        case 7:\n                            if (!(_b < _c.length)) return [3 /*break*/, 10];\n                            child = _c[_b];\n                            return [4 /*yield*/, this.renderNode(child)];\n                        case 8:\n                            _p.sent();\n                            _p.label = 9;\n                        case 9:\n                            _b++;\n                            return [3 /*break*/, 7];\n                        case 10:\n                            _d = 0, _e = stack.nonPositionedFloats;\n                            _p.label = 11;\n                        case 11:\n                            if (!(_d < _e.length)) return [3 /*break*/, 14];\n                            child = _e[_d];\n                            return [4 /*yield*/, this.renderStack(child)];\n                        case 12:\n                            _p.sent();\n                            _p.label = 13;\n                        case 13:\n                            _d++;\n                            return [3 /*break*/, 11];\n                        case 14:\n                            _f = 0, _g = stack.nonPositionedInlineLevel;\n                            _p.label = 15;\n                        case 15:\n                            if (!(_f < _g.length)) return [3 /*break*/, 18];\n                            child = _g[_f];\n                            return [4 /*yield*/, this.renderStack(child)];\n                        case 16:\n                            _p.sent();\n                            _p.label = 17;\n                        case 17:\n                            _f++;\n                            return [3 /*break*/, 15];\n                        case 18:\n                            _h = 0, _j = stack.inlineLevel;\n                            _p.label = 19;\n                        case 19:\n                            if (!(_h < _j.length)) return [3 /*break*/, 22];\n                            child = _j[_h];\n                            return [4 /*yield*/, this.renderNode(child)];\n                        case 20:\n                            _p.sent();\n                            _p.label = 21;\n                        case 21:\n                            _h++;\n                            return [3 /*break*/, 19];\n                        case 22:\n                            _k = 0, _l = stack.zeroOrAutoZIndexOrTransformedOrOpacity;\n                            _p.label = 23;\n                        case 23:\n                            if (!(_k < _l.length)) return [3 /*break*/, 26];\n                            child = _l[_k];\n                            return [4 /*yield*/, this.renderStack(child)];\n                        case 24:\n                            _p.sent();\n                            _p.label = 25;\n                        case 25:\n                            _k++;\n                            return [3 /*break*/, 23];\n                        case 26:\n                            _m = 0, _o = stack.positiveZIndex;\n                            _p.label = 27;\n                        case 27:\n                            if (!(_m < _o.length)) return [3 /*break*/, 30];\n                            child = _o[_m];\n                            return [4 /*yield*/, this.renderStack(child)];\n                        case 28:\n                            _p.sent();\n                            _p.label = 29;\n                        case 29:\n                            _m++;\n                            return [3 /*break*/, 27];\n                        case 30: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.mask = function (paths) {\n            this.ctx.beginPath();\n            this.ctx.moveTo(0, 0);\n            this.ctx.lineTo(this.canvas.width, 0);\n            this.ctx.lineTo(this.canvas.width, this.canvas.height);\n            this.ctx.lineTo(0, this.canvas.height);\n            this.ctx.lineTo(0, 0);\n            this.formatPath(paths.slice(0).reverse());\n            this.ctx.closePath();\n        };\n        CanvasRenderer.prototype.path = function (paths) {\n            this.ctx.beginPath();\n            this.formatPath(paths);\n            this.ctx.closePath();\n        };\n        CanvasRenderer.prototype.formatPath = function (paths) {\n            var _this = this;\n            paths.forEach(function (point, index) {\n                var start = isBezierCurve(point) ? point.start : point;\n                if (index === 0) {\n                    _this.ctx.moveTo(start.x, start.y);\n                }\n                else {\n                    _this.ctx.lineTo(start.x, start.y);\n                }\n                if (isBezierCurve(point)) {\n                    _this.ctx.bezierCurveTo(point.startControl.x, point.startControl.y, point.endControl.x, point.endControl.y, point.end.x, point.end.y);\n                }\n            });\n        };\n        CanvasRenderer.prototype.renderRepeat = function (path, pattern, offsetX, offsetY) {\n            this.path(path);\n            this.ctx.fillStyle = pattern;\n            this.ctx.translate(offsetX, offsetY);\n            this.ctx.fill();\n            this.ctx.translate(-offsetX, -offsetY);\n        };\n        CanvasRenderer.prototype.resizeImage = function (image, width, height) {\n            var _a;\n            if (image.width === width && image.height === height) {\n                return image;\n            }\n            var ownerDocument = (_a = this.canvas.ownerDocument) !== null && _a !== void 0 ? _a : document;\n            var canvas = ownerDocument.createElement('canvas');\n            canvas.width = Math.max(1, width);\n            canvas.height = Math.max(1, height);\n            var ctx = canvas.getContext('2d');\n            ctx.drawImage(image, 0, 0, image.width, image.height, 0, 0, width, height);\n            return canvas;\n        };\n        CanvasRenderer.prototype.renderBackgroundImage = function (container) {\n            return __awaiter(this, void 0, void 0, function () {\n                var index, _loop_1, this_1, _i, _a, backgroundImage;\n                return __generator(this, function (_b) {\n                    switch (_b.label) {\n                        case 0:\n                            index = container.styles.backgroundImage.length - 1;\n                            _loop_1 = function (backgroundImage) {\n                                var image, url, _c, path, x, y, width, height, pattern, _d, path, x, y, width, height, _e, lineLength, x0, x1, y0, y1, canvas, ctx, gradient_1, pattern, _f, path, left, top_1, width, height, position, x, y, _g, rx, ry, radialGradient_1, midX, midY, f, invF;\n                                return __generator(this, function (_h) {\n                                    switch (_h.label) {\n                                        case 0:\n                                            if (!(backgroundImage.type === 0 /* URL */)) return [3 /*break*/, 5];\n                                            image = void 0;\n                                            url = backgroundImage.url;\n                                            _h.label = 1;\n                                        case 1:\n                                            _h.trys.push([1, 3, , 4]);\n                                            return [4 /*yield*/, this_1.context.cache.match(url)];\n                                        case 2:\n                                            image = _h.sent();\n                                            return [3 /*break*/, 4];\n                                        case 3:\n                                            _h.sent();\n                                            this_1.context.logger.error(\"Error loading background-image \" + url);\n                                            return [3 /*break*/, 4];\n                                        case 4:\n                                            if (image) {\n                                                _c = calculateBackgroundRendering(container, index, [\n                                                    image.width,\n                                                    image.height,\n                                                    image.width / image.height\n                                                ]), path = _c[0], x = _c[1], y = _c[2], width = _c[3], height = _c[4];\n                                                pattern = this_1.ctx.createPattern(this_1.resizeImage(image, width, height), 'repeat');\n                                                this_1.renderRepeat(path, pattern, x, y);\n                                            }\n                                            return [3 /*break*/, 6];\n                                        case 5:\n                                            if (isLinearGradient(backgroundImage)) {\n                                                _d = calculateBackgroundRendering(container, index, [null, null, null]), path = _d[0], x = _d[1], y = _d[2], width = _d[3], height = _d[4];\n                                                _e = calculateGradientDirection(backgroundImage.angle, width, height), lineLength = _e[0], x0 = _e[1], x1 = _e[2], y0 = _e[3], y1 = _e[4];\n                                                canvas = document.createElement('canvas');\n                                                canvas.width = width;\n                                                canvas.height = height;\n                                                ctx = canvas.getContext('2d');\n                                                gradient_1 = ctx.createLinearGradient(x0, y0, x1, y1);\n                                                processColorStops(backgroundImage.stops, lineLength).forEach(function (colorStop) {\n                                                    return gradient_1.addColorStop(colorStop.stop, asString(colorStop.color));\n                                                });\n                                                ctx.fillStyle = gradient_1;\n                                                ctx.fillRect(0, 0, width, height);\n                                                if (width > 0 && height > 0) {\n                                                    pattern = this_1.ctx.createPattern(canvas, 'repeat');\n                                                    this_1.renderRepeat(path, pattern, x, y);\n                                                }\n                                            }\n                                            else if (isRadialGradient(backgroundImage)) {\n                                                _f = calculateBackgroundRendering(container, index, [\n                                                    null,\n                                                    null,\n                                                    null\n                                                ]), path = _f[0], left = _f[1], top_1 = _f[2], width = _f[3], height = _f[4];\n                                                position = backgroundImage.position.length === 0 ? [FIFTY_PERCENT] : backgroundImage.position;\n                                                x = getAbsoluteValue(position[0], width);\n                                                y = getAbsoluteValue(position[position.length - 1], height);\n                                                _g = calculateRadius(backgroundImage, x, y, width, height), rx = _g[0], ry = _g[1];\n                                                if (rx > 0 && ry > 0) {\n                                                    radialGradient_1 = this_1.ctx.createRadialGradient(left + x, top_1 + y, 0, left + x, top_1 + y, rx);\n                                                    processColorStops(backgroundImage.stops, rx * 2).forEach(function (colorStop) {\n                                                        return radialGradient_1.addColorStop(colorStop.stop, asString(colorStop.color));\n                                                    });\n                                                    this_1.path(path);\n                                                    this_1.ctx.fillStyle = radialGradient_1;\n                                                    if (rx !== ry) {\n                                                        midX = container.bounds.left + 0.5 * container.bounds.width;\n                                                        midY = container.bounds.top + 0.5 * container.bounds.height;\n                                                        f = ry / rx;\n                                                        invF = 1 / f;\n                                                        this_1.ctx.save();\n                                                        this_1.ctx.translate(midX, midY);\n                                                        this_1.ctx.transform(1, 0, 0, f, 0, 0);\n                                                        this_1.ctx.translate(-midX, -midY);\n                                                        this_1.ctx.fillRect(left, invF * (top_1 - midY) + midY, width, height * invF);\n                                                        this_1.ctx.restore();\n                                                    }\n                                                    else {\n                                                        this_1.ctx.fill();\n                                                    }\n                                                }\n                                            }\n                                            _h.label = 6;\n                                        case 6:\n                                            index--;\n                                            return [2 /*return*/];\n                                    }\n                                });\n                            };\n                            this_1 = this;\n                            _i = 0, _a = container.styles.backgroundImage.slice(0).reverse();\n                            _b.label = 1;\n                        case 1:\n                            if (!(_i < _a.length)) return [3 /*break*/, 4];\n                            backgroundImage = _a[_i];\n                            return [5 /*yield**/, _loop_1(backgroundImage)];\n                        case 2:\n                            _b.sent();\n                            _b.label = 3;\n                        case 3:\n                            _i++;\n                            return [3 /*break*/, 1];\n                        case 4: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderSolidBorder = function (color, side, curvePoints) {\n            return __awaiter(this, void 0, void 0, function () {\n                return __generator(this, function (_a) {\n                    this.path(parsePathForBorder(curvePoints, side));\n                    this.ctx.fillStyle = asString(color);\n                    this.ctx.fill();\n                    return [2 /*return*/];\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderDoubleBorder = function (color, width, side, curvePoints) {\n            return __awaiter(this, void 0, void 0, function () {\n                var outerPaths, innerPaths;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            if (!(width < 3)) return [3 /*break*/, 2];\n                            return [4 /*yield*/, this.renderSolidBorder(color, side, curvePoints)];\n                        case 1:\n                            _a.sent();\n                            return [2 /*return*/];\n                        case 2:\n                            outerPaths = parsePathForBorderDoubleOuter(curvePoints, side);\n                            this.path(outerPaths);\n                            this.ctx.fillStyle = asString(color);\n                            this.ctx.fill();\n                            innerPaths = parsePathForBorderDoubleInner(curvePoints, side);\n                            this.path(innerPaths);\n                            this.ctx.fill();\n                            return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderNodeBackgroundAndBorders = function (paint) {\n            return __awaiter(this, void 0, void 0, function () {\n                var styles, hasBackground, borders, backgroundPaintingArea, side, _i, borders_1, border;\n                var _this = this;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            this.applyEffects(paint.getEffects(2 /* BACKGROUND_BORDERS */));\n                            styles = paint.container.styles;\n                            hasBackground = !isTransparent(styles.backgroundColor) || styles.backgroundImage.length;\n                            borders = [\n                                { style: styles.borderTopStyle, color: styles.borderTopColor, width: styles.borderTopWidth },\n                                { style: styles.borderRightStyle, color: styles.borderRightColor, width: styles.borderRightWidth },\n                                { style: styles.borderBottomStyle, color: styles.borderBottomColor, width: styles.borderBottomWidth },\n                                { style: styles.borderLeftStyle, color: styles.borderLeftColor, width: styles.borderLeftWidth }\n                            ];\n                            backgroundPaintingArea = calculateBackgroundCurvedPaintingArea(getBackgroundValueForIndex(styles.backgroundClip, 0), paint.curves);\n                            if (!(hasBackground || styles.boxShadow.length)) return [3 /*break*/, 2];\n                            this.ctx.save();\n                            this.path(backgroundPaintingArea);\n                            this.ctx.clip();\n                            if (!isTransparent(styles.backgroundColor)) {\n                                this.ctx.fillStyle = asString(styles.backgroundColor);\n                                this.ctx.fill();\n                            }\n                            return [4 /*yield*/, this.renderBackgroundImage(paint.container)];\n                        case 1:\n                            _a.sent();\n                            this.ctx.restore();\n                            styles.boxShadow\n                                .slice(0)\n                                .reverse()\n                                .forEach(function (shadow) {\n                                _this.ctx.save();\n                                var borderBoxArea = calculateBorderBoxPath(paint.curves);\n                                var maskOffset = shadow.inset ? 0 : MASK_OFFSET;\n                                var shadowPaintingArea = transformPath(borderBoxArea, -maskOffset + (shadow.inset ? 1 : -1) * shadow.spread.number, (shadow.inset ? 1 : -1) * shadow.spread.number, shadow.spread.number * (shadow.inset ? -2 : 2), shadow.spread.number * (shadow.inset ? -2 : 2));\n                                if (shadow.inset) {\n                                    _this.path(borderBoxArea);\n                                    _this.ctx.clip();\n                                    _this.mask(shadowPaintingArea);\n                                }\n                                else {\n                                    _this.mask(borderBoxArea);\n                                    _this.ctx.clip();\n                                    _this.path(shadowPaintingArea);\n                                }\n                                _this.ctx.shadowOffsetX = shadow.offsetX.number + maskOffset;\n                                _this.ctx.shadowOffsetY = shadow.offsetY.number;\n                                _this.ctx.shadowColor = asString(shadow.color);\n                                _this.ctx.shadowBlur = shadow.blur.number;\n                                _this.ctx.fillStyle = shadow.inset ? asString(shadow.color) : 'rgba(0,0,0,1)';\n                                _this.ctx.fill();\n                                _this.ctx.restore();\n                            });\n                            _a.label = 2;\n                        case 2:\n                            side = 0;\n                            _i = 0, borders_1 = borders;\n                            _a.label = 3;\n                        case 3:\n                            if (!(_i < borders_1.length)) return [3 /*break*/, 13];\n                            border = borders_1[_i];\n                            if (!(border.style !== 0 /* NONE */ && !isTransparent(border.color) && border.width > 0)) return [3 /*break*/, 11];\n                            if (!(border.style === 2 /* DASHED */)) return [3 /*break*/, 5];\n                            return [4 /*yield*/, this.renderDashedDottedBorder(border.color, border.width, side, paint.curves, 2 /* DASHED */)];\n                        case 4:\n                            _a.sent();\n                            return [3 /*break*/, 11];\n                        case 5:\n                            if (!(border.style === 3 /* DOTTED */)) return [3 /*break*/, 7];\n                            return [4 /*yield*/, this.renderDashedDottedBorder(border.color, border.width, side, paint.curves, 3 /* DOTTED */)];\n                        case 6:\n                            _a.sent();\n                            return [3 /*break*/, 11];\n                        case 7:\n                            if (!(border.style === 4 /* DOUBLE */)) return [3 /*break*/, 9];\n                            return [4 /*yield*/, this.renderDoubleBorder(border.color, border.width, side, paint.curves)];\n                        case 8:\n                            _a.sent();\n                            return [3 /*break*/, 11];\n                        case 9: return [4 /*yield*/, this.renderSolidBorder(border.color, side, paint.curves)];\n                        case 10:\n                            _a.sent();\n                            _a.label = 11;\n                        case 11:\n                            side++;\n                            _a.label = 12;\n                        case 12:\n                            _i++;\n                            return [3 /*break*/, 3];\n                        case 13: return [2 /*return*/];\n                    }\n                });\n            });\n        };\n        CanvasRenderer.prototype.renderDashedDottedBorder = function (color, width, side, curvePoints, style) {\n            return __awaiter(this, void 0, void 0, function () {\n                var strokePaths, boxPaths, startX, startY, endX, endY, length, dashLength, spaceLength, useLineDash, multiplier, numberOfDashes, minSpace, maxSpace, path1, path2, path1, path2;\n                return __generator(this, function (_a) {\n                    this.ctx.save();\n                    strokePaths = parsePathForBorderStroke(curvePoints, side);\n                    boxPaths = parsePathForBorder(curvePoints, side);\n                    if (style === 2 /* DASHED */) {\n                        this.path(boxPaths);\n                        this.ctx.clip();\n                    }\n                    if (isBezierCurve(boxPaths[0])) {\n                        startX = boxPaths[0].start.x;\n                        startY = boxPaths[0].start.y;\n                    }\n                    else {\n                        startX = boxPaths[0].x;\n                        startY = boxPaths[0].y;\n                    }\n                    if (isBezierCurve(boxPaths[1])) {\n                        endX = boxPaths[1].end.x;\n                        endY = boxPaths[1].end.y;\n                    }\n                    else {\n                        endX = boxPaths[1].x;\n                        endY = boxPaths[1].y;\n                    }\n                    if (side === 0 || side === 2) {\n                        length = Math.abs(startX - endX);\n                    }\n                    else {\n                        length = Math.abs(startY - endY);\n                    }\n                    this.ctx.beginPath();\n                    if (style === 3 /* DOTTED */) {\n                        this.formatPath(strokePaths);\n                    }\n                    else {\n                        this.formatPath(boxPaths.slice(0, 2));\n                    }\n                    dashLength = width < 3 ? width * 3 : width * 2;\n                    spaceLength = width < 3 ? width * 2 : width;\n                    if (style === 3 /* DOTTED */) {\n                        dashLength = width;\n                        spaceLength = width;\n                    }\n                    useLineDash = true;\n                    if (length <= dashLength * 2) {\n                        useLineDash = false;\n                    }\n                    else if (length <= dashLength * 2 + spaceLength) {\n                        multiplier = length / (2 * dashLength + spaceLength);\n                        dashLength *= multiplier;\n                        spaceLength *= multiplier;\n                    }\n                    else {\n                        numberOfDashes = Math.floor((length + spaceLength) / (dashLength + spaceLength));\n                        minSpace = (length - numberOfDashes * dashLength) / (numberOfDashes - 1);\n                        maxSpace = (length - (numberOfDashes + 1) * dashLength) / numberOfDashes;\n                        spaceLength =\n                            maxSpace <= 0 || Math.abs(spaceLength - minSpace) < Math.abs(spaceLength - maxSpace)\n                                ? minSpace\n                                : maxSpace;\n                    }\n                    if (useLineDash) {\n                        if (style === 3 /* DOTTED */) {\n                            this.ctx.setLineDash([0, dashLength + spaceLength]);\n                        }\n                        else {\n                            this.ctx.setLineDash([dashLength, spaceLength]);\n                        }\n                    }\n                    if (style === 3 /* DOTTED */) {\n                        this.ctx.lineCap = 'round';\n                        this.ctx.lineWidth = width;\n                    }\n                    else {\n                        this.ctx.lineWidth = width * 2 + 1.1;\n                    }\n                    this.ctx.strokeStyle = asString(color);\n                    this.ctx.stroke();\n                    this.ctx.setLineDash([]);\n                    // dashed round edge gap\n                    if (style === 2 /* DASHED */) {\n                        if (isBezierCurve(boxPaths[0])) {\n                            path1 = boxPaths[3];\n                            path2 = boxPaths[0];\n                            this.ctx.beginPath();\n                            this.formatPath([new Vector(path1.end.x, path1.end.y), new Vector(path2.start.x, path2.start.y)]);\n                            this.ctx.stroke();\n                        }\n                        if (isBezierCurve(boxPaths[1])) {\n                            path1 = boxPaths[1];\n                            path2 = boxPaths[2];\n                            this.ctx.beginPath();\n                            this.formatPath([new Vector(path1.end.x, path1.end.y), new Vector(path2.start.x, path2.start.y)]);\n                            this.ctx.stroke();\n                        }\n                    }\n                    this.ctx.restore();\n                    return [2 /*return*/];\n                });\n            });\n        };\n        CanvasRenderer.prototype.render = function (element) {\n            return __awaiter(this, void 0, void 0, function () {\n                var stack;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            if (this.options.backgroundColor) {\n                                this.ctx.fillStyle = asString(this.options.backgroundColor);\n                                this.ctx.fillRect(this.options.x, this.options.y, this.options.width, this.options.height);\n                            }\n                            stack = parseStackingContexts(element);\n                            return [4 /*yield*/, this.renderStack(stack)];\n                        case 1:\n                            _a.sent();\n                            this.applyEffects([]);\n                            return [2 /*return*/, this.canvas];\n                    }\n                });\n            });\n        };\n        return CanvasRenderer;\n    }(Renderer));\n    var isTextInputElement = function (container) {\n        if (container instanceof TextareaElementContainer) {\n            return true;\n        }\n        else if (container instanceof SelectElementContainer) {\n            return true;\n        }\n        else if (container instanceof InputElementContainer && container.type !== RADIO && container.type !== CHECKBOX) {\n            return true;\n        }\n        return false;\n    };\n    var calculateBackgroundCurvedPaintingArea = function (clip, curves) {\n        switch (clip) {\n            case 0 /* BORDER_BOX */:\n                return calculateBorderBoxPath(curves);\n            case 2 /* CONTENT_BOX */:\n                return calculateContentBoxPath(curves);\n            case 1 /* PADDING_BOX */:\n            default:\n                return calculatePaddingBoxPath(curves);\n        }\n    };\n    var canvasTextAlign = function (textAlign) {\n        switch (textAlign) {\n            case 1 /* CENTER */:\n                return 'center';\n            case 2 /* RIGHT */:\n                return 'right';\n            case 0 /* LEFT */:\n            default:\n                return 'left';\n        }\n    };\n    // see https://github.com/niklasvh/html2canvas/pull/2645\n    var iOSBrokenFonts = ['-apple-system', 'system-ui'];\n    var fixIOSSystemFonts = function (fontFamilies) {\n        return /iPhone OS 15_(0|1)/.test(window.navigator.userAgent)\n            ? fontFamilies.filter(function (fontFamily) { return iOSBrokenFonts.indexOf(fontFamily) === -1; })\n            : fontFamilies;\n    };\n\n    var ForeignObjectRenderer = /** @class */ (function (_super) {\n        __extends(ForeignObjectRenderer, _super);\n        function ForeignObjectRenderer(context, options) {\n            var _this = _super.call(this, context, options) || this;\n            _this.canvas = options.canvas ? options.canvas : document.createElement('canvas');\n            _this.ctx = _this.canvas.getContext('2d');\n            _this.options = options;\n            _this.canvas.width = Math.floor(options.width * options.scale);\n            _this.canvas.height = Math.floor(options.height * options.scale);\n            _this.canvas.style.width = options.width + \"px\";\n            _this.canvas.style.height = options.height + \"px\";\n            _this.ctx.scale(_this.options.scale, _this.options.scale);\n            _this.ctx.translate(-options.x, -options.y);\n            _this.context.logger.debug(\"EXPERIMENTAL ForeignObject renderer initialized (\" + options.width + \"x\" + options.height + \" at \" + options.x + \",\" + options.y + \") with scale \" + options.scale);\n            return _this;\n        }\n        ForeignObjectRenderer.prototype.render = function (element) {\n            return __awaiter(this, void 0, void 0, function () {\n                var svg, img;\n                return __generator(this, function (_a) {\n                    switch (_a.label) {\n                        case 0:\n                            svg = createForeignObjectSVG(this.options.width * this.options.scale, this.options.height * this.options.scale, this.options.scale, this.options.scale, element);\n                            return [4 /*yield*/, loadSerializedSVG(svg)];\n                        case 1:\n                            img = _a.sent();\n                            if (this.options.backgroundColor) {\n                                this.ctx.fillStyle = asString(this.options.backgroundColor);\n                                this.ctx.fillRect(0, 0, this.options.width * this.options.scale, this.options.height * this.options.scale);\n                            }\n                            this.ctx.drawImage(img, -this.options.x * this.options.scale, -this.options.y * this.options.scale);\n                            return [2 /*return*/, this.canvas];\n                    }\n                });\n            });\n        };\n        return ForeignObjectRenderer;\n    }(Renderer));\n    var loadSerializedSVG = function (svg) {\n        return new Promise(function (resolve, reject) {\n            var img = new Image();\n            img.onload = function () {\n                resolve(img);\n            };\n            img.onerror = reject;\n            img.src = \"data:image/svg+xml;charset=utf-8,\" + encodeURIComponent(new XMLSerializer().serializeToString(svg));\n        });\n    };\n\n    var Logger = /** @class */ (function () {\n        function Logger(_a) {\n            var id = _a.id, enabled = _a.enabled;\n            this.id = id;\n            this.enabled = enabled;\n            this.start = Date.now();\n        }\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        Logger.prototype.debug = function () {\n            var args = [];\n            for (var _i = 0; _i < arguments.length; _i++) {\n                args[_i] = arguments[_i];\n            }\n            if (this.enabled) {\n                // eslint-disable-next-line no-console\n                if (typeof window !== 'undefined' && window.console && typeof console.debug === 'function') {\n                    // eslint-disable-next-line no-console\n                    console.debug.apply(console, __spreadArray([this.id, this.getTime() + \"ms\"], args));\n                }\n                else {\n                    this.info.apply(this, args);\n                }\n            }\n        };\n        Logger.prototype.getTime = function () {\n            return Date.now() - this.start;\n        };\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        Logger.prototype.info = function () {\n            var args = [];\n            for (var _i = 0; _i < arguments.length; _i++) {\n                args[_i] = arguments[_i];\n            }\n            if (this.enabled) {\n                // eslint-disable-next-line no-console\n                if (typeof window !== 'undefined' && window.console && typeof console.info === 'function') {\n                    // eslint-disable-next-line no-console\n                    console.info.apply(console, __spreadArray([this.id, this.getTime() + \"ms\"], args));\n                }\n            }\n        };\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        Logger.prototype.warn = function () {\n            var args = [];\n            for (var _i = 0; _i < arguments.length; _i++) {\n                args[_i] = arguments[_i];\n            }\n            if (this.enabled) {\n                // eslint-disable-next-line no-console\n                if (typeof window !== 'undefined' && window.console && typeof console.warn === 'function') {\n                    // eslint-disable-next-line no-console\n                    console.warn.apply(console, __spreadArray([this.id, this.getTime() + \"ms\"], args));\n                }\n                else {\n                    this.info.apply(this, args);\n                }\n            }\n        };\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        Logger.prototype.error = function () {\n            var args = [];\n            for (var _i = 0; _i < arguments.length; _i++) {\n                args[_i] = arguments[_i];\n            }\n            if (this.enabled) {\n                // eslint-disable-next-line no-console\n                if (typeof window !== 'undefined' && window.console && typeof console.error === 'function') {\n                    // eslint-disable-next-line no-console\n                    console.error.apply(console, __spreadArray([this.id, this.getTime() + \"ms\"], args));\n                }\n                else {\n                    this.info.apply(this, args);\n                }\n            }\n        };\n        Logger.instances = {};\n        return Logger;\n    }());\n\n    var Context = /** @class */ (function () {\n        function Context(options, windowBounds) {\n            var _a;\n            this.windowBounds = windowBounds;\n            this.instanceName = \"#\" + Context.instanceCount++;\n            this.logger = new Logger({ id: this.instanceName, enabled: options.logging });\n            this.cache = (_a = options.cache) !== null && _a !== void 0 ? _a : new Cache(this, options);\n        }\n        Context.instanceCount = 1;\n        return Context;\n    }());\n\n    var html2canvas = function (element, options) {\n        if (options === void 0) { options = {}; }\n        return renderElement(element, options);\n    };\n    if (typeof window !== 'undefined') {\n        CacheStorage.setContext(window);\n    }\n    var renderElement = function (element, opts) { return __awaiter(void 0, void 0, void 0, function () {\n        var ownerDocument, defaultView, resourceOptions, contextOptions, windowOptions, windowBounds, context, foreignObjectRendering, cloneOptions, documentCloner, clonedElement, container, _a, width, height, left, top, backgroundColor, renderOptions, canvas, renderer, root, renderer;\n        var _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t;\n        return __generator(this, function (_u) {\n            switch (_u.label) {\n                case 0:\n                    if (!element || typeof element !== 'object') {\n                        return [2 /*return*/, Promise.reject('Invalid element provided as first argument')];\n                    }\n                    ownerDocument = element.ownerDocument;\n                    if (!ownerDocument) {\n                        throw new Error(\"Element is not attached to a Document\");\n                    }\n                    defaultView = ownerDocument.defaultView;\n                    if (!defaultView) {\n                        throw new Error(\"Document is not attached to a Window\");\n                    }\n                    resourceOptions = {\n                        allowTaint: (_b = opts.allowTaint) !== null && _b !== void 0 ? _b : false,\n                        imageTimeout: (_c = opts.imageTimeout) !== null && _c !== void 0 ? _c : 15000,\n                        proxy: opts.proxy,\n                        useCORS: (_d = opts.useCORS) !== null && _d !== void 0 ? _d : false\n                    };\n                    contextOptions = __assign({ logging: (_e = opts.logging) !== null && _e !== void 0 ? _e : true, cache: opts.cache }, resourceOptions);\n                    windowOptions = {\n                        windowWidth: (_f = opts.windowWidth) !== null && _f !== void 0 ? _f : defaultView.innerWidth,\n                        windowHeight: (_g = opts.windowHeight) !== null && _g !== void 0 ? _g : defaultView.innerHeight,\n                        scrollX: (_h = opts.scrollX) !== null && _h !== void 0 ? _h : defaultView.pageXOffset,\n                        scrollY: (_j = opts.scrollY) !== null && _j !== void 0 ? _j : defaultView.pageYOffset\n                    };\n                    windowBounds = new Bounds(windowOptions.scrollX, windowOptions.scrollY, windowOptions.windowWidth, windowOptions.windowHeight);\n                    context = new Context(contextOptions, windowBounds);\n                    foreignObjectRendering = (_k = opts.foreignObjectRendering) !== null && _k !== void 0 ? _k : false;\n                    cloneOptions = {\n                        allowTaint: (_l = opts.allowTaint) !== null && _l !== void 0 ? _l : false,\n                        onclone: opts.onclone,\n                        ignoreElements: opts.ignoreElements,\n                        inlineImages: foreignObjectRendering,\n                        copyStyles: foreignObjectRendering\n                    };\n                    context.logger.debug(\"Starting document clone with size \" + windowBounds.width + \"x\" + windowBounds.height + \" scrolled to \" + -windowBounds.left + \",\" + -windowBounds.top);\n                    documentCloner = new DocumentCloner(context, element, cloneOptions);\n                    clonedElement = documentCloner.clonedReferenceElement;\n                    if (!clonedElement) {\n                        return [2 /*return*/, Promise.reject(\"Unable to find element in cloned iframe\")];\n                    }\n                    return [4 /*yield*/, documentCloner.toIFrame(ownerDocument, windowBounds)];\n                case 1:\n                    container = _u.sent();\n                    _a = isBodyElement(clonedElement) || isHTMLElement(clonedElement)\n                        ? parseDocumentSize(clonedElement.ownerDocument)\n                        : parseBounds(context, clonedElement), width = _a.width, height = _a.height, left = _a.left, top = _a.top;\n                    backgroundColor = parseBackgroundColor(context, clonedElement, opts.backgroundColor);\n                    renderOptions = {\n                        canvas: opts.canvas,\n                        backgroundColor: backgroundColor,\n                        scale: (_o = (_m = opts.scale) !== null && _m !== void 0 ? _m : defaultView.devicePixelRatio) !== null && _o !== void 0 ? _o : 1,\n                        x: ((_p = opts.x) !== null && _p !== void 0 ? _p : 0) + left,\n                        y: ((_q = opts.y) !== null && _q !== void 0 ? _q : 0) + top,\n                        width: (_r = opts.width) !== null && _r !== void 0 ? _r : Math.ceil(width),\n                        height: (_s = opts.height) !== null && _s !== void 0 ? _s : Math.ceil(height)\n                    };\n                    if (!foreignObjectRendering) return [3 /*break*/, 3];\n                    context.logger.debug(\"Document cloned, using foreign object rendering\");\n                    renderer = new ForeignObjectRenderer(context, renderOptions);\n                    return [4 /*yield*/, renderer.render(clonedElement)];\n                case 2:\n                    canvas = _u.sent();\n                    return [3 /*break*/, 5];\n                case 3:\n                    context.logger.debug(\"Document cloned, element located at \" + left + \",\" + top + \" with size \" + width + \"x\" + height + \" using computed rendering\");\n                    context.logger.debug(\"Starting DOM parsing\");\n                    root = parseTree(context, clonedElement);\n                    if (backgroundColor === root.styles.backgroundColor) {\n                        root.styles.backgroundColor = COLORS.TRANSPARENT;\n                    }\n                    context.logger.debug(\"Starting renderer for element at \" + renderOptions.x + \",\" + renderOptions.y + \" with size \" + renderOptions.width + \"x\" + renderOptions.height);\n                    renderer = new CanvasRenderer(context, renderOptions);\n                    return [4 /*yield*/, renderer.render(root)];\n                case 4:\n                    canvas = _u.sent();\n                    _u.label = 5;\n                case 5:\n                    if ((_t = opts.removeContainer) !== null && _t !== void 0 ? _t : true) {\n                        if (!DocumentCloner.destroy(container)) {\n                            context.logger.error(\"Cannot detach cloned iframe as it is not in the DOM anymore\");\n                        }\n                    }\n                    context.logger.debug(\"Finished rendering\");\n                    return [2 /*return*/, canvas];\n            }\n        });\n    }); };\n    var parseBackgroundColor = function (context, element, backgroundColorOverride) {\n        var ownerDocument = element.ownerDocument;\n        // http://www.w3.org/TR/css3-background/#special-backgrounds\n        var documentBackgroundColor = ownerDocument.documentElement\n            ? parseColor(context, getComputedStyle(ownerDocument.documentElement).backgroundColor)\n            : COLORS.TRANSPARENT;\n        var bodyBackgroundColor = ownerDocument.body\n            ? parseColor(context, getComputedStyle(ownerDocument.body).backgroundColor)\n            : COLORS.TRANSPARENT;\n        var defaultBackgroundColor = typeof backgroundColorOverride === 'string'\n            ? parseColor(context, backgroundColorOverride)\n            : backgroundColorOverride === null\n                ? COLORS.TRANSPARENT\n                : 0xffffffff;\n        return element === ownerDocument.documentElement\n            ? isTransparent(documentBackgroundColor)\n                ? isTransparent(bodyBackgroundColor)\n                    ? defaultBackgroundColor\n                    : bodyBackgroundColor\n                : documentBackgroundColor\n            : defaultBackgroundColor;\n    };\n\n    return html2canvas;\n\n})));\n//# sourceMappingURL=html2canvas.js.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/html2canvas/dist/html2canvas.js?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/index.js":
/*!*************************************************!*\
  !*** ../../symphony_lib/dist/elements/index.js ***!
  \*************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AppHeader: () => (/* reexport safe */ _AppHeader_svelte__WEBPACK_IMPORTED_MODULE_0__[\"default\"]),\n/* harmony export */   AudioSample: () => (/* reexport safe */ _AudioSample_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]),\n/* harmony export */   ComponentHeader: () => (/* reexport safe */ _ComponentHeader_svelte__WEBPACK_IMPORTED_MODULE_22__[\"default\"]),\n/* harmony export */   Container: () => (/* reexport safe */ _Container_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"]),\n/* harmony export */   DataSample: () => (/* reexport safe */ _DataSample_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"]),\n/* harmony export */   DataSampleDetail: () => (/* reexport safe */ _DataSampleDetail_svelte__WEBPACK_IMPORTED_MODULE_4__[\"default\"]),\n/* harmony export */   Dropdown: () => (/* reexport safe */ _Dropdown_svelte__WEBPACK_IMPORTED_MODULE_5__[\"default\"]),\n/* harmony export */   GroupChip: () => (/* reexport safe */ _GroupChip_svelte__WEBPACK_IMPORTED_MODULE_6__[\"default\"]),\n/* harmony export */   HeaderButton: () => (/* reexport safe */ _HeaderButton_svelte__WEBPACK_IMPORTED_MODULE_7__[\"default\"]),\n/* harmony export */   Heading: () => (/* reexport safe */ _Heading_svelte__WEBPACK_IMPORTED_MODULE_8__[\"default\"]),\n/* harmony export */   IconButton: () => (/* reexport safe */ _IconButton_svelte__WEBPACK_IMPORTED_MODULE_9__[\"default\"]),\n/* harmony export */   ImageSample: () => (/* reexport safe */ _ImageSample_svelte__WEBPACK_IMPORTED_MODULE_10__[\"default\"]),\n/* harmony export */   MultiSelect: () => (/* reexport safe */ _MultiSelect_svelte__WEBPACK_IMPORTED_MODULE_18__[\"default\"]),\n/* harmony export */   NumberInput: () => (/* reexport safe */ _NumberInput_svelte__WEBPACK_IMPORTED_MODULE_19__[\"default\"]),\n/* harmony export */   Pagination: () => (/* reexport safe */ _Pagination_svelte__WEBPACK_IMPORTED_MODULE_20__[\"default\"]),\n/* harmony export */   PaginationControls: () => (/* reexport safe */ _PaginationControls_svelte__WEBPACK_IMPORTED_MODULE_21__[\"default\"]),\n/* harmony export */   Promo: () => (/* reexport safe */ _Promo_svelte__WEBPACK_IMPORTED_MODULE_11__[\"default\"]),\n/* harmony export */   SampleRowContainer: () => (/* reexport safe */ _SampleRowContainer_svelte__WEBPACK_IMPORTED_MODULE_12__[\"default\"]),\n/* harmony export */   SubHeading: () => (/* reexport safe */ _SubHeading_svelte__WEBPACK_IMPORTED_MODULE_14__[\"default\"]),\n/* harmony export */   SymphonyVegaLite: () => (/* reexport safe */ _SymphonyVegaLite_svelte__WEBPACK_IMPORTED_MODULE_13__[\"default\"]),\n/* harmony export */   TextField: () => (/* reexport safe */ _TextField_svelte__WEBPACK_IMPORTED_MODULE_15__[\"default\"]),\n/* harmony export */   ToggleButton: () => (/* reexport safe */ _ToggleButton_svelte__WEBPACK_IMPORTED_MODULE_16__[\"default\"]),\n/* harmony export */   Tooltip: () => (/* reexport safe */ _Tooltip_svelte__WEBPACK_IMPORTED_MODULE_17__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _AppHeader_svelte__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./AppHeader.svelte */ \"../../symphony_lib/dist/elements/AppHeader.svelte\");\n/* harmony import */ var _AudioSample_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AudioSample.svelte */ \"../../symphony_lib/dist/elements/AudioSample.svelte\");\n/* harmony import */ var _Container_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Container.svelte */ \"../../symphony_lib/dist/elements/Container.svelte\");\n/* harmony import */ var _DataSample_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./DataSample.svelte */ \"../../symphony_lib/dist/elements/DataSample.svelte\");\n/* harmony import */ var _DataSampleDetail_svelte__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./DataSampleDetail.svelte */ \"../../symphony_lib/dist/elements/DataSampleDetail.svelte\");\n/* harmony import */ var _Dropdown_svelte__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./Dropdown.svelte */ \"../../symphony_lib/dist/elements/Dropdown.svelte\");\n/* harmony import */ var _GroupChip_svelte__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./GroupChip.svelte */ \"../../symphony_lib/dist/elements/GroupChip.svelte\");\n/* harmony import */ var _HeaderButton_svelte__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./HeaderButton.svelte */ \"../../symphony_lib/dist/elements/HeaderButton.svelte\");\n/* harmony import */ var _Heading_svelte__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Heading.svelte */ \"../../symphony_lib/dist/elements/Heading.svelte\");\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* harmony import */ var _ImageSample_svelte__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./ImageSample.svelte */ \"../../symphony_lib/dist/elements/ImageSample.svelte\");\n/* harmony import */ var _Promo_svelte__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./Promo.svelte */ \"../../symphony_lib/dist/elements/Promo.svelte\");\n/* harmony import */ var _SampleRowContainer_svelte__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./SampleRowContainer.svelte */ \"../../symphony_lib/dist/elements/SampleRowContainer.svelte\");\n/* harmony import */ var _SymphonyVegaLite_svelte__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./SymphonyVegaLite.svelte */ \"../../symphony_lib/dist/elements/SymphonyVegaLite.svelte\");\n/* harmony import */ var _SubHeading_svelte__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./SubHeading.svelte */ \"../../symphony_lib/dist/elements/SubHeading.svelte\");\n/* harmony import */ var _TextField_svelte__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./TextField.svelte */ \"../../symphony_lib/dist/elements/TextField.svelte\");\n/* harmony import */ var _ToggleButton_svelte__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./ToggleButton.svelte */ \"../../symphony_lib/dist/elements/ToggleButton.svelte\");\n/* harmony import */ var _Tooltip_svelte__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./Tooltip.svelte */ \"../../symphony_lib/dist/elements/Tooltip.svelte\");\n/* harmony import */ var _MultiSelect_svelte__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./MultiSelect.svelte */ \"../../symphony_lib/dist/elements/MultiSelect.svelte\");\n/* harmony import */ var _NumberInput_svelte__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./NumberInput.svelte */ \"../../symphony_lib/dist/elements/NumberInput.svelte\");\n/* harmony import */ var _Pagination_svelte__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./Pagination.svelte */ \"../../symphony_lib/dist/elements/Pagination.svelte\");\n/* harmony import */ var _PaginationControls_svelte__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./PaginationControls.svelte */ \"../../symphony_lib/dist/elements/PaginationControls.svelte\");\n/* harmony import */ var _ComponentHeader_svelte__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./ComponentHeader.svelte */ \"../../symphony_lib/dist/elements/ComponentHeader.svelte\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/index.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/dimensions.js":
/*!*****************************************************!*\
  !*** ../../symphony_lib/dist/helpers/dimensions.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   mapHeight: () => (/* binding */ mapHeight),\n/* harmony export */   mapHeightFixed: () => (/* binding */ mapHeightFixed),\n/* harmony export */   mapWidth: () => (/* binding */ mapWidth)\n/* harmony export */ });\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\nfunction mapWidth(width) {\n    switch (width) {\n        case 'XS':\n            return 'col-span-1';\n        case 'S':\n            return 'col-span-2';\n        case 'M':\n            return 'col-span-3';\n        case 'L':\n            return 'col-span-4';\n        case 'XL':\n            return 'col-span-5';\n        case 'XXL':\n            return 'col-span-6';\n        default:\n            return 'col-span-2';\n    }\n}\nfunction mapHeight(height, grid = false) {\n    switch (height) {\n        case 'XS':\n            return grid ? 'row-span-1' : 'max-h-XS';\n        case 'S':\n            return grid ? 'row-span-2' : 'max-h-S';\n        case 'M':\n            return grid ? 'row-span-3' : 'max-h-M';\n        case 'L':\n            return grid ? 'row-span-4' : 'max-h-L';\n        case 'XL':\n            return grid ? 'row-span-5' : 'max-h-XL';\n        case 'XXL':\n            return grid ? 'row-span-6' : 'max-h-XXL';\n        default:\n            return grid ? 'row-span-2' : 'max-h-S';\n    }\n}\nfunction mapHeightFixed(height, grid = false) {\n    switch (height) {\n        case 'XS':\n            return grid ? 'row-span-1' : 'h-XS';\n        case 'S':\n            return grid ? 'row-span-2' : 'h-S';\n        case 'M':\n            return grid ? 'row-span-3' : 'h-M';\n        case 'L':\n            return grid ? 'row-span-4' : 'h-L';\n        case 'XL':\n            return grid ? 'row-span-5' : 'h-XL';\n        case 'XXL':\n            return grid ? 'row-span-6' : 'h-XXL';\n        default:\n            return grid ? 'row-span-2' : 'h-S';\n    }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/dimensions.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/export.js":
/*!*************************************************!*\
  !*** ../../symphony_lib/dist/helpers/export.js ***!
  \*************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   exportView: () => (/* binding */ exportView)\n/* harmony export */ });\n/* harmony import */ var html2canvas__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! html2canvas */ \"../../node_modules/html2canvas/dist/html2canvas.js\");\n/* harmony import */ var html2canvas__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(html2canvas__WEBPACK_IMPORTED_MODULE_0__);\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\nfunction exportView(container, name) {\n    html2canvas__WEBPACK_IMPORTED_MODULE_0___default()(container).then((canvas) => {\n        const a = document.createElement(\"a\");\n        a.href = canvas\n            .toDataURL(\"image/jpeg\")\n            .replace(\"image/jpeg\", \"image/octet-stream\");\n        a.download = `${name}.jpg`;\n        a.click();\n    });\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/export.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/filetype.js":
/*!***************************************************!*\
  !*** ../../symphony_lib/dist/helpers/filetype.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getComponentForType: () => (/* binding */ getComponentForType)\n/* harmony export */ });\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../types */ \"../../symphony_lib/dist/types.js\");\n/* harmony import */ var _elements_ImageSample_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../elements/ImageSample.svelte */ \"../../symphony_lib/dist/elements/ImageSample.svelte\");\n/* harmony import */ var _elements_AudioSample_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../elements/AudioSample.svelte */ \"../../symphony_lib/dist/elements/AudioSample.svelte\");\n/* harmony import */ var _elements_TabularSample_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../elements/TabularSample.svelte */ \"../../symphony_lib/dist/elements/TabularSample.svelte\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\nfunction getComponentForType(type) {\n    switch (type) {\n        case _types__WEBPACK_IMPORTED_MODULE_0__.SymphonyDataType.AUDIO:\n            return _elements_AudioSample_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n        case _types__WEBPACK_IMPORTED_MODULE_0__.SymphonyDataType.IMAGE:\n            return _elements_ImageSample_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"];\n        default:\n            return _elements_TabularSample_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n    }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/filetype.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/index.js":
/*!************************************************!*\
  !*** ../../symphony_lib/dist/helpers/index.js ***!
  \************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   cartesian: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_2__.cartesian),\n/* harmony export */   exportView: () => (/* reexport safe */ _export__WEBPACK_IMPORTED_MODULE_4__.exportView),\n/* harmony export */   getBinnableStringColumns: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_2__.getBinnableStringColumns),\n/* harmony export */   getColumnType: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_2__.getColumnType),\n/* harmony export */   isStringColumnBinnable: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_2__.isStringColumnBinnable),\n/* harmony export */   mapHeight: () => (/* reexport safe */ _dimensions__WEBPACK_IMPORTED_MODULE_0__.mapHeight),\n/* harmony export */   mapHeightFixed: () => (/* reexport safe */ _dimensions__WEBPACK_IMPORTED_MODULE_0__.mapHeightFixed),\n/* harmony export */   mapWidth: () => (/* reexport safe */ _dimensions__WEBPACK_IMPORTED_MODULE_0__.mapWidth),\n/* harmony export */   selectAll: () => (/* reexport safe */ _selection__WEBPACK_IMPORTED_MODULE_3__.selectAll),\n/* harmony export */   slide: () => (/* reexport safe */ _transitions__WEBPACK_IMPORTED_MODULE_1__.slide)\n/* harmony export */ });\n/* harmony import */ var _dimensions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dimensions */ \"../../symphony_lib/dist/helpers/dimensions.js\");\n/* harmony import */ var _transitions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./transitions */ \"../../symphony_lib/dist/helpers/transitions.js\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./table */ \"../../symphony_lib/dist/helpers/table.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./selection */ \"../../symphony_lib/dist/helpers/selection.js\");\n/* harmony import */ var _export__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./export */ \"../../symphony_lib/dist/helpers/export.js\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/index.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/selection.js":
/*!****************************************************!*\
  !*** ../../symphony_lib/dist/helpers/selection.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   selectAll: () => (/* binding */ selectAll)\n/* harmony export */ });\n/* harmony import */ var svelte_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/store */ \"../../node_modules/svelte/store/index.mjs\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\nfunction selectAll(selectedStore, newSelected) {\n    let existingSelectedSet = new Set((0,svelte_store__WEBPACK_IMPORTED_MODULE_0__.get)(selectedStore));\n    let newSelectedSet = new Set(newSelected);\n    if (setHasAll(newSelectedSet, existingSelectedSet)) {\n        for (var toRemove of newSelectedSet)\n            existingSelectedSet.delete(toRemove);\n        selectedStore.update(() => [...existingSelectedSet]);\n        return;\n    }\n    let combinedSelected = new Set([...existingSelectedSet, ...newSelectedSet]);\n    selectedStore.set(Array.from(combinedSelected));\n}\nfunction setHasAll(set, setHas) {\n    for (var a of set)\n        if (!setHas.has(a))\n            return false;\n    return true;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/selection.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/table.js":
/*!************************************************!*\
  !*** ../../symphony_lib/dist/helpers/table.js ***!
  \************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   cartesian: () => (/* binding */ cartesian),\n/* harmony export */   getBinnableStringColumns: () => (/* binding */ getBinnableStringColumns),\n/* harmony export */   getColumnType: () => (/* binding */ getColumnType),\n/* harmony export */   isStringColumnBinnable: () => (/* binding */ isStringColumnBinnable)\n/* harmony export */ });\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\nconst UNIQUE_COLS_PCTG = 0.1;\nfunction getColumnType(table, columnName) {\n    const col = table.column(columnName);\n    if (col === undefined) {\n        return undefined;\n    }\n    const firstValue = col.get(0);\n    if (firstValue.constructor.name === \"SignedBigNum\") {\n        return \"number\";\n    }\n    if (typeof firstValue === \"object\") {\n        const objectClass = firstValue.constructor.name;\n        if (objectClass.includes(\"Array\")) {\n            return \"array\";\n        }\n    }\n    return typeof firstValue;\n}\nfunction getBinnableStringColumns(table) {\n    const colNames = table.columnNames();\n    const binnnableStringColumns = [];\n    for (const colName of colNames) {\n        const columnType = getColumnType(table, colName);\n        if (columnType === \"string\") {\n            if (isStringColumnBinnable(colName, table)) {\n                binnnableStringColumns.push(colName);\n            }\n        }\n    }\n    return binnnableStringColumns;\n}\nfunction isStringColumnBinnable(columnName, table) {\n    /** If more than UNIQUE_COLS_PCTG percent of the column are unique strings, likely an ID, don't bin. */\n    const unique = table.groupby(columnName).count().numRows();\n    if (unique < UNIQUE_COLS_PCTG * table.numRows()) {\n        return true;\n    }\n    return false;\n}\nconst cartesian = (...a) => a.reduce((a, b) => a.flatMap((d) => b.map((e) => [d, e].reduce((acc, val) => acc.concat(val), []))));\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/table.js?");

/***/ }),

/***/ "../../symphony_lib/dist/helpers/transitions.js":
/*!******************************************************!*\
  !*** ../../symphony_lib/dist/helpers/transitions.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   slide: () => (/* binding */ slide)\n/* harmony export */ });\n/* harmony import */ var svelte_easing__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/easing */ \"../../node_modules/svelte/easing/index.mjs\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\nfunction slide(node, { delay = 0, duration = 400, easing = svelte_easing__WEBPACK_IMPORTED_MODULE_0__.cubicOut } = {}) {\n    const style = getComputedStyle(node);\n    const opacity = +style.opacity;\n    const width = parseFloat(style.width);\n    const padding_right = parseFloat(style.paddingRight);\n    const padding_left = parseFloat(style.paddingLeft);\n    const margin_right = parseFloat(style.marginRight);\n    const margin_left = parseFloat(style.marginLeft);\n    const border_right_width = parseFloat(style.borderRightWidth);\n    const border_left_width = parseFloat(style.borderLeftWidth);\n    return {\n        delay,\n        duration,\n        easing,\n        css: (t) => 'overflow: hidden;' +\n            `opacity: ${Math.min(t * 20, 1) * opacity};` +\n            `width: ${t * width}px;` +\n            `padding-right: ${t * padding_right}px;` +\n            `padding-left: ${t * padding_left}px;` +\n            `margin-right: ${t * margin_right}px;` +\n            `margin-left: ${t * margin_left}px;` +\n            `border-right-width: ${t * border_right_width}px;` +\n            `border-left-width: ${t * border_left_width}px;`,\n    };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/helpers/transitions.js?");

/***/ }),

/***/ "../../symphony_lib/dist/index.js":
/*!****************************************!*\
  !*** ../../symphony_lib/dist/index.js ***!
  \****************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AppHeader: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.AppHeader),\n/* harmony export */   AudioSample: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.AudioSample),\n/* harmony export */   ComponentHeader: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.ComponentHeader),\n/* harmony export */   Container: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Container),\n/* harmony export */   DataSample: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.DataSample),\n/* harmony export */   DataSampleDetail: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.DataSampleDetail),\n/* harmony export */   Dropdown: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Dropdown),\n/* harmony export */   GroupChip: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.GroupChip),\n/* harmony export */   HeaderButton: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.HeaderButton),\n/* harmony export */   Heading: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Heading),\n/* harmony export */   IconButton: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.IconButton),\n/* harmony export */   ImageSample: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.ImageSample),\n/* harmony export */   JupyterWidget: () => (/* reexport safe */ _JupyterWidget_svelte__WEBPACK_IMPORTED_MODULE_5__[\"default\"]),\n/* harmony export */   MultiSelect: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.MultiSelect),\n/* harmony export */   NumberInput: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.NumberInput),\n/* harmony export */   Pagination: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Pagination),\n/* harmony export */   PaginationControls: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.PaginationControls),\n/* harmony export */   Promo: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Promo),\n/* harmony export */   ResolverType: () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_1__.ResolverType),\n/* harmony export */   SampleRowContainer: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.SampleRowContainer),\n/* harmony export */   SubHeading: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.SubHeading),\n/* harmony export */   SymphonyDataType: () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_1__.SymphonyDataType),\n/* harmony export */   SymphonyVegaLite: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.SymphonyVegaLite),\n/* harmony export */   TextField: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.TextField),\n/* harmony export */   ToggleButton: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.ToggleButton),\n/* harmony export */   Tooltip: () => (/* reexport safe */ _elements__WEBPACK_IMPORTED_MODULE_2__.Tooltip),\n/* harmony export */   cartesian: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.cartesian),\n/* harmony export */   dataTable: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.dataTable),\n/* harmony export */   exportView: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.exportView),\n/* harmony export */   filter: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.filter),\n/* harmony export */   filterError: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.filterError),\n/* harmony export */   filteredTable: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.filteredTable),\n/* harmony export */   getBinnableStringColumns: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.getBinnableStringColumns),\n/* harmony export */   getColumnType: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.getColumnType),\n/* harmony export */   groupColumns: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.groupColumns),\n/* harmony export */   groupNames: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.groupNames),\n/* harmony export */   groupedTables: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.groupedTables),\n/* harmony export */   initializeStores: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.initializeStores),\n/* harmony export */   isStringColumnBinnable: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.isStringColumnBinnable),\n/* harmony export */   mapHeight: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.mapHeight),\n/* harmony export */   mapHeightFixed: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.mapHeightFixed),\n/* harmony export */   mapWidth: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.mapWidth),\n/* harmony export */   selectAll: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.selectAll),\n/* harmony export */   selected: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.selected),\n/* harmony export */   serializers: () => (/* binding */ serializers),\n/* harmony export */   slide: () => (/* reexport safe */ _helpers__WEBPACK_IMPORTED_MODULE_3__.slide),\n/* harmony export */   symphonySpec: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.symphonySpec),\n/* harmony export */   table: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.table),\n/* harmony export */   tooltip: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.tooltip),\n/* harmony export */   widgetSpecs: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.widgetSpecs),\n/* harmony export */   widgetWritable: () => (/* reexport safe */ _stores__WEBPACK_IMPORTED_MODULE_4__.widgetWritable)\n/* harmony export */ });\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @jupyter-widgets/base */ \"@jupyter-widgets/base\");\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./types */ \"../../symphony_lib/dist/types.js\");\n/* harmony import */ var _elements__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./elements */ \"../../symphony_lib/dist/elements/index.js\");\n/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./helpers */ \"../../symphony_lib/dist/helpers/index.js\");\n/* harmony import */ var _stores__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./stores */ \"../../symphony_lib/dist/stores.js\");\n/* harmony import */ var _JupyterWidget_svelte__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./JupyterWidget.svelte */ \"../../symphony_lib/dist/JupyterWidget.svelte\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\n\n\nconst serializers = Object.assign(Object.assign({}, _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetModel.serializers), { table: {\n        serialize: (value) => {\n            return new DataView(value.buffer.slice(0));\n        },\n    } });\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/index.js?");

/***/ }),

/***/ "../../symphony_lib/dist/stores.js":
/*!*****************************************!*\
  !*** ../../symphony_lib/dist/stores.js ***!
  \*****************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   dataTable: () => (/* binding */ dataTable),\n/* harmony export */   filter: () => (/* binding */ filter),\n/* harmony export */   filterError: () => (/* binding */ filterError),\n/* harmony export */   filteredTable: () => (/* binding */ filteredTable),\n/* harmony export */   groupColumns: () => (/* binding */ groupColumns),\n/* harmony export */   groupNames: () => (/* binding */ groupNames),\n/* harmony export */   groupedTables: () => (/* binding */ groupedTables),\n/* harmony export */   initializeStores: () => (/* binding */ initializeStores),\n/* harmony export */   selected: () => (/* binding */ selected),\n/* harmony export */   symphonySpec: () => (/* binding */ symphonySpec),\n/* harmony export */   table: () => (/* binding */ table),\n/* harmony export */   tooltip: () => (/* binding */ tooltip),\n/* harmony export */   widgetSpecs: () => (/* binding */ widgetSpecs),\n/* harmony export */   widgetWritable: () => (/* binding */ widgetWritable)\n/* harmony export */ });\n/* harmony import */ var arquero__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! arquero */ \"../../node_modules/arquero/src/index.js\");\n/* harmony import */ var svelte_store__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte/store */ \"../../node_modules/svelte/store/index.mjs\");\n/* harmony import */ var _helpers_table__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./helpers/table */ \"../../symphony_lib/dist/helpers/table.js\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\nfunction widgetWritable(name_, value_) {\n    const name = name_;\n    const curVal = (0,svelte_store__WEBPACK_IMPORTED_MODULE_1__.writable)(value_);\n    let model;\n    return {\n        set: (v) => {\n            curVal.set(v);\n            if (model) {\n                model.set(name, v);\n                model.save_changes();\n            }\n        },\n        setModel: (m) => {\n            model = m;\n            curVal.set(model.get(name));\n            model.on(\"change:\" + name, () => curVal.set(model.get(name)), null);\n        },\n        subscribe: curVal.subscribe,\n        update: (func) => {\n            curVal.update((v) => {\n                const out = func(v);\n                // TODO: figure out why spread operator isn't enough to update model.\n                if (model) {\n                    model.set(name, \"\");\n                    model.set(name, out);\n                    model.save_changes();\n                }\n                return out;\n            });\n        },\n    };\n}\nconst symphonySpec = widgetWritable(\"symphony_spec\", {});\nconst widgetSpecs = widgetWritable(\"widgetSpecs\", {});\nconst dataTable = widgetWritable(\"table\", new DataView(new ArrayBuffer(0)));\nconst selected = widgetWritable(\"selected\", []);\nconst groupColumns = widgetWritable(\"group_columns\", []);\nconst filter = widgetWritable(\"filter\", \"\");\nconst filterError = widgetWritable(\"filter_error\", \"\");\nconst tooltip = widgetWritable(\"tooltip\", {\n    hover: false,\n    mousePos: { x: 0, y: 0 },\n    fetchPrefix: \"\",\n    instance: undefined,\n    number: 0,\n});\nconst table = (0,svelte_store__WEBPACK_IMPORTED_MODULE_1__.derived)(dataTable, (d) => (0,arquero__WEBPACK_IMPORTED_MODULE_0__.fromArrow)(d));\nconst filteredTable = (0,svelte_store__WEBPACK_IMPORTED_MODULE_1__.derived)([table, filter], ([table, filter]) => {\n    filterError.set(\"\");\n    let filteredTable = table;\n    if (filter) {\n        try {\n            filteredTable = filteredTable.filter(filter);\n        }\n        catch (err) {\n            filterError.set(err);\n        }\n    }\n    return filteredTable;\n});\nconst groupNames = (0,svelte_store__WEBPACK_IMPORTED_MODULE_1__.derived)([filteredTable, groupColumns], ([filteredTable, groupColumns]) => {\n    if (groupColumns.length > 0) {\n        const uniqueColumnValues = groupColumns.map((col) => filteredTable\n            .rollup({ col: arquero__WEBPACK_IMPORTED_MODULE_0__.op.array_agg_distinct(col) })\n            .object().col);\n        // If just one column, don't do cartesian product and make it a 2D array.\n        if (uniqueColumnValues.length === 1) {\n            return uniqueColumnValues[0].map((group) => [group]);\n        }\n        return (0,_helpers_table__WEBPACK_IMPORTED_MODULE_2__.cartesian)(...uniqueColumnValues);\n    }\n    else\n        return [];\n});\nconst groupedTables = (0,svelte_store__WEBPACK_IMPORTED_MODULE_1__.derived)([filteredTable, groupColumns, groupNames, symphonySpec], ([filteredTable, groupColumns, groupNames, symphonySpec]) => {\n    if (groupColumns !== undefined &&\n        filteredTable !== undefined &&\n        groupNames !== undefined &&\n        groupColumns.length > 0 &&\n        groupNames.length > 0) {\n        let groupedTable = filteredTable.groupby(...groupColumns);\n        let partitions = groupedTable.partitions();\n        let groupedTables = partitions.map((partition) => filteredTable.reify(partition));\n        return groupedTables;\n    }\n    else {\n        return [];\n    }\n});\nfunction initializeStores(model) {\n    selected.setModel(model);\n    filter.setModel(model);\n    groupColumns.setModel(model);\n    symphonySpec.setModel(model);\n    dataTable.setModel(model);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/stores.js?");

/***/ }),

/***/ "../../symphony_lib/dist/types.js":
/*!****************************************!*\
  !*** ../../symphony_lib/dist/types.js ***!
  \****************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ResolverType: () => (/* binding */ ResolverType),\n/* harmony export */   SymphonyDataType: () => (/* binding */ SymphonyDataType)\n/* harmony export */ });\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\nvar SymphonyDataType;\n(function (SymphonyDataType) {\n    SymphonyDataType[SymphonyDataType[\"TABULAR\"] = 1] = \"TABULAR\";\n    SymphonyDataType[SymphonyDataType[\"IMAGE\"] = 2] = \"IMAGE\";\n    SymphonyDataType[SymphonyDataType[\"AUDIO\"] = 3] = \"AUDIO\";\n})(SymphonyDataType || (SymphonyDataType = {}));\nvar ResolverType;\n(function (ResolverType) {\n    ResolverType[ResolverType[\"BINNED_STRING\"] = 0] = \"BINNED_STRING\";\n    ResolverType[ResolverType[\"NUMBER\"] = 1] = \"NUMBER\";\n})(ResolverType || (ResolverType = {}));\n\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/types.js?");

/***/ }),

/***/ "../../node_modules/svelte-fa/src/utils.js":
/*!*************************************************!*\
  !*** ../../node_modules/svelte-fa/src/utils.js ***!
  \*************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getStyles: () => (/* binding */ getStyles),\n/* harmony export */   getTransform: () => (/* binding */ getTransform),\n/* harmony export */   joinCss: () => (/* binding */ joinCss)\n/* harmony export */ });\nconst parseNumber = parseFloat;\n\nfunction joinCss(obj, separator = ';') {\n  let texts;\n  if (Array.isArray(obj)) {\n    texts = obj.filter((text) => text);\n  } else {\n    texts = [];\n    for (const prop in obj) {\n      if (obj[prop]) {\n        texts.push(`${prop}:${obj[prop]}`);\n      }\n    }\n  }\n  return texts.join(separator);\n}\n\nfunction getStyles(style, size, pull, fw) {\n  let float;\n  let width;\n  const height = '1em';\n  let lineHeight;\n  let fontSize;\n  let textAlign;\n  let verticalAlign = '-.125em';\n  const overflow = 'visible';\n\n  if (fw) {\n    textAlign = 'center';\n    width = '1.25em';\n  }\n\n  if (pull) {\n    float = pull;\n  }\n\n  if (size) {\n    if (size == 'lg') {\n      fontSize = '1.33333em';\n      lineHeight = '.75em';\n      verticalAlign = '-.225em';\n    } else if (size == 'xs') {\n      fontSize = '.75em';\n    } else if (size == 'sm') {\n      fontSize = '.875em';\n    } else {\n      fontSize = size.replace('x', 'em');\n    }\n  }\n\n  return joinCss([\n    joinCss({\n      float,\n      width,\n      height,\n      'line-height': lineHeight,\n      'font-size': fontSize,\n      'text-align': textAlign,\n      'vertical-align': verticalAlign,\n      'transform-origin': 'center',\n      overflow,\n    }),\n    style,\n  ]);\n}\n\nfunction getTransform(\n  scale,\n  translateX,\n  translateY,\n  rotate,\n  flip,\n  translateTimes = 1,\n  translateUnit = '',\n  rotateUnit = '',\n) {\n  let flipX = 1;\n  let flipY = 1;\n\n  if (flip) {\n    if (flip == 'horizontal') {\n      flipX = -1;\n    } else if (flip == 'vertical') {\n      flipY = -1;\n    } else {\n      flipX = flipY = -1;\n    }\n  }\n\n  return joinCss(\n    [\n      `translate(${parseNumber(translateX) * translateTimes}${translateUnit},${parseNumber(translateY) * translateTimes}${translateUnit})`,\n      `scale(${flipX * parseNumber(scale)},${flipY * parseNumber(scale)})`,\n      rotate && `rotate(${rotate}${rotateUnit})`,\n    ],\n    ' ',\n  );\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-fa/src/utils.js?");

/***/ }),

/***/ "../../node_modules/svelte-fa/src/fa.svelte":
/*!**************************************************!*\
  !*** ../../node_modules/svelte-fa/src/fa.svelte ***!
  \**************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./utils */ \"../../node_modules/svelte-fa/src/utils.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-fa/src/fa.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-1i7u104\", \".spin.svelte-1i7u104{-webkit-animation:svelte-1i7u104-spin 2s 0s infinite linear;animation:svelte-1i7u104-spin 2s 0s infinite linear}.pulse.svelte-1i7u104{-webkit-animation:svelte-1i7u104-spin 1s infinite steps(8);animation:svelte-1i7u104-spin 1s infinite steps(8)}@-webkit-keyframes svelte-1i7u104-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes svelte-1i7u104-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}\");\n}\n\n// (94:0) {#if i[4]}\nfunction create_if_block(ctx) {\n\tlet svg;\n\tlet g1;\n\tlet g0;\n\tlet g1_transform_value;\n\tlet g1_transform_origin_value;\n\tlet svg_class_value;\n\tlet svg_viewBox_value;\n\n\tfunction select_block_type(ctx, dirty) {\n\t\tif (typeof /*i*/ ctx[7][4] == 'string') return create_if_block_1;\n\t\treturn create_else_block;\n\t}\n\n\tlet current_block_type = select_block_type(ctx, -1);\n\tlet if_block = current_block_type(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tsvg = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"svg\");\n\t\t\tg1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"g\");\n\t\t\tg0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"g\");\n\t\t\tif_block.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g0, \"transform\", /*transform*/ ctx[10]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g1, \"transform\", g1_transform_value = `translate(${/*i*/ ctx[7][0] / 2} ${/*i*/ ctx[7][1] / 2})`);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g1, \"transform-origin\", g1_transform_origin_value = `${/*i*/ ctx[7][0] / 4} 0`);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"id\", /*id*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"class\", svg_class_value = \"\" + ((0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.null_to_empty)(/*c*/ ctx[8]) + \" svelte-1i7u104\"));\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"style\", /*s*/ ctx[9]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"viewBox\", svg_viewBox_value = `0 0 ${/*i*/ ctx[7][0]} ${/*i*/ ctx[7][1]}`);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"aria-hidden\", \"true\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"role\", \"img\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"xmlns\", \"http://www.w3.org/2000/svg\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, svg, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(svg, g1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(g1, g0);\n\t\t\tif_block.m(g0, null);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (current_block_type === (current_block_type = select_block_type(ctx, dirty)) && if_block) {\n\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t} else {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = current_block_type(ctx);\n\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(g0, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tif (dirty & /*transform*/ 1024) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g0, \"transform\", /*transform*/ ctx[10]);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && g1_transform_value !== (g1_transform_value = `translate(${/*i*/ ctx[7][0] / 2} ${/*i*/ ctx[7][1] / 2})`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g1, \"transform\", g1_transform_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && g1_transform_origin_value !== (g1_transform_origin_value = `${/*i*/ ctx[7][0] / 4} 0`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(g1, \"transform-origin\", g1_transform_origin_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*id*/ 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"id\", /*id*/ ctx[0]);\n\t\t\t}\n\n\t\t\tif (dirty & /*c*/ 256 && svg_class_value !== (svg_class_value = \"\" + ((0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.null_to_empty)(/*c*/ ctx[8]) + \" svelte-1i7u104\"))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"class\", svg_class_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*s*/ 512) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"style\", /*s*/ ctx[9]);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && svg_viewBox_value !== (svg_viewBox_value = `0 0 ${/*i*/ ctx[7][0]} ${/*i*/ ctx[7][1]}`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"viewBox\", svg_viewBox_value);\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(svg);\n\t\t\tif_block.d();\n\t\t}\n\t};\n}\n\n// (115:8) {:else}\nfunction create_else_block(ctx) {\n\tlet path0;\n\tlet path0_d_value;\n\tlet path0_fill_value;\n\tlet path0_fill_opacity_value;\n\tlet path0_transform_value;\n\tlet path1;\n\tlet path1_d_value;\n\tlet path1_fill_value;\n\tlet path1_fill_opacity_value;\n\tlet path1_transform_value;\n\n\treturn {\n\t\tc() {\n\t\t\tpath0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"path\");\n\t\t\tpath1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"path\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"d\", path0_d_value = /*i*/ ctx[7][4][0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"fill\", path0_fill_value = /*secondaryColor*/ ctx[3] || /*color*/ ctx[1] || 'currentColor');\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"fill-opacity\", path0_fill_opacity_value = /*swapOpacity*/ ctx[6] != false\n\t\t\t? /*primaryOpacity*/ ctx[4]\n\t\t\t: /*secondaryOpacity*/ ctx[5]);\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"transform\", path0_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"d\", path1_d_value = /*i*/ ctx[7][4][1]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"fill\", path1_fill_value = /*primaryColor*/ ctx[2] || /*color*/ ctx[1] || 'currentColor');\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"fill-opacity\", path1_fill_opacity_value = /*swapOpacity*/ ctx[6] != false\n\t\t\t? /*secondaryOpacity*/ ctx[5]\n\t\t\t: /*primaryOpacity*/ ctx[4]);\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"transform\", path1_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, path0, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, path1, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*i*/ 128 && path0_d_value !== (path0_d_value = /*i*/ ctx[7][4][0])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"d\", path0_d_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*secondaryColor, color*/ 10 && path0_fill_value !== (path0_fill_value = /*secondaryColor*/ ctx[3] || /*color*/ ctx[1] || 'currentColor')) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"fill\", path0_fill_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*swapOpacity, primaryOpacity, secondaryOpacity*/ 112 && path0_fill_opacity_value !== (path0_fill_opacity_value = /*swapOpacity*/ ctx[6] != false\n\t\t\t? /*primaryOpacity*/ ctx[4]\n\t\t\t: /*secondaryOpacity*/ ctx[5])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"fill-opacity\", path0_fill_opacity_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && path0_transform_value !== (path0_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path0, \"transform\", path0_transform_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && path1_d_value !== (path1_d_value = /*i*/ ctx[7][4][1])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"d\", path1_d_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*primaryColor, color*/ 6 && path1_fill_value !== (path1_fill_value = /*primaryColor*/ ctx[2] || /*color*/ ctx[1] || 'currentColor')) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"fill\", path1_fill_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*swapOpacity, secondaryOpacity, primaryOpacity*/ 112 && path1_fill_opacity_value !== (path1_fill_opacity_value = /*swapOpacity*/ ctx[6] != false\n\t\t\t? /*secondaryOpacity*/ ctx[5]\n\t\t\t: /*primaryOpacity*/ ctx[4])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"fill-opacity\", path1_fill_opacity_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && path1_transform_value !== (path1_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path1, \"transform\", path1_transform_value);\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(path0);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(path1);\n\t\t}\n\t};\n}\n\n// (109:8) {#if typeof i[4] == 'string'}\nfunction create_if_block_1(ctx) {\n\tlet path;\n\tlet path_d_value;\n\tlet path_fill_value;\n\tlet path_transform_value;\n\n\treturn {\n\t\tc() {\n\t\t\tpath = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"path\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"d\", path_d_value = /*i*/ ctx[7][4]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"fill\", path_fill_value = /*color*/ ctx[1] || /*primaryColor*/ ctx[2] || 'currentColor');\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"transform\", path_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, path, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*i*/ 128 && path_d_value !== (path_d_value = /*i*/ ctx[7][4])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"d\", path_d_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*color, primaryColor*/ 6 && path_fill_value !== (path_fill_value = /*color*/ ctx[1] || /*primaryColor*/ ctx[2] || 'currentColor')) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"fill\", path_fill_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*i*/ 128 && path_transform_value !== (path_transform_value = `translate(${/*i*/ ctx[7][0] / -2} ${/*i*/ ctx[7][1] / -2})`)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"transform\", path_transform_value);\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(path);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet if_block_anchor;\n\tlet if_block = /*i*/ ctx[7][4] && create_if_block(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tif (if_block) if_block.c();\n\t\t\tif_block_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (if_block) if_block.m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, if_block_anchor, anchor);\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (/*i*/ ctx[7][4]) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(if_block_anchor.parentNode, if_block_anchor);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = null;\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (if_block) if_block.d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(if_block_anchor);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { class: clazz = '' } = $$props;\n\tlet { id = '' } = $$props;\n\tlet { style = '' } = $$props;\n\tlet { icon } = $$props;\n\tlet { size = '' } = $$props;\n\tlet { color = '' } = $$props;\n\tlet { fw = false } = $$props;\n\tlet { pull = '' } = $$props;\n\tlet { scale = 1 } = $$props;\n\tlet { translateX = 0 } = $$props;\n\tlet { translateY = 0 } = $$props;\n\tlet { rotate = '' } = $$props;\n\tlet { flip = false } = $$props;\n\tlet { spin = false } = $$props;\n\tlet { pulse = false } = $$props;\n\tlet { primaryColor = '' } = $$props;\n\tlet { secondaryColor = '' } = $$props;\n\tlet { primaryOpacity = 1 } = $$props;\n\tlet { secondaryOpacity = 0.4 } = $$props;\n\tlet { swapOpacity = false } = $$props;\n\tlet i;\n\tlet c;\n\tlet s;\n\tlet transform;\n\n\t$$self.$$set = $$props => {\n\t\tif ('class' in $$props) $$invalidate(11, clazz = $$props.class);\n\t\tif ('id' in $$props) $$invalidate(0, id = $$props.id);\n\t\tif ('style' in $$props) $$invalidate(12, style = $$props.style);\n\t\tif ('icon' in $$props) $$invalidate(13, icon = $$props.icon);\n\t\tif ('size' in $$props) $$invalidate(14, size = $$props.size);\n\t\tif ('color' in $$props) $$invalidate(1, color = $$props.color);\n\t\tif ('fw' in $$props) $$invalidate(15, fw = $$props.fw);\n\t\tif ('pull' in $$props) $$invalidate(16, pull = $$props.pull);\n\t\tif ('scale' in $$props) $$invalidate(17, scale = $$props.scale);\n\t\tif ('translateX' in $$props) $$invalidate(18, translateX = $$props.translateX);\n\t\tif ('translateY' in $$props) $$invalidate(19, translateY = $$props.translateY);\n\t\tif ('rotate' in $$props) $$invalidate(20, rotate = $$props.rotate);\n\t\tif ('flip' in $$props) $$invalidate(21, flip = $$props.flip);\n\t\tif ('spin' in $$props) $$invalidate(22, spin = $$props.spin);\n\t\tif ('pulse' in $$props) $$invalidate(23, pulse = $$props.pulse);\n\t\tif ('primaryColor' in $$props) $$invalidate(2, primaryColor = $$props.primaryColor);\n\t\tif ('secondaryColor' in $$props) $$invalidate(3, secondaryColor = $$props.secondaryColor);\n\t\tif ('primaryOpacity' in $$props) $$invalidate(4, primaryOpacity = $$props.primaryOpacity);\n\t\tif ('secondaryOpacity' in $$props) $$invalidate(5, secondaryOpacity = $$props.secondaryOpacity);\n\t\tif ('swapOpacity' in $$props) $$invalidate(6, swapOpacity = $$props.swapOpacity);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*icon*/ 8192) {\n\t\t\t$: $$invalidate(7, i = icon && icon.icon || [0, 0, '', [], '']);\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*clazz, spin, pulse*/ 12584960) {\n\t\t\t$: $$invalidate(8, c = (0,_utils__WEBPACK_IMPORTED_MODULE_1__.joinCss)([clazz, 'svelte-fa', spin && 'spin', pulse && 'pulse'], ' '));\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*style, size, pull, fw*/ 118784) {\n\t\t\t$: $$invalidate(9, s = (0,_utils__WEBPACK_IMPORTED_MODULE_1__.getStyles)(style, size, pull, fw));\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*scale, translateX, translateY, rotate, flip*/ 4063232) {\n\t\t\t$: $$invalidate(10, transform = (0,_utils__WEBPACK_IMPORTED_MODULE_1__.getTransform)(scale, translateX, translateY, rotate, flip, 512));\n\t\t}\n\t};\n\n\treturn [\n\t\tid,\n\t\tcolor,\n\t\tprimaryColor,\n\t\tsecondaryColor,\n\t\tprimaryOpacity,\n\t\tsecondaryOpacity,\n\t\tswapOpacity,\n\t\ti,\n\t\tc,\n\t\ts,\n\t\ttransform,\n\t\tclazz,\n\t\tstyle,\n\t\ticon,\n\t\tsize,\n\t\tfw,\n\t\tpull,\n\t\tscale,\n\t\ttranslateX,\n\t\ttranslateY,\n\t\trotate,\n\t\tflip,\n\t\tspin,\n\t\tpulse\n\t];\n}\n\nclass Fa extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\tclass: 11,\n\t\t\t\tid: 0,\n\t\t\t\tstyle: 12,\n\t\t\t\ticon: 13,\n\t\t\t\tsize: 14,\n\t\t\t\tcolor: 1,\n\t\t\t\tfw: 15,\n\t\t\t\tpull: 16,\n\t\t\t\tscale: 17,\n\t\t\t\ttranslateX: 18,\n\t\t\t\ttranslateY: 19,\n\t\t\t\trotate: 20,\n\t\t\t\tflip: 21,\n\t\t\t\tspin: 22,\n\t\t\t\tpulse: 23,\n\t\t\t\tprimaryColor: 2,\n\t\t\t\tsecondaryColor: 3,\n\t\t\t\tprimaryOpacity: 4,\n\t\t\t\tsecondaryOpacity: 5,\n\t\t\t\tswapOpacity: 6\n\t\t\t},\n\t\t\tadd_css\n\t\t);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Fa);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-fa/src/fa.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/ClearIcon.svelte":
/*!*************************************************************!*\
  !*** ../../node_modules/svelte-select/src/ClearIcon.svelte ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/ClearIcon.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet svg;\n\tlet path;\n\n\treturn {\n\t\tc() {\n\t\t\tsvg = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"svg\");\n\t\t\tpath = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"path\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"fill\", \"currentColor\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"d\", \"M34.923,37.251L24,26.328L13.077,37.251L9.436,33.61l10.923-10.923L9.436,11.765l3.641-3.641L24,19.047L34.923,8.124\\n    l3.641,3.641L27.641,22.688L38.564,33.61L34.923,37.251z\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"width\", \"100%\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"height\", \"100%\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"viewBox\", \"-2 -2 50 50\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"focusable\", \"false\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"aria-hidden\", \"true\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"role\", \"presentation\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, svg, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(svg, path);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(svg);\n\t\t}\n\t};\n}\n\nclass ClearIcon extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, null, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ClearIcon);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/ClearIcon.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/Item.svelte":
/*!********************************************************!*\
  !*** ../../node_modules/svelte-select/src/Item.svelte ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/Item.svelte generated by Svelte v3.59.2 */\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-19bcy4y\", \".item.svelte-19bcy4y{cursor:default;height:42px;height:var(--height, 42px);line-height:42px;line-height:var(--height, 42px);padding:0 20px;padding:var(--itemPadding, 0 20px);color:inherit;color:var(--itemColor, inherit);text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.groupHeader.svelte-19bcy4y{text-transform:uppercase;text-transform:var(--groupTitleTextTransform, uppercase)}.groupItem.svelte-19bcy4y{padding-left:40px;padding-left:var(--groupItemPaddingLeft, 40px)}.item.svelte-19bcy4y:active{background:#b9daff;background:var(--itemActiveBackground, #b9daff)}.item.active.svelte-19bcy4y{background:#007aff;background:var(--itemIsActiveBG, #007aff);color:#fff;color:var(--itemIsActiveColor, #fff)}.item.notSelectable.svelte-19bcy4y{color:#999;color:var(--itemIsNotSelectableColor, #999)}.item.first.svelte-19bcy4y{border-radius:4px 4px 0 0;border-radius:var(--itemFirstBorderRadius, 4px 4px 0 0)}.item.hover.svelte-19bcy4y:not(.active){background:#e7f2ff;background:var(--itemHoverBG, #e7f2ff);color:inherit;color:var(--itemHoverColor, inherit)}\");\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet raw_value = /*getOptionLabel*/ ctx[0](/*item*/ ctx[1], /*filterText*/ ctx[2]) + \"\";\n\tlet div_class_value;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value = \"item \" + /*itemClasses*/ ctx[3] + \" svelte-19bcy4y\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tdiv.innerHTML = raw_value;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*getOptionLabel, item, filterText*/ 7 && raw_value !== (raw_value = /*getOptionLabel*/ ctx[0](/*item*/ ctx[1], /*filterText*/ ctx[2]) + \"\")) div.innerHTML = raw_value;;\n\n\t\t\tif (dirty & /*itemClasses*/ 8 && div_class_value !== (div_class_value = \"item \" + /*itemClasses*/ ctx[3] + \" svelte-19bcy4y\")) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { isActive = false } = $$props;\n\tlet { isFirst = false } = $$props;\n\tlet { isHover = false } = $$props;\n\tlet { isSelectable = false } = $$props;\n\tlet { getOptionLabel = undefined } = $$props;\n\tlet { item = undefined } = $$props;\n\tlet { filterText = '' } = $$props;\n\tlet itemClasses = '';\n\n\t$$self.$$set = $$props => {\n\t\tif ('isActive' in $$props) $$invalidate(4, isActive = $$props.isActive);\n\t\tif ('isFirst' in $$props) $$invalidate(5, isFirst = $$props.isFirst);\n\t\tif ('isHover' in $$props) $$invalidate(6, isHover = $$props.isHover);\n\t\tif ('isSelectable' in $$props) $$invalidate(7, isSelectable = $$props.isSelectable);\n\t\tif ('getOptionLabel' in $$props) $$invalidate(0, getOptionLabel = $$props.getOptionLabel);\n\t\tif ('item' in $$props) $$invalidate(1, item = $$props.item);\n\t\tif ('filterText' in $$props) $$invalidate(2, filterText = $$props.filterText);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*isActive, isFirst, isHover, item, isSelectable*/ 242) {\n\t\t\t$: {\n\t\t\t\tconst classes = [];\n\n\t\t\t\tif (isActive) {\n\t\t\t\t\tclasses.push('active');\n\t\t\t\t}\n\n\t\t\t\tif (isFirst) {\n\t\t\t\t\tclasses.push('first');\n\t\t\t\t}\n\n\t\t\t\tif (isHover) {\n\t\t\t\t\tclasses.push('hover');\n\t\t\t\t}\n\n\t\t\t\tif (item.isGroupHeader) {\n\t\t\t\t\tclasses.push('groupHeader');\n\t\t\t\t}\n\n\t\t\t\tif (item.isGroupItem) {\n\t\t\t\t\tclasses.push('groupItem');\n\t\t\t\t}\n\n\t\t\t\tif (!isSelectable) {\n\t\t\t\t\tclasses.push('notSelectable');\n\t\t\t\t}\n\n\t\t\t\t$$invalidate(3, itemClasses = classes.join(' '));\n\t\t\t}\n\t\t}\n\t};\n\n\treturn [\n\t\tgetOptionLabel,\n\t\titem,\n\t\tfilterText,\n\t\titemClasses,\n\t\tisActive,\n\t\tisFirst,\n\t\tisHover,\n\t\tisSelectable\n\t];\n}\n\nclass Item extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\tisActive: 4,\n\t\t\t\tisFirst: 5,\n\t\t\t\tisHover: 6,\n\t\t\t\tisSelectable: 7,\n\t\t\t\tgetOptionLabel: 0,\n\t\t\t\titem: 1,\n\t\t\t\tfilterText: 2\n\t\t\t},\n\t\t\tadd_css\n\t\t);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Item);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/Item.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/List.svelte":
/*!********************************************************!*\
  !*** ../../node_modules/svelte-select/src/List.svelte ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* harmony import */ var _utils_isOutOfViewport__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./utils/isOutOfViewport */ \"../../node_modules/svelte-select/src/utils/isOutOfViewport.js\");\n/* harmony import */ var _Item_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./Item.svelte */ \"../../node_modules/svelte-select/src/Item.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/List.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-1ohsdgd\", \".listContainer.svelte-1ohsdgd{box-shadow:0 2px 3px 0 rgba(44, 62, 80, 0.24);box-shadow:var(--listShadow, 0 2px 3px 0 rgba(44, 62, 80, 0.24));border-radius:4px;border-radius:var(--listBorderRadius, 4px);max-height:250px;max-height:var(--listMaxHeight, 250px);overflow-y:auto;background:#fff;background:var(--listBackground, #fff);border:none;border:var(--listBorder, none);position:absolute;position:var(--listPosition, absolute);z-index:2;z-index:var(--listZIndex, 2);width:100%;left:0;left:var(--listLeft, 0);right:0;right:var(--listRight, 0)}.virtualList.svelte-1ohsdgd{height:200px;height:var(--virtualListHeight, 200px)}.listGroupTitle.svelte-1ohsdgd{color:#8f8f8f;color:var(--groupTitleColor, #8f8f8f);cursor:default;font-size:12px;font-size:var(--groupTitleFontSize, 12px);font-weight:600;font-weight:var(--groupTitleFontWeight, 600);height:42px;height:var(--height, 42px);line-height:42px;line-height:var(--height, 42px);padding:0 20px;padding:var(--groupTitlePadding, 0 20px);text-overflow:ellipsis;overflow-x:hidden;white-space:nowrap;text-transform:uppercase;text-transform:var(--groupTitleTextTransform, uppercase)}.empty.svelte-1ohsdgd{text-align:center;text-align:var(--listEmptyTextAlign, center);padding:20px 0;padding:var(--listEmptyPadding, 20px 0);color:#78848f;color:var(--listEmptyColor, #78848f)}\");\n}\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[41] = list[i];\n\tchild_ctx[42] = i;\n\treturn child_ctx;\n}\n\n// (328:4) {:else}\nfunction create_else_block(ctx) {\n\tlet each_1_anchor;\n\tlet current;\n\tlet each_value = /*items*/ ctx[1];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\tconst out = i => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i], 1, 1, () => {\n\t\teach_blocks[i] = null;\n\t});\n\n\tlet each_1_else = null;\n\n\tif (!each_value.length) {\n\t\teach_1_else = create_else_block_2(ctx);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\teach_1_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\n\t\t\tif (each_1_else) {\n\t\t\t\teach_1_else.c();\n\t\t\t}\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(target, anchor);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, each_1_anchor, anchor);\n\n\t\t\tif (each_1_else) {\n\t\t\t\teach_1_else.m(target, anchor);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*getGroupHeaderLabel, items, handleHover, handleClick, Item, filterText, getOptionLabel, value, optionIdentifier, hoverItemIndex, noOptionsMessage, hideEmptyState*/ 114390) {\n\t\t\t\teach_value = /*items*/ ctx[1];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t\teach_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\tfor (i = each_value.length; i < each_blocks.length; i += 1) {\n\t\t\t\t\tout(i);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\n\t\t\t\tif (!each_value.length && each_1_else) {\n\t\t\t\t\teach_1_else.p(ctx, dirty);\n\t\t\t\t} else if (!each_value.length) {\n\t\t\t\t\teach_1_else = create_else_block_2(ctx);\n\t\t\t\t\teach_1_else.c();\n\t\t\t\t\teach_1_else.m(each_1_anchor.parentNode, each_1_anchor);\n\t\t\t\t} else if (each_1_else) {\n\t\t\t\t\teach_1_else.d(1);\n\t\t\t\t\teach_1_else = null;\n\t\t\t\t}\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\teach_blocks = each_blocks.filter(Boolean);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(each_1_anchor);\n\t\t\tif (each_1_else) each_1_else.d(detaching);\n\t\t}\n\t};\n}\n\n// (305:4) {#if isVirtualList}\nfunction create_if_block(ctx) {\n\tlet switch_instance;\n\tlet switch_instance_anchor;\n\tlet current;\n\tvar switch_value = /*VirtualList*/ ctx[3];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\titems: /*items*/ ctx[1],\n\t\t\t\titemHeight: /*itemHeight*/ ctx[8],\n\t\t\t\t$$slots: {\n\t\t\t\t\tdefault: [\n\t\t\t\t\t\tcreate_default_slot,\n\t\t\t\t\t\t({ item, i }) => ({ 41: item, 42: i }),\n\t\t\t\t\t\t({ item, i }) => [0, (item ? 1024 : 0) | (i ? 2048 : 0)]\n\t\t\t\t\t]\n\t\t\t\t},\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tswitch_instance_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, switch_instance_anchor, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty[0] & /*items*/ 2) switch_instance_changes.items = /*items*/ ctx[1];\n\t\t\tif (dirty[0] & /*itemHeight*/ 256) switch_instance_changes.itemHeight = /*itemHeight*/ ctx[8];\n\n\t\t\tif (dirty[0] & /*Item, filterText, getOptionLabel, value, optionIdentifier, hoverItemIndex, items*/ 9814 | dirty[1] & /*$$scope, i, item*/ 11264) {\n\t\t\t\tswitch_instance_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\tif (dirty[0] & /*VirtualList*/ 8 && switch_value !== (switch_value = /*VirtualList*/ ctx[3])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, switch_instance_anchor.parentNode, switch_instance_anchor);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(switch_instance_anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance, detaching);\n\t\t}\n\t};\n}\n\n// (350:8) {:else}\nfunction create_else_block_2(ctx) {\n\tlet if_block_anchor;\n\tlet if_block = !/*hideEmptyState*/ ctx[11] && create_if_block_2(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tif (if_block) if_block.c();\n\t\t\tif_block_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (if_block) if_block.m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, if_block_anchor, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (!/*hideEmptyState*/ ctx[11]) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block_2(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(if_block_anchor.parentNode, if_block_anchor);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = null;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (if_block) if_block.d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(if_block_anchor);\n\t\t}\n\t};\n}\n\n// (351:12) {#if !hideEmptyState}\nfunction create_if_block_2(ctx) {\n\tlet div;\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*noOptionsMessage*/ ctx[12]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"empty svelte-1ohsdgd\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*noOptionsMessage*/ 4096) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, /*noOptionsMessage*/ ctx[12]);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\n// (332:12) {:else}\nfunction create_else_block_1(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet t;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tvar switch_value = /*Item*/ ctx[4];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\titem: /*item*/ ctx[41],\n\t\t\t\tfilterText: /*filterText*/ ctx[13],\n\t\t\t\tgetOptionLabel: /*getOptionLabel*/ ctx[6],\n\t\t\t\tisFirst: isItemFirst(/*i*/ ctx[42]),\n\t\t\t\tisActive: isItemActive(/*item*/ ctx[41], /*value*/ ctx[9], /*optionIdentifier*/ ctx[10]),\n\t\t\t\tisHover: isItemHover(/*hoverItemIndex*/ ctx[2], /*item*/ ctx[41], /*i*/ ctx[42], /*items*/ ctx[1]),\n\t\t\t\tisSelectable: isItemSelectable(/*item*/ ctx[41])\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\tfunction mouseover_handler_1() {\n\t\treturn /*mouseover_handler_1*/ ctx[29](/*i*/ ctx[42]);\n\t}\n\n\tfunction focus_handler_1() {\n\t\treturn /*focus_handler_1*/ ctx[30](/*i*/ ctx[42]);\n\t}\n\n\tfunction click_handler_1(...args) {\n\t\treturn /*click_handler_1*/ ctx[31](/*item*/ ctx[41], /*i*/ ctx[42], ...args);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"listItem\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"tabindex\", \"-1\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"mouseover\", mouseover_handler_1),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"focus\", focus_handler_1),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", click_handler_1)\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(new_ctx, dirty) {\n\t\t\tctx = new_ctx;\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty[0] & /*items*/ 2) switch_instance_changes.item = /*item*/ ctx[41];\n\t\t\tif (dirty[0] & /*filterText*/ 8192) switch_instance_changes.filterText = /*filterText*/ ctx[13];\n\t\t\tif (dirty[0] & /*getOptionLabel*/ 64) switch_instance_changes.getOptionLabel = /*getOptionLabel*/ ctx[6];\n\t\t\tif (dirty[0] & /*items, value, optionIdentifier*/ 1538) switch_instance_changes.isActive = isItemActive(/*item*/ ctx[41], /*value*/ ctx[9], /*optionIdentifier*/ ctx[10]);\n\t\t\tif (dirty[0] & /*hoverItemIndex, items*/ 6) switch_instance_changes.isHover = isItemHover(/*hoverItemIndex*/ ctx[2], /*item*/ ctx[41], /*i*/ ctx[42], /*items*/ ctx[1]);\n\t\t\tif (dirty[0] & /*items*/ 2) switch_instance_changes.isSelectable = isItemSelectable(/*item*/ ctx[41]);\n\n\t\t\tif (dirty[0] & /*Item*/ 16 && switch_value !== (switch_value = /*Item*/ ctx[4])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, t);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\n// (330:12) {#if item.isGroupHeader && !item.isSelectable}\nfunction create_if_block_1(ctx) {\n\tlet div;\n\tlet t_value = /*getGroupHeaderLabel*/ ctx[7](/*item*/ ctx[41]) + \"\";\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t_value);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"listGroupTitle svelte-1ohsdgd\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*getGroupHeaderLabel, items*/ 130 && t_value !== (t_value = /*getGroupHeaderLabel*/ ctx[7](/*item*/ ctx[41]) + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, t_value);\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\n// (329:8) {#each items as item, i}\nfunction create_each_block(ctx) {\n\tlet current_block_type_index;\n\tlet if_block;\n\tlet if_block_anchor;\n\tlet current;\n\tconst if_block_creators = [create_if_block_1, create_else_block_1];\n\tconst if_blocks = [];\n\n\tfunction select_block_type_1(ctx, dirty) {\n\t\tif (/*item*/ ctx[41].isGroupHeader && !/*item*/ ctx[41].isSelectable) return 0;\n\t\treturn 1;\n\t}\n\n\tcurrent_block_type_index = select_block_type_1(ctx, [-1, -1]);\n\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tif_block.c();\n\t\t\tif_block_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif_blocks[current_block_type_index].m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, if_block_anchor, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tlet previous_block_index = current_block_type_index;\n\t\t\tcurrent_block_type_index = select_block_type_1(ctx, dirty);\n\n\t\t\tif (current_block_type_index === previous_block_index) {\n\t\t\t\tif_blocks[current_block_type_index].p(ctx, dirty);\n\t\t\t} else {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_blocks[previous_block_index], 1, 1, () => {\n\t\t\t\t\tif_blocks[previous_block_index] = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\tif_block = if_blocks[current_block_type_index];\n\n\t\t\t\tif (!if_block) {\n\t\t\t\t\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t} else {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\tif_block.m(if_block_anchor.parentNode, if_block_anchor);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif_blocks[current_block_type_index].d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(if_block_anchor);\n\t\t}\n\t};\n}\n\n// (306:8) <svelte:component             this={VirtualList}             {items}             {itemHeight}             let:item             let:i>\nfunction create_default_slot(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tvar switch_value = /*Item*/ ctx[4];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\titem: /*item*/ ctx[41],\n\t\t\t\tfilterText: /*filterText*/ ctx[13],\n\t\t\t\tgetOptionLabel: /*getOptionLabel*/ ctx[6],\n\t\t\t\tisFirst: isItemFirst(/*i*/ ctx[42]),\n\t\t\t\tisActive: isItemActive(/*item*/ ctx[41], /*value*/ ctx[9], /*optionIdentifier*/ ctx[10]),\n\t\t\t\tisHover: isItemHover(/*hoverItemIndex*/ ctx[2], /*item*/ ctx[41], /*i*/ ctx[42], /*items*/ ctx[1]),\n\t\t\t\tisSelectable: isItemSelectable(/*item*/ ctx[41])\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\tfunction mouseover_handler() {\n\t\treturn /*mouseover_handler*/ ctx[26](/*i*/ ctx[42]);\n\t}\n\n\tfunction focus_handler() {\n\t\treturn /*focus_handler*/ ctx[27](/*i*/ ctx[42]);\n\t}\n\n\tfunction click_handler(...args) {\n\t\treturn /*click_handler*/ ctx[28](/*item*/ ctx[41], /*i*/ ctx[42], ...args);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"listItem\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"mouseover\", mouseover_handler),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"focus\", focus_handler),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", click_handler)\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(new_ctx, dirty) {\n\t\t\tctx = new_ctx;\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty[1] & /*item*/ 1024) switch_instance_changes.item = /*item*/ ctx[41];\n\t\t\tif (dirty[0] & /*filterText*/ 8192) switch_instance_changes.filterText = /*filterText*/ ctx[13];\n\t\t\tif (dirty[0] & /*getOptionLabel*/ 64) switch_instance_changes.getOptionLabel = /*getOptionLabel*/ ctx[6];\n\t\t\tif (dirty[1] & /*i*/ 2048) switch_instance_changes.isFirst = isItemFirst(/*i*/ ctx[42]);\n\t\t\tif (dirty[0] & /*value, optionIdentifier*/ 1536 | dirty[1] & /*item*/ 1024) switch_instance_changes.isActive = isItemActive(/*item*/ ctx[41], /*value*/ ctx[9], /*optionIdentifier*/ ctx[10]);\n\t\t\tif (dirty[0] & /*hoverItemIndex, items*/ 6 | dirty[1] & /*item, i*/ 3072) switch_instance_changes.isHover = isItemHover(/*hoverItemIndex*/ ctx[2], /*item*/ ctx[41], /*i*/ ctx[42], /*items*/ ctx[1]);\n\t\t\tif (dirty[1] & /*item*/ 1024) switch_instance_changes.isSelectable = isItemSelectable(/*item*/ ctx[41]);\n\n\t\t\tif (dirty[0] & /*Item*/ 16 && switch_value !== (switch_value = /*Item*/ ctx[4])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet current_block_type_index;\n\tlet if_block;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tconst if_block_creators = [create_if_block, create_else_block];\n\tconst if_blocks = [];\n\n\tfunction select_block_type(ctx, dirty) {\n\t\tif (/*isVirtualList*/ ctx[5]) return 0;\n\t\treturn 1;\n\t}\n\n\tcurrent_block_type_index = select_block_type(ctx, [-1, -1]);\n\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif_block.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"listContainer svelte-1ohsdgd\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"style\", /*listStyle*/ ctx[14]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"virtualList\", /*isVirtualList*/ ctx[5]);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif_blocks[current_block_type_index].m(div, null);\n\t\t\t/*div_binding*/ ctx[32](div);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"keydown\", /*handleKeyDown*/ ctx[17]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"resize\", /*computePlacement*/ ctx[18])\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tlet previous_block_index = current_block_type_index;\n\t\t\tcurrent_block_type_index = select_block_type(ctx, dirty);\n\n\t\t\tif (current_block_type_index === previous_block_index) {\n\t\t\t\tif_blocks[current_block_type_index].p(ctx, dirty);\n\t\t\t} else {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_blocks[previous_block_index], 1, 1, () => {\n\t\t\t\t\tif_blocks[previous_block_index] = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\tif_block = if_blocks[current_block_type_index];\n\n\t\t\t\tif (!if_block) {\n\t\t\t\t\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t} else {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\tif_block.m(div, null);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*listStyle*/ 16384) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"style\", /*listStyle*/ ctx[14]);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*isVirtualList*/ 32) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"virtualList\", /*isVirtualList*/ ctx[5]);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif_blocks[current_block_type_index].d();\n\t\t\t/*div_binding*/ ctx[32](null);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction isItemActive(item, value, optionIdentifier) {\n\treturn value && value[optionIdentifier] === item[optionIdentifier];\n}\n\nfunction isItemFirst(itemIndex) {\n\treturn itemIndex === 0;\n}\n\nfunction isItemHover(hoverItemIndex, item, itemIndex, items) {\n\treturn isItemSelectable(item) && (hoverItemIndex === itemIndex || items.length === 1);\n}\n\nfunction isItemSelectable(item) {\n\treturn item.isGroupHeader && item.isSelectable || item.selectable || !item.hasOwnProperty('selectable'); // Default; if `selectable` was not specified, the object is selectable\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\tlet { container = undefined } = $$props;\n\tlet { VirtualList = null } = $$props;\n\tlet { Item = _Item_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"] } = $$props;\n\tlet { isVirtualList = false } = $$props;\n\tlet { items = [] } = $$props;\n\tlet { labelIdentifier = 'label' } = $$props;\n\n\tlet { getOptionLabel = (option, filterText) => {\n\t\tif (option) return option.isCreator\n\t\t? `Create \\\"${filterText}\\\"`\n\t\t: option[labelIdentifier];\n\t} } = $$props;\n\n\tlet { getGroupHeaderLabel = null } = $$props;\n\tlet { itemHeight = 40 } = $$props;\n\tlet { hoverItemIndex = 0 } = $$props;\n\tlet { value = undefined } = $$props;\n\tlet { optionIdentifier = 'value' } = $$props;\n\tlet { hideEmptyState = false } = $$props;\n\tlet { noOptionsMessage = 'No options' } = $$props;\n\tlet { isMulti = false } = $$props;\n\tlet { activeItemIndex = 0 } = $$props;\n\tlet { filterText = '' } = $$props;\n\tlet { parent = null } = $$props;\n\tlet { listPlacement = null } = $$props;\n\tlet { listAutoWidth = null } = $$props;\n\tlet { listOffset = 5 } = $$props;\n\tlet isScrollingTimer = 0;\n\tlet isScrolling = false;\n\tlet prev_items;\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.onMount)(() => {\n\t\tif (items.length > 0 && !isMulti && value) {\n\t\t\tconst _hoverItemIndex = items.findIndex(item => item[optionIdentifier] === value[optionIdentifier]);\n\n\t\t\tif (_hoverItemIndex) {\n\t\t\t\t$$invalidate(2, hoverItemIndex = _hoverItemIndex);\n\t\t\t}\n\t\t}\n\n\t\tscrollToActiveItem('active');\n\n\t\tcontainer.addEventListener(\n\t\t\t'scroll',\n\t\t\t() => {\n\t\t\t\tclearTimeout(isScrollingTimer);\n\n\t\t\t\tisScrollingTimer = setTimeout(\n\t\t\t\t\t() => {\n\t\t\t\t\t\tisScrolling = false;\n\t\t\t\t\t},\n\t\t\t\t\t100\n\t\t\t\t);\n\t\t\t},\n\t\t\tfalse\n\t\t);\n\t});\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.beforeUpdate)(() => {\n\t\tif (!items) $$invalidate(1, items = []);\n\n\t\tif (items !== prev_items && items.length > 0) {\n\t\t\t$$invalidate(2, hoverItemIndex = 0);\n\t\t}\n\n\t\tprev_items = items;\n\t});\n\n\tfunction handleSelect(item) {\n\t\tif (item.isCreator) return;\n\t\tdispatch('itemSelected', item);\n\t}\n\n\tfunction handleHover(i) {\n\t\tif (isScrolling) return;\n\t\t$$invalidate(2, hoverItemIndex = i);\n\t}\n\n\tfunction handleClick(args) {\n\t\tconst { item, i, event } = args;\n\t\tevent.stopPropagation();\n\t\tif (value && !isMulti && value[optionIdentifier] === item[optionIdentifier]) return closeList();\n\n\t\tif (item.isCreator) {\n\t\t\tdispatch('itemCreated', filterText);\n\t\t} else if (isItemSelectable(item)) {\n\t\t\t$$invalidate(19, activeItemIndex = i);\n\t\t\t$$invalidate(2, hoverItemIndex = i);\n\t\t\thandleSelect(item);\n\t\t}\n\t}\n\n\tfunction closeList() {\n\t\tdispatch('closeList');\n\t}\n\n\tasync function updateHoverItem(increment) {\n\t\tif (isVirtualList) return;\n\t\tlet isNonSelectableItem = true;\n\n\t\twhile (isNonSelectableItem) {\n\t\t\tif (increment > 0 && hoverItemIndex === items.length - 1) {\n\t\t\t\t$$invalidate(2, hoverItemIndex = 0);\n\t\t\t} else if (increment < 0 && hoverItemIndex === 0) {\n\t\t\t\t$$invalidate(2, hoverItemIndex = items.length - 1);\n\t\t\t} else {\n\t\t\t\t$$invalidate(2, hoverItemIndex = hoverItemIndex + increment);\n\t\t\t}\n\n\t\t\tisNonSelectableItem = !isItemSelectable(items[hoverItemIndex]);\n\t\t}\n\n\t\tawait (0,svelte__WEBPACK_IMPORTED_MODULE_1__.tick)();\n\t\tscrollToActiveItem('hover');\n\t}\n\n\tfunction handleKeyDown(e) {\n\t\tswitch (e.key) {\n\t\t\tcase 'Escape':\n\t\t\t\te.preventDefault();\n\t\t\t\tcloseList();\n\t\t\t\tbreak;\n\t\t\tcase 'ArrowDown':\n\t\t\t\te.preventDefault();\n\t\t\t\titems.length && updateHoverItem(1);\n\t\t\t\tbreak;\n\t\t\tcase 'ArrowUp':\n\t\t\t\te.preventDefault();\n\t\t\t\titems.length && updateHoverItem(-1);\n\t\t\t\tbreak;\n\t\t\tcase 'Enter':\n\t\t\t\te.preventDefault();\n\t\t\t\tif (items.length === 0) break;\n\t\t\t\tconst hoverItem = items[hoverItemIndex];\n\t\t\t\tif (value && !isMulti && value[optionIdentifier] === hoverItem[optionIdentifier]) {\n\t\t\t\t\tcloseList();\n\t\t\t\t\tbreak;\n\t\t\t\t}\n\t\t\t\tif (hoverItem.isCreator) {\n\t\t\t\t\tdispatch('itemCreated', filterText);\n\t\t\t\t} else {\n\t\t\t\t\t$$invalidate(19, activeItemIndex = hoverItemIndex);\n\t\t\t\t\thandleSelect(items[hoverItemIndex]);\n\t\t\t\t}\n\t\t\t\tbreak;\n\t\t\tcase 'Tab':\n\t\t\t\te.preventDefault();\n\t\t\t\tif (items.length === 0) {\n\t\t\t\t\treturn closeList();\n\t\t\t\t}\n\t\t\t\tif (value && value[optionIdentifier] === items[hoverItemIndex][optionIdentifier]) return closeList();\n\t\t\t\t$$invalidate(19, activeItemIndex = hoverItemIndex);\n\t\t\t\thandleSelect(items[hoverItemIndex]);\n\t\t\t\tbreak;\n\t\t}\n\t}\n\n\tfunction scrollToActiveItem(className) {\n\t\tif (isVirtualList || !container) return;\n\t\tlet offsetBounding;\n\t\tconst focusedElemBounding = container.querySelector(`.listItem .${className}`);\n\n\t\tif (focusedElemBounding) {\n\t\t\toffsetBounding = container.getBoundingClientRect().bottom - focusedElemBounding.getBoundingClientRect().bottom;\n\t\t}\n\n\t\t$$invalidate(0, container.scrollTop -= offsetBounding, container);\n\t}\n\n\tlet listStyle;\n\n\tfunction computePlacement() {\n\t\tconst { top, height, width } = parent.getBoundingClientRect();\n\t\t$$invalidate(14, listStyle = '');\n\t\t$$invalidate(14, listStyle += `min-width:${width}px;width:${listAutoWidth ? 'auto' : '100%'};`);\n\n\t\tif (listPlacement === 'top' || listPlacement === 'auto' && (0,_utils_isOutOfViewport__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(parent).bottom) {\n\t\t\t$$invalidate(14, listStyle += `bottom:${height + listOffset}px;`);\n\t\t} else {\n\t\t\t$$invalidate(14, listStyle += `top:${height + listOffset}px;`);\n\t\t}\n\t}\n\n\tconst mouseover_handler = i => handleHover(i);\n\tconst focus_handler = i => handleHover(i);\n\tconst click_handler = (item, i, event) => handleClick({ item, i, event });\n\tconst mouseover_handler_1 = i => handleHover(i);\n\tconst focus_handler_1 = i => handleHover(i);\n\tconst click_handler_1 = (item, i, event) => handleClick({ item, i, event });\n\n\tfunction div_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tcontainer = $$value;\n\t\t\t$$invalidate(0, container);\n\t\t});\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('container' in $$props) $$invalidate(0, container = $$props.container);\n\t\tif ('VirtualList' in $$props) $$invalidate(3, VirtualList = $$props.VirtualList);\n\t\tif ('Item' in $$props) $$invalidate(4, Item = $$props.Item);\n\t\tif ('isVirtualList' in $$props) $$invalidate(5, isVirtualList = $$props.isVirtualList);\n\t\tif ('items' in $$props) $$invalidate(1, items = $$props.items);\n\t\tif ('labelIdentifier' in $$props) $$invalidate(20, labelIdentifier = $$props.labelIdentifier);\n\t\tif ('getOptionLabel' in $$props) $$invalidate(6, getOptionLabel = $$props.getOptionLabel);\n\t\tif ('getGroupHeaderLabel' in $$props) $$invalidate(7, getGroupHeaderLabel = $$props.getGroupHeaderLabel);\n\t\tif ('itemHeight' in $$props) $$invalidate(8, itemHeight = $$props.itemHeight);\n\t\tif ('hoverItemIndex' in $$props) $$invalidate(2, hoverItemIndex = $$props.hoverItemIndex);\n\t\tif ('value' in $$props) $$invalidate(9, value = $$props.value);\n\t\tif ('optionIdentifier' in $$props) $$invalidate(10, optionIdentifier = $$props.optionIdentifier);\n\t\tif ('hideEmptyState' in $$props) $$invalidate(11, hideEmptyState = $$props.hideEmptyState);\n\t\tif ('noOptionsMessage' in $$props) $$invalidate(12, noOptionsMessage = $$props.noOptionsMessage);\n\t\tif ('isMulti' in $$props) $$invalidate(21, isMulti = $$props.isMulti);\n\t\tif ('activeItemIndex' in $$props) $$invalidate(19, activeItemIndex = $$props.activeItemIndex);\n\t\tif ('filterText' in $$props) $$invalidate(13, filterText = $$props.filterText);\n\t\tif ('parent' in $$props) $$invalidate(22, parent = $$props.parent);\n\t\tif ('listPlacement' in $$props) $$invalidate(23, listPlacement = $$props.listPlacement);\n\t\tif ('listAutoWidth' in $$props) $$invalidate(24, listAutoWidth = $$props.listAutoWidth);\n\t\tif ('listOffset' in $$props) $$invalidate(25, listOffset = $$props.listOffset);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty[0] & /*parent, container*/ 4194305) {\n\t\t\t$: {\n\t\t\t\tif (parent && container) computePlacement();\n\t\t\t}\n\t\t}\n\t};\n\n\treturn [\n\t\tcontainer,\n\t\titems,\n\t\thoverItemIndex,\n\t\tVirtualList,\n\t\tItem,\n\t\tisVirtualList,\n\t\tgetOptionLabel,\n\t\tgetGroupHeaderLabel,\n\t\titemHeight,\n\t\tvalue,\n\t\toptionIdentifier,\n\t\thideEmptyState,\n\t\tnoOptionsMessage,\n\t\tfilterText,\n\t\tlistStyle,\n\t\thandleHover,\n\t\thandleClick,\n\t\thandleKeyDown,\n\t\tcomputePlacement,\n\t\tactiveItemIndex,\n\t\tlabelIdentifier,\n\t\tisMulti,\n\t\tparent,\n\t\tlistPlacement,\n\t\tlistAutoWidth,\n\t\tlistOffset,\n\t\tmouseover_handler,\n\t\tfocus_handler,\n\t\tclick_handler,\n\t\tmouseover_handler_1,\n\t\tfocus_handler_1,\n\t\tclick_handler_1,\n\t\tdiv_binding\n\t];\n}\n\nclass List extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\tcontainer: 0,\n\t\t\t\tVirtualList: 3,\n\t\t\t\tItem: 4,\n\t\t\t\tisVirtualList: 5,\n\t\t\t\titems: 1,\n\t\t\t\tlabelIdentifier: 20,\n\t\t\t\tgetOptionLabel: 6,\n\t\t\t\tgetGroupHeaderLabel: 7,\n\t\t\t\titemHeight: 8,\n\t\t\t\thoverItemIndex: 2,\n\t\t\t\tvalue: 9,\n\t\t\t\toptionIdentifier: 10,\n\t\t\t\thideEmptyState: 11,\n\t\t\t\tnoOptionsMessage: 12,\n\t\t\t\tisMulti: 21,\n\t\t\t\tactiveItemIndex: 19,\n\t\t\t\tfilterText: 13,\n\t\t\t\tparent: 22,\n\t\t\t\tlistPlacement: 23,\n\t\t\t\tlistAutoWidth: 24,\n\t\t\t\tlistOffset: 25\n\t\t\t},\n\t\t\tadd_css,\n\t\t\t[-1, -1]\n\t\t);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (List);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/List.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/MultiSelection.svelte":
/*!******************************************************************!*\
  !*** ../../node_modules/svelte-select/src/MultiSelection.svelte ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/MultiSelection.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-so8ht0\", \".multiSelectItem.svelte-so8ht0.svelte-so8ht0{background:#ebedef;background:var(--multiItemBG, #ebedef);margin:5px 5px 0 0;margin:var(--multiItemMargin, 5px 5px 0 0);border-radius:16px;border-radius:var(--multiItemBorderRadius, 16px);height:32px;height:var(--multiItemHeight, 32px);line-height:32px;line-height:var(--multiItemHeight, 32px);display:-webkit-box;display:-ms-flexbox;display:flex;cursor:default;padding:0 10px 0 15px;padding:var(--multiItemPadding, 0 10px 0 15px);max-width:100%}.multiSelectItem_label.svelte-so8ht0.svelte-so8ht0{margin:0 5px 0 0;margin:var(--multiLabelMargin, 0 5px 0 0);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.multiSelectItem.svelte-so8ht0.svelte-so8ht0:hover,.multiSelectItem.active.svelte-so8ht0.svelte-so8ht0{background-color:#006fff;background-color:var(--multiItemActiveBG, #006fff);color:#fff;color:var(--multiItemActiveColor, #fff)}.multiSelectItem.disabled.svelte-so8ht0.svelte-so8ht0:hover{background:#ebedef;background:var(--multiItemDisabledHoverBg, #ebedef);color:#c1c6cc;color:var(--multiItemDisabledHoverColor, #c1c6cc)}.multiSelectItem_clear.svelte-so8ht0.svelte-so8ht0{border-radius:50%;border-radius:var(--multiClearRadius, 50%);background:#52616f;background:var(--multiClearBG, #52616f);min-width:16px;min-width:var(--multiClearWidth, 16px);max-width:16px;max-width:var(--multiClearWidth, 16px);height:16px;height:var(--multiClearHeight, 16px);position:relative;top:8px;top:var(--multiClearTop, 8px);text-align:center;text-align:var(--multiClearTextAlign, center);padding:1px;padding:var(--multiClearPadding, 1px)}.multiSelectItem_clear.svelte-so8ht0.svelte-so8ht0:hover,.active.svelte-so8ht0 .multiSelectItem_clear.svelte-so8ht0{background:#fff;background:var(--multiClearHoverBG, #fff)}.multiSelectItem_clear.svelte-so8ht0:hover svg.svelte-so8ht0,.active.svelte-so8ht0 .multiSelectItem_clear svg.svelte-so8ht0{fill:#006fff;fill:var(--multiClearHoverFill, #006fff)}.multiSelectItem_clear.svelte-so8ht0 svg.svelte-so8ht0{fill:#ebedef;fill:var(--multiClearFill, #ebedef);vertical-align:top}\");\n}\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[9] = list[i];\n\tchild_ctx[11] = i;\n\treturn child_ctx;\n}\n\n// (107:8) {#if !isDisabled && !multiFullItemClearable}\nfunction create_if_block(ctx) {\n\tlet div;\n\tlet mounted;\n\tlet dispose;\n\n\tfunction click_handler(...args) {\n\t\treturn /*click_handler*/ ctx[6](/*i*/ ctx[11], ...args);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv.innerHTML = `<svg width=\"100%\" height=\"100%\" viewBox=\"-2 -2 50 50\" focusable=\"false\" aria-hidden=\"true\" role=\"presentation\" class=\"svelte-so8ht0\"><path d=\"M34.923,37.251L24,26.328L13.077,37.251L9.436,33.61l10.923-10.923L9.436,11.765l3.641-3.641L24,19.047L34.923,8.124 l3.641,3.641L27.641,22.688L38.564,33.61L34.923,37.251z\"></path></svg>`;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"multiSelectItem_clear svelte-so8ht0\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", click_handler);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(new_ctx, dirty) {\n\t\t\tctx = new_ctx;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\n// (97:0) {#each value as item, i}\nfunction create_each_block(ctx) {\n\tlet div1;\n\tlet div0;\n\tlet raw_value = /*getSelectionLabel*/ ctx[4](/*item*/ ctx[9]) + \"\";\n\tlet t0;\n\tlet t1;\n\tlet div1_class_value;\n\tlet mounted;\n\tlet dispose;\n\tlet if_block = !/*isDisabled*/ ctx[2] && !/*multiFullItemClearable*/ ctx[3] && create_if_block(ctx);\n\n\tfunction click_handler_1(...args) {\n\t\treturn /*click_handler_1*/ ctx[7](/*i*/ ctx[11], ...args);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block) if_block.c();\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"multiSelectItem_label svelte-so8ht0\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", div1_class_value = \"multiSelectItem \" + (/*activeValue*/ ctx[1] === /*i*/ ctx[11] ? 'active' : '') + \" \" + (/*isDisabled*/ ctx[2] ? 'disabled' : '') + \" svelte-so8ht0\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div1, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\t\t\tdiv0.innerHTML = raw_value;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t0);\n\t\t\tif (if_block) if_block.m(div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t1);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div1, \"click\", click_handler_1);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(new_ctx, dirty) {\n\t\t\tctx = new_ctx;\n\t\t\tif (dirty & /*getSelectionLabel, value*/ 17 && raw_value !== (raw_value = /*getSelectionLabel*/ ctx[4](/*item*/ ctx[9]) + \"\")) div0.innerHTML = raw_value;;\n\n\t\t\tif (!/*isDisabled*/ ctx[2] && !/*multiFullItemClearable*/ ctx[3]) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(div1, t1);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = null;\n\t\t\t}\n\n\t\t\tif (dirty & /*activeValue, isDisabled*/ 6 && div1_class_value !== (div1_class_value = \"multiSelectItem \" + (/*activeValue*/ ctx[1] === /*i*/ ctx[11] ? 'active' : '') + \" \" + (/*isDisabled*/ ctx[2] ? 'disabled' : '') + \" svelte-so8ht0\")) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", div1_class_value);\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div1);\n\t\t\tif (if_block) if_block.d();\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet each_1_anchor;\n\tlet each_value = /*value*/ ctx[0];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\teach_1_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(target, anchor);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, each_1_anchor, anchor);\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*activeValue, isDisabled, multiFullItemClearable, handleClear, getSelectionLabel, value*/ 63) {\n\t\t\t\teach_value = /*value*/ ctx[0];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(each_1_anchor);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\tlet { value = [] } = $$props;\n\tlet { activeValue = undefined } = $$props;\n\tlet { isDisabled = false } = $$props;\n\tlet { multiFullItemClearable = false } = $$props;\n\tlet { getSelectionLabel = undefined } = $$props;\n\n\tfunction handleClear(i, event) {\n\t\tevent.stopPropagation();\n\t\tdispatch('multiItemClear', { i });\n\t}\n\n\tconst click_handler = (i, event) => handleClear(i, event);\n\tconst click_handler_1 = (i, event) => multiFullItemClearable ? handleClear(i, event) : {};\n\n\t$$self.$$set = $$props => {\n\t\tif ('value' in $$props) $$invalidate(0, value = $$props.value);\n\t\tif ('activeValue' in $$props) $$invalidate(1, activeValue = $$props.activeValue);\n\t\tif ('isDisabled' in $$props) $$invalidate(2, isDisabled = $$props.isDisabled);\n\t\tif ('multiFullItemClearable' in $$props) $$invalidate(3, multiFullItemClearable = $$props.multiFullItemClearable);\n\t\tif ('getSelectionLabel' in $$props) $$invalidate(4, getSelectionLabel = $$props.getSelectionLabel);\n\t};\n\n\treturn [\n\t\tvalue,\n\t\tactiveValue,\n\t\tisDisabled,\n\t\tmultiFullItemClearable,\n\t\tgetSelectionLabel,\n\t\thandleClear,\n\t\tclick_handler,\n\t\tclick_handler_1\n\t];\n}\n\nclass MultiSelection extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\tvalue: 0,\n\t\t\t\tactiveValue: 1,\n\t\t\t\tisDisabled: 2,\n\t\t\t\tmultiFullItemClearable: 3,\n\t\t\t\tgetSelectionLabel: 4\n\t\t\t},\n\t\t\tadd_css\n\t\t);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MultiSelection);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/MultiSelection.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/Select.svelte":
/*!**********************************************************!*\
  !*** ../../node_modules/svelte-select/src/Select.svelte ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* harmony import */ var _List_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./List.svelte */ \"../../node_modules/svelte-select/src/List.svelte\");\n/* harmony import */ var _Item_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./Item.svelte */ \"../../node_modules/svelte-select/src/Item.svelte\");\n/* harmony import */ var _Selection_svelte__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Selection.svelte */ \"../../node_modules/svelte-select/src/Selection.svelte\");\n/* harmony import */ var _MultiSelection_svelte__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./MultiSelection.svelte */ \"../../node_modules/svelte-select/src/MultiSelection.svelte\");\n/* harmony import */ var _VirtualList_svelte__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./VirtualList.svelte */ \"../../node_modules/svelte-select/src/VirtualList.svelte\");\n/* harmony import */ var _ClearIcon_svelte__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./ClearIcon.svelte */ \"../../node_modules/svelte-select/src/ClearIcon.svelte\");\n/* harmony import */ var _utils_debounce__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./utils/debounce */ \"../../node_modules/svelte-select/src/utils/debounce.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/Select.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-15ybu53\", \".selectContainer.svelte-15ybu53.svelte-15ybu53{--internalPadding:0 16px;border:1px solid #d8dbdf;border:var(--border, 1px solid #d8dbdf);border-radius:3px;border-radius:var(--borderRadius, 3px);box-sizing:border-box;height:42px;height:var(--height, 42px);position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;align-items:center;padding:var(--internalPadding);padding:var(--padding, var(--internalPadding));background:#fff;background:var(--background, #fff);margin:0;margin:var(--margin, 0)}.selectContainer.svelte-15ybu53 input.svelte-15ybu53{cursor:default;border:none;color:#3f4f5f;color:var(--inputColor, #3f4f5f);height:42px;height:var(--height, 42px);line-height:42px;line-height:var(--height, 42px);padding:var(--internalPadding);padding:var(--inputPadding, var(--padding, var(--internalPadding)));width:100%;background:transparent;font-size:14px;font-size:var(--inputFontSize, 14px);letter-spacing:-0.08px;letter-spacing:var(--inputLetterSpacing, -0.08px);position:absolute;left:0;left:var(--inputLeft, 0);margin:0;margin:var(--inputMargin, 0)}.selectContainer.svelte-15ybu53 input.svelte-15ybu53::placeholder{color:#78848f;color:var(--placeholderColor, #78848f);opacity:1;opacity:var(--placeholderOpacity, 1)}.selectContainer.svelte-15ybu53 input.svelte-15ybu53:focus{outline:none}.selectContainer.svelte-15ybu53.svelte-15ybu53:hover{border-color:#b2b8bf;border-color:var(--borderHoverColor, #b2b8bf)}.selectContainer.focused.svelte-15ybu53.svelte-15ybu53{border-color:#006fe8;border-color:var(--borderFocusColor, #006fe8)}.selectContainer.disabled.svelte-15ybu53.svelte-15ybu53{background:#ebedef;background:var(--disabledBackground, #ebedef);border-color:#ebedef;border-color:var(--disabledBorderColor, #ebedef);color:#c1c6cc;color:var(--disabledColor, #c1c6cc)}.selectContainer.disabled.svelte-15ybu53 input.svelte-15ybu53::placeholder{color:#c1c6cc;color:var(--disabledPlaceholderColor, #c1c6cc);opacity:1;opacity:var(--disabledPlaceholderOpacity, 1)}.selectedItem.svelte-15ybu53.svelte-15ybu53{line-height:42px;line-height:var(--height, 42px);height:42px;height:var(--height, 42px);overflow-x:hidden;padding:0 20px 0 0;padding:var(--selectedItemPadding, 0 20px 0 0)}.selectedItem.svelte-15ybu53.svelte-15ybu53:focus{outline:none}.clearSelect.svelte-15ybu53.svelte-15ybu53{position:absolute;right:10px;right:var(--clearSelectRight, 10px);top:11px;top:var(--clearSelectTop, 11px);bottom:11px;bottom:var(--clearSelectBottom, 11px);width:20px;width:var(--clearSelectWidth, 20px);color:#c5cacf;color:var(--clearSelectColor, #c5cacf);flex:none !important}.clearSelect.svelte-15ybu53.svelte-15ybu53:hover{color:#2c3e50;color:var(--clearSelectHoverColor, #2c3e50)}.selectContainer.focused.svelte-15ybu53 .clearSelect.svelte-15ybu53{color:#3f4f5f;color:var(--clearSelectFocusColor, #3f4f5f)}.indicator.svelte-15ybu53.svelte-15ybu53{position:absolute;right:10px;right:var(--indicatorRight, 10px);top:11px;top:var(--indicatorTop, 11px);width:20px;width:var(--indicatorWidth, 20px);height:20px;height:var(--indicatorHeight, 20px);color:#c5cacf;color:var(--indicatorColor, #c5cacf)}.indicator.svelte-15ybu53 svg.svelte-15ybu53{display:inline-block;fill:currentcolor;fill:var(--indicatorFill, currentcolor);line-height:1;stroke:currentcolor;stroke:var(--indicatorStroke, currentcolor);stroke-width:0}.spinner.svelte-15ybu53.svelte-15ybu53{position:absolute;right:10px;right:var(--spinnerRight, 10px);top:11px;top:var(--spinnerLeft, 11px);width:20px;width:var(--spinnerWidth, 20px);height:20px;height:var(--spinnerHeight, 20px);color:#51ce6c;color:var(--spinnerColor, #51ce6c);animation:svelte-15ybu53-rotate 0.75s linear infinite}.spinner_icon.svelte-15ybu53.svelte-15ybu53{display:block;height:100%;transform-origin:center center;width:100%;position:absolute;top:0;bottom:0;left:0;right:0;margin:auto;-webkit-transform:none}.spinner_path.svelte-15ybu53.svelte-15ybu53{stroke-dasharray:90;stroke-linecap:round}.multiSelect.svelte-15ybu53.svelte-15ybu53{display:-webkit-box;display:-ms-flexbox;display:flex;padding:0 35px 0 16px;padding:var(--multiSelectPadding, 0 35px 0 16px);height:auto;flex-wrap:wrap;align-items:stretch}.multiSelect.svelte-15ybu53>.svelte-15ybu53{flex:1 1 50px}.selectContainer.multiSelect.svelte-15ybu53 input.svelte-15ybu53{padding:0;padding:var(--multiSelectInputPadding, 0);position:relative;margin:0;margin:var(--multiSelectInputMargin, 0)}.hasError.svelte-15ybu53.svelte-15ybu53{border:1px solid #ff2d55;border:var(--errorBorder, 1px solid #ff2d55);background:#fff;background:var(--errorBackground, #fff)}.a11yText.svelte-15ybu53.svelte-15ybu53{z-index:9999;border:0px;clip:rect(1px, 1px, 1px, 1px);height:1px;width:1px;position:absolute;overflow:hidden;padding:0px;white-space:nowrap}@keyframes svelte-15ybu53-rotate{100%{transform:rotate(360deg)}}\");\n}\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[103] = list[i];\n\treturn child_ctx;\n}\n\n// (927:8) {#if isFocused}\nfunction create_if_block_10(ctx) {\n\tlet span0;\n\tlet t0;\n\tlet t1;\n\tlet span1;\n\tlet t2;\n\n\treturn {\n\t\tc() {\n\t\t\tspan0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*ariaSelection*/ ctx[33]);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tspan1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*ariaContext*/ ctx[32]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span0, \"id\", \"aria-selection\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span1, \"id\", \"aria-context\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span0, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span0, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, t1, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span1, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span1, t2);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[1] & /*ariaSelection*/ 4) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, /*ariaSelection*/ ctx[33]);\n\t\t\tif (dirty[1] & /*ariaContext*/ 2) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t2, /*ariaContext*/ ctx[32]);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span0);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(t1);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span1);\n\t\t}\n\t};\n}\n\n// (935:4) {#if Icon}\nfunction create_if_block_9(ctx) {\n\tlet switch_instance;\n\tlet switch_instance_anchor;\n\tlet current;\n\tconst switch_instance_spread_levels = [/*iconProps*/ ctx[18]];\n\tvar switch_value = /*Icon*/ ctx[17];\n\n\tfunction switch_props(ctx) {\n\t\tlet switch_instance_props = {};\n\n\t\tfor (let i = 0; i < switch_instance_spread_levels.length; i += 1) {\n\t\t\tswitch_instance_props = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.assign)(switch_instance_props, switch_instance_spread_levels[i]);\n\t\t}\n\n\t\treturn { props: switch_instance_props };\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tswitch_instance_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, switch_instance_anchor, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = (dirty[0] & /*iconProps*/ 262144)\n\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_spread_update)(switch_instance_spread_levels, [(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_spread_object)(/*iconProps*/ ctx[18])])\n\t\t\t: {};\n\n\t\t\tif (dirty[0] & /*Icon*/ 131072 && switch_value !== (switch_value = /*Icon*/ ctx[17])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, switch_instance_anchor.parentNode, switch_instance_anchor);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(switch_instance_anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance, detaching);\n\t\t}\n\t};\n}\n\n// (939:4) {#if showMultiSelect}\nfunction create_if_block_8(ctx) {\n\tlet switch_instance;\n\tlet switch_instance_anchor;\n\tlet current;\n\tvar switch_value = /*MultiSelection*/ ctx[26];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\tvalue: /*value*/ ctx[2],\n\t\t\t\tgetSelectionLabel: /*getSelectionLabel*/ ctx[12],\n\t\t\t\tactiveValue: /*activeValue*/ ctx[30],\n\t\t\t\tisDisabled: /*isDisabled*/ ctx[9],\n\t\t\t\tmultiFullItemClearable: /*multiFullItemClearable*/ ctx[8]\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\tswitch_instance.$on(\"multiItemClear\", /*handleMultiItemClear*/ ctx[38]);\n\t\tswitch_instance.$on(\"focus\", /*handleFocus*/ ctx[40]);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tswitch_instance_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, switch_instance_anchor, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty[0] & /*value*/ 4) switch_instance_changes.value = /*value*/ ctx[2];\n\t\t\tif (dirty[0] & /*getSelectionLabel*/ 4096) switch_instance_changes.getSelectionLabel = /*getSelectionLabel*/ ctx[12];\n\t\t\tif (dirty[0] & /*activeValue*/ 1073741824) switch_instance_changes.activeValue = /*activeValue*/ ctx[30];\n\t\t\tif (dirty[0] & /*isDisabled*/ 512) switch_instance_changes.isDisabled = /*isDisabled*/ ctx[9];\n\t\t\tif (dirty[0] & /*multiFullItemClearable*/ 256) switch_instance_changes.multiFullItemClearable = /*multiFullItemClearable*/ ctx[8];\n\n\t\t\tif (dirty[0] & /*MultiSelection*/ 67108864 && switch_value !== (switch_value = /*MultiSelection*/ ctx[26])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\tswitch_instance.$on(\"multiItemClear\", /*handleMultiItemClear*/ ctx[38]);\n\t\t\t\t\tswitch_instance.$on(\"focus\", /*handleFocus*/ ctx[40]);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, switch_instance_anchor.parentNode, switch_instance_anchor);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(switch_instance_anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance, detaching);\n\t\t}\n\t};\n}\n\n// (961:4) {#if !isMulti && showSelectedItem}\nfunction create_if_block_7(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tvar switch_value = /*Selection*/ ctx[25];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\titem: /*value*/ ctx[2],\n\t\t\t\tgetSelectionLabel: /*getSelectionLabel*/ ctx[12]\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"selectedItem svelte-15ybu53\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"focus\", /*handleFocus*/ ctx[40]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty[0] & /*value*/ 4) switch_instance_changes.item = /*value*/ ctx[2];\n\t\t\tif (dirty[0] & /*getSelectionLabel*/ 4096) switch_instance_changes.getSelectionLabel = /*getSelectionLabel*/ ctx[12];\n\n\t\t\tif (dirty[0] & /*Selection*/ 33554432 && switch_value !== (switch_value = /*Selection*/ ctx[25])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\n// (970:4) {#if showClearIcon}\nfunction create_if_block_6(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tvar switch_value = /*ClearIcon*/ ctx[23];\n\n\tfunction switch_props(ctx) {\n\t\treturn {};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"clearSelect svelte-15ybu53\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"aria-hidden\", \"true\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.prevent_default)(/*handleClear*/ ctx[27]));\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*ClearIcon*/ 8388608 && switch_value !== (switch_value = /*ClearIcon*/ ctx[23])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\t\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\n// (979:4) {#if !showClearIcon && (showIndicator || (showChevron && !value) || (!isSearchable && !isDisabled && !isWaiting && ((showSelectedItem && !isClearable) || !showSelectedItem)))}\nfunction create_if_block_4(ctx) {\n\tlet div;\n\n\tfunction select_block_type(ctx, dirty) {\n\t\tif (/*indicatorSvg*/ ctx[22]) return create_if_block_5;\n\t\treturn create_else_block;\n\t}\n\n\tlet current_block_type = select_block_type(ctx, [-1, -1, -1, -1]);\n\tlet if_block = current_block_type(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif_block.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"indicator svelte-15ybu53\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"aria-hidden\", \"true\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif_block.m(div, null);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (current_block_type === (current_block_type = select_block_type(ctx, dirty)) && if_block) {\n\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t} else {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = current_block_type(ctx);\n\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(div, null);\n\t\t\t\t}\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif_block.d();\n\t\t}\n\t};\n}\n\n// (983:12) {:else}\nfunction create_else_block(ctx) {\n\tlet svg;\n\tlet path;\n\n\treturn {\n\t\tc() {\n\t\t\tsvg = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"svg\");\n\t\t\tpath = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.svg_element)(\"path\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(path, \"d\", \"M4.516 7.548c0.436-0.446 1.043-0.481 1.576 0l3.908 3.747\\n          3.908-3.747c0.533-0.481 1.141-0.446 1.574 0 0.436 0.445 0.408 1.197 0\\n          1.615-0.406 0.418-4.695 4.502-4.695 4.502-0.217 0.223-0.502\\n          0.335-0.787 0.335s-0.57-0.112-0.789-0.335c0\\n          0-4.287-4.084-4.695-4.502s-0.436-1.17 0-1.615z\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"width\", \"100%\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"height\", \"100%\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"viewBox\", \"0 0 20 20\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"focusable\", \"false\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"aria-hidden\", \"true\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(svg, \"class\", \"svelte-15ybu53\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, svg, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(svg, path);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(svg);\n\t\t}\n\t};\n}\n\n// (981:12) {#if indicatorSvg}\nfunction create_if_block_5(ctx) {\n\tlet html_tag;\n\tlet html_anchor;\n\n\treturn {\n\t\tc() {\n\t\t\thtml_tag = new svelte_internal__WEBPACK_IMPORTED_MODULE_0__.HtmlTag(false);\n\t\t\thtml_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t\thtml_tag.a = html_anchor;\n\t\t},\n\t\tm(target, anchor) {\n\t\t\thtml_tag.m(/*indicatorSvg*/ ctx[22], target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, html_anchor, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*indicatorSvg*/ 4194304) html_tag.p(/*indicatorSvg*/ ctx[22]);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(html_anchor);\n\t\t\tif (detaching) html_tag.d();\n\t\t}\n\t};\n}\n\n// (1001:4) {#if isWaiting}\nfunction create_if_block_3(ctx) {\n\tlet div;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv.innerHTML = `<svg class=\"spinner_icon svelte-15ybu53\" viewBox=\"25 25 50 50\"><circle class=\"spinner_path svelte-15ybu53\" cx=\"50\" cy=\"50\" r=\"20\" fill=\"none\" stroke=\"currentColor\" stroke-width=\"5\" stroke-miterlimit=\"10\"></circle></svg>`;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"spinner svelte-15ybu53\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\n// (1017:4) {#if listOpen}\nfunction create_if_block_2(ctx) {\n\tlet switch_instance;\n\tlet updating_hoverItemIndex;\n\tlet switch_instance_anchor;\n\tlet current;\n\tconst switch_instance_spread_levels = [/*listProps*/ ctx[34]];\n\n\tfunction switch_instance_hoverItemIndex_binding(value) {\n\t\t/*switch_instance_hoverItemIndex_binding*/ ctx[84](value);\n\t}\n\n\tvar switch_value = /*List*/ ctx[24];\n\n\tfunction switch_props(ctx) {\n\t\tlet switch_instance_props = {};\n\n\t\tfor (let i = 0; i < switch_instance_spread_levels.length; i += 1) {\n\t\t\tswitch_instance_props = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.assign)(switch_instance_props, switch_instance_spread_levels[i]);\n\t\t}\n\n\t\tif (/*hoverItemIndex*/ ctx[28] !== void 0) {\n\t\t\tswitch_instance_props.hoverItemIndex = /*hoverItemIndex*/ ctx[28];\n\t\t}\n\n\t\treturn { props: switch_instance_props };\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks.push(() => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.bind)(switch_instance, 'hoverItemIndex', switch_instance_hoverItemIndex_binding));\n\t\tswitch_instance.$on(\"itemSelected\", /*itemSelected*/ ctx[43]);\n\t\tswitch_instance.$on(\"itemCreated\", /*itemCreated*/ ctx[44]);\n\t\tswitch_instance.$on(\"closeList\", /*closeList*/ ctx[45]);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tswitch_instance_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, switch_instance_anchor, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = (dirty[1] & /*listProps*/ 8)\n\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_spread_update)(switch_instance_spread_levels, [(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_spread_object)(/*listProps*/ ctx[34])])\n\t\t\t: {};\n\n\t\t\tif (!updating_hoverItemIndex && dirty[0] & /*hoverItemIndex*/ 268435456) {\n\t\t\t\tupdating_hoverItemIndex = true;\n\t\t\t\tswitch_instance_changes.hoverItemIndex = /*hoverItemIndex*/ ctx[28];\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_flush_callback)(() => updating_hoverItemIndex = false);\n\t\t\t}\n\n\t\t\tif (dirty[0] & /*List*/ 16777216 && switch_value !== (switch_value = /*List*/ ctx[24])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks.push(() => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.bind)(switch_instance, 'hoverItemIndex', switch_instance_hoverItemIndex_binding));\n\t\t\t\t\tswitch_instance.$on(\"itemSelected\", /*itemSelected*/ ctx[43]);\n\t\t\t\t\tswitch_instance.$on(\"itemCreated\", /*itemCreated*/ ctx[44]);\n\t\t\t\t\tswitch_instance.$on(\"closeList\", /*closeList*/ ctx[45]);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, switch_instance_anchor.parentNode, switch_instance_anchor);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(switch_instance_anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance, detaching);\n\t\t}\n\t};\n}\n\n// (1027:4) {#if !isMulti || (isMulti && !showMultiSelect)}\nfunction create_if_block_1(ctx) {\n\tlet input_1;\n\tlet input_1_name_value;\n\tlet input_1_value_value;\n\n\treturn {\n\t\tc() {\n\t\t\tinput_1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"input\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"name\", input_1_name_value = /*inputAttributes*/ ctx[16].name);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"type\", \"hidden\");\n\n\t\t\tinput_1.value = input_1_value_value = /*value*/ ctx[2]\n\t\t\t? /*getSelectionLabel*/ ctx[12](/*value*/ ctx[2])\n\t\t\t: null;\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"class\", \"svelte-15ybu53\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, input_1, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*inputAttributes*/ 65536 && input_1_name_value !== (input_1_name_value = /*inputAttributes*/ ctx[16].name)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"name\", input_1_name_value);\n\t\t\t}\n\n\t\t\tif (dirty[0] & /*value, getSelectionLabel*/ 4100 && input_1_value_value !== (input_1_value_value = /*value*/ ctx[2]\n\t\t\t? /*getSelectionLabel*/ ctx[12](/*value*/ ctx[2])\n\t\t\t: null)) {\n\t\t\t\tinput_1.value = input_1_value_value;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(input_1);\n\t\t}\n\t};\n}\n\n// (1034:4) {#if isMulti && showMultiSelect}\nfunction create_if_block(ctx) {\n\tlet each_1_anchor;\n\tlet each_value = /*value*/ ctx[2];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\teach_1_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(target, anchor);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, each_1_anchor, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*inputAttributes, value, getSelectionLabel*/ 69636) {\n\t\t\t\teach_value = /*value*/ ctx[2];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(each_1_anchor);\n\t\t}\n\t};\n}\n\n// (1035:8) {#each value as item}\nfunction create_each_block(ctx) {\n\tlet input_1;\n\tlet input_1_name_value;\n\tlet input_1_value_value;\n\n\treturn {\n\t\tc() {\n\t\t\tinput_1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"input\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"name\", input_1_name_value = /*inputAttributes*/ ctx[16].name);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"type\", \"hidden\");\n\n\t\t\tinput_1.value = input_1_value_value = /*item*/ ctx[103]\n\t\t\t? /*getSelectionLabel*/ ctx[12](/*item*/ ctx[103])\n\t\t\t: null;\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"class\", \"svelte-15ybu53\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, input_1, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty[0] & /*inputAttributes*/ 65536 && input_1_name_value !== (input_1_name_value = /*inputAttributes*/ ctx[16].name)) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input_1, \"name\", input_1_name_value);\n\t\t\t}\n\n\t\t\tif (dirty[0] & /*value, getSelectionLabel*/ 4100 && input_1_value_value !== (input_1_value_value = /*item*/ ctx[103]\n\t\t\t? /*getSelectionLabel*/ ctx[12](/*item*/ ctx[103])\n\t\t\t: null)) {\n\t\t\t\tinput_1.value = input_1_value_value;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(input_1);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet span;\n\tlet t0;\n\tlet t1;\n\tlet t2;\n\tlet input_1;\n\tlet input_1_readonly_value;\n\tlet t3;\n\tlet t4;\n\tlet t5;\n\tlet t6;\n\tlet t7;\n\tlet t8;\n\tlet t9;\n\tlet div_class_value;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tlet if_block0 = /*isFocused*/ ctx[1] && create_if_block_10(ctx);\n\tlet if_block1 = /*Icon*/ ctx[17] && create_if_block_9(ctx);\n\tlet if_block2 = /*showMultiSelect*/ ctx[35] && create_if_block_8(ctx);\n\n\tlet input_1_levels = [\n\t\t{\n\t\t\treadOnly: input_1_readonly_value = !/*isSearchable*/ ctx[13]\n\t\t},\n\t\t/*_inputAttributes*/ ctx[31],\n\t\t{ placeholder: /*placeholderText*/ ctx[36] },\n\t\t{ style: /*inputStyles*/ ctx[14] },\n\t\t{ disabled: /*isDisabled*/ ctx[9] }\n\t];\n\n\tlet input_data = {};\n\n\tfor (let i = 0; i < input_1_levels.length; i += 1) {\n\t\tinput_data = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.assign)(input_data, input_1_levels[i]);\n\t}\n\n\tlet if_block3 = !/*isMulti*/ ctx[7] && /*showSelectedItem*/ ctx[29] && create_if_block_7(ctx);\n\tlet if_block4 = /*showClearIcon*/ ctx[37] && create_if_block_6(ctx);\n\tlet if_block5 = !/*showClearIcon*/ ctx[37] && (/*showIndicator*/ ctx[20] || /*showChevron*/ ctx[19] && !/*value*/ ctx[2] || !/*isSearchable*/ ctx[13] && !/*isDisabled*/ ctx[9] && !/*isWaiting*/ ctx[4] && (/*showSelectedItem*/ ctx[29] && !/*isClearable*/ ctx[15] || !/*showSelectedItem*/ ctx[29])) && create_if_block_4(ctx);\n\tlet if_block6 = /*isWaiting*/ ctx[4] && create_if_block_3(ctx);\n\tlet if_block7 = /*listOpen*/ ctx[5] && create_if_block_2(ctx);\n\tlet if_block8 = (!/*isMulti*/ ctx[7] || /*isMulti*/ ctx[7] && !/*showMultiSelect*/ ctx[35]) && create_if_block_1(ctx);\n\tlet if_block9 = /*isMulti*/ ctx[7] && /*showMultiSelect*/ ctx[35] && create_if_block(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tif (if_block0) if_block0.c();\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block1) if_block1.c();\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block2) if_block2.c();\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tinput_1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"input\");\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block3) if_block3.c();\n\t\t\tt4 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block4) if_block4.c();\n\t\t\tt5 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block5) if_block5.c();\n\t\t\tt6 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block6) if_block6.c();\n\t\t\tt7 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block7) if_block7.c();\n\t\t\tt8 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block8) if_block8.c();\n\t\t\tt9 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block9) if_block9.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"aria-live\", \"polite\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"aria-atomic\", \"false\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"aria-relevant\", \"additions text\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"a11yText svelte-15ybu53\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_attributes)(input_1, input_data);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(input_1, \"svelte-15ybu53\", true);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value = \"selectContainer \" + /*containerClasses*/ ctx[21] + \" svelte-15ybu53\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"style\", /*containerStyles*/ ctx[11]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"hasError\", /*hasError*/ ctx[10]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"multiSelect\", /*isMulti*/ ctx[7]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"disabled\", /*isDisabled*/ ctx[9]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"focused\", /*isFocused*/ ctx[1]);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, span);\n\t\t\tif (if_block0) if_block0.m(span, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t0);\n\t\t\tif (if_block1) if_block1.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t1);\n\t\t\tif (if_block2) if_block2.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, input_1);\n\t\t\tif (input_1.autofocus) input_1.focus();\n\t\t\t/*input_1_binding*/ ctx[82](input_1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input_1, /*filterText*/ ctx[3]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t3);\n\t\t\tif (if_block3) if_block3.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t4);\n\t\t\tif (if_block4) if_block4.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t5);\n\t\t\tif (if_block5) if_block5.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t6);\n\t\t\tif (if_block6) if_block6.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t7);\n\t\t\tif (if_block7) if_block7.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t8);\n\t\t\tif (if_block8) if_block8.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t9);\n\t\t\tif (if_block9) if_block9.m(div, null);\n\t\t\t/*div_binding*/ ctx[85](div);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"click\", /*handleWindowEvent*/ ctx[41]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"focusin\", /*handleWindowEvent*/ ctx[41]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"keydown\", /*handleKeyDown*/ ctx[39]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(input_1, \"focus\", /*handleFocus*/ ctx[40]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(input_1, \"input\", /*input_1_input_handler*/ ctx[83]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", /*handleClick*/ ctx[42])\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (/*isFocused*/ ctx[1]) {\n\t\t\t\tif (if_block0) {\n\t\t\t\t\tif_block0.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block0 = create_if_block_10(ctx);\n\t\t\t\t\tif_block0.c();\n\t\t\t\t\tif_block0.m(span, null);\n\t\t\t\t}\n\t\t\t} else if (if_block0) {\n\t\t\t\tif_block0.d(1);\n\t\t\t\tif_block0 = null;\n\t\t\t}\n\n\t\t\tif (/*Icon*/ ctx[17]) {\n\t\t\t\tif (if_block1) {\n\t\t\t\t\tif_block1.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty[0] & /*Icon*/ 131072) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block1 = create_if_block_9(ctx);\n\t\t\t\t\tif_block1.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1, 1);\n\t\t\t\t\tif_block1.m(div, t1);\n\t\t\t\t}\n\t\t\t} else if (if_block1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block1, 1, 1, () => {\n\t\t\t\t\tif_block1 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (/*showMultiSelect*/ ctx[35]) {\n\t\t\t\tif (if_block2) {\n\t\t\t\t\tif_block2.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty[1] & /*showMultiSelect*/ 16) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block2, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block2 = create_if_block_8(ctx);\n\t\t\t\t\tif_block2.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block2, 1);\n\t\t\t\t\tif_block2.m(div, t2);\n\t\t\t\t}\n\t\t\t} else if (if_block2) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block2, 1, 1, () => {\n\t\t\t\t\tif_block2 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_attributes)(input_1, input_data = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_spread_update)(input_1_levels, [\n\t\t\t\t(!current || dirty[0] & /*isSearchable*/ 8192 && input_1_readonly_value !== (input_1_readonly_value = !/*isSearchable*/ ctx[13])) && { readOnly: input_1_readonly_value },\n\t\t\t\tdirty[1] & /*_inputAttributes*/ 1 && /*_inputAttributes*/ ctx[31],\n\t\t\t\t(!current || dirty[1] & /*placeholderText*/ 32) && { placeholder: /*placeholderText*/ ctx[36] },\n\t\t\t\t(!current || dirty[0] & /*inputStyles*/ 16384) && { style: /*inputStyles*/ ctx[14] },\n\t\t\t\t(!current || dirty[0] & /*isDisabled*/ 512) && { disabled: /*isDisabled*/ ctx[9] }\n\t\t\t]));\n\n\t\t\tif (dirty[0] & /*filterText*/ 8 && input_1.value !== /*filterText*/ ctx[3]) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input_1, /*filterText*/ ctx[3]);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(input_1, \"svelte-15ybu53\", true);\n\n\t\t\tif (!/*isMulti*/ ctx[7] && /*showSelectedItem*/ ctx[29]) {\n\t\t\t\tif (if_block3) {\n\t\t\t\t\tif_block3.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty[0] & /*isMulti, showSelectedItem*/ 536871040) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block3, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block3 = create_if_block_7(ctx);\n\t\t\t\t\tif_block3.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block3, 1);\n\t\t\t\t\tif_block3.m(div, t4);\n\t\t\t\t}\n\t\t\t} else if (if_block3) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block3, 1, 1, () => {\n\t\t\t\t\tif_block3 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (/*showClearIcon*/ ctx[37]) {\n\t\t\t\tif (if_block4) {\n\t\t\t\t\tif_block4.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty[1] & /*showClearIcon*/ 64) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block4, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block4 = create_if_block_6(ctx);\n\t\t\t\t\tif_block4.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block4, 1);\n\t\t\t\t\tif_block4.m(div, t5);\n\t\t\t\t}\n\t\t\t} else if (if_block4) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block4, 1, 1, () => {\n\t\t\t\t\tif_block4 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (!/*showClearIcon*/ ctx[37] && (/*showIndicator*/ ctx[20] || /*showChevron*/ ctx[19] && !/*value*/ ctx[2] || !/*isSearchable*/ ctx[13] && !/*isDisabled*/ ctx[9] && !/*isWaiting*/ ctx[4] && (/*showSelectedItem*/ ctx[29] && !/*isClearable*/ ctx[15] || !/*showSelectedItem*/ ctx[29]))) {\n\t\t\t\tif (if_block5) {\n\t\t\t\t\tif_block5.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block5 = create_if_block_4(ctx);\n\t\t\t\t\tif_block5.c();\n\t\t\t\t\tif_block5.m(div, t6);\n\t\t\t\t}\n\t\t\t} else if (if_block5) {\n\t\t\t\tif_block5.d(1);\n\t\t\t\tif_block5 = null;\n\t\t\t}\n\n\t\t\tif (/*isWaiting*/ ctx[4]) {\n\t\t\t\tif (if_block6) {\n\t\t\t\t\t\n\t\t\t\t} else {\n\t\t\t\t\tif_block6 = create_if_block_3(ctx);\n\t\t\t\t\tif_block6.c();\n\t\t\t\t\tif_block6.m(div, t7);\n\t\t\t\t}\n\t\t\t} else if (if_block6) {\n\t\t\t\tif_block6.d(1);\n\t\t\t\tif_block6 = null;\n\t\t\t}\n\n\t\t\tif (/*listOpen*/ ctx[5]) {\n\t\t\t\tif (if_block7) {\n\t\t\t\t\tif_block7.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty[0] & /*listOpen*/ 32) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block7, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block7 = create_if_block_2(ctx);\n\t\t\t\t\tif_block7.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block7, 1);\n\t\t\t\t\tif_block7.m(div, t8);\n\t\t\t\t}\n\t\t\t} else if (if_block7) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block7, 1, 1, () => {\n\t\t\t\t\tif_block7 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (!/*isMulti*/ ctx[7] || /*isMulti*/ ctx[7] && !/*showMultiSelect*/ ctx[35]) {\n\t\t\t\tif (if_block8) {\n\t\t\t\t\tif_block8.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block8 = create_if_block_1(ctx);\n\t\t\t\t\tif_block8.c();\n\t\t\t\t\tif_block8.m(div, t9);\n\t\t\t\t}\n\t\t\t} else if (if_block8) {\n\t\t\t\tif_block8.d(1);\n\t\t\t\tif_block8 = null;\n\t\t\t}\n\n\t\t\tif (/*isMulti*/ ctx[7] && /*showMultiSelect*/ ctx[35]) {\n\t\t\t\tif (if_block9) {\n\t\t\t\t\tif_block9.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block9 = create_if_block(ctx);\n\t\t\t\t\tif_block9.c();\n\t\t\t\t\tif_block9.m(div, null);\n\t\t\t\t}\n\t\t\t} else if (if_block9) {\n\t\t\t\tif_block9.d(1);\n\t\t\t\tif_block9 = null;\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerClasses*/ 2097152 && div_class_value !== (div_class_value = \"selectContainer \" + /*containerClasses*/ ctx[21] + \" svelte-15ybu53\")) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerStyles*/ 2048) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"style\", /*containerStyles*/ ctx[11]);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerClasses, hasError*/ 2098176) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"hasError\", /*hasError*/ ctx[10]);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerClasses, isMulti*/ 2097280) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"multiSelect\", /*isMulti*/ ctx[7]);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerClasses, isDisabled*/ 2097664) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"disabled\", /*isDisabled*/ ctx[9]);\n\t\t\t}\n\n\t\t\tif (!current || dirty[0] & /*containerClasses, isFocused*/ 2097154) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.toggle_class)(div, \"focused\", /*isFocused*/ ctx[1]);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block4);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block7);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block4);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block7);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (if_block0) if_block0.d();\n\t\t\tif (if_block1) if_block1.d();\n\t\t\tif (if_block2) if_block2.d();\n\t\t\t/*input_1_binding*/ ctx[82](null);\n\t\t\tif (if_block3) if_block3.d();\n\t\t\tif (if_block4) if_block4.d();\n\t\t\tif (if_block5) if_block5.d();\n\t\t\tif (if_block6) if_block6.d();\n\t\t\tif (if_block7) if_block7.d();\n\t\t\tif (if_block8) if_block8.d();\n\t\t\tif (if_block9) if_block9.d();\n\t\t\t/*div_binding*/ ctx[85](null);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction convertStringItemsToObjects(_items) {\n\treturn _items.map((item, index) => {\n\t\treturn { index, value: item, label: `${item}` };\n\t});\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet filteredItems;\n\tlet showSelectedItem;\n\tlet showClearIcon;\n\tlet placeholderText;\n\tlet showMultiSelect;\n\tlet listProps;\n\tlet ariaSelection;\n\tlet ariaContext;\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\tlet { id = null } = $$props;\n\tlet { container = undefined } = $$props;\n\tlet { input = undefined } = $$props;\n\tlet { isMulti = false } = $$props;\n\tlet { multiFullItemClearable = false } = $$props;\n\tlet { isDisabled = false } = $$props;\n\tlet { isCreatable = false } = $$props;\n\tlet { isFocused = false } = $$props;\n\tlet { value = null } = $$props;\n\tlet { filterText = '' } = $$props;\n\tlet { placeholder = 'Select...' } = $$props;\n\tlet { placeholderAlwaysShow = false } = $$props;\n\tlet { items = null } = $$props;\n\tlet { itemFilter = (label, filterText, option) => `${label}`.toLowerCase().includes(filterText.toLowerCase()) } = $$props;\n\tlet { groupBy = undefined } = $$props;\n\tlet { groupFilter = groups => groups } = $$props;\n\tlet { isGroupHeaderSelectable = false } = $$props;\n\n\tlet { getGroupHeaderLabel = option => {\n\t\treturn option[labelIdentifier] || option.id;\n\t} } = $$props;\n\n\tlet { labelIdentifier = 'label' } = $$props;\n\n\tlet { getOptionLabel = (option, filterText) => {\n\t\treturn option.isCreator\n\t\t? `Create \\\"${filterText}\\\"`\n\t\t: option[labelIdentifier];\n\t} } = $$props;\n\n\tlet { optionIdentifier = 'value' } = $$props;\n\tlet { loadOptions = undefined } = $$props;\n\tlet { hasError = false } = $$props;\n\tlet { containerStyles = '' } = $$props;\n\n\tlet { getSelectionLabel = option => {\n\t\tif (option) return option[labelIdentifier]; else return null;\n\t} } = $$props;\n\n\tlet { createGroupHeaderItem = groupValue => {\n\t\treturn { value: groupValue, label: groupValue };\n\t} } = $$props;\n\n\tlet { createItem = filterText => {\n\t\treturn { value: filterText, label: filterText };\n\t} } = $$props;\n\n\tconst getFilteredItems = () => {\n\t\treturn filteredItems;\n\t};\n\n\tlet { isSearchable = true } = $$props;\n\tlet { inputStyles = '' } = $$props;\n\tlet { isClearable = true } = $$props;\n\tlet { isWaiting = false } = $$props;\n\tlet { listPlacement = 'auto' } = $$props;\n\tlet { listOpen = false } = $$props;\n\tlet { isVirtualList = false } = $$props;\n\tlet { loadOptionsInterval = 300 } = $$props;\n\tlet { noOptionsMessage = 'No options' } = $$props;\n\tlet { hideEmptyState = false } = $$props;\n\tlet { inputAttributes = {} } = $$props;\n\tlet { listAutoWidth = true } = $$props;\n\tlet { itemHeight = 40 } = $$props;\n\tlet { Icon = undefined } = $$props;\n\tlet { iconProps = {} } = $$props;\n\tlet { showChevron = false } = $$props;\n\tlet { showIndicator = false } = $$props;\n\tlet { containerClasses = '' } = $$props;\n\tlet { indicatorSvg = undefined } = $$props;\n\tlet { listOffset = 5 } = $$props;\n\tlet { ClearIcon = _ClearIcon_svelte__WEBPACK_IMPORTED_MODULE_7__[\"default\"] } = $$props;\n\tlet { Item = _Item_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"] } = $$props;\n\tlet { List = _List_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"] } = $$props;\n\tlet { Selection = _Selection_svelte__WEBPACK_IMPORTED_MODULE_4__[\"default\"] } = $$props;\n\tlet { MultiSelection = _MultiSelection_svelte__WEBPACK_IMPORTED_MODULE_5__[\"default\"] } = $$props;\n\tlet { VirtualList = _VirtualList_svelte__WEBPACK_IMPORTED_MODULE_6__[\"default\"] } = $$props;\n\n\tfunction filterMethod(args) {\n\t\tif (args.loadOptions && args.filterText.length > 0) return;\n\t\tif (!args.items) return [];\n\n\t\tif (args.items && args.items.length > 0 && typeof args.items[0] !== 'object') {\n\t\t\targs.items = convertStringItemsToObjects(args.items);\n\t\t}\n\n\t\tlet filterResults = args.items.filter(item => {\n\t\t\tlet matchesFilter = itemFilter(getOptionLabel(item, args.filterText), args.filterText, item);\n\n\t\t\tif (matchesFilter && args.isMulti && args.value && Array.isArray(args.value)) {\n\t\t\t\tmatchesFilter = !args.value.some(x => {\n\t\t\t\t\treturn x[args.optionIdentifier] === item[args.optionIdentifier];\n\t\t\t\t});\n\t\t\t}\n\n\t\t\treturn matchesFilter;\n\t\t});\n\n\t\tif (args.groupBy) {\n\t\t\tfilterResults = filterGroupedItems(filterResults);\n\t\t}\n\n\t\tif (args.isCreatable) {\n\t\t\tfilterResults = addCreatableItem(filterResults, args.filterText);\n\t\t}\n\n\t\treturn filterResults;\n\t}\n\n\tfunction addCreatableItem(_items, _filterText) {\n\t\tif (_filterText.length === 0) return _items;\n\t\tconst itemToCreate = createItem(_filterText);\n\t\tif (_items[0] && _filterText === _items[0][labelIdentifier]) return _items;\n\t\titemToCreate.isCreator = true;\n\t\treturn [..._items, itemToCreate];\n\t}\n\n\tlet { selectedValue = null } = $$props;\n\tlet activeValue;\n\tlet prev_value;\n\tlet prev_filterText;\n\tlet prev_isFocused;\n\tlet prev_isMulti;\n\tlet hoverItemIndex;\n\n\tconst getItems = (0,_utils_debounce__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(\n\t\tasync () => {\n\t\t\t$$invalidate(4, isWaiting = true);\n\n\t\t\tlet res = await loadOptions(filterText).catch(err => {\n\t\t\t\tconsole.warn('svelte-select loadOptions error :>> ', err);\n\t\t\t\tdispatch('error', { type: 'loadOptions', details: err });\n\t\t\t});\n\n\t\t\tif (res && !res.cancelled) {\n\t\t\t\tif (res) {\n\t\t\t\t\tif (res && res.length > 0 && typeof res[0] !== 'object') {\n\t\t\t\t\t\tres = convertStringItemsToObjects(res);\n\t\t\t\t\t}\n\n\t\t\t\t\t$$invalidate(81, filteredItems = [...res]);\n\t\t\t\t\tdispatch('loaded', { items: filteredItems });\n\t\t\t\t} else {\n\t\t\t\t\t$$invalidate(81, filteredItems = []);\n\t\t\t\t}\n\n\t\t\t\tif (isCreatable) {\n\t\t\t\t\t$$invalidate(81, filteredItems = addCreatableItem(filteredItems, filterText));\n\t\t\t\t}\n\n\t\t\t\t$$invalidate(4, isWaiting = false);\n\t\t\t\t$$invalidate(1, isFocused = true);\n\t\t\t\t$$invalidate(5, listOpen = true);\n\t\t\t}\n\t\t},\n\t\tloadOptionsInterval\n\t);\n\n\tfunction setValue() {\n\t\tif (typeof value === 'string') {\n\t\t\t$$invalidate(2, value = { [optionIdentifier]: value, label: value });\n\t\t} else if (isMulti && Array.isArray(value) && value.length > 0) {\n\t\t\t$$invalidate(2, value = value.map(item => typeof item === 'string'\n\t\t\t? { value: item, label: item }\n\t\t\t: item));\n\t\t}\n\t}\n\n\tlet _inputAttributes;\n\n\tfunction assignInputAttributes() {\n\t\t$$invalidate(31, _inputAttributes = Object.assign(\n\t\t\t{\n\t\t\t\tautocapitalize: 'none',\n\t\t\t\tautocomplete: 'off',\n\t\t\t\tautocorrect: 'off',\n\t\t\t\tspellcheck: false,\n\t\t\t\ttabindex: 0,\n\t\t\t\ttype: 'text',\n\t\t\t\t'aria-autocomplete': 'list'\n\t\t\t},\n\t\t\tinputAttributes\n\t\t));\n\n\t\tif (id) {\n\t\t\t$$invalidate(31, _inputAttributes.id = id, _inputAttributes);\n\t\t}\n\n\t\tif (!isSearchable) {\n\t\t\t$$invalidate(31, _inputAttributes.readonly = true, _inputAttributes);\n\t\t}\n\t}\n\n\tfunction filterGroupedItems(_items) {\n\t\tconst groupValues = [];\n\t\tconst groups = {};\n\n\t\t_items.forEach(item => {\n\t\t\tconst groupValue = groupBy(item);\n\n\t\t\tif (!groupValues.includes(groupValue)) {\n\t\t\t\tgroupValues.push(groupValue);\n\t\t\t\tgroups[groupValue] = [];\n\n\t\t\t\tif (groupValue) {\n\t\t\t\t\tgroups[groupValue].push(Object.assign(createGroupHeaderItem(groupValue, item), {\n\t\t\t\t\t\tid: groupValue,\n\t\t\t\t\t\tisGroupHeader: true,\n\t\t\t\t\t\tisSelectable: isGroupHeaderSelectable\n\t\t\t\t\t}));\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tgroups[groupValue].push(Object.assign({ isGroupItem: !!groupValue }, item));\n\t\t});\n\n\t\tconst sortedGroupedItems = [];\n\n\t\tgroupFilter(groupValues).forEach(groupValue => {\n\t\t\tsortedGroupedItems.push(...groups[groupValue]);\n\t\t});\n\n\t\treturn sortedGroupedItems;\n\t}\n\n\tfunction dispatchSelectedItem() {\n\t\tif (isMulti) {\n\t\t\tif (JSON.stringify(value) !== JSON.stringify(prev_value)) {\n\t\t\t\tif (checkValueForDuplicates()) {\n\t\t\t\t\tdispatch('select', value);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\treturn;\n\t\t}\n\n\t\tif (!prev_value || JSON.stringify(value[optionIdentifier]) !== JSON.stringify(prev_value[optionIdentifier])) {\n\t\t\tdispatch('select', value);\n\t\t}\n\t}\n\n\tfunction setupFocus() {\n\t\tif (isFocused || listOpen) {\n\t\t\thandleFocus();\n\t\t} else {\n\t\t\tif (input) input.blur();\n\t\t}\n\t}\n\n\tfunction setupMulti() {\n\t\tif (value) {\n\t\t\tif (Array.isArray(value)) {\n\t\t\t\t$$invalidate(2, value = [...value]);\n\t\t\t} else {\n\t\t\t\t$$invalidate(2, value = [value]);\n\t\t\t}\n\t\t}\n\t}\n\n\tfunction setupSingle() {\n\t\tif (value) $$invalidate(2, value = null);\n\t}\n\n\tfunction setupFilterText() {\n\t\tif (filterText.length === 0) return;\n\t\t$$invalidate(1, isFocused = true);\n\t\t$$invalidate(5, listOpen = true);\n\n\t\tif (loadOptions) {\n\t\t\tgetItems();\n\t\t} else {\n\t\t\t$$invalidate(5, listOpen = true);\n\n\t\t\tif (isMulti) {\n\t\t\t\t$$invalidate(30, activeValue = undefined);\n\t\t\t}\n\t\t}\n\t}\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.beforeUpdate)(async () => {\n\t\t$$invalidate(77, prev_value = value);\n\t\t$$invalidate(78, prev_filterText = filterText);\n\t\t$$invalidate(79, prev_isFocused = isFocused);\n\t\t$$invalidate(80, prev_isMulti = isMulti);\n\t});\n\n\tfunction checkValueForDuplicates() {\n\t\tlet noDuplicates = true;\n\n\t\tif (value) {\n\t\t\tconst ids = [];\n\t\t\tconst uniqueValues = [];\n\n\t\t\tvalue.forEach(val => {\n\t\t\t\tif (!ids.includes(val[optionIdentifier])) {\n\t\t\t\t\tids.push(val[optionIdentifier]);\n\t\t\t\t\tuniqueValues.push(val);\n\t\t\t\t} else {\n\t\t\t\t\tnoDuplicates = false;\n\t\t\t\t}\n\t\t\t});\n\n\t\t\tif (!noDuplicates) $$invalidate(2, value = uniqueValues);\n\t\t}\n\n\t\treturn noDuplicates;\n\t}\n\n\tfunction findItem(selection) {\n\t\tlet matchTo = selection\n\t\t? selection[optionIdentifier]\n\t\t: value[optionIdentifier];\n\n\t\treturn items.find(item => item[optionIdentifier] === matchTo);\n\t}\n\n\tfunction updateValueDisplay(items) {\n\t\tif (!items || items.length === 0 || items.some(item => typeof item !== 'object')) return;\n\n\t\tif (!value || (isMulti\n\t\t? value.some(selection => !selection || !selection[optionIdentifier])\n\t\t: !value[optionIdentifier])) return;\n\n\t\tif (Array.isArray(value)) {\n\t\t\t$$invalidate(2, value = value.map(selection => findItem(selection) || selection));\n\t\t} else {\n\t\t\t$$invalidate(2, value = findItem() || value);\n\t\t}\n\t}\n\n\tfunction handleMultiItemClear(event) {\n\t\tconst { detail } = event;\n\t\tconst itemToRemove = value[detail ? detail.i : value.length - 1];\n\n\t\tif (value.length === 1) {\n\t\t\t$$invalidate(2, value = undefined);\n\t\t} else {\n\t\t\t$$invalidate(2, value = value.filter(item => {\n\t\t\t\treturn item !== itemToRemove;\n\t\t\t}));\n\t\t}\n\n\t\tdispatch('clear', itemToRemove);\n\t}\n\n\tfunction handleKeyDown(e) {\n\t\tif (!isFocused) return;\n\n\t\tswitch (e.key) {\n\t\t\tcase 'ArrowDown':\n\t\t\t\te.preventDefault();\n\t\t\t\t$$invalidate(5, listOpen = true);\n\t\t\t\t$$invalidate(30, activeValue = undefined);\n\t\t\t\tbreak;\n\t\t\tcase 'ArrowUp':\n\t\t\t\te.preventDefault();\n\t\t\t\t$$invalidate(5, listOpen = true);\n\t\t\t\t$$invalidate(30, activeValue = undefined);\n\t\t\t\tbreak;\n\t\t\tcase 'Tab':\n\t\t\t\tif (!listOpen) $$invalidate(1, isFocused = false);\n\t\t\t\tbreak;\n\t\t\tcase 'Backspace':\n\t\t\t\tif (!isMulti || filterText.length > 0) return;\n\t\t\t\tif (isMulti && value && value.length > 0) {\n\t\t\t\t\thandleMultiItemClear(activeValue !== undefined\n\t\t\t\t\t? activeValue\n\t\t\t\t\t: value.length - 1);\n\n\t\t\t\t\tif (activeValue === 0 || activeValue === undefined) break;\n\t\t\t\t\t$$invalidate(30, activeValue = value.length > activeValue ? activeValue - 1 : undefined);\n\t\t\t\t}\n\t\t\t\tbreak;\n\t\t\tcase 'ArrowLeft':\n\t\t\t\tif (!isMulti || filterText.length > 0) return;\n\t\t\t\tif (activeValue === undefined) {\n\t\t\t\t\t$$invalidate(30, activeValue = value.length - 1);\n\t\t\t\t} else if (value.length > activeValue && activeValue !== 0) {\n\t\t\t\t\t$$invalidate(30, activeValue -= 1);\n\t\t\t\t}\n\t\t\t\tbreak;\n\t\t\tcase 'ArrowRight':\n\t\t\t\tif (!isMulti || filterText.length > 0 || activeValue === undefined) return;\n\t\t\t\tif (activeValue === value.length - 1) {\n\t\t\t\t\t$$invalidate(30, activeValue = undefined);\n\t\t\t\t} else if (activeValue < value.length - 1) {\n\t\t\t\t\t$$invalidate(30, activeValue += 1);\n\t\t\t\t}\n\t\t\t\tbreak;\n\t\t}\n\t}\n\n\tfunction handleFocus() {\n\t\t$$invalidate(1, isFocused = true);\n\t\tif (input) input.focus();\n\t}\n\n\tfunction handleWindowEvent(event) {\n\t\tif (!container) return;\n\n\t\tconst eventTarget = event.path && event.path.length > 0\n\t\t? event.path[0]\n\t\t: event.target;\n\n\t\tif (container.contains(eventTarget)) return;\n\t\t$$invalidate(1, isFocused = false);\n\t\t$$invalidate(5, listOpen = false);\n\t\t$$invalidate(30, activeValue = undefined);\n\t\tif (input) input.blur();\n\t}\n\n\tfunction handleClick() {\n\t\tif (isDisabled) return;\n\t\t$$invalidate(1, isFocused = true);\n\t\t$$invalidate(5, listOpen = !listOpen);\n\t}\n\n\tfunction handleClear() {\n\t\t$$invalidate(2, value = undefined);\n\t\t$$invalidate(5, listOpen = false);\n\t\tdispatch('clear', value);\n\t\thandleFocus();\n\t}\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.onMount)(() => {\n\t\tif (isFocused && input) input.focus();\n\t});\n\n\tfunction itemSelected(event) {\n\t\tconst { detail } = event;\n\n\t\tif (detail) {\n\t\t\t$$invalidate(3, filterText = '');\n\t\t\tconst item = Object.assign({}, detail);\n\n\t\t\tif (!item.isGroupHeader || item.isSelectable) {\n\t\t\t\tif (isMulti) {\n\t\t\t\t\t$$invalidate(2, value = value ? value.concat([item]) : [item]);\n\t\t\t\t} else {\n\t\t\t\t\t$$invalidate(2, value = item);\n\t\t\t\t}\n\n\t\t\t\t$$invalidate(2, value);\n\n\t\t\t\tsetTimeout(() => {\n\t\t\t\t\t$$invalidate(5, listOpen = false);\n\t\t\t\t\t$$invalidate(30, activeValue = undefined);\n\t\t\t\t});\n\t\t\t}\n\t\t}\n\t}\n\n\tfunction itemCreated(event) {\n\t\tconst { detail } = event;\n\n\t\tif (isMulti) {\n\t\t\t$$invalidate(2, value = value || []);\n\t\t\t$$invalidate(2, value = [...value, createItem(detail)]);\n\t\t} else {\n\t\t\t$$invalidate(2, value = createItem(detail));\n\t\t}\n\n\t\tdispatch('itemCreated', detail);\n\t\t$$invalidate(3, filterText = '');\n\t\t$$invalidate(5, listOpen = false);\n\t\t$$invalidate(30, activeValue = undefined);\n\t}\n\n\tfunction closeList() {\n\t\t$$invalidate(3, filterText = '');\n\t\t$$invalidate(5, listOpen = false);\n\t}\n\n\tlet { ariaValues = values => {\n\t\treturn `Option ${values}, selected.`;\n\t} } = $$props;\n\n\tlet { ariaListOpen = (label, count) => {\n\t\treturn `You are currently focused on option ${label}. There are ${count} results available.`;\n\t} } = $$props;\n\n\tlet { ariaFocused = () => {\n\t\treturn `Select is focused, type to refine list, press down to open the menu.`;\n\t} } = $$props;\n\n\tfunction handleAriaSelection() {\n\t\tlet selected = undefined;\n\n\t\tif (isMulti && value.length > 0) {\n\t\t\tselected = value.map(v => getSelectionLabel(v)).join(', ');\n\t\t} else {\n\t\t\tselected = getSelectionLabel(value);\n\t\t}\n\n\t\treturn ariaValues(selected);\n\t}\n\n\tfunction handleAriaContent() {\n\t\tif (!isFocused || !filteredItems || filteredItems.length === 0) return '';\n\t\tlet _item = filteredItems[hoverItemIndex];\n\n\t\tif (listOpen && _item) {\n\t\t\tlet label = getSelectionLabel(_item);\n\t\t\tlet count = filteredItems ? filteredItems.length : 0;\n\t\t\treturn ariaListOpen(label, count);\n\t\t} else {\n\t\t\treturn ariaFocused();\n\t\t}\n\t}\n\n\tfunction input_1_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tinput = $$value;\n\t\t\t$$invalidate(6, input);\n\t\t});\n\t}\n\n\tfunction input_1_input_handler() {\n\t\tfilterText = this.value;\n\t\t$$invalidate(3, filterText);\n\t}\n\n\tfunction switch_instance_hoverItemIndex_binding(value) {\n\t\thoverItemIndex = value;\n\t\t$$invalidate(28, hoverItemIndex);\n\t}\n\n\tfunction div_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tcontainer = $$value;\n\t\t\t$$invalidate(0, container);\n\t\t});\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('id' in $$props) $$invalidate(46, id = $$props.id);\n\t\tif ('container' in $$props) $$invalidate(0, container = $$props.container);\n\t\tif ('input' in $$props) $$invalidate(6, input = $$props.input);\n\t\tif ('isMulti' in $$props) $$invalidate(7, isMulti = $$props.isMulti);\n\t\tif ('multiFullItemClearable' in $$props) $$invalidate(8, multiFullItemClearable = $$props.multiFullItemClearable);\n\t\tif ('isDisabled' in $$props) $$invalidate(9, isDisabled = $$props.isDisabled);\n\t\tif ('isCreatable' in $$props) $$invalidate(47, isCreatable = $$props.isCreatable);\n\t\tif ('isFocused' in $$props) $$invalidate(1, isFocused = $$props.isFocused);\n\t\tif ('value' in $$props) $$invalidate(2, value = $$props.value);\n\t\tif ('filterText' in $$props) $$invalidate(3, filterText = $$props.filterText);\n\t\tif ('placeholder' in $$props) $$invalidate(48, placeholder = $$props.placeholder);\n\t\tif ('placeholderAlwaysShow' in $$props) $$invalidate(49, placeholderAlwaysShow = $$props.placeholderAlwaysShow);\n\t\tif ('items' in $$props) $$invalidate(50, items = $$props.items);\n\t\tif ('itemFilter' in $$props) $$invalidate(51, itemFilter = $$props.itemFilter);\n\t\tif ('groupBy' in $$props) $$invalidate(52, groupBy = $$props.groupBy);\n\t\tif ('groupFilter' in $$props) $$invalidate(53, groupFilter = $$props.groupFilter);\n\t\tif ('isGroupHeaderSelectable' in $$props) $$invalidate(54, isGroupHeaderSelectable = $$props.isGroupHeaderSelectable);\n\t\tif ('getGroupHeaderLabel' in $$props) $$invalidate(55, getGroupHeaderLabel = $$props.getGroupHeaderLabel);\n\t\tif ('labelIdentifier' in $$props) $$invalidate(56, labelIdentifier = $$props.labelIdentifier);\n\t\tif ('getOptionLabel' in $$props) $$invalidate(57, getOptionLabel = $$props.getOptionLabel);\n\t\tif ('optionIdentifier' in $$props) $$invalidate(58, optionIdentifier = $$props.optionIdentifier);\n\t\tif ('loadOptions' in $$props) $$invalidate(59, loadOptions = $$props.loadOptions);\n\t\tif ('hasError' in $$props) $$invalidate(10, hasError = $$props.hasError);\n\t\tif ('containerStyles' in $$props) $$invalidate(11, containerStyles = $$props.containerStyles);\n\t\tif ('getSelectionLabel' in $$props) $$invalidate(12, getSelectionLabel = $$props.getSelectionLabel);\n\t\tif ('createGroupHeaderItem' in $$props) $$invalidate(60, createGroupHeaderItem = $$props.createGroupHeaderItem);\n\t\tif ('createItem' in $$props) $$invalidate(61, createItem = $$props.createItem);\n\t\tif ('isSearchable' in $$props) $$invalidate(13, isSearchable = $$props.isSearchable);\n\t\tif ('inputStyles' in $$props) $$invalidate(14, inputStyles = $$props.inputStyles);\n\t\tif ('isClearable' in $$props) $$invalidate(15, isClearable = $$props.isClearable);\n\t\tif ('isWaiting' in $$props) $$invalidate(4, isWaiting = $$props.isWaiting);\n\t\tif ('listPlacement' in $$props) $$invalidate(63, listPlacement = $$props.listPlacement);\n\t\tif ('listOpen' in $$props) $$invalidate(5, listOpen = $$props.listOpen);\n\t\tif ('isVirtualList' in $$props) $$invalidate(64, isVirtualList = $$props.isVirtualList);\n\t\tif ('loadOptionsInterval' in $$props) $$invalidate(65, loadOptionsInterval = $$props.loadOptionsInterval);\n\t\tif ('noOptionsMessage' in $$props) $$invalidate(66, noOptionsMessage = $$props.noOptionsMessage);\n\t\tif ('hideEmptyState' in $$props) $$invalidate(67, hideEmptyState = $$props.hideEmptyState);\n\t\tif ('inputAttributes' in $$props) $$invalidate(16, inputAttributes = $$props.inputAttributes);\n\t\tif ('listAutoWidth' in $$props) $$invalidate(68, listAutoWidth = $$props.listAutoWidth);\n\t\tif ('itemHeight' in $$props) $$invalidate(69, itemHeight = $$props.itemHeight);\n\t\tif ('Icon' in $$props) $$invalidate(17, Icon = $$props.Icon);\n\t\tif ('iconProps' in $$props) $$invalidate(18, iconProps = $$props.iconProps);\n\t\tif ('showChevron' in $$props) $$invalidate(19, showChevron = $$props.showChevron);\n\t\tif ('showIndicator' in $$props) $$invalidate(20, showIndicator = $$props.showIndicator);\n\t\tif ('containerClasses' in $$props) $$invalidate(21, containerClasses = $$props.containerClasses);\n\t\tif ('indicatorSvg' in $$props) $$invalidate(22, indicatorSvg = $$props.indicatorSvg);\n\t\tif ('listOffset' in $$props) $$invalidate(70, listOffset = $$props.listOffset);\n\t\tif ('ClearIcon' in $$props) $$invalidate(23, ClearIcon = $$props.ClearIcon);\n\t\tif ('Item' in $$props) $$invalidate(71, Item = $$props.Item);\n\t\tif ('List' in $$props) $$invalidate(24, List = $$props.List);\n\t\tif ('Selection' in $$props) $$invalidate(25, Selection = $$props.Selection);\n\t\tif ('MultiSelection' in $$props) $$invalidate(26, MultiSelection = $$props.MultiSelection);\n\t\tif ('VirtualList' in $$props) $$invalidate(72, VirtualList = $$props.VirtualList);\n\t\tif ('selectedValue' in $$props) $$invalidate(73, selectedValue = $$props.selectedValue);\n\t\tif ('ariaValues' in $$props) $$invalidate(74, ariaValues = $$props.ariaValues);\n\t\tif ('ariaListOpen' in $$props) $$invalidate(75, ariaListOpen = $$props.ariaListOpen);\n\t\tif ('ariaFocused' in $$props) $$invalidate(76, ariaFocused = $$props.ariaFocused);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty[0] & /*filterText, value, isMulti*/ 140 | $$self.$$.dirty[1] & /*loadOptions, items, optionIdentifier, groupBy, isCreatable*/ 405340160) {\n\t\t\t$: $$invalidate(81, filteredItems = filterMethod({\n\t\t\t\tloadOptions,\n\t\t\t\tfilterText,\n\t\t\t\titems,\n\t\t\t\tvalue,\n\t\t\t\tisMulti,\n\t\t\t\toptionIdentifier,\n\t\t\t\tgroupBy,\n\t\t\t\tisCreatable\n\t\t\t}));\n\t\t}\n\n\t\tif ($$self.$$.dirty[2] & /*selectedValue*/ 2048) {\n\t\t\t$: {\n\t\t\t\tif (selectedValue) console.warn('selectedValue is no longer used. Please use value instead.');\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[1] & /*items*/ 524288) {\n\t\t\t$: updateValueDisplay(items);\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*value*/ 4) {\n\t\t\t$: {\n\t\t\t\tif (value) setValue();\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*inputAttributes, isSearchable*/ 73728) {\n\t\t\t$: {\n\t\t\t\tif (inputAttributes || !isSearchable) assignInputAttributes();\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*isMulti*/ 128 | $$self.$$.dirty[2] & /*prev_isMulti*/ 262144) {\n\t\t\t$: {\n\t\t\t\tif (isMulti) {\n\t\t\t\t\tsetupMulti();\n\t\t\t\t}\n\n\t\t\t\tif (prev_isMulti && !isMulti) {\n\t\t\t\t\tsetupSingle();\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*isMulti, value*/ 132) {\n\t\t\t$: {\n\t\t\t\tif (isMulti && value && value.length > 1) {\n\t\t\t\t\tcheckValueForDuplicates();\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*value*/ 4) {\n\t\t\t$: {\n\t\t\t\tif (value) dispatchSelectedItem();\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*value, isMulti*/ 132 | $$self.$$.dirty[2] & /*prev_value*/ 32768) {\n\t\t\t$: {\n\t\t\t\tif (!value && isMulti && prev_value) {\n\t\t\t\t\tdispatch('select', value);\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*isFocused*/ 2 | $$self.$$.dirty[2] & /*prev_isFocused*/ 131072) {\n\t\t\t$: {\n\t\t\t\tif (isFocused !== prev_isFocused) {\n\t\t\t\t\tsetupFocus();\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*filterText*/ 8 | $$self.$$.dirty[2] & /*prev_filterText*/ 65536) {\n\t\t\t$: {\n\t\t\t\tif (filterText !== prev_filterText) {\n\t\t\t\t\tsetupFilterText();\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*value, filterText*/ 12) {\n\t\t\t$: $$invalidate(29, showSelectedItem = value && filterText.length === 0);\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*showSelectedItem, isClearable, isDisabled, isWaiting*/ 536904208) {\n\t\t\t$: $$invalidate(37, showClearIcon = showSelectedItem && isClearable && !isDisabled && !isWaiting);\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*isMulti, value*/ 132 | $$self.$$.dirty[1] & /*placeholderAlwaysShow, placeholder*/ 393216) {\n\t\t\t$: $$invalidate(36, placeholderText = placeholderAlwaysShow && isMulti\n\t\t\t? placeholder\n\t\t\t: value ? '' : placeholder);\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*isMulti, value*/ 132) {\n\t\t\t$: $$invalidate(35, showMultiSelect = isMulti && value && value.length > 0);\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*filterText, value, isMulti, container*/ 141 | $$self.$$.dirty[1] & /*optionIdentifier, getGroupHeaderLabel, getOptionLabel*/ 218103808 | $$self.$$.dirty[2] & /*Item, noOptionsMessage, hideEmptyState, isVirtualList, VirtualList, filteredItems, itemHeight, listPlacement, listAutoWidth, listOffset*/ 526326) {\n\t\t\t$: $$invalidate(34, listProps = {\n\t\t\t\tItem,\n\t\t\t\tfilterText,\n\t\t\t\toptionIdentifier,\n\t\t\t\tnoOptionsMessage,\n\t\t\t\thideEmptyState,\n\t\t\t\tisVirtualList,\n\t\t\t\tVirtualList,\n\t\t\t\tvalue,\n\t\t\t\tisMulti,\n\t\t\t\tgetGroupHeaderLabel,\n\t\t\t\titems: filteredItems,\n\t\t\t\titemHeight,\n\t\t\t\tgetOptionLabel,\n\t\t\t\tlistPlacement,\n\t\t\t\tparent: container,\n\t\t\t\tlistAutoWidth,\n\t\t\t\tlistOffset\n\t\t\t});\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*value, isMulti*/ 132) {\n\t\t\t$: $$invalidate(33, ariaSelection = value ? handleAriaSelection(isMulti) : '');\n\t\t}\n\n\t\tif ($$self.$$.dirty[0] & /*hoverItemIndex, isFocused, listOpen*/ 268435490 | $$self.$$.dirty[2] & /*filteredItems*/ 524288) {\n\t\t\t$: $$invalidate(32, ariaContext = handleAriaContent(filteredItems, hoverItemIndex, isFocused, listOpen));\n\t\t}\n\t};\n\n\treturn [\n\t\tcontainer,\n\t\tisFocused,\n\t\tvalue,\n\t\tfilterText,\n\t\tisWaiting,\n\t\tlistOpen,\n\t\tinput,\n\t\tisMulti,\n\t\tmultiFullItemClearable,\n\t\tisDisabled,\n\t\thasError,\n\t\tcontainerStyles,\n\t\tgetSelectionLabel,\n\t\tisSearchable,\n\t\tinputStyles,\n\t\tisClearable,\n\t\tinputAttributes,\n\t\tIcon,\n\t\ticonProps,\n\t\tshowChevron,\n\t\tshowIndicator,\n\t\tcontainerClasses,\n\t\tindicatorSvg,\n\t\tClearIcon,\n\t\tList,\n\t\tSelection,\n\t\tMultiSelection,\n\t\thandleClear,\n\t\thoverItemIndex,\n\t\tshowSelectedItem,\n\t\tactiveValue,\n\t\t_inputAttributes,\n\t\tariaContext,\n\t\tariaSelection,\n\t\tlistProps,\n\t\tshowMultiSelect,\n\t\tplaceholderText,\n\t\tshowClearIcon,\n\t\thandleMultiItemClear,\n\t\thandleKeyDown,\n\t\thandleFocus,\n\t\thandleWindowEvent,\n\t\thandleClick,\n\t\titemSelected,\n\t\titemCreated,\n\t\tcloseList,\n\t\tid,\n\t\tisCreatable,\n\t\tplaceholder,\n\t\tplaceholderAlwaysShow,\n\t\titems,\n\t\titemFilter,\n\t\tgroupBy,\n\t\tgroupFilter,\n\t\tisGroupHeaderSelectable,\n\t\tgetGroupHeaderLabel,\n\t\tlabelIdentifier,\n\t\tgetOptionLabel,\n\t\toptionIdentifier,\n\t\tloadOptions,\n\t\tcreateGroupHeaderItem,\n\t\tcreateItem,\n\t\tgetFilteredItems,\n\t\tlistPlacement,\n\t\tisVirtualList,\n\t\tloadOptionsInterval,\n\t\tnoOptionsMessage,\n\t\thideEmptyState,\n\t\tlistAutoWidth,\n\t\titemHeight,\n\t\tlistOffset,\n\t\tItem,\n\t\tVirtualList,\n\t\tselectedValue,\n\t\tariaValues,\n\t\tariaListOpen,\n\t\tariaFocused,\n\t\tprev_value,\n\t\tprev_filterText,\n\t\tprev_isFocused,\n\t\tprev_isMulti,\n\t\tfilteredItems,\n\t\tinput_1_binding,\n\t\tinput_1_input_handler,\n\t\tswitch_instance_hoverItemIndex_binding,\n\t\tdiv_binding\n\t];\n}\n\nclass Select extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\tid: 46,\n\t\t\t\tcontainer: 0,\n\t\t\t\tinput: 6,\n\t\t\t\tisMulti: 7,\n\t\t\t\tmultiFullItemClearable: 8,\n\t\t\t\tisDisabled: 9,\n\t\t\t\tisCreatable: 47,\n\t\t\t\tisFocused: 1,\n\t\t\t\tvalue: 2,\n\t\t\t\tfilterText: 3,\n\t\t\t\tplaceholder: 48,\n\t\t\t\tplaceholderAlwaysShow: 49,\n\t\t\t\titems: 50,\n\t\t\t\titemFilter: 51,\n\t\t\t\tgroupBy: 52,\n\t\t\t\tgroupFilter: 53,\n\t\t\t\tisGroupHeaderSelectable: 54,\n\t\t\t\tgetGroupHeaderLabel: 55,\n\t\t\t\tlabelIdentifier: 56,\n\t\t\t\tgetOptionLabel: 57,\n\t\t\t\toptionIdentifier: 58,\n\t\t\t\tloadOptions: 59,\n\t\t\t\thasError: 10,\n\t\t\t\tcontainerStyles: 11,\n\t\t\t\tgetSelectionLabel: 12,\n\t\t\t\tcreateGroupHeaderItem: 60,\n\t\t\t\tcreateItem: 61,\n\t\t\t\tgetFilteredItems: 62,\n\t\t\t\tisSearchable: 13,\n\t\t\t\tinputStyles: 14,\n\t\t\t\tisClearable: 15,\n\t\t\t\tisWaiting: 4,\n\t\t\t\tlistPlacement: 63,\n\t\t\t\tlistOpen: 5,\n\t\t\t\tisVirtualList: 64,\n\t\t\t\tloadOptionsInterval: 65,\n\t\t\t\tnoOptionsMessage: 66,\n\t\t\t\thideEmptyState: 67,\n\t\t\t\tinputAttributes: 16,\n\t\t\t\tlistAutoWidth: 68,\n\t\t\t\titemHeight: 69,\n\t\t\t\tIcon: 17,\n\t\t\t\ticonProps: 18,\n\t\t\t\tshowChevron: 19,\n\t\t\t\tshowIndicator: 20,\n\t\t\t\tcontainerClasses: 21,\n\t\t\t\tindicatorSvg: 22,\n\t\t\t\tlistOffset: 70,\n\t\t\t\tClearIcon: 23,\n\t\t\t\tItem: 71,\n\t\t\t\tList: 24,\n\t\t\t\tSelection: 25,\n\t\t\t\tMultiSelection: 26,\n\t\t\t\tVirtualList: 72,\n\t\t\t\tselectedValue: 73,\n\t\t\t\thandleClear: 27,\n\t\t\t\tariaValues: 74,\n\t\t\t\tariaListOpen: 75,\n\t\t\t\tariaFocused: 76\n\t\t\t},\n\t\t\tadd_css,\n\t\t\t[-1, -1, -1, -1]\n\t\t);\n\t}\n\n\tget getFilteredItems() {\n\t\treturn this.$$.ctx[62];\n\t}\n\n\tget handleClear() {\n\t\treturn this.$$.ctx[27];\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Select);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/Select.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/Selection.svelte":
/*!*************************************************************!*\
  !*** ../../node_modules/svelte-select/src/Selection.svelte ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/Selection.svelte generated by Svelte v3.59.2 */\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-16nttcf\", \".selection.svelte-16nttcf{text-overflow:ellipsis;overflow-x:hidden;white-space:nowrap}\");\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet raw_value = /*getSelectionLabel*/ ctx[0](/*item*/ ctx[1]) + \"\";\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"selection svelte-16nttcf\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tdiv.innerHTML = raw_value;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*getSelectionLabel, item*/ 3 && raw_value !== (raw_value = /*getSelectionLabel*/ ctx[0](/*item*/ ctx[1]) + \"\")) div.innerHTML = raw_value;;\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { getSelectionLabel = undefined } = $$props;\n\tlet { item = undefined } = $$props;\n\n\t$$self.$$set = $$props => {\n\t\tif ('getSelectionLabel' in $$props) $$invalidate(0, getSelectionLabel = $$props.getSelectionLabel);\n\t\tif ('item' in $$props) $$invalidate(1, item = $$props.item);\n\t};\n\n\treturn [getSelectionLabel, item];\n}\n\nclass Selection extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { getSelectionLabel: 0, item: 1 }, add_css);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Selection);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/Selection.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/VirtualList.svelte":
/*!***************************************************************!*\
  !*** ../../node_modules/svelte-select/src/VirtualList.svelte ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-select/src/VirtualList.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-bh33jg\", \"svelte-virtual-list-viewport.svelte-bh33jg{position:relative;overflow-y:auto;-webkit-overflow-scrolling:touch;display:block}svelte-virtual-list-contents.svelte-bh33jg,svelte-virtual-list-row.svelte-bh33jg{display:block}svelte-virtual-list-row.svelte-bh33jg{overflow:hidden}\");\n}\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[23] = list[i];\n\treturn child_ctx;\n}\n\nconst get_default_slot_changes = dirty => ({\n\titem: dirty & /*visible*/ 32,\n\ti: dirty & /*visible*/ 32,\n\thoverItemIndex: dirty & /*hoverItemIndex*/ 2\n});\n\nconst get_default_slot_context = ctx => ({\n\titem: /*row*/ ctx[23].data,\n\ti: /*row*/ ctx[23].index,\n\thoverItemIndex: /*hoverItemIndex*/ ctx[1]\n});\n\n// (152:69) Missing template\nfunction fallback_block(ctx) {\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"Missing template\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, t, anchor);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(t);\n\t\t}\n\t};\n}\n\n// (150:8) {#each visible as row (row.index)}\nfunction create_each_block(key_1, ctx) {\n\tlet svelte_virtual_list_row;\n\tlet t;\n\tlet current;\n\tconst default_slot_template = /*#slots*/ ctx[15].default;\n\tconst default_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(default_slot_template, ctx, /*$$scope*/ ctx[14], get_default_slot_context);\n\tconst default_slot_or_fallback = default_slot || fallback_block(ctx);\n\n\treturn {\n\t\tkey: key_1,\n\t\tfirst: null,\n\t\tc() {\n\t\t\tsvelte_virtual_list_row = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"svelte-virtual-list-row\");\n\t\t\tif (default_slot_or_fallback) default_slot_or_fallback.c();\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_custom_element_data)(svelte_virtual_list_row, \"class\", \"svelte-bh33jg\");\n\t\t\tthis.first = svelte_virtual_list_row;\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, svelte_virtual_list_row, anchor);\n\n\t\t\tif (default_slot_or_fallback) {\n\t\t\t\tdefault_slot_or_fallback.m(svelte_virtual_list_row, null);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(svelte_virtual_list_row, t);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(new_ctx, dirty) {\n\t\t\tctx = new_ctx;\n\n\t\t\tif (default_slot) {\n\t\t\t\tif (default_slot.p && (!current || dirty & /*$$scope, visible, hoverItemIndex*/ 16418)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\tdefault_slot,\n\t\t\t\t\t\tdefault_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[14],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[14])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(default_slot_template, /*$$scope*/ ctx[14], dirty, get_default_slot_changes),\n\t\t\t\t\t\tget_default_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(default_slot_or_fallback, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(default_slot_or_fallback, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(svelte_virtual_list_row);\n\t\t\tif (default_slot_or_fallback) default_slot_or_fallback.d(detaching);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet svelte_virtual_list_viewport;\n\tlet svelte_virtual_list_contents;\n\tlet each_blocks = [];\n\tlet each_1_lookup = new Map();\n\tlet svelte_virtual_list_viewport_resize_listener;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tlet each_value = /*visible*/ ctx[5];\n\tconst get_key = ctx => /*row*/ ctx[23].index;\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\tlet child_ctx = get_each_context(ctx, each_value, i);\n\t\tlet key = get_key(child_ctx);\n\t\teach_1_lookup.set(key, each_blocks[i] = create_each_block(key, child_ctx));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tsvelte_virtual_list_viewport = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"svelte-virtual-list-viewport\");\n\t\t\tsvelte_virtual_list_contents = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"svelte-virtual-list-contents\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_contents, \"padding-top\", /*top*/ ctx[6] + \"px\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_contents, \"padding-bottom\", /*bottom*/ ctx[7] + \"px\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_custom_element_data)(svelte_virtual_list_contents, \"class\", \"svelte-bh33jg\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_viewport, \"height\", /*height*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_custom_element_data)(svelte_virtual_list_viewport, \"class\", \"svelte-bh33jg\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_render_callback)(() => /*svelte_virtual_list_viewport_elementresize_handler*/ ctx[18].call(svelte_virtual_list_viewport));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, svelte_virtual_list_viewport, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(svelte_virtual_list_viewport, svelte_virtual_list_contents);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(svelte_virtual_list_contents, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t/*svelte_virtual_list_contents_binding*/ ctx[16](svelte_virtual_list_contents);\n\t\t\t/*svelte_virtual_list_viewport_binding*/ ctx[17](svelte_virtual_list_viewport);\n\t\t\tsvelte_virtual_list_viewport_resize_listener = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_iframe_resize_listener)(svelte_virtual_list_viewport, /*svelte_virtual_list_viewport_elementresize_handler*/ ctx[18].bind(svelte_virtual_list_viewport));\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(svelte_virtual_list_viewport, \"scroll\", /*handle_scroll*/ ctx[8]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*$$scope, visible, hoverItemIndex*/ 16418) {\n\t\t\t\teach_value = /*visible*/ ctx[5];\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\teach_blocks = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_keyed_each)(each_blocks, dirty, get_key, 1, ctx, each_value, each_1_lookup, svelte_virtual_list_contents, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.outro_and_destroy_block, create_each_block, null, get_each_context);\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*top*/ 64) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_contents, \"padding-top\", /*top*/ ctx[6] + \"px\");\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*bottom*/ 128) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_contents, \"padding-bottom\", /*bottom*/ ctx[7] + \"px\");\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*height*/ 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(svelte_virtual_list_viewport, \"height\", /*height*/ ctx[0]);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(svelte_virtual_list_viewport);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].d();\n\t\t\t}\n\n\t\t\t/*svelte_virtual_list_contents_binding*/ ctx[16](null);\n\t\t\t/*svelte_virtual_list_viewport_binding*/ ctx[17](null);\n\t\t\tsvelte_virtual_list_viewport_resize_listener();\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { $$slots: slots = {}, $$scope } = $$props;\n\tlet { items = undefined } = $$props;\n\tlet { height = '100%' } = $$props;\n\tlet { itemHeight = 40 } = $$props;\n\tlet { hoverItemIndex = 0 } = $$props;\n\tlet { start = 0 } = $$props;\n\tlet { end = 0 } = $$props;\n\tlet height_map = [];\n\tlet rows;\n\tlet viewport;\n\tlet contents;\n\tlet viewport_height = 0;\n\tlet visible;\n\tlet mounted;\n\tlet top = 0;\n\tlet bottom = 0;\n\tlet average_height;\n\n\tasync function refresh(items, viewport_height, itemHeight) {\n\t\tconst { scrollTop } = viewport;\n\t\tawait (0,svelte__WEBPACK_IMPORTED_MODULE_1__.tick)();\n\t\tlet content_height = top - scrollTop;\n\t\tlet i = start;\n\n\t\twhile (content_height < viewport_height && i < items.length) {\n\t\t\tlet row = rows[i - start];\n\n\t\t\tif (!row) {\n\t\t\t\t$$invalidate(10, end = i + 1);\n\t\t\t\tawait (0,svelte__WEBPACK_IMPORTED_MODULE_1__.tick)();\n\t\t\t\trow = rows[i - start];\n\t\t\t}\n\n\t\t\tconst row_height = height_map[i] = itemHeight || row.offsetHeight;\n\t\t\tcontent_height += row_height;\n\t\t\ti += 1;\n\t\t}\n\n\t\t$$invalidate(10, end = i);\n\t\tconst remaining = items.length - end;\n\t\taverage_height = (top + content_height) / end;\n\t\t$$invalidate(7, bottom = remaining * average_height);\n\t\theight_map.length = items.length;\n\t\tif (viewport) $$invalidate(3, viewport.scrollTop = 0, viewport);\n\t}\n\n\tasync function handle_scroll() {\n\t\tconst { scrollTop } = viewport;\n\t\tconst old_start = start;\n\n\t\tfor (let v = 0; v < rows.length; v += 1) {\n\t\t\theight_map[start + v] = itemHeight || rows[v].offsetHeight;\n\t\t}\n\n\t\tlet i = 0;\n\t\tlet y = 0;\n\n\t\twhile (i < items.length) {\n\t\t\tconst row_height = height_map[i] || average_height;\n\n\t\t\tif (y + row_height > scrollTop) {\n\t\t\t\t$$invalidate(9, start = i);\n\t\t\t\t$$invalidate(6, top = y);\n\t\t\t\tbreak;\n\t\t\t}\n\n\t\t\ty += row_height;\n\t\t\ti += 1;\n\t\t}\n\n\t\twhile (i < items.length) {\n\t\t\ty += height_map[i] || average_height;\n\t\t\ti += 1;\n\t\t\tif (y > scrollTop + viewport_height) break;\n\t\t}\n\n\t\t$$invalidate(10, end = i);\n\t\tconst remaining = items.length - end;\n\t\taverage_height = y / end;\n\t\twhile (i < items.length) height_map[i++] = average_height;\n\t\t$$invalidate(7, bottom = remaining * average_height);\n\n\t\tif (start < old_start) {\n\t\t\tawait (0,svelte__WEBPACK_IMPORTED_MODULE_1__.tick)();\n\t\t\tlet expected_height = 0;\n\t\t\tlet actual_height = 0;\n\n\t\t\tfor (let i = start; i < old_start; i += 1) {\n\t\t\t\tif (rows[i - start]) {\n\t\t\t\t\texpected_height += height_map[i];\n\t\t\t\t\tactual_height += itemHeight || rows[i - start].offsetHeight;\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tconst d = actual_height - expected_height;\n\t\t\tviewport.scrollTo(0, scrollTop + d);\n\t\t}\n\t}\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.onMount)(() => {\n\t\trows = contents.getElementsByTagName('svelte-virtual-list-row');\n\t\t$$invalidate(13, mounted = true);\n\t});\n\n\tfunction svelte_virtual_list_contents_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tcontents = $$value;\n\t\t\t$$invalidate(4, contents);\n\t\t});\n\t}\n\n\tfunction svelte_virtual_list_viewport_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tviewport = $$value;\n\t\t\t$$invalidate(3, viewport);\n\t\t});\n\t}\n\n\tfunction svelte_virtual_list_viewport_elementresize_handler() {\n\t\tviewport_height = this.offsetHeight;\n\t\t$$invalidate(2, viewport_height);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('items' in $$props) $$invalidate(11, items = $$props.items);\n\t\tif ('height' in $$props) $$invalidate(0, height = $$props.height);\n\t\tif ('itemHeight' in $$props) $$invalidate(12, itemHeight = $$props.itemHeight);\n\t\tif ('hoverItemIndex' in $$props) $$invalidate(1, hoverItemIndex = $$props.hoverItemIndex);\n\t\tif ('start' in $$props) $$invalidate(9, start = $$props.start);\n\t\tif ('end' in $$props) $$invalidate(10, end = $$props.end);\n\t\tif ('$$scope' in $$props) $$invalidate(14, $$scope = $$props.$$scope);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*items, start, end*/ 3584) {\n\t\t\t$: $$invalidate(5, visible = items.slice(start, end).map((data, i) => {\n\t\t\t\treturn { index: i + start, data };\n\t\t\t}));\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*mounted, items, viewport_height, itemHeight*/ 14340) {\n\t\t\t$: if (mounted) refresh(items, viewport_height, itemHeight);\n\t\t}\n\t};\n\n\treturn [\n\t\theight,\n\t\thoverItemIndex,\n\t\tviewport_height,\n\t\tviewport,\n\t\tcontents,\n\t\tvisible,\n\t\ttop,\n\t\tbottom,\n\t\thandle_scroll,\n\t\tstart,\n\t\tend,\n\t\titems,\n\t\titemHeight,\n\t\tmounted,\n\t\t$$scope,\n\t\tslots,\n\t\tsvelte_virtual_list_contents_binding,\n\t\tsvelte_virtual_list_viewport_binding,\n\t\tsvelte_virtual_list_viewport_elementresize_handler\n\t];\n}\n\nclass VirtualList extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(\n\t\t\tthis,\n\t\t\toptions,\n\t\t\tinstance,\n\t\t\tcreate_fragment,\n\t\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal,\n\t\t\t{\n\t\t\t\titems: 11,\n\t\t\t\theight: 0,\n\t\t\t\titemHeight: 12,\n\t\t\t\thoverItemIndex: 1,\n\t\t\t\tstart: 9,\n\t\t\t\tend: 10\n\t\t\t},\n\t\t\tadd_css\n\t\t);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (VirtualList);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/VirtualList.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/Vega.svelte":
/*!*******************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/Vega.svelte ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _VegaEmbed_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./VegaEmbed.svelte */ \"../../node_modules/svelte-vega/dist/VegaEmbed.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-vega/dist/Vega.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet vegaembed;\n\tlet updating_view;\n\tlet current;\n\n\tfunction vegaembed_view_binding(value) {\n\t\t/*vegaembed_view_binding*/ ctx[6](value);\n\t}\n\n\tlet vegaembed_props = {\n\t\tspec: /*spec*/ ctx[1],\n\t\tdata: /*data*/ ctx[2],\n\t\tsignalListeners: /*signalListeners*/ ctx[3],\n\t\toptions: /*vegaOptions*/ ctx[4]\n\t};\n\n\tif (/*view*/ ctx[0] !== void 0) {\n\t\tvegaembed_props.view = /*view*/ ctx[0];\n\t}\n\n\tvegaembed = new _VegaEmbed_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: vegaembed_props });\n\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks.push(() => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.bind)(vegaembed, 'view', vegaembed_view_binding));\n\tvegaembed.$on(\"onNewView\", /*onNewView_handler*/ ctx[7]);\n\tvegaembed.$on(\"onError\", /*onError_handler*/ ctx[8]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(vegaembed.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(vegaembed, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst vegaembed_changes = {};\n\t\t\tif (dirty & /*spec*/ 2) vegaembed_changes.spec = /*spec*/ ctx[1];\n\t\t\tif (dirty & /*data*/ 4) vegaembed_changes.data = /*data*/ ctx[2];\n\t\t\tif (dirty & /*signalListeners*/ 8) vegaembed_changes.signalListeners = /*signalListeners*/ ctx[3];\n\t\t\tif (dirty & /*vegaOptions*/ 16) vegaembed_changes.options = /*vegaOptions*/ ctx[4];\n\n\t\t\tif (!updating_view && dirty & /*view*/ 1) {\n\t\t\t\tupdating_view = true;\n\t\t\t\tvegaembed_changes.view = /*view*/ ctx[0];\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_flush_callback)(() => updating_view = false);\n\t\t\t}\n\n\t\t\tvegaembed.$set(vegaembed_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(vegaembed.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(vegaembed.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(vegaembed, detaching);\n\t\t}\n\t};\n}\n\nconst mode = \"vega\";\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet vegaOptions;\n\tlet { spec } = $$props;\n\tlet { options = {} } = $$props;\n\tlet { data = {} } = $$props;\n\tlet { signalListeners = {} } = $$props;\n\tlet { view = undefined } = $$props;\n\n\tfunction vegaembed_view_binding(value) {\n\t\tview = value;\n\t\t$$invalidate(0, view);\n\t}\n\n\tfunction onNewView_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\tfunction onError_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('spec' in $$props) $$invalidate(1, spec = $$props.spec);\n\t\tif ('options' in $$props) $$invalidate(5, options = $$props.options);\n\t\tif ('data' in $$props) $$invalidate(2, data = $$props.data);\n\t\tif ('signalListeners' in $$props) $$invalidate(3, signalListeners = $$props.signalListeners);\n\t\tif ('view' in $$props) $$invalidate(0, view = $$props.view);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*options*/ 32) {\n\t\t\t$: $$invalidate(4, vegaOptions = { ...options, mode });\n\t\t}\n\t};\n\n\treturn [\n\t\tview,\n\t\tspec,\n\t\tdata,\n\t\tsignalListeners,\n\t\tvegaOptions,\n\t\toptions,\n\t\tvegaembed_view_binding,\n\t\tonNewView_handler,\n\t\tonError_handler\n\t];\n}\n\nclass Vega extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\tspec: 1,\n\t\t\toptions: 5,\n\t\t\tdata: 2,\n\t\t\tsignalListeners: 3,\n\t\t\tview: 0\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Vega);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/Vega.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/VegaEmbed.svelte":
/*!************************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/VegaEmbed.svelte ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* harmony import */ var vega_embed__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-embed */ \"../../node_modules/vega-embed/build/vega-embed.module.js\");\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./constants */ \"../../node_modules/svelte-vega/dist/constants.js\");\n/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./utils */ \"../../node_modules/svelte-vega/dist/utils.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-vega/dist/VegaEmbed.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet div;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t/*div_binding*/ ctx[11](div);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t/*div_binding*/ ctx[11](null);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { options } = $$props;\n\tlet { spec } = $$props;\n\tlet { view } = $$props;\n\tlet { signalListeners = {} } = $$props;\n\tlet { data = {} } = $$props;\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\tlet result = undefined;\n\tlet prevOptions = {};\n\tlet prevSignalListeners = {};\n\tlet prevSpec = {};\n\tlet prevData = {};\n\tlet chartContainer;\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.onDestroy)(() => {\n\t\tclearView();\n\t});\n\n\tasync function createView() {\n\t\tclearView();\n\n\t\ttry {\n\t\t\t$$invalidate(6, result = await (0,vega_embed__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(chartContainer, spec, options));\n\t\t\t$$invalidate(1, view = result.view);\n\n\t\t\tif ((0,_utils__WEBPACK_IMPORTED_MODULE_4__.addSignalListenersToView)(view, signalListeners)) {\n\t\t\t\tview.runAsync();\n\t\t\t}\n\n\t\t\tonNewView(view);\n\t\t} catch(e) {\n\t\t\thandleError(e);\n\t\t}\n\t}\n\n\tfunction clearView() {\n\t\tif (result) {\n\t\t\tresult.finalize();\n\t\t\t$$invalidate(6, result = undefined);\n\t\t\t$$invalidate(1, view = undefined);\n\t\t}\n\t}\n\n\tfunction handleError(error) {\n\t\tdispatch(\"onError\", { error });\n\t\tconsole.warn(error);\n\t}\n\n\tfunction onNewView(view) {\n\t\tupdate();\n\t\tdispatch(\"onNewView\", { view });\n\t}\n\n\tasync function update() {\n\t\tif (data && Object.keys(data).length > 0 && result !== undefined) {\n\t\t\t$$invalidate(1, view = result.view);\n\t\t\t(0,_utils__WEBPACK_IMPORTED_MODULE_4__.updateMultipleDatasetsInView)(view, data);\n\t\t\tawait view.resize().runAsync();\n\t\t}\n\t}\n\n\tfunction div_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tchartContainer = $$value;\n\t\t\t$$invalidate(0, chartContainer);\n\t\t});\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('options' in $$props) $$invalidate(2, options = $$props.options);\n\t\tif ('spec' in $$props) $$invalidate(3, spec = $$props.spec);\n\t\tif ('view' in $$props) $$invalidate(1, view = $$props.view);\n\t\tif ('signalListeners' in $$props) $$invalidate(4, signalListeners = $$props.signalListeners);\n\t\tif ('data' in $$props) $$invalidate(5, data = $$props.data);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*data, prevData*/ 1056) {\n\t\t\t$: {\n\t\t\t\tif (!(0,_utils__WEBPACK_IMPORTED_MODULE_4__.shallowEqual)(data, prevData)) {\n\t\t\t\t\tupdate();\n\t\t\t\t}\n\n\t\t\t\t$$invalidate(10, prevData = data);\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*chartContainer, options, prevOptions, spec, prevSpec, signalListeners, prevSignalListeners, result, view*/ 991) {\n\t\t\t$: {\n\t\t\t\tif (chartContainer !== undefined) {\n\t\t\t\t\t// only create a new view if neccessary\n\t\t\t\t\tif (!(0,_utils__WEBPACK_IMPORTED_MODULE_4__.shallowEqual)(options, prevOptions, _constants__WEBPACK_IMPORTED_MODULE_3__.WIDTH_HEIGHT)) {\n\t\t\t\t\t\tcreateView();\n\t\t\t\t\t} else {\n\t\t\t\t\t\tconst specChanges = (0,_utils__WEBPACK_IMPORTED_MODULE_4__.computeSpecChanges)((0,_utils__WEBPACK_IMPORTED_MODULE_4__.combineSpecWithDimension)(spec, options), (0,_utils__WEBPACK_IMPORTED_MODULE_4__.combineSpecWithDimension)(prevSpec, prevOptions));\n\t\t\t\t\t\tconst newSignalListeners = signalListeners;\n\t\t\t\t\t\tconst oldSignalListeners = prevSignalListeners;\n\n\t\t\t\t\t\tif (specChanges) {\n\t\t\t\t\t\t\tif (specChanges.isExpensive) {\n\t\t\t\t\t\t\t\tcreateView();\n\t\t\t\t\t\t\t} else if (result !== undefined) {\n\t\t\t\t\t\t\t\tconst areSignalListenersChanged = !(0,_utils__WEBPACK_IMPORTED_MODULE_4__.shallowEqual)(newSignalListeners, oldSignalListeners);\n\t\t\t\t\t\t\t\t$$invalidate(1, view = result.view);\n\n\t\t\t\t\t\t\t\tif (specChanges.width !== false) {\n\t\t\t\t\t\t\t\t\tview.width(specChanges.width);\n\t\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\t\tif (specChanges.height !== false) {\n\t\t\t\t\t\t\t\t\tview.height(specChanges.height);\n\t\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\t\tif (areSignalListenersChanged) {\n\t\t\t\t\t\t\t\t\tif (oldSignalListeners) {\n\t\t\t\t\t\t\t\t\t\t(0,_utils__WEBPACK_IMPORTED_MODULE_4__.removeSignalListenersFromView)(view, oldSignalListeners);\n\t\t\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\t\t\tif (newSignalListeners) {\n\t\t\t\t\t\t\t\t\t\t(0,_utils__WEBPACK_IMPORTED_MODULE_4__.addSignalListenersToView)(view, newSignalListeners);\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\t\tview.runAsync();\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t} else if (!(0,_utils__WEBPACK_IMPORTED_MODULE_4__.shallowEqual)(newSignalListeners, oldSignalListeners) && result !== undefined) {\n\t\t\t\t\t\t\t$$invalidate(1, view = result.view);\n\n\t\t\t\t\t\t\tif (oldSignalListeners) {\n\t\t\t\t\t\t\t\t(0,_utils__WEBPACK_IMPORTED_MODULE_4__.removeSignalListenersFromView)(view, oldSignalListeners);\n\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\tif (newSignalListeners) {\n\t\t\t\t\t\t\t\t(0,_utils__WEBPACK_IMPORTED_MODULE_4__.addSignalListenersToView)(view, newSignalListeners);\n\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\tview.runAsync();\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\n\t\t\t\t\t$$invalidate(7, prevOptions = options);\n\t\t\t\t\t$$invalidate(8, prevSignalListeners = signalListeners);\n\t\t\t\t\t$$invalidate(9, prevSpec = spec);\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t};\n\n\treturn [\n\t\tchartContainer,\n\t\tview,\n\t\toptions,\n\t\tspec,\n\t\tsignalListeners,\n\t\tdata,\n\t\tresult,\n\t\tprevOptions,\n\t\tprevSignalListeners,\n\t\tprevSpec,\n\t\tprevData,\n\t\tdiv_binding\n\t];\n}\n\nclass VegaEmbed extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\toptions: 2,\n\t\t\tspec: 3,\n\t\t\tview: 1,\n\t\t\tsignalListeners: 4,\n\t\t\tdata: 5\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (VegaEmbed);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/VegaEmbed.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/VegaLite.svelte":
/*!***********************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/VegaLite.svelte ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _VegaEmbed_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./VegaEmbed.svelte */ \"../../node_modules/svelte-vega/dist/VegaEmbed.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/node_modules/svelte-vega/dist/VegaLite.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet vegaembed;\n\tlet updating_view;\n\tlet current;\n\n\tfunction vegaembed_view_binding(value) {\n\t\t/*vegaembed_view_binding*/ ctx[6](value);\n\t}\n\n\tlet vegaembed_props = {\n\t\tspec: /*spec*/ ctx[1],\n\t\tdata: /*data*/ ctx[2],\n\t\tsignalListeners: /*signalListeners*/ ctx[3],\n\t\toptions: /*vegaLiteOptions*/ ctx[4]\n\t};\n\n\tif (/*view*/ ctx[0] !== void 0) {\n\t\tvegaembed_props.view = /*view*/ ctx[0];\n\t}\n\n\tvegaembed = new _VegaEmbed_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: vegaembed_props });\n\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks.push(() => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.bind)(vegaembed, 'view', vegaembed_view_binding));\n\tvegaembed.$on(\"onNewView\", /*onNewView_handler*/ ctx[7]);\n\tvegaembed.$on(\"onError\", /*onError_handler*/ ctx[8]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(vegaembed.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(vegaembed, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst vegaembed_changes = {};\n\t\t\tif (dirty & /*spec*/ 2) vegaembed_changes.spec = /*spec*/ ctx[1];\n\t\t\tif (dirty & /*data*/ 4) vegaembed_changes.data = /*data*/ ctx[2];\n\t\t\tif (dirty & /*signalListeners*/ 8) vegaembed_changes.signalListeners = /*signalListeners*/ ctx[3];\n\t\t\tif (dirty & /*vegaLiteOptions*/ 16) vegaembed_changes.options = /*vegaLiteOptions*/ ctx[4];\n\n\t\t\tif (!updating_view && dirty & /*view*/ 1) {\n\t\t\t\tupdating_view = true;\n\t\t\t\tvegaembed_changes.view = /*view*/ ctx[0];\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_flush_callback)(() => updating_view = false);\n\t\t\t}\n\n\t\t\tvegaembed.$set(vegaembed_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(vegaembed.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(vegaembed.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(vegaembed, detaching);\n\t\t}\n\t};\n}\n\nconst mode = \"vega-lite\";\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet vegaLiteOptions;\n\tlet { spec } = $$props;\n\tlet { options = {} } = $$props;\n\tlet { data = {} } = $$props;\n\tlet { signalListeners = {} } = $$props;\n\tlet { view = undefined } = $$props;\n\n\tfunction vegaembed_view_binding(value) {\n\t\tview = value;\n\t\t$$invalidate(0, view);\n\t}\n\n\tfunction onNewView_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\tfunction onError_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('spec' in $$props) $$invalidate(1, spec = $$props.spec);\n\t\tif ('options' in $$props) $$invalidate(5, options = $$props.options);\n\t\tif ('data' in $$props) $$invalidate(2, data = $$props.data);\n\t\tif ('signalListeners' in $$props) $$invalidate(3, signalListeners = $$props.signalListeners);\n\t\tif ('view' in $$props) $$invalidate(0, view = $$props.view);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*options*/ 32) {\n\t\t\t$: $$invalidate(4, vegaLiteOptions = { ...options, mode });\n\t\t}\n\t};\n\n\treturn [\n\t\tview,\n\t\tspec,\n\t\tdata,\n\t\tsignalListeners,\n\t\tvegaLiteOptions,\n\t\toptions,\n\t\tvegaembed_view_binding,\n\t\tonNewView_handler,\n\t\tonError_handler\n\t];\n}\n\nclass VegaLite extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\tspec: 1,\n\t\t\toptions: 5,\n\t\t\tdata: 2,\n\t\t\tsignalListeners: 3,\n\t\t\tview: 0\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (VegaLite);\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/VegaLite.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/JupyterWidget.svelte":
/*!****************************************************!*\
  !*** ../../symphony_lib/dist/JupyterWidget.svelte ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _stores__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./stores */ \"../../symphony_lib/dist/stores.js\");\n/* harmony import */ var _elements__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./elements */ \"../../symphony_lib/dist/elements/DataSampleDetail.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/JupyterWidget.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction create_else_block(ctx) {\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"No data to show.\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, t, anchor);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(t);\n\t\t}\n\t};\n}\n\n// (16:0) {#if $table && $widgetSpec}\nfunction create_if_block(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet div_class_value;\n\tlet current;\n\tvar switch_value = /*widget*/ ctx[0];\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\twidgetSpec: /*$widgetSpec*/ ctx[2],\n\t\t\t\tselected: _stores__WEBPACK_IMPORTED_MODULE_1__.selected,\n\t\t\t\tfilter: _stores__WEBPACK_IMPORTED_MODULE_1__.filter,\n\t\t\t\tgroupColumns: _stores__WEBPACK_IMPORTED_MODULE_1__.groupColumns,\n\t\t\t\tgroupNames: _stores__WEBPACK_IMPORTED_MODULE_1__.groupNames,\n\t\t\t\tsymphonySpec: _stores__WEBPACK_IMPORTED_MODULE_1__.symphonySpec,\n\t\t\t\tdataTable: _stores__WEBPACK_IMPORTED_MODULE_1__.dataTable,\n\t\t\t\tfilterError: _stores__WEBPACK_IMPORTED_MODULE_1__.filterError,\n\t\t\t\ttooltip: _stores__WEBPACK_IMPORTED_MODULE_1__.tooltip,\n\t\t\t\ttable: _stores__WEBPACK_IMPORTED_MODULE_1__.table,\n\t\t\t\tfilteredTable: _stores__WEBPACK_IMPORTED_MODULE_1__.filteredTable,\n\t\t\t\tgroupedTables: _stores__WEBPACK_IMPORTED_MODULE_1__.groupedTables,\n\t\t\t\tnotebook: true\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\tswitch_instance.$on(\"specChanged\", /*handleSpecChanged*/ ctx[4]);\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value = \"\" + ((/*$widgetSpec*/ ctx[2].name === 'toolbar'\n\t\t\t? 'border-midgrey border-2'\n\t\t\t: '') + \" mt-2 h-full\"));\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(div, \"min-height\", \"350px\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty & /*$widgetSpec*/ 4) switch_instance_changes.widgetSpec = /*$widgetSpec*/ ctx[2];\n\n\t\t\tif (dirty & /*widget*/ 1 && switch_value !== (switch_value = /*widget*/ ctx[0])) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\tswitch_instance.$on(\"specChanged\", /*handleSpecChanged*/ ctx[4]);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*$widgetSpec*/ 4 && div_class_value !== (div_class_value = \"\" + ((/*$widgetSpec*/ ctx[2].name === 'toolbar'\n\t\t\t? 'border-midgrey border-2'\n\t\t\t: '') + \" mt-2 h-full\"))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet current_block_type_index;\n\tlet if_block;\n\tlet t;\n\tlet datasampledetail;\n\tlet current;\n\tconst if_block_creators = [create_if_block, create_else_block];\n\tconst if_blocks = [];\n\n\tfunction select_block_type(ctx, dirty) {\n\t\tif (/*$table*/ ctx[1] && /*$widgetSpec*/ ctx[2]) return 0;\n\t\treturn 1;\n\t}\n\n\tcurrent_block_type_index = select_block_type(ctx, -1);\n\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\tdatasampledetail = new _elements__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({ props: { tooltip: _stores__WEBPACK_IMPORTED_MODULE_1__.tooltip, symphonySpec: _stores__WEBPACK_IMPORTED_MODULE_1__.symphonySpec } });\n\n\treturn {\n\t\tc() {\n\t\t\tif_block.c();\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(datasampledetail.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif_blocks[current_block_type_index].m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, t, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(datasampledetail, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tlet previous_block_index = current_block_type_index;\n\t\t\tcurrent_block_type_index = select_block_type(ctx, dirty);\n\n\t\t\tif (current_block_type_index === previous_block_index) {\n\t\t\t\tif_blocks[current_block_type_index].p(ctx, dirty);\n\t\t\t} else {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_blocks[previous_block_index], 1, 1, () => {\n\t\t\t\t\tif_blocks[previous_block_index] = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\tif_block = if_blocks[current_block_type_index];\n\n\t\t\t\tif (!if_block) {\n\t\t\t\t\tif_block = if_blocks[current_block_type_index] = if_block_creators[current_block_type_index](ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t} else {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\tif_block.m(t.parentNode, t);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(datasampledetail.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(datasampledetail.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif_blocks[current_block_type_index].d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(t);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(datasampledetail, detaching);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet $table;\n\tlet $widgetSpec;\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.component_subscribe)($$self, _stores__WEBPACK_IMPORTED_MODULE_1__.table, $$value => $$invalidate(1, $table = $$value));\n\tlet { model } = $$props;\n\tlet { widget } = $$props;\n\t(0,_stores__WEBPACK_IMPORTED_MODULE_1__.initializeStores)(model);\n\tlet widgetSpec = (0,_stores__WEBPACK_IMPORTED_MODULE_1__.widgetWritable)(\"widget_spec\", model.attributes.widget_spec);\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.component_subscribe)($$self, widgetSpec, value => $$invalidate(2, $widgetSpec = value));\n\twidgetSpec.setModel(model);\n\n\tfunction handleSpecChanged(event) {\n\t\twidgetSpec.set(event.detail.spec);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('model' in $$props) $$invalidate(5, model = $$props.model);\n\t\tif ('widget' in $$props) $$invalidate(0, widget = $$props.widget);\n\t};\n\n\treturn [widget, $table, $widgetSpec, widgetSpec, handleSpecChanged, model];\n}\n\nclass JupyterWidget extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { model: 5, widget: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (JupyterWidget);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/JupyterWidget.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/AppHeader.svelte":
/*!*********************************************************!*\
  !*** ../../symphony_lib/dist/elements/AppHeader.svelte ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _HeaderButton_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./HeaderButton.svelte */ \"../../symphony_lib/dist/elements/HeaderButton.svelte\");\n/* harmony import */ var _Promo_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Promo.svelte */ \"../../symphony_lib/dist/elements/Promo.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/AppHeader.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[4] = list[i];\n\treturn child_ctx;\n}\n\n// (14:4) {#if pages !== undefined}\nfunction create_if_block_1(ctx) {\n\tlet div;\n\tlet current;\n\tlet each_value = /*pages*/ ctx[1];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\tconst out = i => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i], 1, 1, () => {\n\t\teach_blocks[i] = null;\n\t});\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"flex pl-12 overflow-auto\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*pages, selectedPage*/ 6) {\n\t\t\t\teach_value = /*pages*/ ctx[1];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t\teach_blocks[i].m(div, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\tfor (i = each_value.length; i < each_blocks.length; i += 1) {\n\t\t\t\t\tout(i);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\teach_blocks = each_blocks.filter(Boolean);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t}\n\t};\n}\n\n// (16:8) {#each pages as page}\nfunction create_each_block(ctx) {\n\tlet headerbutton;\n\tlet current;\n\n\theaderbutton = new _HeaderButton_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tselected: /*page*/ ctx[4] === /*selectedPage*/ ctx[2],\n\t\t\t\tvalue: /*page*/ ctx[4]\n\t\t\t}\n\t\t});\n\n\theaderbutton.$on(\"click\", /*click_handler*/ ctx[3]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(headerbutton.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(headerbutton, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst headerbutton_changes = {};\n\t\t\tif (dirty & /*pages, selectedPage*/ 6) headerbutton_changes.selected = /*page*/ ctx[4] === /*selectedPage*/ ctx[2];\n\t\t\tif (dirty & /*pages*/ 2) headerbutton_changes.value = /*page*/ ctx[4];\n\t\t\theaderbutton.$set(headerbutton_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(headerbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(headerbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(headerbutton, detaching);\n\t\t}\n\t};\n}\n\n// (27:4) {#if experiment !== undefined}\nfunction create_if_block(ctx) {\n\tlet h2;\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\th2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"h2\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*experiment*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(h2, \"class\", \"text-text-dark font-bold pr-4\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, h2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(h2, t);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*experiment*/ 1) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, /*experiment*/ ctx[0]);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(h2);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet nav;\n\tlet div0;\n\tlet h2;\n\tlet t1;\n\tlet t2;\n\tlet div1;\n\tlet t3;\n\tlet promo;\n\tlet current;\n\tlet if_block0 = /*pages*/ ctx[1] !== undefined && create_if_block_1(ctx);\n\tlet if_block1 = /*experiment*/ ctx[0] !== undefined && create_if_block(ctx);\n\tpromo = new _Promo_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({});\n\n\treturn {\n\t\tc() {\n\t\t\tnav = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"nav\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\th2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"h2\");\n\t\t\th2.textContent = \"Symphony\";\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block0) if_block0.c();\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (if_block1) if_block1.c();\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(promo.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(h2, \"class\", \"text-2xl font-bold text-text-dark\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex items-center\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex items-center pl-4\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(nav, \"class\", \"p-2 pl-3 bg-black flex justify-between\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, nav, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, div0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, h2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, t1);\n\t\t\tif (if_block0) if_block0.m(div0, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, div1);\n\t\t\tif (if_block1) if_block1.m(div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(promo, div1, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (/*pages*/ ctx[1] !== undefined) {\n\t\t\t\tif (if_block0) {\n\t\t\t\t\tif_block0.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*pages*/ 2) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block0 = create_if_block_1(ctx);\n\t\t\t\t\tif_block0.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0, 1);\n\t\t\t\t\tif_block0.m(div0, null);\n\t\t\t\t}\n\t\t\t} else if (if_block0) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block0, 1, 1, () => {\n\t\t\t\t\tif_block0 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (/*experiment*/ ctx[0] !== undefined) {\n\t\t\t\tif (if_block1) {\n\t\t\t\t\tif_block1.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block1 = create_if_block(ctx);\n\t\t\t\t\tif_block1.c();\n\t\t\t\t\tif_block1.m(div1, t3);\n\t\t\t\t}\n\t\t\t} else if (if_block1) {\n\t\t\t\tif_block1.d(1);\n\t\t\t\tif_block1 = null;\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(promo.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(promo.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(nav);\n\t\t\tif (if_block0) if_block0.d();\n\t\t\tif (if_block1) if_block1.d();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(promo);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { experiment = undefined } = $$props;\n\tlet { pages = undefined } = $$props;\n\tlet { selectedPage = undefined } = $$props;\n\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('experiment' in $$props) $$invalidate(0, experiment = $$props.experiment);\n\t\tif ('pages' in $$props) $$invalidate(1, pages = $$props.pages);\n\t\tif ('selectedPage' in $$props) $$invalidate(2, selectedPage = $$props.selectedPage);\n\t};\n\n\treturn [experiment, pages, selectedPage, click_handler];\n}\n\nclass AppHeader extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { experiment: 0, pages: 1, selectedPage: 2 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (AppHeader);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/AppHeader.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/AudioSample.svelte":
/*!***********************************************************!*\
  !*** ../../symphony_lib/dist/elements/AudioSample.svelte ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* harmony import */ var wavesurfer_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! wavesurfer.js */ \"../../node_modules/wavesurfer.js/dist/wavesurfer.js\");\n/* harmony import */ var wavesurfer_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(wavesurfer_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* harmony import */ var _fireflysemantics_join__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @fireflysemantics/join */ \"../../node_modules/@fireflysemantics/join/fesm2015/fireflysemantics-join.js\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faPlay__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faPlay */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faPlay.js\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faPause__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faPause */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faPause.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/AudioSample.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\n\n\nfunction create_icon_slot(ctx) {\n\tlet fa;\n\tlet current;\n\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\ticon: /*playing*/ ctx[3] ? _fortawesome_free_solid_svg_icons_faPause__WEBPACK_IMPORTED_MODULE_4__.faPause : _fortawesome_free_solid_svg_icons_faPlay__WEBPACK_IMPORTED_MODULE_5__.faPlay,\n\t\t\t\tslot: \"icon\"\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst fa_changes = {};\n\t\t\tif (dirty & /*playing*/ 8) fa_changes.icon = /*playing*/ ctx[3] ? _fortawesome_free_solid_svg_icons_faPause__WEBPACK_IMPORTED_MODULE_4__.faPause : _fortawesome_free_solid_svg_icons_faPlay__WEBPACK_IMPORTED_MODULE_5__.faPlay;\n\t\t\tfa.$set(fa_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div2;\n\tlet div0;\n\tlet t;\n\tlet div1;\n\tlet iconbutton;\n\tlet div2_class_value;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_6__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\t$$slots: { icon: [create_icon_slot] },\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*changePlayStatus*/ ctx[4]);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", div2_class_value = \"flex flex-col \" + (/*large*/ ctx[1] ? 'w-48 mx-1' : 'w-24 m-1'));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div0);\n\t\t\t/*div0_binding*/ ctx[10](div0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, div1, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div0, \"click\", /*click_handler*/ ctx[9]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope, playing*/ 2056) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\n\t\t\tif (!current || dirty & /*large*/ 2 && div2_class_value !== (div2_class_value = \"flex flex-col \" + (/*large*/ ctx[1] ? 'w-48 mx-1' : 'w-24 m-1'))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", div2_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div2);\n\t\t\t/*div0_binding*/ ctx[10](null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet $symphonySpec,\n\t\t$$unsubscribe_symphonySpec = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_symphonySpec = () => ($$unsubscribe_symphonySpec(), $$unsubscribe_symphonySpec = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(symphonySpec, $$value => $$invalidate(8, $symphonySpec = $$value)), symphonySpec);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_symphonySpec());\n\tlet { id } = $$props;\n\tlet { symphonySpec } = $$props;\n\t$$subscribe_symphonySpec();\n\tlet { large = false } = $$props;\n\tlet container;\n\tlet wavesurfer;\n\tlet playing = false;\n\tlet oldId = \"\";\n\n\tfunction changePlayStatus() {\n\t\tif (playing) {\n\t\t\twavesurfer.pause();\n\t\t\t$$invalidate(3, playing = false);\n\t\t} else {\n\t\t\twavesurfer.play();\n\t\t\t$$invalidate(3, playing = true);\n\t\t}\n\t}\n\n\t(0,svelte__WEBPACK_IMPORTED_MODULE_1__.onDestroy)(() => wavesurfer.destroy());\n\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\tfunction div0_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tcontainer = $$value;\n\t\t\t(((($$invalidate(2, container), $$invalidate(5, id)), $$invalidate(7, oldId)), $$invalidate(6, wavesurfer)), $$invalidate(8, $symphonySpec));\n\t\t});\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('id' in $$props) $$invalidate(5, id = $$props.id);\n\t\tif ('symphonySpec' in $$props) $$subscribe_symphonySpec($$invalidate(0, symphonySpec = $$props.symphonySpec));\n\t\tif ('large' in $$props) $$invalidate(1, large = $$props.large);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*container, id, oldId, wavesurfer, $symphonySpec*/ 484) {\n\t\t\t$: if (container !== undefined && id !== oldId) {\n\t\t\t\tif (wavesurfer !== undefined) wavesurfer.destroy();\n\t\t\t\t$$invalidate(2, container.innerHTML = \"\", container);\n\n\t\t\t\t$$invalidate(6, wavesurfer = wavesurfer_js__WEBPACK_IMPORTED_MODULE_2___default().create({\n\t\t\t\t\tcontainer,\n\t\t\t\t\twaveColor: \"#cfcfcf\",\n\t\t\t\t\tprogressColor: \"#0071e3\"\n\t\t\t\t}));\n\n\t\t\t\twavesurfer.load((0,_fireflysemantics_join__WEBPACK_IMPORTED_MODULE_7__.join)($symphonySpec.filesPath, id));\n\t\t\t\t$$invalidate(3, playing = false);\n\t\t\t\t$$invalidate(7, oldId = id);\n\t\t\t}\n\t\t}\n\t};\n\n\treturn [\n\t\tsymphonySpec,\n\t\tlarge,\n\t\tcontainer,\n\t\tplaying,\n\t\tchangePlayStatus,\n\t\tid,\n\t\twavesurfer,\n\t\toldId,\n\t\t$symphonySpec,\n\t\tclick_handler,\n\t\tdiv0_binding\n\t];\n}\n\nclass AudioSample extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { id: 5, symphonySpec: 0, large: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (AudioSample);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/AudioSample.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/ComponentHeader.svelte":
/*!***************************************************************!*\
  !*** ../../symphony_lib/dist/elements/ComponentHeader.svelte ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _Heading_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./Heading.svelte */ \"../../symphony_lib/dist/elements/Heading.svelte\");\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* harmony import */ var _helpers_export__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../helpers/export */ \"../../symphony_lib/dist/helpers/export.js\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faImage__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faImage */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faImage.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/ComponentHeader.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\nfunction create_icon_slot(ctx) {\n\tlet fa;\n\tlet current;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faImage__WEBPACK_IMPORTED_MODULE_2__.faImage, slot: \"icon\" } });\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\n// (24:6) \nfunction create_text_slot(ctx) {\n\tlet span;\n\n\treturn {\n\t\tc() {\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tspan.textContent = \"Download\";\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"slot\", \"text\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span, anchor);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div3;\n\tlet div1;\n\tlet heading;\n\tlet t0;\n\tlet div0;\n\tlet t1;\n\tlet div2;\n\tlet iconbutton;\n\tlet current;\n\n\theading = new _Heading_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\theading: /*title*/ ctx[0],\n\t\t\t\tdescription: /*description*/ ctx[1]\n\t\t\t}\n\t\t});\n\n\tconst default_slot_template = /*#slots*/ ctx[3].default;\n\tconst default_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(default_slot_template, ctx, /*$$scope*/ ctx[5], null);\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_4__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\t$$slots: {\n\t\t\t\t\ttext: [create_text_slot],\n\t\t\t\t\ticon: [create_icon_slot]\n\t\t\t\t},\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*click_handler*/ ctx[4]);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(heading.$$.fragment);\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (default_slot) default_slot.c();\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex flex-wrap\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex flex-wrap\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"pb-3 pl-3\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", \"flex items-top justify-between\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div3, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(heading, div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\n\t\t\tif (default_slot) {\n\t\t\t\tdefault_slot.m(div0, null);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, div2, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst heading_changes = {};\n\t\t\tif (dirty & /*title*/ 1) heading_changes.heading = /*title*/ ctx[0];\n\t\t\tif (dirty & /*description*/ 2) heading_changes.description = /*description*/ ctx[1];\n\t\t\theading.$set(heading_changes);\n\n\t\t\tif (default_slot) {\n\t\t\t\tif (default_slot.p && (!current || dirty & /*$$scope*/ 32)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\tdefault_slot,\n\t\t\t\t\t\tdefault_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[5],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[5])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(default_slot_template, /*$$scope*/ ctx[5], dirty, null),\n\t\t\t\t\t\tnull\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope*/ 32) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(heading.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(default_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(heading.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(default_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(heading);\n\t\t\tif (default_slot) default_slot.d(detaching);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { $$slots: slots = {}, $$scope } = $$props;\n\tlet { title } = $$props;\n\tlet { description } = $$props;\n\tlet { container } = $$props;\n\tconst click_handler = () => (0,_helpers_export__WEBPACK_IMPORTED_MODULE_5__.exportView)(container, \"Scatterplot\");\n\n\t$$self.$$set = $$props => {\n\t\tif ('title' in $$props) $$invalidate(0, title = $$props.title);\n\t\tif ('description' in $$props) $$invalidate(1, description = $$props.description);\n\t\tif ('container' in $$props) $$invalidate(2, container = $$props.container);\n\t\tif ('$$scope' in $$props) $$invalidate(5, $$scope = $$props.$$scope);\n\t};\n\n\treturn [title, description, container, slots, click_handler, $$scope];\n}\n\nclass ComponentHeader extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { title: 0, description: 1, container: 2 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ComponentHeader);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/ComponentHeader.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Container.svelte":
/*!*********************************************************!*\
  !*** ../../symphony_lib/dist/elements/Container.svelte ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Container.svelte generated by Svelte v3.59.2 */\n\n\nconst get_content_slot_changes = dirty => ({});\nconst get_content_slot_context = ctx => ({});\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[4] = list[i];\n\treturn child_ctx;\n}\n\nconst get_icon_slot_changes = dirty => ({});\nconst get_icon_slot_context = ctx => ({});\nconst get_header_slot_changes = dirty => ({});\nconst get_header_slot_context = ctx => ({});\n\n// (14:4) {#if title !== undefined}\nfunction create_if_block_1(ctx) {\n\tlet span;\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*title*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"pr-2 text-lg\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span, t);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*title*/ 1) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, /*title*/ ctx[0]);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span);\n\t\t}\n\t};\n}\n\n// (17:4) {#if categories !== undefined}\nfunction create_if_block(ctx) {\n\tlet each_1_anchor;\n\tlet each_value = /*categories*/ ctx[1];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\teach_1_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(target, anchor);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, each_1_anchor, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*categories*/ 2) {\n\t\t\t\teach_value = /*categories*/ ctx[1];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(each_1_anchor);\n\t\t}\n\t};\n}\n\n// (18:6) {#each categories as category}\nfunction create_each_block(ctx) {\n\tlet span;\n\tlet t_value = /*category*/ ctx[4] + \"\";\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t_value);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"pr-1 text-sm\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span, t);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*categories*/ 2 && t_value !== (t_value = /*category*/ ctx[4] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, t_value);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div2;\n\tlet div0;\n\tlet t0;\n\tlet div1;\n\tlet t1;\n\tlet t2;\n\tlet t3;\n\tlet current;\n\tconst header_slot_template = /*#slots*/ ctx[3].header;\n\tconst header_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(header_slot_template, ctx, /*$$scope*/ ctx[2], get_header_slot_context);\n\tconst icon_slot_template = /*#slots*/ ctx[3].icon;\n\tconst icon_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(icon_slot_template, ctx, /*$$scope*/ ctx[2], get_icon_slot_context);\n\tlet if_block0 = /*title*/ ctx[0] !== undefined && create_if_block_1(ctx);\n\tlet if_block1 = /*categories*/ ctx[1] !== undefined && create_if_block(ctx);\n\tconst content_slot_template = /*#slots*/ ctx[3].content;\n\tconst content_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(content_slot_template, ctx, /*$$scope*/ ctx[2], get_content_slot_context);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (header_slot) header_slot.c();\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (icon_slot) icon_slot.c();\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block0) if_block0.c();\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block1) if_block1.c();\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (content_slot) content_slot.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex items-top mb-2 justify-between border-b pb-1 border-midgrey\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex items-center\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"flex flex-col border-midgrey border rounded-md p-2 w-full\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div0);\n\n\t\t\tif (header_slot) {\n\t\t\t\theader_slot.m(div0, null);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\n\t\t\tif (icon_slot) {\n\t\t\t\ticon_slot.m(div1, null);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t1);\n\t\t\tif (if_block0) if_block0.m(div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t2);\n\t\t\tif (if_block1) if_block1.m(div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t3);\n\n\t\t\tif (content_slot) {\n\t\t\t\tcontent_slot.m(div2, null);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (header_slot) {\n\t\t\t\tif (header_slot.p && (!current || dirty & /*$$scope*/ 4)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\theader_slot,\n\t\t\t\t\t\theader_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[2],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[2])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(header_slot_template, /*$$scope*/ ctx[2], dirty, get_header_slot_changes),\n\t\t\t\t\t\tget_header_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tif (icon_slot) {\n\t\t\t\tif (icon_slot.p && (!current || dirty & /*$$scope*/ 4)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\ticon_slot,\n\t\t\t\t\t\ticon_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[2],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[2])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(icon_slot_template, /*$$scope*/ ctx[2], dirty, get_icon_slot_changes),\n\t\t\t\t\t\tget_icon_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tif (/*title*/ ctx[0] !== undefined) {\n\t\t\t\tif (if_block0) {\n\t\t\t\t\tif_block0.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block0 = create_if_block_1(ctx);\n\t\t\t\t\tif_block0.c();\n\t\t\t\t\tif_block0.m(div1, t2);\n\t\t\t\t}\n\t\t\t} else if (if_block0) {\n\t\t\t\tif_block0.d(1);\n\t\t\t\tif_block0 = null;\n\t\t\t}\n\n\t\t\tif (/*categories*/ ctx[1] !== undefined) {\n\t\t\t\tif (if_block1) {\n\t\t\t\t\tif_block1.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block1 = create_if_block(ctx);\n\t\t\t\t\tif_block1.c();\n\t\t\t\t\tif_block1.m(div1, null);\n\t\t\t\t}\n\t\t\t} else if (if_block1) {\n\t\t\t\tif_block1.d(1);\n\t\t\t\tif_block1 = null;\n\t\t\t}\n\n\t\t\tif (content_slot) {\n\t\t\t\tif (content_slot.p && (!current || dirty & /*$$scope*/ 4)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\tcontent_slot,\n\t\t\t\t\t\tcontent_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[2],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[2])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(content_slot_template, /*$$scope*/ ctx[2], dirty, get_content_slot_changes),\n\t\t\t\t\t\tget_content_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(header_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(icon_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(content_slot, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(header_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(icon_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(content_slot, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div2);\n\t\t\tif (header_slot) header_slot.d(detaching);\n\t\t\tif (icon_slot) icon_slot.d(detaching);\n\t\t\tif (if_block0) if_block0.d();\n\t\t\tif (if_block1) if_block1.d();\n\t\t\tif (content_slot) content_slot.d(detaching);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { $$slots: slots = {}, $$scope } = $$props;\n\tlet { title = undefined } = $$props;\n\tlet { categories = undefined } = $$props;\n\n\t$$self.$$set = $$props => {\n\t\tif ('title' in $$props) $$invalidate(0, title = $$props.title);\n\t\tif ('categories' in $$props) $$invalidate(1, categories = $$props.categories);\n\t\tif ('$$scope' in $$props) $$invalidate(2, $$scope = $$props.$$scope);\n\t};\n\n\treturn [title, categories, $$scope, slots];\n}\n\nclass Container extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { title: 0, categories: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Container);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Container.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/DataSample.svelte":
/*!**********************************************************!*\
  !*** ../../symphony_lib/dist/elements/DataSample.svelte ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faCheckSquare__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faCheckSquare */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faCheckSquare.js\");\n/* harmony import */ var _helpers_filetype__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../helpers/filetype */ \"../../symphony_lib/dist/helpers/filetype.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/DataSample.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction create_if_block(ctx) {\n\tlet icon;\n\tlet current;\n\n\ticon = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tclass: \"absolute top-0 right-0 bg-white border-2 border-white\",\n\t\t\t\ticon: _fortawesome_free_solid_svg_icons_faCheckSquare__WEBPACK_IMPORTED_MODULE_2__.faCheckSquare\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(icon.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(icon, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(icon.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(icon.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(icon, detaching);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet switch_instance;\n\tlet t;\n\tlet show_if = /*$selected*/ ctx[5].includes(/*id*/ ctx[4]);\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tvar switch_value = (0,_helpers_filetype__WEBPACK_IMPORTED_MODULE_3__.getComponentForType)(/*$symphonySpec*/ ctx[2].dataType);\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\tid: /*id*/ ctx[4],\n\t\t\t\tsymphonySpec: /*symphonySpec*/ ctx[0]\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\tswitch_instance.$on(\"click\", /*click_handler*/ ctx[12]);\n\t}\n\n\tlet if_block = show_if && create_if_block(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block) if_block.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"relative\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\t\t\tif (if_block) if_block.m(div, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"mouseenter\", /*mouseenter_handler*/ ctx[13]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"mouseleave\", /*mouseleave_handler*/ ctx[14]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"mousemove\", /*handleMousemove*/ ctx[7])\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty & /*id*/ 16) switch_instance_changes.id = /*id*/ ctx[4];\n\t\t\tif (dirty & /*symphonySpec*/ 1) switch_instance_changes.symphonySpec = /*symphonySpec*/ ctx[0];\n\n\t\t\tif (dirty & /*$symphonySpec*/ 4 && switch_value !== (switch_value = (0,_helpers_filetype__WEBPACK_IMPORTED_MODULE_3__.getComponentForType)(/*$symphonySpec*/ ctx[2].dataType))) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\tswitch_instance.$on(\"click\", /*click_handler*/ ctx[12]);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div, t);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\n\t\t\tif (dirty & /*$selected, id*/ 48) show_if = /*$selected*/ ctx[5].includes(/*id*/ ctx[4]);\n\n\t\t\tif (show_if) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*$selected, id*/ 48) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\tif_block.m(div, null);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block, 1, 1, () => {\n\t\t\t\t\tif_block = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tif (if_block) if_block.d();\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet id;\n\n\tlet $symphonySpec,\n\t\t$$unsubscribe_symphonySpec = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_symphonySpec = () => ($$unsubscribe_symphonySpec(), $$unsubscribe_symphonySpec = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(symphonySpec, $$value => $$invalidate(2, $symphonySpec = $$value)), symphonySpec);\n\n\tlet $selected,\n\t\t$$unsubscribe_selected = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_selected = () => ($$unsubscribe_selected(), $$unsubscribe_selected = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(selected, $$value => $$invalidate(5, $selected = $$value)), selected);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_symphonySpec());\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_selected());\n\tlet { dataPoint } = $$props;\n\tlet { symphonySpec } = $$props;\n\t$$subscribe_symphonySpec();\n\tlet { selected } = $$props;\n\t$$subscribe_selected();\n\tlet { tooltip } = $$props;\n\tlet { number = undefined } = $$props;\n\tlet hover = false;\n\tlet m = { x: 0, y: 0 };\n\n\tfunction select() {\n\t\tconst index = $selected.indexOf(id);\n\n\t\tif (index > -1) {\n\t\t\tselected.update(d => {\n\t\t\t\td.splice(index, 1);\n\t\t\t\treturn [...d];\n\t\t\t});\n\t\t} else {\n\t\t\tselected.set([...$selected, id]);\n\t\t}\n\t}\n\n\tfunction handleMousemove(event) {\n\t\tm.x = event.clientX;\n\t\tm.y = event.clientY;\n\t\tupdateSampleTooltip();\n\t}\n\n\tfunction updateSampleTooltip() {\n\t\ttooltip.set({\n\t\t\thover,\n\t\t\tmousePos: m,\n\t\t\tfetchPrefix: $symphonySpec.filesPath,\n\t\t\tinstance: dataPoint,\n\t\t\tnumber\n\t\t});\n\t}\n\n\tconst click_handler = () => select();\n\n\tconst mouseenter_handler = () => {\n\t\t$$invalidate(3, hover = true);\n\t\tupdateSampleTooltip();\n\t};\n\n\tconst mouseleave_handler = () => {\n\t\t$$invalidate(3, hover = false);\n\t\tupdateSampleTooltip();\n\t};\n\n\t$$self.$$set = $$props => {\n\t\tif ('dataPoint' in $$props) $$invalidate(9, dataPoint = $$props.dataPoint);\n\t\tif ('symphonySpec' in $$props) $$subscribe_symphonySpec($$invalidate(0, symphonySpec = $$props.symphonySpec));\n\t\tif ('selected' in $$props) $$subscribe_selected($$invalidate(1, selected = $$props.selected));\n\t\tif ('tooltip' in $$props) $$invalidate(10, tooltip = $$props.tooltip);\n\t\tif ('number' in $$props) $$invalidate(11, number = $$props.number);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*dataPoint, $symphonySpec*/ 516) {\n\t\t\t$: $$invalidate(4, id = dataPoint[$symphonySpec.idColumn]);\n\t\t}\n\t};\n\n\treturn [\n\t\tsymphonySpec,\n\t\tselected,\n\t\t$symphonySpec,\n\t\thover,\n\t\tid,\n\t\t$selected,\n\t\tselect,\n\t\thandleMousemove,\n\t\tupdateSampleTooltip,\n\t\tdataPoint,\n\t\ttooltip,\n\t\tnumber,\n\t\tclick_handler,\n\t\tmouseenter_handler,\n\t\tmouseleave_handler\n\t];\n}\n\nclass DataSample extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\tdataPoint: 9,\n\t\t\tsymphonySpec: 0,\n\t\t\tselected: 1,\n\t\t\ttooltip: 10,\n\t\t\tnumber: 11\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (DataSample);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/DataSample.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/DataSampleDetail.svelte":
/*!****************************************************************!*\
  !*** ../../symphony_lib/dist/elements/DataSampleDetail.svelte ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var svelte_transition__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte/transition */ \"../../node_modules/svelte/transition/index.mjs\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faChartBar__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faChartBar */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faChartBar.js\");\n/* harmony import */ var _helpers_filetype__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../helpers/filetype */ \"../../symphony_lib/dist/helpers/filetype.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/DataSampleDetail.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[13] = list[i][0];\n\tchild_ctx[14] = list[i][1];\n\treturn child_ctx;\n}\n\n// (26:0) {#if $tooltip.hover && $tooltip.instance !== undefined}\nfunction create_if_block(ctx) {\n\tlet div3;\n\tlet div0;\n\tlet switch_instance;\n\tlet t0;\n\tlet div2;\n\tlet div1;\n\tlet t1_value = /*$tooltip*/ ctx[6].instance[/*$symphonySpec*/ ctx[8].idColumn] + \"\";\n\tlet t1;\n\tlet t2;\n\tlet t3;\n\tlet div3_resize_listener;\n\tlet div3_transition;\n\tlet current;\n\tvar switch_value = (0,_helpers_filetype__WEBPACK_IMPORTED_MODULE_2__.getComponentForType)(/*$symphonySpec*/ ctx[8].dataType);\n\n\tfunction switch_props(ctx) {\n\t\treturn {\n\t\t\tprops: {\n\t\t\t\tid: /*$tooltip*/ ctx[6].instance[/*$symphonySpec*/ ctx[8].idColumn],\n\t\t\t\tsymphonySpec: /*symphonySpec*/ ctx[0],\n\t\t\t\tlarge: true\n\t\t\t}\n\t\t};\n\t}\n\n\tif (switch_value) {\n\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t}\n\n\tlet if_block = /*$tooltip*/ ctx[6].number !== undefined && create_if_block_2(ctx);\n\tlet each_value = Object.entries(/*$tooltip*/ ctx[6].instance);\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tdiv3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t1_value);\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block) if_block.c();\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex flex-shrink-0\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex font-bold\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"flex flex-col pl-2 pr-4 m-2 mt-0 break-all\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", \"text-sm fixed p-1 rounded text-text-dark shadow z-10 flex mt-4 mb-4\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"style\", /*style*/ ctx[7]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_render_callback)(() => /*div3_elementresize_handler*/ ctx[12].call(div3));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div3, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div0);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div0, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t2);\n\t\t\tif (if_block) if_block.m(div2, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t3);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div2, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tdiv3_resize_listener = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_iframe_resize_listener)(div3, /*div3_elementresize_handler*/ ctx[12].bind(div3));\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst switch_instance_changes = {};\n\t\t\tif (dirty & /*$tooltip, $symphonySpec*/ 320) switch_instance_changes.id = /*$tooltip*/ ctx[6].instance[/*$symphonySpec*/ ctx[8].idColumn];\n\t\t\tif (dirty & /*symphonySpec*/ 1) switch_instance_changes.symphonySpec = /*symphonySpec*/ ctx[0];\n\n\t\t\tif (dirty & /*$symphonySpec*/ 256 && switch_value !== (switch_value = (0,_helpers_filetype__WEBPACK_IMPORTED_MODULE_2__.getComponentForType)(/*$symphonySpec*/ ctx[8].dataType))) {\n\t\t\t\tif (switch_instance) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\t\t\t\t\tconst old_component = switch_instance;\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(old_component.$$.fragment, 1, 0, () => {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(old_component, 1);\n\t\t\t\t\t});\n\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t\t}\n\n\t\t\t\tif (switch_value) {\n\t\t\t\t\tswitch_instance = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.construct_svelte_component)(switch_value, switch_props(ctx));\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(switch_instance.$$.fragment);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, 1);\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(switch_instance, div0, null);\n\t\t\t\t} else {\n\t\t\t\t\tswitch_instance = null;\n\t\t\t\t}\n\t\t\t} else if (switch_value) {\n\t\t\t\tswitch_instance.$set(switch_instance_changes);\n\t\t\t}\n\n\t\t\tif ((!current || dirty & /*$tooltip, $symphonySpec*/ 320) && t1_value !== (t1_value = /*$tooltip*/ ctx[6].instance[/*$symphonySpec*/ ctx[8].idColumn] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t1, t1_value);\n\n\t\t\tif (/*$tooltip*/ ctx[6].number !== undefined) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*$tooltip*/ 64) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block_2(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\tif_block.m(div2, t3);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block, 1, 1, () => {\n\t\t\t\t\tif_block = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (dirty & /*Array, Object, $tooltip, isNaN, Number, $symphonySpec*/ 320) {\n\t\t\t\teach_value = Object.entries(/*$tooltip*/ ctx[6].instance);\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(div2, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*style*/ 128) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"style\", /*style*/ ctx[7]);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(switch_instance.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_render_callback)(() => {\n\t\t\t\tif (!current) return;\n\t\t\t\tif (!div3_transition) div3_transition = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_bidirectional_transition)(div3, svelte_transition__WEBPACK_IMPORTED_MODULE_1__.fade, {}, true);\n\t\t\t\tdiv3_transition.run(1);\n\t\t\t});\n\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(switch_instance.$$.fragment, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\tif (!div3_transition) div3_transition = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_bidirectional_transition)(div3, svelte_transition__WEBPACK_IMPORTED_MODULE_1__.fade, {}, false);\n\t\t\tdiv3_transition.run(0);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div3);\n\t\t\tif (switch_instance) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(switch_instance);\n\t\t\tif (if_block) if_block.d();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tdiv3_resize_listener();\n\t\t\tif (detaching && div3_transition) div3_transition.end();\n\t\t}\n\t};\n}\n\n// (46:6) {#if $tooltip.number !== undefined}\nfunction create_if_block_2(ctx) {\n\tlet div;\n\tlet fa;\n\tlet t0;\n\tlet span;\n\tlet t1_value = /*$tooltip*/ ctx[6].number + \"\";\n\tlet t1;\n\tlet current;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faChartBar__WEBPACK_IMPORTED_MODULE_4__.faChartBar } });\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t1_value);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"ml-2\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"flex flex-nowrap\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, span);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span, t1);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif ((!current || dirty & /*$tooltip*/ 64) && t1_value !== (t1_value = /*$tooltip*/ ctx[6].number + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t1, t1_value);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa);\n\t\t}\n\t};\n}\n\n// (53:8) {#if key !== $symphonySpec.idColumn && !key.startsWith(\"familiarity_\") && !key.startsWith(\"duplicates_\") && !key.startsWith(\"projection_\") && !key.startsWith(\"splitFamiliarity\")}\nfunction create_if_block_1(ctx) {\n\tlet div;\n\tlet span0;\n\tlet t0_value = /*key*/ ctx[13] + \"\";\n\tlet t0;\n\tlet t1;\n\tlet t2;\n\tlet span1;\n\n\tlet t3_value = (Array.isArray(/*val*/ ctx[14])\n\t? /*val*/ ctx[14]\n\t: isNaN(Number.parseFloat(/*val*/ ctx[14]))\n\t\t? /*val*/ ctx[14]\n\t\t: Number.parseFloat(/*val*/ ctx[14]).toFixed(2)) + \"\";\n\n\tlet t3;\n\tlet t4;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tspan0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t0_value);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\":\");\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tspan1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t3_value);\n\t\t\tt4 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span0, \"class\", \"text-bold\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span1, \"class\", \"ml-2 \");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"flex flex-nowrap\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, span0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span0, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span0, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, span1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span1, t3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t4);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*$tooltip*/ 64 && t0_value !== (t0_value = /*key*/ ctx[13] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, t0_value);\n\n\t\t\tif (dirty & /*$tooltip*/ 64 && t3_value !== (t3_value = (Array.isArray(/*val*/ ctx[14])\n\t\t\t? /*val*/ ctx[14]\n\t\t\t: isNaN(Number.parseFloat(/*val*/ ctx[14]))\n\t\t\t\t? /*val*/ ctx[14]\n\t\t\t\t: Number.parseFloat(/*val*/ ctx[14]).toFixed(2)) + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t3, t3_value);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\n// (52:6) {#each Object.entries($tooltip.instance) as [key, val]}\nfunction create_each_block(ctx) {\n\tlet show_if = /*key*/ ctx[13] !== /*$symphonySpec*/ ctx[8].idColumn && !/*key*/ ctx[13].startsWith(\"familiarity_\") && !/*key*/ ctx[13].startsWith(\"duplicates_\") && !/*key*/ ctx[13].startsWith(\"projection_\") && !/*key*/ ctx[13].startsWith(\"splitFamiliarity\");\n\tlet if_block_anchor;\n\tlet if_block = show_if && create_if_block_1(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tif (if_block) if_block.c();\n\t\t\tif_block_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (if_block) if_block.m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, if_block_anchor, anchor);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*$tooltip, $symphonySpec*/ 320) show_if = /*key*/ ctx[13] !== /*$symphonySpec*/ ctx[8].idColumn && !/*key*/ ctx[13].startsWith(\"familiarity_\") && !/*key*/ ctx[13].startsWith(\"duplicates_\") && !/*key*/ ctx[13].startsWith(\"projection_\") && !/*key*/ ctx[13].startsWith(\"splitFamiliarity\");\n\n\t\t\tif (show_if) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block_1(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\tif_block.m(if_block_anchor.parentNode, if_block_anchor);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\tif_block.d(1);\n\t\t\t\tif_block = null;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (if_block) if_block.d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(if_block_anchor);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet if_block_anchor;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_render_callback)(/*onwindowresize*/ ctx[11]);\n\tlet if_block = /*$tooltip*/ ctx[6].hover && /*$tooltip*/ ctx[6].instance !== undefined && create_if_block(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tif (if_block) if_block.c();\n\t\t\tif_block_anchor = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.empty)();\n\t\t},\n\t\tm(target, anchor) {\n\t\t\tif (if_block) if_block.m(target, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, if_block_anchor, anchor);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(window, \"resize\", /*onwindowresize*/ ctx[11]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (/*$tooltip*/ ctx[6].hover && /*$tooltip*/ ctx[6].instance !== undefined) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*$tooltip*/ 64) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\tif_block.m(if_block_anchor.parentNode, if_block_anchor);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block, 1, 1, () => {\n\t\t\t\t\tif_block = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (if_block) if_block.d(detaching);\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(if_block_anchor);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet yPos;\n\tlet xStyle;\n\tlet style;\n\n\tlet $tooltip,\n\t\t$$unsubscribe_tooltip = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_tooltip = () => ($$unsubscribe_tooltip(), $$unsubscribe_tooltip = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(tooltip, $$value => $$invalidate(6, $tooltip = $$value)), tooltip);\n\n\tlet $symphonySpec,\n\t\t$$unsubscribe_symphonySpec = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_symphonySpec = () => ($$unsubscribe_symphonySpec(), $$unsubscribe_symphonySpec = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(symphonySpec, $$value => $$invalidate(8, $symphonySpec = $$value)), symphonySpec);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_tooltip());\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_symphonySpec());\n\tlet { symphonySpec } = $$props;\n\t$$subscribe_symphonySpec();\n\tlet { tooltip } = $$props;\n\t$$subscribe_tooltip();\n\tlet windowWidth = 0;\n\tlet windowHeight = 0;\n\tlet tooltipWidth = 0;\n\tlet tooltipHeight = 0;\n\n\tfunction onwindowresize() {\n\t\t$$invalidate(2, windowWidth = window.innerWidth)\n\t\t$$invalidate(3, windowHeight = window.innerHeight)\n\t}\n\n\tfunction div3_elementresize_handler() {\n\t\ttooltipWidth = this.offsetWidth;\n\t\ttooltipHeight = this.offsetHeight;\n\t\t$$invalidate(4, tooltipWidth);\n\t\t$$invalidate(5, tooltipHeight);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('symphonySpec' in $$props) $$subscribe_symphonySpec($$invalidate(0, symphonySpec = $$props.symphonySpec));\n\t\tif ('tooltip' in $$props) $$subscribe_tooltip($$invalidate(1, tooltip = $$props.tooltip));\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*windowHeight, $tooltip, tooltipHeight*/ 104) {\n\t\t\t$: $$invalidate(10, yPos = windowHeight > $tooltip.mousePos.y + tooltipHeight\n\t\t\t? $tooltip.mousePos.y\n\t\t\t: $tooltip.mousePos.y - tooltipHeight - 20);\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*windowWidth, $tooltip, tooltipWidth*/ 84) {\n\t\t\t$: $$invalidate(9, xStyle = windowWidth > $tooltip.mousePos.x + tooltipWidth + 10\n\t\t\t? `left: ${$tooltip.mousePos.x}px;`\n\t\t\t: `right: 10px;`);\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*yPos, xStyle*/ 1536) {\n\t\t\t$: $$invalidate(7, style = `top: ${yPos}px; ${xStyle}; background: black`);\n\t\t}\n\t};\n\n\treturn [\n\t\tsymphonySpec,\n\t\ttooltip,\n\t\twindowWidth,\n\t\twindowHeight,\n\t\ttooltipWidth,\n\t\ttooltipHeight,\n\t\t$tooltip,\n\t\tstyle,\n\t\t$symphonySpec,\n\t\txStyle,\n\t\tyPos,\n\t\tonwindowresize,\n\t\tdiv3_elementresize_handler\n\t];\n}\n\nclass DataSampleDetail extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { symphonySpec: 0, tooltip: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (DataSampleDetail);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/DataSampleDetail.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Dropdown.svelte":
/*!********************************************************!*\
  !*** ../../symphony_lib/dist/elements/Dropdown.svelte ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Dropdown.svelte generated by Svelte v3.59.2 */\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[3] = list[i];\n\treturn child_ctx;\n}\n\n// (9:2) {#each items as item}\nfunction create_each_block(ctx) {\n\tlet option;\n\tlet t0_value = /*item*/ ctx[3] + \"\";\n\tlet t0;\n\tlet t1;\n\tlet option_value_value;\n\n\treturn {\n\t\tc() {\n\t\t\toption = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"option\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t0_value);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\toption.__value = option_value_value = /*item*/ ctx[3];\n\t\t\toption.value = option.__value;\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, option, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(option, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(option, t1);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*items*/ 2 && t0_value !== (t0_value = /*item*/ ctx[3] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, t0_value);\n\n\t\t\tif (dirty & /*items*/ 2 && option_value_value !== (option_value_value = /*item*/ ctx[3])) {\n\t\t\t\toption.__value = option_value_value;\n\t\t\t\toption.value = option.__value;\n\t\t\t}\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(option);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet select;\n\tlet mounted;\n\tlet dispose;\n\tlet each_value = /*items*/ ctx[1];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\treturn {\n\t\tc() {\n\t\t\tselect = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"select\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(select, \"class\", \"rounded border border-midgrey\");\n\t\t\tif (/*value*/ ctx[0] === void 0) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_render_callback)(() => /*select_change_handler*/ ctx[2].call(select));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, select, anchor);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(select, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.select_option)(select, /*value*/ ctx[0], true);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(select, \"change\", /*select_change_handler*/ ctx[2]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*items*/ 2) {\n\t\t\t\teach_value = /*items*/ ctx[1];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(select, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\n\t\t\tif (dirty & /*value, items*/ 3) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.select_option)(select, /*value*/ ctx[0]);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(select);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { items } = $$props;\n\tlet { value } = $$props;\n\n\tfunction select_change_handler() {\n\t\tvalue = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.select_value)(this);\n\t\t$$invalidate(0, value);\n\t\t$$invalidate(1, items);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('items' in $$props) $$invalidate(1, items = $$props.items);\n\t\tif ('value' in $$props) $$invalidate(0, value = $$props.value);\n\t};\n\n\treturn [value, items, select_change_handler];\n}\n\nclass Dropdown extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { items: 1, value: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Dropdown);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Dropdown.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/GroupChip.svelte":
/*!*********************************************************!*\
  !*** ../../symphony_lib/dist/elements/GroupChip.svelte ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faTimes__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faTimes */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faTimes.js\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/GroupChip.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[4] = list[i];\n\tchild_ctx[6] = i;\n\treturn child_ctx;\n}\n\n// (19:4) {#each values as value, i}\nfunction create_each_block(ctx) {\n\tlet div;\n\tlet t0_value = /*value*/ ctx[4] + \"\";\n\tlet t0;\n\tlet t1;\n\tlet t2_value = (/*i*/ ctx[6] !== /*values*/ ctx[0].length - 1 ? \"|\" : \"\") + \"\";\n\tlet t2;\n\tlet t3;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t0_value);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t2_value);\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"text-s pr-0.5 pl-0.5 font-normal max-w-full flex-initial\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t3);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*values*/ 1 && t0_value !== (t0_value = /*value*/ ctx[4] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, t0_value);\n\t\t\tif (dirty & /*values*/ 1 && t2_value !== (t2_value = (/*i*/ ctx[6] !== /*values*/ ctx[0].length - 1 ? \"|\" : \"\") + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t2, t2_value);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div3;\n\tlet div0;\n\tlet t0;\n\tlet div1;\n\tlet t1;\n\tlet t2_value = /*groupSize*/ ctx[1].toLocaleString() + \"\";\n\tlet t2;\n\tlet t3;\n\tlet t4;\n\tlet div2;\n\tlet button;\n\tlet icon;\n\tlet div3_class_value;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tlet each_value = /*values*/ ctx[0];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\ticon = new svelte_fa__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faTimes__WEBPACK_IMPORTED_MODULE_3__.faTimes } });\n\n\treturn {\n\t\tc() {\n\t\t\tdiv3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"(\");\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t2_value);\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\")\");\n\t\t\tt4 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tbutton = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"button\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(icon.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex h-full pr-0.5 pl-0.5 items-center\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"text-s text-text-dimmed pr-0.5 pl-0.5\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"flex flex-auto pl-1 text-s\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", div3_class_value = \"flex items-center m-1 px-2 h-8 w-max border border-button_outline rounded \" + (/*groupSize*/ ctx[1] > 0 ? 'bg-body-light' : ''));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div3, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div0);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t4);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, button);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(icon, button, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(button, \"click\", /*click_handler*/ ctx[3]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*values*/ 1) {\n\t\t\t\teach_value = /*values*/ ctx[0];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\tfor (; i < each_blocks.length; i += 1) {\n\t\t\t\t\teach_blocks[i].d(1);\n\t\t\t\t}\n\n\t\t\t\teach_blocks.length = each_value.length;\n\t\t\t}\n\n\t\t\tif ((!current || dirty & /*groupSize*/ 2) && t2_value !== (t2_value = /*groupSize*/ ctx[1].toLocaleString() + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t2, t2_value);\n\n\t\t\tif (!current || dirty & /*groupSize*/ 2 && div3_class_value !== (div3_class_value = \"flex items-center m-1 px-2 h-8 w-max border border-button_outline rounded \" + (/*groupSize*/ ctx[1] > 0 ? 'bg-body-light' : ''))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", div3_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(icon.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(icon.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(icon);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { values } = $$props;\n\tlet { groupSize } = $$props;\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\n\tconst click_handler = () => {\n\t\tdispatch(\"remove\", { values });\n\t\t$$invalidate(0, values = []); // clear the value list\n\t};\n\n\t$$self.$$set = $$props => {\n\t\tif ('values' in $$props) $$invalidate(0, values = $$props.values);\n\t\tif ('groupSize' in $$props) $$invalidate(1, groupSize = $$props.groupSize);\n\t};\n\n\treturn [values, groupSize, dispatch, click_handler];\n}\n\nclass GroupChip extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { values: 0, groupSize: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (GroupChip);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/GroupChip.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/HeaderButton.svelte":
/*!************************************************************!*\
  !*** ../../symphony_lib/dist/elements/HeaderButton.svelte ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/HeaderButton.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet button;\n\tlet t;\n\tlet button_class_value;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tbutton = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"button\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*value*/ ctx[1]);\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(button, \"class\", button_class_value = \"bg-transparent px-2 \" + (/*selected*/ ctx[0]\n\t\t\t? 'text-text-dark'\n\t\t\t: 'text-text-dimmed hover:text-text-dark'));\n\n\t\t\tbutton.value = /*value*/ ctx[1];\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, button, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(button, t);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(button, \"click\", /*click_handler*/ ctx[2]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*value*/ 2) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, /*value*/ ctx[1]);\n\n\t\t\tif (dirty & /*selected*/ 1 && button_class_value !== (button_class_value = \"bg-transparent px-2 \" + (/*selected*/ ctx[0]\n\t\t\t? 'text-text-dark'\n\t\t\t: 'text-text-dimmed hover:text-text-dark'))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(button, \"class\", button_class_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*value*/ 2) {\n\t\t\t\tbutton.value = /*value*/ ctx[1];\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(button);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { selected } = $$props;\n\tlet { value } = $$props;\n\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('selected' in $$props) $$invalidate(0, selected = $$props.selected);\n\t\tif ('value' in $$props) $$invalidate(1, value = $$props.value);\n\t};\n\n\treturn [selected, value, click_handler];\n}\n\nclass HeaderButton extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { selected: 0, value: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (HeaderButton);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/HeaderButton.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Heading.svelte":
/*!*******************************************************!*\
  !*** ../../symphony_lib/dist/elements/Heading.svelte ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _Tooltip_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./Tooltip.svelte */ \"../../symphony_lib/dist/elements/Tooltip.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Heading.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet div1;\n\tlet div0;\n\tlet h2;\n\tlet t0;\n\tlet t1;\n\tlet tooltip;\n\tlet current;\n\ttooltip = new _Tooltip_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: { text: /*description*/ ctx[1] } });\n\n\treturn {\n\t\tc() {\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\th2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"h2\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*heading*/ ctx[0]);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(tooltip.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(h2, \"class\", \"text-2xl font-bold leading-7 text-gray-900 pr-2\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex items-center\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex items-center justify-between pb-3 pr-4\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div1, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, h2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(h2, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(tooltip, div0, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (!current || dirty & /*heading*/ 1) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, /*heading*/ ctx[0]);\n\t\t\tconst tooltip_changes = {};\n\t\t\tif (dirty & /*description*/ 2) tooltip_changes.text = /*description*/ ctx[1];\n\t\t\ttooltip.$set(tooltip_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(tooltip.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(tooltip.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(tooltip);\n\t\t}\n\t};\n}\n\nlet hover = false;\nlet offsetX = 0;\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { heading } = $$props;\n\tlet { description } = $$props;\n\n\t$$self.$$set = $$props => {\n\t\tif ('heading' in $$props) $$invalidate(0, heading = $$props.heading);\n\t\tif ('description' in $$props) $$invalidate(1, description = $$props.description);\n\t};\n\n\treturn [heading, description];\n}\n\nclass Heading extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { heading: 0, description: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Heading);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Heading.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/IconButton.svelte":
/*!**********************************************************!*\
  !*** ../../symphony_lib/dist/elements/IconButton.svelte ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/IconButton.svelte generated by Svelte v3.59.2 */\n\n\nconst get_text_slot_changes = dirty => ({});\nconst get_text_slot_context = ctx => ({});\nconst get_icon_slot_changes = dirty => ({});\nconst get_icon_slot_context = ctx => ({});\n\n// (15:4) {#if $$slots.icon}\nfunction create_if_block(ctx) {\n\tlet div;\n\tlet div_class_value;\n\tlet current;\n\tconst icon_slot_template = /*#slots*/ ctx[3].icon;\n\tconst icon_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(icon_slot_template, ctx, /*$$scope*/ ctx[2], get_icon_slot_context);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (icon_slot) icon_slot.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value = /*$$slots*/ ctx[1].text ? \"pr-2 flex\" : \"flex\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\n\t\t\tif (icon_slot) {\n\t\t\t\ticon_slot.m(div, null);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (icon_slot) {\n\t\t\t\tif (icon_slot.p && (!current || dirty & /*$$scope*/ 4)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\ticon_slot,\n\t\t\t\t\t\ticon_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[2],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[2])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(icon_slot_template, /*$$scope*/ ctx[2], dirty, get_icon_slot_changes),\n\t\t\t\t\t\tget_icon_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*$$slots*/ 2 && div_class_value !== (div_class_value = /*$$slots*/ ctx[1].text ? \"pr-2 flex\" : \"flex\")) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", div_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(icon_slot, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(icon_slot, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tif (icon_slot) icon_slot.d(detaching);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet button;\n\tlet div;\n\tlet t;\n\tlet button_class_value;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tlet if_block = /*$$slots*/ ctx[1].icon && create_if_block(ctx);\n\tconst text_slot_template = /*#slots*/ ctx[3].text;\n\tconst text_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(text_slot_template, ctx, /*$$scope*/ ctx[2], get_text_slot_context);\n\n\treturn {\n\t\tc() {\n\t\t\tbutton = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"button\");\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tif (if_block) if_block.c();\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (text_slot) text_slot.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"flex items-center\");\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(button, \"class\", button_class_value = \"\" + ((/*filled*/ ctx[0]\n\t\t\t? 'bg-button hover:bg-button_hover text-text-dark'\n\t\t\t: 'bg-white text-button border border-button hover:bg-button hover:text-white') + \" rounded-md py-1 px-2 transition\"));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, button, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(button, div);\n\t\t\tif (if_block) if_block.m(div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\n\t\t\tif (text_slot) {\n\t\t\t\ttext_slot.m(div, null);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(button, \"click\", /*click_handler*/ ctx[4]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(button, \"mouseleave\", /*mouseleave_handler*/ ctx[5])\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (/*$$slots*/ ctx[1].icon) {\n\t\t\t\tif (if_block) {\n\t\t\t\t\tif_block.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*$$slots*/ 2) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block = create_if_block(ctx);\n\t\t\t\t\tif_block.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block, 1);\n\t\t\t\t\tif_block.m(div, t);\n\t\t\t\t}\n\t\t\t} else if (if_block) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block, 1, 1, () => {\n\t\t\t\t\tif_block = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (text_slot) {\n\t\t\t\tif (text_slot.p && (!current || dirty & /*$$scope*/ 4)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\ttext_slot,\n\t\t\t\t\t\ttext_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[2],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[2])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(text_slot_template, /*$$scope*/ ctx[2], dirty, get_text_slot_changes),\n\t\t\t\t\t\tget_text_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*filled*/ 1 && button_class_value !== (button_class_value = \"\" + ((/*filled*/ ctx[0]\n\t\t\t? 'bg-button hover:bg-button_hover text-text-dark'\n\t\t\t: 'bg-white text-button border border-button hover:bg-button hover:text-white') + \" rounded-md py-1 px-2 transition\"))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(button, \"class\", button_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(text_slot, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(text_slot, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(button);\n\t\t\tif (if_block) if_block.d();\n\t\t\tif (text_slot) text_slot.d(detaching);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { $$slots: slots = {}, $$scope } = $$props;\n\tconst $$slots = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.compute_slots)(slots);\n\tlet { filled = false } = $$props;\n\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\tfunction mouseleave_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('filled' in $$props) $$invalidate(0, filled = $$props.filled);\n\t\tif ('$$scope' in $$props) $$invalidate(2, $$scope = $$props.$$scope);\n\t};\n\n\treturn [filled, $$slots, $$scope, slots, click_handler, mouseleave_handler];\n}\n\nclass IconButton extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { filled: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (IconButton);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/IconButton.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/ImageSample.svelte":
/*!***********************************************************!*\
  !*** ../../symphony_lib/dist/elements/ImageSample.svelte ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _fireflysemantics_join__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @fireflysemantics/join */ \"../../node_modules/@fireflysemantics/join/fesm2015/fireflysemantics-join.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/ImageSample.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet img;\n\tlet img_src_value;\n\tlet img_alt_value;\n\tlet img_class_value;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\timg = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"img\");\n\t\t\tif (!(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.src_url_equal)(img.src, img_src_value = (0,_fireflysemantics_join__WEBPACK_IMPORTED_MODULE_1__.join)(/*$symphonySpec*/ ctx[3].filesPath, /*id*/ ctx[0]))) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"src\", img_src_value);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"alt\", img_alt_value = \"Image with title: \" + /*id*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"class\", img_class_value = /*large*/ ctx[2] ? \"mx-1\" : \"w-12 m-1\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(img, \"background\", \"black\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_style)(img, \"max-width\", \"250px\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, img);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(img, \"click\", /*click_handler*/ ctx[4]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*$symphonySpec, id*/ 9 && !(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.src_url_equal)(img.src, img_src_value = (0,_fireflysemantics_join__WEBPACK_IMPORTED_MODULE_1__.join)(/*$symphonySpec*/ ctx[3].filesPath, /*id*/ ctx[0]))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"src\", img_src_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*id*/ 1 && img_alt_value !== (img_alt_value = \"Image with title: \" + /*id*/ ctx[0])) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"alt\", img_alt_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*large*/ 4 && img_class_value !== (img_class_value = /*large*/ ctx[2] ? \"mx-1\" : \"w-12 m-1\")) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(img, \"class\", img_class_value);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet $symphonySpec,\n\t\t$$unsubscribe_symphonySpec = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_symphonySpec = () => ($$unsubscribe_symphonySpec(), $$unsubscribe_symphonySpec = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(symphonySpec, $$value => $$invalidate(3, $symphonySpec = $$value)), symphonySpec);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_symphonySpec());\n\tlet { id } = $$props;\n\tlet { symphonySpec } = $$props;\n\t$$subscribe_symphonySpec();\n\tlet { large = false } = $$props;\n\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('id' in $$props) $$invalidate(0, id = $$props.id);\n\t\tif ('symphonySpec' in $$props) $$subscribe_symphonySpec($$invalidate(1, symphonySpec = $$props.symphonySpec));\n\t\tif ('large' in $$props) $$invalidate(2, large = $$props.large);\n\t};\n\n\treturn [id, symphonySpec, large, $symphonySpec, click_handler];\n}\n\nclass ImageSample extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { id: 0, symphonySpec: 1, large: 2 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ImageSample);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/ImageSample.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/MultiSelect.svelte":
/*!***********************************************************!*\
  !*** ../../symphony_lib/dist/elements/MultiSelect.svelte ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_select__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-select */ \"../../node_modules/svelte-select/src/index.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/MultiSelect.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet select;\n\tlet current;\n\n\tselect = new svelte_select__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tvalue: /*value*/ ctx[2],\n\t\t\t\tplaceholder: /*placeholder*/ ctx[0],\n\t\t\t\titems: /*items*/ ctx[1],\n\t\t\t\tisMulti: true\n\t\t\t}\n\t\t});\n\n\tselect.$on(\"select\", /*select_handler*/ ctx[3]);\n\tselect.$on(\"clear\", /*clear_handler*/ ctx[4]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(select.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(select, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst select_changes = {};\n\t\t\tif (dirty & /*value*/ 4) select_changes.value = /*value*/ ctx[2];\n\t\t\tif (dirty & /*placeholder*/ 1) select_changes.placeholder = /*placeholder*/ ctx[0];\n\t\t\tif (dirty & /*items*/ 2) select_changes.items = /*items*/ ctx[1];\n\t\t\tselect.$set(select_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(select.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(select.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(select, detaching);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { placeholder } = $$props;\n\tlet { items } = $$props;\n\tlet { value } = $$props;\n\n\tfunction select_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\tfunction clear_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('placeholder' in $$props) $$invalidate(0, placeholder = $$props.placeholder);\n\t\tif ('items' in $$props) $$invalidate(1, items = $$props.items);\n\t\tif ('value' in $$props) $$invalidate(2, value = $$props.value);\n\t};\n\n\treturn [placeholder, items, value, select_handler, clear_handler];\n}\n\nclass MultiSelect extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { placeholder: 0, items: 1, value: 2 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MultiSelect);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/MultiSelect.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/NumberInput.svelte":
/*!***********************************************************!*\
  !*** ../../symphony_lib/dist/elements/NumberInput.svelte ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/NumberInput.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet span;\n\tlet t0;\n\tlet t1;\n\tlet input;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*title*/ ctx[1]);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tinput = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"input\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"pr-1\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"class\", \"rounded border border-midgrey w-24\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"type\", \"number\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"flex justify-between items-center\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, span);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, input);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input, /*value*/ ctx[0]);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(input, \"input\", /*input_input_handler*/ ctx[2]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*title*/ 2) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, /*title*/ ctx[1]);\n\n\t\t\tif (dirty & /*value*/ 1 && (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.to_number)(input.value) !== /*value*/ ctx[0]) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input, /*value*/ ctx[0]);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { value } = $$props;\n\tlet { title } = $$props;\n\n\tfunction input_input_handler() {\n\t\tvalue = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.to_number)(this.value);\n\t\t$$invalidate(0, value);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('value' in $$props) $$invalidate(0, value = $$props.value);\n\t\tif ('title' in $$props) $$invalidate(1, title = $$props.title);\n\t};\n\n\treturn [value, title, input_input_handler];\n}\n\nclass NumberInput extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { value: 0, title: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (NumberInput);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/NumberInput.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Pagination.svelte":
/*!**********************************************************!*\
  !*** ../../symphony_lib/dist/elements/Pagination.svelte ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _helpers_selection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../helpers/selection */ \"../../symphony_lib/dist/helpers/selection.js\");\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* harmony import */ var _DataSample_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./DataSample.svelte */ \"../../symphony_lib/dist/elements/DataSample.svelte\");\n/* harmony import */ var _PaginationControls_svelte__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./PaginationControls.svelte */ \"../../symphony_lib/dist/elements/PaginationControls.svelte\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faCheckSquare__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faCheckSquare */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faCheckSquare.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Pagination.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\nconst get_extra_slot_changes = dirty => ({});\nconst get_extra_slot_context = ctx => ({});\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[13] = list[i];\n\treturn child_ctx;\n}\n\n// (44:6) \nfunction create_icon_slot(ctx) {\n\tlet fa;\n\tlet current;\n\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: { icon: _fortawesome_free_solid_svg_icons_faCheckSquare__WEBPACK_IMPORTED_MODULE_2__.faCheckSquare, slot: \"icon\" }\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\n// (51:6) {#each dataPoints as dataPoint}\nfunction create_each_block(ctx) {\n\tlet datasample;\n\tlet current;\n\n\tdatasample = new _DataSample_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tdataPoint: /*dataPoint*/ ctx[13],\n\t\t\t\tsymphonySpec: /*symphonySpec*/ ctx[3],\n\t\t\t\tselected: /*selected*/ ctx[2],\n\t\t\t\ttooltip: /*tooltip*/ ctx[4]\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(datasample.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(datasample, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst datasample_changes = {};\n\t\t\tif (dirty & /*dataPoints*/ 128) datasample_changes.dataPoint = /*dataPoint*/ ctx[13];\n\t\t\tif (dirty & /*symphonySpec*/ 8) datasample_changes.symphonySpec = /*symphonySpec*/ ctx[3];\n\t\t\tif (dirty & /*selected*/ 4) datasample_changes.selected = /*selected*/ ctx[2];\n\t\t\tif (dirty & /*tooltip*/ 16) datasample_changes.tooltip = /*tooltip*/ ctx[4];\n\t\t\tdatasample.$set(datasample_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(datasample.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(datasample.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(datasample, detaching);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div3;\n\tlet div0;\n\tlet h3;\n\tlet t0;\n\tlet t1;\n\tlet iconbutton;\n\tlet t2;\n\tlet div2;\n\tlet div1;\n\tlet t3;\n\tlet t4;\n\tlet paginationcontrols;\n\tlet updating_page;\n\tlet current;\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_4__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tuiChange: true,\n\t\t\t\t$$slots: { icon: [create_icon_slot] },\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*click_handler*/ ctx[9]);\n\tlet each_value = /*dataPoints*/ ctx[7];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\tconst out = i => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i], 1, 1, () => {\n\t\teach_blocks[i] = null;\n\t});\n\n\tconst extra_slot_template = /*#slots*/ ctx[8].extra;\n\tconst extra_slot = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_slot)(extra_slot_template, ctx, /*$$scope*/ ctx[11], get_extra_slot_context);\n\n\tfunction paginationcontrols_page_binding(value) {\n\t\t/*paginationcontrols_page_binding*/ ctx[10](value);\n\t}\n\n\tlet paginationcontrols_props = {\n\t\tsize: /*filteredTable*/ ctx[1].size,\n\t\tinstancesPerPage: /*$symphonySpec*/ ctx[6].instancesPerPage\n\t};\n\n\tif (/*page*/ ctx[5] !== void 0) {\n\t\tpaginationcontrols_props.page = /*page*/ ctx[5];\n\t}\n\n\tpaginationcontrols = new _PaginationControls_svelte__WEBPACK_IMPORTED_MODULE_5__[\"default\"]({ props: paginationcontrols_props });\n\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks.push(() => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.bind)(paginationcontrols, 'page', paginationcontrols_page_binding));\n\n\treturn {\n\t\tc() {\n\t\t\tdiv3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\th3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"h3\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*title*/ ctx[0]);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (extra_slot) extra_slot.c();\n\t\t\tt4 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(paginationcontrols.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(h3, \"class\", \"font-bold whitespace-nowrap mr-3\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex items-center mb-2 justify-between border-b pb-1 border-midgrey\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex flex-wrap content-top\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"flex flex-nowrap items-top border-b border-midgrey justify-between\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", \"w-full border rounded-md border-midgrey p-2\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div3, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, h3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(h3, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, div0, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div1, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t3);\n\n\t\t\tif (extra_slot) {\n\t\t\t\textra_slot.m(div2, null);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, t4);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(paginationcontrols, div3, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (!current || dirty & /*title*/ 1) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, /*title*/ ctx[0]);\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope*/ 2048) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\n\t\t\tif (dirty & /*dataPoints, symphonySpec, selected, tooltip*/ 156) {\n\t\t\t\teach_value = /*dataPoints*/ ctx[7];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t\teach_blocks[i].m(div1, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\tfor (i = each_value.length; i < each_blocks.length; i += 1) {\n\t\t\t\t\tout(i);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (extra_slot) {\n\t\t\t\tif (extra_slot.p && (!current || dirty & /*$$scope*/ 2048)) {\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.update_slot_base)(\n\t\t\t\t\t\textra_slot,\n\t\t\t\t\t\textra_slot_template,\n\t\t\t\t\t\tctx,\n\t\t\t\t\t\t/*$$scope*/ ctx[11],\n\t\t\t\t\t\t!current\n\t\t\t\t\t\t? (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_all_dirty_from_scope)(/*$$scope*/ ctx[11])\n\t\t\t\t\t\t: (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.get_slot_changes)(extra_slot_template, /*$$scope*/ ctx[11], dirty, get_extra_slot_changes),\n\t\t\t\t\t\tget_extra_slot_context\n\t\t\t\t\t);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\tconst paginationcontrols_changes = {};\n\t\t\tif (dirty & /*filteredTable*/ 2) paginationcontrols_changes.size = /*filteredTable*/ ctx[1].size;\n\t\t\tif (dirty & /*$symphonySpec*/ 64) paginationcontrols_changes.instancesPerPage = /*$symphonySpec*/ ctx[6].instancesPerPage;\n\n\t\t\tif (!updating_page && dirty & /*page*/ 32) {\n\t\t\t\tupdating_page = true;\n\t\t\t\tpaginationcontrols_changes.page = /*page*/ ctx[5];\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.add_flush_callback)(() => updating_page = false);\n\t\t\t}\n\n\t\t\tpaginationcontrols.$set(paginationcontrols_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(extra_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(paginationcontrols.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\teach_blocks = each_blocks.filter(Boolean);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(extra_slot, local);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(paginationcontrols.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (extra_slot) extra_slot.d(detaching);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(paginationcontrols);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet dataPoints;\n\n\tlet $symphonySpec,\n\t\t$$unsubscribe_symphonySpec = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_symphonySpec = () => ($$unsubscribe_symphonySpec(), $$unsubscribe_symphonySpec = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(symphonySpec, $$value => $$invalidate(6, $symphonySpec = $$value)), symphonySpec);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_symphonySpec());\n\tlet { $$slots: slots = {}, $$scope } = $$props;\n\tlet { title } = $$props;\n\tlet { filteredTable } = $$props;\n\tlet { selected } = $$props;\n\tlet { symphonySpec } = $$props;\n\t$$subscribe_symphonySpec();\n\tlet { tooltip } = $$props;\n\tlet page = 0;\n\n\tfunction resetPage() {\n\t\t$$invalidate(5, page = 0);\n\t}\n\n\tconst click_handler = () => {\n\t\t(0,_helpers_selection__WEBPACK_IMPORTED_MODULE_6__.selectAll)(selected, dataPoints.map(d => d[$symphonySpec.idColumn]));\n\t};\n\n\tfunction paginationcontrols_page_binding(value) {\n\t\tpage = value;\n\t\t$$invalidate(5, page);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('title' in $$props) $$invalidate(0, title = $$props.title);\n\t\tif ('filteredTable' in $$props) $$invalidate(1, filteredTable = $$props.filteredTable);\n\t\tif ('selected' in $$props) $$invalidate(2, selected = $$props.selected);\n\t\tif ('symphonySpec' in $$props) $$subscribe_symphonySpec($$invalidate(3, symphonySpec = $$props.symphonySpec));\n\t\tif ('tooltip' in $$props) $$invalidate(4, tooltip = $$props.tooltip);\n\t\tif ('$$scope' in $$props) $$invalidate(11, $$scope = $$props.$$scope);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*filteredTable*/ 2) {\n\t\t\t$: {\n\t\t\t\tfilteredTable;\n\t\t\t\tresetPage();\n\t\t\t}\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*filteredTable, page, $symphonySpec*/ 98) {\n\t\t\t$: $$invalidate(7, dataPoints = filteredTable.slice(page * $symphonySpec.instancesPerPage, Math.min(page * $symphonySpec.instancesPerPage + $symphonySpec.instancesPerPage, filteredTable.size)).objects());\n\t\t}\n\t};\n\n\treturn [\n\t\ttitle,\n\t\tfilteredTable,\n\t\tselected,\n\t\tsymphonySpec,\n\t\ttooltip,\n\t\tpage,\n\t\t$symphonySpec,\n\t\tdataPoints,\n\t\tslots,\n\t\tclick_handler,\n\t\tpaginationcontrols_page_binding,\n\t\t$$scope\n\t];\n}\n\nclass Pagination extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\ttitle: 0,\n\t\t\tfilteredTable: 1,\n\t\t\tselected: 2,\n\t\t\tsymphonySpec: 3,\n\t\t\ttooltip: 4\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Pagination);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Pagination.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/PaginationControls.svelte":
/*!******************************************************************!*\
  !*** ../../symphony_lib/dist/elements/PaginationControls.svelte ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/PaginationControls.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet div3;\n\tlet div2;\n\tlet div0;\n\tlet p0;\n\tlet t0;\n\tlet span0;\n\tlet t1_value = /*page*/ ctx[0] * /*instancesPerPage*/ ctx[1] + 1 + \"\";\n\tlet t1;\n\tlet t2;\n\tlet span1;\n\tlet t3_value = Math.min(/*page*/ ctx[0] * /*instancesPerPage*/ ctx[1] + /*instancesPerPage*/ ctx[1], /*size*/ ctx[2]) + \"\";\n\tlet t3;\n\tlet t4;\n\tlet span2;\n\tlet t5;\n\tlet t6;\n\tlet t7;\n\tlet div1;\n\tlet nav;\n\tlet p1;\n\tlet t10;\n\tlet p2;\n\tlet t11;\n\tlet t12_value = /*page*/ ctx[0] + 1 + \"\";\n\tlet t12;\n\tlet t13;\n\tlet t14;\n\tlet t15;\n\tlet p3;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tp0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"Showing\\n        \");\n\t\t\tspan0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t1_value);\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"\\n        to\\n        \");\n\t\t\tspan1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t3_value);\n\t\t\tt4 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"\\n        of\\n        \");\n\t\t\tspan2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt5 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*size*/ ctx[2]);\n\t\t\tt6 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"\\n        results\");\n\t\t\tt7 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tnav = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"nav\");\n\t\t\tp1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\n\t\t\tp1.innerHTML = `<span class=\"sr-only\">Previous</span> \n          \n          <svg class=\"h-5 w-5\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 20 20\" fill=\"currentColor\" aria-hidden=\"true\"><path fill-rule=\"evenodd\" d=\"M12.707 5.293a1 1 0 010 1.414L9.414 10l3.293 3.293a1 1 0 01-1.414 1.414l-4-4a1 1 0 010-1.414l4-4a1 1 0 011.414 0z\" clip-rule=\"evenodd\"></path></svg>`;\n\n\t\t\tt10 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tp2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\t\t\tt11 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"Page \");\n\t\t\tt12 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t12_value);\n\t\t\tt13 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\" of \");\n\t\t\tt14 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*maxPage*/ ctx[3]);\n\t\t\tt15 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tp3 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\n\t\t\tp3.innerHTML = `<span class=\"sr-only\">Next</span> \n          \n          <svg class=\"h-5 w-5\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 20 20\" fill=\"currentColor\" aria-hidden=\"true\"><path fill-rule=\"evenodd\" d=\"M7.293 14.707a1 1 0 010-1.414L10.586 10 7.293 6.707a1 1 0 011.414-1.414l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414 0z\" clip-rule=\"evenodd\"></path></svg>`;\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span0, \"class\", \"font-medium\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span1, \"class\", \"font-medium\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span2, \"class\", \"font-medium\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p0, \"class\", \"text-sm text-gray-700\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p1, \"class\", \"bg-white relative cursor-pointer inline-flex items-center px-2 py-2 rounded-l-md border border-lightgrey text-sm font-medium text-gray-500 hover:bg-lightgrey\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p2, \"aria-current\", \"page\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p2, \"class\", \"z-10 bg-indigo-50 border-lightgrey text-indigo-600 relative inline-flex items-center px-4 py-2 border text-sm font-medium bg-white\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p3, \"class\", \"bg-white relative cursor-pointer inline-flex items-center px-2 py-2 rounded-r-md border border-lightgrey text-sm font-medium text-gray-500 hover:bg-lightgrey\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(nav, \"class\", \"relative z-0 inline-flex rounded-md shadow-sm -space-x-px\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(nav, \"aria-label\", \"Pagination\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"sm:flex-1 sm:flex sm:items-center sm:justify-between\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div3, \"class\", \"pt-2 flex items-center justify-between\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div3, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div3, div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div0, p0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, span0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span0, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, t2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, span1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span1, t3);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, t4);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, span2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span2, t5);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p0, t6);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t7);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, nav);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, p1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, t10);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, p2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p2, t11);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p2, t12);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p2, t13);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p2, t14);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, t15);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(nav, p3);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = [\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(p1, \"click\", /*click_handler*/ ctx[4]),\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(p3, \"click\", /*click_handler_1*/ ctx[5])\n\t\t\t\t];\n\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*page, instancesPerPage*/ 3 && t1_value !== (t1_value = /*page*/ ctx[0] * /*instancesPerPage*/ ctx[1] + 1 + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t1, t1_value);\n\t\t\tif (dirty & /*page, instancesPerPage, size*/ 7 && t3_value !== (t3_value = Math.min(/*page*/ ctx[0] * /*instancesPerPage*/ ctx[1] + /*instancesPerPage*/ ctx[1], /*size*/ ctx[2]) + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t3, t3_value);\n\t\t\tif (dirty & /*size*/ 4) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t5, /*size*/ ctx[2]);\n\t\t\tif (dirty & /*page*/ 1 && t12_value !== (t12_value = /*page*/ ctx[0] + 1 + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t12, t12_value);\n\t\t\tif (dirty & /*maxPage*/ 8) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t14, /*maxPage*/ ctx[3]);\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div3);\n\t\t\tmounted = false;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.run_all)(dispose);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet maxPage;\n\tlet { instancesPerPage } = $$props;\n\tlet { size } = $$props;\n\tlet { page = 0 } = $$props;\n\tconst click_handler = () => page !== 0 ? $$invalidate(0, page--, page) : \"\";\n\tconst click_handler_1 = () => page < maxPage - 1 ? $$invalidate(0, page++, page) : \"\";\n\n\t$$self.$$set = $$props => {\n\t\tif ('instancesPerPage' in $$props) $$invalidate(1, instancesPerPage = $$props.instancesPerPage);\n\t\tif ('size' in $$props) $$invalidate(2, size = $$props.size);\n\t\tif ('page' in $$props) $$invalidate(0, page = $$props.page);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*size, instancesPerPage*/ 6) {\n\t\t\t$: $$invalidate(3, maxPage = Math.ceil(size / instancesPerPage));\n\t\t}\n\t};\n\n\treturn [page, instancesPerPage, size, maxPage, click_handler, click_handler_1];\n}\n\nclass PaginationControls extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { instancesPerPage: 1, size: 2, page: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (PaginationControls);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/PaginationControls.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Promo.svelte":
/*!*****************************************************!*\
  !*** ../../symphony_lib/dist/elements/Promo.svelte ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_brands_svg_icons_faGithub__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-brands-svg-icons/faGithub */ \"../../node_modules/@fortawesome/free-brands-svg-icons/faGithub.js\");\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Promo.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction create_icon_slot(ctx) {\n\tlet fa;\n\tlet current;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: { icon: _fortawesome_free_brands_svg_icons_faGithub__WEBPACK_IMPORTED_MODULE_2__.faGithub, slot: \"icon\" } });\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\n// (18:4) \nfunction create_text_slot(ctx) {\n\tlet span;\n\n\treturn {\n\t\tc() {\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tspan.textContent = \"Use Symphony\";\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"slot\", \"text\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, span, anchor);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(span);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet iconbutton;\n\tlet current;\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tfilled: true,\n\t\t\t\t$$slots: {\n\t\t\t\t\ttext: [create_text_slot],\n\t\t\t\t\ticon: [create_icon_slot]\n\t\t\t\t},\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*click_handler*/ ctx[0]);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, div, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope*/ 2) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton);\n\t\t}\n\t};\n}\n\nfunction instance($$self) {\n\tconst click_handler = () => window.open(\"https://github.com/apple/ml-symphony\", \"_blank\");\n\treturn [click_handler];\n}\n\nclass Promo extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Promo);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Promo.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/SampleRowContainer.svelte":
/*!******************************************************************!*\
  !*** ../../symphony_lib/dist/elements/SampleRowContainer.svelte ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _DataSample_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./DataSample.svelte */ \"../../symphony_lib/dist/elements/DataSample.svelte\");\n/* harmony import */ var _IconButton_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./IconButton.svelte */ \"../../symphony_lib/dist/elements/IconButton.svelte\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faEyeSlash__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faEyeSlash */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faEyeSlash.js\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faEye__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faEye */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faEye.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/SampleRowContainer.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[8] = list[i];\n\treturn child_ctx;\n}\n\n// (19:4) {#each dataPoints.slice(0, numberShown) as dataPoint}\nfunction create_each_block(ctx) {\n\tlet datasample;\n\tlet current;\n\n\tdatasample = new _DataSample_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\tdataPoint: /*dataPoint*/ ctx[8],\n\t\t\t\tsymphonySpec: /*symphonySpec*/ ctx[3],\n\t\t\t\tselected: /*selected*/ ctx[2],\n\t\t\t\ttooltip: /*tooltip*/ ctx[4]\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(datasample.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(datasample, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst datasample_changes = {};\n\t\t\tif (dirty & /*dataPoints, numberShown*/ 34) datasample_changes.dataPoint = /*dataPoint*/ ctx[8];\n\t\t\tif (dirty & /*symphonySpec*/ 8) datasample_changes.symphonySpec = /*symphonySpec*/ ctx[3];\n\t\t\tif (dirty & /*selected*/ 4) datasample_changes.selected = /*selected*/ ctx[2];\n\t\t\tif (dirty & /*tooltip*/ 16) datasample_changes.tooltip = /*tooltip*/ ctx[4];\n\t\t\tdatasample.$set(datasample_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(datasample.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(datasample.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(datasample, detaching);\n\t\t}\n\t};\n}\n\n// (23:2) {#if dataPoints.length > numberShown}\nfunction create_if_block_1(ctx) {\n\tlet iconbutton;\n\tlet current;\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\t$$slots: {\n\t\t\t\t\ttext: [create_text_slot_1],\n\t\t\t\t\ticon: [create_icon_slot_1]\n\t\t\t\t},\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*click_handler*/ ctx[6]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope, dataPoints, defaultNumberShown*/ 2051) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton, detaching);\n\t\t}\n\t};\n}\n\n// (25:6) \nfunction create_icon_slot_1(ctx) {\n\tlet fa;\n\tlet current;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faEye__WEBPACK_IMPORTED_MODULE_4__.faEye, slot: \"icon\" } });\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\n// (26:6) \nfunction create_text_slot_1(ctx) {\n\tlet p;\n\tlet t0;\n\tlet t1_value = /*dataPoints*/ ctx[1].length - /*defaultNumberShown*/ ctx[0] + \"\";\n\tlet t1;\n\tlet t2;\n\n\treturn {\n\t\tc() {\n\t\t\tp = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\"Show \");\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(t1_value);\n\t\t\tt2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(\" more\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p, \"slot\", \"text\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, p, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(p, t2);\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tif (dirty & /*dataPoints, defaultNumberShown*/ 3 && t1_value !== (t1_value = /*dataPoints*/ ctx[1].length - /*defaultNumberShown*/ ctx[0] + \"\")) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t1, t1_value);\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(p);\n\t\t}\n\t};\n}\n\n// (29:2) {#if dataPoints.length === numberShown && dataPoints.length > defaultNumberShown}\nfunction create_if_block(ctx) {\n\tlet iconbutton;\n\tlet current;\n\n\ticonbutton = new _IconButton_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\t$$slots: {\n\t\t\t\t\ttext: [create_text_slot],\n\t\t\t\t\ticon: [create_icon_slot]\n\t\t\t\t},\n\t\t\t\t$$scope: { ctx }\n\t\t\t}\n\t\t});\n\n\ticonbutton.$on(\"click\", /*click_handler_1*/ ctx[7]);\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(iconbutton.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(iconbutton, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst iconbutton_changes = {};\n\n\t\t\tif (dirty & /*$$scope*/ 2048) {\n\t\t\t\ticonbutton_changes.$$scope = { dirty, ctx };\n\t\t\t}\n\n\t\t\ticonbutton.$set(iconbutton_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(iconbutton.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(iconbutton, detaching);\n\t\t}\n\t};\n}\n\n// (31:6) \nfunction create_icon_slot(ctx) {\n\tlet fa;\n\tlet current;\n\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_3__[\"default\"]({\n\t\t\tprops: { icon: _fortawesome_free_solid_svg_icons_faEyeSlash__WEBPACK_IMPORTED_MODULE_5__.faEyeSlash, slot: \"icon\" }\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa, detaching);\n\t\t}\n\t};\n}\n\n// (32:6) \nfunction create_text_slot(ctx) {\n\tlet p;\n\n\treturn {\n\t\tc() {\n\t\t\tp = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"p\");\n\t\t\tp.textContent = \"Collapse\";\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(p, \"slot\", \"text\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, p, anchor);\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(p);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div1;\n\tlet div0;\n\tlet t0;\n\tlet t1;\n\tlet current;\n\tlet each_value = /*dataPoints*/ ctx[1].slice(0, /*numberShown*/ ctx[5]);\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\tconst out = i => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i], 1, 1, () => {\n\t\teach_blocks[i] = null;\n\t});\n\n\tlet if_block0 = /*dataPoints*/ ctx[1].length > /*numberShown*/ ctx[5] && create_if_block_1(ctx);\n\tlet if_block1 = /*dataPoints*/ ctx[1].length === /*numberShown*/ ctx[5] && /*dataPoints*/ ctx[1].length > /*defaultNumberShown*/ ctx[0] && create_if_block(ctx);\n\n\treturn {\n\t\tc() {\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block0) if_block0.c();\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tif (if_block1) if_block1.c();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex flex-wrap\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex flex-wrap items-center justify-between flex-1\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div1, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t0);\n\t\t\tif (if_block0) if_block0.m(div1, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, t1);\n\t\t\tif (if_block1) if_block1.m(div1, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*dataPoints, numberShown, symphonySpec, selected, tooltip*/ 62) {\n\t\t\t\teach_value = /*dataPoints*/ ctx[1].slice(0, /*numberShown*/ ctx[5]);\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\tfor (i = each_value.length; i < each_blocks.length; i += 1) {\n\t\t\t\t\tout(i);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (/*dataPoints*/ ctx[1].length > /*numberShown*/ ctx[5]) {\n\t\t\t\tif (if_block0) {\n\t\t\t\t\tif_block0.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*dataPoints, numberShown*/ 34) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block0 = create_if_block_1(ctx);\n\t\t\t\t\tif_block0.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0, 1);\n\t\t\t\t\tif_block0.m(div1, t1);\n\t\t\t\t}\n\t\t\t} else if (if_block0) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block0, 1, 1, () => {\n\t\t\t\t\tif_block0 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (/*dataPoints*/ ctx[1].length === /*numberShown*/ ctx[5] && /*dataPoints*/ ctx[1].length > /*defaultNumberShown*/ ctx[0]) {\n\t\t\t\tif (if_block1) {\n\t\t\t\t\tif_block1.p(ctx, dirty);\n\n\t\t\t\t\tif (dirty & /*dataPoints, numberShown, defaultNumberShown*/ 35) {\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1, 1);\n\t\t\t\t\t}\n\t\t\t\t} else {\n\t\t\t\t\tif_block1 = create_if_block(ctx);\n\t\t\t\t\tif_block1.c();\n\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1, 1);\n\t\t\t\t\tif_block1.m(div1, null);\n\t\t\t\t}\n\t\t\t} else if (if_block1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block1, 1, 1, () => {\n\t\t\t\t\tif_block1 = null;\n\t\t\t\t});\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(if_block1);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\teach_blocks = each_blocks.filter(Boolean);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(if_block1);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\tif (if_block0) if_block0.d();\n\t\t\tif (if_block1) if_block1.d();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { defaultNumberShown = 20 } = $$props;\n\tlet { dataPoints } = $$props;\n\tlet { selected } = $$props;\n\tlet { symphonySpec } = $$props;\n\tlet { tooltip } = $$props;\n\tlet numberShown = defaultNumberShown;\n\tconst click_handler = () => $$invalidate(5, numberShown = dataPoints.length);\n\tconst click_handler_1 = () => $$invalidate(5, numberShown = defaultNumberShown);\n\n\t$$self.$$set = $$props => {\n\t\tif ('defaultNumberShown' in $$props) $$invalidate(0, defaultNumberShown = $$props.defaultNumberShown);\n\t\tif ('dataPoints' in $$props) $$invalidate(1, dataPoints = $$props.dataPoints);\n\t\tif ('selected' in $$props) $$invalidate(2, selected = $$props.selected);\n\t\tif ('symphonySpec' in $$props) $$invalidate(3, symphonySpec = $$props.symphonySpec);\n\t\tif ('tooltip' in $$props) $$invalidate(4, tooltip = $$props.tooltip);\n\t};\n\n\treturn [\n\t\tdefaultNumberShown,\n\t\tdataPoints,\n\t\tselected,\n\t\tsymphonySpec,\n\t\ttooltip,\n\t\tnumberShown,\n\t\tclick_handler,\n\t\tclick_handler_1\n\t];\n}\n\nclass SampleRowContainer extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\tdefaultNumberShown: 0,\n\t\t\tdataPoints: 1,\n\t\t\tselected: 2,\n\t\t\tsymphonySpec: 3,\n\t\t\ttooltip: 4\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SampleRowContainer);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/SampleRowContainer.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/SubHeading.svelte":
/*!**********************************************************!*\
  !*** ../../symphony_lib/dist/elements/SubHeading.svelte ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/SubHeading.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet h2;\n\tlet t;\n\n\treturn {\n\t\tc() {\n\t\t\th2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"h2\");\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*heading*/ ctx[0]);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(h2, \"class\", \"text-xl font-bold leading-7 pr-2 mt-2\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, h2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(h2, t);\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*heading*/ 1) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t, /*heading*/ ctx[0]);\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(h2);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { heading } = $$props;\n\n\t$$self.$$set = $$props => {\n\t\tif ('heading' in $$props) $$invalidate(0, heading = $$props.heading);\n\t};\n\n\treturn [heading];\n}\n\nclass SubHeading extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { heading: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SubHeading);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/SubHeading.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/SymphonyVegaLite.svelte":
/*!****************************************************************!*\
  !*** ../../symphony_lib/dist/elements/SymphonyVegaLite.svelte ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte */ \"../../node_modules/svelte/index.mjs\");\n/* harmony import */ var svelte_vega__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! svelte-vega */ \"../../node_modules/svelte-vega/dist/index.js\");\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../types */ \"../../symphony_lib/dist/types.js\");\n/* harmony import */ var arquero__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! arquero */ \"../../node_modules/arquero/src/index.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/SymphonyVegaLite.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet vegalite;\n\tlet current;\n\n\tvegalite = new svelte_vega__WEBPACK_IMPORTED_MODULE_2__.VegaLite({\n\t\t\tprops: {\n\t\t\t\tspec: /*parsedSpec*/ ctx[1],\n\t\t\t\tdata: /*parsedData*/ ctx[0],\n\t\t\t\toptions: /*options*/ ctx[2],\n\t\t\t\tsignalListeners: {\n\t\t\t\t\tselect: /*handleSelect*/ ctx[3],\n\t\t\t\t\tbrush: /*handleBrush*/ ctx[4]\n\t\t\t\t}\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(vegalite.$$.fragment);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(vegalite, target, anchor);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst vegalite_changes = {};\n\t\t\tif (dirty & /*parsedSpec*/ 2) vegalite_changes.spec = /*parsedSpec*/ ctx[1];\n\t\t\tif (dirty & /*parsedData*/ 1) vegalite_changes.data = /*parsedData*/ ctx[0];\n\t\t\tif (dirty & /*options*/ 4) vegalite_changes.options = /*options*/ ctx[2];\n\t\t\tvegalite.$set(vegalite_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(vegalite.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(vegalite.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(vegalite, detaching);\n\t\t}\n\t};\n}\n\nfunction binnedStringResolver(resolver, table) {\n\tconst reduced_table = table.groupby(resolver.columnName).count();\n\treturn { values: reduced_table };\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet reducedData;\n\tlet { data = {} } = $$props;\n\tlet { spec } = $$props;\n\tlet { table } = $$props;\n\tlet { filteredTable } = $$props;\n\tlet { showUnfilteredData } = $$props;\n\tlet { width = undefined } = $$props;\n\tlet { height = undefined } = $$props;\n\tlet { resolver = undefined } = $$props;\n\tconst dispatch = (0,svelte__WEBPACK_IMPORTED_MODULE_1__.createEventDispatcher)();\n\tlet parsedData = {};\n\tlet parsedSpec = undefined;\n\tlet parsedSpecRaw = undefined;\n\tlet parsedSpecFiltered = undefined;\n\tlet options = { actions: false };\n\n\tfunction parseSpecs(spec, data, reducedData, showUnfilteredData) {\n\t\t$$invalidate(1, parsedSpec = spec);\n\t\tparsedSpecRaw = Object.assign(Object.assign({}, spec), { params: [] });\n\t\tparsedSpecFiltered = Object.assign({}, spec);\n\t\t$$invalidate(0, parsedData = data);\n\n\t\tif (typeof data.values === \"string\") {\n\t\t\tconst stringData = data.values;\n\n\t\t\tif (stringData && stringData === \"arrow_table\") {\n\t\t\t\tparsedSpecFiltered.data = reducedData.filtered;\n\t\t\t\tparsedSpecRaw.data = reducedData.raw;\n\n\t\t\t\tif (showUnfilteredData) {\n\t\t\t\t\tparsedSpecRaw.mark = Object.assign(Object.assign({}, parsedSpecRaw.mark), { color: \"#dcdcdc\" });\n\n\t\t\t\t\t$$invalidate(1, parsedSpec = {\n\t\t\t\t\t\tlayer: [\n\t\t\t\t\t\t\tObject.assign({}, parsedSpecRaw),\n\t\t\t\t\t\t\tObject.assign({}, parsedSpecFiltered)\n\t\t\t\t\t\t]\n\t\t\t\t\t});\n\t\t\t\t} else {\n\t\t\t\t\t$$invalidate(1, parsedSpec = Object.assign({}, parsedSpecFiltered));\n\t\t\t\t}\n\n\t\t\t\t$$invalidate(0, parsedData = {});\n\t\t\t}\n\t\t}\n\t}\n\n\tfunction extractData(resolver, table, filteredTable) {\n\t\tif (resolver === undefined) {\n\t\t\treturn {\n\t\t\t\tfiltered: { values: filteredTable },\n\t\t\t\traw: { values: table }\n\t\t\t};\n\t\t}\n\n\t\tswitch (resolver.type) {\n\t\t\tcase _types__WEBPACK_IMPORTED_MODULE_4__.ResolverType.NUMBER:\n\t\t\t\treturn {\n\t\t\t\t\tfiltered: numberResolver(resolver, filteredTable),\n\t\t\t\t\traw: numberResolver(resolver, table)\n\t\t\t\t};\n\t\t\tdefault:\n\t\t\t\treturn {\n\t\t\t\t\tfiltered: binnedStringResolver(resolver, filteredTable),\n\t\t\t\t\traw: binnedStringResolver(resolver, table)\n\t\t\t\t};\n\t\t}\n\t}\n\n\tfunction numberResolver(resolver, table) {\n\t\tconst reducedTable = table.groupby({\n\t\t\tbin_0: arquero__WEBPACK_IMPORTED_MODULE_3__.bin(resolver.columnName, { maxbins: 20 }),\n\t\t\tbin_1: arquero__WEBPACK_IMPORTED_MODULE_3__.bin(resolver.columnName, { maxbins: 20, offset: 1 })\n\t\t}).count();\n\n\t\treturn { values: reducedTable };\n\t}\n\n\tfunction handleSelect(_, value) {\n\t\tdispatch(\"select\", { value });\n\t}\n\n\tfunction handleBrush(_, value) {\n\t\tdispatch(\"brush\", { value });\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('data' in $$props) $$invalidate(5, data = $$props.data);\n\t\tif ('spec' in $$props) $$invalidate(6, spec = $$props.spec);\n\t\tif ('table' in $$props) $$invalidate(7, table = $$props.table);\n\t\tif ('filteredTable' in $$props) $$invalidate(8, filteredTable = $$props.filteredTable);\n\t\tif ('showUnfilteredData' in $$props) $$invalidate(9, showUnfilteredData = $$props.showUnfilteredData);\n\t\tif ('width' in $$props) $$invalidate(10, width = $$props.width);\n\t\tif ('height' in $$props) $$invalidate(11, height = $$props.height);\n\t\tif ('resolver' in $$props) $$invalidate(12, resolver = $$props.resolver);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*width*/ 1024) {\n\t\t\t$: if (width) $$invalidate(2, options.width = width, options);\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*height*/ 2048) {\n\t\t\t$: if (height) $$invalidate(2, options.height = height, options);\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*resolver, table, filteredTable*/ 4480) {\n\t\t\t$: $$invalidate(13, reducedData = extractData(resolver, table, filteredTable));\n\t\t}\n\n\t\tif ($$self.$$.dirty & /*spec, data, reducedData, showUnfilteredData*/ 8800) {\n\t\t\t$: parseSpecs(spec, data, reducedData, showUnfilteredData);\n\t\t}\n\t};\n\n\treturn [\n\t\tparsedData,\n\t\tparsedSpec,\n\t\toptions,\n\t\thandleSelect,\n\t\thandleBrush,\n\t\tdata,\n\t\tspec,\n\t\ttable,\n\t\tfilteredTable,\n\t\tshowUnfilteredData,\n\t\twidth,\n\t\theight,\n\t\tresolver,\n\t\treducedData\n\t];\n}\n\nclass SymphonyVegaLite extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\tdata: 5,\n\t\t\tspec: 6,\n\t\t\ttable: 7,\n\t\t\tfilteredTable: 8,\n\t\t\tshowUnfilteredData: 9,\n\t\t\twidth: 10,\n\t\t\theight: 11,\n\t\t\tresolver: 12\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SymphonyVegaLite);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/SymphonyVegaLite.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/TabularSample.svelte":
/*!*************************************************************!*\
  !*** ../../symphony_lib/dist/elements/TabularSample.svelte ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faTable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faTable */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faTable.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/TabularSample.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet fa;\n\tlet current;\n\tlet mounted;\n\tlet dispose;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faTable__WEBPACK_IMPORTED_MODULE_2__.faTable } });\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"p-2\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, div, null);\n\t\t\tcurrent = true;\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div, \"click\", /*click_handler*/ ctx[0]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self) {\n\tfunction click_handler(event) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.bubble.call(this, $$self, event);\n\t}\n\n\treturn [click_handler];\n}\n\nclass TabularSample extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TabularSample);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/TabularSample.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/TextField.svelte":
/*!*********************************************************!*\
  !*** ../../symphony_lib/dist/elements/TextField.svelte ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/TextField.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet input;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tinput = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"input\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"class\", \"border border-midgrey rounded w-full\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"type\", \"text\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"placeholder\", /*placeholder*/ ctx[1]);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, input, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input, /*value*/ ctx[0]);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(input, \"input\", /*input_input_handler*/ ctx[2]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*placeholder*/ 2) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(input, \"placeholder\", /*placeholder*/ ctx[1]);\n\t\t\t}\n\n\t\t\tif (dirty & /*value*/ 1 && input.value !== /*value*/ ctx[0]) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_input_value)(input, /*value*/ ctx[0]);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(input);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { value } = $$props;\n\tlet { placeholder = \"\" } = $$props;\n\n\tfunction input_input_handler() {\n\t\tvalue = this.value;\n\t\t$$invalidate(0, value);\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('value' in $$props) $$invalidate(0, value = $$props.value);\n\t\tif ('placeholder' in $$props) $$invalidate(1, placeholder = $$props.placeholder);\n\t};\n\n\treturn [value, placeholder, input_input_handler];\n}\n\nclass TextField extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { value: 0, placeholder: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TextField);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/TextField.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/ToggleButton.svelte":
/*!************************************************************!*\
  !*** ../../symphony_lib/dist/elements/ToggleButton.svelte ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/ToggleButton.svelte generated by Svelte v3.59.2 */\n\n\nfunction create_fragment(ctx) {\n\tlet div2;\n\tlet span;\n\tlet t0;\n\tlet t1;\n\tlet div1;\n\tlet div0;\n\tlet div0_class_value;\n\tlet div1_class_value;\n\tlet mounted;\n\tlet dispose;\n\n\treturn {\n\t\tc() {\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tspan = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"span\");\n\t\t\tt0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.text)(/*title*/ ctx[1]);\n\t\t\tt1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(span, \"class\", \"pr-1\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", div0_class_value = \"bg-white w-4 h-4 rounded-full shadow-md transform duration-100 ease-in-out \" + (/*active*/ ctx[0] ? 'translate-x-4' : ''));\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", div1_class_value = \"w-10 h-6 flex items-center bg-midgrey rounded-full p-1 duration-100 ease-in-out \" + (/*active*/ ctx[0] ? 'bg-highlight' : ''));\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", \"flex justify-between items-center\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, span);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(span, t0);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\n\t\t\tif (!mounted) {\n\t\t\t\tdispose = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.listen)(div2, \"click\", /*click_handler*/ ctx[2]);\n\t\t\t\tmounted = true;\n\t\t\t}\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (dirty & /*title*/ 2) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.set_data)(t0, /*title*/ ctx[1]);\n\n\t\t\tif (dirty & /*active*/ 1 && div0_class_value !== (div0_class_value = \"bg-white w-4 h-4 rounded-full shadow-md transform duration-100 ease-in-out \" + (/*active*/ ctx[0] ? 'translate-x-4' : ''))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", div0_class_value);\n\t\t\t}\n\n\t\t\tif (dirty & /*active*/ 1 && div1_class_value !== (div1_class_value = \"w-10 h-6 flex items-center bg-midgrey rounded-full p-1 duration-100 ease-in-out \" + (/*active*/ ctx[0] ? 'bg-highlight' : ''))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", div1_class_value);\n\t\t\t}\n\t\t},\n\t\ti: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\to: svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div2);\n\t\t\tmounted = false;\n\t\t\tdispose();\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { active = true } = $$props;\n\tlet { title } = $$props;\n\tconst click_handler = () => $$invalidate(0, active = !active);\n\n\t$$self.$$set = $$props => {\n\t\tif ('active' in $$props) $$invalidate(0, active = $$props.active);\n\t\tif ('title' in $$props) $$invalidate(1, title = $$props.title);\n\t};\n\n\treturn [active, title, click_handler];\n}\n\nclass ToggleButton extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { active: 0, title: 1 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ToggleButton);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/ToggleButton.svelte?");

/***/ }),

/***/ "../../symphony_lib/dist/elements/Tooltip.svelte":
/*!*******************************************************!*\
  !*** ../../symphony_lib/dist/elements/Tooltip.svelte ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_fa__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-fa */ \"../../node_modules/svelte-fa/src/fa.svelte\");\n/* harmony import */ var _fortawesome_free_solid_svg_icons_faQuestionCircle__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @fortawesome/free-solid-svg-icons/faQuestionCircle */ \"../../node_modules/@fortawesome/free-solid-svg-icons/faQuestionCircle.js\");\n/* Users/fredhohman/Github/apple/ml-symphony/symphony_lib/dist/elements/Tooltip.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\n\nfunction add_css(target) {\n\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append_styles)(target, \"svelte-hnj7xm\", \"[data-tooltip].svelte-hnj7xm{position:relative;z-index:2;display:block}[data-tooltip].svelte-hnj7xm:before,[data-tooltip].svelte-hnj7xm:after{visibility:hidden;opacity:0;pointer-events:none;transition:0.2s ease-out;transform:translate(-50%, 5px)}[data-tooltip].svelte-hnj7xm:before{position:absolute;top:100%;left:50%;margin-bottom:5px;padding:7px;width:100%;min-width:300px;max-width:400px;border-radius:3px;background-color:#000;background-color:hsla(0, 0%, 20%, 0.9);color:#fff;content:attr(data-tooltip);text-align:center;font-size:14px;line-height:1.2;transition:0.2s ease-out}[data-tooltip].svelte-hnj7xm:hover:before,[data-tooltip].svelte-hnj7xm:hover:after{visibility:visible;opacity:1;transform:translate(-50%, 0)}[data-tooltip=\\\"false\\\"].svelte-hnj7xm:hover:before,[data-tooltip=\\\"false\\\"].svelte-hnj7xm:hover:after{visibility:hidden;opacity:0}\");\n}\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet fa;\n\tlet current;\n\tfa = new svelte_fa__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({ props: { icon: _fortawesome_free_solid_svg_icons_faQuestionCircle__WEBPACK_IMPORTED_MODULE_2__.faQuestionCircle } });\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(fa.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"w-max svelte-hnj7xm\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"data-tooltip\", /*text*/ ctx[0]);\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(fa, div, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tif (!current || dirty & /*text*/ 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"data-tooltip\", /*text*/ ctx[0]);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(fa.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(fa.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(fa);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet { text } = $$props;\n\n\t$$self.$$set = $$props => {\n\t\tif ('text' in $$props) $$invalidate(0, text = $$props.text);\n\t};\n\n\treturn [text];\n}\n\nclass Tooltip extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { text: 0 }, add_css);\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Tooltip);\n\n//# sourceURL=webpack://symphony-vega/../../symphony_lib/dist/elements/Tooltip.svelte?");

/***/ }),

/***/ "./src/SymphonyVega.svelte":
/*!*********************************!*\
  !*** ./src/SymphonyVega.svelte ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @apple/symphony-lib */ \"../../symphony_lib/dist/elements/ComponentHeader.svelte\");\n/* harmony import */ var _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @apple/symphony-lib */ \"../../symphony_lib/dist/helpers/dimensions.js\");\n/* harmony import */ var _VegaListElement_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./VegaListElement.svelte */ \"./src/VegaListElement.svelte\");\n/* src/SymphonyVega.svelte generated by Svelte v3.59.2 */\n\n\n\n\n\nfunction get_each_context(ctx, list, i) {\n\tconst child_ctx = ctx.slice();\n\tchild_ctx[6] = list[i];\n\treturn child_ctx;\n}\n\n// (23:6) {#each elements as element}\nfunction create_each_block(ctx) {\n\tlet div;\n\tlet vegalistelement;\n\tlet t;\n\tlet current;\n\n\tvegalistelement = new _VegaListElement_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\telement: /*element*/ ctx[6],\n\t\t\t\tfilteredTable: /*filteredTable*/ ctx[2]\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(vegalistelement.$$.fragment);\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"relative\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(vegalistelement, div, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div, t);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, dirty) {\n\t\t\tconst vegalistelement_changes = {};\n\t\t\tif (dirty & /*elements*/ 16) vegalistelement_changes.element = /*element*/ ctx[6];\n\t\t\tif (dirty & /*filteredTable*/ 4) vegalistelement_changes.filteredTable = /*filteredTable*/ ctx[2];\n\t\t\tvegalistelement.$set(vegalistelement_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(vegalistelement.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(vegalistelement.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(vegalistelement);\n\t\t}\n\t};\n}\n\nfunction create_fragment(ctx) {\n\tlet div2;\n\tlet componentheader;\n\tlet t;\n\tlet div1;\n\tlet div0;\n\tlet div2_class_value;\n\tlet current;\n\n\tcomponentheader = new _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_2__[\"default\"]({\n\t\t\tprops: {\n\t\t\t\ttitle: 'Vega Charts',\n\t\t\t\tdescription: /*widgetSpec*/ ctx[0].description,\n\t\t\t\tcontainer: /*container*/ ctx[3]\n\t\t\t}\n\t\t});\n\n\tlet each_value = /*elements*/ ctx[4];\n\tlet each_blocks = [];\n\n\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\teach_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));\n\t}\n\n\tconst out = i => (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i], 1, 1, () => {\n\t\teach_blocks[i] = null;\n\t});\n\n\treturn {\n\t\tc() {\n\t\t\tdiv2 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(componentheader.$$.fragment);\n\t\t\tt = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.space)();\n\t\t\tdiv1 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\tdiv0 = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\teach_blocks[i].c();\n\t\t\t}\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div0, \"class\", \"flex flex-wrap\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div1, \"class\", \"flex flex-col overflow-auto\");\n\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", div2_class_value = \"flex flex-col p-2 \" + (/*fullSize*/ ctx[1]\n\t\t\t? 'h-full'\n\t\t\t: (0,_apple_symphony_lib__WEBPACK_IMPORTED_MODULE_3__.mapHeight)(/*widgetSpec*/ ctx[0].height)));\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div2, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(componentheader, div2, null);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, t);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div2, div1);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.append)(div1, div0);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t}\n\t\t\t}\n\n\t\t\t/*div1_binding*/ ctx[5](div1);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst componentheader_changes = {};\n\t\t\tif (dirty & /*widgetSpec*/ 1) componentheader_changes.description = /*widgetSpec*/ ctx[0].description;\n\t\t\tif (dirty & /*container*/ 8) componentheader_changes.container = /*container*/ ctx[3];\n\t\t\tcomponentheader.$set(componentheader_changes);\n\n\t\t\tif (dirty & /*elements, filteredTable*/ 20) {\n\t\t\t\teach_value = /*elements*/ ctx[4];\n\t\t\t\tlet i;\n\n\t\t\t\tfor (i = 0; i < each_value.length; i += 1) {\n\t\t\t\t\tconst child_ctx = get_each_context(ctx, each_value, i);\n\n\t\t\t\t\tif (each_blocks[i]) {\n\t\t\t\t\t\teach_blocks[i].p(child_ctx, dirty);\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t} else {\n\t\t\t\t\t\teach_blocks[i] = create_each_block(child_ctx);\n\t\t\t\t\t\teach_blocks[i].c();\n\t\t\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i], 1);\n\t\t\t\t\t\teach_blocks[i].m(div0, null);\n\t\t\t\t\t}\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.group_outros)();\n\n\t\t\t\tfor (i = each_value.length; i < each_blocks.length; i += 1) {\n\t\t\t\t\tout(i);\n\t\t\t\t}\n\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.check_outros)();\n\t\t\t}\n\n\t\t\tif (!current || dirty & /*fullSize, widgetSpec*/ 3 && div2_class_value !== (div2_class_value = \"flex flex-col p-2 \" + (/*fullSize*/ ctx[1]\n\t\t\t? 'h-full'\n\t\t\t: (0,_apple_symphony_lib__WEBPACK_IMPORTED_MODULE_3__.mapHeight)(/*widgetSpec*/ ctx[0].height)))) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div2, \"class\", div2_class_value);\n\t\t\t}\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(componentheader.$$.fragment, local);\n\n\t\t\tfor (let i = 0; i < each_value.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(componentheader.$$.fragment, local);\n\t\t\teach_blocks = each_blocks.filter(Boolean);\n\n\t\t\tfor (let i = 0; i < each_blocks.length; i += 1) {\n\t\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(each_blocks[i]);\n\t\t\t}\n\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div2);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(componentheader);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_each)(each_blocks, detaching);\n\t\t\t/*div1_binding*/ ctx[5](null);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet elements;\n\tlet { widgetSpec } = $$props;\n\tlet { fullSize = false } = $$props;\n\tlet { filteredTable } = $$props;\n\tlet container;\n\n\tfunction div1_binding($$value) {\n\t\tsvelte_internal__WEBPACK_IMPORTED_MODULE_0__.binding_callbacks[$$value ? 'unshift' : 'push'](() => {\n\t\t\tcontainer = $$value;\n\t\t\t$$invalidate(3, container);\n\t\t});\n\t}\n\n\t$$self.$$set = $$props => {\n\t\tif ('widgetSpec' in $$props) $$invalidate(0, widgetSpec = $$props.widgetSpec);\n\t\tif ('fullSize' in $$props) $$invalidate(1, fullSize = $$props.fullSize);\n\t\tif ('filteredTable' in $$props) $$invalidate(2, filteredTable = $$props.filteredTable);\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*widgetSpec*/ 1) {\n\t\t\t$: $$invalidate(4, elements = widgetSpec.vegaElements);\n\t\t}\n\t};\n\n\treturn [widgetSpec, fullSize, filteredTable, container, elements, div1_binding];\n}\n\nclass SymphonyVega extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, {\n\t\t\twidgetSpec: 0,\n\t\t\tfullSize: 1,\n\t\t\tfilteredTable: 2\n\t\t});\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SymphonyVega);\n\n//# sourceURL=webpack://symphony-vega/./src/SymphonyVega.svelte?");

/***/ }),

/***/ "./src/VegaListElement.svelte":
/*!************************************!*\
  !*** ./src/VegaListElement.svelte ***!
  \************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var svelte_internal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! svelte/internal */ \"../../node_modules/svelte/internal/index.mjs\");\n/* harmony import */ var svelte_vega__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! svelte-vega */ \"../../node_modules/svelte-vega/dist/index.js\");\n/* src/VegaListElement.svelte generated by Svelte v3.59.2 */\n\n\n\n\nfunction create_fragment(ctx) {\n\tlet div;\n\tlet vega;\n\tlet current;\n\n\tvega = new svelte_vega__WEBPACK_IMPORTED_MODULE_1__.Vega({\n\t\t\tprops: {\n\t\t\t\tspec: /*spec*/ ctx[1],\n\t\t\t\toptions: /*options*/ ctx[2]\n\t\t\t}\n\t\t});\n\n\treturn {\n\t\tc() {\n\t\t\tdiv = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.element)(\"div\");\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.create_component)(vega.$$.fragment);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.attr)(div, \"class\", \"rounded m-1 flex flex-col\");\n\t\t},\n\t\tm(target, anchor) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.insert)(target, div, anchor);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.mount_component)(vega, div, null);\n\t\t\tcurrent = true;\n\t\t},\n\t\tp(ctx, [dirty]) {\n\t\t\tconst vega_changes = {};\n\t\t\tif (dirty & /*spec*/ 2) vega_changes.spec = /*spec*/ ctx[1];\n\t\t\tvega.$set(vega_changes);\n\t\t},\n\t\ti(local) {\n\t\t\tif (current) return;\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_in)(vega.$$.fragment, local);\n\t\t\tcurrent = true;\n\t\t},\n\t\to(local) {\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.transition_out)(vega.$$.fragment, local);\n\t\t\tcurrent = false;\n\t\t},\n\t\td(detaching) {\n\t\t\tif (detaching) (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.detach)(div);\n\t\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.destroy_component)(vega);\n\t\t}\n\t};\n}\n\nfunction instance($$self, $$props, $$invalidate) {\n\tlet spec;\n\n\tlet $filteredTable,\n\t\t$$unsubscribe_filteredTable = svelte_internal__WEBPACK_IMPORTED_MODULE_0__.noop,\n\t\t$$subscribe_filteredTable = () => ($$unsubscribe_filteredTable(), $$unsubscribe_filteredTable = (0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.subscribe)(filteredTable, $$value => $$invalidate(4, $filteredTable = $$value)), filteredTable);\n\n\t$$self.$$.on_destroy.push(() => $$unsubscribe_filteredTable());\n\tlet { element } = $$props;\n\tlet { filteredTable } = $$props;\n\t$$subscribe_filteredTable();\n\tlet options = { actions: false };\n\n\t$$self.$$set = $$props => {\n\t\tif ('element' in $$props) $$invalidate(3, element = $$props.element);\n\t\tif ('filteredTable' in $$props) $$subscribe_filteredTable($$invalidate(0, filteredTable = $$props.filteredTable));\n\t};\n\n\t$$self.$$.update = () => {\n\t\tif ($$self.$$.dirty & /*element, $filteredTable*/ 24) {\n\t\t\t$: $$invalidate(1, spec = typeof element.data.values === 'string' && element.data.values === 'arrow_table'\n\t\t\t? Object.assign(Object.assign({}, element), { data: { values: $filteredTable } })\n\t\t\t: element);\n\t\t}\n\t};\n\n\treturn [filteredTable, spec, options, element, $filteredTable];\n}\n\nclass VegaListElement extends svelte_internal__WEBPACK_IMPORTED_MODULE_0__.SvelteComponent {\n\tconstructor(options) {\n\t\tsuper();\n\t\t(0,svelte_internal__WEBPACK_IMPORTED_MODULE_0__.init)(this, options, instance, create_fragment, svelte_internal__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal, { element: 3, filteredTable: 0 });\n\t}\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (VegaListElement);\n\n//# sourceURL=webpack://symphony-vega/./src/VegaListElement.svelte?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/index.js":
/*!*****************************************************!*\
  !*** ../../node_modules/svelte-select/src/index.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* reexport safe */ _Select_svelte__WEBPACK_IMPORTED_MODULE_0__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _Select_svelte__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Select.svelte */ \"../../node_modules/svelte-select/src/Select.svelte\");\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/index.js?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/utils/debounce.js":
/*!**************************************************************!*\
  !*** ../../node_modules/svelte-select/src/utils/debounce.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ debounce)\n/* harmony export */ });\nfunction debounce(func, wait, immediate) {\n    let timeout;\n\n    return function executedFunction() {\n        let context = this;\n        let args = arguments;\n\n        let later = function () {\n            timeout = null;\n            if (!immediate) func.apply(context, args);\n        };\n\n        let callNow = immediate && !timeout;\n\n        clearTimeout(timeout);\n\n        timeout = setTimeout(later, wait);\n\n        if (callNow) func.apply(context, args);\n    };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/utils/debounce.js?");

/***/ }),

/***/ "../../node_modules/svelte-select/src/utils/isOutOfViewport.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/svelte-select/src/utils/isOutOfViewport.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(elem) {\n    const bounding = elem.getBoundingClientRect();\n    const out = {};\n\n    out.top = bounding.top < 0;\n    out.left = bounding.left < 0;\n    out.bottom =\n        bounding.bottom >\n        (window.innerHeight || document.documentElement.clientHeight);\n    out.right =\n        bounding.right >\n        (window.innerWidth || document.documentElement.clientWidth);\n    out.any = out.top || out.left || out.bottom || out.right;\n\n    return out;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-select/src/utils/isOutOfViewport.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/bbox.js":
/*!******************************************************!*\
  !*** ../../node_modules/topojson-client/src/bbox.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./transform.js */ \"../../node_modules/topojson-client/src/transform.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology) {\n  var t = (0,_transform_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(topology.transform), key,\n      x0 = Infinity, y0 = x0, x1 = -x0, y1 = -x0;\n\n  function bboxPoint(p) {\n    p = t(p);\n    if (p[0] < x0) x0 = p[0];\n    if (p[0] > x1) x1 = p[0];\n    if (p[1] < y0) y0 = p[1];\n    if (p[1] > y1) y1 = p[1];\n  }\n\n  function bboxGeometry(o) {\n    switch (o.type) {\n      case \"GeometryCollection\": o.geometries.forEach(bboxGeometry); break;\n      case \"Point\": bboxPoint(o.coordinates); break;\n      case \"MultiPoint\": o.coordinates.forEach(bboxPoint); break;\n    }\n  }\n\n  topology.arcs.forEach(function(arc) {\n    var i = -1, n = arc.length, p;\n    while (++i < n) {\n      p = t(arc[i], i);\n      if (p[0] < x0) x0 = p[0];\n      if (p[0] > x1) x1 = p[0];\n      if (p[1] < y0) y0 = p[1];\n      if (p[1] > y1) y1 = p[1];\n    }\n  });\n\n  for (key in topology.objects) {\n    bboxGeometry(topology.objects[key]);\n  }\n\n  return [x0, y0, x1, y1];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/bbox.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/bisect.js":
/*!********************************************************!*\
  !*** ../../node_modules/topojson-client/src/bisect.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, x) {\n  var lo = 0, hi = a.length;\n  while (lo < hi) {\n    var mid = lo + hi >>> 1;\n    if (a[mid] < x) lo = mid + 1;\n    else hi = mid;\n  }\n  return lo;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/bisect.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/feature.js":
/*!*********************************************************!*\
  !*** ../../node_modules/topojson-client/src/feature.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   object: () => (/* binding */ object)\n/* harmony export */ });\n/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reverse.js */ \"../../node_modules/topojson-client/src/reverse.js\");\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./transform.js */ \"../../node_modules/topojson-client/src/transform.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology, o) {\n  if (typeof o === \"string\") o = topology.objects[o];\n  return o.type === \"GeometryCollection\"\n      ? {type: \"FeatureCollection\", features: o.geometries.map(function(o) { return feature(topology, o); })}\n      : feature(topology, o);\n}\n\nfunction feature(topology, o) {\n  var id = o.id,\n      bbox = o.bbox,\n      properties = o.properties == null ? {} : o.properties,\n      geometry = object(topology, o);\n  return id == null && bbox == null ? {type: \"Feature\", properties: properties, geometry: geometry}\n      : bbox == null ? {type: \"Feature\", id: id, properties: properties, geometry: geometry}\n      : {type: \"Feature\", id: id, bbox: bbox, properties: properties, geometry: geometry};\n}\n\nfunction object(topology, o) {\n  var transformPoint = (0,_transform_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(topology.transform),\n      arcs = topology.arcs;\n\n  function arc(i, points) {\n    if (points.length) points.pop();\n    for (var a = arcs[i < 0 ? ~i : i], k = 0, n = a.length; k < n; ++k) {\n      points.push(transformPoint(a[k], k));\n    }\n    if (i < 0) (0,_reverse_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(points, n);\n  }\n\n  function point(p) {\n    return transformPoint(p);\n  }\n\n  function line(arcs) {\n    var points = [];\n    for (var i = 0, n = arcs.length; i < n; ++i) arc(arcs[i], points);\n    if (points.length < 2) points.push(points[0]); // This should never happen per the specification.\n    return points;\n  }\n\n  function ring(arcs) {\n    var points = line(arcs);\n    while (points.length < 4) points.push(points[0]); // This may happen if an arc has only two points.\n    return points;\n  }\n\n  function polygon(arcs) {\n    return arcs.map(ring);\n  }\n\n  function geometry(o) {\n    var type = o.type, coordinates;\n    switch (type) {\n      case \"GeometryCollection\": return {type: type, geometries: o.geometries.map(geometry)};\n      case \"Point\": coordinates = point(o.coordinates); break;\n      case \"MultiPoint\": coordinates = o.coordinates.map(point); break;\n      case \"LineString\": coordinates = line(o.arcs); break;\n      case \"MultiLineString\": coordinates = o.arcs.map(line); break;\n      case \"Polygon\": coordinates = polygon(o.arcs); break;\n      case \"MultiPolygon\": coordinates = o.arcs.map(polygon); break;\n      default: return null;\n    }\n    return {type: type, coordinates: coordinates};\n  }\n\n  return geometry(o);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/feature.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/identity.js":
/*!**********************************************************!*\
  !*** ../../node_modules/topojson-client/src/identity.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return x;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/identity.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/index.js":
/*!*******************************************************!*\
  !*** ../../node_modules/topojson-client/src/index.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bbox: () => (/* reexport safe */ _bbox_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]),\n/* harmony export */   feature: () => (/* reexport safe */ _feature_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]),\n/* harmony export */   merge: () => (/* reexport safe */ _merge_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]),\n/* harmony export */   mergeArcs: () => (/* reexport safe */ _merge_js__WEBPACK_IMPORTED_MODULE_3__.mergeArcs),\n/* harmony export */   mesh: () => (/* reexport safe */ _mesh_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]),\n/* harmony export */   meshArcs: () => (/* reexport safe */ _mesh_js__WEBPACK_IMPORTED_MODULE_2__.meshArcs),\n/* harmony export */   neighbors: () => (/* reexport safe */ _neighbors_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"]),\n/* harmony export */   quantize: () => (/* reexport safe */ _quantize_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"]),\n/* harmony export */   transform: () => (/* reexport safe */ _transform_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"]),\n/* harmony export */   untransform: () => (/* reexport safe */ _untransform_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _bbox_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./bbox.js */ \"../../node_modules/topojson-client/src/bbox.js\");\n/* harmony import */ var _feature_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./feature.js */ \"../../node_modules/topojson-client/src/feature.js\");\n/* harmony import */ var _mesh_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mesh.js */ \"../../node_modules/topojson-client/src/mesh.js\");\n/* harmony import */ var _merge_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./merge.js */ \"../../node_modules/topojson-client/src/merge.js\");\n/* harmony import */ var _neighbors_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./neighbors.js */ \"../../node_modules/topojson-client/src/neighbors.js\");\n/* harmony import */ var _quantize_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./quantize.js */ \"../../node_modules/topojson-client/src/quantize.js\");\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./transform.js */ \"../../node_modules/topojson-client/src/transform.js\");\n/* harmony import */ var _untransform_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./untransform.js */ \"../../node_modules/topojson-client/src/untransform.js\");\n\n\n\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/index.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/merge.js":
/*!*******************************************************!*\
  !*** ../../node_modules/topojson-client/src/merge.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   mergeArcs: () => (/* binding */ mergeArcs)\n/* harmony export */ });\n/* harmony import */ var _feature_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./feature.js */ \"../../node_modules/topojson-client/src/feature.js\");\n/* harmony import */ var _stitch_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./stitch.js */ \"../../node_modules/topojson-client/src/stitch.js\");\n\n\n\nfunction planarRingArea(ring) {\n  var i = -1, n = ring.length, a, b = ring[n - 1], area = 0;\n  while (++i < n) a = b, b = ring[i], area += a[0] * b[1] - a[1] * b[0];\n  return Math.abs(area); // Note: doubled area!\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology) {\n  return (0,_feature_js__WEBPACK_IMPORTED_MODULE_0__.object)(topology, mergeArcs.apply(this, arguments));\n}\n\nfunction mergeArcs(topology, objects) {\n  var polygonsByArc = {},\n      polygons = [],\n      groups = [];\n\n  objects.forEach(geometry);\n\n  function geometry(o) {\n    switch (o.type) {\n      case \"GeometryCollection\": o.geometries.forEach(geometry); break;\n      case \"Polygon\": extract(o.arcs); break;\n      case \"MultiPolygon\": o.arcs.forEach(extract); break;\n    }\n  }\n\n  function extract(polygon) {\n    polygon.forEach(function(ring) {\n      ring.forEach(function(arc) {\n        (polygonsByArc[arc = arc < 0 ? ~arc : arc] || (polygonsByArc[arc] = [])).push(polygon);\n      });\n    });\n    polygons.push(polygon);\n  }\n\n  function area(ring) {\n    return planarRingArea((0,_feature_js__WEBPACK_IMPORTED_MODULE_0__.object)(topology, {type: \"Polygon\", arcs: [ring]}).coordinates[0]);\n  }\n\n  polygons.forEach(function(polygon) {\n    if (!polygon._) {\n      var group = [],\n          neighbors = [polygon];\n      polygon._ = 1;\n      groups.push(group);\n      while (polygon = neighbors.pop()) {\n        group.push(polygon);\n        polygon.forEach(function(ring) {\n          ring.forEach(function(arc) {\n            polygonsByArc[arc < 0 ? ~arc : arc].forEach(function(polygon) {\n              if (!polygon._) {\n                polygon._ = 1;\n                neighbors.push(polygon);\n              }\n            });\n          });\n        });\n      }\n    }\n  });\n\n  polygons.forEach(function(polygon) {\n    delete polygon._;\n  });\n\n  return {\n    type: \"MultiPolygon\",\n    arcs: groups.map(function(polygons) {\n      var arcs = [], n;\n\n      // Extract the exterior (unique) arcs.\n      polygons.forEach(function(polygon) {\n        polygon.forEach(function(ring) {\n          ring.forEach(function(arc) {\n            if (polygonsByArc[arc < 0 ? ~arc : arc].length < 2) {\n              arcs.push(arc);\n            }\n          });\n        });\n      });\n\n      // Stitch the arcs into one or more rings.\n      arcs = (0,_stitch_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(topology, arcs);\n\n      // If more than one ring is returned,\n      // at most one of these rings can be the exterior;\n      // choose the one with the greatest absolute area.\n      if ((n = arcs.length) > 1) {\n        for (var i = 1, k = area(arcs[0]), ki, t; i < n; ++i) {\n          if ((ki = area(arcs[i])) > k) {\n            t = arcs[0], arcs[0] = arcs[i], arcs[i] = t, k = ki;\n          }\n        }\n      }\n\n      return arcs;\n    }).filter(function(arcs) {\n      return arcs.length > 0;\n    })\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/merge.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/mesh.js":
/*!******************************************************!*\
  !*** ../../node_modules/topojson-client/src/mesh.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   meshArcs: () => (/* binding */ meshArcs)\n/* harmony export */ });\n/* harmony import */ var _feature_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./feature.js */ \"../../node_modules/topojson-client/src/feature.js\");\n/* harmony import */ var _stitch_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./stitch.js */ \"../../node_modules/topojson-client/src/stitch.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology) {\n  return (0,_feature_js__WEBPACK_IMPORTED_MODULE_0__.object)(topology, meshArcs.apply(this, arguments));\n}\n\nfunction meshArcs(topology, object, filter) {\n  var arcs, i, n;\n  if (arguments.length > 1) arcs = extractArcs(topology, object, filter);\n  else for (i = 0, arcs = new Array(n = topology.arcs.length); i < n; ++i) arcs[i] = i;\n  return {type: \"MultiLineString\", arcs: (0,_stitch_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(topology, arcs)};\n}\n\nfunction extractArcs(topology, object, filter) {\n  var arcs = [],\n      geomsByArc = [],\n      geom;\n\n  function extract0(i) {\n    var j = i < 0 ? ~i : i;\n    (geomsByArc[j] || (geomsByArc[j] = [])).push({i: i, g: geom});\n  }\n\n  function extract1(arcs) {\n    arcs.forEach(extract0);\n  }\n\n  function extract2(arcs) {\n    arcs.forEach(extract1);\n  }\n\n  function extract3(arcs) {\n    arcs.forEach(extract2);\n  }\n\n  function geometry(o) {\n    switch (geom = o, o.type) {\n      case \"GeometryCollection\": o.geometries.forEach(geometry); break;\n      case \"LineString\": extract1(o.arcs); break;\n      case \"MultiLineString\": case \"Polygon\": extract2(o.arcs); break;\n      case \"MultiPolygon\": extract3(o.arcs); break;\n    }\n  }\n\n  geometry(object);\n\n  geomsByArc.forEach(filter == null\n      ? function(geoms) { arcs.push(geoms[0].i); }\n      : function(geoms) { if (filter(geoms[0].g, geoms[geoms.length - 1].g)) arcs.push(geoms[0].i); });\n\n  return arcs;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/mesh.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/neighbors.js":
/*!***********************************************************!*\
  !*** ../../node_modules/topojson-client/src/neighbors.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _bisect_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./bisect.js */ \"../../node_modules/topojson-client/src/bisect.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(objects) {\n  var indexesByArc = {}, // arc index -> array of object indexes\n      neighbors = objects.map(function() { return []; });\n\n  function line(arcs, i) {\n    arcs.forEach(function(a) {\n      if (a < 0) a = ~a;\n      var o = indexesByArc[a];\n      if (o) o.push(i);\n      else indexesByArc[a] = [i];\n    });\n  }\n\n  function polygon(arcs, i) {\n    arcs.forEach(function(arc) { line(arc, i); });\n  }\n\n  function geometry(o, i) {\n    if (o.type === \"GeometryCollection\") o.geometries.forEach(function(o) { geometry(o, i); });\n    else if (o.type in geometryType) geometryType[o.type](o.arcs, i);\n  }\n\n  var geometryType = {\n    LineString: line,\n    MultiLineString: polygon,\n    Polygon: polygon,\n    MultiPolygon: function(arcs, i) { arcs.forEach(function(arc) { polygon(arc, i); }); }\n  };\n\n  objects.forEach(geometry);\n\n  for (var i in indexesByArc) {\n    for (var indexes = indexesByArc[i], m = indexes.length, j = 0; j < m; ++j) {\n      for (var k = j + 1; k < m; ++k) {\n        var ij = indexes[j], ik = indexes[k], n;\n        if ((n = neighbors[ij])[i = (0,_bisect_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(n, ik)] !== ik) n.splice(i, 0, ik);\n        if ((n = neighbors[ik])[i = (0,_bisect_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(n, ij)] !== ij) n.splice(i, 0, ij);\n      }\n    }\n  }\n\n  return neighbors;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/neighbors.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/quantize.js":
/*!**********************************************************!*\
  !*** ../../node_modules/topojson-client/src/quantize.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _bbox_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./bbox.js */ \"../../node_modules/topojson-client/src/bbox.js\");\n/* harmony import */ var _untransform_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./untransform.js */ \"../../node_modules/topojson-client/src/untransform.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology, transform) {\n  if (topology.transform) throw new Error(\"already quantized\");\n\n  if (!transform || !transform.scale) {\n    if (!((n = Math.floor(transform)) >= 2)) throw new Error(\"n must be ≥2\");\n    box = topology.bbox || (0,_bbox_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(topology);\n    var x0 = box[0], y0 = box[1], x1 = box[2], y1 = box[3], n;\n    transform = {scale: [x1 - x0 ? (x1 - x0) / (n - 1) : 1, y1 - y0 ? (y1 - y0) / (n - 1) : 1], translate: [x0, y0]};\n  } else {\n    box = topology.bbox;\n  }\n\n  var t = (0,_untransform_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(transform), box, key, inputs = topology.objects, outputs = {};\n\n  function quantizePoint(point) {\n    return t(point);\n  }\n\n  function quantizeGeometry(input) {\n    var output;\n    switch (input.type) {\n      case \"GeometryCollection\": output = {type: \"GeometryCollection\", geometries: input.geometries.map(quantizeGeometry)}; break;\n      case \"Point\": output = {type: \"Point\", coordinates: quantizePoint(input.coordinates)}; break;\n      case \"MultiPoint\": output = {type: \"MultiPoint\", coordinates: input.coordinates.map(quantizePoint)}; break;\n      default: return input;\n    }\n    if (input.id != null) output.id = input.id;\n    if (input.bbox != null) output.bbox = input.bbox;\n    if (input.properties != null) output.properties = input.properties;\n    return output;\n  }\n\n  function quantizeArc(input) {\n    var i = 0, j = 1, n = input.length, p, output = new Array(n); // pessimistic\n    output[0] = t(input[0], 0);\n    while (++i < n) if ((p = t(input[i], i))[0] || p[1]) output[j++] = p; // non-coincident points\n    if (j === 1) output[j++] = [0, 0]; // an arc must have at least two points\n    output.length = j;\n    return output;\n  }\n\n  for (key in inputs) outputs[key] = quantizeGeometry(inputs[key]);\n\n  return {\n    type: \"Topology\",\n    bbox: box,\n    transform: transform,\n    objects: outputs,\n    arcs: topology.arcs.map(quantizeArc)\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/quantize.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/reverse.js":
/*!*********************************************************!*\
  !*** ../../node_modules/topojson-client/src/reverse.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(array, n) {\n  var t, j = array.length, i = j - n;\n  while (i < --j) t = array[i], array[i++] = array[j], array[j] = t;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/reverse.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/stitch.js":
/*!********************************************************!*\
  !*** ../../node_modules/topojson-client/src/stitch.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(topology, arcs) {\n  var stitchedArcs = {},\n      fragmentByStart = {},\n      fragmentByEnd = {},\n      fragments = [],\n      emptyIndex = -1;\n\n  // Stitch empty arcs first, since they may be subsumed by other arcs.\n  arcs.forEach(function(i, j) {\n    var arc = topology.arcs[i < 0 ? ~i : i], t;\n    if (arc.length < 3 && !arc[1][0] && !arc[1][1]) {\n      t = arcs[++emptyIndex], arcs[emptyIndex] = i, arcs[j] = t;\n    }\n  });\n\n  arcs.forEach(function(i) {\n    var e = ends(i),\n        start = e[0],\n        end = e[1],\n        f, g;\n\n    if (f = fragmentByEnd[start]) {\n      delete fragmentByEnd[f.end];\n      f.push(i);\n      f.end = end;\n      if (g = fragmentByStart[end]) {\n        delete fragmentByStart[g.start];\n        var fg = g === f ? f : f.concat(g);\n        fragmentByStart[fg.start = f.start] = fragmentByEnd[fg.end = g.end] = fg;\n      } else {\n        fragmentByStart[f.start] = fragmentByEnd[f.end] = f;\n      }\n    } else if (f = fragmentByStart[end]) {\n      delete fragmentByStart[f.start];\n      f.unshift(i);\n      f.start = start;\n      if (g = fragmentByEnd[start]) {\n        delete fragmentByEnd[g.end];\n        var gf = g === f ? f : g.concat(f);\n        fragmentByStart[gf.start = g.start] = fragmentByEnd[gf.end = f.end] = gf;\n      } else {\n        fragmentByStart[f.start] = fragmentByEnd[f.end] = f;\n      }\n    } else {\n      f = [i];\n      fragmentByStart[f.start = start] = fragmentByEnd[f.end = end] = f;\n    }\n  });\n\n  function ends(i) {\n    var arc = topology.arcs[i < 0 ? ~i : i], p0 = arc[0], p1;\n    if (topology.transform) p1 = [0, 0], arc.forEach(function(dp) { p1[0] += dp[0], p1[1] += dp[1]; });\n    else p1 = arc[arc.length - 1];\n    return i < 0 ? [p1, p0] : [p0, p1];\n  }\n\n  function flush(fragmentByEnd, fragmentByStart) {\n    for (var k in fragmentByEnd) {\n      var f = fragmentByEnd[k];\n      delete fragmentByStart[f.start];\n      delete f.start;\n      delete f.end;\n      f.forEach(function(i) { stitchedArcs[i < 0 ? ~i : i] = 1; });\n      fragments.push(f);\n    }\n  }\n\n  flush(fragmentByEnd, fragmentByStart);\n  flush(fragmentByStart, fragmentByEnd);\n  arcs.forEach(function(i) { if (!stitchedArcs[i < 0 ? ~i : i]) fragments.push([i]); });\n\n  return fragments;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/stitch.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/transform.js":
/*!***********************************************************!*\
  !*** ../../node_modules/topojson-client/src/transform.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity.js */ \"../../node_modules/topojson-client/src/identity.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(transform) {\n  if (transform == null) return _identity_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n  var x0,\n      y0,\n      kx = transform.scale[0],\n      ky = transform.scale[1],\n      dx = transform.translate[0],\n      dy = transform.translate[1];\n  return function(input, i) {\n    if (!i) x0 = y0 = 0;\n    var j = 2, n = input.length, output = new Array(n);\n    output[0] = (x0 += input[0]) * kx + dx;\n    output[1] = (y0 += input[1]) * ky + dy;\n    while (j < n) output[j] = input[j], ++j;\n    return output;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/transform.js?");

/***/ }),

/***/ "../../node_modules/topojson-client/src/untransform.js":
/*!*************************************************************!*\
  !*** ../../node_modules/topojson-client/src/untransform.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity.js */ \"../../node_modules/topojson-client/src/identity.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(transform) {\n  if (transform == null) return _identity_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n  var x0,\n      y0,\n      kx = transform.scale[0],\n      ky = transform.scale[1],\n      dx = transform.translate[0],\n      dy = transform.translate[1];\n  return function(input, i) {\n    if (!i) x0 = y0 = 0;\n    var j = 2,\n        n = input.length,\n        output = new Array(n),\n        x1 = Math.round((input[0] - dx) / kx),\n        y1 = Math.round((input[1] - dy) / ky);\n    output[0] = x1 - x0, x0 = x1;\n    output[1] = y1 - y0, y0 = y1;\n    while (j < n) output[j] = input[j], ++j;\n    return output;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/topojson-client/src/untransform.js?");

/***/ }),

/***/ "./src/plugin.ts":
/*!***********************!*\
  !*** ./src/plugin.ts ***!
  \***********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @jupyter-widgets/base */ \"@jupyter-widgets/base\");\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _widget__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./widget */ \"./src/widget.ts\");\n/* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./version */ \"./src/version.ts\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\nconst EXTENSION_ID = 'symphony-vega:plugin';\n/**\n * The example plugin.\n */\nconst examplePlugin = {\n    id: EXTENSION_ID,\n    requires: [_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.IJupyterWidgetRegistry],\n    activate: activateWidgetExtension,\n    autoStart: true,\n};\n// the \"as unknown as ...\" typecast above is solely to support JupyterLab 1\n// and 2 in the same codebase and should be removed when we migrate to Lumino.\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (examplePlugin);\n/**\n * Activate the widget extension.\n */\nfunction activateWidgetExtension(app, registry) {\n    registry.registerWidget({\n        name: _version__WEBPACK_IMPORTED_MODULE_2__.MODULE_NAME,\n        version: _version__WEBPACK_IMPORTED_MODULE_2__.MODULE_VERSION,\n        exports: _widget__WEBPACK_IMPORTED_MODULE_1__,\n    });\n}\n\n\n//# sourceURL=webpack://symphony-vega/./src/plugin.ts?");

/***/ }),

/***/ "./src/version.ts":
/*!************************!*\
  !*** ./src/version.ts ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MODULE_NAME: () => (/* binding */ MODULE_NAME),\n/* harmony export */   MODULE_VERSION: () => (/* binding */ MODULE_VERSION)\n/* harmony export */ });\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n// eslint-disable-next-line @typescript-eslint/no-var-requires\nconst data = __webpack_require__(/*! ../package.json */ \"./package.json\");\n/**\n * The _model_module_version/_view_module_version this package implements.\n *\n * The html widget manager assumes that this is the same as the npm package\n * version number.\n */\nconst MODULE_VERSION = data.version;\n/*\n * The current package name.\n */\nconst MODULE_NAME = data.name;\n\n\n//# sourceURL=webpack://symphony-vega/./src/version.ts?");

/***/ }),

/***/ "./src/widget.ts":
/*!***********************!*\
  !*** ./src/widget.ts ***!
  \***********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SymphonyVegaModel: () => (/* binding */ SymphonyVegaModel),\n/* harmony export */   SymphonyVegaView: () => (/* binding */ SymphonyVegaView)\n/* harmony export */ });\n/* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./version */ \"./src/version.ts\");\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @jupyter-widgets/base */ \"@jupyter-widgets/base\");\n/* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @apple/symphony-lib */ \"../../symphony_lib/dist/index.js\");\n/* harmony import */ var _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @apple/symphony-lib */ \"../../symphony_lib/dist/JupyterWidget.svelte\");\n/* harmony import */ var _SymphonyVega_svelte__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./SymphonyVega.svelte */ \"./src/SymphonyVega.svelte\");\n// For licensing see accompanying LICENSE file.\n// Copyright (C) 2023 Apple Inc. All Rights Reserved.\n\n\n\n\nclass SymphonyVegaModel extends _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetModel {\n    defaults() {\n        return Object.assign(Object.assign({}, super.defaults()), { _model_name: SymphonyVegaModel.model_name, _model_module: SymphonyVegaModel.model_module, _model_module_version: SymphonyVegaModel.model_module_version, _view_name: SymphonyVegaModel.view_name, _view_module: SymphonyVegaModel.view_module, _view_module_version: SymphonyVegaModel.view_module_version });\n    }\n}\nSymphonyVegaModel.serializers = _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_3__.serializers;\nSymphonyVegaModel.model_name = 'SymphonyVegaModel';\nSymphonyVegaModel.model_module = _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_NAME;\nSymphonyVegaModel.model_module_version = _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_VERSION;\nSymphonyVegaModel.view_name = 'SymphonyVegaView'; // Set to null if no view\nSymphonyVegaModel.view_module = _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_NAME; // Set to null if no view\nSymphonyVegaModel.view_module_version = _version__WEBPACK_IMPORTED_MODULE_0__.MODULE_VERSION;\nclass SymphonyVegaView extends _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetView {\n    render() {\n        new _apple_symphony_lib__WEBPACK_IMPORTED_MODULE_4__[\"default\"]({\n            target: this.el,\n            props: {\n                model: this.model,\n                widget: _SymphonyVega_svelte__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n            },\n        });\n    }\n}\n\n\n//# sourceURL=webpack://symphony-vega/./src/widget.ts?");

/***/ }),

/***/ "../../node_modules/vega-canvas/build/vega-canvas.browser.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-canvas/build/vega-canvas.browser.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   canvas: () => (/* binding */ domCanvas),\n/* harmony export */   domCanvas: () => (/* binding */ domCanvas),\n/* harmony export */   image: () => (/* binding */ domImage)\n/* harmony export */ });\nfunction domCanvas(w, h) {\n  if (typeof document !== 'undefined' && document.createElement) {\n    const c = document.createElement('canvas');\n    if (c && c.getContext) {\n      c.width = w;\n      c.height = h;\n      return c;\n    }\n  }\n  return null;\n}\nconst domImage = () => typeof Image !== 'undefined' ? Image : null;\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-canvas/build/vega-canvas.browser.module.js?");

/***/ }),

/***/ "../../node_modules/vega-crossfilter/build/vega-crossfilter.module.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-crossfilter/build/vega-crossfilter.module.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   crossfilter: () => (/* binding */ CrossFilter),\n/* harmony export */   resolvefilter: () => (/* binding */ ResolveFilter)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/permute.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\n\n\nconst array8 = n => new Uint8Array(n);\nconst array16 = n => new Uint16Array(n);\nconst array32 = n => new Uint32Array(n);\n\n/**\n * Maintains CrossFilter state.\n */\nfunction Bitmaps() {\n  let width = 8,\n    data = [],\n    seen = array32(0),\n    curr = array(0, width),\n    prev = array(0, width);\n  return {\n    data: () => data,\n    seen: () => seen = lengthen(seen, data.length),\n    add(array) {\n      for (let i = 0, j = data.length, n = array.length, t; i < n; ++i) {\n        t = array[i];\n        t._index = j++;\n        data.push(t);\n      }\n    },\n    remove(num, map) {\n      // map: index -> boolean (true => remove)\n      const n = data.length,\n        copy = Array(n - num),\n        reindex = data; // reuse old data array for index map\n      let t, i, j;\n\n      // seek forward to first removal\n      for (i = 0; !map[i] && i < n; ++i) {\n        copy[i] = data[i];\n        reindex[i] = i;\n      }\n\n      // condense arrays\n      for (j = i; i < n; ++i) {\n        t = data[i];\n        if (!map[i]) {\n          reindex[i] = j;\n          curr[j] = curr[i];\n          prev[j] = prev[i];\n          copy[j] = t;\n          t._index = j++;\n        } else {\n          reindex[i] = -1;\n        }\n        curr[i] = 0; // clear unused bits\n      }\n\n      data = copy;\n      return reindex;\n    },\n    size: () => data.length,\n    curr: () => curr,\n    prev: () => prev,\n    reset: k => prev[k] = curr[k],\n    all: () => width < 0x101 ? 0xff : width < 0x10001 ? 0xffff : 0xffffffff,\n    set(k, one) {\n      curr[k] |= one;\n    },\n    clear(k, one) {\n      curr[k] &= ~one;\n    },\n    resize(n, m) {\n      const k = curr.length;\n      if (n > k || m > width) {\n        width = Math.max(m, width);\n        curr = array(n, width, curr);\n        prev = array(n, width);\n      }\n    }\n  };\n}\nfunction lengthen(array, length, copy) {\n  if (array.length >= length) return array;\n  copy = copy || new array.constructor(length);\n  copy.set(array);\n  return copy;\n}\nfunction array(n, m, array) {\n  const copy = (m < 0x101 ? array8 : m < 0x10001 ? array16 : array32)(n);\n  if (array) copy.set(array);\n  return copy;\n}\n\nfunction Dimension (index, i, query) {\n  const bit = 1 << i;\n  return {\n    one: bit,\n    zero: ~bit,\n    range: query.slice(),\n    bisect: index.bisect,\n    index: index.index,\n    size: index.size,\n    onAdd(added, curr) {\n      const dim = this,\n        range = dim.bisect(dim.range, added.value),\n        idx = added.index,\n        lo = range[0],\n        hi = range[1],\n        n1 = idx.length;\n      let i;\n      for (i = 0; i < lo; ++i) curr[idx[i]] |= bit;\n      for (i = hi; i < n1; ++i) curr[idx[i]] |= bit;\n      return dim;\n    }\n  };\n}\n\n/**\n * Maintains a list of values, sorted by key.\n */\nfunction SortedIndex() {\n  let index = array32(0),\n    value = [],\n    size = 0;\n  function insert(key, data, base) {\n    if (!data.length) return [];\n    const n0 = size,\n      n1 = data.length,\n      addi = array32(n1);\n    let addv = Array(n1),\n      oldv,\n      oldi,\n      i;\n    for (i = 0; i < n1; ++i) {\n      addv[i] = key(data[i]);\n      addi[i] = i;\n    }\n    addv = sort(addv, addi);\n    if (n0) {\n      oldv = value;\n      oldi = index;\n      value = Array(n0 + n1);\n      index = array32(n0 + n1);\n      merge(base, oldv, oldi, n0, addv, addi, n1, value, index);\n    } else {\n      if (base > 0) for (i = 0; i < n1; ++i) {\n        addi[i] += base;\n      }\n      value = addv;\n      index = addi;\n    }\n    size = n0 + n1;\n    return {\n      index: addi,\n      value: addv\n    };\n  }\n  function remove(num, map) {\n    // map: index -> remove\n    const n = size;\n    let idx, i, j;\n\n    // seek forward to first removal\n    for (i = 0; !map[index[i]] && i < n; ++i);\n\n    // condense index and value arrays\n    for (j = i; i < n; ++i) {\n      if (!map[idx = index[i]]) {\n        index[j] = idx;\n        value[j] = value[i];\n        ++j;\n      }\n    }\n    size = n - num;\n  }\n  function reindex(map) {\n    for (let i = 0, n = size; i < n; ++i) {\n      index[i] = map[index[i]];\n    }\n  }\n  function bisect(range, array) {\n    let n;\n    if (array) {\n      n = array.length;\n    } else {\n      array = value;\n      n = size;\n    }\n    return [(0,d3_array__WEBPACK_IMPORTED_MODULE_2__.bisectLeft)(array, range[0], 0, n), (0,d3_array__WEBPACK_IMPORTED_MODULE_2__.bisectRight)(array, range[1], 0, n)];\n  }\n  return {\n    insert: insert,\n    remove: remove,\n    bisect: bisect,\n    reindex: reindex,\n    index: () => index,\n    size: () => size\n  };\n}\nfunction sort(values, index) {\n  values.sort.call(index, (a, b) => {\n    const x = values[a],\n      y = values[b];\n    return x < y ? -1 : x > y ? 1 : 0;\n  });\n  return (0,d3_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values, index);\n}\nfunction merge(base, value0, index0, n0, value1, index1, n1, value, index) {\n  let i0 = 0,\n    i1 = 0,\n    i;\n  for (i = 0; i0 < n0 && i1 < n1; ++i) {\n    if (value0[i0] < value1[i1]) {\n      value[i] = value0[i0];\n      index[i] = index0[i0++];\n    } else {\n      value[i] = value1[i1];\n      index[i] = index1[i1++] + base;\n    }\n  }\n  for (; i0 < n0; ++i0, ++i) {\n    value[i] = value0[i0];\n    index[i] = index0[i0];\n  }\n  for (; i1 < n1; ++i1, ++i) {\n    value[i] = value1[i1];\n    index[i] = index1[i1] + base;\n  }\n}\n\n/**\n * An indexed multi-dimensional filter.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} params.fields - An array of dimension accessors to filter.\n * @param {Array} params.query - An array of per-dimension range queries.\n */\nfunction CrossFilter(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, Bitmaps(), params);\n  this._indices = null;\n  this._dims = null;\n}\nCrossFilter.Definition = {\n  'type': 'CrossFilter',\n  'metadata': {},\n  'params': [{\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'required': true\n  }, {\n    'name': 'query',\n    'type': 'array',\n    'array': true,\n    'required': true,\n    'content': {\n      'type': 'number',\n      'array': true,\n      'length': 2\n    }\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(CrossFilter, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (!this._dims) {\n      return this.init(_, pulse);\n    } else {\n      var init = _.modified('fields') || _.fields.some(f => pulse.modified(f.fields));\n      return init ? this.reinit(_, pulse) : this.eval(_, pulse);\n    }\n  },\n  init(_, pulse) {\n    const fields = _.fields,\n      query = _.query,\n      indices = this._indices = {},\n      dims = this._dims = [],\n      m = query.length;\n    let i = 0,\n      key,\n      index;\n\n    // instantiate indices and dimensions\n    for (; i < m; ++i) {\n      key = fields[i].fname;\n      index = indices[key] || (indices[key] = SortedIndex());\n      dims.push(Dimension(index, i, query[i]));\n    }\n    return this.eval(_, pulse);\n  },\n  reinit(_, pulse) {\n    const output = pulse.materialize().fork(),\n      fields = _.fields,\n      query = _.query,\n      indices = this._indices,\n      dims = this._dims,\n      bits = this.value,\n      curr = bits.curr(),\n      prev = bits.prev(),\n      all = bits.all(),\n      out = output.rem = output.add,\n      mod = output.mod,\n      m = query.length,\n      adds = {};\n    let add, index, key, mods, remMap, modMap, i, n, f;\n\n    // set prev to current state\n    prev.set(curr);\n\n    // if pulse has remove tuples, process them first\n    if (pulse.rem.length) {\n      remMap = this.remove(_, pulse, output);\n    }\n\n    // if pulse has added tuples, add them to state\n    if (pulse.add.length) {\n      bits.add(pulse.add);\n    }\n\n    // if pulse has modified tuples, create an index map\n    if (pulse.mod.length) {\n      modMap = {};\n      for (mods = pulse.mod, i = 0, n = mods.length; i < n; ++i) {\n        modMap[mods[i]._index] = 1;\n      }\n    }\n\n    // re-initialize indices as needed, update curr bitmap\n    for (i = 0; i < m; ++i) {\n      f = fields[i];\n      if (!dims[i] || _.modified('fields', i) || pulse.modified(f.fields)) {\n        key = f.fname;\n        if (!(add = adds[key])) {\n          indices[key] = index = SortedIndex();\n          adds[key] = add = index.insert(f, pulse.source, 0);\n        }\n        dims[i] = Dimension(index, i, query[i]).onAdd(add, curr);\n      }\n    }\n\n    // visit each tuple\n    // if filter state changed, push index to add/rem\n    // else if in mod and passes a filter, push index to mod\n    for (i = 0, n = bits.data().length; i < n; ++i) {\n      if (remMap[i]) {\n        // skip if removed tuple\n        continue;\n      } else if (prev[i] !== curr[i]) {\n        // add if state changed\n        out.push(i);\n      } else if (modMap[i] && curr[i] !== all) {\n        // otherwise, pass mods through\n        mod.push(i);\n      }\n    }\n    bits.mask = (1 << m) - 1;\n    return output;\n  },\n  eval(_, pulse) {\n    const output = pulse.materialize().fork(),\n      m = this._dims.length;\n    let mask = 0;\n    if (pulse.rem.length) {\n      this.remove(_, pulse, output);\n      mask |= (1 << m) - 1;\n    }\n    if (_.modified('query') && !_.modified('fields')) {\n      mask |= this.update(_, pulse, output);\n    }\n    if (pulse.add.length) {\n      this.insert(_, pulse, output);\n      mask |= (1 << m) - 1;\n    }\n    if (pulse.mod.length) {\n      this.modify(pulse, output);\n      mask |= (1 << m) - 1;\n    }\n    this.value.mask = mask;\n    return output;\n  },\n  insert(_, pulse, output) {\n    const tuples = pulse.add,\n      bits = this.value,\n      dims = this._dims,\n      indices = this._indices,\n      fields = _.fields,\n      adds = {},\n      out = output.add,\n      n = bits.size() + tuples.length,\n      m = dims.length;\n    let k = bits.size(),\n      j,\n      key,\n      add;\n\n    // resize bitmaps and add tuples as needed\n    bits.resize(n, m);\n    bits.add(tuples);\n    const curr = bits.curr(),\n      prev = bits.prev(),\n      all = bits.all();\n\n    // add to dimensional indices\n    for (j = 0; j < m; ++j) {\n      key = fields[j].fname;\n      add = adds[key] || (adds[key] = indices[key].insert(fields[j], tuples, k));\n      dims[j].onAdd(add, curr);\n    }\n\n    // set previous filters, output if passes at least one filter\n    for (; k < n; ++k) {\n      prev[k] = all;\n      if (curr[k] !== all) out.push(k);\n    }\n  },\n  modify(pulse, output) {\n    const out = output.mod,\n      bits = this.value,\n      curr = bits.curr(),\n      all = bits.all(),\n      tuples = pulse.mod;\n    let i, n, k;\n    for (i = 0, n = tuples.length; i < n; ++i) {\n      k = tuples[i]._index;\n      if (curr[k] !== all) out.push(k);\n    }\n  },\n  remove(_, pulse, output) {\n    const indices = this._indices,\n      bits = this.value,\n      curr = bits.curr(),\n      prev = bits.prev(),\n      all = bits.all(),\n      map = {},\n      out = output.rem,\n      tuples = pulse.rem;\n    let i, n, k, f;\n\n    // process tuples, output if passes at least one filter\n    for (i = 0, n = tuples.length; i < n; ++i) {\n      k = tuples[i]._index;\n      map[k] = 1; // build index map\n      prev[k] = f = curr[k];\n      curr[k] = all;\n      if (f !== all) out.push(k);\n    }\n\n    // remove from dimensional indices\n    for (k in indices) {\n      indices[k].remove(n, map);\n    }\n    this.reindex(pulse, n, map);\n    return map;\n  },\n  // reindex filters and indices after propagation completes\n  reindex(pulse, num, map) {\n    const indices = this._indices,\n      bits = this.value;\n    pulse.runAfter(() => {\n      const indexMap = bits.remove(num, map);\n      for (const key in indices) indices[key].reindex(indexMap);\n    });\n  },\n  update(_, pulse, output) {\n    const dims = this._dims,\n      query = _.query,\n      stamp = pulse.stamp,\n      m = dims.length;\n    let mask = 0,\n      i,\n      q;\n\n    // survey how many queries have changed\n    output.filters = 0;\n    for (q = 0; q < m; ++q) {\n      if (_.modified('query', q)) {\n        i = q;\n        ++mask;\n      }\n    }\n    if (mask === 1) {\n      // only one query changed, use more efficient update\n      mask = dims[i].one;\n      this.incrementOne(dims[i], query[i], output.add, output.rem);\n    } else {\n      // multiple queries changed, perform full record keeping\n      for (q = 0, mask = 0; q < m; ++q) {\n        if (!_.modified('query', q)) continue;\n        mask |= dims[q].one;\n        this.incrementAll(dims[q], query[q], stamp, output.add);\n        output.rem = output.add; // duplicate add/rem for downstream resolve\n      }\n    }\n\n    return mask;\n  },\n  incrementAll(dim, query, stamp, out) {\n    const bits = this.value,\n      seen = bits.seen(),\n      curr = bits.curr(),\n      prev = bits.prev(),\n      index = dim.index(),\n      old = dim.bisect(dim.range),\n      range = dim.bisect(query),\n      lo1 = range[0],\n      hi1 = range[1],\n      lo0 = old[0],\n      hi0 = old[1],\n      one = dim.one;\n    let i, j, k;\n\n    // Fast incremental update based on previous lo index.\n    if (lo1 < lo0) {\n      for (i = lo1, j = Math.min(lo0, hi1); i < j; ++i) {\n        k = index[i];\n        if (seen[k] !== stamp) {\n          prev[k] = curr[k];\n          seen[k] = stamp;\n          out.push(k);\n        }\n        curr[k] ^= one;\n      }\n    } else if (lo1 > lo0) {\n      for (i = lo0, j = Math.min(lo1, hi0); i < j; ++i) {\n        k = index[i];\n        if (seen[k] !== stamp) {\n          prev[k] = curr[k];\n          seen[k] = stamp;\n          out.push(k);\n        }\n        curr[k] ^= one;\n      }\n    }\n\n    // Fast incremental update based on previous hi index.\n    if (hi1 > hi0) {\n      for (i = Math.max(lo1, hi0), j = hi1; i < j; ++i) {\n        k = index[i];\n        if (seen[k] !== stamp) {\n          prev[k] = curr[k];\n          seen[k] = stamp;\n          out.push(k);\n        }\n        curr[k] ^= one;\n      }\n    } else if (hi1 < hi0) {\n      for (i = Math.max(lo0, hi1), j = hi0; i < j; ++i) {\n        k = index[i];\n        if (seen[k] !== stamp) {\n          prev[k] = curr[k];\n          seen[k] = stamp;\n          out.push(k);\n        }\n        curr[k] ^= one;\n      }\n    }\n    dim.range = query.slice();\n  },\n  incrementOne(dim, query, add, rem) {\n    const bits = this.value,\n      curr = bits.curr(),\n      index = dim.index(),\n      old = dim.bisect(dim.range),\n      range = dim.bisect(query),\n      lo1 = range[0],\n      hi1 = range[1],\n      lo0 = old[0],\n      hi0 = old[1],\n      one = dim.one;\n    let i, j, k;\n\n    // Fast incremental update based on previous lo index.\n    if (lo1 < lo0) {\n      for (i = lo1, j = Math.min(lo0, hi1); i < j; ++i) {\n        k = index[i];\n        curr[k] ^= one;\n        add.push(k);\n      }\n    } else if (lo1 > lo0) {\n      for (i = lo0, j = Math.min(lo1, hi0); i < j; ++i) {\n        k = index[i];\n        curr[k] ^= one;\n        rem.push(k);\n      }\n    }\n\n    // Fast incremental update based on previous hi index.\n    if (hi1 > hi0) {\n      for (i = Math.max(lo1, hi0), j = hi1; i < j; ++i) {\n        k = index[i];\n        curr[k] ^= one;\n        add.push(k);\n      }\n    } else if (hi1 < hi0) {\n      for (i = Math.max(lo0, hi1), j = hi0; i < j; ++i) {\n        k = index[i];\n        curr[k] ^= one;\n        rem.push(k);\n      }\n    }\n    dim.range = query.slice();\n  }\n});\n\n/**\n * Selectively filters tuples by resolving against a filter bitmap.\n * Useful for processing the output of a cross-filter transform.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {object} params.ignore - A bit mask indicating which filters to ignore.\n * @param {object} params.filter - The per-tuple filter bitmaps. Typically this\n *   parameter value is a reference to a {@link CrossFilter} transform.\n */\nfunction ResolveFilter(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nResolveFilter.Definition = {\n  'type': 'ResolveFilter',\n  'metadata': {},\n  'params': [{\n    'name': 'ignore',\n    'type': 'number',\n    'required': true,\n    'description': 'A bit mask indicating which filters to ignore.'\n  }, {\n    'name': 'filter',\n    'type': 'object',\n    'required': true,\n    'description': 'Per-tuple filter bitmaps from a CrossFilter transform.'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(ResolveFilter, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const ignore = ~(_.ignore || 0),\n      // bit mask where zeros -> dims to ignore\n      bitmap = _.filter,\n      mask = bitmap.mask;\n\n    // exit early if no relevant filter changes\n    if ((mask & ignore) === 0) return pulse.StopPropagation;\n    const output = pulse.fork(pulse.ALL),\n      data = bitmap.data(),\n      curr = bitmap.curr(),\n      prev = bitmap.prev(),\n      pass = k => !(curr[k] & ignore) ? data[k] : null;\n\n    // propagate all mod tuples that pass the filter\n    output.filter(output.MOD, pass);\n\n    // determine add & rem tuples via filter functions\n    // for efficiency, we do *not* populate new arrays,\n    // instead we add filter functions applied downstream\n\n    if (!(mask & mask - 1)) {\n      // only one filter changed\n      output.filter(output.ADD, pass);\n      output.filter(output.REM, k => (curr[k] & ignore) === mask ? data[k] : null);\n    } else {\n      // multiple filters changed\n      output.filter(output.ADD, k => {\n        const c = curr[k] & ignore,\n          f = !c && c ^ prev[k] & ignore;\n        return f ? data[k] : null;\n      });\n      output.filter(output.REM, k => {\n        const c = curr[k] & ignore,\n          f = c && !(c ^ (c ^ prev[k] & ignore));\n        return f ? data[k] : null;\n      });\n    }\n\n    // add filter to source data in case of reflow...\n    return output.filter(output.SOURCE, t => pass(t._index));\n  }\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-crossfilter/build/vega-crossfilter.module.js?");

/***/ }),

/***/ "../../node_modules/vega-dataflow/build/vega-dataflow.module.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-dataflow/build/vega-dataflow.module.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Dataflow: () => (/* binding */ Dataflow),\n/* harmony export */   EventStream: () => (/* binding */ EventStream),\n/* harmony export */   MultiPulse: () => (/* binding */ MultiPulse),\n/* harmony export */   Operator: () => (/* binding */ Operator),\n/* harmony export */   Parameters: () => (/* binding */ Parameters),\n/* harmony export */   Pulse: () => (/* binding */ Pulse),\n/* harmony export */   Transform: () => (/* binding */ Transform),\n/* harmony export */   UniqueList: () => (/* binding */ UniqueList),\n/* harmony export */   asyncCallback: () => (/* binding */ asyncCallback),\n/* harmony export */   changeset: () => (/* binding */ changeset),\n/* harmony export */   definition: () => (/* binding */ definition),\n/* harmony export */   derive: () => (/* binding */ derive),\n/* harmony export */   ingest: () => (/* binding */ ingest$1),\n/* harmony export */   isChangeSet: () => (/* binding */ isChangeSet),\n/* harmony export */   isTuple: () => (/* binding */ isTuple),\n/* harmony export */   rederive: () => (/* binding */ rederive),\n/* harmony export */   replace: () => (/* binding */ replace),\n/* harmony export */   stableCompare: () => (/* binding */ stableCompare),\n/* harmony export */   transform: () => (/* binding */ transform),\n/* harmony export */   transforms: () => (/* binding */ transforms),\n/* harmony export */   tupleid: () => (/* binding */ tupleid)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_loader__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-loader */ \"../../node_modules/vega-loader/build/vega-loader.browser.module.js\");\n/* harmony import */ var vega_format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-format */ \"../../node_modules/vega-format/build/vega-format.module.js\");\n\n\n\n\nfunction UniqueList(idFunc) {\n  const $ = idFunc || vega_util__WEBPACK_IMPORTED_MODULE_0__.identity,\n    list = [],\n    ids = {};\n  list.add = _ => {\n    const id = $(_);\n    if (!ids[id]) {\n      ids[id] = 1;\n      list.push(_);\n    }\n    return list;\n  };\n  list.remove = _ => {\n    const id = $(_);\n    if (ids[id]) {\n      ids[id] = 0;\n      const idx = list.indexOf(_);\n      if (idx >= 0) list.splice(idx, 1);\n    }\n    return list;\n  };\n  return list;\n}\n\n/**\n * Invoke and await a potentially async callback function. If\n * an error occurs, trap it and route to Dataflow.error.\n * @param {Dataflow} df - The dataflow instance\n * @param {function} callback - A callback function to invoke\n *   and then await. The dataflow will be passed as the single\n *   argument to the function.\n */\nasync function asyncCallback (df, callback) {\n  try {\n    await callback(df);\n  } catch (err) {\n    df.error(err);\n  }\n}\n\nconst TUPLE_ID_KEY = Symbol('vega_id');\nlet TUPLE_ID = 1;\n\n/**\n * Checks if an input value is a registered tuple.\n * @param {*} t - The value to check.\n * @return {boolean} True if the input is a tuple, false otherwise.\n */\nfunction isTuple(t) {\n  return !!(t && tupleid(t));\n}\n\n/**\n * Returns the id of a tuple.\n * @param {object} t - The input tuple.\n * @return {*} the tuple id.\n */\nfunction tupleid(t) {\n  return t[TUPLE_ID_KEY];\n}\n\n/**\n * Sets the id of a tuple.\n * @param {object} t - The input tuple.\n * @param {*} id - The id value to set.\n * @return {object} the input tuple.\n */\nfunction setid(t, id) {\n  t[TUPLE_ID_KEY] = id;\n  return t;\n}\n\n/**\n * Ingest an object or value as a data tuple.\n * If the input value is an object, an id field will be added to it. For\n * efficiency, the input object is modified directly. A copy is not made.\n * If the input value is a literal, it will be wrapped in a new object\n * instance, with the value accessible as the 'data' property.\n * @param datum - The value to ingest.\n * @return {object} The ingested data tuple.\n */\nfunction ingest$1(datum) {\n  const t = datum === Object(datum) ? datum : {\n    data: datum\n  };\n  return tupleid(t) ? t : setid(t, TUPLE_ID++);\n}\n\n/**\n * Given a source tuple, return a derived copy.\n * @param {object} t - The source tuple.\n * @return {object} The derived tuple.\n */\nfunction derive(t) {\n  return rederive(t, ingest$1({}));\n}\n\n/**\n * Rederive a derived tuple by copying values from the source tuple.\n * @param {object} t - The source tuple.\n * @param {object} d - The derived tuple.\n * @return {object} The derived tuple.\n */\nfunction rederive(t, d) {\n  for (const k in t) d[k] = t[k];\n  return d;\n}\n\n/**\n * Replace an existing tuple with a new tuple.\n * @param {object} t - The existing data tuple.\n * @param {object} d - The new tuple that replaces the old.\n * @return {object} The new tuple.\n */\nfunction replace(t, d) {\n  return setid(d, tupleid(t));\n}\n\n/**\n * Generate an augmented comparator function that provides stable\n * sorting by tuple id when the given comparator produces ties.\n * @param {function} cmp - The comparator to augment.\n * @param {function} [f] - Optional tuple accessor function.\n * @return {function} An augmented comparator function.\n */\nfunction stableCompare(cmp, f) {\n  return !cmp ? null : f ? (a, b) => cmp(a, b) || tupleid(f(a)) - tupleid(f(b)) : (a, b) => cmp(a, b) || tupleid(a) - tupleid(b);\n}\n\nfunction isChangeSet(v) {\n  return v && v.constructor === changeset;\n}\nfunction changeset() {\n  const add = [],\n    // insert tuples\n    rem = [],\n    // remove tuples\n    mod = [],\n    // modify tuples\n    remp = [],\n    // remove by predicate\n    modp = []; // modify by predicate\n  let clean = null,\n    reflow = false;\n  return {\n    constructor: changeset,\n    insert(t) {\n      const d = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(t),\n        n = d.length;\n      for (let i = 0; i < n; ++i) add.push(d[i]);\n      return this;\n    },\n    remove(t) {\n      const a = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(t) ? remp : rem,\n        d = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(t),\n        n = d.length;\n      for (let i = 0; i < n; ++i) a.push(d[i]);\n      return this;\n    },\n    modify(t, field, value) {\n      const m = {\n        field: field,\n        value: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(value)\n      };\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(t)) {\n        m.filter = t;\n        modp.push(m);\n      } else {\n        m.tuple = t;\n        mod.push(m);\n      }\n      return this;\n    },\n    encode(t, set) {\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(t)) modp.push({\n        filter: t,\n        field: set\n      });else mod.push({\n        tuple: t,\n        field: set\n      });\n      return this;\n    },\n    clean(value) {\n      clean = value;\n      return this;\n    },\n    reflow() {\n      reflow = true;\n      return this;\n    },\n    pulse(pulse, tuples) {\n      const cur = {},\n        out = {};\n      let i, n, m, f, t, id;\n\n      // build lookup table of current tuples\n      for (i = 0, n = tuples.length; i < n; ++i) {\n        cur[tupleid(tuples[i])] = 1;\n      }\n\n      // process individual tuples to remove\n      for (i = 0, n = rem.length; i < n; ++i) {\n        t = rem[i];\n        cur[tupleid(t)] = -1;\n      }\n\n      // process predicate-based removals\n      for (i = 0, n = remp.length; i < n; ++i) {\n        f = remp[i];\n        tuples.forEach(t => {\n          if (f(t)) cur[tupleid(t)] = -1;\n        });\n      }\n\n      // process all add tuples\n      for (i = 0, n = add.length; i < n; ++i) {\n        t = add[i];\n        id = tupleid(t);\n        if (cur[id]) {\n          // tuple already resides in dataset\n          // if flagged for both add and remove, cancel\n          cur[id] = 1;\n        } else {\n          // tuple does not reside in dataset, add\n          pulse.add.push(ingest$1(add[i]));\n        }\n      }\n\n      // populate pulse rem list\n      for (i = 0, n = tuples.length; i < n; ++i) {\n        t = tuples[i];\n        if (cur[tupleid(t)] < 0) pulse.rem.push(t);\n      }\n\n      // modify helper method\n      function modify(t, f, v) {\n        if (v) {\n          t[f] = v(t);\n        } else {\n          pulse.encode = f;\n        }\n        if (!reflow) out[tupleid(t)] = t;\n      }\n\n      // process individual tuples to modify\n      for (i = 0, n = mod.length; i < n; ++i) {\n        m = mod[i];\n        t = m.tuple;\n        f = m.field;\n        id = cur[tupleid(t)];\n        if (id > 0) {\n          modify(t, f, m.value);\n          pulse.modifies(f);\n        }\n      }\n\n      // process predicate-based modifications\n      for (i = 0, n = modp.length; i < n; ++i) {\n        m = modp[i];\n        f = m.filter;\n        tuples.forEach(t => {\n          if (f(t) && cur[tupleid(t)] > 0) {\n            modify(t, m.field, m.value);\n          }\n        });\n        pulse.modifies(m.field);\n      }\n\n      // upon reflow request, populate mod with all non-removed tuples\n      // otherwise, populate mod with modified tuples only\n      if (reflow) {\n        pulse.mod = rem.length || remp.length ? tuples.filter(t => cur[tupleid(t)] > 0) : tuples.slice();\n      } else {\n        for (id in out) pulse.mod.push(out[id]);\n      }\n\n      // set pulse garbage collection request\n      if (clean || clean == null && (rem.length || remp.length)) {\n        pulse.clean(true);\n      }\n      return pulse;\n    }\n  };\n}\n\nconst CACHE = '_:mod:_';\n\n/**\n * Hash that tracks modifications to assigned values.\n * Callers *must* use the set method to update values.\n */\nfunction Parameters() {\n  Object.defineProperty(this, CACHE, {\n    writable: true,\n    value: {}\n  });\n}\nParameters.prototype = {\n  /**\n   * Set a parameter value. If the parameter value changes, the parameter\n   * will be recorded as modified.\n   * @param {string} name - The parameter name.\n   * @param {number} index - The index into an array-value parameter. Ignored if\n   *   the argument is undefined, null or less than zero.\n   * @param {*} value - The parameter value to set.\n   * @param {boolean} [force=false] - If true, records the parameter as modified\n   *   even if the value is unchanged.\n   * @return {Parameters} - This parameter object.\n   */\n  set(name, index, value, force) {\n    const o = this,\n      v = o[name],\n      mod = o[CACHE];\n    if (index != null && index >= 0) {\n      if (v[index] !== value || force) {\n        v[index] = value;\n        mod[index + ':' + name] = -1;\n        mod[name] = -1;\n      }\n    } else if (v !== value || force) {\n      o[name] = value;\n      mod[name] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) ? 1 + value.length : -1;\n    }\n    return o;\n  },\n  /**\n   * Tests if one or more parameters has been modified. If invoked with no\n   * arguments, returns true if any parameter value has changed. If the first\n   * argument is array, returns trues if any parameter name in the array has\n   * changed. Otherwise, tests if the given name and optional array index has\n   * changed.\n   * @param {string} name - The parameter name to test.\n   * @param {number} [index=undefined] - The parameter array index to test.\n   * @return {boolean} - Returns true if a queried parameter was modified.\n   */\n  modified(name, index) {\n    const mod = this[CACHE];\n    if (!arguments.length) {\n      for (const k in mod) {\n        if (mod[k]) return true;\n      }\n      return false;\n    } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(name)) {\n      for (let k = 0; k < name.length; ++k) {\n        if (mod[name[k]]) return true;\n      }\n      return false;\n    }\n    return index != null && index >= 0 ? index + 1 < mod[name] || !!mod[index + ':' + name] : !!mod[name];\n  },\n  /**\n   * Clears the modification records. After calling this method,\n   * all parameters are considered unmodified.\n   */\n  clear() {\n    this[CACHE] = {};\n    return this;\n  }\n};\n\nlet OP_ID = 0;\nconst PULSE = 'pulse',\n  NO_PARAMS = new Parameters();\n\n// Boolean Flags\nconst SKIP$1 = 1,\n  MODIFIED = 2;\n\n/**\n * An Operator is a processing node in a dataflow graph.\n * Each operator stores a value and an optional value update function.\n * Operators can accept a hash of named parameters. Parameter values can\n * either be direct (JavaScript literals, arrays, objects) or indirect\n * (other operators whose values will be pulled dynamically). Operators\n * included as parameters will have this operator added as a dependency.\n * @constructor\n * @param {*} [init] - The initial value for this operator.\n * @param {function(object, Pulse)} [update] - An update function. Upon\n *   evaluation of this operator, the update function will be invoked and the\n *   return value will be used as the new value of this operator.\n * @param {object} [params] - The parameters for this operator.\n * @param {boolean} [react=true] - Flag indicating if this operator should\n *   listen for changes to upstream operators included as parameters.\n * @see parameters\n */\nfunction Operator(init, update, params, react) {\n  this.id = ++OP_ID;\n  this.value = init;\n  this.stamp = -1;\n  this.rank = -1;\n  this.qrank = -1;\n  this.flags = 0;\n  if (update) {\n    this._update = update;\n  }\n  if (params) this.parameters(params, react);\n}\nfunction flag(bit) {\n  return function (state) {\n    const f = this.flags;\n    if (arguments.length === 0) return !!(f & bit);\n    this.flags = state ? f | bit : f & ~bit;\n    return this;\n  };\n}\nOperator.prototype = {\n  /**\n   * Returns a list of target operators dependent on this operator.\n   * If this list does not exist, it is created and then returned.\n   * @return {UniqueList}\n   */\n  targets() {\n    return this._targets || (this._targets = UniqueList(vega_util__WEBPACK_IMPORTED_MODULE_0__.id));\n  },\n  /**\n   * Sets the value of this operator.\n   * @param {*} value - the value to set.\n   * @return {Number} Returns 1 if the operator value has changed\n   *   according to strict equality, returns 0 otherwise.\n   */\n  set(value) {\n    if (this.value !== value) {\n      this.value = value;\n      return 1;\n    } else {\n      return 0;\n    }\n  },\n  /**\n   * Indicates that operator evaluation should be skipped on the next pulse.\n   * This operator will still propagate incoming pulses, but its update function\n   * will not be invoked. The skip flag is reset after every pulse, so calling\n   * this method will affect processing of the next pulse only.\n   */\n  skip: flag(SKIP$1),\n  /**\n   * Indicates that this operator's value has been modified on its most recent\n   * pulse. Normally modification is checked via strict equality; however, in\n   * some cases it is more efficient to update the internal state of an object.\n   * In those cases, the modified flag can be used to trigger propagation. Once\n   * set, the modification flag persists across pulses until unset. The flag can\n   * be used with the last timestamp to test if a modification is recent.\n   */\n  modified: flag(MODIFIED),\n  /**\n   * Sets the parameters for this operator. The parameter values are analyzed for\n   * operator instances. If found, this operator will be added as a dependency\n   * of the parameterizing operator. Operator values are dynamically marshalled\n   * from each operator parameter prior to evaluation. If a parameter value is\n   * an array, the array will also be searched for Operator instances. However,\n   * the search does not recurse into sub-arrays or object properties.\n   * @param {object} params - A hash of operator parameters.\n   * @param {boolean} [react=true] - A flag indicating if this operator should\n   *   automatically update (react) when parameter values change. In other words,\n   *   this flag determines if the operator registers itself as a listener on\n   *   any upstream operators included in the parameters.\n   * @param {boolean} [initonly=false] - A flag indicating if this operator\n   *   should calculate an update only upon its initial evaluation, then\n   *   deregister dependencies and suppress all future update invocations.\n   * @return {Operator[]} - An array of upstream dependencies.\n   */\n  parameters(params, react, initonly) {\n    react = react !== false;\n    const argval = this._argval = this._argval || new Parameters(),\n      argops = this._argops = this._argops || [],\n      deps = [];\n    let name, value, n, i;\n    const add = (name, index, value) => {\n      if (value instanceof Operator) {\n        if (value !== this) {\n          if (react) value.targets().add(this);\n          deps.push(value);\n        }\n        argops.push({\n          op: value,\n          name: name,\n          index: index\n        });\n      } else {\n        argval.set(name, index, value);\n      }\n    };\n    for (name in params) {\n      value = params[name];\n      if (name === PULSE) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(value).forEach(op => {\n          if (!(op instanceof Operator)) {\n            (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Pulse parameters must be operator instances.');\n          } else if (op !== this) {\n            op.targets().add(this);\n            deps.push(op);\n          }\n        });\n        this.source = value;\n      } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value)) {\n        argval.set(name, -1, Array(n = value.length));\n        for (i = 0; i < n; ++i) add(name, i, value[i]);\n      } else {\n        add(name, -1, value);\n      }\n    }\n    this.marshall().clear(); // initialize values\n    if (initonly) argops.initonly = true;\n    return deps;\n  },\n  /**\n   * Internal method for marshalling parameter values.\n   * Visits each operator dependency to pull the latest value.\n   * @return {Parameters} A Parameters object to pass to the update function.\n   */\n  marshall(stamp) {\n    const argval = this._argval || NO_PARAMS,\n      argops = this._argops;\n    let item, i, op, mod;\n    if (argops) {\n      const n = argops.length;\n      for (i = 0; i < n; ++i) {\n        item = argops[i];\n        op = item.op;\n        mod = op.modified() && op.stamp === stamp;\n        argval.set(item.name, item.index, op.value, mod);\n      }\n      if (argops.initonly) {\n        for (i = 0; i < n; ++i) {\n          item = argops[i];\n          item.op.targets().remove(this);\n        }\n        this._argops = null;\n        this._update = null;\n      }\n    }\n    return argval;\n  },\n  /**\n   * Detach this operator from the dataflow.\n   * Unregisters listeners on upstream dependencies.\n   */\n  detach() {\n    const argops = this._argops;\n    let i, n, item, op;\n    if (argops) {\n      for (i = 0, n = argops.length; i < n; ++i) {\n        item = argops[i];\n        op = item.op;\n        if (op._targets) {\n          op._targets.remove(this);\n        }\n      }\n    }\n\n    // remove references to the source and pulse object,\n    // if present, to prevent memory leaks of old data.\n    this.pulse = null;\n    this.source = null;\n  },\n  /**\n   * Delegate method to perform operator processing.\n   * Subclasses can override this method to perform custom processing.\n   * By default, it marshalls parameters and calls the update function\n   * if that function is defined. If the update function does not\n   * change the operator value then StopPropagation is returned.\n   * If no update function is defined, this method does nothing.\n   * @param {Pulse} pulse - the current dataflow pulse.\n   * @return The output pulse or StopPropagation. A falsy return value\n   *   (including undefined) will let the input pulse pass through.\n   */\n  evaluate(pulse) {\n    const update = this._update;\n    if (update) {\n      const params = this.marshall(pulse.stamp),\n        v = update.call(this, params, pulse);\n      params.clear();\n      if (v !== this.value) {\n        this.value = v;\n      } else if (!this.modified()) {\n        return pulse.StopPropagation;\n      }\n    }\n  },\n  /**\n   * Run this operator for the current pulse. If this operator has already\n   * been run at (or after) the pulse timestamp, returns StopPropagation.\n   * Internally, this method calls {@link evaluate} to perform processing.\n   * If {@link evaluate} returns a falsy value, the input pulse is returned.\n   * This method should NOT be overridden, instead overrride {@link evaluate}.\n   * @param {Pulse} pulse - the current dataflow pulse.\n   * @return the output pulse for this operator (or StopPropagation)\n   */\n  run(pulse) {\n    if (pulse.stamp < this.stamp) return pulse.StopPropagation;\n    let rv;\n    if (this.skip()) {\n      this.skip(false);\n      rv = 0;\n    } else {\n      rv = this.evaluate(pulse);\n    }\n    return this.pulse = rv || pulse;\n  }\n};\n\n/**\n * Add an operator to the dataflow graph. This function accepts a\n * variety of input argument types. The basic signature supports an\n * initial value, update function and parameters. If the first parameter\n * is an Operator instance, it will be added directly. If it is a\n * constructor for an Operator subclass, a new instance will be instantiated.\n * Otherwise, if the first parameter is a function instance, it will be used\n * as the update function and a null initial value is assumed.\n * @param {*} init - One of: the operator to add, the initial value of\n *   the operator, an operator class to instantiate, or an update function.\n * @param {function} [update] - The operator update function.\n * @param {object} [params] - The operator parameters.\n * @param {boolean} [react=true] - Flag indicating if this operator should\n *   listen for changes to upstream operators included as parameters.\n * @return {Operator} - The added operator.\n */\nfunction add (init, update, params, react) {\n  let shift = 1,\n    op;\n  if (init instanceof Operator) {\n    op = init;\n  } else if (init && init.prototype instanceof Operator) {\n    op = new init();\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(init)) {\n    op = new Operator(null, init);\n  } else {\n    shift = 0;\n    op = new Operator(init, update);\n  }\n  this.rank(op);\n  if (shift) {\n    react = params;\n    params = update;\n  }\n  if (params) this.connect(op, op.parameters(params, react));\n  this.touch(op);\n  return op;\n}\n\n/**\n * Connect a target operator as a dependent of source operators.\n * If necessary, this method will rerank the target operator and its\n * dependents to ensure propagation proceeds in a topologically sorted order.\n * @param {Operator} target - The target operator.\n * @param {Array<Operator>} - The source operators that should propagate\n *   to the target operator.\n */\nfunction connect (target, sources) {\n  const targetRank = target.rank,\n    n = sources.length;\n  for (let i = 0; i < n; ++i) {\n    if (targetRank < sources[i].rank) {\n      this.rerank(target);\n      return;\n    }\n  }\n}\n\nlet STREAM_ID = 0;\n\n/**\n * Models an event stream.\n * @constructor\n * @param {function(Object, number): boolean} [filter] - Filter predicate.\n *   Events pass through when truthy, events are suppressed when falsy.\n * @param {function(Object): *} [apply] - Applied to input events to produce\n *   new event values.\n * @param {function(Object)} [receive] - Event callback function to invoke\n *   upon receipt of a new event. Use to override standard event processing.\n */\nfunction EventStream(filter, apply, receive) {\n  this.id = ++STREAM_ID;\n  this.value = null;\n  if (receive) this.receive = receive;\n  if (filter) this._filter = filter;\n  if (apply) this._apply = apply;\n}\n\n/**\n * Creates a new event stream instance with the provided\n * (optional) filter, apply and receive functions.\n * @param {function(Object, number): boolean} [filter] - Filter predicate.\n *   Events pass through when truthy, events are suppressed when falsy.\n * @param {function(Object): *} [apply] - Applied to input events to produce\n *   new event values.\n * @see EventStream\n */\nfunction stream(filter, apply, receive) {\n  return new EventStream(filter, apply, receive);\n}\nEventStream.prototype = {\n  _filter: vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy,\n  _apply: vega_util__WEBPACK_IMPORTED_MODULE_0__.identity,\n  targets() {\n    return this._targets || (this._targets = UniqueList(vega_util__WEBPACK_IMPORTED_MODULE_0__.id));\n  },\n  consume(_) {\n    if (!arguments.length) return !!this._consume;\n    this._consume = !!_;\n    return this;\n  },\n  receive(evt) {\n    if (this._filter(evt)) {\n      const val = this.value = this._apply(evt),\n        trg = this._targets,\n        n = trg ? trg.length : 0;\n      for (let i = 0; i < n; ++i) trg[i].receive(val);\n      if (this._consume) {\n        evt.preventDefault();\n        evt.stopPropagation();\n      }\n    }\n  },\n  filter(filter) {\n    const s = stream(filter);\n    this.targets().add(s);\n    return s;\n  },\n  apply(apply) {\n    const s = stream(null, apply);\n    this.targets().add(s);\n    return s;\n  },\n  merge() {\n    const s = stream();\n    this.targets().add(s);\n    for (let i = 0, n = arguments.length; i < n; ++i) {\n      arguments[i].targets().add(s);\n    }\n    return s;\n  },\n  throttle(pause) {\n    let t = -1;\n    return this.filter(() => {\n      const now = Date.now();\n      if (now - t > pause) {\n        t = now;\n        return 1;\n      } else {\n        return 0;\n      }\n    });\n  },\n  debounce(delay) {\n    const s = stream();\n    this.targets().add(stream(null, null, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.debounce)(delay, e => {\n      const df = e.dataflow;\n      s.receive(e);\n      if (df && df.run) df.run();\n    })));\n    return s;\n  },\n  between(a, b) {\n    let active = false;\n    a.targets().add(stream(null, null, () => active = true));\n    b.targets().add(stream(null, null, () => active = false));\n    return this.filter(() => active);\n  },\n  detach() {\n    // ensures compatibility with operators (#2753)\n    // remove references to other streams and filter functions that may\n    // be bound to subcontexts that need to be garbage collected.\n    this._filter = vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy;\n    this._targets = null;\n  }\n};\n\n/**\n * Create a new event stream from an event source.\n * @param {object} source - The event source to monitor. The input must\n *  support the addEventListener method.\n * @param {string} type - The event type.\n * @param {function(object): boolean} [filter] - Event filter function.\n * @param {function(object): *} [apply] - Event application function.\n *   If provided, this function will be invoked and the result will be\n *   used as the downstream event value.\n * @return {EventStream}\n */\nfunction events (source, type, filter, apply) {\n  const df = this,\n    s = stream(filter, apply),\n    send = function (e) {\n      e.dataflow = df;\n      try {\n        s.receive(e);\n      } catch (error) {\n        df.error(error);\n      } finally {\n        df.run();\n      }\n    };\n  let sources;\n  if (typeof source === 'string' && typeof document !== 'undefined') {\n    sources = document.querySelectorAll(source);\n  } else {\n    sources = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(source);\n  }\n  const n = sources.length;\n  for (let i = 0; i < n; ++i) {\n    sources[i].addEventListener(type, send);\n  }\n  return s;\n}\n\nfunction parse(data, format) {\n  const locale = this.locale();\n  return (0,vega_loader__WEBPACK_IMPORTED_MODULE_1__.read)(data, format, locale.timeParse, locale.utcParse);\n}\n\n/**\n * Ingests new data into the dataflow. First parses the data using the\n * vega-loader read method, then pulses a changeset to the target operator.\n * @param {Operator} target - The Operator to target with ingested data,\n *   typically a Collect transform instance.\n * @param {*} data - The input data, prior to parsing. For JSON this may\n *   be a string or an object. For CSV, TSV, etc should be a string.\n * @param {object} format - The data format description for parsing\n *   loaded data. This object is passed to the vega-loader read method.\n * @returns {Dataflow}\n */\nfunction ingest(target, data, format) {\n  data = this.parse(data, format);\n  return this.pulse(target, this.changeset().insert(data));\n}\n\n/**\n * Request data from an external source, parse it, and return a Promise.\n * @param {string} url - The URL from which to load the data. This string\n *   is passed to the vega-loader load method.\n * @param {object} [format] - The data format description for parsing\n *   loaded data. This object is passed to the vega-loader read method.\n * @return {Promise} A Promise that resolves upon completion of the request.\n *   The resolved object contains the following properties:\n *   - data: an array of parsed data (or null upon error)\n *   - status: a code for success (0), load fail (-1), or parse fail (-2)\n */\nasync function request(url, format) {\n  const df = this;\n  let status = 0,\n    data;\n  try {\n    data = await df.loader().load(url, {\n      context: 'dataflow',\n      response: (0,vega_loader__WEBPACK_IMPORTED_MODULE_1__.responseType)(format && format.type)\n    });\n    try {\n      data = df.parse(data, format);\n    } catch (err) {\n      status = -2;\n      df.warn('Data ingestion failed', url, err);\n    }\n  } catch (err) {\n    status = -1;\n    df.warn('Loading failed', url, err);\n  }\n  return {\n    data,\n    status\n  };\n}\nasync function preload(target, url, format) {\n  const df = this,\n    pending = df._pending || loadPending(df);\n  pending.requests += 1;\n  const res = await df.request(url, format);\n  df.pulse(target, df.changeset().remove(vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy).insert(res.data || []));\n  pending.done();\n  return res;\n}\nfunction loadPending(df) {\n  let accept;\n  const pending = new Promise(a => accept = a);\n  pending.requests = 0;\n  pending.done = () => {\n    if (--pending.requests === 0) {\n      df._pending = null;\n      accept(df);\n    }\n  };\n  return df._pending = pending;\n}\n\nconst SKIP = {\n  skip: true\n};\n\n/**\n * Perform operator updates in response to events. Applies an\n * update function to compute a new operator value. If the update function\n * returns a {@link ChangeSet}, the operator will be pulsed with those tuple\n * changes. Otherwise, the operator value will be updated to the return value.\n * @param {EventStream|Operator} source - The event source to react to.\n *   This argument can be either an EventStream or an Operator.\n * @param {Operator|function(object):Operator} target - The operator to update.\n *   This argument can either be an Operator instance or (if the source\n *   argument is an EventStream), a function that accepts an event object as\n *   input and returns an Operator to target.\n * @param {function(Parameters,Event): *} [update] - Optional update function\n *   to compute the new operator value, or a literal value to set. Update\n *   functions expect to receive a parameter object and event as arguments.\n *   This function can either return a new operator value or (if the source\n *   argument is an EventStream) a {@link ChangeSet} instance to pulse\n *   the target operator with tuple changes.\n * @param {object} [params] - The update function parameters.\n * @param {object} [options] - Additional options hash. If not overridden,\n *   updated operators will be skipped by default.\n * @param {boolean} [options.skip] - If true, the operator will\n *  be skipped: it will not be evaluated, but its dependents will be.\n * @param {boolean} [options.force] - If true, the operator will\n *   be re-evaluated even if its value has not changed.\n * @return {Dataflow}\n */\nfunction on (source, target, update, params, options) {\n  const fn = source instanceof Operator ? onOperator : onStream;\n  fn(this, source, target, update, params, options);\n  return this;\n}\nfunction onStream(df, stream, target, update, params, options) {\n  const opt = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, options, SKIP);\n  let func, op;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(target)) target = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(target);\n  if (update === undefined) {\n    func = e => df.touch(target(e));\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(update)) {\n    op = new Operator(null, update, params, false);\n    func = e => {\n      op.evaluate(e);\n      const t = target(e),\n        v = op.value;\n      isChangeSet(v) ? df.pulse(t, v, options) : df.update(t, v, opt);\n    };\n  } else {\n    func = e => df.update(target(e), update, opt);\n  }\n  stream.apply(func);\n}\nfunction onOperator(df, source, target, update, params, options) {\n  if (update === undefined) {\n    source.targets().add(target);\n  } else {\n    const opt = options || {},\n      op = new Operator(null, updater(target, update), params, false);\n    op.modified(opt.force);\n    op.rank = source.rank; // immediately follow source\n    source.targets().add(op); // add dependency\n\n    if (target) {\n      op.skip(true); // skip first invocation\n      op.value = target.value; // initialize value\n      op.targets().add(target); // chain dependencies\n      df.connect(target, [op]); // rerank as needed, #1672\n    }\n  }\n}\n\nfunction updater(target, update) {\n  update = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(update) ? update : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(update);\n  return target ? function (_, pulse) {\n    const value = update(_, pulse);\n    if (!target.skip()) {\n      target.skip(value !== this.value).value = value;\n    }\n    return value;\n  } : update;\n}\n\n/**\n * Assigns a rank to an operator. Ranks are assigned in increasing order\n * by incrementing an internal rank counter.\n * @param {Operator} op - The operator to assign a rank.\n */\nfunction rank(op) {\n  op.rank = ++this._rank;\n}\n\n/**\n * Re-ranks an operator and all downstream target dependencies. This\n * is necessary when upstream dependencies of higher rank are added to\n * a target operator.\n * @param {Operator} op - The operator to re-rank.\n */\nfunction rerank(op) {\n  const queue = [op];\n  let cur, list, i;\n  while (queue.length) {\n    this.rank(cur = queue.pop());\n    if (list = cur._targets) {\n      for (i = list.length; --i >= 0;) {\n        queue.push(cur = list[i]);\n        if (cur === op) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Cycle detected in dataflow graph.');\n      }\n    }\n  }\n}\n\n/**\n * Sentinel value indicating pulse propagation should stop.\n */\nconst StopPropagation = {};\n\n// Pulse visit type flags\nconst ADD = 1 << 0,\n  REM = 1 << 1,\n  MOD = 1 << 2,\n  ADD_REM = ADD | REM,\n  ADD_MOD = ADD | MOD,\n  ALL = ADD | REM | MOD,\n  REFLOW = 1 << 3,\n  SOURCE = 1 << 4,\n  NO_SOURCE = 1 << 5,\n  NO_FIELDS = 1 << 6;\n\n/**\n * A Pulse enables inter-operator communication during a run of the\n * dataflow graph. In addition to the current timestamp, a pulse may also\n * contain a change-set of added, removed or modified data tuples, as well as\n * a pointer to a full backing data source. Tuple change sets may not\n * be fully materialized; for example, to prevent needless array creation\n * a change set may include larger arrays and corresponding filter functions.\n * The pulse provides a {@link visit} method to enable proper and efficient\n * iteration over requested data tuples.\n *\n * In addition, each pulse can track modification flags for data tuple fields.\n * Responsible transform operators should call the {@link modifies} method to\n * indicate changes to data fields. The {@link modified} method enables\n * querying of this modification state.\n *\n * @constructor\n * @param {Dataflow} dataflow - The backing dataflow instance.\n * @param {number} stamp - The current propagation timestamp.\n * @param {string} [encode] - An optional encoding set name, which is then\n *   accessible as Pulse.encode. Operators can respond to (or ignore) this\n *   setting as appropriate. This parameter can be used in conjunction with\n *   the Encode transform in the vega-encode module.\n */\nfunction Pulse(dataflow, stamp, encode) {\n  this.dataflow = dataflow;\n  this.stamp = stamp == null ? -1 : stamp;\n  this.add = [];\n  this.rem = [];\n  this.mod = [];\n  this.fields = null;\n  this.encode = encode || null;\n}\nfunction materialize(data, filter) {\n  const out = [];\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(data, filter, _ => out.push(_));\n  return out;\n}\nfunction filter(pulse, flags) {\n  const map = {};\n  pulse.visit(flags, t => {\n    map[tupleid(t)] = 1;\n  });\n  return t => map[tupleid(t)] ? null : t;\n}\nfunction addFilter(a, b) {\n  return a ? (t, i) => a(t, i) && b(t, i) : b;\n}\nPulse.prototype = {\n  /**\n   * Sentinel value indicating pulse propagation should stop.\n   */\n  StopPropagation,\n  /**\n   * Boolean flag indicating ADD (added) tuples.\n   */\n  ADD,\n  /**\n   * Boolean flag indicating REM (removed) tuples.\n   */\n  REM,\n  /**\n   * Boolean flag indicating MOD (modified) tuples.\n   */\n  MOD,\n  /**\n   * Boolean flag indicating ADD (added) and REM (removed) tuples.\n   */\n  ADD_REM,\n  /**\n   * Boolean flag indicating ADD (added) and MOD (modified) tuples.\n   */\n  ADD_MOD,\n  /**\n   * Boolean flag indicating ADD, REM and MOD tuples.\n   */\n  ALL,\n  /**\n   * Boolean flag indicating all tuples in a data source\n   * except for the ADD, REM and MOD tuples.\n   */\n  REFLOW,\n  /**\n   * Boolean flag indicating a 'pass-through' to a\n   * backing data source, ignoring ADD, REM and MOD tuples.\n   */\n  SOURCE,\n  /**\n   * Boolean flag indicating that source data should be\n   * suppressed when creating a forked pulse.\n   */\n  NO_SOURCE,\n  /**\n   * Boolean flag indicating that field modifications should be\n   * suppressed when creating a forked pulse.\n   */\n  NO_FIELDS,\n  /**\n   * Creates a new pulse based on the values of this pulse.\n   * The dataflow, time stamp and field modification values are copied over.\n   * By default, new empty ADD, REM and MOD arrays are created.\n   * @param {number} flags - Integer of boolean flags indicating which (if any)\n   *   tuple arrays should be copied to the new pulse. The supported flag values\n   *   are ADD, REM and MOD. Array references are copied directly: new array\n   *   instances are not created.\n   * @return {Pulse} - The forked pulse instance.\n   * @see init\n   */\n  fork(flags) {\n    return new Pulse(this.dataflow).init(this, flags);\n  },\n  /**\n   * Creates a copy of this pulse with new materialized array\n   * instances for the ADD, REM, MOD, and SOURCE arrays.\n   * The dataflow, time stamp and field modification values are copied over.\n   * @return {Pulse} - The cloned pulse instance.\n   * @see init\n   */\n  clone() {\n    const p = this.fork(ALL);\n    p.add = p.add.slice();\n    p.rem = p.rem.slice();\n    p.mod = p.mod.slice();\n    if (p.source) p.source = p.source.slice();\n    return p.materialize(ALL | SOURCE);\n  },\n  /**\n   * Returns a pulse that adds all tuples from a backing source. This is\n   * useful for cases where operators are added to a dataflow after an\n   * upstream data pipeline has already been processed, ensuring that\n   * new operators can observe all tuples within a stream.\n   * @return {Pulse} - A pulse instance with all source tuples included\n   *   in the add array. If the current pulse already has all source\n   *   tuples in its add array, it is returned directly. If the current\n   *   pulse does not have a backing source, it is returned directly.\n   */\n  addAll() {\n    let p = this;\n    const reuse = !p.source || p.add === p.rem // special case for indexed set (e.g., crossfilter)\n    || !p.rem.length && p.source.length === p.add.length;\n    if (reuse) {\n      return p;\n    } else {\n      p = new Pulse(this.dataflow).init(this);\n      p.add = p.source;\n      p.rem = []; // new operators can ignore rem #2769\n      return p;\n    }\n  },\n  /**\n   * Initialize this pulse based on the values of another pulse. This method\n   * is used internally by {@link fork} to initialize a new forked tuple.\n   * The dataflow, time stamp and field modification values are copied over.\n   * By default, new empty ADD, REM and MOD arrays are created.\n   * @param {Pulse} src - The source pulse to copy from.\n   * @param {number} flags - Integer of boolean flags indicating which (if any)\n   *   tuple arrays should be copied to the new pulse. The supported flag values\n   *   are ADD, REM and MOD. Array references are copied directly: new array\n   *   instances are not created. By default, source data arrays are copied\n   *   to the new pulse. Use the NO_SOURCE flag to enforce a null source.\n   * @return {Pulse} - Returns this Pulse instance.\n   */\n  init(src, flags) {\n    const p = this;\n    p.stamp = src.stamp;\n    p.encode = src.encode;\n    if (src.fields && !(flags & NO_FIELDS)) {\n      p.fields = src.fields;\n    }\n    if (flags & ADD) {\n      p.addF = src.addF;\n      p.add = src.add;\n    } else {\n      p.addF = null;\n      p.add = [];\n    }\n    if (flags & REM) {\n      p.remF = src.remF;\n      p.rem = src.rem;\n    } else {\n      p.remF = null;\n      p.rem = [];\n    }\n    if (flags & MOD) {\n      p.modF = src.modF;\n      p.mod = src.mod;\n    } else {\n      p.modF = null;\n      p.mod = [];\n    }\n    if (flags & NO_SOURCE) {\n      p.srcF = null;\n      p.source = null;\n    } else {\n      p.srcF = src.srcF;\n      p.source = src.source;\n      if (src.cleans) p.cleans = src.cleans;\n    }\n    return p;\n  },\n  /**\n   * Schedules a function to run after pulse propagation completes.\n   * @param {function} func - The function to run.\n   */\n  runAfter(func) {\n    this.dataflow.runAfter(func);\n  },\n  /**\n   * Indicates if tuples have been added, removed or modified.\n   * @param {number} [flags] - The tuple types (ADD, REM or MOD) to query.\n   *   Defaults to ALL, returning true if any tuple type has changed.\n   * @return {boolean} - Returns true if one or more queried tuple types have\n   *   changed, false otherwise.\n   */\n  changed(flags) {\n    const f = flags || ALL;\n    return f & ADD && this.add.length || f & REM && this.rem.length || f & MOD && this.mod.length;\n  },\n  /**\n   * Forces a \"reflow\" of tuple values, such that all tuples in the backing\n   * source are added to the MOD set, unless already present in the ADD set.\n   * @param {boolean} [fork=false] - If true, returns a forked copy of this\n   *   pulse, and invokes reflow on that derived pulse.\n   * @return {Pulse} - The reflowed pulse instance.\n   */\n  reflow(fork) {\n    if (fork) return this.fork(ALL).reflow();\n    const len = this.add.length,\n      src = this.source && this.source.length;\n    if (src && src !== len) {\n      this.mod = this.source;\n      if (len) this.filter(MOD, filter(this, ADD));\n    }\n    return this;\n  },\n  /**\n   * Get/set metadata to pulse requesting garbage collection\n   * to reclaim currently unused resources.\n   */\n  clean(value) {\n    if (arguments.length) {\n      this.cleans = !!value;\n      return this;\n    } else {\n      return this.cleans;\n    }\n  },\n  /**\n   * Marks one or more data field names as modified to assist dependency\n   * tracking and incremental processing by transform operators.\n   * @param {string|Array<string>} _ - The field(s) to mark as modified.\n   * @return {Pulse} - This pulse instance.\n   */\n  modifies(_) {\n    const hash = this.fields || (this.fields = {});\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_)) {\n      _.forEach(f => hash[f] = true);\n    } else {\n      hash[_] = true;\n    }\n    return this;\n  },\n  /**\n   * Checks if one or more data fields have been modified during this pulse\n   * propagation timestamp.\n   * @param {string|Array<string>} _ - The field(s) to check for modified.\n   * @param {boolean} nomod - If true, will check the modified flag even if\n   *   no mod tuples exist. If false (default), mod tuples must be present.\n   * @return {boolean} - Returns true if any of the provided fields has been\n   *   marked as modified, false otherwise.\n   */\n  modified(_, nomod) {\n    const fields = this.fields;\n    return !((nomod || this.mod.length) && fields) ? false : !arguments.length ? !!fields : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_) ? _.some(f => fields[f]) : fields[_];\n  },\n  /**\n   * Adds a filter function to one more tuple sets. Filters are applied to\n   * backing tuple arrays, to determine the actual set of tuples considered\n   * added, removed or modified. They can be used to delay materialization of\n   * a tuple set in order to avoid expensive array copies. In addition, the\n   * filter functions can serve as value transformers: unlike standard predicate\n   * function (which return boolean values), Pulse filters should return the\n   * actual tuple value to process. If a tuple set is already filtered, the\n   * new filter function will be appended into a conjuntive ('and') query.\n   * @param {number} flags - Flags indicating the tuple set(s) to filter.\n   * @param {function(*):object} filter - Filter function that will be applied\n   *   to the tuple set array, and should return a data tuple if the value\n   *   should be included in the tuple set, and falsy (or null) otherwise.\n   * @return {Pulse} - Returns this pulse instance.\n   */\n  filter(flags, filter) {\n    const p = this;\n    if (flags & ADD) p.addF = addFilter(p.addF, filter);\n    if (flags & REM) p.remF = addFilter(p.remF, filter);\n    if (flags & MOD) p.modF = addFilter(p.modF, filter);\n    if (flags & SOURCE) p.srcF = addFilter(p.srcF, filter);\n    return p;\n  },\n  /**\n   * Materialize one or more tuple sets in this pulse. If the tuple set(s) have\n   * a registered filter function, it will be applied and the tuple set(s) will\n   * be replaced with materialized tuple arrays.\n   * @param {number} flags - Flags indicating the tuple set(s) to materialize.\n   * @return {Pulse} - Returns this pulse instance.\n   */\n  materialize(flags) {\n    flags = flags || ALL;\n    const p = this;\n    if (flags & ADD && p.addF) {\n      p.add = materialize(p.add, p.addF);\n      p.addF = null;\n    }\n    if (flags & REM && p.remF) {\n      p.rem = materialize(p.rem, p.remF);\n      p.remF = null;\n    }\n    if (flags & MOD && p.modF) {\n      p.mod = materialize(p.mod, p.modF);\n      p.modF = null;\n    }\n    if (flags & SOURCE && p.srcF) {\n      p.source = p.source.filter(p.srcF);\n      p.srcF = null;\n    }\n    return p;\n  },\n  /**\n   * Visit one or more tuple sets in this pulse.\n   * @param {number} flags - Flags indicating the tuple set(s) to visit.\n   *   Legal values are ADD, REM, MOD and SOURCE (if a backing data source\n   *   has been set).\n   * @param {function(object):*} - Visitor function invoked per-tuple.\n   * @return {Pulse} - Returns this pulse instance.\n   */\n  visit(flags, visitor) {\n    const p = this,\n      v = visitor;\n    if (flags & SOURCE) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(p.source, p.srcF, v);\n      return p;\n    }\n    if (flags & ADD) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(p.add, p.addF, v);\n    if (flags & REM) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(p.rem, p.remF, v);\n    if (flags & MOD) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(p.mod, p.modF, v);\n    const src = p.source;\n    if (flags & REFLOW && src) {\n      const sum = p.add.length + p.mod.length;\n      if (sum === src.length) ; else if (sum) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(src, filter(p, ADD_MOD), v);\n      } else {\n        // if no add/rem/mod tuples, visit source\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray)(src, p.srcF, v);\n      }\n    }\n    return p;\n  }\n};\n\n/**\n * Represents a set of multiple pulses. Used as input for operators\n * that accept multiple pulses at a time. Contained pulses are\n * accessible via the public \"pulses\" array property. This pulse doe\n * not carry added, removed or modified tuples directly. However,\n * the visit method can be used to traverse all such tuples contained\n * in sub-pulses with a timestamp matching this parent multi-pulse.\n * @constructor\n * @param {Dataflow} dataflow - The backing dataflow instance.\n * @param {number} stamp - The timestamp.\n * @param {Array<Pulse>} pulses - The sub-pulses for this multi-pulse.\n */\nfunction MultiPulse(dataflow, stamp, pulses, encode) {\n  const p = this;\n  let c = 0;\n  this.dataflow = dataflow;\n  this.stamp = stamp;\n  this.fields = null;\n  this.encode = encode || null;\n  this.pulses = pulses;\n  for (const pulse of pulses) {\n    if (pulse.stamp !== stamp) continue;\n    if (pulse.fields) {\n      const hash = p.fields || (p.fields = {});\n      for (const f in pulse.fields) {\n        hash[f] = 1;\n      }\n    }\n    if (pulse.changed(p.ADD)) c |= p.ADD;\n    if (pulse.changed(p.REM)) c |= p.REM;\n    if (pulse.changed(p.MOD)) c |= p.MOD;\n  }\n  this.changes = c;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(MultiPulse, Pulse, {\n  /**\n   * Creates a new pulse based on the values of this pulse.\n   * The dataflow, time stamp and field modification values are copied over.\n   * @return {Pulse}\n   */\n  fork(flags) {\n    const p = new Pulse(this.dataflow).init(this, flags & this.NO_FIELDS);\n    if (flags !== undefined) {\n      if (flags & p.ADD) this.visit(p.ADD, t => p.add.push(t));\n      if (flags & p.REM) this.visit(p.REM, t => p.rem.push(t));\n      if (flags & p.MOD) this.visit(p.MOD, t => p.mod.push(t));\n    }\n    return p;\n  },\n  changed(flags) {\n    return this.changes & flags;\n  },\n  modified(_) {\n    const p = this,\n      fields = p.fields;\n    return !(fields && p.changes & p.MOD) ? 0 : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_) ? _.some(f => fields[f]) : fields[_];\n  },\n  filter() {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('MultiPulse does not support filtering.');\n  },\n  materialize() {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('MultiPulse does not support materialization.');\n  },\n  visit(flags, visitor) {\n    const p = this,\n      pulses = p.pulses,\n      n = pulses.length;\n    let i = 0;\n    if (flags & p.SOURCE) {\n      for (; i < n; ++i) {\n        pulses[i].visit(flags, visitor);\n      }\n    } else {\n      for (; i < n; ++i) {\n        if (pulses[i].stamp === p.stamp) {\n          pulses[i].visit(flags, visitor);\n        }\n      }\n    }\n    return p;\n  }\n});\n\n/* eslint-disable require-atomic-updates */\n\n/**\n * Evaluates the dataflow and returns a Promise that resolves when pulse\n * propagation completes. This method will increment the current timestamp\n * and process all updated, pulsed and touched operators. When invoked for\n * the first time, all registered operators will be processed. This method\n * should not be invoked by third-party clients, use {@link runAsync} or\n * {@link run} instead.\n * @param {string} [encode] - The name of an encoding set to invoke during\n *   propagation. This value is added to generated Pulse instances;\n *   operators can then respond to (or ignore) this setting as appropriate.\n *   This parameter can be used in conjunction with the Encode transform in\n *   the vega-encode package.\n * @param {function} [prerun] - An optional callback function to invoke\n *   immediately before dataflow evaluation commences.\n * @param {function} [postrun] - An optional callback function to invoke\n *   after dataflow evaluation completes. The callback will be invoked\n *   after those registered via {@link runAfter}.\n * @return {Promise} - A promise that resolves to this dataflow after\n *   evaluation completes.\n */\nasync function evaluate(encode, prerun, postrun) {\n  const df = this,\n    async = [];\n\n  // if the pulse value is set, this is a re-entrant call\n  if (df._pulse) return reentrant(df);\n\n  // wait for pending datasets to load\n  if (df._pending) await df._pending;\n\n  // invoke prerun function, if provided\n  if (prerun) await asyncCallback(df, prerun);\n\n  // exit early if there are no updates\n  if (!df._touched.length) {\n    df.debug('Dataflow invoked, but nothing to do.');\n    return df;\n  }\n\n  // increment timestamp clock\n  const stamp = ++df._clock;\n\n  // set the current pulse\n  df._pulse = new Pulse(df, stamp, encode);\n\n  // initialize priority queue, reset touched operators\n  df._touched.forEach(op => df._enqueue(op, true));\n  df._touched = UniqueList(vega_util__WEBPACK_IMPORTED_MODULE_0__.id);\n  let count = 0,\n    op,\n    next,\n    error;\n  try {\n    while (df._heap.size() > 0) {\n      // dequeue operator with highest priority\n      op = df._heap.pop();\n\n      // re-queue if rank changed\n      if (op.rank !== op.qrank) {\n        df._enqueue(op, true);\n        continue;\n      }\n\n      // otherwise, evaluate the operator\n      next = op.run(df._getPulse(op, encode));\n      if (next.then) {\n        // await if operator returns a promise directly\n        next = await next;\n      } else if (next.async) {\n        // queue parallel asynchronous execution\n        async.push(next.async);\n        next = StopPropagation;\n      }\n\n      // propagate evaluation, enqueue dependent operators\n      if (next !== StopPropagation) {\n        if (op._targets) op._targets.forEach(op => df._enqueue(op));\n      }\n\n      // increment visit counter\n      ++count;\n    }\n  } catch (err) {\n    df._heap.clear();\n    error = err;\n  }\n\n  // reset pulse map\n  df._input = {};\n  df._pulse = null;\n  df.debug(`Pulse ${stamp}: ${count} operators`);\n  if (error) {\n    df._postrun = [];\n    df.error(error);\n  }\n\n  // invoke callbacks queued via runAfter\n  if (df._postrun.length) {\n    const pr = df._postrun.sort((a, b) => b.priority - a.priority);\n    df._postrun = [];\n    for (let i = 0; i < pr.length; ++i) {\n      await asyncCallback(df, pr[i].callback);\n    }\n  }\n\n  // invoke postrun function, if provided\n  if (postrun) await asyncCallback(df, postrun);\n\n  // handle non-blocking asynchronous callbacks\n  if (async.length) {\n    Promise.all(async).then(cb => df.runAsync(null, () => {\n      cb.forEach(f => {\n        try {\n          f(df);\n        } catch (err) {\n          df.error(err);\n        }\n      });\n    }));\n  }\n  return df;\n}\n\n/**\n * Queues dataflow evaluation to run once any other queued evaluations have\n * completed and returns a Promise that resolves when the queued pulse\n * propagation completes. If provided, a callback function will be invoked\n * immediately before evaluation commences. This method will ensure a\n * separate evaluation is invoked for each time it is called.\n * @param {string} [encode] - The name of an encoding set to invoke during\n *   propagation. This value is added to generated Pulse instances;\n *   operators can then respond to (or ignore) this setting as appropriate.\n *   This parameter can be used in conjunction with the Encode transform in\n *   the vega-encode package.\n * @param {function} [prerun] - An optional callback function to invoke\n *   immediately before dataflow evaluation commences.\n * @param {function} [postrun] - An optional callback function to invoke\n *   after dataflow evaluation completes. The callback will be invoked\n *   after those registered via {@link runAfter}.\n * @return {Promise} - A promise that resolves to this dataflow after\n *   evaluation completes.\n */\nasync function runAsync(encode, prerun, postrun) {\n  // await previously queued functions\n  while (this._running) await this._running;\n\n  // run dataflow, manage running promise\n  const clear = () => this._running = null;\n  (this._running = this.evaluate(encode, prerun, postrun)).then(clear, clear);\n  return this._running;\n}\n\n/**\n * Requests dataflow evaluation and the immediately returns this dataflow\n * instance. If there are pending data loading or other asynchronous\n * operations, the dataflow will evaluate asynchronously after this method\n * has been invoked. To track when dataflow evaluation completes, use the\n * {@link runAsync} method instead. This method will raise an error if\n * invoked while the dataflow is already in the midst of evaluation.\n * @param {string} [encode] - The name of an encoding set to invoke during\n *   propagation. This value is added to generated Pulse instances;\n *   operators can then respond to (or ignore) this setting as appropriate.\n *   This parameter can be used in conjunction with the Encode transform in\n *   the vega-encode module.\n * @param {function} [prerun] - An optional callback function to invoke\n *   immediately before dataflow evaluation commences.\n * @param {function} [postrun] - An optional callback function to invoke\n *   after dataflow evaluation completes. The callback will be invoked\n *   after those registered via {@link runAfter}.\n * @return {Dataflow} - This dataflow instance.\n */\nfunction run(encode, prerun, postrun) {\n  return this._pulse ? reentrant(this) : (this.evaluate(encode, prerun, postrun), this);\n}\n\n/**\n * Schedules a callback function to be invoked after the current pulse\n * propagation completes. If no propagation is currently occurring,\n * the function is invoked immediately. Callbacks scheduled via runAfter\n * are invoked immediately upon completion of the current cycle, before\n * any request queued via runAsync. This method is primarily intended for\n * internal use. Third-party callers using runAfter to schedule a callback\n * that invokes {@link run} or {@link runAsync} should not use this method,\n * but instead use {@link runAsync} with prerun or postrun arguments.\n * @param {function(Dataflow)} callback - The callback function to run.\n *   The callback will be invoked with this Dataflow instance as its\n *   sole argument.\n * @param {boolean} enqueue - A boolean flag indicating that the\n *   callback should be queued up to run after the next propagation\n *   cycle, suppressing immediate invocation when propagation is not\n *   currently occurring.\n * @param {number} [priority] - A priority value used to sort registered\n *   callbacks to determine execution order. This argument is intended\n *   for internal Vega use only.\n */\nfunction runAfter(callback, enqueue, priority) {\n  if (this._pulse || enqueue) {\n    // pulse propagation is currently running, queue to run after\n    this._postrun.push({\n      priority: priority || 0,\n      callback: callback\n    });\n  } else {\n    // pulse propagation already complete, invoke immediately\n    try {\n      callback(this);\n    } catch (err) {\n      this.error(err);\n    }\n  }\n}\n\n/**\n * Raise an error for re-entrant dataflow evaluation.\n */\nfunction reentrant(df) {\n  df.error('Dataflow already running. Use runAsync() to chain invocations.');\n  return df;\n}\n\n/**\n * Enqueue an operator into the priority queue for evaluation. The operator\n * will be enqueued if it has no registered pulse for the current cycle, or if\n * the force argument is true. Upon enqueue, this method also sets the\n * operator's qrank to the current rank value.\n * @param {Operator} op - The operator to enqueue.\n * @param {boolean} [force] - A flag indicating if the operator should be\n *   forceably added to the queue, even if it has already been previously\n *   enqueued during the current pulse propagation. This is useful when the\n *   dataflow graph is dynamically modified and the operator rank changes.\n */\nfunction enqueue(op, force) {\n  const q = op.stamp < this._clock;\n  if (q) op.stamp = this._clock;\n  if (q || force) {\n    op.qrank = op.rank;\n    this._heap.push(op);\n  }\n}\n\n/**\n * Provide a correct pulse for evaluating an operator. If the operator has an\n * explicit source operator, we will try to pull the pulse(s) from it.\n * If there is an array of source operators, we build a multi-pulse.\n * Otherwise, we return a current pulse with correct source data.\n * If the pulse is the pulse map has an explicit target set, we use that.\n * Else if the pulse on the upstream source operator is current, we use that.\n * Else we use the pulse from the pulse map, but copy the source tuple array.\n * @param {Operator} op - The operator for which to get an input pulse.\n * @param {string} [encode] - An (optional) encoding set name with which to\n *   annotate the returned pulse. See {@link run} for more information.\n */\nfunction getPulse(op, encode) {\n  const s = op.source,\n    stamp = this._clock;\n  return s && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(s) ? new MultiPulse(this, stamp, s.map(_ => _.pulse), encode) : this._input[op.id] || singlePulse(this._pulse, s && s.pulse);\n}\nfunction singlePulse(p, s) {\n  if (s && s.stamp === p.stamp) {\n    return s;\n  }\n  p = p.fork();\n  if (s && s !== StopPropagation) {\n    p.source = s.source;\n  }\n  return p;\n}\n\nconst NO_OPT = {\n  skip: false,\n  force: false\n};\n\n/**\n * Touches an operator, scheduling it to be evaluated. If invoked outside of\n * a pulse propagation, the operator will be evaluated the next time this\n * dataflow is run. If invoked in the midst of pulse propagation, the operator\n * will be queued for evaluation if and only if the operator has not yet been\n * evaluated on the current propagation timestamp.\n * @param {Operator} op - The operator to touch.\n * @param {object} [options] - Additional options hash.\n * @param {boolean} [options.skip] - If true, the operator will\n *   be skipped: it will not be evaluated, but its dependents will be.\n * @return {Dataflow}\n */\nfunction touch(op, options) {\n  const opt = options || NO_OPT;\n  if (this._pulse) {\n    // if in midst of propagation, add to priority queue\n    this._enqueue(op);\n  } else {\n    // otherwise, queue for next propagation\n    this._touched.add(op);\n  }\n  if (opt.skip) op.skip(true);\n  return this;\n}\n\n/**\n * Updates the value of the given operator.\n * @param {Operator} op - The operator to update.\n * @param {*} value - The value to set.\n * @param {object} [options] - Additional options hash.\n * @param {boolean} [options.force] - If true, the operator will\n *   be re-evaluated even if its value has not changed.\n * @param {boolean} [options.skip] - If true, the operator will\n *   be skipped: it will not be evaluated, but its dependents will be.\n * @return {Dataflow}\n */\nfunction update(op, value, options) {\n  const opt = options || NO_OPT;\n  if (op.set(value) || opt.force) {\n    this.touch(op, opt);\n  }\n  return this;\n}\n\n/**\n * Pulses an operator with a changeset of tuples. If invoked outside of\n * a pulse propagation, the pulse will be applied the next time this\n * dataflow is run. If invoked in the midst of pulse propagation, the pulse\n * will be added to the set of active pulses and will be applied if and\n * only if the target operator has not yet been evaluated on the current\n * propagation timestamp.\n * @param {Operator} op - The operator to pulse.\n * @param {ChangeSet} value - The tuple changeset to apply.\n * @param {object} [options] - Additional options hash.\n * @param {boolean} [options.skip] - If true, the operator will\n *   be skipped: it will not be evaluated, but its dependents will be.\n * @return {Dataflow}\n */\nfunction pulse(op, changeset, options) {\n  this.touch(op, options || NO_OPT);\n  const p = new Pulse(this, this._clock + (this._pulse ? 0 : 1)),\n    t = op.pulse && op.pulse.source || [];\n  p.target = op;\n  this._input[op.id] = changeset.pulse(p, t);\n  return this;\n}\n\nfunction Heap(cmp) {\n  let nodes = [];\n  return {\n    clear: () => nodes = [],\n    size: () => nodes.length,\n    peek: () => nodes[0],\n    push: x => {\n      nodes.push(x);\n      return siftdown(nodes, 0, nodes.length - 1, cmp);\n    },\n    pop: () => {\n      const last = nodes.pop();\n      let item;\n      if (nodes.length) {\n        item = nodes[0];\n        nodes[0] = last;\n        siftup(nodes, 0, cmp);\n      } else {\n        item = last;\n      }\n      return item;\n    }\n  };\n}\nfunction siftdown(array, start, idx, cmp) {\n  let parent, pidx;\n  const item = array[idx];\n  while (idx > start) {\n    pidx = idx - 1 >> 1;\n    parent = array[pidx];\n    if (cmp(item, parent) < 0) {\n      array[idx] = parent;\n      idx = pidx;\n      continue;\n    }\n    break;\n  }\n  return array[idx] = item;\n}\nfunction siftup(array, idx, cmp) {\n  const start = idx,\n    end = array.length,\n    item = array[idx];\n  let cidx = (idx << 1) + 1,\n    ridx;\n  while (cidx < end) {\n    ridx = cidx + 1;\n    if (ridx < end && cmp(array[cidx], array[ridx]) >= 0) {\n      cidx = ridx;\n    }\n    array[idx] = array[cidx];\n    idx = cidx;\n    cidx = (idx << 1) + 1;\n  }\n  array[idx] = item;\n  return siftdown(array, start, idx, cmp);\n}\n\n/**\n * A dataflow graph for reactive processing of data streams.\n * @constructor\n */\nfunction Dataflow() {\n  this.logger((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.logger)());\n  this.logLevel(vega_util__WEBPACK_IMPORTED_MODULE_0__.Error);\n  this._clock = 0;\n  this._rank = 0;\n  this._locale = (0,vega_format__WEBPACK_IMPORTED_MODULE_2__.defaultLocale)();\n  try {\n    this._loader = (0,vega_loader__WEBPACK_IMPORTED_MODULE_1__.loader)();\n  } catch (e) {\n    // do nothing if loader module is unavailable\n  }\n  this._touched = UniqueList(vega_util__WEBPACK_IMPORTED_MODULE_0__.id);\n  this._input = {};\n  this._pulse = null;\n  this._heap = Heap((a, b) => a.qrank - b.qrank);\n  this._postrun = [];\n}\nfunction logMethod(method) {\n  return function () {\n    return this._log[method].apply(this, arguments);\n  };\n}\nDataflow.prototype = {\n  /**\n   * The current timestamp of this dataflow. This value reflects the\n   * timestamp of the previous dataflow run. The dataflow is initialized\n   * with a stamp value of 0. The initial run of the dataflow will have\n   * a timestap of 1, and so on. This value will match the\n   * {@link Pulse.stamp} property.\n   * @return {number} - The current timestamp value.\n   */\n  stamp() {\n    return this._clock;\n  },\n  /**\n   * Gets or sets the loader instance to use for data file loading. A\n   * loader object must provide a \"load\" method for loading files and a\n   * \"sanitize\" method for checking URL/filename validity. Both methods\n   * should accept a URI and options hash as arguments, and return a Promise\n   * that resolves to the loaded file contents (load) or a hash containing\n   * sanitized URI data with the sanitized url assigned to the \"href\" property\n   * (sanitize).\n   * @param {object} _ - The loader instance to use.\n   * @return {object|Dataflow} - If no arguments are provided, returns\n   *   the current loader instance. Otherwise returns this Dataflow instance.\n   */\n  loader(_) {\n    if (arguments.length) {\n      this._loader = _;\n      return this;\n    } else {\n      return this._loader;\n    }\n  },\n  /**\n   * Gets or sets the locale instance to use for formatting and parsing\n   * string values. The locale object should be provided by the\n   * vega-format library, and include methods such as format, timeFormat,\n   * utcFormat, timeParse, and utcParse.\n   * @param {object} _ - The locale instance to use.\n   * @return {object|Dataflow} - If no arguments are provided, returns\n   *   the current locale instance. Otherwise returns this Dataflow instance.\n   */\n  locale(_) {\n    if (arguments.length) {\n      this._locale = _;\n      return this;\n    } else {\n      return this._locale;\n    }\n  },\n  /**\n   * Get or set the logger instance used to log messages. If no arguments are\n   * provided, returns the current logger instance. Otherwise, sets the logger\n   * and return this Dataflow instance. Provided loggers must support the full\n   * API of logger objects generated by the vega-util logger method. Note that\n   * by default the log level of the new logger will be used; use the logLevel\n   * method to adjust the log level as needed.\n   */\n  logger(logger) {\n    if (arguments.length) {\n      this._log = logger;\n      return this;\n    } else {\n      return this._log;\n    }\n  },\n  /**\n   * Logs an error message. By default, logged messages are written to console\n   * output. The message will only be logged if the current log level is high\n   * enough to permit error messages.\n   */\n  error: logMethod('error'),\n  /**\n   * Logs a warning message. By default, logged messages are written to console\n   * output. The message will only be logged if the current log level is high\n   * enough to permit warning messages.\n   */\n  warn: logMethod('warn'),\n  /**\n   * Logs a information message. By default, logged messages are written to\n   * console output. The message will only be logged if the current log level is\n   * high enough to permit information messages.\n   */\n  info: logMethod('info'),\n  /**\n   * Logs a debug message. By default, logged messages are written to console\n   * output. The message will only be logged if the current log level is high\n   * enough to permit debug messages.\n   */\n  debug: logMethod('debug'),\n  /**\n   * Get or set the current log level. If an argument is provided, it\n   * will be used as the new log level.\n   * @param {number} [level] - Should be one of None, Warn, Info\n   * @return {number} - The current log level.\n   */\n  logLevel: logMethod('level'),\n  /**\n   * Empty entry threshold for garbage cleaning. Map data structures will\n   * perform cleaning once the number of empty entries exceeds this value.\n   */\n  cleanThreshold: 1e4,\n  // OPERATOR REGISTRATION\n  add,\n  connect,\n  rank,\n  rerank,\n  // OPERATOR UPDATES\n  pulse,\n  touch,\n  update,\n  changeset,\n  // DATA LOADING\n  ingest,\n  parse,\n  preload,\n  request,\n  // EVENT HANDLING\n  events,\n  on,\n  // PULSE PROPAGATION\n  evaluate,\n  run,\n  runAsync,\n  runAfter,\n  _enqueue: enqueue,\n  _getPulse: getPulse\n};\n\n/**\n * Abstract class for operators that process data tuples.\n * Subclasses must provide a {@link transform} method for operator processing.\n * @constructor\n * @param {*} [init] - The initial value for this operator.\n * @param {object} [params] - The parameters for this operator.\n * @param {Operator} [source] - The operator from which to receive pulses.\n */\nfunction Transform(init, params) {\n  Operator.call(this, init, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Transform, Operator, {\n  /**\n   * Overrides {@link Operator.evaluate} for transform operators.\n   * Internally, this method calls {@link evaluate} to perform processing.\n   * If {@link evaluate} returns a falsy value, the input pulse is returned.\n   * This method should NOT be overridden, instead overrride {@link evaluate}.\n   * @param {Pulse} pulse - the current dataflow pulse.\n   * @return the output pulse for this operator (or StopPropagation)\n   */\n  run(pulse) {\n    if (pulse.stamp < this.stamp) return pulse.StopPropagation;\n    let rv;\n    if (this.skip()) {\n      this.skip(false);\n    } else {\n      rv = this.evaluate(pulse);\n    }\n    rv = rv || pulse;\n    if (rv.then) {\n      rv = rv.then(_ => this.pulse = _);\n    } else if (rv !== pulse.StopPropagation) {\n      this.pulse = rv;\n    }\n    return rv;\n  },\n  /**\n   * Overrides {@link Operator.evaluate} for transform operators.\n   * Marshalls parameter values and then invokes {@link transform}.\n   * @param {Pulse} pulse - the current dataflow pulse.\n   * @return {Pulse} The output pulse (or StopPropagation). A falsy return\n       value (including undefined) will let the input pulse pass through.\n  */\n  evaluate(pulse) {\n    const params = this.marshall(pulse.stamp),\n      out = this.transform(params, pulse);\n    params.clear();\n    return out;\n  },\n  /**\n   * Process incoming pulses.\n   * Subclasses should override this method to implement transforms.\n   * @param {Parameters} _ - The operator parameter values.\n   * @param {Pulse} pulse - The current dataflow pulse.\n   * @return {Pulse} The output pulse (or StopPropagation). A falsy return\n   *   value (including undefined) will let the input pulse pass through.\n   */\n  transform() {}\n});\n\nconst transforms = {};\nfunction definition(type) {\n  const t = transform(type);\n  return t && t.Definition || null;\n}\nfunction transform(type) {\n  type = type && type.toLowerCase();\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(transforms, type) ? transforms[type] : null;\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-dataflow/build/vega-dataflow.module.js?");

/***/ }),

/***/ "../../node_modules/vega-embed/build/vega-embed.module.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-embed/build/vega-embed.module.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DEFAULT_ACTIONS: () => (/* binding */ DEFAULT_ACTIONS),\n/* harmony export */   \"default\": () => (/* binding */ embed),\n/* harmony export */   guessMode: () => (/* binding */ guessMode),\n/* harmony export */   vega: () => (/* binding */ vega),\n/* harmony export */   vegaLite: () => (/* binding */ vegaLite),\n/* harmony export */   version: () => (/* binding */ version)\n/* harmony export */ });\n/* harmony import */ var fast_json_patch__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! fast-json-patch */ \"../../node_modules/fast-json-patch/index.mjs\");\n/* harmony import */ var json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! json-stringify-pretty-compact */ \"../../node_modules/json-stringify-pretty-compact/index.js\");\n/* harmony import */ var json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_interpreter__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-interpreter */ \"../../node_modules/vega-interpreter/build/vega-interpreter.module.js\");\n/* harmony import */ var vega_lite__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-lite */ \"../../node_modules/vega-lite/build/src/index.js\");\n/* harmony import */ var vega_schema_url_parser__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! vega-schema-url-parser */ \"../../node_modules/vega-schema-url-parser/dist/parser.module.js\");\n/* harmony import */ var vega_themes__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! vega-themes */ \"../../node_modules/vega-themes/build/vega-themes.module.js\");\n/* harmony import */ var vega_tooltip__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! vega-tooltip */ \"../../node_modules/vega-tooltip/build/vega-tooltip.module.js\");\n\n\n\n\n\n\n\n\n\n\nfunction _typeof(obj) {\n  \"@babel/helpers - typeof\";\n\n  return _typeof = \"function\" == typeof Symbol && \"symbol\" == typeof Symbol.iterator ? function (obj) {\n    return typeof obj;\n  } : function (obj) {\n    return obj && \"function\" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj;\n  }, _typeof(obj);\n}\n\nfunction _toPrimitive(input, hint) {\n  if (_typeof(input) !== \"object\" || input === null) return input;\n  var prim = input[Symbol.toPrimitive];\n  if (prim !== undefined) {\n    var res = prim.call(input, hint || \"default\");\n    if (_typeof(res) !== \"object\") return res;\n    throw new TypeError(\"@@toPrimitive must return a primitive value.\");\n  }\n  return (hint === \"string\" ? String : Number)(input);\n}\n\nfunction _toPropertyKey(arg) {\n  var key = _toPrimitive(arg, \"string\");\n  return _typeof(key) === \"symbol\" ? key : String(key);\n}\n\nfunction _defineProperty(obj, key, value) {\n  key = _toPropertyKey(key);\n  if (key in obj) {\n    Object.defineProperty(obj, key, {\n      value: value,\n      enumerable: true,\n      configurable: true,\n      writable: true\n    });\n  } else {\n    obj[key] = value;\n  }\n  return obj;\n}\n\nfunction getDefaultExportFromCjs (x) {\n\treturn x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;\n}\n\nvar iterator;\nvar hasRequiredIterator;\nfunction requireIterator() {\n  if (hasRequiredIterator) return iterator;\n  hasRequiredIterator = 1;\n  iterator = function (Yallist) {\n    Yallist.prototype[Symbol.iterator] = function* () {\n      for (let walker = this.head; walker; walker = walker.next) {\n        yield walker.value;\n      }\n    };\n  };\n  return iterator;\n}\n\nvar yallist = Yallist$1;\nYallist$1.Node = Node;\nYallist$1.create = Yallist$1;\nfunction Yallist$1(list) {\n  var self = this;\n  if (!(self instanceof Yallist$1)) {\n    self = new Yallist$1();\n  }\n  self.tail = null;\n  self.head = null;\n  self.length = 0;\n  if (list && typeof list.forEach === 'function') {\n    list.forEach(function (item) {\n      self.push(item);\n    });\n  } else if (arguments.length > 0) {\n    for (var i = 0, l = arguments.length; i < l; i++) {\n      self.push(arguments[i]);\n    }\n  }\n  return self;\n}\nYallist$1.prototype.removeNode = function (node) {\n  if (node.list !== this) {\n    throw new Error('removing node which does not belong to this list');\n  }\n  var next = node.next;\n  var prev = node.prev;\n  if (next) {\n    next.prev = prev;\n  }\n  if (prev) {\n    prev.next = next;\n  }\n  if (node === this.head) {\n    this.head = next;\n  }\n  if (node === this.tail) {\n    this.tail = prev;\n  }\n  node.list.length--;\n  node.next = null;\n  node.prev = null;\n  node.list = null;\n  return next;\n};\nYallist$1.prototype.unshiftNode = function (node) {\n  if (node === this.head) {\n    return;\n  }\n  if (node.list) {\n    node.list.removeNode(node);\n  }\n  var head = this.head;\n  node.list = this;\n  node.next = head;\n  if (head) {\n    head.prev = node;\n  }\n  this.head = node;\n  if (!this.tail) {\n    this.tail = node;\n  }\n  this.length++;\n};\nYallist$1.prototype.pushNode = function (node) {\n  if (node === this.tail) {\n    return;\n  }\n  if (node.list) {\n    node.list.removeNode(node);\n  }\n  var tail = this.tail;\n  node.list = this;\n  node.prev = tail;\n  if (tail) {\n    tail.next = node;\n  }\n  this.tail = node;\n  if (!this.head) {\n    this.head = node;\n  }\n  this.length++;\n};\nYallist$1.prototype.push = function () {\n  for (var i = 0, l = arguments.length; i < l; i++) {\n    push(this, arguments[i]);\n  }\n  return this.length;\n};\nYallist$1.prototype.unshift = function () {\n  for (var i = 0, l = arguments.length; i < l; i++) {\n    unshift(this, arguments[i]);\n  }\n  return this.length;\n};\nYallist$1.prototype.pop = function () {\n  if (!this.tail) {\n    return undefined;\n  }\n  var res = this.tail.value;\n  this.tail = this.tail.prev;\n  if (this.tail) {\n    this.tail.next = null;\n  } else {\n    this.head = null;\n  }\n  this.length--;\n  return res;\n};\nYallist$1.prototype.shift = function () {\n  if (!this.head) {\n    return undefined;\n  }\n  var res = this.head.value;\n  this.head = this.head.next;\n  if (this.head) {\n    this.head.prev = null;\n  } else {\n    this.tail = null;\n  }\n  this.length--;\n  return res;\n};\nYallist$1.prototype.forEach = function (fn, thisp) {\n  thisp = thisp || this;\n  for (var walker = this.head, i = 0; walker !== null; i++) {\n    fn.call(thisp, walker.value, i, this);\n    walker = walker.next;\n  }\n};\nYallist$1.prototype.forEachReverse = function (fn, thisp) {\n  thisp = thisp || this;\n  for (var walker = this.tail, i = this.length - 1; walker !== null; i--) {\n    fn.call(thisp, walker.value, i, this);\n    walker = walker.prev;\n  }\n};\nYallist$1.prototype.get = function (n) {\n  for (var i = 0, walker = this.head; walker !== null && i < n; i++) {\n    // abort out of the list early if we hit a cycle\n    walker = walker.next;\n  }\n  if (i === n && walker !== null) {\n    return walker.value;\n  }\n};\nYallist$1.prototype.getReverse = function (n) {\n  for (var i = 0, walker = this.tail; walker !== null && i < n; i++) {\n    // abort out of the list early if we hit a cycle\n    walker = walker.prev;\n  }\n  if (i === n && walker !== null) {\n    return walker.value;\n  }\n};\nYallist$1.prototype.map = function (fn, thisp) {\n  thisp = thisp || this;\n  var res = new Yallist$1();\n  for (var walker = this.head; walker !== null;) {\n    res.push(fn.call(thisp, walker.value, this));\n    walker = walker.next;\n  }\n  return res;\n};\nYallist$1.prototype.mapReverse = function (fn, thisp) {\n  thisp = thisp || this;\n  var res = new Yallist$1();\n  for (var walker = this.tail; walker !== null;) {\n    res.push(fn.call(thisp, walker.value, this));\n    walker = walker.prev;\n  }\n  return res;\n};\nYallist$1.prototype.reduce = function (fn, initial) {\n  var acc;\n  var walker = this.head;\n  if (arguments.length > 1) {\n    acc = initial;\n  } else if (this.head) {\n    walker = this.head.next;\n    acc = this.head.value;\n  } else {\n    throw new TypeError('Reduce of empty list with no initial value');\n  }\n  for (var i = 0; walker !== null; i++) {\n    acc = fn(acc, walker.value, i);\n    walker = walker.next;\n  }\n  return acc;\n};\nYallist$1.prototype.reduceReverse = function (fn, initial) {\n  var acc;\n  var walker = this.tail;\n  if (arguments.length > 1) {\n    acc = initial;\n  } else if (this.tail) {\n    walker = this.tail.prev;\n    acc = this.tail.value;\n  } else {\n    throw new TypeError('Reduce of empty list with no initial value');\n  }\n  for (var i = this.length - 1; walker !== null; i--) {\n    acc = fn(acc, walker.value, i);\n    walker = walker.prev;\n  }\n  return acc;\n};\nYallist$1.prototype.toArray = function () {\n  var arr = new Array(this.length);\n  for (var i = 0, walker = this.head; walker !== null; i++) {\n    arr[i] = walker.value;\n    walker = walker.next;\n  }\n  return arr;\n};\nYallist$1.prototype.toArrayReverse = function () {\n  var arr = new Array(this.length);\n  for (var i = 0, walker = this.tail; walker !== null; i++) {\n    arr[i] = walker.value;\n    walker = walker.prev;\n  }\n  return arr;\n};\nYallist$1.prototype.slice = function (from, to) {\n  to = to || this.length;\n  if (to < 0) {\n    to += this.length;\n  }\n  from = from || 0;\n  if (from < 0) {\n    from += this.length;\n  }\n  var ret = new Yallist$1();\n  if (to < from || to < 0) {\n    return ret;\n  }\n  if (from < 0) {\n    from = 0;\n  }\n  if (to > this.length) {\n    to = this.length;\n  }\n  for (var i = 0, walker = this.head; walker !== null && i < from; i++) {\n    walker = walker.next;\n  }\n  for (; walker !== null && i < to; i++, walker = walker.next) {\n    ret.push(walker.value);\n  }\n  return ret;\n};\nYallist$1.prototype.sliceReverse = function (from, to) {\n  to = to || this.length;\n  if (to < 0) {\n    to += this.length;\n  }\n  from = from || 0;\n  if (from < 0) {\n    from += this.length;\n  }\n  var ret = new Yallist$1();\n  if (to < from || to < 0) {\n    return ret;\n  }\n  if (from < 0) {\n    from = 0;\n  }\n  if (to > this.length) {\n    to = this.length;\n  }\n  for (var i = this.length, walker = this.tail; walker !== null && i > to; i--) {\n    walker = walker.prev;\n  }\n  for (; walker !== null && i > from; i--, walker = walker.prev) {\n    ret.push(walker.value);\n  }\n  return ret;\n};\nYallist$1.prototype.splice = function (start, deleteCount, ...nodes) {\n  if (start > this.length) {\n    start = this.length - 1;\n  }\n  if (start < 0) {\n    start = this.length + start;\n  }\n  for (var i = 0, walker = this.head; walker !== null && i < start; i++) {\n    walker = walker.next;\n  }\n  var ret = [];\n  for (var i = 0; walker && i < deleteCount; i++) {\n    ret.push(walker.value);\n    walker = this.removeNode(walker);\n  }\n  if (walker === null) {\n    walker = this.tail;\n  }\n  if (walker !== this.head && walker !== this.tail) {\n    walker = walker.prev;\n  }\n  for (var i = 0; i < nodes.length; i++) {\n    walker = insert(this, walker, nodes[i]);\n  }\n  return ret;\n};\nYallist$1.prototype.reverse = function () {\n  var head = this.head;\n  var tail = this.tail;\n  for (var walker = head; walker !== null; walker = walker.prev) {\n    var p = walker.prev;\n    walker.prev = walker.next;\n    walker.next = p;\n  }\n  this.head = tail;\n  this.tail = head;\n  return this;\n};\nfunction insert(self, node, value) {\n  var inserted = node === self.head ? new Node(value, null, node, self) : new Node(value, node, node.next, self);\n  if (inserted.next === null) {\n    self.tail = inserted;\n  }\n  if (inserted.prev === null) {\n    self.head = inserted;\n  }\n  self.length++;\n  return inserted;\n}\nfunction push(self, item) {\n  self.tail = new Node(item, self.tail, null, self);\n  if (!self.head) {\n    self.head = self.tail;\n  }\n  self.length++;\n}\nfunction unshift(self, item) {\n  self.head = new Node(item, null, self.head, self);\n  if (!self.tail) {\n    self.tail = self.head;\n  }\n  self.length++;\n}\nfunction Node(value, prev, next, list) {\n  if (!(this instanceof Node)) {\n    return new Node(value, prev, next, list);\n  }\n  this.list = list;\n  this.value = value;\n  if (prev) {\n    prev.next = this;\n    this.prev = prev;\n  } else {\n    this.prev = null;\n  }\n  if (next) {\n    next.prev = this;\n    this.next = next;\n  } else {\n    this.next = null;\n  }\n}\ntry {\n  // add if support for Symbol.iterator is present\n  requireIterator()(Yallist$1);\n} catch (er) {}\n\n// A linked list to keep track of recently-used-ness\nconst Yallist = yallist;\nconst MAX = Symbol('max');\nconst LENGTH = Symbol('length');\nconst LENGTH_CALCULATOR = Symbol('lengthCalculator');\nconst ALLOW_STALE = Symbol('allowStale');\nconst MAX_AGE = Symbol('maxAge');\nconst DISPOSE = Symbol('dispose');\nconst NO_DISPOSE_ON_SET = Symbol('noDisposeOnSet');\nconst LRU_LIST = Symbol('lruList');\nconst CACHE = Symbol('cache');\nconst UPDATE_AGE_ON_GET = Symbol('updateAgeOnGet');\nconst naiveLength = () => 1;\n\n// lruList is a yallist where the head is the youngest\n// item, and the tail is the oldest.  the list contains the Hit\n// objects as the entries.\n// Each Hit object has a reference to its Yallist.Node.  This\n// never changes.\n//\n// cache is a Map (or PseudoMap) that matches the keys to\n// the Yallist.Node object.\nclass LRUCache {\n  constructor(options) {\n    if (typeof options === 'number') options = {\n      max: options\n    };\n    if (!options) options = {};\n    if (options.max && (typeof options.max !== 'number' || options.max < 0)) throw new TypeError('max must be a non-negative number');\n    // Kind of weird to have a default max of Infinity, but oh well.\n    this[MAX] = options.max || Infinity;\n    const lc = options.length || naiveLength;\n    this[LENGTH_CALCULATOR] = typeof lc !== 'function' ? naiveLength : lc;\n    this[ALLOW_STALE] = options.stale || false;\n    if (options.maxAge && typeof options.maxAge !== 'number') throw new TypeError('maxAge must be a number');\n    this[MAX_AGE] = options.maxAge || 0;\n    this[DISPOSE] = options.dispose;\n    this[NO_DISPOSE_ON_SET] = options.noDisposeOnSet || false;\n    this[UPDATE_AGE_ON_GET] = options.updateAgeOnGet || false;\n    this.reset();\n  }\n\n  // resize the cache when the max changes.\n  set max(mL) {\n    if (typeof mL !== 'number' || mL < 0) throw new TypeError('max must be a non-negative number');\n    this[MAX] = mL || Infinity;\n    trim(this);\n  }\n  get max() {\n    return this[MAX];\n  }\n  set allowStale(allowStale) {\n    this[ALLOW_STALE] = !!allowStale;\n  }\n  get allowStale() {\n    return this[ALLOW_STALE];\n  }\n  set maxAge(mA) {\n    if (typeof mA !== 'number') throw new TypeError('maxAge must be a non-negative number');\n    this[MAX_AGE] = mA;\n    trim(this);\n  }\n  get maxAge() {\n    return this[MAX_AGE];\n  }\n\n  // resize the cache when the lengthCalculator changes.\n  set lengthCalculator(lC) {\n    if (typeof lC !== 'function') lC = naiveLength;\n    if (lC !== this[LENGTH_CALCULATOR]) {\n      this[LENGTH_CALCULATOR] = lC;\n      this[LENGTH] = 0;\n      this[LRU_LIST].forEach(hit => {\n        hit.length = this[LENGTH_CALCULATOR](hit.value, hit.key);\n        this[LENGTH] += hit.length;\n      });\n    }\n    trim(this);\n  }\n  get lengthCalculator() {\n    return this[LENGTH_CALCULATOR];\n  }\n  get length() {\n    return this[LENGTH];\n  }\n  get itemCount() {\n    return this[LRU_LIST].length;\n  }\n  rforEach(fn, thisp) {\n    thisp = thisp || this;\n    for (let walker = this[LRU_LIST].tail; walker !== null;) {\n      const prev = walker.prev;\n      forEachStep(this, fn, walker, thisp);\n      walker = prev;\n    }\n  }\n  forEach(fn, thisp) {\n    thisp = thisp || this;\n    for (let walker = this[LRU_LIST].head; walker !== null;) {\n      const next = walker.next;\n      forEachStep(this, fn, walker, thisp);\n      walker = next;\n    }\n  }\n  keys() {\n    return this[LRU_LIST].toArray().map(k => k.key);\n  }\n  values() {\n    return this[LRU_LIST].toArray().map(k => k.value);\n  }\n  reset() {\n    if (this[DISPOSE] && this[LRU_LIST] && this[LRU_LIST].length) {\n      this[LRU_LIST].forEach(hit => this[DISPOSE](hit.key, hit.value));\n    }\n    this[CACHE] = new Map(); // hash of items by key\n    this[LRU_LIST] = new Yallist(); // list of items in order of use recency\n    this[LENGTH] = 0; // length of items in the list\n  }\n\n  dump() {\n    return this[LRU_LIST].map(hit => isStale(this, hit) ? false : {\n      k: hit.key,\n      v: hit.value,\n      e: hit.now + (hit.maxAge || 0)\n    }).toArray().filter(h => h);\n  }\n  dumpLru() {\n    return this[LRU_LIST];\n  }\n  set(key, value, maxAge) {\n    maxAge = maxAge || this[MAX_AGE];\n    if (maxAge && typeof maxAge !== 'number') throw new TypeError('maxAge must be a number');\n    const now = maxAge ? Date.now() : 0;\n    const len = this[LENGTH_CALCULATOR](value, key);\n    if (this[CACHE].has(key)) {\n      if (len > this[MAX]) {\n        del(this, this[CACHE].get(key));\n        return false;\n      }\n      const node = this[CACHE].get(key);\n      const item = node.value;\n\n      // dispose of the old one before overwriting\n      // split out into 2 ifs for better coverage tracking\n      if (this[DISPOSE]) {\n        if (!this[NO_DISPOSE_ON_SET]) this[DISPOSE](key, item.value);\n      }\n      item.now = now;\n      item.maxAge = maxAge;\n      item.value = value;\n      this[LENGTH] += len - item.length;\n      item.length = len;\n      this.get(key);\n      trim(this);\n      return true;\n    }\n    const hit = new Entry(key, value, len, now, maxAge);\n\n    // oversized objects fall out of cache automatically.\n    if (hit.length > this[MAX]) {\n      if (this[DISPOSE]) this[DISPOSE](key, value);\n      return false;\n    }\n    this[LENGTH] += hit.length;\n    this[LRU_LIST].unshift(hit);\n    this[CACHE].set(key, this[LRU_LIST].head);\n    trim(this);\n    return true;\n  }\n  has(key) {\n    if (!this[CACHE].has(key)) return false;\n    const hit = this[CACHE].get(key).value;\n    return !isStale(this, hit);\n  }\n  get(key) {\n    return get(this, key, true);\n  }\n  peek(key) {\n    return get(this, key, false);\n  }\n  pop() {\n    const node = this[LRU_LIST].tail;\n    if (!node) return null;\n    del(this, node);\n    return node.value;\n  }\n  del(key) {\n    del(this, this[CACHE].get(key));\n  }\n  load(arr) {\n    // reset the cache\n    this.reset();\n    const now = Date.now();\n    // A previous serialized cache has the most recent items first\n    for (let l = arr.length - 1; l >= 0; l--) {\n      const hit = arr[l];\n      const expiresAt = hit.e || 0;\n      if (expiresAt === 0)\n        // the item was created without expiration in a non aged cache\n        this.set(hit.k, hit.v);else {\n        const maxAge = expiresAt - now;\n        // dont add already expired items\n        if (maxAge > 0) {\n          this.set(hit.k, hit.v, maxAge);\n        }\n      }\n    }\n  }\n  prune() {\n    this[CACHE].forEach((value, key) => get(this, key, false));\n  }\n}\nconst get = (self, key, doUse) => {\n  const node = self[CACHE].get(key);\n  if (node) {\n    const hit = node.value;\n    if (isStale(self, hit)) {\n      del(self, node);\n      if (!self[ALLOW_STALE]) return undefined;\n    } else {\n      if (doUse) {\n        if (self[UPDATE_AGE_ON_GET]) node.value.now = Date.now();\n        self[LRU_LIST].unshiftNode(node);\n      }\n    }\n    return hit.value;\n  }\n};\nconst isStale = (self, hit) => {\n  if (!hit || !hit.maxAge && !self[MAX_AGE]) return false;\n  const diff = Date.now() - hit.now;\n  return hit.maxAge ? diff > hit.maxAge : self[MAX_AGE] && diff > self[MAX_AGE];\n};\nconst trim = self => {\n  if (self[LENGTH] > self[MAX]) {\n    for (let walker = self[LRU_LIST].tail; self[LENGTH] > self[MAX] && walker !== null;) {\n      // We know that we're about to delete this one, and also\n      // what the next least recently used key will be, so just\n      // go ahead and set it now.\n      const prev = walker.prev;\n      del(self, walker);\n      walker = prev;\n    }\n  }\n};\nconst del = (self, node) => {\n  if (node) {\n    const hit = node.value;\n    if (self[DISPOSE]) self[DISPOSE](hit.key, hit.value);\n    self[LENGTH] -= hit.length;\n    self[CACHE].delete(hit.key);\n    self[LRU_LIST].removeNode(node);\n  }\n};\nclass Entry {\n  constructor(key, value, length, now, maxAge) {\n    this.key = key;\n    this.value = value;\n    this.length = length;\n    this.now = now;\n    this.maxAge = maxAge || 0;\n  }\n}\nconst forEachStep = (self, fn, node, thisp) => {\n  let hit = node.value;\n  if (isStale(self, hit)) {\n    del(self, node);\n    if (!self[ALLOW_STALE]) hit = undefined;\n  }\n  if (hit) fn.call(thisp, hit.value, hit.key, self);\n};\nvar lruCache = LRUCache;\n\n// parse out just the options we care about\nconst looseOption = Object.freeze({\n  loose: true\n});\nconst emptyOpts = Object.freeze({});\nconst parseOptions$1 = options => {\n  if (!options) {\n    return emptyOpts;\n  }\n  if (typeof options !== 'object') {\n    return looseOption;\n  }\n  return options;\n};\nvar parseOptions_1 = parseOptions$1;\n\nvar re$1 = {exports: {}};\n\n// Note: this is the semver.org version of the spec that it implements\n// Not necessarily the package version of this code.\nconst SEMVER_SPEC_VERSION = '2.0.0';\nconst MAX_LENGTH$1 = 256;\nconst MAX_SAFE_INTEGER$1 = Number.MAX_SAFE_INTEGER || /* istanbul ignore next */9007199254740991;\n\n// Max safe segment length for coercion.\nconst MAX_SAFE_COMPONENT_LENGTH = 16;\n\n// Max safe length for a build identifier. The max length minus 6 characters for\n// the shortest version with a build 0.0.0+BUILD.\nconst MAX_SAFE_BUILD_LENGTH = MAX_LENGTH$1 - 6;\nconst RELEASE_TYPES = ['major', 'premajor', 'minor', 'preminor', 'patch', 'prepatch', 'prerelease'];\nvar constants = {\n  MAX_LENGTH: MAX_LENGTH$1,\n  MAX_SAFE_COMPONENT_LENGTH,\n  MAX_SAFE_BUILD_LENGTH,\n  MAX_SAFE_INTEGER: MAX_SAFE_INTEGER$1,\n  RELEASE_TYPES,\n  SEMVER_SPEC_VERSION,\n  FLAG_INCLUDE_PRERELEASE: 0b001,\n  FLAG_LOOSE: 0b010\n};\n\nconst debug$1 = typeof process === 'object' && process.env && process.env.NODE_DEBUG && /\\bsemver\\b/i.test(process.env.NODE_DEBUG) ? (...args) => console.error('SEMVER', ...args) : () => {};\nvar debug_1 = debug$1;\n\n(function (module, exports) {\n  const {\n    MAX_SAFE_COMPONENT_LENGTH,\n    MAX_SAFE_BUILD_LENGTH,\n    MAX_LENGTH\n  } = constants;\n  const debug = debug_1;\n  exports = module.exports = {};\n\n  // The actual regexps go on exports.re\n  const re = exports.re = [];\n  const safeRe = exports.safeRe = [];\n  const src = exports.src = [];\n  const t = exports.t = {};\n  let R = 0;\n  const LETTERDASHNUMBER = '[a-zA-Z0-9-]';\n\n  // Replace some greedy regex tokens to prevent regex dos issues. These regex are\n  // used internally via the safeRe object since all inputs in this library get\n  // normalized first to trim and collapse all extra whitespace. The original\n  // regexes are exported for userland consumption and lower level usage. A\n  // future breaking change could export the safer regex only with a note that\n  // all input should have extra whitespace removed.\n  const safeRegexReplacements = [['\\\\s', 1], ['\\\\d', MAX_LENGTH], [LETTERDASHNUMBER, MAX_SAFE_BUILD_LENGTH]];\n  const makeSafeRegex = value => {\n    for (const [token, max] of safeRegexReplacements) {\n      value = value.split(`${token}*`).join(`${token}{0,${max}}`).split(`${token}+`).join(`${token}{1,${max}}`);\n    }\n    return value;\n  };\n  const createToken = (name, value, isGlobal) => {\n    const safe = makeSafeRegex(value);\n    const index = R++;\n    debug(name, index, value);\n    t[name] = index;\n    src[index] = value;\n    re[index] = new RegExp(value, isGlobal ? 'g' : undefined);\n    safeRe[index] = new RegExp(safe, isGlobal ? 'g' : undefined);\n  };\n\n  // The following Regular Expressions can be used for tokenizing,\n  // validating, and parsing SemVer version strings.\n\n  // ## Numeric Identifier\n  // A single `0`, or a non-zero digit followed by zero or more digits.\n\n  createToken('NUMERICIDENTIFIER', '0|[1-9]\\\\d*');\n  createToken('NUMERICIDENTIFIERLOOSE', '\\\\d+');\n\n  // ## Non-numeric Identifier\n  // Zero or more digits, followed by a letter or hyphen, and then zero or\n  // more letters, digits, or hyphens.\n\n  createToken('NONNUMERICIDENTIFIER', `\\\\d*[a-zA-Z-]${LETTERDASHNUMBER}*`);\n\n  // ## Main Version\n  // Three dot-separated numeric identifiers.\n\n  createToken('MAINVERSION', `(${src[t.NUMERICIDENTIFIER]})\\\\.` + `(${src[t.NUMERICIDENTIFIER]})\\\\.` + `(${src[t.NUMERICIDENTIFIER]})`);\n  createToken('MAINVERSIONLOOSE', `(${src[t.NUMERICIDENTIFIERLOOSE]})\\\\.` + `(${src[t.NUMERICIDENTIFIERLOOSE]})\\\\.` + `(${src[t.NUMERICIDENTIFIERLOOSE]})`);\n\n  // ## Pre-release Version Identifier\n  // A numeric identifier, or a non-numeric identifier.\n\n  createToken('PRERELEASEIDENTIFIER', `(?:${src[t.NUMERICIDENTIFIER]}|${src[t.NONNUMERICIDENTIFIER]})`);\n  createToken('PRERELEASEIDENTIFIERLOOSE', `(?:${src[t.NUMERICIDENTIFIERLOOSE]}|${src[t.NONNUMERICIDENTIFIER]})`);\n\n  // ## Pre-release Version\n  // Hyphen, followed by one or more dot-separated pre-release version\n  // identifiers.\n\n  createToken('PRERELEASE', `(?:-(${src[t.PRERELEASEIDENTIFIER]}(?:\\\\.${src[t.PRERELEASEIDENTIFIER]})*))`);\n  createToken('PRERELEASELOOSE', `(?:-?(${src[t.PRERELEASEIDENTIFIERLOOSE]}(?:\\\\.${src[t.PRERELEASEIDENTIFIERLOOSE]})*))`);\n\n  // ## Build Metadata Identifier\n  // Any combination of digits, letters, or hyphens.\n\n  createToken('BUILDIDENTIFIER', `${LETTERDASHNUMBER}+`);\n\n  // ## Build Metadata\n  // Plus sign, followed by one or more period-separated build metadata\n  // identifiers.\n\n  createToken('BUILD', `(?:\\\\+(${src[t.BUILDIDENTIFIER]}(?:\\\\.${src[t.BUILDIDENTIFIER]})*))`);\n\n  // ## Full Version String\n  // A main version, followed optionally by a pre-release version and\n  // build metadata.\n\n  // Note that the only major, minor, patch, and pre-release sections of\n  // the version string are capturing groups.  The build metadata is not a\n  // capturing group, because it should not ever be used in version\n  // comparison.\n\n  createToken('FULLPLAIN', `v?${src[t.MAINVERSION]}${src[t.PRERELEASE]}?${src[t.BUILD]}?`);\n  createToken('FULL', `^${src[t.FULLPLAIN]}$`);\n\n  // like full, but allows v1.2.3 and =1.2.3, which people do sometimes.\n  // also, 1.0.0alpha1 (prerelease without the hyphen) which is pretty\n  // common in the npm registry.\n  createToken('LOOSEPLAIN', `[v=\\\\s]*${src[t.MAINVERSIONLOOSE]}${src[t.PRERELEASELOOSE]}?${src[t.BUILD]}?`);\n  createToken('LOOSE', `^${src[t.LOOSEPLAIN]}$`);\n  createToken('GTLT', '((?:<|>)?=?)');\n\n  // Something like \"2.*\" or \"1.2.x\".\n  // Note that \"x.x\" is a valid xRange identifer, meaning \"any version\"\n  // Only the first item is strictly required.\n  createToken('XRANGEIDENTIFIERLOOSE', `${src[t.NUMERICIDENTIFIERLOOSE]}|x|X|\\\\*`);\n  createToken('XRANGEIDENTIFIER', `${src[t.NUMERICIDENTIFIER]}|x|X|\\\\*`);\n  createToken('XRANGEPLAIN', `[v=\\\\s]*(${src[t.XRANGEIDENTIFIER]})` + `(?:\\\\.(${src[t.XRANGEIDENTIFIER]})` + `(?:\\\\.(${src[t.XRANGEIDENTIFIER]})` + `(?:${src[t.PRERELEASE]})?${src[t.BUILD]}?` + `)?)?`);\n  createToken('XRANGEPLAINLOOSE', `[v=\\\\s]*(${src[t.XRANGEIDENTIFIERLOOSE]})` + `(?:\\\\.(${src[t.XRANGEIDENTIFIERLOOSE]})` + `(?:\\\\.(${src[t.XRANGEIDENTIFIERLOOSE]})` + `(?:${src[t.PRERELEASELOOSE]})?${src[t.BUILD]}?` + `)?)?`);\n  createToken('XRANGE', `^${src[t.GTLT]}\\\\s*${src[t.XRANGEPLAIN]}$`);\n  createToken('XRANGELOOSE', `^${src[t.GTLT]}\\\\s*${src[t.XRANGEPLAINLOOSE]}$`);\n\n  // Coercion.\n  // Extract anything that could conceivably be a part of a valid semver\n  createToken('COERCE', `${'(^|[^\\\\d])' + '(\\\\d{1,'}${MAX_SAFE_COMPONENT_LENGTH}})` + `(?:\\\\.(\\\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?` + `(?:\\\\.(\\\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?` + `(?:$|[^\\\\d])`);\n  createToken('COERCERTL', src[t.COERCE], true);\n\n  // Tilde ranges.\n  // Meaning is \"reasonably at or greater than\"\n  createToken('LONETILDE', '(?:~>?)');\n  createToken('TILDETRIM', `(\\\\s*)${src[t.LONETILDE]}\\\\s+`, true);\n  exports.tildeTrimReplace = '$1~';\n  createToken('TILDE', `^${src[t.LONETILDE]}${src[t.XRANGEPLAIN]}$`);\n  createToken('TILDELOOSE', `^${src[t.LONETILDE]}${src[t.XRANGEPLAINLOOSE]}$`);\n\n  // Caret ranges.\n  // Meaning is \"at least and backwards compatible with\"\n  createToken('LONECARET', '(?:\\\\^)');\n  createToken('CARETTRIM', `(\\\\s*)${src[t.LONECARET]}\\\\s+`, true);\n  exports.caretTrimReplace = '$1^';\n  createToken('CARET', `^${src[t.LONECARET]}${src[t.XRANGEPLAIN]}$`);\n  createToken('CARETLOOSE', `^${src[t.LONECARET]}${src[t.XRANGEPLAINLOOSE]}$`);\n\n  // A simple gt/lt/eq thing, or just \"\" to indicate \"any version\"\n  createToken('COMPARATORLOOSE', `^${src[t.GTLT]}\\\\s*(${src[t.LOOSEPLAIN]})$|^$`);\n  createToken('COMPARATOR', `^${src[t.GTLT]}\\\\s*(${src[t.FULLPLAIN]})$|^$`);\n\n  // An expression to strip any whitespace between the gtlt and the thing\n  // it modifies, so that `> 1.2.3` ==> `>1.2.3`\n  createToken('COMPARATORTRIM', `(\\\\s*)${src[t.GTLT]}\\\\s*(${src[t.LOOSEPLAIN]}|${src[t.XRANGEPLAIN]})`, true);\n  exports.comparatorTrimReplace = '$1$2$3';\n\n  // Something like `1.2.3 - 1.2.4`\n  // Note that these all use the loose form, because they'll be\n  // checked against either the strict or loose comparator form\n  // later.\n  createToken('HYPHENRANGE', `^\\\\s*(${src[t.XRANGEPLAIN]})` + `\\\\s+-\\\\s+` + `(${src[t.XRANGEPLAIN]})` + `\\\\s*$`);\n  createToken('HYPHENRANGELOOSE', `^\\\\s*(${src[t.XRANGEPLAINLOOSE]})` + `\\\\s+-\\\\s+` + `(${src[t.XRANGEPLAINLOOSE]})` + `\\\\s*$`);\n\n  // Star ranges basically just allow anything at all.\n  createToken('STAR', '(<|>)?=?\\\\s*\\\\*');\n  // >=0.0.0 is like a star\n  createToken('GTE0', '^\\\\s*>=\\\\s*0\\\\.0\\\\.0\\\\s*$');\n  createToken('GTE0PRE', '^\\\\s*>=\\\\s*0\\\\.0\\\\.0-0\\\\s*$');\n})(re$1, re$1.exports);\nvar reExports = re$1.exports;\n\nconst numeric = /^[0-9]+$/;\nconst compareIdentifiers$1 = (a, b) => {\n  const anum = numeric.test(a);\n  const bnum = numeric.test(b);\n  if (anum && bnum) {\n    a = +a;\n    b = +b;\n  }\n  return a === b ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a < b ? -1 : 1;\n};\nconst rcompareIdentifiers = (a, b) => compareIdentifiers$1(b, a);\nvar identifiers = {\n  compareIdentifiers: compareIdentifiers$1,\n  rcompareIdentifiers\n};\n\nconst debug = debug_1;\nconst {\n  MAX_LENGTH,\n  MAX_SAFE_INTEGER\n} = constants;\nconst {\n  safeRe: re,\n  t\n} = reExports;\nconst parseOptions = parseOptions_1;\nconst {\n  compareIdentifiers\n} = identifiers;\nlet SemVer$1 = class SemVer {\n  constructor(version, options) {\n    options = parseOptions(options);\n    if (version instanceof SemVer) {\n      if (version.loose === !!options.loose && version.includePrerelease === !!options.includePrerelease) {\n        return version;\n      } else {\n        version = version.version;\n      }\n    } else if (typeof version !== 'string') {\n      throw new TypeError(`Invalid version. Must be a string. Got type \"${typeof version}\".`);\n    }\n    if (version.length > MAX_LENGTH) {\n      throw new TypeError(`version is longer than ${MAX_LENGTH} characters`);\n    }\n    debug('SemVer', version, options);\n    this.options = options;\n    this.loose = !!options.loose;\n    // this isn't actually relevant for versions, but keep it so that we\n    // don't run into trouble passing this.options around.\n    this.includePrerelease = !!options.includePrerelease;\n    const m = version.trim().match(options.loose ? re[t.LOOSE] : re[t.FULL]);\n    if (!m) {\n      throw new TypeError(`Invalid Version: ${version}`);\n    }\n    this.raw = version;\n\n    // these are actually numbers\n    this.major = +m[1];\n    this.minor = +m[2];\n    this.patch = +m[3];\n    if (this.major > MAX_SAFE_INTEGER || this.major < 0) {\n      throw new TypeError('Invalid major version');\n    }\n    if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {\n      throw new TypeError('Invalid minor version');\n    }\n    if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {\n      throw new TypeError('Invalid patch version');\n    }\n\n    // numberify any prerelease numeric ids\n    if (!m[4]) {\n      this.prerelease = [];\n    } else {\n      this.prerelease = m[4].split('.').map(id => {\n        if (/^[0-9]+$/.test(id)) {\n          const num = +id;\n          if (num >= 0 && num < MAX_SAFE_INTEGER) {\n            return num;\n          }\n        }\n        return id;\n      });\n    }\n    this.build = m[5] ? m[5].split('.') : [];\n    this.format();\n  }\n  format() {\n    this.version = `${this.major}.${this.minor}.${this.patch}`;\n    if (this.prerelease.length) {\n      this.version += `-${this.prerelease.join('.')}`;\n    }\n    return this.version;\n  }\n  toString() {\n    return this.version;\n  }\n  compare(other) {\n    debug('SemVer.compare', this.version, this.options, other);\n    if (!(other instanceof SemVer)) {\n      if (typeof other === 'string' && other === this.version) {\n        return 0;\n      }\n      other = new SemVer(other, this.options);\n    }\n    if (other.version === this.version) {\n      return 0;\n    }\n    return this.compareMain(other) || this.comparePre(other);\n  }\n  compareMain(other) {\n    if (!(other instanceof SemVer)) {\n      other = new SemVer(other, this.options);\n    }\n    return compareIdentifiers(this.major, other.major) || compareIdentifiers(this.minor, other.minor) || compareIdentifiers(this.patch, other.patch);\n  }\n  comparePre(other) {\n    if (!(other instanceof SemVer)) {\n      other = new SemVer(other, this.options);\n    }\n\n    // NOT having a prerelease is > having one\n    if (this.prerelease.length && !other.prerelease.length) {\n      return -1;\n    } else if (!this.prerelease.length && other.prerelease.length) {\n      return 1;\n    } else if (!this.prerelease.length && !other.prerelease.length) {\n      return 0;\n    }\n    let i = 0;\n    do {\n      const a = this.prerelease[i];\n      const b = other.prerelease[i];\n      debug('prerelease compare', i, a, b);\n      if (a === undefined && b === undefined) {\n        return 0;\n      } else if (b === undefined) {\n        return 1;\n      } else if (a === undefined) {\n        return -1;\n      } else if (a === b) {\n        continue;\n      } else {\n        return compareIdentifiers(a, b);\n      }\n    } while (++i);\n  }\n  compareBuild(other) {\n    if (!(other instanceof SemVer)) {\n      other = new SemVer(other, this.options);\n    }\n    let i = 0;\n    do {\n      const a = this.build[i];\n      const b = other.build[i];\n      debug('prerelease compare', i, a, b);\n      if (a === undefined && b === undefined) {\n        return 0;\n      } else if (b === undefined) {\n        return 1;\n      } else if (a === undefined) {\n        return -1;\n      } else if (a === b) {\n        continue;\n      } else {\n        return compareIdentifiers(a, b);\n      }\n    } while (++i);\n  }\n\n  // preminor will bump the version up to the next minor release, and immediately\n  // down to pre-release. premajor and prepatch work the same way.\n  inc(release, identifier, identifierBase) {\n    switch (release) {\n      case 'premajor':\n        this.prerelease.length = 0;\n        this.patch = 0;\n        this.minor = 0;\n        this.major++;\n        this.inc('pre', identifier, identifierBase);\n        break;\n      case 'preminor':\n        this.prerelease.length = 0;\n        this.patch = 0;\n        this.minor++;\n        this.inc('pre', identifier, identifierBase);\n        break;\n      case 'prepatch':\n        // If this is already a prerelease, it will bump to the next version\n        // drop any prereleases that might already exist, since they are not\n        // relevant at this point.\n        this.prerelease.length = 0;\n        this.inc('patch', identifier, identifierBase);\n        this.inc('pre', identifier, identifierBase);\n        break;\n      // If the input is a non-prerelease version, this acts the same as\n      // prepatch.\n      case 'prerelease':\n        if (this.prerelease.length === 0) {\n          this.inc('patch', identifier, identifierBase);\n        }\n        this.inc('pre', identifier, identifierBase);\n        break;\n      case 'major':\n        // If this is a pre-major version, bump up to the same major version.\n        // Otherwise increment major.\n        // 1.0.0-5 bumps to 1.0.0\n        // 1.1.0 bumps to 2.0.0\n        if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {\n          this.major++;\n        }\n        this.minor = 0;\n        this.patch = 0;\n        this.prerelease = [];\n        break;\n      case 'minor':\n        // If this is a pre-minor version, bump up to the same minor version.\n        // Otherwise increment minor.\n        // 1.2.0-5 bumps to 1.2.0\n        // 1.2.1 bumps to 1.3.0\n        if (this.patch !== 0 || this.prerelease.length === 0) {\n          this.minor++;\n        }\n        this.patch = 0;\n        this.prerelease = [];\n        break;\n      case 'patch':\n        // If this is not a pre-release version, it will increment the patch.\n        // If it is a pre-release it will bump up to the same patch version.\n        // 1.2.0-5 patches to 1.2.0\n        // 1.2.0 patches to 1.2.1\n        if (this.prerelease.length === 0) {\n          this.patch++;\n        }\n        this.prerelease = [];\n        break;\n      // This probably shouldn't be used publicly.\n      // 1.0.0 'pre' would become 1.0.0-0 which is the wrong direction.\n      case 'pre':\n        {\n          const base = Number(identifierBase) ? 1 : 0;\n          if (!identifier && identifierBase === false) {\n            throw new Error('invalid increment argument: identifier is empty');\n          }\n          if (this.prerelease.length === 0) {\n            this.prerelease = [base];\n          } else {\n            let i = this.prerelease.length;\n            while (--i >= 0) {\n              if (typeof this.prerelease[i] === 'number') {\n                this.prerelease[i]++;\n                i = -2;\n              }\n            }\n            if (i === -1) {\n              // didn't increment anything\n              if (identifier === this.prerelease.join('.') && identifierBase === false) {\n                throw new Error('invalid increment argument: identifier already exists');\n              }\n              this.prerelease.push(base);\n            }\n          }\n          if (identifier) {\n            // 1.2.0-beta.1 bumps to 1.2.0-beta.2,\n            // 1.2.0-beta.fooblz or 1.2.0-beta bumps to 1.2.0-beta.0\n            let prerelease = [identifier, base];\n            if (identifierBase === false) {\n              prerelease = [identifier];\n            }\n            if (compareIdentifiers(this.prerelease[0], identifier) === 0) {\n              if (isNaN(this.prerelease[1])) {\n                this.prerelease = prerelease;\n              }\n            } else {\n              this.prerelease = prerelease;\n            }\n          }\n          break;\n        }\n      default:\n        throw new Error(`invalid increment argument: ${release}`);\n    }\n    this.raw = this.format();\n    if (this.build.length) {\n      this.raw += `+${this.build.join('.')}`;\n    }\n    return this;\n  }\n};\nvar semver = SemVer$1;\n\nconst SemVer = semver;\nconst compare$6 = (a, b, loose) => new SemVer(a, loose).compare(new SemVer(b, loose));\nvar compare_1 = compare$6;\n\nconst compare$5 = compare_1;\nconst eq$1 = (a, b, loose) => compare$5(a, b, loose) === 0;\nvar eq_1 = eq$1;\n\nconst compare$4 = compare_1;\nconst neq$1 = (a, b, loose) => compare$4(a, b, loose) !== 0;\nvar neq_1 = neq$1;\n\nconst compare$3 = compare_1;\nconst gt$1 = (a, b, loose) => compare$3(a, b, loose) > 0;\nvar gt_1 = gt$1;\n\nconst compare$2 = compare_1;\nconst gte$1 = (a, b, loose) => compare$2(a, b, loose) >= 0;\nvar gte_1 = gte$1;\n\nconst compare$1 = compare_1;\nconst lt$1 = (a, b, loose) => compare$1(a, b, loose) < 0;\nvar lt_1 = lt$1;\n\nconst compare = compare_1;\nconst lte$1 = (a, b, loose) => compare(a, b, loose) <= 0;\nvar lte_1 = lte$1;\n\nconst eq = eq_1;\nconst neq = neq_1;\nconst gt = gt_1;\nconst gte = gte_1;\nconst lt = lt_1;\nconst lte = lte_1;\nconst cmp = (a, op, b, loose) => {\n  switch (op) {\n    case '===':\n      if (typeof a === 'object') {\n        a = a.version;\n      }\n      if (typeof b === 'object') {\n        b = b.version;\n      }\n      return a === b;\n    case '!==':\n      if (typeof a === 'object') {\n        a = a.version;\n      }\n      if (typeof b === 'object') {\n        b = b.version;\n      }\n      return a !== b;\n    case '':\n    case '=':\n    case '==':\n      return eq(a, b, loose);\n    case '!=':\n      return neq(a, b, loose);\n    case '>':\n      return gt(a, b, loose);\n    case '>=':\n      return gte(a, b, loose);\n    case '<':\n      return lt(a, b, loose);\n    case '<=':\n      return lte(a, b, loose);\n    default:\n      throw new TypeError(`Invalid operator: ${op}`);\n  }\n};\nvar cmp_1 = cmp;\n\nvar comparator;\nvar hasRequiredComparator;\nfunction requireComparator() {\n  if (hasRequiredComparator) return comparator;\n  hasRequiredComparator = 1;\n  const ANY = Symbol('SemVer ANY');\n  // hoisted class for cyclic dependency\n  class Comparator {\n    static get ANY() {\n      return ANY;\n    }\n    constructor(comp, options) {\n      options = parseOptions(options);\n      if (comp instanceof Comparator) {\n        if (comp.loose === !!options.loose) {\n          return comp;\n        } else {\n          comp = comp.value;\n        }\n      }\n      comp = comp.trim().split(/\\s+/).join(' ');\n      debug('comparator', comp, options);\n      this.options = options;\n      this.loose = !!options.loose;\n      this.parse(comp);\n      if (this.semver === ANY) {\n        this.value = '';\n      } else {\n        this.value = this.operator + this.semver.version;\n      }\n      debug('comp', this);\n    }\n    parse(comp) {\n      const r = this.options.loose ? re[t.COMPARATORLOOSE] : re[t.COMPARATOR];\n      const m = comp.match(r);\n      if (!m) {\n        throw new TypeError(`Invalid comparator: ${comp}`);\n      }\n      this.operator = m[1] !== undefined ? m[1] : '';\n      if (this.operator === '=') {\n        this.operator = '';\n      }\n\n      // if it literally is just '>' or '' then allow anything.\n      if (!m[2]) {\n        this.semver = ANY;\n      } else {\n        this.semver = new SemVer(m[2], this.options.loose);\n      }\n    }\n    toString() {\n      return this.value;\n    }\n    test(version) {\n      debug('Comparator.test', version, this.options.loose);\n      if (this.semver === ANY || version === ANY) {\n        return true;\n      }\n      if (typeof version === 'string') {\n        try {\n          version = new SemVer(version, this.options);\n        } catch (er) {\n          return false;\n        }\n      }\n      return cmp(version, this.operator, this.semver, this.options);\n    }\n    intersects(comp, options) {\n      if (!(comp instanceof Comparator)) {\n        throw new TypeError('a Comparator is required');\n      }\n      if (this.operator === '') {\n        if (this.value === '') {\n          return true;\n        }\n        return new Range(comp.value, options).test(this.value);\n      } else if (comp.operator === '') {\n        if (comp.value === '') {\n          return true;\n        }\n        return new Range(this.value, options).test(comp.semver);\n      }\n      options = parseOptions(options);\n\n      // Special cases where nothing can possibly be lower\n      if (options.includePrerelease && (this.value === '<0.0.0-0' || comp.value === '<0.0.0-0')) {\n        return false;\n      }\n      if (!options.includePrerelease && (this.value.startsWith('<0.0.0') || comp.value.startsWith('<0.0.0'))) {\n        return false;\n      }\n\n      // Same direction increasing (> or >=)\n      if (this.operator.startsWith('>') && comp.operator.startsWith('>')) {\n        return true;\n      }\n      // Same direction decreasing (< or <=)\n      if (this.operator.startsWith('<') && comp.operator.startsWith('<')) {\n        return true;\n      }\n      // same SemVer and both sides are inclusive (<= or >=)\n      if (this.semver.version === comp.semver.version && this.operator.includes('=') && comp.operator.includes('=')) {\n        return true;\n      }\n      // opposite directions less than\n      if (cmp(this.semver, '<', comp.semver, options) && this.operator.startsWith('>') && comp.operator.startsWith('<')) {\n        return true;\n      }\n      // opposite directions greater than\n      if (cmp(this.semver, '>', comp.semver, options) && this.operator.startsWith('<') && comp.operator.startsWith('>')) {\n        return true;\n      }\n      return false;\n    }\n  }\n  comparator = Comparator;\n  const parseOptions = parseOptions_1;\n  const {\n    safeRe: re,\n    t\n  } = reExports;\n  const cmp = cmp_1;\n  const debug = debug_1;\n  const SemVer = semver;\n  const Range = requireRange();\n  return comparator;\n}\n\nvar range;\nvar hasRequiredRange;\nfunction requireRange() {\n  if (hasRequiredRange) return range;\n  hasRequiredRange = 1;\n  // hoisted class for cyclic dependency\n  class Range {\n    constructor(range, options) {\n      options = parseOptions(options);\n      if (range instanceof Range) {\n        if (range.loose === !!options.loose && range.includePrerelease === !!options.includePrerelease) {\n          return range;\n        } else {\n          return new Range(range.raw, options);\n        }\n      }\n      if (range instanceof Comparator) {\n        // just put it in the set and return\n        this.raw = range.value;\n        this.set = [[range]];\n        this.format();\n        return this;\n      }\n      this.options = options;\n      this.loose = !!options.loose;\n      this.includePrerelease = !!options.includePrerelease;\n\n      // First reduce all whitespace as much as possible so we do not have to rely\n      // on potentially slow regexes like \\s*. This is then stored and used for\n      // future error messages as well.\n      this.raw = range.trim().split(/\\s+/).join(' ');\n\n      // First, split on ||\n      this.set = this.raw.split('||')\n      // map the range to a 2d array of comparators\n      .map(r => this.parseRange(r.trim()))\n      // throw out any comparator lists that are empty\n      // this generally means that it was not a valid range, which is allowed\n      // in loose mode, but will still throw if the WHOLE range is invalid.\n      .filter(c => c.length);\n      if (!this.set.length) {\n        throw new TypeError(`Invalid SemVer Range: ${this.raw}`);\n      }\n\n      // if we have any that are not the null set, throw out null sets.\n      if (this.set.length > 1) {\n        // keep the first one, in case they're all null sets\n        const first = this.set[0];\n        this.set = this.set.filter(c => !isNullSet(c[0]));\n        if (this.set.length === 0) {\n          this.set = [first];\n        } else if (this.set.length > 1) {\n          // if we have any that are *, then the range is just *\n          for (const c of this.set) {\n            if (c.length === 1 && isAny(c[0])) {\n              this.set = [c];\n              break;\n            }\n          }\n        }\n      }\n      this.format();\n    }\n    format() {\n      this.range = this.set.map(comps => comps.join(' ').trim()).join('||').trim();\n      return this.range;\n    }\n    toString() {\n      return this.range;\n    }\n    parseRange(range) {\n      // memoize range parsing for performance.\n      // this is a very hot path, and fully deterministic.\n      const memoOpts = (this.options.includePrerelease && FLAG_INCLUDE_PRERELEASE) | (this.options.loose && FLAG_LOOSE);\n      const memoKey = memoOpts + ':' + range;\n      const cached = cache.get(memoKey);\n      if (cached) {\n        return cached;\n      }\n      const loose = this.options.loose;\n      // `1.2.3 - 1.2.4` => `>=1.2.3 <=1.2.4`\n      const hr = loose ? re[t.HYPHENRANGELOOSE] : re[t.HYPHENRANGE];\n      range = range.replace(hr, hyphenReplace(this.options.includePrerelease));\n      debug('hyphen replace', range);\n\n      // `> 1.2.3 < 1.2.5` => `>1.2.3 <1.2.5`\n      range = range.replace(re[t.COMPARATORTRIM], comparatorTrimReplace);\n      debug('comparator trim', range);\n\n      // `~ 1.2.3` => `~1.2.3`\n      range = range.replace(re[t.TILDETRIM], tildeTrimReplace);\n      debug('tilde trim', range);\n\n      // `^ 1.2.3` => `^1.2.3`\n      range = range.replace(re[t.CARETTRIM], caretTrimReplace);\n      debug('caret trim', range);\n\n      // At this point, the range is completely trimmed and\n      // ready to be split into comparators.\n\n      let rangeList = range.split(' ').map(comp => parseComparator(comp, this.options)).join(' ').split(/\\s+/)\n      // >=0.0.0 is equivalent to *\n      .map(comp => replaceGTE0(comp, this.options));\n      if (loose) {\n        // in loose mode, throw out any that are not valid comparators\n        rangeList = rangeList.filter(comp => {\n          debug('loose invalid filter', comp, this.options);\n          return !!comp.match(re[t.COMPARATORLOOSE]);\n        });\n      }\n      debug('range list', rangeList);\n\n      // if any comparators are the null set, then replace with JUST null set\n      // if more than one comparator, remove any * comparators\n      // also, don't include the same comparator more than once\n      const rangeMap = new Map();\n      const comparators = rangeList.map(comp => new Comparator(comp, this.options));\n      for (const comp of comparators) {\n        if (isNullSet(comp)) {\n          return [comp];\n        }\n        rangeMap.set(comp.value, comp);\n      }\n      if (rangeMap.size > 1 && rangeMap.has('')) {\n        rangeMap.delete('');\n      }\n      const result = [...rangeMap.values()];\n      cache.set(memoKey, result);\n      return result;\n    }\n    intersects(range, options) {\n      if (!(range instanceof Range)) {\n        throw new TypeError('a Range is required');\n      }\n      return this.set.some(thisComparators => {\n        return isSatisfiable(thisComparators, options) && range.set.some(rangeComparators => {\n          return isSatisfiable(rangeComparators, options) && thisComparators.every(thisComparator => {\n            return rangeComparators.every(rangeComparator => {\n              return thisComparator.intersects(rangeComparator, options);\n            });\n          });\n        });\n      });\n    }\n\n    // if ANY of the sets match ALL of its comparators, then pass\n    test(version) {\n      if (!version) {\n        return false;\n      }\n      if (typeof version === 'string') {\n        try {\n          version = new SemVer(version, this.options);\n        } catch (er) {\n          return false;\n        }\n      }\n      for (let i = 0; i < this.set.length; i++) {\n        if (testSet(this.set[i], version, this.options)) {\n          return true;\n        }\n      }\n      return false;\n    }\n  }\n  range = Range;\n  const LRU = lruCache;\n  const cache = new LRU({\n    max: 1000\n  });\n  const parseOptions = parseOptions_1;\n  const Comparator = requireComparator();\n  const debug = debug_1;\n  const SemVer = semver;\n  const {\n    safeRe: re,\n    t,\n    comparatorTrimReplace,\n    tildeTrimReplace,\n    caretTrimReplace\n  } = reExports;\n  const {\n    FLAG_INCLUDE_PRERELEASE,\n    FLAG_LOOSE\n  } = constants;\n  const isNullSet = c => c.value === '<0.0.0-0';\n  const isAny = c => c.value === '';\n\n  // take a set of comparators and determine whether there\n  // exists a version which can satisfy it\n  const isSatisfiable = (comparators, options) => {\n    let result = true;\n    const remainingComparators = comparators.slice();\n    let testComparator = remainingComparators.pop();\n    while (result && remainingComparators.length) {\n      result = remainingComparators.every(otherComparator => {\n        return testComparator.intersects(otherComparator, options);\n      });\n      testComparator = remainingComparators.pop();\n    }\n    return result;\n  };\n\n  // comprised of xranges, tildes, stars, and gtlt's at this point.\n  // already replaced the hyphen ranges\n  // turn into a set of JUST comparators.\n  const parseComparator = (comp, options) => {\n    debug('comp', comp, options);\n    comp = replaceCarets(comp, options);\n    debug('caret', comp);\n    comp = replaceTildes(comp, options);\n    debug('tildes', comp);\n    comp = replaceXRanges(comp, options);\n    debug('xrange', comp);\n    comp = replaceStars(comp, options);\n    debug('stars', comp);\n    return comp;\n  };\n  const isX = id => !id || id.toLowerCase() === 'x' || id === '*';\n\n  // ~, ~> --> * (any, kinda silly)\n  // ~2, ~2.x, ~2.x.x, ~>2, ~>2.x ~>2.x.x --> >=2.0.0 <3.0.0-0\n  // ~2.0, ~2.0.x, ~>2.0, ~>2.0.x --> >=2.0.0 <2.1.0-0\n  // ~1.2, ~1.2.x, ~>1.2, ~>1.2.x --> >=1.2.0 <1.3.0-0\n  // ~1.2.3, ~>1.2.3 --> >=1.2.3 <1.3.0-0\n  // ~1.2.0, ~>1.2.0 --> >=1.2.0 <1.3.0-0\n  // ~0.0.1 --> >=0.0.1 <0.1.0-0\n  const replaceTildes = (comp, options) => {\n    return comp.trim().split(/\\s+/).map(c => replaceTilde(c, options)).join(' ');\n  };\n  const replaceTilde = (comp, options) => {\n    const r = options.loose ? re[t.TILDELOOSE] : re[t.TILDE];\n    return comp.replace(r, (_, M, m, p, pr) => {\n      debug('tilde', comp, _, M, m, p, pr);\n      let ret;\n      if (isX(M)) {\n        ret = '';\n      } else if (isX(m)) {\n        ret = `>=${M}.0.0 <${+M + 1}.0.0-0`;\n      } else if (isX(p)) {\n        // ~1.2 == >=1.2.0 <1.3.0-0\n        ret = `>=${M}.${m}.0 <${M}.${+m + 1}.0-0`;\n      } else if (pr) {\n        debug('replaceTilde pr', pr);\n        ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;\n      } else {\n        // ~1.2.3 == >=1.2.3 <1.3.0-0\n        ret = `>=${M}.${m}.${p} <${M}.${+m + 1}.0-0`;\n      }\n      debug('tilde return', ret);\n      return ret;\n    });\n  };\n\n  // ^ --> * (any, kinda silly)\n  // ^2, ^2.x, ^2.x.x --> >=2.0.0 <3.0.0-0\n  // ^2.0, ^2.0.x --> >=2.0.0 <3.0.0-0\n  // ^1.2, ^1.2.x --> >=1.2.0 <2.0.0-0\n  // ^1.2.3 --> >=1.2.3 <2.0.0-0\n  // ^1.2.0 --> >=1.2.0 <2.0.0-0\n  // ^0.0.1 --> >=0.0.1 <0.0.2-0\n  // ^0.1.0 --> >=0.1.0 <0.2.0-0\n  const replaceCarets = (comp, options) => {\n    return comp.trim().split(/\\s+/).map(c => replaceCaret(c, options)).join(' ');\n  };\n  const replaceCaret = (comp, options) => {\n    debug('caret', comp, options);\n    const r = options.loose ? re[t.CARETLOOSE] : re[t.CARET];\n    const z = options.includePrerelease ? '-0' : '';\n    return comp.replace(r, (_, M, m, p, pr) => {\n      debug('caret', comp, _, M, m, p, pr);\n      let ret;\n      if (isX(M)) {\n        ret = '';\n      } else if (isX(m)) {\n        ret = `>=${M}.0.0${z} <${+M + 1}.0.0-0`;\n      } else if (isX(p)) {\n        if (M === '0') {\n          ret = `>=${M}.${m}.0${z} <${M}.${+m + 1}.0-0`;\n        } else {\n          ret = `>=${M}.${m}.0${z} <${+M + 1}.0.0-0`;\n        }\n      } else if (pr) {\n        debug('replaceCaret pr', pr);\n        if (M === '0') {\n          if (m === '0') {\n            ret = `>=${M}.${m}.${p}-${pr} <${M}.${m}.${+p + 1}-0`;\n          } else {\n            ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;\n          }\n        } else {\n          ret = `>=${M}.${m}.${p}-${pr} <${+M + 1}.0.0-0`;\n        }\n      } else {\n        debug('no pr');\n        if (M === '0') {\n          if (m === '0') {\n            ret = `>=${M}.${m}.${p}${z} <${M}.${m}.${+p + 1}-0`;\n          } else {\n            ret = `>=${M}.${m}.${p}${z} <${M}.${+m + 1}.0-0`;\n          }\n        } else {\n          ret = `>=${M}.${m}.${p} <${+M + 1}.0.0-0`;\n        }\n      }\n      debug('caret return', ret);\n      return ret;\n    });\n  };\n  const replaceXRanges = (comp, options) => {\n    debug('replaceXRanges', comp, options);\n    return comp.split(/\\s+/).map(c => replaceXRange(c, options)).join(' ');\n  };\n  const replaceXRange = (comp, options) => {\n    comp = comp.trim();\n    const r = options.loose ? re[t.XRANGELOOSE] : re[t.XRANGE];\n    return comp.replace(r, (ret, gtlt, M, m, p, pr) => {\n      debug('xRange', comp, ret, gtlt, M, m, p, pr);\n      const xM = isX(M);\n      const xm = xM || isX(m);\n      const xp = xm || isX(p);\n      const anyX = xp;\n      if (gtlt === '=' && anyX) {\n        gtlt = '';\n      }\n\n      // if we're including prereleases in the match, then we need\n      // to fix this to -0, the lowest possible prerelease value\n      pr = options.includePrerelease ? '-0' : '';\n      if (xM) {\n        if (gtlt === '>' || gtlt === '<') {\n          // nothing is allowed\n          ret = '<0.0.0-0';\n        } else {\n          // nothing is forbidden\n          ret = '*';\n        }\n      } else if (gtlt && anyX) {\n        // we know patch is an x, because we have any x at all.\n        // replace X with 0\n        if (xm) {\n          m = 0;\n        }\n        p = 0;\n        if (gtlt === '>') {\n          // >1 => >=2.0.0\n          // >1.2 => >=1.3.0\n          gtlt = '>=';\n          if (xm) {\n            M = +M + 1;\n            m = 0;\n            p = 0;\n          } else {\n            m = +m + 1;\n            p = 0;\n          }\n        } else if (gtlt === '<=') {\n          // <=0.7.x is actually <0.8.0, since any 0.7.x should\n          // pass.  Similarly, <=7.x is actually <8.0.0, etc.\n          gtlt = '<';\n          if (xm) {\n            M = +M + 1;\n          } else {\n            m = +m + 1;\n          }\n        }\n        if (gtlt === '<') {\n          pr = '-0';\n        }\n        ret = `${gtlt + M}.${m}.${p}${pr}`;\n      } else if (xm) {\n        ret = `>=${M}.0.0${pr} <${+M + 1}.0.0-0`;\n      } else if (xp) {\n        ret = `>=${M}.${m}.0${pr} <${M}.${+m + 1}.0-0`;\n      }\n      debug('xRange return', ret);\n      return ret;\n    });\n  };\n\n  // Because * is AND-ed with everything else in the comparator,\n  // and '' means \"any version\", just remove the *s entirely.\n  const replaceStars = (comp, options) => {\n    debug('replaceStars', comp, options);\n    // Looseness is ignored here.  star is always as loose as it gets!\n    return comp.trim().replace(re[t.STAR], '');\n  };\n  const replaceGTE0 = (comp, options) => {\n    debug('replaceGTE0', comp, options);\n    return comp.trim().replace(re[options.includePrerelease ? t.GTE0PRE : t.GTE0], '');\n  };\n\n  // This function is passed to string.replace(re[t.HYPHENRANGE])\n  // M, m, patch, prerelease, build\n  // 1.2 - 3.4.5 => >=1.2.0 <=3.4.5\n  // 1.2.3 - 3.4 => >=1.2.0 <3.5.0-0 Any 3.4.x will do\n  // 1.2 - 3.4 => >=1.2.0 <3.5.0-0\n  const hyphenReplace = incPr => ($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr, tb) => {\n    if (isX(fM)) {\n      from = '';\n    } else if (isX(fm)) {\n      from = `>=${fM}.0.0${incPr ? '-0' : ''}`;\n    } else if (isX(fp)) {\n      from = `>=${fM}.${fm}.0${incPr ? '-0' : ''}`;\n    } else if (fpr) {\n      from = `>=${from}`;\n    } else {\n      from = `>=${from}${incPr ? '-0' : ''}`;\n    }\n    if (isX(tM)) {\n      to = '';\n    } else if (isX(tm)) {\n      to = `<${+tM + 1}.0.0-0`;\n    } else if (isX(tp)) {\n      to = `<${tM}.${+tm + 1}.0-0`;\n    } else if (tpr) {\n      to = `<=${tM}.${tm}.${tp}-${tpr}`;\n    } else if (incPr) {\n      to = `<${tM}.${tm}.${+tp + 1}-0`;\n    } else {\n      to = `<=${to}`;\n    }\n    return `${from} ${to}`.trim();\n  };\n  const testSet = (set, version, options) => {\n    for (let i = 0; i < set.length; i++) {\n      if (!set[i].test(version)) {\n        return false;\n      }\n    }\n    if (version.prerelease.length && !options.includePrerelease) {\n      // Find the set of versions that are allowed to have prereleases\n      // For example, ^1.2.3-pr.1 desugars to >=1.2.3-pr.1 <2.0.0\n      // That should allow `1.2.3-pr.2` to pass.\n      // However, `1.2.4-alpha.notready` should NOT be allowed,\n      // even though it's within the range set by the comparators.\n      for (let i = 0; i < set.length; i++) {\n        debug(set[i].semver);\n        if (set[i].semver === Comparator.ANY) {\n          continue;\n        }\n        if (set[i].semver.prerelease.length > 0) {\n          const allowed = set[i].semver;\n          if (allowed.major === version.major && allowed.minor === version.minor && allowed.patch === version.patch) {\n            return true;\n          }\n        }\n      }\n\n      // Version has a -pre, but it's not one of the ones we like.\n      return false;\n    }\n    return true;\n  };\n  return range;\n}\n\nconst Range = requireRange();\nconst satisfies = (version, range, options) => {\n  try {\n    range = new Range(range, options);\n  } catch (er) {\n    return false;\n  }\n  return range.test(version);\n};\nvar satisfies_1 = satisfies;\nvar satisfies$1 = /*@__PURE__*/getDefaultExportFromCjs(satisfies_1);\n\n/**\n * Open editor url in a new window, and pass a message.\n */\nfunction post (window, url, data) {\n  // eslint-disable-next-line @typescript-eslint/no-non-null-assertion\n  const editor = window.open(url);\n  const wait = 10_000;\n  const step = 250;\n  const {\n    origin\n  } = new URL(url);\n  // eslint-disable-next-line no-bitwise\n  let count = ~~(wait / step);\n  function listen(evt) {\n    if (evt.source === editor) {\n      count = 0;\n      window.removeEventListener('message', listen, false);\n    }\n  }\n  window.addEventListener('message', listen, false);\n\n  // send message\n  // periodically resend until ack received or timeout\n  function send() {\n    if (count <= 0) {\n      return;\n    }\n    editor.postMessage(data, origin);\n    setTimeout(send, step);\n    count -= 1;\n  }\n  setTimeout(send, step);\n}\n\n// generated with build-style.sh\nvar embedStyle = `.vega-embed {\n  position: relative;\n  display: inline-block;\n  box-sizing: border-box;\n}\n.vega-embed.has-actions {\n  padding-right: 38px;\n}\n.vega-embed details:not([open]) > :not(summary) {\n  display: none !important;\n}\n.vega-embed summary {\n  list-style: none;\n  position: absolute;\n  top: 0;\n  right: 0;\n  padding: 6px;\n  z-index: 1000;\n  background: white;\n  box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.1);\n  color: #1b1e23;\n  border: 1px solid #aaa;\n  border-radius: 999px;\n  opacity: 0.2;\n  transition: opacity 0.4s ease-in;\n  cursor: pointer;\n  line-height: 0px;\n}\n.vega-embed summary::-webkit-details-marker {\n  display: none;\n}\n.vega-embed summary:active {\n  box-shadow: #aaa 0px 0px 0px 1px inset;\n}\n.vega-embed summary svg {\n  width: 14px;\n  height: 14px;\n}\n.vega-embed details[open] summary {\n  opacity: 0.7;\n}\n.vega-embed:hover summary, .vega-embed:focus-within summary {\n  opacity: 1 !important;\n  transition: opacity 0.2s ease;\n}\n.vega-embed .vega-actions {\n  position: absolute;\n  z-index: 1001;\n  top: 35px;\n  right: -9px;\n  display: flex;\n  flex-direction: column;\n  padding-bottom: 8px;\n  padding-top: 8px;\n  border-radius: 4px;\n  box-shadow: 0 2px 8px 0 rgba(0, 0, 0, 0.2);\n  border: 1px solid #d9d9d9;\n  background: white;\n  animation-duration: 0.15s;\n  animation-name: scale-in;\n  animation-timing-function: cubic-bezier(0.2, 0, 0.13, 1.5);\n  text-align: left;\n}\n.vega-embed .vega-actions a {\n  padding: 8px 16px;\n  font-family: sans-serif;\n  font-size: 14px;\n  font-weight: 600;\n  white-space: nowrap;\n  color: #434a56;\n  text-decoration: none;\n}\n.vega-embed .vega-actions a:hover, .vega-embed .vega-actions a:focus {\n  background-color: #f7f7f9;\n  color: black;\n}\n.vega-embed .vega-actions::before, .vega-embed .vega-actions::after {\n  content: \"\";\n  display: inline-block;\n  position: absolute;\n}\n.vega-embed .vega-actions::before {\n  left: auto;\n  right: 14px;\n  top: -16px;\n  border: 8px solid rgba(0, 0, 0, 0);\n  border-bottom-color: #d9d9d9;\n}\n.vega-embed .vega-actions::after {\n  left: auto;\n  right: 15px;\n  top: -14px;\n  border: 7px solid rgba(0, 0, 0, 0);\n  border-bottom-color: #fff;\n}\n.vega-embed .chart-wrapper.fit-x {\n  width: 100%;\n}\n.vega-embed .chart-wrapper.fit-y {\n  height: 100%;\n}\n\n.vega-embed-wrapper {\n  max-width: 100%;\n  overflow: auto;\n  padding-right: 14px;\n}\n\n@keyframes scale-in {\n  from {\n    opacity: 0;\n    transform: scale(0.6);\n  }\n  to {\n    opacity: 1;\n    transform: scale(1);\n  }\n}\n`;\n\nfunction mergeDeep(dest, ...src) {\n  for (const s of src) {\n    deepMerge_(dest, s);\n  }\n  return dest;\n}\nfunction deepMerge_(dest, src) {\n  for (const property of Object.keys(src)) {\n    (0,vega__WEBPACK_IMPORTED_MODULE_2__.writeConfig)(dest, property, src[property], true);\n  }\n}\n\nvar name = \"vega-embed\";\nvar version$1 = \"6.22.2\";\nvar description = \"Publish Vega visualizations as embedded web components.\";\nvar keywords = [\"vega\", \"data\", \"visualization\", \"component\", \"embed\"];\nvar repository = {\n  type: \"git\",\n  url: \"http://github.com/vega/vega-embed.git\"\n};\nvar author = {\n  name: \"UW Interactive Data Lab\",\n  url: \"http://idl.cs.washington.edu\"\n};\nvar contributors = [{\n  name: \"Dominik Moritz\",\n  url: \"https://www.domoritz.de\"\n}];\nvar bugs = {\n  url: \"https://github.com/vega/vega-embed/issues\"\n};\nvar homepage = \"https://github.com/vega/vega-embed#readme\";\nvar license = \"BSD-3-Clause\";\nvar main = \"build/vega-embed.js\";\nvar module = \"build/vega-embed.module.js\";\nvar unpkg = \"build/vega-embed.min.js\";\nvar jsdelivr = \"build/vega-embed.min.js\";\nvar types = \"build/vega-embed.module.d.ts\";\nvar files = [\"src\", \"build\", \"patches\"];\nvar devDependencies = {\n  \"@babel/core\": \"^7.22.9\",\n  \"@babel/plugin-proposal-async-generator-functions\": \"^7.20.7\",\n  \"@babel/plugin-proposal-json-strings\": \"^7.18.6\",\n  \"@babel/plugin-proposal-object-rest-spread\": \"^7.20.7\",\n  \"@babel/plugin-proposal-optional-catch-binding\": \"^7.18.6\",\n  \"@babel/plugin-transform-runtime\": \"^7.22.9\",\n  \"@babel/preset-env\": \"^7.22.9\",\n  \"@babel/preset-typescript\": \"^7.22.5\",\n  \"@release-it/conventional-changelog\": \"^7.0.0\",\n  \"@rollup/plugin-commonjs\": \"25.0.3\",\n  \"@rollup/plugin-json\": \"^6.0.0\",\n  \"@rollup/plugin-node-resolve\": \"^15.1.0\",\n  \"@rollup/plugin-terser\": \"^0.4.3\",\n  \"@types/semver\": \"^7.5.0\",\n  \"@typescript-eslint/eslint-plugin\": \"^6.2.0\",\n  \"@typescript-eslint/parser\": \"^6.2.0\",\n  \"browser-sync\": \"^2.29.3\",\n  concurrently: \"^8.2.0\",\n  \"del-cli\": \"^5.0.0\",\n  eslint: \"^8.46.0\",\n  \"eslint-config-prettier\": \"^8.9.0\",\n  \"eslint-plugin-jest\": \"^27.2.3\",\n  \"eslint-plugin-prettier\": \"^5.0.0\",\n  jest: \"^29.6.2\",\n  \"jest-canvas-mock\": \"^2.5.2\",\n  \"jest-environment-jsdom\": \"^29.6.2\",\n  \"patch-package\": \"^8.0.0\",\n  \"postinstall-postinstall\": \"^2.1.0\",\n  prettier: \"^3.0.0\",\n  \"release-it\": \"^16.1.3\",\n  rollup: \"3.27.0\",\n  \"rollup-plugin-bundle-size\": \"^1.0.3\",\n  \"rollup-plugin-ts\": \"^3.2.0\",\n  sass: \"^1.64.1\",\n  typescript: \"^5.1.6\",\n  vega: \"^5.22.1\",\n  \"vega-lite\": \"^5.2.0\"\n};\nvar peerDependencies = {\n  vega: \"^5.21.0\",\n  \"vega-lite\": \"*\"\n};\nvar dependencies = {\n  \"fast-json-patch\": \"^3.1.1\",\n  \"json-stringify-pretty-compact\": \"^3.0.0\",\n  semver: \"^7.5.4\",\n  tslib: \"^2.6.1\",\n  \"vega-interpreter\": \"^1.0.5\",\n  \"vega-schema-url-parser\": \"^2.2.0\",\n  \"vega-themes\": \"^2.14.0\",\n  \"vega-tooltip\": \"^0.32.0\"\n};\nvar bundledDependencies = [\"yallist\"];\nvar scripts = {\n  prebuild: \"yarn clean && yarn build:style\",\n  build: \"rollup -c\",\n  \"build:style\": \"./build-style.sh\",\n  clean: \"del-cli build src/style.ts\",\n  prepublishOnly: \"yarn clean && yarn build\",\n  preversion: \"yarn lint && yarn test\",\n  serve: \"browser-sync start --directory -s -f build *.html\",\n  start: \"yarn build && concurrently --kill-others -n Server,Rollup 'yarn serve' 'rollup -c -w'\",\n  pretest: \"yarn build:style\",\n  test: \"jest\",\n  \"test:inspect\": \"node --inspect-brk ./node_modules/.bin/jest --runInBand\",\n  prettierbase: \"prettier '*.{css,scss,html}'\",\n  format: \"eslint . --fix && yarn prettierbase --write\",\n  lint: \"eslint . && yarn prettierbase --check\",\n  release: \"release-it\"\n};\nvar pkg = {\n  name: name,\n  version: version$1,\n  description: description,\n  keywords: keywords,\n  repository: repository,\n  author: author,\n  contributors: contributors,\n  bugs: bugs,\n  homepage: homepage,\n  license: license,\n  main: main,\n  module: module,\n  unpkg: unpkg,\n  jsdelivr: jsdelivr,\n  types: types,\n  files: files,\n  devDependencies: devDependencies,\n  peerDependencies: peerDependencies,\n  dependencies: dependencies,\n  bundledDependencies: bundledDependencies,\n  scripts: scripts\n};\n\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }\nconst version = pkg.version;\nconst vega = vega__WEBPACK_IMPORTED_MODULE_2__;\nlet vegaLite = vega_lite__WEBPACK_IMPORTED_MODULE_4__;\n\n// For backwards compatibility with Vega-Lite before v4.\nconst w = typeof window !== 'undefined' ? window : undefined;\nif (vegaLite === undefined && w?.vl?.compile) {\n  vegaLite = w.vl;\n}\nconst DEFAULT_ACTIONS = {\n  export: {\n    svg: true,\n    png: true\n  },\n  source: true,\n  compiled: true,\n  editor: true\n};\nconst I18N = {\n  CLICK_TO_VIEW_ACTIONS: 'Click to view actions',\n  COMPILED_ACTION: 'View Compiled Vega',\n  EDITOR_ACTION: 'Open in Vega Editor',\n  PNG_ACTION: 'Save as PNG',\n  SOURCE_ACTION: 'View Source',\n  SVG_ACTION: 'Save as SVG'\n};\nconst NAMES = {\n  vega: 'Vega',\n  'vega-lite': 'Vega-Lite'\n};\nconst VERSION = {\n  vega: vega.version,\n  'vega-lite': vegaLite ? vegaLite.version : 'not available'\n};\nconst PREPROCESSOR = {\n  vega: vgSpec => vgSpec,\n  'vega-lite': (vlSpec, config) => vegaLite.compile(vlSpec, {\n    config: config\n  }).spec\n};\nconst SVG_CIRCLES = `\n<svg viewBox=\"0 0 16 16\" fill=\"currentColor\" stroke=\"none\" stroke-width=\"1\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\n  <circle r=\"2\" cy=\"8\" cx=\"2\"></circle>\n  <circle r=\"2\" cy=\"8\" cx=\"8\"></circle>\n  <circle r=\"2\" cy=\"8\" cx=\"14\"></circle>\n</svg>`;\nconst CHART_WRAPPER_CLASS = 'chart-wrapper';\nfunction isTooltipHandler(h) {\n  return typeof h === 'function';\n}\nfunction viewSource(source, sourceHeader, sourceFooter, mode) {\n  const header = `<html><head>${sourceHeader}</head><body><pre><code class=\"json\">`;\n  const footer = `</code></pre>${sourceFooter}</body></html>`;\n  // eslint-disable-next-line @typescript-eslint/no-non-null-assertion\n  const win = window.open('');\n  win.document.write(header + source + footer);\n  win.document.title = `${NAMES[mode]} JSON Source`;\n}\n\n/**\n * Try to guess the type of spec.\n *\n * @param spec Vega or Vega-Lite spec.\n */\nfunction guessMode(spec, providedMode) {\n  // Decide mode\n  if (spec.$schema) {\n    const parsed = (0,vega_schema_url_parser__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(spec.$schema);\n    if (providedMode && providedMode !== parsed.library) {\n      console.warn(`The given visualization spec is written in ${NAMES[parsed.library]}, but mode argument sets ${NAMES[providedMode] ?? providedMode}.`);\n    }\n    const mode = parsed.library;\n    if (!satisfies$1(VERSION[mode], `^${parsed.version.slice(1)}`)) {\n      console.warn(`The input spec uses ${NAMES[mode]} ${parsed.version}, but the current version of ${NAMES[mode]} is v${VERSION[mode]}.`);\n    }\n    return mode;\n  }\n\n  // try to guess from the provided spec\n  if ('mark' in spec || 'encoding' in spec || 'layer' in spec || 'hconcat' in spec || 'vconcat' in spec || 'facet' in spec || 'repeat' in spec) {\n    return 'vega-lite';\n  }\n  if ('marks' in spec || 'signals' in spec || 'scales' in spec || 'axes' in spec) {\n    return 'vega';\n  }\n  return providedMode ?? 'vega';\n}\nfunction isLoader(o) {\n  return !!(o && 'load' in o);\n}\nfunction createLoader(opts) {\n  return isLoader(opts) ? opts : vega.loader(opts);\n}\nfunction embedOptionsFromUsermeta(parsedSpec) {\n  const opts = parsedSpec.usermeta?.embedOptions ?? {};\n  if ((0,vega__WEBPACK_IMPORTED_MODULE_2__.isString)(opts.defaultStyle)) {\n    // we don't allow styles set via usermeta since it would allow injection of logic (we set the style via innerHTML)\n    opts.defaultStyle = false;\n  }\n  return opts;\n}\n\n/**\n * Embed a Vega visualization component in a web page. This function returns a promise.\n *\n * @param el        DOM element in which to place component (DOM node or CSS selector).\n * @param spec      String : A URL string from which to load the Vega specification.\n *                  Object : The Vega/Vega-Lite specification as a parsed JSON object.\n * @param opts       A JavaScript object containing options for embedding.\n */\nasync function embed(el, spec, opts = {}) {\n  let parsedSpec;\n  let loader;\n  if ((0,vega__WEBPACK_IMPORTED_MODULE_2__.isString)(spec)) {\n    loader = createLoader(opts.loader);\n    parsedSpec = JSON.parse(await loader.load(spec));\n  } else {\n    parsedSpec = spec;\n  }\n  const loadedEmbedOptions = embedOptionsFromUsermeta(parsedSpec);\n  const usermetaLoader = loadedEmbedOptions.loader;\n\n  // either create the loader for the first time or create a new loader if the spec has new loader options\n  if (!loader || usermetaLoader) {\n    loader = createLoader(opts.loader ?? usermetaLoader);\n  }\n  const usermetaOpts = await loadOpts(loadedEmbedOptions, loader);\n  const parsedOpts = await loadOpts(opts, loader);\n  const mergedOpts = _objectSpread(_objectSpread({}, mergeDeep(parsedOpts, usermetaOpts)), {}, {\n    config: (0,vega__WEBPACK_IMPORTED_MODULE_2__.mergeConfig)(parsedOpts.config ?? {}, usermetaOpts.config ?? {})\n  });\n  return await _embed(el, parsedSpec, mergedOpts, loader);\n}\nasync function loadOpts(opt, loader) {\n  const config = (0,vega__WEBPACK_IMPORTED_MODULE_2__.isString)(opt.config) ? JSON.parse(await loader.load(opt.config)) : opt.config ?? {};\n  const patch = (0,vega__WEBPACK_IMPORTED_MODULE_2__.isString)(opt.patch) ? JSON.parse(await loader.load(opt.patch)) : opt.patch;\n  return _objectSpread(_objectSpread(_objectSpread({}, opt), patch ? {\n    patch\n  } : {}), config ? {\n    config\n  } : {});\n}\nfunction getRoot(el) {\n  const possibleRoot = el.getRootNode ? el.getRootNode() : document;\n  return possibleRoot instanceof ShadowRoot ? {\n    root: possibleRoot,\n    rootContainer: possibleRoot\n  } : {\n    root: document,\n    rootContainer: document.head ?? document.body\n  };\n}\nasync function _embed(el, spec, opts = {}, loader) {\n  const config = opts.theme ? (0,vega__WEBPACK_IMPORTED_MODULE_2__.mergeConfig)(vega_themes__WEBPACK_IMPORTED_MODULE_6__[opts.theme], opts.config ?? {}) : opts.config;\n  const actions = (0,vega__WEBPACK_IMPORTED_MODULE_2__.isBoolean)(opts.actions) ? opts.actions : mergeDeep({}, DEFAULT_ACTIONS, opts.actions ?? {});\n  const i18n = _objectSpread(_objectSpread({}, I18N), opts.i18n);\n  const renderer = opts.renderer ?? 'canvas';\n  const logLevel = opts.logLevel ?? vega.Warn;\n  const downloadFileName = opts.downloadFileName ?? 'visualization';\n  const element = typeof el === 'string' ? document.querySelector(el) : el;\n  if (!element) {\n    throw new Error(`${el} does not exist`);\n  }\n  if (opts.defaultStyle !== false) {\n    const ID = 'vega-embed-style';\n    const {\n      root,\n      rootContainer\n    } = getRoot(element);\n    if (!root.getElementById(ID)) {\n      const style = document.createElement('style');\n      style.id = ID;\n      style.innerHTML = opts.defaultStyle === undefined || opts.defaultStyle === true ? (embedStyle ).toString() : opts.defaultStyle;\n      rootContainer.appendChild(style);\n    }\n  }\n  const mode = guessMode(spec, opts.mode);\n  let vgSpec = PREPROCESSOR[mode](spec, config);\n  if (mode === 'vega-lite') {\n    if (vgSpec.$schema) {\n      const parsed = (0,vega_schema_url_parser__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(vgSpec.$schema);\n      if (!satisfies$1(VERSION.vega, `^${parsed.version.slice(1)}`)) {\n        console.warn(`The compiled spec uses Vega ${parsed.version}, but current version is v${VERSION.vega}.`);\n      }\n    }\n  }\n  element.classList.add('vega-embed');\n  if (actions) {\n    element.classList.add('has-actions');\n  }\n  element.innerHTML = ''; // clear container\n\n  let container = element;\n  if (actions) {\n    const chartWrapper = document.createElement('div');\n    chartWrapper.classList.add(CHART_WRAPPER_CLASS);\n    element.appendChild(chartWrapper);\n    container = chartWrapper;\n  }\n  const patch = opts.patch;\n  if (patch) {\n    vgSpec = patch instanceof Function ? patch(vgSpec) : (0,fast_json_patch__WEBPACK_IMPORTED_MODULE_0__.applyPatch)(vgSpec, patch, true, false).newDocument;\n  }\n\n  // Set locale. Note that this is a global setting.\n  if (opts.formatLocale) {\n    vega.formatLocale(opts.formatLocale);\n  }\n  if (opts.timeFormatLocale) {\n    vega.timeFormatLocale(opts.timeFormatLocale);\n  }\n\n  // Set custom expression functions\n  if (opts.expressionFunctions) {\n    for (const name in opts.expressionFunctions) {\n      const expressionFunction = opts.expressionFunctions[name];\n      if ('fn' in expressionFunction) {\n        vega.expressionFunction(name, expressionFunction.fn, expressionFunction['visitor']);\n      } else if (expressionFunction instanceof Function) {\n        vega.expressionFunction(name, expressionFunction);\n      }\n    }\n  }\n  const {\n    ast\n  } = opts;\n\n  // Do not apply the config to Vega when we have already applied it to Vega-Lite.\n  // This call may throw an Error if parsing fails.\n  const runtime = vega.parse(vgSpec, mode === 'vega-lite' ? {} : config, {\n    ast\n  });\n  const view = new (opts.viewClass || vega.View)(runtime, _objectSpread({\n    loader,\n    logLevel,\n    renderer\n  }, ast ? {\n    expr: vega.expressionInterpreter ?? opts.expr ?? vega_interpreter__WEBPACK_IMPORTED_MODULE_3__.expressionInterpreter\n  } : {}));\n  view.addSignalListener('autosize', (_, autosize) => {\n    const {\n      type\n    } = autosize;\n    if (type == 'fit-x') {\n      container.classList.add('fit-x');\n      container.classList.remove('fit-y');\n    } else if (type == 'fit-y') {\n      container.classList.remove('fit-x');\n      container.classList.add('fit-y');\n    } else if (type == 'fit') {\n      container.classList.add('fit-x', 'fit-y');\n    } else {\n      container.classList.remove('fit-x', 'fit-y');\n    }\n  });\n  if (opts.tooltip !== false) {\n    const handler = isTooltipHandler(opts.tooltip) ? opts.tooltip :\n    // user provided boolean true or tooltip options\n    new vega_tooltip__WEBPACK_IMPORTED_MODULE_7__.Handler(opts.tooltip === true ? {} : opts.tooltip).call;\n    view.tooltip(handler);\n  }\n  let {\n    hover\n  } = opts;\n  if (hover === undefined) {\n    hover = mode === 'vega';\n  }\n  if (hover) {\n    const {\n      hoverSet,\n      updateSet\n    } = typeof hover === 'boolean' ? {} : hover;\n    view.hover(hoverSet, updateSet);\n  }\n  if (opts) {\n    if (opts.width != null) {\n      view.width(opts.width);\n    }\n    if (opts.height != null) {\n      view.height(opts.height);\n    }\n    if (opts.padding != null) {\n      view.padding(opts.padding);\n    }\n  }\n  await view.initialize(container, opts.bind).runAsync();\n  let documentClickHandler;\n  if (actions !== false) {\n    let wrapper = element;\n    if (opts.defaultStyle !== false) {\n      const details = document.createElement('details');\n      details.title = i18n.CLICK_TO_VIEW_ACTIONS;\n      element.append(details);\n      wrapper = details;\n      const summary = document.createElement('summary');\n      summary.innerHTML = SVG_CIRCLES;\n      details.append(summary);\n      documentClickHandler = ev => {\n        if (!details.contains(ev.target)) {\n          details.removeAttribute('open');\n        }\n      };\n      document.addEventListener('click', documentClickHandler);\n    }\n    const ctrl = document.createElement('div');\n    wrapper.append(ctrl);\n    ctrl.classList.add('vega-actions');\n\n    // add 'Export' action\n    if (actions === true || actions.export !== false) {\n      for (const ext of ['svg', 'png']) {\n        if (actions === true || actions.export === true || actions.export[ext]) {\n          const i18nExportAction = i18n[`${ext.toUpperCase()}_ACTION`];\n          const exportLink = document.createElement('a');\n          const scaleFactor = (0,vega__WEBPACK_IMPORTED_MODULE_2__.isObject)(opts.scaleFactor) ? opts.scaleFactor[ext] : opts.scaleFactor;\n          exportLink.text = i18nExportAction;\n          exportLink.href = '#';\n          exportLink.target = '_blank';\n          exportLink.download = `${downloadFileName}.${ext}`;\n          // add link on mousedown so that it's correct when the click happens\n          exportLink.addEventListener('mousedown', async function (e) {\n            e.preventDefault();\n            const url = await view.toImageURL(ext, scaleFactor);\n            this.href = url;\n          });\n          ctrl.append(exportLink);\n        }\n      }\n    }\n\n    // add 'View Source' action\n    if (actions === true || actions.source !== false) {\n      const viewSourceLink = document.createElement('a');\n      viewSourceLink.text = i18n.SOURCE_ACTION;\n      viewSourceLink.href = '#';\n      viewSourceLink.addEventListener('click', function (e) {\n        viewSource(json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1___default()(spec), opts.sourceHeader ?? '', opts.sourceFooter ?? '', mode);\n        e.preventDefault();\n      });\n      ctrl.append(viewSourceLink);\n    }\n\n    // add 'View Compiled' action\n    if (mode === 'vega-lite' && (actions === true || actions.compiled !== false)) {\n      const compileLink = document.createElement('a');\n      compileLink.text = i18n.COMPILED_ACTION;\n      compileLink.href = '#';\n      compileLink.addEventListener('click', function (e) {\n        viewSource(json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1___default()(vgSpec), opts.sourceHeader ?? '', opts.sourceFooter ?? '', 'vega');\n        e.preventDefault();\n      });\n      ctrl.append(compileLink);\n    }\n\n    // add 'Open in Vega Editor' action\n    if (actions === true || actions.editor !== false) {\n      const editorUrl = opts.editorUrl ?? 'https://vega.github.io/editor/';\n      const editorLink = document.createElement('a');\n      editorLink.text = i18n.EDITOR_ACTION;\n      editorLink.href = '#';\n      editorLink.addEventListener('click', function (e) {\n        post(window, editorUrl, {\n          config: config,\n          mode,\n          renderer,\n          spec: json_stringify_pretty_compact__WEBPACK_IMPORTED_MODULE_1___default()(spec)\n        });\n        e.preventDefault();\n      });\n      ctrl.append(editorLink);\n    }\n  }\n  function finalize() {\n    if (documentClickHandler) {\n      document.removeEventListener('click', documentClickHandler);\n    }\n    view.finalize();\n  }\n  return {\n    view,\n    spec,\n    vgSpec,\n    finalize,\n    embedOptions: opts\n  };\n}\n\n\n//# sourceMappingURL=vega-embed.module.js.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-embed/build/vega-embed.module.js?");

/***/ }),

/***/ "../../node_modules/vega-encode/build/vega-encode.module.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-encode/build/vega-encode.module.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   axisticks: () => (/* binding */ AxisTicks),\n/* harmony export */   datajoin: () => (/* binding */ DataJoin),\n/* harmony export */   encode: () => (/* binding */ Encode),\n/* harmony export */   legendentries: () => (/* binding */ LegendEntries),\n/* harmony export */   linkpath: () => (/* binding */ LinkPath),\n/* harmony export */   pie: () => (/* binding */ Pie),\n/* harmony export */   scale: () => (/* binding */ Scale),\n/* harmony export */   sortitems: () => (/* binding */ SortItems),\n/* harmony export */   stack: () => (/* binding */ Stack)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/sum.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/round.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/value.js\");\n\n\n\n\n\n\n/**\n * Generates axis ticks for visualizing a spatial scale.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Scale} params.scale - The scale to generate ticks for.\n * @param {*} [params.count=10] - The approximate number of ticks, or\n *   desired tick interval, to use.\n * @param {Array<*>} [params.values] - The exact tick values to use.\n *   These must be legal domain values for the provided scale.\n *   If provided, the count argument is ignored.\n * @param {function(*):string} [params.formatSpecifier] - A format specifier\n *   to use in conjunction with scale.tickFormat. Legal values are\n *   any valid d3 4.0 format specifier.\n * @param {function(*):string} [params.format] - The format function to use.\n *   If provided, the formatSpecifier argument is ignored.\n */\nfunction AxisTicks(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(AxisTicks, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !_.modified()) {\n      return pulse.StopPropagation;\n    }\n    var locale = pulse.dataflow.locale(),\n      out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      ticks = this.value,\n      scale = _.scale,\n      tally = _.count == null ? _.values ? _.values.length : 10 : _.count,\n      count = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.tickCount)(scale, tally, _.minstep),\n      format = _.format || (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.tickFormat)(locale, scale, count, _.formatSpecifier, _.formatType, !!_.values),\n      values = _.values ? (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.validTicks)(scale, _.values, count) : (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.tickValues)(scale, count);\n    if (ticks) out.rem = ticks;\n    ticks = values.map((value, i) => (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n      index: i / (values.length - 1 || 1),\n      value: value,\n      label: format(value)\n    }));\n    if (_.extra && ticks.length) {\n      // add an extra tick pegged to the initial domain value\n      // this is used to generate axes with 'binned' domains\n      ticks.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n        index: -1,\n        extra: {\n          value: ticks[0].value\n        },\n        label: ''\n      }));\n    }\n    out.source = ticks;\n    out.add = ticks;\n    this.value = ticks;\n    return out;\n  }\n});\n\n/**\n * Joins a set of data elements against a set of visual items.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): object} [params.item] - An item generator function.\n * @param {function(object): *} [params.key] - The key field associating data and visual items.\n */\nfunction DataJoin(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nfunction defaultItemCreate() {\n  return (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({});\n}\nfunction newMap(key) {\n  const map = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.fastmap)().test(t => t.exit);\n  map.lookup = t => map.get(key(t));\n  return map;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(DataJoin, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var df = pulse.dataflow,\n      out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      item = _.item || defaultItemCreate,\n      key = _.key || vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid,\n      map = this.value;\n\n    // prevent transient (e.g., hover) requests from\n    // cascading across marks derived from marks\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isArray)(out.encode)) {\n      out.encode = null;\n    }\n    if (map && (_.modified('key') || pulse.modified(key))) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('DataJoin does not support modified key function or fields.');\n    }\n    if (!map) {\n      pulse = pulse.addAll();\n      this.value = map = newMap(key);\n    }\n    pulse.visit(pulse.ADD, t => {\n      const k = key(t);\n      let x = map.get(k);\n      if (x) {\n        if (x.exit) {\n          map.empty--;\n          out.add.push(x);\n        } else {\n          out.mod.push(x);\n        }\n      } else {\n        x = item(t);\n        map.set(k, x);\n        out.add.push(x);\n      }\n      x.datum = t;\n      x.exit = false;\n    });\n    pulse.visit(pulse.MOD, t => {\n      const k = key(t),\n        x = map.get(k);\n      if (x) {\n        x.datum = t;\n        out.mod.push(x);\n      }\n    });\n    pulse.visit(pulse.REM, t => {\n      const k = key(t),\n        x = map.get(k);\n      if (t === x.datum && !x.exit) {\n        out.rem.push(x);\n        x.exit = true;\n        ++map.empty;\n      }\n    });\n    if (pulse.changed(pulse.ADD_MOD)) out.modifies('datum');\n    if (pulse.clean() || _.clean && map.empty > df.cleanThreshold) {\n      df.runAfter(map.clean);\n    }\n    return out;\n  }\n});\n\n/**\n * Invokes encoding functions for visual items.\n * @constructor\n * @param {object} params - The parameters to the encoding functions. This\n *   parameter object will be passed through to all invoked encoding functions.\n * @param {object} [params.mod=false] - Flag indicating if tuples in the input\n *   mod set that are unmodified by encoders should be included in the output.\n * @param {object} param.encoders - The encoding functions\n * @param {function(object, object): boolean} [param.encoders.update] - Update encoding set\n * @param {function(object, object): boolean} [param.encoders.enter] - Enter encoding set\n * @param {function(object, object): boolean} [param.encoders.exit] - Exit encoding set\n */\nfunction Encode(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Encode, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var out = pulse.fork(pulse.ADD_REM),\n      fmod = _.mod || false,\n      encoders = _.encoders,\n      encode = pulse.encode;\n\n    // if an array, the encode directive includes additional sets\n    // that must be defined in order for the primary set to be invoked\n    // e.g., only run the update set if the hover set is defined\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isArray)(encode)) {\n      if (out.changed() || encode.every(e => encoders[e])) {\n        encode = encode[0];\n        out.encode = null; // consume targeted encode directive\n      } else {\n        return pulse.StopPropagation;\n      }\n    }\n\n    // marshall encoder functions\n    var reenter = encode === 'enter',\n      update = encoders.update || vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy,\n      enter = encoders.enter || vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy,\n      exit = encoders.exit || vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy,\n      set = (encode && !reenter ? encoders[encode] : update) || vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy;\n    if (pulse.changed(pulse.ADD)) {\n      pulse.visit(pulse.ADD, t => {\n        enter(t, _);\n        update(t, _);\n      });\n      out.modifies(enter.output);\n      out.modifies(update.output);\n      if (set !== vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy && set !== update) {\n        pulse.visit(pulse.ADD, t => {\n          set(t, _);\n        });\n        out.modifies(set.output);\n      }\n    }\n    if (pulse.changed(pulse.REM) && exit !== vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy) {\n      pulse.visit(pulse.REM, t => {\n        exit(t, _);\n      });\n      out.modifies(exit.output);\n    }\n    if (reenter || set !== vega_util__WEBPACK_IMPORTED_MODULE_2__.falsy) {\n      const flag = pulse.MOD | (_.modified() ? pulse.REFLOW : 0);\n      if (reenter) {\n        pulse.visit(flag, t => {\n          const mod = enter(t, _) || fmod;\n          if (set(t, _) || mod) out.mod.push(t);\n        });\n        if (out.mod.length) out.modifies(enter.output);\n      } else {\n        pulse.visit(flag, t => {\n          if (set(t, _) || fmod) out.mod.push(t);\n        });\n      }\n      if (out.mod.length) out.modifies(set.output);\n    }\n    return out.changed() ? out : pulse.StopPropagation;\n  }\n});\n\n/**\n * Generates legend entries for visualizing a scale.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Scale} params.scale - The scale to generate items for.\n * @param {*} [params.count=5] - The approximate number of items, or\n *   desired tick interval, to use.\n * @param {*} [params.limit] - The maximum number of entries to\n *   include in a symbol legend.\n * @param {Array<*>} [params.values] - The exact tick values to use.\n *   These must be legal domain values for the provided scale.\n *   If provided, the count argument is ignored.\n * @param {string} [params.formatSpecifier] - A format specifier\n *   to use in conjunction with scale.tickFormat. Legal values are\n *   any valid D3 format specifier string.\n * @param {function(*):string} [params.format] - The format function to use.\n *   If provided, the formatSpecifier argument is ignored.\n */\nfunction LegendEntries(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, [], params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(LegendEntries, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (this.value != null && !_.modified()) {\n      return pulse.StopPropagation;\n    }\n    var locale = pulse.dataflow.locale(),\n      out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      items = this.value,\n      type = _.type || vega_scale__WEBPACK_IMPORTED_MODULE_1__.SymbolLegend,\n      scale = _.scale,\n      limit = +_.limit,\n      count = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.tickCount)(scale, _.count == null ? 5 : _.count, _.minstep),\n      lskip = !!_.values || type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.SymbolLegend,\n      format = _.format || (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.labelFormat)(locale, scale, count, type, _.formatSpecifier, _.formatType, lskip),\n      values = _.values || (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.labelValues)(scale, count),\n      domain,\n      fraction,\n      size,\n      offset,\n      ellipsis;\n    if (items) out.rem = items;\n    if (type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.SymbolLegend) {\n      if (limit && values.length > limit) {\n        pulse.dataflow.warn('Symbol legend count exceeds limit, filtering items.');\n        items = values.slice(0, limit - 1);\n        ellipsis = true;\n      } else {\n        items = values;\n      }\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(size = _.size)) {\n        // if first value maps to size zero, remove from list (vega#717)\n        if (!_.values && scale(items[0]) === 0) {\n          items = items.slice(1);\n        }\n        // compute size offset for legend entries\n        offset = items.reduce((max, value) => Math.max(max, size(value, _)), 0);\n      } else {\n        size = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.constant)(offset = size || 8);\n      }\n      items = items.map((value, index) => (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n        index: index,\n        label: format(value, index, items),\n        value: value,\n        offset: offset,\n        size: size(value, _)\n      }));\n      if (ellipsis) {\n        ellipsis = values[items.length];\n        items.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n          index: items.length,\n          label: `\\u2026${values.length - items.length} entries`,\n          value: ellipsis,\n          offset: offset,\n          size: size(ellipsis, _)\n        }));\n      }\n    } else if (type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.GradientLegend) {\n      domain = scale.domain(), fraction = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.scaleFraction)(scale, domain[0], (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(domain));\n\n      // if automatic label generation produces 2 or fewer values,\n      // use the domain end points instead (fixes vega/vega#1364)\n      if (values.length < 3 && !_.values && domain[0] !== (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(domain)) {\n        values = [domain[0], (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(domain)];\n      }\n      items = values.map((value, index) => (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n        index: index,\n        label: format(value, index, values),\n        value: value,\n        perc: fraction(value)\n      }));\n    } else {\n      size = values.length - 1;\n      fraction = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.labelFraction)(scale);\n      items = values.map((value, index) => (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n        index: index,\n        label: format(value, index, values),\n        value: value,\n        perc: index ? fraction(value) : 0,\n        perc2: index === size ? 1 : fraction(values[index + 1])\n      }));\n    }\n    out.source = items;\n    out.add = items;\n    this.value = items;\n    return out;\n  }\n});\n\nconst sourceX = t => t.source.x;\nconst sourceY = t => t.source.y;\nconst targetX = t => t.target.x;\nconst targetY = t => t.target.y;\n\n/**\n * Layout paths linking source and target elements.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction LinkPath(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, {}, params);\n}\nLinkPath.Definition = {\n  'type': 'LinkPath',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'sourceX',\n    'type': 'field',\n    'default': 'source.x'\n  }, {\n    'name': 'sourceY',\n    'type': 'field',\n    'default': 'source.y'\n  }, {\n    'name': 'targetX',\n    'type': 'field',\n    'default': 'target.x'\n  }, {\n    'name': 'targetY',\n    'type': 'field',\n    'default': 'target.y'\n  }, {\n    'name': 'orient',\n    'type': 'enum',\n    'default': 'vertical',\n    'values': ['horizontal', 'vertical', 'radial']\n  }, {\n    'name': 'shape',\n    'type': 'enum',\n    'default': 'line',\n    'values': ['line', 'arc', 'curve', 'diagonal', 'orthogonal']\n  }, {\n    'name': 'require',\n    'type': 'signal'\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'path'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(LinkPath, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var sx = _.sourceX || sourceX,\n      sy = _.sourceY || sourceY,\n      tx = _.targetX || targetX,\n      ty = _.targetY || targetY,\n      as = _.as || 'path',\n      orient = _.orient || 'vertical',\n      shape = _.shape || 'line',\n      path = Paths.get(shape + '-' + orient) || Paths.get(shape);\n    if (!path) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('LinkPath unsupported type: ' + _.shape + (_.orient ? '-' + _.orient : ''));\n    }\n    pulse.visit(pulse.SOURCE, t => {\n      t[as] = path(sx(t), sy(t), tx(t), ty(t));\n    });\n    return pulse.reflow(_.modified()).modifies(as);\n  }\n});\nconst line = (sx, sy, tx, ty) => 'M' + sx + ',' + sy + 'L' + tx + ',' + ty;\nconst lineR = (sa, sr, ta, tr) => line(sr * Math.cos(sa), sr * Math.sin(sa), tr * Math.cos(ta), tr * Math.sin(ta));\nconst arc = (sx, sy, tx, ty) => {\n  var dx = tx - sx,\n    dy = ty - sy,\n    rr = Math.hypot(dx, dy) / 2,\n    ra = 180 * Math.atan2(dy, dx) / Math.PI;\n  return 'M' + sx + ',' + sy + 'A' + rr + ',' + rr + ' ' + ra + ' 0 1' + ' ' + tx + ',' + ty;\n};\nconst arcR = (sa, sr, ta, tr) => arc(sr * Math.cos(sa), sr * Math.sin(sa), tr * Math.cos(ta), tr * Math.sin(ta));\nconst curve = (sx, sy, tx, ty) => {\n  const dx = tx - sx,\n    dy = ty - sy,\n    ix = 0.2 * (dx + dy),\n    iy = 0.2 * (dy - dx);\n  return 'M' + sx + ',' + sy + 'C' + (sx + ix) + ',' + (sy + iy) + ' ' + (tx + iy) + ',' + (ty - ix) + ' ' + tx + ',' + ty;\n};\nconst curveR = (sa, sr, ta, tr) => curve(sr * Math.cos(sa), sr * Math.sin(sa), tr * Math.cos(ta), tr * Math.sin(ta));\nconst orthoX = (sx, sy, tx, ty) => 'M' + sx + ',' + sy + 'V' + ty + 'H' + tx;\nconst orthoY = (sx, sy, tx, ty) => 'M' + sx + ',' + sy + 'H' + tx + 'V' + ty;\nconst orthoR = (sa, sr, ta, tr) => {\n  const sc = Math.cos(sa),\n    ss = Math.sin(sa),\n    tc = Math.cos(ta),\n    ts = Math.sin(ta),\n    sf = Math.abs(ta - sa) > Math.PI ? ta <= sa : ta > sa;\n  return 'M' + sr * sc + ',' + sr * ss + 'A' + sr + ',' + sr + ' 0 0,' + (sf ? 1 : 0) + ' ' + sr * tc + ',' + sr * ts + 'L' + tr * tc + ',' + tr * ts;\n};\nconst diagonalX = (sx, sy, tx, ty) => {\n  const m = (sx + tx) / 2;\n  return 'M' + sx + ',' + sy + 'C' + m + ',' + sy + ' ' + m + ',' + ty + ' ' + tx + ',' + ty;\n};\nconst diagonalY = (sx, sy, tx, ty) => {\n  const m = (sy + ty) / 2;\n  return 'M' + sx + ',' + sy + 'C' + sx + ',' + m + ' ' + tx + ',' + m + ' ' + tx + ',' + ty;\n};\nconst diagonalR = (sa, sr, ta, tr) => {\n  const sc = Math.cos(sa),\n    ss = Math.sin(sa),\n    tc = Math.cos(ta),\n    ts = Math.sin(ta),\n    mr = (sr + tr) / 2;\n  return 'M' + sr * sc + ',' + sr * ss + 'C' + mr * sc + ',' + mr * ss + ' ' + mr * tc + ',' + mr * ts + ' ' + tr * tc + ',' + tr * ts;\n};\nconst Paths = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.fastmap)({\n  'line': line,\n  'line-radial': lineR,\n  'arc': arc,\n  'arc-radial': arcR,\n  'curve': curve,\n  'curve-radial': curveR,\n  'orthogonal-horizontal': orthoX,\n  'orthogonal-vertical': orthoY,\n  'orthogonal-radial': orthoR,\n  'diagonal-horizontal': diagonalX,\n  'diagonal-vertical': diagonalY,\n  'diagonal-radial': diagonalR\n});\n\n/**\n * Pie and donut chart layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to size pie segments.\n * @param {number} [params.startAngle=0] - The start angle (in radians) of the layout.\n * @param {number} [params.endAngle=2π] - The end angle (in radians) of the layout.\n * @param {boolean} [params.sort] - Boolean flag for sorting sectors by value.\n */\nfunction Pie(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nPie.Definition = {\n  'type': 'Pie',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'startAngle',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'endAngle',\n    'type': 'number',\n    'default': 6.283185307179586\n  }, {\n    'name': 'sort',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['startAngle', 'endAngle']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Pie, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var as = _.as || ['startAngle', 'endAngle'],\n      startAngle = as[0],\n      endAngle = as[1],\n      field = _.field || vega_util__WEBPACK_IMPORTED_MODULE_2__.one,\n      start = _.startAngle || 0,\n      stop = _.endAngle != null ? _.endAngle : 2 * Math.PI,\n      data = pulse.source,\n      values = data.map(field),\n      n = values.length,\n      a = start,\n      k = (stop - start) / (0,d3_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values),\n      index = (0,d3_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(n),\n      i,\n      t,\n      v;\n    if (_.sort) {\n      index.sort((a, b) => values[a] - values[b]);\n    }\n    for (i = 0; i < n; ++i) {\n      v = values[index[i]];\n      t = data[index[i]];\n      t[startAngle] = a;\n      t[endAngle] = a += v * k;\n    }\n    this.value = values;\n    return pulse.reflow(_.modified()).modifies(as);\n  }\n});\n\nconst DEFAULT_COUNT = 5;\nfunction includeZero(scale) {\n  const type = scale.type;\n  return !scale.bins && (type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Linear || type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Pow || type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sqrt);\n}\nfunction includePad(type) {\n  return (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.isContinuous)(type) && type !== vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sequential;\n}\nconst SKIP = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.toSet)(['set', 'modified', 'clear', 'type', 'scheme', 'schemeExtent', 'schemeCount', 'domain', 'domainMin', 'domainMid', 'domainMax', 'domainRaw', 'domainImplicit', 'nice', 'zero', 'bins', 'range', 'rangeStep', 'round', 'reverse', 'interpolate', 'interpolateGamma']);\n\n/**\n * Maintains a scale function mapping data values to visual channels.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction Scale(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n  this.modified(true); // always treat as modified\n}\n\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Scale, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var df = pulse.dataflow,\n      scale$1 = this.value,\n      key = scaleKey(_);\n    if (!scale$1 || key !== scale$1.type) {\n      this.value = scale$1 = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.scale)(key)();\n    }\n    for (key in _) if (!SKIP[key]) {\n      // padding is a scale property for band/point but not others\n      if (key === 'padding' && includePad(scale$1.type)) continue;\n      // invoke scale property setter, raise warning if not found\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(scale$1[key]) ? scale$1[key](_[key]) : df.warn('Unsupported scale property: ' + key);\n    }\n    configureRange(scale$1, _, configureBins(scale$1, _, configureDomain(scale$1, _, df)));\n    return pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n  }\n});\nfunction scaleKey(_) {\n  var t = _.type,\n    d = '',\n    n;\n\n  // backwards compatibility pre Vega 5.\n  if (t === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sequential) return vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sequential + '-' + vega_scale__WEBPACK_IMPORTED_MODULE_1__.Linear;\n  if (isContinuousColor(_)) {\n    n = _.rawDomain ? _.rawDomain.length : _.domain ? _.domain.length + +(_.domainMid != null) : 0;\n    d = n === 2 ? vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sequential + '-' : n === 3 ? vega_scale__WEBPACK_IMPORTED_MODULE_1__.Diverging + '-' : '';\n  }\n  return (d + t || vega_scale__WEBPACK_IMPORTED_MODULE_1__.Linear).toLowerCase();\n}\nfunction isContinuousColor(_) {\n  const t = _.type;\n  return (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.isContinuous)(t) && t !== vega_scale__WEBPACK_IMPORTED_MODULE_1__.Time && t !== vega_scale__WEBPACK_IMPORTED_MODULE_1__.UTC && (_.scheme || _.range && _.range.length && _.range.every(vega_util__WEBPACK_IMPORTED_MODULE_2__.isString));\n}\nfunction configureDomain(scale, _, df) {\n  // check raw domain, if provided use that and exit early\n  const raw = rawDomain(scale, _.domainRaw, df);\n  if (raw > -1) return raw;\n  var domain = _.domain,\n    type = scale.type,\n    zero = _.zero || _.zero === undefined && includeZero(scale),\n    n,\n    mid;\n  if (!domain) return 0;\n\n  // adjust continuous domain for minimum pixel padding\n  if (includePad(type) && _.padding && domain[0] !== (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(domain)) {\n    domain = padDomain(type, domain, _.range, _.padding, _.exponent, _.constant);\n  }\n\n  // adjust domain based on zero, min, max settings\n  if (zero || _.domainMin != null || _.domainMax != null || _.domainMid != null) {\n    n = (domain = domain.slice()).length - 1 || 1;\n    if (zero) {\n      if (domain[0] > 0) domain[0] = 0;\n      if (domain[n] < 0) domain[n] = 0;\n    }\n    if (_.domainMin != null) domain[0] = _.domainMin;\n    if (_.domainMax != null) domain[n] = _.domainMax;\n    if (_.domainMid != null) {\n      mid = _.domainMid;\n      const i = mid > domain[n] ? n + 1 : mid < domain[0] ? 0 : n;\n      if (i !== n) df.warn('Scale domainMid exceeds domain min or max.', mid);\n      domain.splice(i, 0, mid);\n    }\n  }\n\n  // set the scale domain\n  scale.domain(domainCheck(type, domain, df));\n\n  // if ordinal scale domain is defined, prevent implicit\n  // domain construction as side-effect of scale lookup\n  if (type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Ordinal) {\n    scale.unknown(_.domainImplicit ? vega_scale__WEBPACK_IMPORTED_MODULE_1__.scaleImplicit : undefined);\n  }\n\n  // perform 'nice' adjustment as requested\n  if (_.nice && scale.nice) {\n    scale.nice(_.nice !== true && (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.tickCount)(scale, _.nice) || null);\n  }\n\n  // return the cardinality of the domain\n  return domain.length;\n}\nfunction rawDomain(scale, raw, df) {\n  if (raw) {\n    scale.domain(domainCheck(scale.type, raw, df));\n    return raw.length;\n  } else {\n    return -1;\n  }\n}\nfunction padDomain(type, domain, range, pad, exponent, constant) {\n  var span = Math.abs((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(range) - range[0]),\n    frac = span / (span - 2 * pad),\n    d = type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Log ? (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.zoomLog)(domain, null, frac) : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Sqrt ? (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.zoomPow)(domain, null, frac, 0.5) : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Pow ? (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.zoomPow)(domain, null, frac, exponent || 1) : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Symlog ? (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.zoomSymlog)(domain, null, frac, constant || 1) : (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.zoomLinear)(domain, null, frac);\n  domain = domain.slice();\n  domain[0] = d[0];\n  domain[domain.length - 1] = d[1];\n  return domain;\n}\nfunction domainCheck(type, domain, df) {\n  if ((0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.isLogarithmic)(type)) {\n    // sum signs of domain values\n    // if all pos or all neg, abs(sum) === domain.length\n    var s = Math.abs(domain.reduce((s, v) => s + (v < 0 ? -1 : v > 0 ? 1 : 0), 0));\n    if (s !== domain.length) {\n      df.warn('Log scale domain includes zero: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.stringValue)(domain));\n    }\n  }\n  return domain;\n}\nfunction configureBins(scale, _, count) {\n  let bins = _.bins;\n  if (bins && !(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isArray)(bins)) {\n    // generate bin boundary array\n    const domain = scale.domain(),\n      lo = domain[0],\n      hi = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(domain),\n      step = bins.step;\n    let start = bins.start == null ? lo : bins.start,\n      stop = bins.stop == null ? hi : bins.stop;\n    if (!step) (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('Scale bins parameter missing step property.');\n    if (start < lo) start = step * Math.ceil(lo / step);\n    if (stop > hi) stop = step * Math.floor(hi / step);\n    bins = (0,d3_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(start, stop + step / 2, step);\n  }\n  if (bins) {\n    // assign bin boundaries to scale instance\n    scale.bins = bins;\n  } else if (scale.bins) {\n    // no current bins, remove bins if previously set\n    delete scale.bins;\n  }\n\n  // special handling for bin-ordinal scales\n  if (scale.type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.BinOrdinal) {\n    if (!bins) {\n      // the domain specifies the bins\n      scale.bins = scale.domain();\n    } else if (!_.domain && !_.domainRaw) {\n      // the bins specify the domain\n      scale.domain(bins);\n      count = bins.length;\n    }\n  }\n\n  // return domain cardinality\n  return count;\n}\nfunction configureRange(scale, _, count) {\n  var type = scale.type,\n    round = _.round || false,\n    range = _.range;\n\n  // if range step specified, calculate full range extent\n  if (_.rangeStep != null) {\n    range = configureRangeStep(type, _, count);\n  }\n\n  // else if a range scheme is defined, use that\n  else if (_.scheme) {\n    range = configureScheme(type, _, count);\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(range)) {\n      if (scale.interpolator) {\n        return scale.interpolator(range);\n      } else {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)(`Scale type ${type} does not support interpolating color schemes.`);\n      }\n    }\n  }\n\n  // given a range array for an interpolating scale, convert to interpolator\n  if (range && (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.isInterpolating)(type)) {\n    return scale.interpolator((0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.interpolateColors)(flip(range, _.reverse), _.interpolate, _.interpolateGamma));\n  }\n\n  // configure rounding / interpolation\n  if (range && _.interpolate && scale.interpolate) {\n    scale.interpolate((0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.interpolate)(_.interpolate, _.interpolateGamma));\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(scale.round)) {\n    scale.round(round);\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(scale.rangeRound)) {\n    scale.interpolate(round ? d3_interpolate__WEBPACK_IMPORTED_MODULE_5__[\"default\"] : d3_interpolate__WEBPACK_IMPORTED_MODULE_6__[\"default\"]);\n  }\n  if (range) scale.range(flip(range, _.reverse));\n}\nfunction configureRangeStep(type, _, count) {\n  if (type !== vega_scale__WEBPACK_IMPORTED_MODULE_1__.Band && type !== vega_scale__WEBPACK_IMPORTED_MODULE_1__.Point) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('Only band and point scales support rangeStep.');\n  }\n\n  // calculate full range based on requested step size and padding\n  var outer = (_.paddingOuter != null ? _.paddingOuter : _.padding) || 0,\n    inner = type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Point ? 1 : (_.paddingInner != null ? _.paddingInner : _.padding) || 0;\n  return [0, _.rangeStep * (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.bandSpace)(count, inner, outer)];\n}\nfunction configureScheme(type, _, count) {\n  var extent = _.schemeExtent,\n    name,\n    scheme$1;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isArray)(_.scheme)) {\n    scheme$1 = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.interpolateColors)(_.scheme, _.interpolate, _.interpolateGamma);\n  } else {\n    name = _.scheme.toLowerCase();\n    scheme$1 = (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.scheme)(name);\n    if (!scheme$1) (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)(`Unrecognized scheme name: ${_.scheme}`);\n  }\n\n  // determine size for potential discrete range\n  count = type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Threshold ? count + 1 : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.BinOrdinal ? count - 1 : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Quantile || type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Quantize ? +_.schemeCount || DEFAULT_COUNT : count;\n\n  // adjust and/or quantize scheme as appropriate\n  return (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.isInterpolating)(type) ? adjustScheme(scheme$1, extent, _.reverse) : (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(scheme$1) ? (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.quantizeInterpolator)(adjustScheme(scheme$1, extent), count) : type === vega_scale__WEBPACK_IMPORTED_MODULE_1__.Ordinal ? scheme$1 : scheme$1.slice(0, count);\n}\nfunction adjustScheme(scheme, extent, reverse) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(scheme) && (extent || reverse) ? (0,vega_scale__WEBPACK_IMPORTED_MODULE_1__.interpolateRange)(scheme, flip(extent || [0, 1], reverse)) : scheme;\n}\nfunction flip(array, reverse) {\n  return reverse ? array.slice().reverse() : array;\n}\n\n/**\n * Sorts scenegraph items in the pulse source array.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(*,*): number} [params.sort] - A comparator\n *   function for sorting tuples.\n */\nfunction SortItems(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(SortItems, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const mod = _.modified('sort') || pulse.changed(pulse.ADD) || pulse.modified(_.sort.fields) || pulse.modified('datum');\n    if (mod) pulse.source.sort((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.stableCompare)(_.sort));\n    this.modified(mod);\n    return pulse;\n  }\n});\n\nconst Zero = 'zero',\n  Center = 'center',\n  Normalize = 'normalize',\n  DefOutput = ['y0', 'y1'];\n\n/**\n * Stack layout for visualization elements.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to stack.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors to groupby.\n * @param {function(object,object): number} [params.sort] - A comparator for stack sorting.\n * @param {string} [offset='zero'] - Stack baseline offset. One of 'zero', 'center', 'normalize'.\n */\nfunction Stack(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nStack.Definition = {\n  'type': 'Stack',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'offset',\n    'type': 'enum',\n    'default': Zero,\n    'values': [Zero, Center, Normalize]\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': DefOutput\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Stack, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var as = _.as || DefOutput,\n      y0 = as[0],\n      y1 = as[1],\n      sort = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.stableCompare)(_.sort),\n      field = _.field || vega_util__WEBPACK_IMPORTED_MODULE_2__.one,\n      stack = _.offset === Center ? stackCenter : _.offset === Normalize ? stackNormalize : stackZero,\n      groups,\n      i,\n      n,\n      max;\n\n    // partition, sum, and sort the stack groups\n    groups = partition(pulse.source, _.groupby, sort, field);\n\n    // compute stack layouts per group\n    for (i = 0, n = groups.length, max = groups.max; i < n; ++i) {\n      stack(groups[i], max, field, y0, y1);\n    }\n    return pulse.reflow(_.modified()).modifies(as);\n  }\n});\nfunction stackCenter(group, max, field, y0, y1) {\n  var last = (max - group.sum) / 2,\n    m = group.length,\n    j = 0,\n    t;\n  for (; j < m; ++j) {\n    t = group[j];\n    t[y0] = last;\n    t[y1] = last += Math.abs(field(t));\n  }\n}\nfunction stackNormalize(group, max, field, y0, y1) {\n  var scale = 1 / group.sum,\n    last = 0,\n    m = group.length,\n    j = 0,\n    v = 0,\n    t;\n  for (; j < m; ++j) {\n    t = group[j];\n    t[y0] = last;\n    t[y1] = last = scale * (v += Math.abs(field(t)));\n  }\n}\nfunction stackZero(group, max, field, y0, y1) {\n  var lastPos = 0,\n    lastNeg = 0,\n    m = group.length,\n    j = 0,\n    v,\n    t;\n  for (; j < m; ++j) {\n    t = group[j];\n    v = +field(t);\n    if (v < 0) {\n      t[y0] = lastNeg;\n      t[y1] = lastNeg += v;\n    } else {\n      t[y0] = lastPos;\n      t[y1] = lastPos += v;\n    }\n  }\n}\nfunction partition(data, groupby, sort, field) {\n  var groups = [],\n    get = f => f(t),\n    map,\n    i,\n    n,\n    m,\n    t,\n    k,\n    g,\n    s,\n    max;\n\n  // partition data points into stack groups\n  if (groupby == null) {\n    groups.push(data.slice());\n  } else {\n    for (map = {}, i = 0, n = data.length; i < n; ++i) {\n      t = data[i];\n      k = groupby.map(get);\n      g = map[k];\n      if (!g) {\n        map[k] = g = [];\n        groups.push(g);\n      }\n      g.push(t);\n    }\n  }\n\n  // compute sums of groups, sort groups as needed\n  for (k = 0, max = 0, m = groups.length; k < m; ++k) {\n    g = groups[k];\n    for (i = 0, s = 0, n = g.length; i < n; ++i) {\n      s += Math.abs(field(g[i]));\n    }\n    g.sum = s;\n    if (s > max) max = s;\n    if (sort) g.sort(sort);\n  }\n  groups.max = max;\n  return groups;\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-encode/build/vega-encode.module.js?");

/***/ }),

/***/ "../../node_modules/vega-event-selector/build/vega-event-selector.module.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/vega-event-selector/build/vega-event-selector.module.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseSelector: () => (/* binding */ eventSelector)\n/* harmony export */ });\nconst VIEW = 'view',\n  LBRACK = '[',\n  RBRACK = ']',\n  LBRACE = '{',\n  RBRACE = '}',\n  COLON = ':',\n  COMMA = ',',\n  NAME = '@',\n  GT = '>',\n  ILLEGAL = /[[\\]{}]/,\n  DEFAULT_MARKS = {\n    '*': 1,\n    arc: 1,\n    area: 1,\n    group: 1,\n    image: 1,\n    line: 1,\n    path: 1,\n    rect: 1,\n    rule: 1,\n    shape: 1,\n    symbol: 1,\n    text: 1,\n    trail: 1\n  };\nlet DEFAULT_SOURCE, MARKS;\n\n/**\n * Parse an event selector string.\n * Returns an array of event stream definitions.\n */\nfunction eventSelector (selector, source, marks) {\n  DEFAULT_SOURCE = source || VIEW;\n  MARKS = marks || DEFAULT_MARKS;\n  return parseMerge(selector.trim()).map(parseSelector);\n}\nfunction isMarkType(type) {\n  return MARKS[type];\n}\nfunction find(s, i, endChar, pushChar, popChar) {\n  const n = s.length;\n  let count = 0,\n    c;\n  for (; i < n; ++i) {\n    c = s[i];\n    if (!count && c === endChar) return i;else if (popChar && popChar.indexOf(c) >= 0) --count;else if (pushChar && pushChar.indexOf(c) >= 0) ++count;\n  }\n  return i;\n}\nfunction parseMerge(s) {\n  const output = [],\n    n = s.length;\n  let start = 0,\n    i = 0;\n  while (i < n) {\n    i = find(s, i, COMMA, LBRACK + LBRACE, RBRACK + RBRACE);\n    output.push(s.substring(start, i).trim());\n    start = ++i;\n  }\n  if (output.length === 0) {\n    throw 'Empty event selector: ' + s;\n  }\n  return output;\n}\nfunction parseSelector(s) {\n  return s[0] === '[' ? parseBetween(s) : parseStream(s);\n}\nfunction parseBetween(s) {\n  const n = s.length;\n  let i = 1,\n    b;\n  i = find(s, i, RBRACK, LBRACK, RBRACK);\n  if (i === n) {\n    throw 'Empty between selector: ' + s;\n  }\n  b = parseMerge(s.substring(1, i));\n  if (b.length !== 2) {\n    throw 'Between selector must have two elements: ' + s;\n  }\n  s = s.slice(i + 1).trim();\n  if (s[0] !== GT) {\n    throw 'Expected \\'>\\' after between selector: ' + s;\n  }\n  b = b.map(parseSelector);\n  const stream = parseSelector(s.slice(1).trim());\n  if (stream.between) {\n    return {\n      between: b,\n      stream: stream\n    };\n  } else {\n    stream.between = b;\n  }\n  return stream;\n}\nfunction parseStream(s) {\n  const stream = {\n      source: DEFAULT_SOURCE\n    },\n    source = [];\n  let throttle = [0, 0],\n    markname = 0,\n    start = 0,\n    n = s.length,\n    i = 0,\n    j,\n    filter;\n\n  // extract throttle from end\n  if (s[n - 1] === RBRACE) {\n    i = s.lastIndexOf(LBRACE);\n    if (i >= 0) {\n      try {\n        throttle = parseThrottle(s.substring(i + 1, n - 1));\n      } catch (e) {\n        throw 'Invalid throttle specification: ' + s;\n      }\n      s = s.slice(0, i).trim();\n      n = s.length;\n    } else throw 'Unmatched right brace: ' + s;\n    i = 0;\n  }\n  if (!n) throw s;\n\n  // set name flag based on first char\n  if (s[0] === NAME) markname = ++i;\n\n  // extract first part of multi-part stream selector\n  j = find(s, i, COLON);\n  if (j < n) {\n    source.push(s.substring(start, j).trim());\n    start = i = ++j;\n  }\n\n  // extract remaining part of stream selector\n  i = find(s, i, LBRACK);\n  if (i === n) {\n    source.push(s.substring(start, n).trim());\n  } else {\n    source.push(s.substring(start, i).trim());\n    filter = [];\n    start = ++i;\n    if (start === n) throw 'Unmatched left bracket: ' + s;\n  }\n\n  // extract filters\n  while (i < n) {\n    i = find(s, i, RBRACK);\n    if (i === n) throw 'Unmatched left bracket: ' + s;\n    filter.push(s.substring(start, i).trim());\n    if (i < n - 1 && s[++i] !== LBRACK) throw 'Expected left bracket: ' + s;\n    start = ++i;\n  }\n\n  // marshall event stream specification\n  if (!(n = source.length) || ILLEGAL.test(source[n - 1])) {\n    throw 'Invalid event selector: ' + s;\n  }\n  if (n > 1) {\n    stream.type = source[1];\n    if (markname) {\n      stream.markname = source[0].slice(1);\n    } else if (isMarkType(source[0])) {\n      stream.marktype = source[0];\n    } else {\n      stream.source = source[0];\n    }\n  } else {\n    stream.type = source[0];\n  }\n  if (stream.type.slice(-1) === '!') {\n    stream.consume = true;\n    stream.type = stream.type.slice(0, -1);\n  }\n  if (filter != null) stream.filter = filter;\n  if (throttle[0]) stream.throttle = throttle[0];\n  if (throttle[1]) stream.debounce = throttle[1];\n  return stream;\n}\nfunction parseThrottle(s) {\n  const a = s.split(COMMA);\n  if (!s.length || a.length > 2) throw s;\n  return a.map(_ => {\n    const x = +_;\n    if (x !== x) throw s;\n    return x;\n  });\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-event-selector/build/vega-event-selector.module.js?");

/***/ }),

/***/ "../../node_modules/vega-expression/build/vega-expression.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-expression/build/vega-expression.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ASTNode: () => (/* binding */ ASTNode),\n/* harmony export */   ArrayExpression: () => (/* binding */ ArrayExpression),\n/* harmony export */   BinaryExpression: () => (/* binding */ BinaryExpression),\n/* harmony export */   CallExpression: () => (/* binding */ CallExpression),\n/* harmony export */   ConditionalExpression: () => (/* binding */ ConditionalExpression),\n/* harmony export */   Identifier: () => (/* binding */ Identifier),\n/* harmony export */   Literal: () => (/* binding */ Literal),\n/* harmony export */   LogicalExpression: () => (/* binding */ LogicalExpression),\n/* harmony export */   MemberExpression: () => (/* binding */ MemberExpression),\n/* harmony export */   ObjectExpression: () => (/* binding */ ObjectExpression),\n/* harmony export */   Property: () => (/* binding */ Property),\n/* harmony export */   RawCode: () => (/* binding */ RawCode),\n/* harmony export */   UnaryExpression: () => (/* binding */ UnaryExpression),\n/* harmony export */   codegenExpression: () => (/* binding */ codegen),\n/* harmony export */   constants: () => (/* binding */ Constants),\n/* harmony export */   functions: () => (/* binding */ Functions),\n/* harmony export */   parseExpression: () => (/* binding */ parser)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\nconst RawCode = 'RawCode';\nconst Literal = 'Literal';\nconst Property = 'Property';\nconst Identifier = 'Identifier';\nconst ArrayExpression = 'ArrayExpression';\nconst BinaryExpression = 'BinaryExpression';\nconst CallExpression = 'CallExpression';\nconst ConditionalExpression = 'ConditionalExpression';\nconst LogicalExpression = 'LogicalExpression';\nconst MemberExpression = 'MemberExpression';\nconst ObjectExpression = 'ObjectExpression';\nconst UnaryExpression = 'UnaryExpression';\nfunction ASTNode(type) {\n  this.type = type;\n}\nASTNode.prototype.visit = function (visitor) {\n  let c, i, n;\n  if (visitor(this)) return 1;\n  for (c = children(this), i = 0, n = c.length; i < n; ++i) {\n    if (c[i].visit(visitor)) return 1;\n  }\n};\nfunction children(node) {\n  switch (node.type) {\n    case ArrayExpression:\n      return node.elements;\n    case BinaryExpression:\n    case LogicalExpression:\n      return [node.left, node.right];\n    case CallExpression:\n      return [node.callee].concat(node.arguments);\n    case ConditionalExpression:\n      return [node.test, node.consequent, node.alternate];\n    case MemberExpression:\n      return [node.object, node.property];\n    case ObjectExpression:\n      return node.properties;\n    case Property:\n      return [node.key, node.value];\n    case UnaryExpression:\n      return [node.argument];\n    case Identifier:\n    case Literal:\n    case RawCode:\n    default:\n      return [];\n  }\n}\n\n/*\n  The following expression parser is based on Esprima (http://esprima.org/).\n  Original header comment and license for Esprima is included here:\n\n  Copyright (C) 2013 Ariya Hidayat <ariya.hidayat@gmail.com>\n  Copyright (C) 2013 Thaddee Tyl <thaddee.tyl@gmail.com>\n  Copyright (C) 2013 Mathias Bynens <mathias@qiwi.be>\n  Copyright (C) 2012 Ariya Hidayat <ariya.hidayat@gmail.com>\n  Copyright (C) 2012 Mathias Bynens <mathias@qiwi.be>\n  Copyright (C) 2012 Joost-Wim Boekesteijn <joost-wim@boekesteijn.nl>\n  Copyright (C) 2012 Kris Kowal <kris.kowal@cixar.com>\n  Copyright (C) 2012 Yusuke Suzuki <utatane.tea@gmail.com>\n  Copyright (C) 2012 Arpad Borsos <arpad.borsos@googlemail.com>\n  Copyright (C) 2011 Ariya Hidayat <ariya.hidayat@gmail.com>\n\n  Redistribution and use in source and binary forms, with or without\n  modification, are permitted provided that the following conditions are met:\n\n    * Redistributions of source code must retain the above copyright\n      notice, this list of conditions and the following disclaimer.\n    * Redistributions in binary form must reproduce the above copyright\n      notice, this list of conditions and the following disclaimer in the\n      documentation and/or other materials provided with the distribution.\n\n  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE\n  ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY\n  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES\n  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;\n  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND\n  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF\n  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n*/\nvar TokenName, source, index, length, lookahead;\nvar TokenBooleanLiteral = 1,\n  TokenEOF = 2,\n  TokenIdentifier = 3,\n  TokenKeyword = 4,\n  TokenNullLiteral = 5,\n  TokenNumericLiteral = 6,\n  TokenPunctuator = 7,\n  TokenStringLiteral = 8,\n  TokenRegularExpression = 9;\nTokenName = {};\nTokenName[TokenBooleanLiteral] = 'Boolean';\nTokenName[TokenEOF] = '<end>';\nTokenName[TokenIdentifier] = 'Identifier';\nTokenName[TokenKeyword] = 'Keyword';\nTokenName[TokenNullLiteral] = 'Null';\nTokenName[TokenNumericLiteral] = 'Numeric';\nTokenName[TokenPunctuator] = 'Punctuator';\nTokenName[TokenStringLiteral] = 'String';\nTokenName[TokenRegularExpression] = 'RegularExpression';\nvar SyntaxArrayExpression = 'ArrayExpression',\n  SyntaxBinaryExpression = 'BinaryExpression',\n  SyntaxCallExpression = 'CallExpression',\n  SyntaxConditionalExpression = 'ConditionalExpression',\n  SyntaxIdentifier = 'Identifier',\n  SyntaxLiteral = 'Literal',\n  SyntaxLogicalExpression = 'LogicalExpression',\n  SyntaxMemberExpression = 'MemberExpression',\n  SyntaxObjectExpression = 'ObjectExpression',\n  SyntaxProperty = 'Property',\n  SyntaxUnaryExpression = 'UnaryExpression';\n\n// Error messages should be identical to V8.\nvar MessageUnexpectedToken = 'Unexpected token %0',\n  MessageUnexpectedNumber = 'Unexpected number',\n  MessageUnexpectedString = 'Unexpected string',\n  MessageUnexpectedIdentifier = 'Unexpected identifier',\n  MessageUnexpectedReserved = 'Unexpected reserved word',\n  MessageUnexpectedEOS = 'Unexpected end of input',\n  MessageInvalidRegExp = 'Invalid regular expression',\n  MessageUnterminatedRegExp = 'Invalid regular expression: missing /',\n  MessageStrictOctalLiteral = 'Octal literals are not allowed in strict mode.',\n  MessageStrictDuplicateProperty = 'Duplicate data property in object literal not allowed in strict mode';\nvar ILLEGAL = 'ILLEGAL',\n  DISABLED = 'Disabled.';\n\n// See also tools/generate-unicode-regex.py.\nvar RegexNonAsciiIdentifierStart = new RegExp('[\\\\xAA\\\\xB5\\\\xBA\\\\xC0-\\\\xD6\\\\xD8-\\\\xF6\\\\xF8-\\\\u02C1\\\\u02C6-\\\\u02D1\\\\u02E0-\\\\u02E4\\\\u02EC\\\\u02EE\\\\u0370-\\\\u0374\\\\u0376\\\\u0377\\\\u037A-\\\\u037D\\\\u037F\\\\u0386\\\\u0388-\\\\u038A\\\\u038C\\\\u038E-\\\\u03A1\\\\u03A3-\\\\u03F5\\\\u03F7-\\\\u0481\\\\u048A-\\\\u052F\\\\u0531-\\\\u0556\\\\u0559\\\\u0561-\\\\u0587\\\\u05D0-\\\\u05EA\\\\u05F0-\\\\u05F2\\\\u0620-\\\\u064A\\\\u066E\\\\u066F\\\\u0671-\\\\u06D3\\\\u06D5\\\\u06E5\\\\u06E6\\\\u06EE\\\\u06EF\\\\u06FA-\\\\u06FC\\\\u06FF\\\\u0710\\\\u0712-\\\\u072F\\\\u074D-\\\\u07A5\\\\u07B1\\\\u07CA-\\\\u07EA\\\\u07F4\\\\u07F5\\\\u07FA\\\\u0800-\\\\u0815\\\\u081A\\\\u0824\\\\u0828\\\\u0840-\\\\u0858\\\\u08A0-\\\\u08B2\\\\u0904-\\\\u0939\\\\u093D\\\\u0950\\\\u0958-\\\\u0961\\\\u0971-\\\\u0980\\\\u0985-\\\\u098C\\\\u098F\\\\u0990\\\\u0993-\\\\u09A8\\\\u09AA-\\\\u09B0\\\\u09B2\\\\u09B6-\\\\u09B9\\\\u09BD\\\\u09CE\\\\u09DC\\\\u09DD\\\\u09DF-\\\\u09E1\\\\u09F0\\\\u09F1\\\\u0A05-\\\\u0A0A\\\\u0A0F\\\\u0A10\\\\u0A13-\\\\u0A28\\\\u0A2A-\\\\u0A30\\\\u0A32\\\\u0A33\\\\u0A35\\\\u0A36\\\\u0A38\\\\u0A39\\\\u0A59-\\\\u0A5C\\\\u0A5E\\\\u0A72-\\\\u0A74\\\\u0A85-\\\\u0A8D\\\\u0A8F-\\\\u0A91\\\\u0A93-\\\\u0AA8\\\\u0AAA-\\\\u0AB0\\\\u0AB2\\\\u0AB3\\\\u0AB5-\\\\u0AB9\\\\u0ABD\\\\u0AD0\\\\u0AE0\\\\u0AE1\\\\u0B05-\\\\u0B0C\\\\u0B0F\\\\u0B10\\\\u0B13-\\\\u0B28\\\\u0B2A-\\\\u0B30\\\\u0B32\\\\u0B33\\\\u0B35-\\\\u0B39\\\\u0B3D\\\\u0B5C\\\\u0B5D\\\\u0B5F-\\\\u0B61\\\\u0B71\\\\u0B83\\\\u0B85-\\\\u0B8A\\\\u0B8E-\\\\u0B90\\\\u0B92-\\\\u0B95\\\\u0B99\\\\u0B9A\\\\u0B9C\\\\u0B9E\\\\u0B9F\\\\u0BA3\\\\u0BA4\\\\u0BA8-\\\\u0BAA\\\\u0BAE-\\\\u0BB9\\\\u0BD0\\\\u0C05-\\\\u0C0C\\\\u0C0E-\\\\u0C10\\\\u0C12-\\\\u0C28\\\\u0C2A-\\\\u0C39\\\\u0C3D\\\\u0C58\\\\u0C59\\\\u0C60\\\\u0C61\\\\u0C85-\\\\u0C8C\\\\u0C8E-\\\\u0C90\\\\u0C92-\\\\u0CA8\\\\u0CAA-\\\\u0CB3\\\\u0CB5-\\\\u0CB9\\\\u0CBD\\\\u0CDE\\\\u0CE0\\\\u0CE1\\\\u0CF1\\\\u0CF2\\\\u0D05-\\\\u0D0C\\\\u0D0E-\\\\u0D10\\\\u0D12-\\\\u0D3A\\\\u0D3D\\\\u0D4E\\\\u0D60\\\\u0D61\\\\u0D7A-\\\\u0D7F\\\\u0D85-\\\\u0D96\\\\u0D9A-\\\\u0DB1\\\\u0DB3-\\\\u0DBB\\\\u0DBD\\\\u0DC0-\\\\u0DC6\\\\u0E01-\\\\u0E30\\\\u0E32\\\\u0E33\\\\u0E40-\\\\u0E46\\\\u0E81\\\\u0E82\\\\u0E84\\\\u0E87\\\\u0E88\\\\u0E8A\\\\u0E8D\\\\u0E94-\\\\u0E97\\\\u0E99-\\\\u0E9F\\\\u0EA1-\\\\u0EA3\\\\u0EA5\\\\u0EA7\\\\u0EAA\\\\u0EAB\\\\u0EAD-\\\\u0EB0\\\\u0EB2\\\\u0EB3\\\\u0EBD\\\\u0EC0-\\\\u0EC4\\\\u0EC6\\\\u0EDC-\\\\u0EDF\\\\u0F00\\\\u0F40-\\\\u0F47\\\\u0F49-\\\\u0F6C\\\\u0F88-\\\\u0F8C\\\\u1000-\\\\u102A\\\\u103F\\\\u1050-\\\\u1055\\\\u105A-\\\\u105D\\\\u1061\\\\u1065\\\\u1066\\\\u106E-\\\\u1070\\\\u1075-\\\\u1081\\\\u108E\\\\u10A0-\\\\u10C5\\\\u10C7\\\\u10CD\\\\u10D0-\\\\u10FA\\\\u10FC-\\\\u1248\\\\u124A-\\\\u124D\\\\u1250-\\\\u1256\\\\u1258\\\\u125A-\\\\u125D\\\\u1260-\\\\u1288\\\\u128A-\\\\u128D\\\\u1290-\\\\u12B0\\\\u12B2-\\\\u12B5\\\\u12B8-\\\\u12BE\\\\u12C0\\\\u12C2-\\\\u12C5\\\\u12C8-\\\\u12D6\\\\u12D8-\\\\u1310\\\\u1312-\\\\u1315\\\\u1318-\\\\u135A\\\\u1380-\\\\u138F\\\\u13A0-\\\\u13F4\\\\u1401-\\\\u166C\\\\u166F-\\\\u167F\\\\u1681-\\\\u169A\\\\u16A0-\\\\u16EA\\\\u16EE-\\\\u16F8\\\\u1700-\\\\u170C\\\\u170E-\\\\u1711\\\\u1720-\\\\u1731\\\\u1740-\\\\u1751\\\\u1760-\\\\u176C\\\\u176E-\\\\u1770\\\\u1780-\\\\u17B3\\\\u17D7\\\\u17DC\\\\u1820-\\\\u1877\\\\u1880-\\\\u18A8\\\\u18AA\\\\u18B0-\\\\u18F5\\\\u1900-\\\\u191E\\\\u1950-\\\\u196D\\\\u1970-\\\\u1974\\\\u1980-\\\\u19AB\\\\u19C1-\\\\u19C7\\\\u1A00-\\\\u1A16\\\\u1A20-\\\\u1A54\\\\u1AA7\\\\u1B05-\\\\u1B33\\\\u1B45-\\\\u1B4B\\\\u1B83-\\\\u1BA0\\\\u1BAE\\\\u1BAF\\\\u1BBA-\\\\u1BE5\\\\u1C00-\\\\u1C23\\\\u1C4D-\\\\u1C4F\\\\u1C5A-\\\\u1C7D\\\\u1CE9-\\\\u1CEC\\\\u1CEE-\\\\u1CF1\\\\u1CF5\\\\u1CF6\\\\u1D00-\\\\u1DBF\\\\u1E00-\\\\u1F15\\\\u1F18-\\\\u1F1D\\\\u1F20-\\\\u1F45\\\\u1F48-\\\\u1F4D\\\\u1F50-\\\\u1F57\\\\u1F59\\\\u1F5B\\\\u1F5D\\\\u1F5F-\\\\u1F7D\\\\u1F80-\\\\u1FB4\\\\u1FB6-\\\\u1FBC\\\\u1FBE\\\\u1FC2-\\\\u1FC4\\\\u1FC6-\\\\u1FCC\\\\u1FD0-\\\\u1FD3\\\\u1FD6-\\\\u1FDB\\\\u1FE0-\\\\u1FEC\\\\u1FF2-\\\\u1FF4\\\\u1FF6-\\\\u1FFC\\\\u2071\\\\u207F\\\\u2090-\\\\u209C\\\\u2102\\\\u2107\\\\u210A-\\\\u2113\\\\u2115\\\\u2119-\\\\u211D\\\\u2124\\\\u2126\\\\u2128\\\\u212A-\\\\u212D\\\\u212F-\\\\u2139\\\\u213C-\\\\u213F\\\\u2145-\\\\u2149\\\\u214E\\\\u2160-\\\\u2188\\\\u2C00-\\\\u2C2E\\\\u2C30-\\\\u2C5E\\\\u2C60-\\\\u2CE4\\\\u2CEB-\\\\u2CEE\\\\u2CF2\\\\u2CF3\\\\u2D00-\\\\u2D25\\\\u2D27\\\\u2D2D\\\\u2D30-\\\\u2D67\\\\u2D6F\\\\u2D80-\\\\u2D96\\\\u2DA0-\\\\u2DA6\\\\u2DA8-\\\\u2DAE\\\\u2DB0-\\\\u2DB6\\\\u2DB8-\\\\u2DBE\\\\u2DC0-\\\\u2DC6\\\\u2DC8-\\\\u2DCE\\\\u2DD0-\\\\u2DD6\\\\u2DD8-\\\\u2DDE\\\\u2E2F\\\\u3005-\\\\u3007\\\\u3021-\\\\u3029\\\\u3031-\\\\u3035\\\\u3038-\\\\u303C\\\\u3041-\\\\u3096\\\\u309D-\\\\u309F\\\\u30A1-\\\\u30FA\\\\u30FC-\\\\u30FF\\\\u3105-\\\\u312D\\\\u3131-\\\\u318E\\\\u31A0-\\\\u31BA\\\\u31F0-\\\\u31FF\\\\u3400-\\\\u4DB5\\\\u4E00-\\\\u9FCC\\\\uA000-\\\\uA48C\\\\uA4D0-\\\\uA4FD\\\\uA500-\\\\uA60C\\\\uA610-\\\\uA61F\\\\uA62A\\\\uA62B\\\\uA640-\\\\uA66E\\\\uA67F-\\\\uA69D\\\\uA6A0-\\\\uA6EF\\\\uA717-\\\\uA71F\\\\uA722-\\\\uA788\\\\uA78B-\\\\uA78E\\\\uA790-\\\\uA7AD\\\\uA7B0\\\\uA7B1\\\\uA7F7-\\\\uA801\\\\uA803-\\\\uA805\\\\uA807-\\\\uA80A\\\\uA80C-\\\\uA822\\\\uA840-\\\\uA873\\\\uA882-\\\\uA8B3\\\\uA8F2-\\\\uA8F7\\\\uA8FB\\\\uA90A-\\\\uA925\\\\uA930-\\\\uA946\\\\uA960-\\\\uA97C\\\\uA984-\\\\uA9B2\\\\uA9CF\\\\uA9E0-\\\\uA9E4\\\\uA9E6-\\\\uA9EF\\\\uA9FA-\\\\uA9FE\\\\uAA00-\\\\uAA28\\\\uAA40-\\\\uAA42\\\\uAA44-\\\\uAA4B\\\\uAA60-\\\\uAA76\\\\uAA7A\\\\uAA7E-\\\\uAAAF\\\\uAAB1\\\\uAAB5\\\\uAAB6\\\\uAAB9-\\\\uAABD\\\\uAAC0\\\\uAAC2\\\\uAADB-\\\\uAADD\\\\uAAE0-\\\\uAAEA\\\\uAAF2-\\\\uAAF4\\\\uAB01-\\\\uAB06\\\\uAB09-\\\\uAB0E\\\\uAB11-\\\\uAB16\\\\uAB20-\\\\uAB26\\\\uAB28-\\\\uAB2E\\\\uAB30-\\\\uAB5A\\\\uAB5C-\\\\uAB5F\\\\uAB64\\\\uAB65\\\\uABC0-\\\\uABE2\\\\uAC00-\\\\uD7A3\\\\uD7B0-\\\\uD7C6\\\\uD7CB-\\\\uD7FB\\\\uF900-\\\\uFA6D\\\\uFA70-\\\\uFAD9\\\\uFB00-\\\\uFB06\\\\uFB13-\\\\uFB17\\\\uFB1D\\\\uFB1F-\\\\uFB28\\\\uFB2A-\\\\uFB36\\\\uFB38-\\\\uFB3C\\\\uFB3E\\\\uFB40\\\\uFB41\\\\uFB43\\\\uFB44\\\\uFB46-\\\\uFBB1\\\\uFBD3-\\\\uFD3D\\\\uFD50-\\\\uFD8F\\\\uFD92-\\\\uFDC7\\\\uFDF0-\\\\uFDFB\\\\uFE70-\\\\uFE74\\\\uFE76-\\\\uFEFC\\\\uFF21-\\\\uFF3A\\\\uFF41-\\\\uFF5A\\\\uFF66-\\\\uFFBE\\\\uFFC2-\\\\uFFC7\\\\uFFCA-\\\\uFFCF\\\\uFFD2-\\\\uFFD7\\\\uFFDA-\\\\uFFDC]'),\n  // eslint-disable-next-line no-misleading-character-class\n  RegexNonAsciiIdentifierPart = new RegExp('[\\\\xAA\\\\xB5\\\\xBA\\\\xC0-\\\\xD6\\\\xD8-\\\\xF6\\\\xF8-\\\\u02C1\\\\u02C6-\\\\u02D1\\\\u02E0-\\\\u02E4\\\\u02EC\\\\u02EE\\\\u0300-\\\\u0374\\\\u0376\\\\u0377\\\\u037A-\\\\u037D\\\\u037F\\\\u0386\\\\u0388-\\\\u038A\\\\u038C\\\\u038E-\\\\u03A1\\\\u03A3-\\\\u03F5\\\\u03F7-\\\\u0481\\\\u0483-\\\\u0487\\\\u048A-\\\\u052F\\\\u0531-\\\\u0556\\\\u0559\\\\u0561-\\\\u0587\\\\u0591-\\\\u05BD\\\\u05BF\\\\u05C1\\\\u05C2\\\\u05C4\\\\u05C5\\\\u05C7\\\\u05D0-\\\\u05EA\\\\u05F0-\\\\u05F2\\\\u0610-\\\\u061A\\\\u0620-\\\\u0669\\\\u066E-\\\\u06D3\\\\u06D5-\\\\u06DC\\\\u06DF-\\\\u06E8\\\\u06EA-\\\\u06FC\\\\u06FF\\\\u0710-\\\\u074A\\\\u074D-\\\\u07B1\\\\u07C0-\\\\u07F5\\\\u07FA\\\\u0800-\\\\u082D\\\\u0840-\\\\u085B\\\\u08A0-\\\\u08B2\\\\u08E4-\\\\u0963\\\\u0966-\\\\u096F\\\\u0971-\\\\u0983\\\\u0985-\\\\u098C\\\\u098F\\\\u0990\\\\u0993-\\\\u09A8\\\\u09AA-\\\\u09B0\\\\u09B2\\\\u09B6-\\\\u09B9\\\\u09BC-\\\\u09C4\\\\u09C7\\\\u09C8\\\\u09CB-\\\\u09CE\\\\u09D7\\\\u09DC\\\\u09DD\\\\u09DF-\\\\u09E3\\\\u09E6-\\\\u09F1\\\\u0A01-\\\\u0A03\\\\u0A05-\\\\u0A0A\\\\u0A0F\\\\u0A10\\\\u0A13-\\\\u0A28\\\\u0A2A-\\\\u0A30\\\\u0A32\\\\u0A33\\\\u0A35\\\\u0A36\\\\u0A38\\\\u0A39\\\\u0A3C\\\\u0A3E-\\\\u0A42\\\\u0A47\\\\u0A48\\\\u0A4B-\\\\u0A4D\\\\u0A51\\\\u0A59-\\\\u0A5C\\\\u0A5E\\\\u0A66-\\\\u0A75\\\\u0A81-\\\\u0A83\\\\u0A85-\\\\u0A8D\\\\u0A8F-\\\\u0A91\\\\u0A93-\\\\u0AA8\\\\u0AAA-\\\\u0AB0\\\\u0AB2\\\\u0AB3\\\\u0AB5-\\\\u0AB9\\\\u0ABC-\\\\u0AC5\\\\u0AC7-\\\\u0AC9\\\\u0ACB-\\\\u0ACD\\\\u0AD0\\\\u0AE0-\\\\u0AE3\\\\u0AE6-\\\\u0AEF\\\\u0B01-\\\\u0B03\\\\u0B05-\\\\u0B0C\\\\u0B0F\\\\u0B10\\\\u0B13-\\\\u0B28\\\\u0B2A-\\\\u0B30\\\\u0B32\\\\u0B33\\\\u0B35-\\\\u0B39\\\\u0B3C-\\\\u0B44\\\\u0B47\\\\u0B48\\\\u0B4B-\\\\u0B4D\\\\u0B56\\\\u0B57\\\\u0B5C\\\\u0B5D\\\\u0B5F-\\\\u0B63\\\\u0B66-\\\\u0B6F\\\\u0B71\\\\u0B82\\\\u0B83\\\\u0B85-\\\\u0B8A\\\\u0B8E-\\\\u0B90\\\\u0B92-\\\\u0B95\\\\u0B99\\\\u0B9A\\\\u0B9C\\\\u0B9E\\\\u0B9F\\\\u0BA3\\\\u0BA4\\\\u0BA8-\\\\u0BAA\\\\u0BAE-\\\\u0BB9\\\\u0BBE-\\\\u0BC2\\\\u0BC6-\\\\u0BC8\\\\u0BCA-\\\\u0BCD\\\\u0BD0\\\\u0BD7\\\\u0BE6-\\\\u0BEF\\\\u0C00-\\\\u0C03\\\\u0C05-\\\\u0C0C\\\\u0C0E-\\\\u0C10\\\\u0C12-\\\\u0C28\\\\u0C2A-\\\\u0C39\\\\u0C3D-\\\\u0C44\\\\u0C46-\\\\u0C48\\\\u0C4A-\\\\u0C4D\\\\u0C55\\\\u0C56\\\\u0C58\\\\u0C59\\\\u0C60-\\\\u0C63\\\\u0C66-\\\\u0C6F\\\\u0C81-\\\\u0C83\\\\u0C85-\\\\u0C8C\\\\u0C8E-\\\\u0C90\\\\u0C92-\\\\u0CA8\\\\u0CAA-\\\\u0CB3\\\\u0CB5-\\\\u0CB9\\\\u0CBC-\\\\u0CC4\\\\u0CC6-\\\\u0CC8\\\\u0CCA-\\\\u0CCD\\\\u0CD5\\\\u0CD6\\\\u0CDE\\\\u0CE0-\\\\u0CE3\\\\u0CE6-\\\\u0CEF\\\\u0CF1\\\\u0CF2\\\\u0D01-\\\\u0D03\\\\u0D05-\\\\u0D0C\\\\u0D0E-\\\\u0D10\\\\u0D12-\\\\u0D3A\\\\u0D3D-\\\\u0D44\\\\u0D46-\\\\u0D48\\\\u0D4A-\\\\u0D4E\\\\u0D57\\\\u0D60-\\\\u0D63\\\\u0D66-\\\\u0D6F\\\\u0D7A-\\\\u0D7F\\\\u0D82\\\\u0D83\\\\u0D85-\\\\u0D96\\\\u0D9A-\\\\u0DB1\\\\u0DB3-\\\\u0DBB\\\\u0DBD\\\\u0DC0-\\\\u0DC6\\\\u0DCA\\\\u0DCF-\\\\u0DD4\\\\u0DD6\\\\u0DD8-\\\\u0DDF\\\\u0DE6-\\\\u0DEF\\\\u0DF2\\\\u0DF3\\\\u0E01-\\\\u0E3A\\\\u0E40-\\\\u0E4E\\\\u0E50-\\\\u0E59\\\\u0E81\\\\u0E82\\\\u0E84\\\\u0E87\\\\u0E88\\\\u0E8A\\\\u0E8D\\\\u0E94-\\\\u0E97\\\\u0E99-\\\\u0E9F\\\\u0EA1-\\\\u0EA3\\\\u0EA5\\\\u0EA7\\\\u0EAA\\\\u0EAB\\\\u0EAD-\\\\u0EB9\\\\u0EBB-\\\\u0EBD\\\\u0EC0-\\\\u0EC4\\\\u0EC6\\\\u0EC8-\\\\u0ECD\\\\u0ED0-\\\\u0ED9\\\\u0EDC-\\\\u0EDF\\\\u0F00\\\\u0F18\\\\u0F19\\\\u0F20-\\\\u0F29\\\\u0F35\\\\u0F37\\\\u0F39\\\\u0F3E-\\\\u0F47\\\\u0F49-\\\\u0F6C\\\\u0F71-\\\\u0F84\\\\u0F86-\\\\u0F97\\\\u0F99-\\\\u0FBC\\\\u0FC6\\\\u1000-\\\\u1049\\\\u1050-\\\\u109D\\\\u10A0-\\\\u10C5\\\\u10C7\\\\u10CD\\\\u10D0-\\\\u10FA\\\\u10FC-\\\\u1248\\\\u124A-\\\\u124D\\\\u1250-\\\\u1256\\\\u1258\\\\u125A-\\\\u125D\\\\u1260-\\\\u1288\\\\u128A-\\\\u128D\\\\u1290-\\\\u12B0\\\\u12B2-\\\\u12B5\\\\u12B8-\\\\u12BE\\\\u12C0\\\\u12C2-\\\\u12C5\\\\u12C8-\\\\u12D6\\\\u12D8-\\\\u1310\\\\u1312-\\\\u1315\\\\u1318-\\\\u135A\\\\u135D-\\\\u135F\\\\u1380-\\\\u138F\\\\u13A0-\\\\u13F4\\\\u1401-\\\\u166C\\\\u166F-\\\\u167F\\\\u1681-\\\\u169A\\\\u16A0-\\\\u16EA\\\\u16EE-\\\\u16F8\\\\u1700-\\\\u170C\\\\u170E-\\\\u1714\\\\u1720-\\\\u1734\\\\u1740-\\\\u1753\\\\u1760-\\\\u176C\\\\u176E-\\\\u1770\\\\u1772\\\\u1773\\\\u1780-\\\\u17D3\\\\u17D7\\\\u17DC\\\\u17DD\\\\u17E0-\\\\u17E9\\\\u180B-\\\\u180D\\\\u1810-\\\\u1819\\\\u1820-\\\\u1877\\\\u1880-\\\\u18AA\\\\u18B0-\\\\u18F5\\\\u1900-\\\\u191E\\\\u1920-\\\\u192B\\\\u1930-\\\\u193B\\\\u1946-\\\\u196D\\\\u1970-\\\\u1974\\\\u1980-\\\\u19AB\\\\u19B0-\\\\u19C9\\\\u19D0-\\\\u19D9\\\\u1A00-\\\\u1A1B\\\\u1A20-\\\\u1A5E\\\\u1A60-\\\\u1A7C\\\\u1A7F-\\\\u1A89\\\\u1A90-\\\\u1A99\\\\u1AA7\\\\u1AB0-\\\\u1ABD\\\\u1B00-\\\\u1B4B\\\\u1B50-\\\\u1B59\\\\u1B6B-\\\\u1B73\\\\u1B80-\\\\u1BF3\\\\u1C00-\\\\u1C37\\\\u1C40-\\\\u1C49\\\\u1C4D-\\\\u1C7D\\\\u1CD0-\\\\u1CD2\\\\u1CD4-\\\\u1CF6\\\\u1CF8\\\\u1CF9\\\\u1D00-\\\\u1DF5\\\\u1DFC-\\\\u1F15\\\\u1F18-\\\\u1F1D\\\\u1F20-\\\\u1F45\\\\u1F48-\\\\u1F4D\\\\u1F50-\\\\u1F57\\\\u1F59\\\\u1F5B\\\\u1F5D\\\\u1F5F-\\\\u1F7D\\\\u1F80-\\\\u1FB4\\\\u1FB6-\\\\u1FBC\\\\u1FBE\\\\u1FC2-\\\\u1FC4\\\\u1FC6-\\\\u1FCC\\\\u1FD0-\\\\u1FD3\\\\u1FD6-\\\\u1FDB\\\\u1FE0-\\\\u1FEC\\\\u1FF2-\\\\u1FF4\\\\u1FF6-\\\\u1FFC\\\\u200C\\\\u200D\\\\u203F\\\\u2040\\\\u2054\\\\u2071\\\\u207F\\\\u2090-\\\\u209C\\\\u20D0-\\\\u20DC\\\\u20E1\\\\u20E5-\\\\u20F0\\\\u2102\\\\u2107\\\\u210A-\\\\u2113\\\\u2115\\\\u2119-\\\\u211D\\\\u2124\\\\u2126\\\\u2128\\\\u212A-\\\\u212D\\\\u212F-\\\\u2139\\\\u213C-\\\\u213F\\\\u2145-\\\\u2149\\\\u214E\\\\u2160-\\\\u2188\\\\u2C00-\\\\u2C2E\\\\u2C30-\\\\u2C5E\\\\u2C60-\\\\u2CE4\\\\u2CEB-\\\\u2CF3\\\\u2D00-\\\\u2D25\\\\u2D27\\\\u2D2D\\\\u2D30-\\\\u2D67\\\\u2D6F\\\\u2D7F-\\\\u2D96\\\\u2DA0-\\\\u2DA6\\\\u2DA8-\\\\u2DAE\\\\u2DB0-\\\\u2DB6\\\\u2DB8-\\\\u2DBE\\\\u2DC0-\\\\u2DC6\\\\u2DC8-\\\\u2DCE\\\\u2DD0-\\\\u2DD6\\\\u2DD8-\\\\u2DDE\\\\u2DE0-\\\\u2DFF\\\\u2E2F\\\\u3005-\\\\u3007\\\\u3021-\\\\u302F\\\\u3031-\\\\u3035\\\\u3038-\\\\u303C\\\\u3041-\\\\u3096\\\\u3099\\\\u309A\\\\u309D-\\\\u309F\\\\u30A1-\\\\u30FA\\\\u30FC-\\\\u30FF\\\\u3105-\\\\u312D\\\\u3131-\\\\u318E\\\\u31A0-\\\\u31BA\\\\u31F0-\\\\u31FF\\\\u3400-\\\\u4DB5\\\\u4E00-\\\\u9FCC\\\\uA000-\\\\uA48C\\\\uA4D0-\\\\uA4FD\\\\uA500-\\\\uA60C\\\\uA610-\\\\uA62B\\\\uA640-\\\\uA66F\\\\uA674-\\\\uA67D\\\\uA67F-\\\\uA69D\\\\uA69F-\\\\uA6F1\\\\uA717-\\\\uA71F\\\\uA722-\\\\uA788\\\\uA78B-\\\\uA78E\\\\uA790-\\\\uA7AD\\\\uA7B0\\\\uA7B1\\\\uA7F7-\\\\uA827\\\\uA840-\\\\uA873\\\\uA880-\\\\uA8C4\\\\uA8D0-\\\\uA8D9\\\\uA8E0-\\\\uA8F7\\\\uA8FB\\\\uA900-\\\\uA92D\\\\uA930-\\\\uA953\\\\uA960-\\\\uA97C\\\\uA980-\\\\uA9C0\\\\uA9CF-\\\\uA9D9\\\\uA9E0-\\\\uA9FE\\\\uAA00-\\\\uAA36\\\\uAA40-\\\\uAA4D\\\\uAA50-\\\\uAA59\\\\uAA60-\\\\uAA76\\\\uAA7A-\\\\uAAC2\\\\uAADB-\\\\uAADD\\\\uAAE0-\\\\uAAEF\\\\uAAF2-\\\\uAAF6\\\\uAB01-\\\\uAB06\\\\uAB09-\\\\uAB0E\\\\uAB11-\\\\uAB16\\\\uAB20-\\\\uAB26\\\\uAB28-\\\\uAB2E\\\\uAB30-\\\\uAB5A\\\\uAB5C-\\\\uAB5F\\\\uAB64\\\\uAB65\\\\uABC0-\\\\uABEA\\\\uABEC\\\\uABED\\\\uABF0-\\\\uABF9\\\\uAC00-\\\\uD7A3\\\\uD7B0-\\\\uD7C6\\\\uD7CB-\\\\uD7FB\\\\uF900-\\\\uFA6D\\\\uFA70-\\\\uFAD9\\\\uFB00-\\\\uFB06\\\\uFB13-\\\\uFB17\\\\uFB1D-\\\\uFB28\\\\uFB2A-\\\\uFB36\\\\uFB38-\\\\uFB3C\\\\uFB3E\\\\uFB40\\\\uFB41\\\\uFB43\\\\uFB44\\\\uFB46-\\\\uFBB1\\\\uFBD3-\\\\uFD3D\\\\uFD50-\\\\uFD8F\\\\uFD92-\\\\uFDC7\\\\uFDF0-\\\\uFDFB\\\\uFE00-\\\\uFE0F\\\\uFE20-\\\\uFE2D\\\\uFE33\\\\uFE34\\\\uFE4D-\\\\uFE4F\\\\uFE70-\\\\uFE74\\\\uFE76-\\\\uFEFC\\\\uFF10-\\\\uFF19\\\\uFF21-\\\\uFF3A\\\\uFF3F\\\\uFF41-\\\\uFF5A\\\\uFF66-\\\\uFFBE\\\\uFFC2-\\\\uFFC7\\\\uFFCA-\\\\uFFCF\\\\uFFD2-\\\\uFFD7\\\\uFFDA-\\\\uFFDC]');\n\n// Ensure the condition is true, otherwise throw an error.\n// This is only to have a better contract semantic, i.e. another safety net\n// to catch a logic error. The condition shall be fulfilled in normal case.\n// Do NOT use this to enforce a certain condition on any user input.\n\nfunction assert(condition, message) {\n  /* istanbul ignore next */\n  if (!condition) {\n    throw new Error('ASSERT: ' + message);\n  }\n}\nfunction isDecimalDigit(ch) {\n  return ch >= 0x30 && ch <= 0x39; // 0..9\n}\n\nfunction isHexDigit(ch) {\n  return '0123456789abcdefABCDEF'.indexOf(ch) >= 0;\n}\nfunction isOctalDigit(ch) {\n  return '01234567'.indexOf(ch) >= 0;\n}\n\n// 7.2 White Space\n\nfunction isWhiteSpace(ch) {\n  return ch === 0x20 || ch === 0x09 || ch === 0x0B || ch === 0x0C || ch === 0xA0 || ch >= 0x1680 && [0x1680, 0x180E, 0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008, 0x2009, 0x200A, 0x202F, 0x205F, 0x3000, 0xFEFF].indexOf(ch) >= 0;\n}\n\n// 7.3 Line Terminators\n\nfunction isLineTerminator(ch) {\n  return ch === 0x0A || ch === 0x0D || ch === 0x2028 || ch === 0x2029;\n}\n\n// 7.6 Identifier Names and Identifiers\n\nfunction isIdentifierStart(ch) {\n  return ch === 0x24 || ch === 0x5F ||\n  // $ (dollar) and _ (underscore)\n  ch >= 0x41 && ch <= 0x5A ||\n  // A..Z\n  ch >= 0x61 && ch <= 0x7A ||\n  // a..z\n  ch === 0x5C ||\n  // \\ (backslash)\n  ch >= 0x80 && RegexNonAsciiIdentifierStart.test(String.fromCharCode(ch));\n}\nfunction isIdentifierPart(ch) {\n  return ch === 0x24 || ch === 0x5F ||\n  // $ (dollar) and _ (underscore)\n  ch >= 0x41 && ch <= 0x5A ||\n  // A..Z\n  ch >= 0x61 && ch <= 0x7A ||\n  // a..z\n  ch >= 0x30 && ch <= 0x39 ||\n  // 0..9\n  ch === 0x5C ||\n  // \\ (backslash)\n  ch >= 0x80 && RegexNonAsciiIdentifierPart.test(String.fromCharCode(ch));\n}\n\n// 7.6.1.1 Keywords\n\nconst keywords = {\n  'if': 1,\n  'in': 1,\n  'do': 1,\n  'var': 1,\n  'for': 1,\n  'new': 1,\n  'try': 1,\n  'let': 1,\n  'this': 1,\n  'else': 1,\n  'case': 1,\n  'void': 1,\n  'with': 1,\n  'enum': 1,\n  'while': 1,\n  'break': 1,\n  'catch': 1,\n  'throw': 1,\n  'const': 1,\n  'yield': 1,\n  'class': 1,\n  'super': 1,\n  'return': 1,\n  'typeof': 1,\n  'delete': 1,\n  'switch': 1,\n  'export': 1,\n  'import': 1,\n  'public': 1,\n  'static': 1,\n  'default': 1,\n  'finally': 1,\n  'extends': 1,\n  'package': 1,\n  'private': 1,\n  'function': 1,\n  'continue': 1,\n  'debugger': 1,\n  'interface': 1,\n  'protected': 1,\n  'instanceof': 1,\n  'implements': 1\n};\nfunction skipComment() {\n  while (index < length) {\n    const ch = source.charCodeAt(index);\n    if (isWhiteSpace(ch) || isLineTerminator(ch)) {\n      ++index;\n    } else {\n      break;\n    }\n  }\n}\nfunction scanHexEscape(prefix) {\n  var i,\n    len,\n    ch,\n    code = 0;\n  len = prefix === 'u' ? 4 : 2;\n  for (i = 0; i < len; ++i) {\n    if (index < length && isHexDigit(source[index])) {\n      ch = source[index++];\n      code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());\n    } else {\n      throwError({}, MessageUnexpectedToken, ILLEGAL);\n    }\n  }\n  return String.fromCharCode(code);\n}\nfunction scanUnicodeCodePointEscape() {\n  var ch, code, cu1, cu2;\n  ch = source[index];\n  code = 0;\n\n  // At least, one hex digit is required.\n  if (ch === '}') {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  while (index < length) {\n    ch = source[index++];\n    if (!isHexDigit(ch)) {\n      break;\n    }\n    code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());\n  }\n  if (code > 0x10FFFF || ch !== '}') {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n\n  // UTF-16 Encoding\n  if (code <= 0xFFFF) {\n    return String.fromCharCode(code);\n  }\n  cu1 = (code - 0x10000 >> 10) + 0xD800;\n  cu2 = (code - 0x10000 & 1023) + 0xDC00;\n  return String.fromCharCode(cu1, cu2);\n}\nfunction getEscapedIdentifier() {\n  var ch, id;\n  ch = source.charCodeAt(index++);\n  id = String.fromCharCode(ch);\n\n  // '\\u' (U+005C, U+0075) denotes an escaped character.\n  if (ch === 0x5C) {\n    if (source.charCodeAt(index) !== 0x75) {\n      throwError({}, MessageUnexpectedToken, ILLEGAL);\n    }\n    ++index;\n    ch = scanHexEscape('u');\n    if (!ch || ch === '\\\\' || !isIdentifierStart(ch.charCodeAt(0))) {\n      throwError({}, MessageUnexpectedToken, ILLEGAL);\n    }\n    id = ch;\n  }\n  while (index < length) {\n    ch = source.charCodeAt(index);\n    if (!isIdentifierPart(ch)) {\n      break;\n    }\n    ++index;\n    id += String.fromCharCode(ch);\n\n    // '\\u' (U+005C, U+0075) denotes an escaped character.\n    if (ch === 0x5C) {\n      id = id.substr(0, id.length - 1);\n      if (source.charCodeAt(index) !== 0x75) {\n        throwError({}, MessageUnexpectedToken, ILLEGAL);\n      }\n      ++index;\n      ch = scanHexEscape('u');\n      if (!ch || ch === '\\\\' || !isIdentifierPart(ch.charCodeAt(0))) {\n        throwError({}, MessageUnexpectedToken, ILLEGAL);\n      }\n      id += ch;\n    }\n  }\n  return id;\n}\nfunction getIdentifier() {\n  var start, ch;\n  start = index++;\n  while (index < length) {\n    ch = source.charCodeAt(index);\n    if (ch === 0x5C) {\n      // Blackslash (U+005C) marks Unicode escape sequence.\n      index = start;\n      return getEscapedIdentifier();\n    }\n    if (isIdentifierPart(ch)) {\n      ++index;\n    } else {\n      break;\n    }\n  }\n  return source.slice(start, index);\n}\nfunction scanIdentifier() {\n  var start, id, type;\n  start = index;\n\n  // Backslash (U+005C) starts an escaped character.\n  id = source.charCodeAt(index) === 0x5C ? getEscapedIdentifier() : getIdentifier();\n\n  // There is no keyword or literal with only one character.\n  // Thus, it must be an identifier.\n  if (id.length === 1) {\n    type = TokenIdentifier;\n  } else if (keywords.hasOwnProperty(id)) {\n    // eslint-disable-line no-prototype-builtins\n    type = TokenKeyword;\n  } else if (id === 'null') {\n    type = TokenNullLiteral;\n  } else if (id === 'true' || id === 'false') {\n    type = TokenBooleanLiteral;\n  } else {\n    type = TokenIdentifier;\n  }\n  return {\n    type: type,\n    value: id,\n    start: start,\n    end: index\n  };\n}\n\n// 7.7 Punctuators\n\nfunction scanPunctuator() {\n  var start = index,\n    code = source.charCodeAt(index),\n    code2,\n    ch1 = source[index],\n    ch2,\n    ch3,\n    ch4;\n  switch (code) {\n    // Check for most common single-character punctuators.\n    case 0x2E: // . dot\n    case 0x28: // ( open bracket\n    case 0x29: // ) close bracket\n    case 0x3B: // ; semicolon\n    case 0x2C: // , comma\n    case 0x7B: // { open curly brace\n    case 0x7D: // } close curly brace\n    case 0x5B: // [\n    case 0x5D: // ]\n    case 0x3A: // :\n    case 0x3F: // ?\n    case 0x7E:\n      // ~\n      ++index;\n      return {\n        type: TokenPunctuator,\n        value: String.fromCharCode(code),\n        start: start,\n        end: index\n      };\n    default:\n      code2 = source.charCodeAt(index + 1);\n\n      // '=' (U+003D) marks an assignment or comparison operator.\n      if (code2 === 0x3D) {\n        switch (code) {\n          case 0x2B: // +\n          case 0x2D: // -\n          case 0x2F: // /\n          case 0x3C: // <\n          case 0x3E: // >\n          case 0x5E: // ^\n          case 0x7C: // |\n          case 0x25: // %\n          case 0x26: // &\n          case 0x2A:\n            // *\n            index += 2;\n            return {\n              type: TokenPunctuator,\n              value: String.fromCharCode(code) + String.fromCharCode(code2),\n              start: start,\n              end: index\n            };\n          case 0x21: // !\n          case 0x3D:\n            // =\n            index += 2;\n\n            // !== and ===\n            if (source.charCodeAt(index) === 0x3D) {\n              ++index;\n            }\n            return {\n              type: TokenPunctuator,\n              value: source.slice(start, index),\n              start: start,\n              end: index\n            };\n        }\n      }\n  }\n\n  // 4-character punctuator: >>>=\n\n  ch4 = source.substr(index, 4);\n  if (ch4 === '>>>=') {\n    index += 4;\n    return {\n      type: TokenPunctuator,\n      value: ch4,\n      start: start,\n      end: index\n    };\n  }\n\n  // 3-character punctuators: === !== >>> <<= >>=\n\n  ch3 = ch4.substr(0, 3);\n  if (ch3 === '>>>' || ch3 === '<<=' || ch3 === '>>=') {\n    index += 3;\n    return {\n      type: TokenPunctuator,\n      value: ch3,\n      start: start,\n      end: index\n    };\n  }\n\n  // Other 2-character punctuators: ++ -- << >> && ||\n  ch2 = ch3.substr(0, 2);\n  if (ch1 === ch2[1] && '+-<>&|'.indexOf(ch1) >= 0 || ch2 === '=>') {\n    index += 2;\n    return {\n      type: TokenPunctuator,\n      value: ch2,\n      start: start,\n      end: index\n    };\n  }\n  if (ch2 === '//') {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n\n  // 1-character punctuators: < > = ! + - * % & | ^ /\n\n  if ('<>=!+-*%&|^/'.indexOf(ch1) >= 0) {\n    ++index;\n    return {\n      type: TokenPunctuator,\n      value: ch1,\n      start: start,\n      end: index\n    };\n  }\n  throwError({}, MessageUnexpectedToken, ILLEGAL);\n}\n\n// 7.8.3 Numeric Literals\n\nfunction scanHexLiteral(start) {\n  let number = '';\n  while (index < length) {\n    if (!isHexDigit(source[index])) {\n      break;\n    }\n    number += source[index++];\n  }\n  if (number.length === 0) {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  if (isIdentifierStart(source.charCodeAt(index))) {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  return {\n    type: TokenNumericLiteral,\n    value: parseInt('0x' + number, 16),\n    start: start,\n    end: index\n  };\n}\nfunction scanOctalLiteral(start) {\n  let number = '0' + source[index++];\n  while (index < length) {\n    if (!isOctalDigit(source[index])) {\n      break;\n    }\n    number += source[index++];\n  }\n  if (isIdentifierStart(source.charCodeAt(index)) || isDecimalDigit(source.charCodeAt(index))) {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  return {\n    type: TokenNumericLiteral,\n    value: parseInt(number, 8),\n    octal: true,\n    start: start,\n    end: index\n  };\n}\nfunction scanNumericLiteral() {\n  var number, start, ch;\n  ch = source[index];\n  assert(isDecimalDigit(ch.charCodeAt(0)) || ch === '.', 'Numeric literal must start with a decimal digit or a decimal point');\n  start = index;\n  number = '';\n  if (ch !== '.') {\n    number = source[index++];\n    ch = source[index];\n\n    // Hex number starts with '0x'.\n    // Octal number starts with '0'.\n    if (number === '0') {\n      if (ch === 'x' || ch === 'X') {\n        ++index;\n        return scanHexLiteral(start);\n      }\n      if (isOctalDigit(ch)) {\n        return scanOctalLiteral(start);\n      }\n\n      // decimal number starts with '0' such as '09' is illegal.\n      if (ch && isDecimalDigit(ch.charCodeAt(0))) {\n        throwError({}, MessageUnexpectedToken, ILLEGAL);\n      }\n    }\n    while (isDecimalDigit(source.charCodeAt(index))) {\n      number += source[index++];\n    }\n    ch = source[index];\n  }\n  if (ch === '.') {\n    number += source[index++];\n    while (isDecimalDigit(source.charCodeAt(index))) {\n      number += source[index++];\n    }\n    ch = source[index];\n  }\n  if (ch === 'e' || ch === 'E') {\n    number += source[index++];\n    ch = source[index];\n    if (ch === '+' || ch === '-') {\n      number += source[index++];\n    }\n    if (isDecimalDigit(source.charCodeAt(index))) {\n      while (isDecimalDigit(source.charCodeAt(index))) {\n        number += source[index++];\n      }\n    } else {\n      throwError({}, MessageUnexpectedToken, ILLEGAL);\n    }\n  }\n  if (isIdentifierStart(source.charCodeAt(index))) {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  return {\n    type: TokenNumericLiteral,\n    value: parseFloat(number),\n    start: start,\n    end: index\n  };\n}\n\n// 7.8.4 String Literals\n\nfunction scanStringLiteral() {\n  var str = '',\n    quote,\n    start,\n    ch,\n    code,\n    octal = false;\n  quote = source[index];\n  assert(quote === '\\'' || quote === '\"', 'String literal must starts with a quote');\n  start = index;\n  ++index;\n  while (index < length) {\n    ch = source[index++];\n    if (ch === quote) {\n      quote = '';\n      break;\n    } else if (ch === '\\\\') {\n      ch = source[index++];\n      if (!ch || !isLineTerminator(ch.charCodeAt(0))) {\n        switch (ch) {\n          case 'u':\n          case 'x':\n            if (source[index] === '{') {\n              ++index;\n              str += scanUnicodeCodePointEscape();\n            } else {\n              str += scanHexEscape(ch);\n            }\n            break;\n          case 'n':\n            str += '\\n';\n            break;\n          case 'r':\n            str += '\\r';\n            break;\n          case 't':\n            str += '\\t';\n            break;\n          case 'b':\n            str += '\\b';\n            break;\n          case 'f':\n            str += '\\f';\n            break;\n          case 'v':\n            str += '\\x0B';\n            break;\n          default:\n            if (isOctalDigit(ch)) {\n              code = '01234567'.indexOf(ch);\n\n              // \\0 is not octal escape sequence\n              if (code !== 0) {\n                octal = true;\n              }\n              if (index < length && isOctalDigit(source[index])) {\n                octal = true;\n                code = code * 8 + '01234567'.indexOf(source[index++]);\n\n                // 3 digits are only allowed when string starts\n                // with 0, 1, 2, 3\n                if ('0123'.indexOf(ch) >= 0 && index < length && isOctalDigit(source[index])) {\n                  code = code * 8 + '01234567'.indexOf(source[index++]);\n                }\n              }\n              str += String.fromCharCode(code);\n            } else {\n              str += ch;\n            }\n            break;\n        }\n      } else {\n        if (ch === '\\r' && source[index] === '\\n') {\n          ++index;\n        }\n      }\n    } else if (isLineTerminator(ch.charCodeAt(0))) {\n      break;\n    } else {\n      str += ch;\n    }\n  }\n  if (quote !== '') {\n    throwError({}, MessageUnexpectedToken, ILLEGAL);\n  }\n  return {\n    type: TokenStringLiteral,\n    value: str,\n    octal: octal,\n    start: start,\n    end: index\n  };\n}\nfunction testRegExp(pattern, flags) {\n  let tmp = pattern;\n  if (flags.indexOf('u') >= 0) {\n    // Replace each astral symbol and every Unicode code point\n    // escape sequence with a single ASCII symbol to avoid throwing on\n    // regular expressions that are only valid in combination with the\n    // `/u` flag.\n    // Note: replacing with the ASCII symbol `x` might cause false\n    // negatives in unlikely scenarios. For example, `[\\u{61}-b]` is a\n    // perfectly valid pattern that is equivalent to `[a-b]`, but it\n    // would be replaced by `[x-b]` which throws an error.\n    tmp = tmp.replace(/\\\\u\\{([0-9a-fA-F]+)\\}/g, ($0, $1) => {\n      if (parseInt($1, 16) <= 0x10FFFF) {\n        return 'x';\n      }\n      throwError({}, MessageInvalidRegExp);\n    }).replace(/[\\uD800-\\uDBFF][\\uDC00-\\uDFFF]/g, 'x');\n  }\n\n  // First, detect invalid regular expressions.\n  try {\n    new RegExp(tmp);\n  } catch (e) {\n    throwError({}, MessageInvalidRegExp);\n  }\n\n  // Return a regular expression object for this pattern-flag pair, or\n  // `null` in case the current environment doesn't support the flags it\n  // uses.\n  try {\n    return new RegExp(pattern, flags);\n  } catch (exception) {\n    return null;\n  }\n}\nfunction scanRegExpBody() {\n  var ch, str, classMarker, terminated, body;\n  ch = source[index];\n  assert(ch === '/', 'Regular expression literal must start with a slash');\n  str = source[index++];\n  classMarker = false;\n  terminated = false;\n  while (index < length) {\n    ch = source[index++];\n    str += ch;\n    if (ch === '\\\\') {\n      ch = source[index++];\n      // ECMA-262 7.8.5\n      if (isLineTerminator(ch.charCodeAt(0))) {\n        throwError({}, MessageUnterminatedRegExp);\n      }\n      str += ch;\n    } else if (isLineTerminator(ch.charCodeAt(0))) {\n      throwError({}, MessageUnterminatedRegExp);\n    } else if (classMarker) {\n      if (ch === ']') {\n        classMarker = false;\n      }\n    } else {\n      if (ch === '/') {\n        terminated = true;\n        break;\n      } else if (ch === '[') {\n        classMarker = true;\n      }\n    }\n  }\n  if (!terminated) {\n    throwError({}, MessageUnterminatedRegExp);\n  }\n\n  // Exclude leading and trailing slash.\n  body = str.substr(1, str.length - 2);\n  return {\n    value: body,\n    literal: str\n  };\n}\nfunction scanRegExpFlags() {\n  var ch, str, flags;\n  str = '';\n  flags = '';\n  while (index < length) {\n    ch = source[index];\n    if (!isIdentifierPart(ch.charCodeAt(0))) {\n      break;\n    }\n    ++index;\n    if (ch === '\\\\' && index < length) {\n      throwError({}, MessageUnexpectedToken, ILLEGAL);\n    } else {\n      flags += ch;\n      str += ch;\n    }\n  }\n  if (flags.search(/[^gimuy]/g) >= 0) {\n    throwError({}, MessageInvalidRegExp, flags);\n  }\n  return {\n    value: flags,\n    literal: str\n  };\n}\nfunction scanRegExp() {\n  var start, body, flags, value;\n  lookahead = null;\n  skipComment();\n  start = index;\n  body = scanRegExpBody();\n  flags = scanRegExpFlags();\n  value = testRegExp(body.value, flags.value);\n  return {\n    literal: body.literal + flags.literal,\n    value: value,\n    regex: {\n      pattern: body.value,\n      flags: flags.value\n    },\n    start: start,\n    end: index\n  };\n}\nfunction isIdentifierName(token) {\n  return token.type === TokenIdentifier || token.type === TokenKeyword || token.type === TokenBooleanLiteral || token.type === TokenNullLiteral;\n}\nfunction advance() {\n  skipComment();\n  if (index >= length) {\n    return {\n      type: TokenEOF,\n      start: index,\n      end: index\n    };\n  }\n  const ch = source.charCodeAt(index);\n  if (isIdentifierStart(ch)) {\n    return scanIdentifier();\n  }\n\n  // Very common: ( and ) and ;\n  if (ch === 0x28 || ch === 0x29 || ch === 0x3B) {\n    return scanPunctuator();\n  }\n\n  // String literal starts with single quote (U+0027) or double quote (U+0022).\n  if (ch === 0x27 || ch === 0x22) {\n    return scanStringLiteral();\n  }\n\n  // Dot (.) U+002E can also start a floating-point number, hence the need\n  // to check the next character.\n  if (ch === 0x2E) {\n    if (isDecimalDigit(source.charCodeAt(index + 1))) {\n      return scanNumericLiteral();\n    }\n    return scanPunctuator();\n  }\n  if (isDecimalDigit(ch)) {\n    return scanNumericLiteral();\n  }\n  return scanPunctuator();\n}\nfunction lex() {\n  const token = lookahead;\n  index = token.end;\n  lookahead = advance();\n  index = token.end;\n  return token;\n}\nfunction peek() {\n  const pos = index;\n  lookahead = advance();\n  index = pos;\n}\nfunction finishArrayExpression(elements) {\n  const node = new ASTNode(SyntaxArrayExpression);\n  node.elements = elements;\n  return node;\n}\nfunction finishBinaryExpression(operator, left, right) {\n  const node = new ASTNode(operator === '||' || operator === '&&' ? SyntaxLogicalExpression : SyntaxBinaryExpression);\n  node.operator = operator;\n  node.left = left;\n  node.right = right;\n  return node;\n}\nfunction finishCallExpression(callee, args) {\n  const node = new ASTNode(SyntaxCallExpression);\n  node.callee = callee;\n  node.arguments = args;\n  return node;\n}\nfunction finishConditionalExpression(test, consequent, alternate) {\n  const node = new ASTNode(SyntaxConditionalExpression);\n  node.test = test;\n  node.consequent = consequent;\n  node.alternate = alternate;\n  return node;\n}\nfunction finishIdentifier(name) {\n  const node = new ASTNode(SyntaxIdentifier);\n  node.name = name;\n  return node;\n}\nfunction finishLiteral(token) {\n  const node = new ASTNode(SyntaxLiteral);\n  node.value = token.value;\n  node.raw = source.slice(token.start, token.end);\n  if (token.regex) {\n    if (node.raw === '//') {\n      node.raw = '/(?:)/';\n    }\n    node.regex = token.regex;\n  }\n  return node;\n}\nfunction finishMemberExpression(accessor, object, property) {\n  const node = new ASTNode(SyntaxMemberExpression);\n  node.computed = accessor === '[';\n  node.object = object;\n  node.property = property;\n  if (!node.computed) property.member = true;\n  return node;\n}\nfunction finishObjectExpression(properties) {\n  const node = new ASTNode(SyntaxObjectExpression);\n  node.properties = properties;\n  return node;\n}\nfunction finishProperty(kind, key, value) {\n  const node = new ASTNode(SyntaxProperty);\n  node.key = key;\n  node.value = value;\n  node.kind = kind;\n  return node;\n}\nfunction finishUnaryExpression(operator, argument) {\n  const node = new ASTNode(SyntaxUnaryExpression);\n  node.operator = operator;\n  node.argument = argument;\n  node.prefix = true;\n  return node;\n}\n\n// Throw an exception\n\nfunction throwError(token, messageFormat) {\n  var error,\n    args = Array.prototype.slice.call(arguments, 2),\n    msg = messageFormat.replace(/%(\\d)/g, (whole, index) => {\n      assert(index < args.length, 'Message reference must be in range');\n      return args[index];\n    });\n  error = new Error(msg);\n  error.index = index;\n  error.description = msg;\n  throw error;\n}\n\n// Throw an exception because of the token.\n\nfunction throwUnexpected(token) {\n  if (token.type === TokenEOF) {\n    throwError(token, MessageUnexpectedEOS);\n  }\n  if (token.type === TokenNumericLiteral) {\n    throwError(token, MessageUnexpectedNumber);\n  }\n  if (token.type === TokenStringLiteral) {\n    throwError(token, MessageUnexpectedString);\n  }\n  if (token.type === TokenIdentifier) {\n    throwError(token, MessageUnexpectedIdentifier);\n  }\n  if (token.type === TokenKeyword) {\n    throwError(token, MessageUnexpectedReserved);\n  }\n\n  // BooleanLiteral, NullLiteral, or Punctuator.\n  throwError(token, MessageUnexpectedToken, token.value);\n}\n\n// Expect the next token to match the specified punctuator.\n// If not, an exception will be thrown.\n\nfunction expect(value) {\n  const token = lex();\n  if (token.type !== TokenPunctuator || token.value !== value) {\n    throwUnexpected(token);\n  }\n}\n\n// Return true if the next token matches the specified punctuator.\n\nfunction match(value) {\n  return lookahead.type === TokenPunctuator && lookahead.value === value;\n}\n\n// Return true if the next token matches the specified keyword\n\nfunction matchKeyword(keyword) {\n  return lookahead.type === TokenKeyword && lookahead.value === keyword;\n}\n\n// 11.1.4 Array Initialiser\n\nfunction parseArrayInitialiser() {\n  const elements = [];\n  index = lookahead.start;\n  expect('[');\n  while (!match(']')) {\n    if (match(',')) {\n      lex();\n      elements.push(null);\n    } else {\n      elements.push(parseConditionalExpression());\n      if (!match(']')) {\n        expect(',');\n      }\n    }\n  }\n  lex();\n  return finishArrayExpression(elements);\n}\n\n// 11.1.5 Object Initialiser\n\nfunction parseObjectPropertyKey() {\n  index = lookahead.start;\n  const token = lex();\n\n  // Note: This function is called only from parseObjectProperty(), where\n  // EOF and Punctuator tokens are already filtered out.\n\n  if (token.type === TokenStringLiteral || token.type === TokenNumericLiteral) {\n    if (token.octal) {\n      throwError(token, MessageStrictOctalLiteral);\n    }\n    return finishLiteral(token);\n  }\n  return finishIdentifier(token.value);\n}\nfunction parseObjectProperty() {\n  var token, key, id, value;\n  index = lookahead.start;\n  token = lookahead;\n  if (token.type === TokenIdentifier) {\n    id = parseObjectPropertyKey();\n    expect(':');\n    value = parseConditionalExpression();\n    return finishProperty('init', id, value);\n  }\n  if (token.type === TokenEOF || token.type === TokenPunctuator) {\n    throwUnexpected(token);\n  } else {\n    key = parseObjectPropertyKey();\n    expect(':');\n    value = parseConditionalExpression();\n    return finishProperty('init', key, value);\n  }\n}\nfunction parseObjectInitialiser() {\n  var properties = [],\n    property,\n    name,\n    key,\n    map = {},\n    toString = String;\n  index = lookahead.start;\n  expect('{');\n  while (!match('}')) {\n    property = parseObjectProperty();\n    if (property.key.type === SyntaxIdentifier) {\n      name = property.key.name;\n    } else {\n      name = toString(property.key.value);\n    }\n    key = '$' + name;\n    if (Object.prototype.hasOwnProperty.call(map, key)) {\n      throwError({}, MessageStrictDuplicateProperty);\n    } else {\n      map[key] = true;\n    }\n    properties.push(property);\n    if (!match('}')) {\n      expect(',');\n    }\n  }\n  expect('}');\n  return finishObjectExpression(properties);\n}\n\n// 11.1.6 The Grouping Operator\n\nfunction parseGroupExpression() {\n  expect('(');\n  const expr = parseExpression();\n  expect(')');\n  return expr;\n}\n\n// 11.1 Primary Expressions\n\nconst legalKeywords = {\n  'if': 1\n};\nfunction parsePrimaryExpression() {\n  var type, token, expr;\n  if (match('(')) {\n    return parseGroupExpression();\n  }\n  if (match('[')) {\n    return parseArrayInitialiser();\n  }\n  if (match('{')) {\n    return parseObjectInitialiser();\n  }\n  type = lookahead.type;\n  index = lookahead.start;\n  if (type === TokenIdentifier || legalKeywords[lookahead.value]) {\n    expr = finishIdentifier(lex().value);\n  } else if (type === TokenStringLiteral || type === TokenNumericLiteral) {\n    if (lookahead.octal) {\n      throwError(lookahead, MessageStrictOctalLiteral);\n    }\n    expr = finishLiteral(lex());\n  } else if (type === TokenKeyword) {\n    throw new Error(DISABLED);\n  } else if (type === TokenBooleanLiteral) {\n    token = lex();\n    token.value = token.value === 'true';\n    expr = finishLiteral(token);\n  } else if (type === TokenNullLiteral) {\n    token = lex();\n    token.value = null;\n    expr = finishLiteral(token);\n  } else if (match('/') || match('/=')) {\n    expr = finishLiteral(scanRegExp());\n    peek();\n  } else {\n    throwUnexpected(lex());\n  }\n  return expr;\n}\n\n// 11.2 Left-Hand-Side Expressions\n\nfunction parseArguments() {\n  const args = [];\n  expect('(');\n  if (!match(')')) {\n    while (index < length) {\n      args.push(parseConditionalExpression());\n      if (match(')')) {\n        break;\n      }\n      expect(',');\n    }\n  }\n  expect(')');\n  return args;\n}\nfunction parseNonComputedProperty() {\n  index = lookahead.start;\n  const token = lex();\n  if (!isIdentifierName(token)) {\n    throwUnexpected(token);\n  }\n  return finishIdentifier(token.value);\n}\nfunction parseNonComputedMember() {\n  expect('.');\n  return parseNonComputedProperty();\n}\nfunction parseComputedMember() {\n  expect('[');\n  const expr = parseExpression();\n  expect(']');\n  return expr;\n}\nfunction parseLeftHandSideExpressionAllowCall() {\n  var expr, args, property;\n  expr = parsePrimaryExpression();\n  for (;;) {\n    if (match('.')) {\n      property = parseNonComputedMember();\n      expr = finishMemberExpression('.', expr, property);\n    } else if (match('(')) {\n      args = parseArguments();\n      expr = finishCallExpression(expr, args);\n    } else if (match('[')) {\n      property = parseComputedMember();\n      expr = finishMemberExpression('[', expr, property);\n    } else {\n      break;\n    }\n  }\n  return expr;\n}\n\n// 11.3 Postfix Expressions\n\nfunction parsePostfixExpression() {\n  const expr = parseLeftHandSideExpressionAllowCall();\n  if (lookahead.type === TokenPunctuator) {\n    if (match('++') || match('--')) {\n      throw new Error(DISABLED);\n    }\n  }\n  return expr;\n}\n\n// 11.4 Unary Operators\n\nfunction parseUnaryExpression() {\n  var token, expr;\n  if (lookahead.type !== TokenPunctuator && lookahead.type !== TokenKeyword) {\n    expr = parsePostfixExpression();\n  } else if (match('++') || match('--')) {\n    throw new Error(DISABLED);\n  } else if (match('+') || match('-') || match('~') || match('!')) {\n    token = lex();\n    expr = parseUnaryExpression();\n    expr = finishUnaryExpression(token.value, expr);\n  } else if (matchKeyword('delete') || matchKeyword('void') || matchKeyword('typeof')) {\n    throw new Error(DISABLED);\n  } else {\n    expr = parsePostfixExpression();\n  }\n  return expr;\n}\nfunction binaryPrecedence(token) {\n  let prec = 0;\n  if (token.type !== TokenPunctuator && token.type !== TokenKeyword) {\n    return 0;\n  }\n  switch (token.value) {\n    case '||':\n      prec = 1;\n      break;\n    case '&&':\n      prec = 2;\n      break;\n    case '|':\n      prec = 3;\n      break;\n    case '^':\n      prec = 4;\n      break;\n    case '&':\n      prec = 5;\n      break;\n    case '==':\n    case '!=':\n    case '===':\n    case '!==':\n      prec = 6;\n      break;\n    case '<':\n    case '>':\n    case '<=':\n    case '>=':\n    case 'instanceof':\n    case 'in':\n      prec = 7;\n      break;\n    case '<<':\n    case '>>':\n    case '>>>':\n      prec = 8;\n      break;\n    case '+':\n    case '-':\n      prec = 9;\n      break;\n    case '*':\n    case '/':\n    case '%':\n      prec = 11;\n      break;\n  }\n  return prec;\n}\n\n// 11.5 Multiplicative Operators\n// 11.6 Additive Operators\n// 11.7 Bitwise Shift Operators\n// 11.8 Relational Operators\n// 11.9 Equality Operators\n// 11.10 Binary Bitwise Operators\n// 11.11 Binary Logical Operators\n\nfunction parseBinaryExpression() {\n  var marker, markers, expr, token, prec, stack, right, operator, left, i;\n  marker = lookahead;\n  left = parseUnaryExpression();\n  token = lookahead;\n  prec = binaryPrecedence(token);\n  if (prec === 0) {\n    return left;\n  }\n  token.prec = prec;\n  lex();\n  markers = [marker, lookahead];\n  right = parseUnaryExpression();\n  stack = [left, token, right];\n  while ((prec = binaryPrecedence(lookahead)) > 0) {\n    // Reduce: make a binary expression from the three topmost entries.\n    while (stack.length > 2 && prec <= stack[stack.length - 2].prec) {\n      right = stack.pop();\n      operator = stack.pop().value;\n      left = stack.pop();\n      markers.pop();\n      expr = finishBinaryExpression(operator, left, right);\n      stack.push(expr);\n    }\n\n    // Shift.\n    token = lex();\n    token.prec = prec;\n    stack.push(token);\n    markers.push(lookahead);\n    expr = parseUnaryExpression();\n    stack.push(expr);\n  }\n\n  // Final reduce to clean-up the stack.\n  i = stack.length - 1;\n  expr = stack[i];\n  markers.pop();\n  while (i > 1) {\n    markers.pop();\n    expr = finishBinaryExpression(stack[i - 1].value, stack[i - 2], expr);\n    i -= 2;\n  }\n  return expr;\n}\n\n// 11.12 Conditional Operator\n\nfunction parseConditionalExpression() {\n  var expr, consequent, alternate;\n  expr = parseBinaryExpression();\n  if (match('?')) {\n    lex();\n    consequent = parseConditionalExpression();\n    expect(':');\n    alternate = parseConditionalExpression();\n    expr = finishConditionalExpression(expr, consequent, alternate);\n  }\n  return expr;\n}\n\n// 11.14 Comma Operator\n\nfunction parseExpression() {\n  const expr = parseConditionalExpression();\n  if (match(',')) {\n    throw new Error(DISABLED); // no sequence expressions\n  }\n\n  return expr;\n}\nfunction parser (code) {\n  source = code;\n  index = 0;\n  length = source.length;\n  lookahead = null;\n  peek();\n  const expr = parseExpression();\n  if (lookahead.type !== TokenEOF) {\n    throw new Error('Unexpect token after expression.');\n  }\n  return expr;\n}\n\nvar Constants = {\n  NaN: 'NaN',\n  E: 'Math.E',\n  LN2: 'Math.LN2',\n  LN10: 'Math.LN10',\n  LOG2E: 'Math.LOG2E',\n  LOG10E: 'Math.LOG10E',\n  PI: 'Math.PI',\n  SQRT1_2: 'Math.SQRT1_2',\n  SQRT2: 'Math.SQRT2',\n  MIN_VALUE: 'Number.MIN_VALUE',\n  MAX_VALUE: 'Number.MAX_VALUE'\n};\n\nfunction Functions (codegen) {\n  function fncall(name, args, cast, type) {\n    let obj = codegen(args[0]);\n    if (cast) {\n      obj = cast + '(' + obj + ')';\n      if (cast.lastIndexOf('new ', 0) === 0) obj = '(' + obj + ')';\n    }\n    return obj + '.' + name + (type < 0 ? '' : type === 0 ? '()' : '(' + args.slice(1).map(codegen).join(',') + ')');\n  }\n  function fn(name, cast, type) {\n    return args => fncall(name, args, cast, type);\n  }\n  const DATE = 'new Date',\n    STRING = 'String',\n    REGEXP = 'RegExp';\n  return {\n    // MATH functions\n    isNaN: 'Number.isNaN',\n    isFinite: 'Number.isFinite',\n    abs: 'Math.abs',\n    acos: 'Math.acos',\n    asin: 'Math.asin',\n    atan: 'Math.atan',\n    atan2: 'Math.atan2',\n    ceil: 'Math.ceil',\n    cos: 'Math.cos',\n    exp: 'Math.exp',\n    floor: 'Math.floor',\n    hypot: 'Math.hypot',\n    log: 'Math.log',\n    max: 'Math.max',\n    min: 'Math.min',\n    pow: 'Math.pow',\n    random: 'Math.random',\n    round: 'Math.round',\n    sin: 'Math.sin',\n    sqrt: 'Math.sqrt',\n    tan: 'Math.tan',\n    clamp: function (args) {\n      if (args.length < 3) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing arguments to clamp function.');\n      if (args.length > 3) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Too many arguments to clamp function.');\n      const a = args.map(codegen);\n      return 'Math.max(' + a[1] + ', Math.min(' + a[2] + ',' + a[0] + '))';\n    },\n    // DATE functions\n    now: 'Date.now',\n    utc: 'Date.UTC',\n    datetime: DATE,\n    date: fn('getDate', DATE, 0),\n    day: fn('getDay', DATE, 0),\n    year: fn('getFullYear', DATE, 0),\n    month: fn('getMonth', DATE, 0),\n    hours: fn('getHours', DATE, 0),\n    minutes: fn('getMinutes', DATE, 0),\n    seconds: fn('getSeconds', DATE, 0),\n    milliseconds: fn('getMilliseconds', DATE, 0),\n    time: fn('getTime', DATE, 0),\n    timezoneoffset: fn('getTimezoneOffset', DATE, 0),\n    utcdate: fn('getUTCDate', DATE, 0),\n    utcday: fn('getUTCDay', DATE, 0),\n    utcyear: fn('getUTCFullYear', DATE, 0),\n    utcmonth: fn('getUTCMonth', DATE, 0),\n    utchours: fn('getUTCHours', DATE, 0),\n    utcminutes: fn('getUTCMinutes', DATE, 0),\n    utcseconds: fn('getUTCSeconds', DATE, 0),\n    utcmilliseconds: fn('getUTCMilliseconds', DATE, 0),\n    // sequence functions\n    length: fn('length', null, -1),\n    // STRING functions\n    parseFloat: 'parseFloat',\n    parseInt: 'parseInt',\n    upper: fn('toUpperCase', STRING, 0),\n    lower: fn('toLowerCase', STRING, 0),\n    substring: fn('substring', STRING),\n    split: fn('split', STRING),\n    trim: fn('trim', STRING, 0),\n    // REGEXP functions\n    regexp: REGEXP,\n    test: fn('test', REGEXP),\n    // Control Flow functions\n    if: function (args) {\n      if (args.length < 3) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing arguments to if function.');\n      if (args.length > 3) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Too many arguments to if function.');\n      const a = args.map(codegen);\n      return '(' + a[0] + '?' + a[1] + ':' + a[2] + ')';\n    }\n  };\n}\n\nfunction stripQuotes(s) {\n  const n = s && s.length - 1;\n  return n && (s[0] === '\"' && s[n] === '\"' || s[0] === '\\'' && s[n] === '\\'') ? s.slice(1, -1) : s;\n}\nfunction codegen (opt) {\n  opt = opt || {};\n  const allowed = opt.allowed ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(opt.allowed) : {},\n    forbidden = opt.forbidden ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(opt.forbidden) : {},\n    constants = opt.constants || Constants,\n    functions = (opt.functions || Functions)(visit),\n    globalvar = opt.globalvar,\n    fieldvar = opt.fieldvar,\n    outputGlobal = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(globalvar) ? globalvar : id => `${globalvar}[\"${id}\"]`;\n  let globals = {},\n    fields = {},\n    memberDepth = 0;\n  function visit(ast) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(ast)) return ast;\n    const generator = Generators[ast.type];\n    if (generator == null) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported type: ' + ast.type);\n    return generator(ast);\n  }\n  const Generators = {\n    Literal: n => n.raw,\n    Identifier: n => {\n      const id = n.name;\n      if (memberDepth > 0) {\n        return id;\n      } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(forbidden, id)) {\n        return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Illegal identifier: ' + id);\n      } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(constants, id)) {\n        return constants[id];\n      } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(allowed, id)) {\n        return id;\n      } else {\n        globals[id] = 1;\n        return outputGlobal(id);\n      }\n    },\n    MemberExpression: n => {\n      const d = !n.computed,\n        o = visit(n.object);\n      if (d) memberDepth += 1;\n      const p = visit(n.property);\n      if (o === fieldvar) {\n        // strip quotes to sanitize field name (#1653)\n        fields[stripQuotes(p)] = 1;\n      }\n      if (d) memberDepth -= 1;\n      return o + (d ? '.' + p : '[' + p + ']');\n    },\n    CallExpression: n => {\n      if (n.callee.type !== 'Identifier') {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Illegal callee type: ' + n.callee.type);\n      }\n      const callee = n.callee.name,\n        args = n.arguments,\n        fn = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(functions, callee) && functions[callee];\n      if (!fn) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized function: ' + callee);\n      return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(fn) ? fn(args) : fn + '(' + args.map(visit).join(',') + ')';\n    },\n    ArrayExpression: n => '[' + n.elements.map(visit).join(',') + ']',\n    BinaryExpression: n => '(' + visit(n.left) + ' ' + n.operator + ' ' + visit(n.right) + ')',\n    UnaryExpression: n => '(' + n.operator + visit(n.argument) + ')',\n    ConditionalExpression: n => '(' + visit(n.test) + '?' + visit(n.consequent) + ':' + visit(n.alternate) + ')',\n    LogicalExpression: n => '(' + visit(n.left) + n.operator + visit(n.right) + ')',\n    ObjectExpression: n => '{' + n.properties.map(visit).join(',') + '}',\n    Property: n => {\n      memberDepth += 1;\n      const k = visit(n.key);\n      memberDepth -= 1;\n      return k + ':' + visit(n.value);\n    }\n  };\n  function codegen(ast) {\n    const result = {\n      code: visit(ast),\n      globals: Object.keys(globals),\n      fields: Object.keys(fields)\n    };\n    globals = {};\n    fields = {};\n    return result;\n  }\n  codegen.functions = functions;\n  codegen.constants = constants;\n  return codegen;\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-expression/build/vega-expression.module.js?");

/***/ }),

/***/ "../../node_modules/vega-force/build/vega-force.module.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-force/build/vega-force.module.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   force: () => (/* binding */ Force)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/center.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/collide.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/manyBody.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/link.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/x.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/y.js\");\n/* harmony import */ var d3_force__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-force */ \"../../node_modules/d3-force/src/simulation.js\");\n\n\n\n\nconst ForceMap = {\n  center: d3_force__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  collide: d3_force__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  nbody: d3_force__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  link: d3_force__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  x: d3_force__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  y: d3_force__WEBPACK_IMPORTED_MODULE_7__[\"default\"]\n};\nconst Forces = 'forces',\n  ForceParams = ['alpha', 'alphaMin', 'alphaTarget', 'velocityDecay', 'forces'],\n  ForceConfig = ['static', 'iterations'],\n  ForceOutput = ['x', 'y', 'vx', 'vy'];\n\n/**\n * Force simulation layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<object>} params.forces - The forces to apply.\n */\nfunction Force(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nForce.Definition = {\n  'type': 'Force',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'static',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'restart',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'iterations',\n    'type': 'number',\n    'default': 300\n  }, {\n    'name': 'alpha',\n    'type': 'number',\n    'default': 1\n  }, {\n    'name': 'alphaMin',\n    'type': 'number',\n    'default': 0.001\n  }, {\n    'name': 'alphaTarget',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'velocityDecay',\n    'type': 'number',\n    'default': 0.4\n  }, {\n    'name': 'forces',\n    'type': 'param',\n    'array': true,\n    'params': [{\n      'key': {\n        'force': 'center'\n      },\n      'params': [{\n        'name': 'x',\n        'type': 'number',\n        'default': 0\n      }, {\n        'name': 'y',\n        'type': 'number',\n        'default': 0\n      }]\n    }, {\n      'key': {\n        'force': 'collide'\n      },\n      'params': [{\n        'name': 'radius',\n        'type': 'number',\n        'expr': true\n      }, {\n        'name': 'strength',\n        'type': 'number',\n        'default': 0.7\n      }, {\n        'name': 'iterations',\n        'type': 'number',\n        'default': 1\n      }]\n    }, {\n      'key': {\n        'force': 'nbody'\n      },\n      'params': [{\n        'name': 'strength',\n        'type': 'number',\n        'default': -30,\n        'expr': true\n      }, {\n        'name': 'theta',\n        'type': 'number',\n        'default': 0.9\n      }, {\n        'name': 'distanceMin',\n        'type': 'number',\n        'default': 1\n      }, {\n        'name': 'distanceMax',\n        'type': 'number'\n      }]\n    }, {\n      'key': {\n        'force': 'link'\n      },\n      'params': [{\n        'name': 'links',\n        'type': 'data'\n      }, {\n        'name': 'id',\n        'type': 'field'\n      }, {\n        'name': 'distance',\n        'type': 'number',\n        'default': 30,\n        'expr': true\n      }, {\n        'name': 'strength',\n        'type': 'number',\n        'expr': true\n      }, {\n        'name': 'iterations',\n        'type': 'number',\n        'default': 1\n      }]\n    }, {\n      'key': {\n        'force': 'x'\n      },\n      'params': [{\n        'name': 'strength',\n        'type': 'number',\n        'default': 0.1\n      }, {\n        'name': 'x',\n        'type': 'field'\n      }]\n    }, {\n      'key': {\n        'force': 'y'\n      },\n      'params': [{\n        'name': 'strength',\n        'type': 'number',\n        'default': 0.1\n      }, {\n        'name': 'y',\n        'type': 'field'\n      }]\n    }]\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'modify': false,\n    'default': ForceOutput\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Force, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var sim = this.value,\n      change = pulse.changed(pulse.ADD_REM),\n      params = _.modified(ForceParams),\n      iters = _.iterations || 300;\n\n    // configure simulation\n    if (!sim) {\n      this.value = sim = simulation(pulse.source, _);\n      sim.on('tick', rerun(pulse.dataflow, this));\n      if (!_.static) {\n        change = true;\n        sim.tick(); // ensure we run on init\n      }\n\n      pulse.modifies('index');\n    } else {\n      if (change) {\n        pulse.modifies('index');\n        sim.nodes(pulse.source);\n      }\n      if (params || pulse.changed(pulse.MOD)) {\n        setup(sim, _, 0, pulse);\n      }\n    }\n\n    // run simulation\n    if (params || change || _.modified(ForceConfig) || pulse.changed() && _.restart) {\n      sim.alpha(Math.max(sim.alpha(), _.alpha || 1)).alphaDecay(1 - Math.pow(sim.alphaMin(), 1 / iters));\n      if (_.static) {\n        for (sim.stop(); --iters >= 0;) sim.tick();\n      } else {\n        if (sim.stopped()) sim.restart();\n        if (!change) return pulse.StopPropagation; // defer to sim ticks\n      }\n    }\n\n    return this.finish(_, pulse);\n  },\n  finish(_, pulse) {\n    const dataflow = pulse.dataflow;\n\n    // inspect dependencies, touch link source data\n    for (let args = this._argops, j = 0, m = args.length, arg; j < m; ++j) {\n      arg = args[j];\n      if (arg.name !== Forces || arg.op._argval.force !== 'link') {\n        continue;\n      }\n      for (var ops = arg.op._argops, i = 0, n = ops.length, op; i < n; ++i) {\n        if (ops[i].name === 'links' && (op = ops[i].op.source)) {\n          dataflow.pulse(op, dataflow.changeset().reflow());\n          break;\n        }\n      }\n    }\n\n    // reflow all nodes\n    return pulse.reflow(_.modified()).modifies(ForceOutput);\n  }\n});\nfunction rerun(df, op) {\n  return () => df.touch(op).run();\n}\nfunction simulation(nodes, _) {\n  const sim = (0,d3_force__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(nodes),\n    stop = sim.stop,\n    restart = sim.restart;\n  let stopped = false;\n  sim.stopped = () => stopped;\n  sim.restart = () => (stopped = false, restart());\n  sim.stop = () => (stopped = true, stop());\n  return setup(sim, _, true).on('end', () => stopped = true);\n}\nfunction setup(sim, _, init, pulse) {\n  var f = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(_.forces),\n    i,\n    n,\n    p,\n    name;\n  for (i = 0, n = ForceParams.length; i < n; ++i) {\n    p = ForceParams[i];\n    if (p !== Forces && _.modified(p)) sim[p](_[p]);\n  }\n  for (i = 0, n = f.length; i < n; ++i) {\n    name = Forces + i;\n    p = init || _.modified(Forces, i) ? getForce(f[i]) : pulse && modified(f[i], pulse) ? sim.force(name) : null;\n    if (p) sim.force(name, p);\n  }\n  for (n = sim.numForces || 0; i < n; ++i) {\n    sim.force(Forces + i, null); // remove\n  }\n\n  sim.numForces = f.length;\n  return sim;\n}\nfunction modified(f, pulse) {\n  var k, v;\n  for (k in f) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(v = f[k]) && pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorFields)(v))) return 1;\n  }\n  return 0;\n}\nfunction getForce(_) {\n  var f, p;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.hasOwnProperty)(ForceMap, _.force)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Unrecognized force: ' + _.force);\n  }\n  f = ForceMap[_.force]();\n  for (p in _) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(f[p])) setForceParam(f[p], _[p], _);\n  }\n  return f;\n}\nfunction setForceParam(f, v, _) {\n  f((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(v) ? d => v(d, _) : v);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-force/build/vega-force.module.js?");

/***/ }),

/***/ "../../node_modules/vega-format/build/vega-format.module.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-format/build/vega-format.module.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   defaultLocale: () => (/* binding */ defaultLocale),\n/* harmony export */   locale: () => (/* binding */ locale),\n/* harmony export */   numberFormatDefaultLocale: () => (/* binding */ numberFormatDefaultLocale),\n/* harmony export */   numberFormatLocale: () => (/* binding */ numberFormatLocale),\n/* harmony export */   resetDefaultLocale: () => (/* binding */ resetDefaultLocale),\n/* harmony export */   resetNumberFormatDefaultLocale: () => (/* binding */ resetNumberFormatDefaultLocale),\n/* harmony export */   resetTimeFormatDefaultLocale: () => (/* binding */ resetTimeFormatDefaultLocale),\n/* harmony export */   timeFormatDefaultLocale: () => (/* binding */ timeFormatDefaultLocale),\n/* harmony export */   timeFormatLocale: () => (/* binding */ timeFormatLocale)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/formatSpecifier.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionPrefix.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionRound.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionFixed.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/defaultLocale.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/locale.js\");\n/* harmony import */ var vega_time__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-time */ \"../../node_modules/vega-time/build/vega-time.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_time_format__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-time-format */ \"../../node_modules/d3-time-format/src/defaultLocale.js\");\n/* harmony import */ var d3_time_format__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-time-format */ \"../../node_modules/d3-time-format/src/locale.js\");\n\n\n\n\n\n\nfunction memoize (method) {\n  const cache = {};\n  return spec => cache[spec] || (cache[spec] = method(spec));\n}\n\nfunction trimZeroes(numberFormat, decimalChar) {\n  return x => {\n    const str = numberFormat(x),\n      dec = str.indexOf(decimalChar);\n    if (dec < 0) return str;\n    let idx = rightmostDigit(str, dec);\n    const end = idx < str.length ? str.slice(idx) : '';\n    while (--idx > dec) if (str[idx] !== '0') {\n      ++idx;\n      break;\n    }\n    return str.slice(0, idx) + end;\n  };\n}\nfunction rightmostDigit(str, dec) {\n  let i = str.lastIndexOf('e'),\n    c;\n  if (i > 0) return i;\n  for (i = str.length; --i > dec;) {\n    c = str.charCodeAt(i);\n    if (c >= 48 && c <= 57) return i + 1; // is digit\n  }\n}\n\nfunction numberLocale(locale) {\n  const format = memoize(locale.format),\n    formatPrefix = locale.formatPrefix;\n  return {\n    format,\n    formatPrefix,\n    formatFloat(spec) {\n      const s = (0,d3_format__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(spec || ',');\n      if (s.precision == null) {\n        s.precision = 12;\n        switch (s.type) {\n          case '%':\n            s.precision -= 2;\n            break;\n          case 'e':\n            s.precision -= 1;\n            break;\n        }\n        return trimZeroes(format(s),\n        // number format\n        format('.1f')(1)[1] // decimal point character\n        );\n      } else {\n        return format(s);\n      }\n    },\n    formatSpan(start, stop, count, specifier) {\n      specifier = (0,d3_format__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(specifier == null ? ',f' : specifier);\n      const step = (0,d3_array__WEBPACK_IMPORTED_MODULE_3__.tickStep)(start, stop, count),\n        value = Math.max(Math.abs(start), Math.abs(stop));\n      let precision;\n      if (specifier.precision == null) {\n        switch (specifier.type) {\n          case 's':\n            {\n              if (!isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(step, value))) {\n                specifier.precision = precision;\n              }\n              return formatPrefix(specifier, value);\n            }\n          case '':\n          case 'e':\n          case 'g':\n          case 'p':\n          case 'r':\n            {\n              if (!isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(step, value))) {\n                specifier.precision = precision - (specifier.type === 'e');\n              }\n              break;\n            }\n          case 'f':\n          case '%':\n            {\n              if (!isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(step))) {\n                specifier.precision = precision - (specifier.type === '%') * 2;\n              }\n              break;\n            }\n        }\n      }\n      return format(specifier);\n    }\n  };\n}\nlet defaultNumberLocale;\nresetNumberFormatDefaultLocale();\nfunction resetNumberFormatDefaultLocale() {\n  return defaultNumberLocale = numberLocale({\n    format: d3_format__WEBPACK_IMPORTED_MODULE_7__.format,\n    formatPrefix: d3_format__WEBPACK_IMPORTED_MODULE_7__.formatPrefix\n  });\n}\nfunction numberFormatLocale(definition) {\n  return numberLocale((0,d3_format__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(definition));\n}\nfunction numberFormatDefaultLocale(definition) {\n  return arguments.length ? defaultNumberLocale = numberFormatLocale(definition) : defaultNumberLocale;\n}\n\nfunction timeMultiFormat(format, interval, spec) {\n  spec = spec || {};\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(spec)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)(`Invalid time multi-format specifier: ${spec}`);\n  }\n  const second = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.SECONDS),\n    minute = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.MINUTES),\n    hour = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.HOURS),\n    day = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.DATE),\n    week = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.WEEK),\n    month = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.MONTH),\n    quarter = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.QUARTER),\n    year = interval(vega_time__WEBPACK_IMPORTED_MODULE_0__.YEAR),\n    L = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.MILLISECONDS] || '.%L'),\n    S = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.SECONDS] || ':%S'),\n    M = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.MINUTES] || '%I:%M'),\n    H = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.HOURS] || '%I %p'),\n    d = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.DATE] || spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.DAY] || '%a %d'),\n    w = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.WEEK] || '%b %d'),\n    m = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.MONTH] || '%B'),\n    q = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.QUARTER] || '%B'),\n    y = format(spec[vega_time__WEBPACK_IMPORTED_MODULE_0__.YEAR] || '%Y');\n  return date => (second(date) < date ? L : minute(date) < date ? S : hour(date) < date ? M : day(date) < date ? H : month(date) < date ? week(date) < date ? d : w : year(date) < date ? quarter(date) < date ? m : q : y)(date);\n}\nfunction timeLocale(locale) {\n  const timeFormat = memoize(locale.format),\n    utcFormat = memoize(locale.utcFormat);\n  return {\n    timeFormat: spec => (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(spec) ? timeFormat(spec) : timeMultiFormat(timeFormat, vega_time__WEBPACK_IMPORTED_MODULE_0__.timeInterval, spec),\n    utcFormat: spec => (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(spec) ? utcFormat(spec) : timeMultiFormat(utcFormat, vega_time__WEBPACK_IMPORTED_MODULE_0__.utcInterval, spec),\n    timeParse: memoize(locale.parse),\n    utcParse: memoize(locale.utcParse)\n  };\n}\nlet defaultTimeLocale;\nresetTimeFormatDefaultLocale();\nfunction resetTimeFormatDefaultLocale() {\n  return defaultTimeLocale = timeLocale({\n    format: d3_time_format__WEBPACK_IMPORTED_MODULE_9__.timeFormat,\n    parse: d3_time_format__WEBPACK_IMPORTED_MODULE_9__.timeParse,\n    utcFormat: d3_time_format__WEBPACK_IMPORTED_MODULE_9__.utcFormat,\n    utcParse: d3_time_format__WEBPACK_IMPORTED_MODULE_9__.utcParse\n  });\n}\nfunction timeFormatLocale(definition) {\n  return timeLocale((0,d3_time_format__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(definition));\n}\nfunction timeFormatDefaultLocale(definition) {\n  return arguments.length ? defaultTimeLocale = timeFormatLocale(definition) : defaultTimeLocale;\n}\n\nconst createLocale = (number, time) => (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.extend)({}, number, time);\nfunction locale(numberSpec, timeSpec) {\n  const number = numberSpec ? numberFormatLocale(numberSpec) : numberFormatDefaultLocale();\n  const time = timeSpec ? timeFormatLocale(timeSpec) : timeFormatDefaultLocale();\n  return createLocale(number, time);\n}\nfunction defaultLocale(numberSpec, timeSpec) {\n  const args = arguments.length;\n  if (args && args !== 2) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('defaultLocale expects either zero or two arguments.');\n  }\n  return args ? createLocale(numberFormatDefaultLocale(numberSpec), timeFormatDefaultLocale(timeSpec)) : createLocale(numberFormatDefaultLocale(), timeFormatDefaultLocale());\n}\nfunction resetDefaultLocale() {\n  resetNumberFormatDefaultLocale();\n  resetTimeFormatDefaultLocale();\n  return defaultLocale();\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-format/build/vega-format.module.js?");

/***/ }),

/***/ "../../node_modules/vega-functions/build/vega-functions.module.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-functions/build/vega-functions.module.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DataPrefix: () => (/* binding */ DataPrefix),\n/* harmony export */   IndexPrefix: () => (/* binding */ IndexPrefix),\n/* harmony export */   ScalePrefix: () => (/* binding */ ScalePrefix),\n/* harmony export */   SignalPrefix: () => (/* binding */ SignalPrefix),\n/* harmony export */   bandspace: () => (/* binding */ bandspace),\n/* harmony export */   bandwidth: () => (/* binding */ bandwidth),\n/* harmony export */   codeGenerator: () => (/* binding */ codeGenerator),\n/* harmony export */   codegenParams: () => (/* binding */ codegenParams),\n/* harmony export */   containerSize: () => (/* binding */ containerSize),\n/* harmony export */   contrast: () => (/* binding */ contrast),\n/* harmony export */   copy: () => (/* binding */ copy),\n/* harmony export */   data: () => (/* binding */ data),\n/* harmony export */   dataVisitor: () => (/* binding */ dataVisitor),\n/* harmony export */   dayAbbrevFormat: () => (/* binding */ dayAbbrevFormat),\n/* harmony export */   dayFormat: () => (/* binding */ dayFormat),\n/* harmony export */   debug: () => (/* binding */ debug),\n/* harmony export */   domain: () => (/* binding */ domain),\n/* harmony export */   encode: () => (/* binding */ encode),\n/* harmony export */   expressionFunction: () => (/* binding */ expressionFunction),\n/* harmony export */   format: () => (/* binding */ format),\n/* harmony export */   functionContext: () => (/* binding */ functionContext),\n/* harmony export */   geoArea: () => (/* binding */ geoArea),\n/* harmony export */   geoBounds: () => (/* binding */ geoBounds),\n/* harmony export */   geoCentroid: () => (/* binding */ geoCentroid),\n/* harmony export */   geoShape: () => (/* binding */ geoShape),\n/* harmony export */   inScope: () => (/* binding */ inScope),\n/* harmony export */   indata: () => (/* binding */ indata),\n/* harmony export */   indataVisitor: () => (/* binding */ indataVisitor),\n/* harmony export */   indexof: () => (/* binding */ indexof),\n/* harmony export */   info: () => (/* binding */ info),\n/* harmony export */   invert: () => (/* binding */ invert),\n/* harmony export */   join: () => (/* binding */ join),\n/* harmony export */   lastindexof: () => (/* binding */ lastindexof),\n/* harmony export */   luminance: () => (/* binding */ luminance),\n/* harmony export */   merge: () => (/* binding */ merge),\n/* harmony export */   modify: () => (/* binding */ modify),\n/* harmony export */   monthAbbrevFormat: () => (/* binding */ monthAbbrevFormat),\n/* harmony export */   monthFormat: () => (/* binding */ monthFormat),\n/* harmony export */   parseExpression: () => (/* binding */ parser),\n/* harmony export */   pathShape: () => (/* binding */ pathShape),\n/* harmony export */   pinchAngle: () => (/* binding */ pinchAngle),\n/* harmony export */   pinchDistance: () => (/* binding */ pinchDistance),\n/* harmony export */   pluck: () => (/* binding */ pluck),\n/* harmony export */   range: () => (/* binding */ range),\n/* harmony export */   replace: () => (/* binding */ replace),\n/* harmony export */   reverse: () => (/* binding */ reverse),\n/* harmony export */   scale: () => (/* binding */ scale),\n/* harmony export */   scaleGradient: () => (/* binding */ scaleGradient),\n/* harmony export */   scaleVisitor: () => (/* binding */ scaleVisitor),\n/* harmony export */   screen: () => (/* binding */ screen),\n/* harmony export */   setdata: () => (/* binding */ setdata),\n/* harmony export */   slice: () => (/* binding */ slice),\n/* harmony export */   timeFormat: () => (/* binding */ timeFormat),\n/* harmony export */   timeParse: () => (/* binding */ timeParse),\n/* harmony export */   treeAncestors: () => (/* binding */ treeAncestors),\n/* harmony export */   treePath: () => (/* binding */ treePath),\n/* harmony export */   utcFormat: () => (/* binding */ utcFormat),\n/* harmony export */   utcParse: () => (/* binding */ utcParse),\n/* harmony export */   warn: () => (/* binding */ warn),\n/* harmony export */   windowSize: () => (/* binding */ windowSize)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_expression__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-expression */ \"../../node_modules/vega-expression/build/vega-expression.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/area.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/bounds.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/centroid.js\");\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/lab.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-scenegraph */ \"../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js\");\n/* harmony import */ var vega_selections__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! vega-selections */ \"../../node_modules/vega-selections/build/vega-selection.module.js\");\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n/* harmony import */ var vega_time__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! vega-time */ \"../../node_modules/vega-time/build/vega-time.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n\n\n\n\n\n\n\n\n\n\n\n\nfunction data(name) {\n  const data = this.context.data[name];\n  return data ? data.values.value : [];\n}\nfunction indata(name, field, value) {\n  const index = this.context.data[name]['index:' + field],\n    entry = index ? index.value.get(value) : undefined;\n  return entry ? entry.count : entry;\n}\nfunction setdata(name, tuples) {\n  const df = this.context.dataflow,\n    data = this.context.data[name],\n    input = data.input;\n  df.pulse(input, df.changeset().remove(vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy).insert(tuples));\n  return 1;\n}\n\nfunction encode (item, name, retval) {\n  if (item) {\n    const df = this.context.dataflow,\n      target = item.mark.source;\n    df.pulse(target, df.changeset().encode(item, name));\n  }\n  return retval !== undefined ? retval : item;\n}\n\nconst wrap = method => function (value, spec) {\n  const locale = this.context.dataflow.locale();\n  return locale[method](spec)(value);\n};\nconst format = wrap('format');\nconst timeFormat = wrap('timeFormat');\nconst utcFormat = wrap('utcFormat');\nconst timeParse = wrap('timeParse');\nconst utcParse = wrap('utcParse');\nconst dateObj = new Date(2000, 0, 1);\nfunction time(month, day, specifier) {\n  if (!Number.isInteger(month) || !Number.isInteger(day)) return '';\n  dateObj.setYear(2000);\n  dateObj.setMonth(month);\n  dateObj.setDate(day);\n  return timeFormat.call(this, dateObj, specifier);\n}\nfunction monthFormat(month) {\n  return time.call(this, month, 1, '%B');\n}\nfunction monthAbbrevFormat(month) {\n  return time.call(this, month, 1, '%b');\n}\nfunction dayFormat(day) {\n  return time.call(this, 0, 2 + day, '%A');\n}\nfunction dayAbbrevFormat(day) {\n  return time.call(this, 0, 2 + day, '%a');\n}\n\nconst DataPrefix = ':';\nconst IndexPrefix = '@';\nconst ScalePrefix = '%';\nconst SignalPrefix = '$';\n\nfunction dataVisitor(name, args, scope, params) {\n  if (args[0].type !== vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('First argument to data functions must be a string literal.');\n  }\n  const data = args[0].value,\n    dataName = DataPrefix + data;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(dataName, params)) {\n    try {\n      params[dataName] = scope.getData(data).tuplesRef();\n    } catch (err) {\n      // if data set does not exist, there's nothing to track\n    }\n  }\n}\nfunction indataVisitor(name, args, scope, params) {\n  if (args[0].type !== vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('First argument to indata must be a string literal.');\n  if (args[1].type !== vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Second argument to indata must be a string literal.');\n  const data = args[0].value,\n    field = args[1].value,\n    indexName = IndexPrefix + field;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(indexName, params)) {\n    params[indexName] = scope.getData(data).indataRef(scope, field);\n  }\n}\nfunction scaleVisitor(name, args, scope, params) {\n  if (args[0].type === vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal) {\n    // add scale dependency\n    addScaleDependency(scope, params, args[0].value);\n  } else {\n    // indirect scale lookup; add all scales as parameters\n    for (name in scope.scales) {\n      addScaleDependency(scope, params, name);\n    }\n  }\n}\nfunction addScaleDependency(scope, params, name) {\n  const scaleName = ScalePrefix + name;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(params, scaleName)) {\n    try {\n      params[scaleName] = scope.scaleRef(name);\n    } catch (err) {\n      // TODO: error handling? warning?\n    }\n  }\n}\n\nfunction getScale(nameOrFunction, ctx) {\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(nameOrFunction)) {\n    return nameOrFunction;\n  }\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(nameOrFunction)) {\n    const maybeScale = ctx.scales[nameOrFunction];\n    return maybeScale && (0,vega_scale__WEBPACK_IMPORTED_MODULE_2__.isRegisteredScale)(maybeScale.value) ? maybeScale.value : undefined;\n  }\n  return undefined;\n}\nfunction internalScaleFunctions(codegen, fnctx, visitors) {\n  // add helper method to the 'this' expression function context\n  fnctx.__bandwidth = s => s && s.bandwidth ? s.bandwidth() : 0;\n\n  // register AST visitors for internal scale functions\n  visitors._bandwidth = scaleVisitor;\n  visitors._range = scaleVisitor;\n  visitors._scale = scaleVisitor;\n\n  // resolve scale reference directly to the signal hash argument\n  const ref = arg => '_[' + (arg.type === vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(ScalePrefix + arg.value) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(ScalePrefix) + '+' + codegen(arg)) + ']';\n\n  // define and return internal scale function code generators\n  // these internal functions are called by mark encoders\n  return {\n    _bandwidth: args => `this.__bandwidth(${ref(args[0])})`,\n    _range: args => `${ref(args[0])}.range()`,\n    _scale: args => `${ref(args[0])}(${codegen(args[1])})`\n  };\n}\n\nfunction geoMethod(methodName, globalMethod) {\n  return function (projection, geojson, group) {\n    if (projection) {\n      // projection defined, use it\n      const p = getScale(projection, (group || this).context);\n      return p && p.path[methodName](geojson);\n    } else {\n      // projection undefined, use global method\n      return globalMethod(geojson);\n    }\n  };\n}\nconst geoArea = geoMethod('area', d3_geo__WEBPACK_IMPORTED_MODULE_8__[\"default\"]);\nconst geoBounds = geoMethod('bounds', d3_geo__WEBPACK_IMPORTED_MODULE_9__[\"default\"]);\nconst geoCentroid = geoMethod('centroid', d3_geo__WEBPACK_IMPORTED_MODULE_10__[\"default\"]);\n\nfunction inScope (item) {\n  const group = this.context.group;\n  let value = false;\n  if (group) while (item) {\n    if (item === group) {\n      value = true;\n      break;\n    }\n    item = item.mark.group;\n  }\n  return value;\n}\n\nfunction log(df, method, args) {\n  try {\n    df[method].apply(df, ['EXPRESSION'].concat([].slice.call(args)));\n  } catch (err) {\n    df.warn(err);\n  }\n  return args[args.length - 1];\n}\nfunction warn() {\n  return log(this.context.dataflow, 'warn', arguments);\n}\nfunction info() {\n  return log(this.context.dataflow, 'info', arguments);\n}\nfunction debug() {\n  return log(this.context.dataflow, 'debug', arguments);\n}\n\n// https://www.w3.org/TR/2008/REC-WCAG20-20081211/#relativeluminancedef\nfunction channel_luminance_value(channelValue) {\n  const val = channelValue / 255;\n  if (val <= 0.03928) {\n    return val / 12.92;\n  }\n  return Math.pow((val + 0.055) / 1.055, 2.4);\n}\nfunction luminance(color) {\n  const c = (0,d3_color__WEBPACK_IMPORTED_MODULE_11__.rgb)(color),\n    r = channel_luminance_value(c.r),\n    g = channel_luminance_value(c.g),\n    b = channel_luminance_value(c.b);\n  return 0.2126 * r + 0.7152 * g + 0.0722 * b;\n}\n\n// https://www.w3.org/TR/2008/REC-WCAG20-20081211/#contrast-ratiodef\nfunction contrast(color1, color2) {\n  const lum1 = luminance(color1),\n    lum2 = luminance(color2),\n    lumL = Math.max(lum1, lum2),\n    lumD = Math.min(lum1, lum2);\n  return (lumL + 0.05) / (lumD + 0.05);\n}\n\nfunction merge () {\n  const args = [].slice.call(arguments);\n  args.unshift({});\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(...args);\n}\n\nfunction equal(a, b) {\n  return a === b || a !== a && b !== b ? true : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(a) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(b) && a.length === b.length ? equalArray(a, b) : false : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(a) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(b) ? equalObject(a, b) : false;\n}\nfunction equalArray(a, b) {\n  for (let i = 0, n = a.length; i < n; ++i) {\n    if (!equal(a[i], b[i])) return false;\n  }\n  return true;\n}\nfunction equalObject(a, b) {\n  for (const key in a) {\n    if (!equal(a[key], b[key])) return false;\n  }\n  return true;\n}\nfunction removePredicate(props) {\n  return _ => equalObject(props, _);\n}\nfunction modify (name, insert, remove, toggle, modify, values) {\n  const df = this.context.dataflow,\n    data = this.context.data[name],\n    input = data.input,\n    stamp = df.stamp();\n  let changes = data.changes,\n    predicate,\n    key;\n  if (df._trigger === false || !(input.value.length || insert || toggle)) {\n    // nothing to do!\n    return 0;\n  }\n  if (!changes || changes.stamp < stamp) {\n    data.changes = changes = df.changeset();\n    changes.stamp = stamp;\n    df.runAfter(() => {\n      data.modified = true;\n      df.pulse(input, changes).run();\n    }, true, 1);\n  }\n  if (remove) {\n    predicate = remove === true ? vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(remove) || (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_3__.isTuple)(remove) ? remove : removePredicate(remove);\n    changes.remove(predicate);\n  }\n  if (insert) {\n    changes.insert(insert);\n  }\n  if (toggle) {\n    predicate = removePredicate(toggle);\n    if (input.value.some(predicate)) {\n      changes.remove(predicate);\n    } else {\n      changes.insert(toggle);\n    }\n  }\n  if (modify) {\n    for (key in values) {\n      changes.modify(modify, key, values[key]);\n    }\n  }\n  return 1;\n}\n\nfunction pinchDistance(event) {\n  const t = event.touches,\n    dx = t[0].clientX - t[1].clientX,\n    dy = t[0].clientY - t[1].clientY;\n  return Math.hypot(dx, dy);\n}\nfunction pinchAngle(event) {\n  const t = event.touches;\n  return Math.atan2(t[0].clientY - t[1].clientY, t[0].clientX - t[1].clientX);\n}\n\n// memoize accessor functions\nconst accessors = {};\nfunction pluck (data, name) {\n  const accessor = accessors[name] || (accessors[name] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(name));\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(data) ? data.map(accessor) : accessor(data);\n}\n\nfunction array(seq) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(seq) || ArrayBuffer.isView(seq) ? seq : null;\n}\nfunction sequence(seq) {\n  return array(seq) || ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(seq) ? seq : null);\n}\nfunction join(seq) {\n  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n    args[_key - 1] = arguments[_key];\n  }\n  return array(seq).join(...args);\n}\nfunction indexof(seq) {\n  for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {\n    args[_key2 - 1] = arguments[_key2];\n  }\n  return sequence(seq).indexOf(...args);\n}\nfunction lastindexof(seq) {\n  for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {\n    args[_key3 - 1] = arguments[_key3];\n  }\n  return sequence(seq).lastIndexOf(...args);\n}\nfunction slice(seq) {\n  for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {\n    args[_key4 - 1] = arguments[_key4];\n  }\n  return sequence(seq).slice(...args);\n}\nfunction replace(str, pattern, repl) {\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(repl)) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Function argument passed to replace.');\n  return String(str).replace(pattern, repl);\n}\nfunction reverse(seq) {\n  return array(seq).slice().reverse();\n}\n\nfunction bandspace(count, paddingInner, paddingOuter) {\n  return (0,vega_scale__WEBPACK_IMPORTED_MODULE_2__.bandSpace)(count || 0, paddingInner || 0, paddingOuter || 0);\n}\nfunction bandwidth(name, group) {\n  const s = getScale(name, (group || this).context);\n  return s && s.bandwidth ? s.bandwidth() : 0;\n}\nfunction copy(name, group) {\n  const s = getScale(name, (group || this).context);\n  return s ? s.copy() : undefined;\n}\nfunction domain(name, group) {\n  const s = getScale(name, (group || this).context);\n  return s ? s.domain() : [];\n}\nfunction invert(name, range, group) {\n  const s = getScale(name, (group || this).context);\n  return !s ? undefined : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range) ? (s.invertRange || s.invert)(range) : (s.invert || s.invertExtent)(range);\n}\nfunction range(name, group) {\n  const s = getScale(name, (group || this).context);\n  return s && s.range ? s.range() : [];\n}\nfunction scale(name, value, group) {\n  const s = getScale(name, (group || this).context);\n  return s ? s(value) : undefined;\n}\n\nfunction scaleGradient (scale, p0, p1, count, group) {\n  scale = getScale(scale, (group || this).context);\n  const gradient = (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.Gradient)(p0, p1);\n  let stops = scale.domain(),\n    min = stops[0],\n    max = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(stops),\n    fraction = vega_util__WEBPACK_IMPORTED_MODULE_0__.identity;\n  if (!(max - min)) {\n    // expand scale if domain has zero span, fix #1479\n    scale = (scale.interpolator ? (0,vega_scale__WEBPACK_IMPORTED_MODULE_2__.scale)('sequential')().interpolator(scale.interpolator()) : (0,vega_scale__WEBPACK_IMPORTED_MODULE_2__.scale)('linear')().interpolate(scale.interpolate()).range(scale.range())).domain([min = 0, max = 1]);\n  } else {\n    fraction = (0,vega_scale__WEBPACK_IMPORTED_MODULE_2__.scaleFraction)(scale, min, max);\n  }\n  if (scale.ticks) {\n    stops = scale.ticks(+count || 15);\n    if (min !== stops[0]) stops.unshift(min);\n    if (max !== (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(stops)) stops.push(max);\n  }\n  stops.forEach(_ => gradient.stop(fraction(_), scale(_)));\n  return gradient;\n}\n\nfunction geoShape(projection, geojson, group) {\n  const p = getScale(projection, (group || this).context);\n  return function (context) {\n    return p ? p.path.context(context)(geojson) : '';\n  };\n}\nfunction pathShape(path) {\n  let p = null;\n  return function (context) {\n    return context ? (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.pathRender)(context, p = p || (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.pathParse)(path)) : path;\n  };\n}\n\nconst datum = d => d.data;\nfunction treeNodes(name, context) {\n  const tree = data.call(context, name);\n  return tree.root && tree.root.lookup || {};\n}\nfunction treePath(name, source, target) {\n  const nodes = treeNodes(name, this),\n    s = nodes[source],\n    t = nodes[target];\n  return s && t ? s.path(t).map(datum) : undefined;\n}\nfunction treeAncestors(name, node) {\n  const n = treeNodes(name, this)[node];\n  return n ? n.ancestors().map(datum) : undefined;\n}\n\nconst _window = () => typeof window !== 'undefined' && window || null;\nfunction screen() {\n  const w = _window();\n  return w ? w.screen : {};\n}\nfunction windowSize() {\n  const w = _window();\n  return w ? [w.innerWidth, w.innerHeight] : [undefined, undefined];\n}\nfunction containerSize() {\n  const view = this.context.dataflow,\n    el = view.container && view.container();\n  return el ? [el.clientWidth, el.clientHeight] : [undefined, undefined];\n}\n\nfunction intersect (b, opt, group) {\n  if (!b) return [];\n  const [u, v] = b,\n    box = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.Bounds().set(u[0], u[1], v[0], v[1]),\n    scene = group || this.context.dataflow.scenegraph().root;\n  return (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.intersect)(scene, box, filter(opt));\n}\nfunction filter(opt) {\n  let p = null;\n  if (opt) {\n    const types = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(opt.marktype),\n      names = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(opt.markname);\n    p = _ => (!types.length || types.some(t => _.marktype === t)) && (!names.length || names.some(s => _.name === s));\n  }\n  return p;\n}\n\n/**\n * Appends a new point to the lasso\n *\n * @param {*} lasso the lasso in pixel space\n * @param {*} x the x coordinate in pixel space\n * @param {*} y the y coordinate in pixel space\n * @param {*} minDist the minimum distance, in pixels, that thenew point needs to be apart from the last point\n * @returns a new array containing the lasso with the new point\n */\nfunction lassoAppend(lasso, x, y) {\n  let minDist = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 5;\n  lasso = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(lasso);\n  const last = lasso[lasso.length - 1];\n\n  // Add point to lasso if its the first point or distance to last point exceed minDist\n  return last === undefined || Math.hypot(last[0] - x, last[1] - y) > minDist ? [...lasso, [x, y]] : lasso;\n}\n\n/**\n * Generates a svg path command which draws a lasso\n *\n * @param {*} lasso the lasso in pixel space in the form [[x,y], [x,y], ...]\n * @returns the svg path command that draws the lasso\n */\nfunction lassoPath(lasso) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(lasso).reduce((svg, _ref, i) => {\n    let [x, y] = _ref;\n    return svg += i == 0 ? `M ${x},${y} ` : i === lasso.length - 1 ? ' Z' : `L ${x},${y} `;\n  }, '');\n}\n\n/**\n * Inverts the lasso from pixel space to an array of vega scenegraph tuples\n *\n * @param {*} data the dataset\n * @param {*} pixelLasso the lasso in pixel space, [[x,y], [x,y], ...]\n * @param {*} unit the unit where the lasso is defined\n *\n * @returns an array of vega scenegraph tuples\n */\nfunction intersectLasso(markname, pixelLasso, unit) {\n  const {\n    x,\n    y,\n    mark\n  } = unit;\n  const bb = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_4__.Bounds().set(Number.MAX_SAFE_INTEGER, Number.MAX_SAFE_INTEGER, Number.MIN_SAFE_INTEGER, Number.MIN_SAFE_INTEGER);\n\n  // Get bounding box around lasso\n  for (const [px, py] of pixelLasso) {\n    if (px < bb.x1) bb.x1 = px;\n    if (px > bb.x2) bb.x2 = px;\n    if (py < bb.y1) bb.y1 = py;\n    if (py > bb.y2) bb.y2 = py;\n  }\n\n  // Translate bb against unit coordinates\n  bb.translate(x, y);\n  const intersection = intersect([[bb.x1, bb.y1], [bb.x2, bb.y2]], markname, mark);\n\n  // Check every point against the lasso\n  return intersection.filter(tuple => pointInPolygon(tuple.x, tuple.y, pixelLasso));\n}\n\n/**\n * Performs a test if a point is inside a polygon based on the idea from\n * https://wrf.ecse.rpi.edu/Research/Short_Notes/pnpoly.html\n *\n * This method will not need the same start/end point since it wraps around the edges of the array\n *\n * @param {*} test a point to test against\n * @param {*} polygon a polygon in the form [[x,y], [x,y], ...]\n * @returns true if the point lies inside the polygon, false otherwise\n */\nfunction pointInPolygon(testx, testy, polygon) {\n  let intersections = 0;\n  for (let i = 0, j = polygon.length - 1; i < polygon.length; j = i++) {\n    const [prevX, prevY] = polygon[j];\n    const [x, y] = polygon[i];\n\n    // count intersections\n    if (y > testy != prevY > testy && testx < (prevX - x) * (testy - y) / (prevY - y) + x) {\n      intersections++;\n    }\n  }\n\n  // point is in polygon if intersection count is odd\n  return intersections & 1;\n}\n\n// Expression function context object\nconst functionContext = {\n  random() {\n    return (0,vega_statistics__WEBPACK_IMPORTED_MODULE_6__.random)();\n  },\n  // override default\n  cumulativeNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.cumulativeNormal,\n  cumulativeLogNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.cumulativeLogNormal,\n  cumulativeUniform: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.cumulativeUniform,\n  densityNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.densityNormal,\n  densityLogNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.densityLogNormal,\n  densityUniform: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.densityUniform,\n  quantileNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.quantileNormal,\n  quantileLogNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.quantileLogNormal,\n  quantileUniform: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.quantileUniform,\n  sampleNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.sampleNormal,\n  sampleLogNormal: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.sampleLogNormal,\n  sampleUniform: vega_statistics__WEBPACK_IMPORTED_MODULE_6__.sampleUniform,\n  isArray: vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray,\n  isBoolean: vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean,\n  isDate: vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate,\n  isDefined(_) {\n    return _ !== undefined;\n  },\n  isNumber: vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber,\n  isObject: vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject,\n  isRegExp: vega_util__WEBPACK_IMPORTED_MODULE_0__.isRegExp,\n  isString: vega_util__WEBPACK_IMPORTED_MODULE_0__.isString,\n  isTuple: vega_dataflow__WEBPACK_IMPORTED_MODULE_3__.isTuple,\n  isValid(_) {\n    return _ != null && _ === _;\n  },\n  toBoolean: vega_util__WEBPACK_IMPORTED_MODULE_0__.toBoolean,\n  toDate(_) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toDate)(_);\n  },\n  // suppress extra arguments\n  toNumber: vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber,\n  toString: vega_util__WEBPACK_IMPORTED_MODULE_0__.toString,\n  indexof,\n  join,\n  lastindexof,\n  replace,\n  reverse,\n  slice,\n  flush: vega_util__WEBPACK_IMPORTED_MODULE_0__.flush,\n  lerp: vega_util__WEBPACK_IMPORTED_MODULE_0__.lerp,\n  merge,\n  pad: vega_util__WEBPACK_IMPORTED_MODULE_0__.pad,\n  peek: vega_util__WEBPACK_IMPORTED_MODULE_0__.peek,\n  pluck,\n  span: vega_util__WEBPACK_IMPORTED_MODULE_0__.span,\n  inrange: vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange,\n  truncate: vega_util__WEBPACK_IMPORTED_MODULE_0__.truncate,\n  rgb: d3_color__WEBPACK_IMPORTED_MODULE_11__.rgb,\n  lab: d3_color__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n  hcl: d3_color__WEBPACK_IMPORTED_MODULE_12__.hcl,\n  hsl: d3_color__WEBPACK_IMPORTED_MODULE_11__.hsl,\n  luminance,\n  contrast,\n  sequence: d3_array__WEBPACK_IMPORTED_MODULE_13__[\"default\"],\n  format,\n  utcFormat,\n  utcParse,\n  utcOffset: vega_time__WEBPACK_IMPORTED_MODULE_7__.utcOffset,\n  utcSequence: vega_time__WEBPACK_IMPORTED_MODULE_7__.utcSequence,\n  timeFormat,\n  timeParse,\n  timeOffset: vega_time__WEBPACK_IMPORTED_MODULE_7__.timeOffset,\n  timeSequence: vega_time__WEBPACK_IMPORTED_MODULE_7__.timeSequence,\n  timeUnitSpecifier: vega_time__WEBPACK_IMPORTED_MODULE_7__.timeUnitSpecifier,\n  monthFormat,\n  monthAbbrevFormat,\n  dayFormat,\n  dayAbbrevFormat,\n  quarter: vega_util__WEBPACK_IMPORTED_MODULE_0__.quarter,\n  utcquarter: vega_util__WEBPACK_IMPORTED_MODULE_0__.utcquarter,\n  week: vega_time__WEBPACK_IMPORTED_MODULE_7__.week,\n  utcweek: vega_time__WEBPACK_IMPORTED_MODULE_7__.utcweek,\n  dayofyear: vega_time__WEBPACK_IMPORTED_MODULE_7__.dayofyear,\n  utcdayofyear: vega_time__WEBPACK_IMPORTED_MODULE_7__.utcdayofyear,\n  warn,\n  info,\n  debug,\n  extent(_) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(_);\n  },\n  // suppress extra arguments\n  inScope,\n  intersect,\n  clampRange: vega_util__WEBPACK_IMPORTED_MODULE_0__.clampRange,\n  pinchDistance,\n  pinchAngle,\n  screen,\n  containerSize,\n  windowSize,\n  bandspace,\n  setdata,\n  pathShape,\n  panLinear: vega_util__WEBPACK_IMPORTED_MODULE_0__.panLinear,\n  panLog: vega_util__WEBPACK_IMPORTED_MODULE_0__.panLog,\n  panPow: vega_util__WEBPACK_IMPORTED_MODULE_0__.panPow,\n  panSymlog: vega_util__WEBPACK_IMPORTED_MODULE_0__.panSymlog,\n  zoomLinear: vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomLinear,\n  zoomLog: vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomLog,\n  zoomPow: vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomPow,\n  zoomSymlog: vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomSymlog,\n  encode,\n  modify,\n  lassoAppend,\n  lassoPath,\n  intersectLasso\n};\nconst eventFunctions = ['view', 'item', 'group', 'xy', 'x', 'y'],\n  // event functions\n  eventPrefix = 'event.vega.',\n  // event function prefix\n  thisPrefix = 'this.',\n  // function context prefix\n  astVisitors = {}; // AST visitors for dependency analysis\n\n// export code generator parameters\nconst codegenParams = {\n  forbidden: ['_'],\n  allowed: ['datum', 'event', 'item'],\n  fieldvar: 'datum',\n  globalvar: id => `_[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(SignalPrefix + id)}]`,\n  functions: buildFunctions,\n  constants: vega_expression__WEBPACK_IMPORTED_MODULE_1__.constants,\n  visitors: astVisitors\n};\n\n// export code generator\nconst codeGenerator = (0,vega_expression__WEBPACK_IMPORTED_MODULE_1__.codegenExpression)(codegenParams);\n\n// Build expression function registry\nfunction buildFunctions(codegen) {\n  const fn = (0,vega_expression__WEBPACK_IMPORTED_MODULE_1__.functions)(codegen);\n  eventFunctions.forEach(name => fn[name] = eventPrefix + name);\n  for (const name in functionContext) {\n    fn[name] = thisPrefix + name;\n  }\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(fn, internalScaleFunctions(codegen, functionContext, astVisitors));\n  return fn;\n}\n\n// Register an expression function\nfunction expressionFunction(name, fn, visitor) {\n  if (arguments.length === 1) {\n    return functionContext[name];\n  }\n\n  // register with the functionContext\n  functionContext[name] = fn;\n\n  // if there is an astVisitor register that, too\n  if (visitor) astVisitors[name] = visitor;\n\n  // if the code generator has already been initialized,\n  // we need to also register the function with it\n  if (codeGenerator) codeGenerator.functions[name] = thisPrefix + name;\n  return this;\n}\n\n// register expression functions with ast visitors\nexpressionFunction('bandwidth', bandwidth, scaleVisitor);\nexpressionFunction('copy', copy, scaleVisitor);\nexpressionFunction('domain', domain, scaleVisitor);\nexpressionFunction('range', range, scaleVisitor);\nexpressionFunction('invert', invert, scaleVisitor);\nexpressionFunction('scale', scale, scaleVisitor);\nexpressionFunction('gradient', scaleGradient, scaleVisitor);\nexpressionFunction('geoArea', geoArea, scaleVisitor);\nexpressionFunction('geoBounds', geoBounds, scaleVisitor);\nexpressionFunction('geoCentroid', geoCentroid, scaleVisitor);\nexpressionFunction('geoShape', geoShape, scaleVisitor);\nexpressionFunction('indata', indata, indataVisitor);\nexpressionFunction('data', data, dataVisitor);\nexpressionFunction('treePath', treePath, dataVisitor);\nexpressionFunction('treeAncestors', treeAncestors, dataVisitor);\n\n// register Vega-Lite selection functions\nexpressionFunction('vlSelectionTest', vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionTest, vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionVisitor);\nexpressionFunction('vlSelectionIdTest', vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionIdTest, vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionVisitor);\nexpressionFunction('vlSelectionResolve', vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionResolve, vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionVisitor);\nexpressionFunction('vlSelectionTuples', vega_selections__WEBPACK_IMPORTED_MODULE_5__.selectionTuples);\n\nfunction parser (expr, scope) {\n  const params = {};\n\n  // parse the expression to an abstract syntax tree (ast)\n  let ast;\n  try {\n    expr = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(expr) ? expr : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(expr) + '';\n    ast = (0,vega_expression__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(expr);\n  } catch (err) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Expression parse error: ' + expr);\n  }\n\n  // analyze ast function calls for dependencies\n  ast.visit(node => {\n    if (node.type !== vega_expression__WEBPACK_IMPORTED_MODULE_1__.CallExpression) return;\n    const name = node.callee.name,\n      visit = codegenParams.visitors[name];\n    if (visit) visit(name, node.arguments, scope, params);\n  });\n\n  // perform code generation\n  const gen = codeGenerator(ast);\n\n  // collect signal dependencies\n  gen.globals.forEach(name => {\n    const signalName = SignalPrefix + name;\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(params, signalName) && scope.getSignal(name)) {\n      params[signalName] = scope.signalRef(name);\n    }\n  });\n\n  // return generated expression code and dependencies\n  return {\n    $expr: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n      code: gen.code\n    }, scope.options.ast ? {\n      ast\n    } : null),\n    $fields: gen.fields,\n    $params: params\n  };\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-functions/build/vega-functions.module.js?");

/***/ }),

/***/ "../../node_modules/vega-geo/build/vega-geo.module.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-geo/build/vega-geo.module.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   contour: () => (/* binding */ Contour),\n/* harmony export */   geojson: () => (/* binding */ GeoJSON),\n/* harmony export */   geopath: () => (/* binding */ GeoPath),\n/* harmony export */   geopoint: () => (/* binding */ GeoPoint),\n/* harmony export */   geoshape: () => (/* binding */ GeoShape),\n/* harmony export */   graticule: () => (/* binding */ Graticule),\n/* harmony export */   heatmap: () => (/* binding */ Heatmap),\n/* harmony export */   isocontour: () => (/* binding */ Isocontour),\n/* harmony export */   kde2d: () => (/* binding */ KDE2D),\n/* harmony export */   projection: () => (/* binding */ Projection)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/max.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/sum.js\");\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n/* harmony import */ var vega_projection__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-projection */ \"../../node_modules/vega-projection/build/vega-projection.module.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/graticule.js\");\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var vega_canvas__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-canvas */ \"../../node_modules/vega-canvas/build/vega-canvas.browser.module.js\");\n\n\n\n\n\n\n\n\n\nfunction noop() {}\nconst cases = [[], [[[1.0, 1.5], [0.5, 1.0]]], [[[1.5, 1.0], [1.0, 1.5]]], [[[1.5, 1.0], [0.5, 1.0]]], [[[1.0, 0.5], [1.5, 1.0]]], [[[1.0, 1.5], [0.5, 1.0]], [[1.0, 0.5], [1.5, 1.0]]], [[[1.0, 0.5], [1.0, 1.5]]], [[[1.0, 0.5], [0.5, 1.0]]], [[[0.5, 1.0], [1.0, 0.5]]], [[[1.0, 1.5], [1.0, 0.5]]], [[[0.5, 1.0], [1.0, 0.5]], [[1.5, 1.0], [1.0, 1.5]]], [[[1.5, 1.0], [1.0, 0.5]]], [[[0.5, 1.0], [1.5, 1.0]]], [[[1.0, 1.5], [1.5, 1.0]]], [[[0.5, 1.0], [1.0, 1.5]]], []];\n\n// Implementation adapted from d3/d3-contour. Thanks!\nfunction contours () {\n  var dx = 1,\n    dy = 1,\n    smooth = smoothLinear;\n  function contours(values, tz) {\n    return tz.map(value => contour(values, value));\n  }\n\n  // Accumulate, smooth contour rings, assign holes to exterior rings.\n  // Based on https://github.com/mbostock/shapefile/blob/v0.6.2/shp/polygon.js\n  function contour(values, value) {\n    var polygons = [],\n      holes = [];\n    isorings(values, value, ring => {\n      smooth(ring, values, value);\n      if (area(ring) > 0) polygons.push([ring]);else holes.push(ring);\n    });\n    holes.forEach(hole => {\n      for (var i = 0, n = polygons.length, polygon; i < n; ++i) {\n        if (contains((polygon = polygons[i])[0], hole) !== -1) {\n          polygon.push(hole);\n          return;\n        }\n      }\n    });\n    return {\n      type: 'MultiPolygon',\n      value: value,\n      coordinates: polygons\n    };\n  }\n\n  // Marching squares with isolines stitched into rings.\n  // Based on https://github.com/topojson/topojson-client/blob/v3.0.0/src/stitch.js\n  function isorings(values, value, callback) {\n    var fragmentByStart = new Array(),\n      fragmentByEnd = new Array(),\n      x,\n      y,\n      t0,\n      t1,\n      t2,\n      t3;\n\n    // Special case for the first row (y = -1, t2 = t3 = 0).\n    x = y = -1;\n    t1 = values[0] >= value;\n    cases[t1 << 1].forEach(stitch);\n    while (++x < dx - 1) {\n      t0 = t1, t1 = values[x + 1] >= value;\n      cases[t0 | t1 << 1].forEach(stitch);\n    }\n    cases[t1 << 0].forEach(stitch);\n\n    // General case for the intermediate rows.\n    while (++y < dy - 1) {\n      x = -1;\n      t1 = values[y * dx + dx] >= value;\n      t2 = values[y * dx] >= value;\n      cases[t1 << 1 | t2 << 2].forEach(stitch);\n      while (++x < dx - 1) {\n        t0 = t1, t1 = values[y * dx + dx + x + 1] >= value;\n        t3 = t2, t2 = values[y * dx + x + 1] >= value;\n        cases[t0 | t1 << 1 | t2 << 2 | t3 << 3].forEach(stitch);\n      }\n      cases[t1 | t2 << 3].forEach(stitch);\n    }\n\n    // Special case for the last row (y = dy - 1, t0 = t1 = 0).\n    x = -1;\n    t2 = values[y * dx] >= value;\n    cases[t2 << 2].forEach(stitch);\n    while (++x < dx - 1) {\n      t3 = t2, t2 = values[y * dx + x + 1] >= value;\n      cases[t2 << 2 | t3 << 3].forEach(stitch);\n    }\n    cases[t2 << 3].forEach(stitch);\n    function stitch(line) {\n      var start = [line[0][0] + x, line[0][1] + y],\n        end = [line[1][0] + x, line[1][1] + y],\n        startIndex = index(start),\n        endIndex = index(end),\n        f,\n        g;\n      if (f = fragmentByEnd[startIndex]) {\n        if (g = fragmentByStart[endIndex]) {\n          delete fragmentByEnd[f.end];\n          delete fragmentByStart[g.start];\n          if (f === g) {\n            f.ring.push(end);\n            callback(f.ring);\n          } else {\n            fragmentByStart[f.start] = fragmentByEnd[g.end] = {\n              start: f.start,\n              end: g.end,\n              ring: f.ring.concat(g.ring)\n            };\n          }\n        } else {\n          delete fragmentByEnd[f.end];\n          f.ring.push(end);\n          fragmentByEnd[f.end = endIndex] = f;\n        }\n      } else if (f = fragmentByStart[endIndex]) {\n        if (g = fragmentByEnd[startIndex]) {\n          delete fragmentByStart[f.start];\n          delete fragmentByEnd[g.end];\n          if (f === g) {\n            f.ring.push(end);\n            callback(f.ring);\n          } else {\n            fragmentByStart[g.start] = fragmentByEnd[f.end] = {\n              start: g.start,\n              end: f.end,\n              ring: g.ring.concat(f.ring)\n            };\n          }\n        } else {\n          delete fragmentByStart[f.start];\n          f.ring.unshift(start);\n          fragmentByStart[f.start = startIndex] = f;\n        }\n      } else {\n        fragmentByStart[startIndex] = fragmentByEnd[endIndex] = {\n          start: startIndex,\n          end: endIndex,\n          ring: [start, end]\n        };\n      }\n    }\n  }\n  function index(point) {\n    return point[0] * 2 + point[1] * (dx + 1) * 4;\n  }\n  function smoothLinear(ring, values, value) {\n    ring.forEach(point => {\n      var x = point[0],\n        y = point[1],\n        xt = x | 0,\n        yt = y | 0,\n        v0,\n        v1 = values[yt * dx + xt];\n      if (x > 0 && x < dx && xt === x) {\n        v0 = values[yt * dx + xt - 1];\n        point[0] = x + (value - v0) / (v1 - v0) - 0.5;\n      }\n      if (y > 0 && y < dy && yt === y) {\n        v0 = values[(yt - 1) * dx + xt];\n        point[1] = y + (value - v0) / (v1 - v0) - 0.5;\n      }\n    });\n  }\n  contours.contour = contour;\n  contours.size = function (_) {\n    if (!arguments.length) return [dx, dy];\n    var _0 = Math.floor(_[0]),\n      _1 = Math.floor(_[1]);\n    if (!(_0 >= 0 && _1 >= 0)) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('invalid size');\n    return dx = _0, dy = _1, contours;\n  };\n  contours.smooth = function (_) {\n    return arguments.length ? (smooth = _ ? smoothLinear : noop, contours) : smooth === smoothLinear;\n  };\n  return contours;\n}\nfunction area(ring) {\n  var i = 0,\n    n = ring.length,\n    area = ring[n - 1][1] * ring[0][0] - ring[n - 1][0] * ring[0][1];\n  while (++i < n) area += ring[i - 1][1] * ring[i][0] - ring[i - 1][0] * ring[i][1];\n  return area;\n}\nfunction contains(ring, hole) {\n  var i = -1,\n    n = hole.length,\n    c;\n  while (++i < n) if (c = ringContains(ring, hole[i])) return c;\n  return 0;\n}\nfunction ringContains(ring, point) {\n  var x = point[0],\n    y = point[1],\n    contains = -1;\n  for (var i = 0, n = ring.length, j = n - 1; i < n; j = i++) {\n    var pi = ring[i],\n      xi = pi[0],\n      yi = pi[1],\n      pj = ring[j],\n      xj = pj[0],\n      yj = pj[1];\n    if (segmentContains(pi, pj, point)) return 0;\n    if (yi > y !== yj > y && x < (xj - xi) * (y - yi) / (yj - yi) + xi) contains = -contains;\n  }\n  return contains;\n}\nfunction segmentContains(a, b, c) {\n  var i;\n  return collinear(a, b, c) && within(a[i = +(a[0] === b[0])], c[i], b[i]);\n}\nfunction collinear(a, b, c) {\n  return (b[0] - a[0]) * (c[1] - a[1]) === (c[0] - a[0]) * (b[1] - a[1]);\n}\nfunction within(p, q, r) {\n  return p <= q && q <= r || r <= q && q <= p;\n}\n\nfunction quantize (k, nice, zero) {\n  return function (values) {\n    var ex = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.extent)(values),\n      start = zero ? Math.min(ex[0], 0) : ex[0],\n      stop = ex[1],\n      span = stop - start,\n      step = nice ? (0,d3_array__WEBPACK_IMPORTED_MODULE_5__.tickStep)(start, stop, k) : span / (k + 1);\n    return (0,d3_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(start + step, stop, step);\n  };\n}\n\n/**\n * Generate isocontours (level sets) based on input raster grid data.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} [params.field] - The field with raster grid\n *   data. If unspecified, the tuple itself is interpreted as a raster grid.\n * @param {Array<number>} [params.thresholds] - Contour threshold array. If\n *   specified, the levels, nice, resolve, and zero parameters are ignored.\n * @param {number} [params.levels] - The desired number of contour levels.\n * @param {boolean} [params.nice] - Boolean flag indicating if the contour\n *   threshold values should be automatically aligned to \"nice\"\n *   human-friendly values. Setting this flag may cause the number of\n *   thresholds to deviate from the specified levels.\n * @param {string} [params.resolve] - The method for resolving thresholds\n *   across multiple input grids. If 'independent' (the default), threshold\n *   calculation will be performed separately for each grid. If 'shared', a\n *   single set of threshold values will be used for all input grids.\n * @param {boolean} [params.zero] - Boolean flag indicating if the contour\n *   threshold values should include zero.\n * @param {boolean} [params.smooth] - Boolean flag indicating if the contour\n *   polygons should be smoothed using linear interpolation. The default is\n *   true. The parameter is ignored when using density estimation.\n * @param {boolean} [params.scale] - Optional numerical value by which to\n *   scale the output isocontour coordinates. This parameter can be useful\n *   to scale the contours to match a desired output resolution.\n * @param {string} [params.as='contour'] - The output field in which to store\n *   the generated isocontour data (default 'contour').\n */\nfunction Isocontour(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nIsocontour.Definition = {\n  'type': 'Isocontour',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'thresholds',\n    'type': 'number',\n    'array': true\n  }, {\n    'name': 'levels',\n    'type': 'number'\n  }, {\n    'name': 'nice',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'resolve',\n    'type': 'enum',\n    'values': ['shared', 'independent'],\n    'default': 'independent'\n  }, {\n    'name': 'zero',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'smooth',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'scale',\n    'type': 'number',\n    'expr': true\n  }, {\n    'name': 'translate',\n    'type': 'number',\n    'array': true,\n    'expr': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'null': true,\n    'default': 'contour'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Isocontour, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !pulse.changed() && !_.modified()) {\n      return pulse.StopPropagation;\n    }\n    var out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      source = pulse.materialize(pulse.SOURCE).source,\n      field = _.field || vega_util__WEBPACK_IMPORTED_MODULE_1__.identity,\n      contour = contours().smooth(_.smooth !== false),\n      tz = _.thresholds || levels(source, field, _),\n      as = _.as === null ? null : _.as || 'contour',\n      values = [];\n    source.forEach(t => {\n      const grid = field(t);\n\n      // generate contour paths in GeoJSON format\n      const paths = contour.size([grid.width, grid.height])(grid.values, (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isArray)(tz) ? tz : tz(grid.values));\n\n      // adjust contour path coordinates as needed\n      transformPaths(paths, grid, t, _);\n\n      // ingest; copy source data properties to output\n      paths.forEach(p => {\n        values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.rederive)(t, (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)(as != null ? {\n          [as]: p\n        } : p)));\n      });\n    });\n    if (this.value) out.rem = this.value;\n    this.value = out.source = out.add = values;\n    return out;\n  }\n});\nfunction levels(values, f, _) {\n  const q = quantize(_.levels || 10, _.nice, _.zero !== false);\n  return _.resolve !== 'shared' ? q : q(values.map(t => (0,d3_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(f(t).values)));\n}\nfunction transformPaths(paths, grid, datum, _) {\n  let s = _.scale || grid.scale,\n    t = _.translate || grid.translate;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(s)) s = s(datum, _);\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(t)) t = t(datum, _);\n  if ((s === 1 || s == null) && !t) return;\n  const sx = ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isNumber)(s) ? s : s[0]) || 1,\n    sy = ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isNumber)(s) ? s : s[1]) || 1,\n    tx = t && t[0] || 0,\n    ty = t && t[1] || 0;\n  paths.forEach(transform(grid, sx, sy, tx, ty));\n}\nfunction transform(grid, sx, sy, tx, ty) {\n  const x1 = grid.x1 || 0,\n    y1 = grid.y1 || 0,\n    flip = sx * sy < 0;\n  function transformPolygon(coordinates) {\n    coordinates.forEach(transformRing);\n  }\n  function transformRing(coordinates) {\n    if (flip) coordinates.reverse(); // maintain winding order\n    coordinates.forEach(transformPoint);\n  }\n  function transformPoint(coordinates) {\n    coordinates[0] = (coordinates[0] - x1) * sx + tx;\n    coordinates[1] = (coordinates[1] - y1) * sy + ty;\n  }\n  return function (geometry) {\n    geometry.coordinates.forEach(transformPolygon);\n    return geometry;\n  };\n}\n\nfunction radius(bw, data, f) {\n  const v = bw >= 0 ? bw : (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.bandwidthNRD)(data, f);\n  return Math.round((Math.sqrt(4 * v * v + 1) - 1) / 2);\n}\nfunction number(_) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(_) ? _ : (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.constant)(+_);\n}\n\n// Implementation adapted from d3/d3-contour. Thanks!\nfunction density2D () {\n  var x = d => d[0],\n    y = d => d[1],\n    weight = vega_util__WEBPACK_IMPORTED_MODULE_1__.one,\n    bandwidth = [-1, -1],\n    dx = 960,\n    dy = 500,\n    k = 2; // log2(cellSize)\n\n  function density(data, counts) {\n    const rx = radius(bandwidth[0], data, x) >> k,\n      // blur x-radius\n      ry = radius(bandwidth[1], data, y) >> k,\n      // blur y-radius\n      ox = rx ? rx + 2 : 0,\n      // x-offset padding for blur\n      oy = ry ? ry + 2 : 0,\n      // y-offset padding for blur\n      n = 2 * ox + (dx >> k),\n      // grid width\n      m = 2 * oy + (dy >> k),\n      // grid height\n      values0 = new Float32Array(n * m),\n      values1 = new Float32Array(n * m);\n    let values = values0;\n    data.forEach(d => {\n      const xi = ox + (+x(d) >> k),\n        yi = oy + (+y(d) >> k);\n      if (xi >= 0 && xi < n && yi >= 0 && yi < m) {\n        values0[xi + yi * n] += +weight(d);\n      }\n    });\n    if (rx > 0 && ry > 0) {\n      blurX(n, m, values0, values1, rx);\n      blurY(n, m, values1, values0, ry);\n      blurX(n, m, values0, values1, rx);\n      blurY(n, m, values1, values0, ry);\n      blurX(n, m, values0, values1, rx);\n      blurY(n, m, values1, values0, ry);\n    } else if (rx > 0) {\n      blurX(n, m, values0, values1, rx);\n      blurX(n, m, values1, values0, rx);\n      blurX(n, m, values0, values1, rx);\n      values = values1;\n    } else if (ry > 0) {\n      blurY(n, m, values0, values1, ry);\n      blurY(n, m, values1, values0, ry);\n      blurY(n, m, values0, values1, ry);\n      values = values1;\n    }\n\n    // scale density estimates\n    // density in points per square pixel or probability density\n    const s = counts ? Math.pow(2, -2 * k) : 1 / (0,d3_array__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(values);\n    for (let i = 0, sz = n * m; i < sz; ++i) values[i] *= s;\n    return {\n      values: values,\n      scale: 1 << k,\n      width: n,\n      height: m,\n      x1: ox,\n      y1: oy,\n      x2: ox + (dx >> k),\n      y2: oy + (dy >> k)\n    };\n  }\n  density.x = function (_) {\n    return arguments.length ? (x = number(_), density) : x;\n  };\n  density.y = function (_) {\n    return arguments.length ? (y = number(_), density) : y;\n  };\n  density.weight = function (_) {\n    return arguments.length ? (weight = number(_), density) : weight;\n  };\n  density.size = function (_) {\n    if (!arguments.length) return [dx, dy];\n    var _0 = +_[0],\n      _1 = +_[1];\n    if (!(_0 >= 0 && _1 >= 0)) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('invalid size');\n    return dx = _0, dy = _1, density;\n  };\n  density.cellSize = function (_) {\n    if (!arguments.length) return 1 << k;\n    if (!((_ = +_) >= 1)) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('invalid cell size');\n    k = Math.floor(Math.log(_) / Math.LN2);\n    return density;\n  };\n  density.bandwidth = function (_) {\n    if (!arguments.length) return bandwidth;\n    _ = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(_);\n    if (_.length === 1) _ = [+_[0], +_[0]];\n    if (_.length !== 2) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('invalid bandwidth');\n    return bandwidth = _, density;\n  };\n  return density;\n}\nfunction blurX(n, m, source, target, r) {\n  const w = (r << 1) + 1;\n  for (let j = 0; j < m; ++j) {\n    for (let i = 0, sr = 0; i < n + r; ++i) {\n      if (i < n) {\n        sr += source[i + j * n];\n      }\n      if (i >= r) {\n        if (i >= w) {\n          sr -= source[i - w + j * n];\n        }\n        target[i - r + j * n] = sr / Math.min(i + 1, n - 1 + w - i, w);\n      }\n    }\n  }\n}\nfunction blurY(n, m, source, target, r) {\n  const w = (r << 1) + 1;\n  for (let i = 0; i < n; ++i) {\n    for (let j = 0, sr = 0; j < m + r; ++j) {\n      if (j < m) {\n        sr += source[i + j * n];\n      }\n      if (j >= r) {\n        if (j >= w) {\n          sr -= source[i + (j - w) * n];\n        }\n        target[i + (j - r) * n] = sr / Math.min(j + 1, m - 1 + w - j, w);\n      }\n    }\n  }\n}\n\n/**\n * Perform 2D kernel-density estimation of point data.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<number>} params.size - The [width, height] extent (in\n *   units of input pixels) over which to perform density estimation.\n * @param {function(object): number} params.x - The x-coordinate accessor.\n * @param {function(object): number} params.y - The y-coordinate accessor.\n * @param {function(object): number} [params.weight] - The weight accessor.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors\n *   to groupby.\n * @param {number} [params.cellSize] - Contour density calculation cell size.\n *   This parameter determines the level of spatial approximation. For example,\n *   the default value of 4 maps to 2x reductions in both x- and y- dimensions.\n *   A value of 1 will result in an output raster grid whose dimensions exactly\n *   matches the size parameter.\n * @param {Array<number>} [params.bandwidth] - The KDE kernel bandwidths,\n *   in pixels. The input can be a two-element array specifying separate\n *   x and y bandwidths, or a single-element array specifying both. If the\n *   bandwidth is unspecified or less than zero, the bandwidth will be\n *   automatically determined.\n * @param {boolean} [params.counts=false] - A boolean flag indicating if the\n *   output values should be probability estimates (false, default) or\n *   smoothed counts (true).\n * @param {string} [params.as='grid'] - The output field in which to store\n *   the generated raster grid (default 'grid').\n */\nfunction KDE2D(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nKDE2D.Definition = {\n  'type': 'KDE2D',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2,\n    'required': true\n  }, {\n    'name': 'x',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'y',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'weight',\n    'type': 'field'\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'cellSize',\n    'type': 'number'\n  }, {\n    'name': 'bandwidth',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'counts',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'grid'\n  }]\n};\nconst PARAMS = ['x', 'y', 'weight', 'size', 'cellSize', 'bandwidth'];\nfunction params(obj, _) {\n  PARAMS.forEach(param => _[param] != null ? obj[param](_[param]) : 0);\n  return obj;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(KDE2D, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !pulse.changed() && !_.modified()) return pulse.StopPropagation;\n    var out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      source = pulse.materialize(pulse.SOURCE).source,\n      groups = partition(source, _.groupby),\n      names = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorName),\n      kde = params(density2D(), _),\n      as = _.as || 'grid',\n      values = [];\n    function set(t, vals) {\n      for (let i = 0; i < names.length; ++i) t[names[i]] = vals[i];\n      return t;\n    }\n\n    // generate density raster grids\n    values = groups.map(g => (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)(set({\n      [as]: kde(g, _.counts)\n    }, g.dims)));\n    if (this.value) out.rem = this.value;\n    this.value = out.source = out.add = values;\n    return out;\n  }\n});\nfunction partition(data, groupby) {\n  var groups = [],\n    get = f => f(t),\n    map,\n    i,\n    n,\n    t,\n    k,\n    g;\n\n  // partition data points into groups\n  if (groupby == null) {\n    groups.push(data);\n  } else {\n    for (map = {}, i = 0, n = data.length; i < n; ++i) {\n      t = data[i];\n      k = groupby.map(get);\n      g = map[k];\n      if (!g) {\n        map[k] = g = [];\n        g.dims = k;\n        groups.push(g);\n      }\n      g.push(t);\n    }\n  }\n  return groups;\n}\n\n/**\n * Generate contours based on kernel-density estimation of point data.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<number>} params.size - The dimensions [width, height] over which to compute contours.\n *  If the values parameter is provided, this must be the dimensions of the input data.\n *  If density estimation is performed, this is the output view dimensions in pixels.\n * @param {Array<number>} [params.values] - An array of numeric values representing an\n *  width x height grid of values over which to compute contours. If unspecified, this\n *  transform will instead attempt to compute contours for the kernel density estimate\n *  using values drawn from data tuples in the input pulse.\n * @param {function(object): number} [params.x] - The pixel x-coordinate accessor for density estimation.\n * @param {function(object): number} [params.y] - The pixel y-coordinate accessor for density estimation.\n * @param {function(object): number} [params.weight] - The data point weight accessor for density estimation.\n * @param {number} [params.cellSize] - Contour density calculation cell size.\n * @param {number} [params.bandwidth] - Kernel density estimation bandwidth.\n * @param {Array<number>} [params.thresholds] - Contour threshold array. If\n *   this parameter is set, the count and nice parameters will be ignored.\n * @param {number} [params.count] - The desired number of contours.\n * @param {boolean} [params.nice] - Boolean flag indicating if the contour\n *   threshold values should be automatically aligned to \"nice\"\n *   human-friendly values. Setting this flag may cause the number of\n *   thresholds to deviate from the specified count.\n * @param {boolean} [params.smooth] - Boolean flag indicating if the contour\n *   polygons should be smoothed using linear interpolation. The default is\n *   true. The parameter is ignored when using density estimation.\n */\nfunction Contour(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nContour.Definition = {\n  'type': 'Contour',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2,\n    'required': true\n  }, {\n    'name': 'values',\n    'type': 'number',\n    'array': true\n  }, {\n    'name': 'x',\n    'type': 'field'\n  }, {\n    'name': 'y',\n    'type': 'field'\n  }, {\n    'name': 'weight',\n    'type': 'field'\n  }, {\n    'name': 'cellSize',\n    'type': 'number'\n  }, {\n    'name': 'bandwidth',\n    'type': 'number'\n  }, {\n    'name': 'count',\n    'type': 'number'\n  }, {\n    'name': 'nice',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'thresholds',\n    'type': 'number',\n    'array': true\n  }, {\n    'name': 'smooth',\n    'type': 'boolean',\n    'default': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Contour, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !pulse.changed() && !_.modified()) {\n      return pulse.StopPropagation;\n    }\n    var out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      contour = contours().smooth(_.smooth !== false),\n      values = _.values,\n      thresh = _.thresholds || quantize(_.count || 10, _.nice, !!values),\n      size = _.size,\n      grid,\n      post;\n    if (!values) {\n      values = pulse.materialize(pulse.SOURCE).source;\n      grid = params(density2D(), _)(values, true);\n      post = transform(grid, grid.scale || 1, grid.scale || 1, 0, 0);\n      size = [grid.width, grid.height];\n      values = grid.values;\n    }\n    thresh = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isArray)(thresh) ? thresh : thresh(values);\n    values = contour.size(size)(values, thresh);\n    if (post) values.forEach(post);\n    if (this.value) out.rem = this.value;\n    this.value = out.source = out.add = (values || []).map(vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest);\n    return out;\n  }\n});\n\nconst Feature = 'Feature';\nconst FeatureCollection = 'FeatureCollection';\nconst MultiPoint = 'MultiPoint';\n\n/**\n * Consolidate an array of [longitude, latitude] points or GeoJSON features\n * into a combined GeoJSON object. This transform is particularly useful for\n * combining geo data for a Projection's fit argument. The resulting GeoJSON\n * data is available as this transform's value. Input pulses are unchanged.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} [params.fields] - A two-element array\n *   of field accessors for the longitude and latitude values.\n * @param {function(object): *} params.geojson - A field accessor for\n *   retrieving GeoJSON feature data.\n */\nfunction GeoJSON(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nGeoJSON.Definition = {\n  'type': 'GeoJSON',\n  'metadata': {},\n  'params': [{\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'geojson',\n    'type': 'field'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(GeoJSON, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var features = this._features,\n      points = this._points,\n      fields = _.fields,\n      lon = fields && fields[0],\n      lat = fields && fields[1],\n      geojson = _.geojson || !fields && vega_util__WEBPACK_IMPORTED_MODULE_1__.identity,\n      flag = pulse.ADD,\n      mod;\n    mod = _.modified() || pulse.changed(pulse.REM) || pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorFields)(geojson)) || lon && pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorFields)(lon)) || lat && pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorFields)(lat));\n    if (!this.value || mod) {\n      flag = pulse.SOURCE;\n      this._features = features = [];\n      this._points = points = [];\n    }\n    if (geojson) {\n      pulse.visit(flag, t => features.push(geojson(t)));\n    }\n    if (lon && lat) {\n      pulse.visit(flag, t => {\n        var x = lon(t),\n          y = lat(t);\n        if (x != null && y != null && (x = +x) === x && (y = +y) === y) {\n          points.push([x, y]);\n        }\n      });\n      features = features.concat({\n        type: Feature,\n        geometry: {\n          type: MultiPoint,\n          coordinates: points\n        }\n      });\n    }\n    this.value = {\n      type: FeatureCollection,\n      features: features\n    };\n  }\n});\n\n/**\n * Map GeoJSON data to an SVG path string.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(number, number): *} params.projection - The cartographic\n *   projection to apply.\n * @param {function(object): *} [params.field] - The field with GeoJSON data,\n *   or null if the tuple itself is a GeoJSON feature.\n * @param {string} [params.as='path'] - The output field in which to store\n *   the generated path data (default 'path').\n */\nfunction GeoPath(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nGeoPath.Definition = {\n  'type': 'GeoPath',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'projection',\n    'type': 'projection'\n  }, {\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'pointRadius',\n    'type': 'number',\n    'expr': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'path'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(GeoPath, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var out = pulse.fork(pulse.ALL),\n      path = this.value,\n      field = _.field || vega_util__WEBPACK_IMPORTED_MODULE_1__.identity,\n      as = _.as || 'path',\n      flag = out.SOURCE;\n    if (!path || _.modified()) {\n      // parameters updated, reset and reflow\n      this.value = path = (0,vega_projection__WEBPACK_IMPORTED_MODULE_3__.getProjectionPath)(_.projection);\n      out.materialize().reflow();\n    } else {\n      flag = field === vega_util__WEBPACK_IMPORTED_MODULE_1__.identity || pulse.modified(field.fields) ? out.ADD_MOD : out.ADD;\n    }\n    const prev = initPath(path, _.pointRadius);\n    out.visit(flag, t => t[as] = path(field(t)));\n    path.pointRadius(prev);\n    return out.modifies(as);\n  }\n});\nfunction initPath(path, pointRadius) {\n  const prev = path.pointRadius();\n  path.context(null);\n  if (pointRadius != null) {\n    path.pointRadius(pointRadius);\n  }\n  return prev;\n}\n\n/**\n * Geo-code a longitude/latitude point to an x/y coordinate.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(number, number): *} params.projection - The cartographic\n *   projection to apply.\n * @param {Array<function(object): *>} params.fields - A two-element array of\n *   field accessors for the longitude and latitude values.\n * @param {Array<string>} [params.as] - A two-element array of field names\n *   under which to store the result. Defaults to ['x','y'].\n */\nfunction GeoPoint(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nGeoPoint.Definition = {\n  'type': 'GeoPoint',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'projection',\n    'type': 'projection',\n    'required': true\n  }, {\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'required': true,\n    'length': 2\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['x', 'y']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(GeoPoint, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var proj = _.projection,\n      lon = _.fields[0],\n      lat = _.fields[1],\n      as = _.as || ['x', 'y'],\n      x = as[0],\n      y = as[1],\n      mod;\n    function set(t) {\n      const xy = proj([lon(t), lat(t)]);\n      if (xy) {\n        t[x] = xy[0];\n        t[y] = xy[1];\n      } else {\n        t[x] = undefined;\n        t[y] = undefined;\n      }\n    }\n    if (_.modified()) {\n      // parameters updated, reflow\n      pulse = pulse.materialize().reflow(true).visit(pulse.SOURCE, set);\n    } else {\n      mod = pulse.modified(lon.fields) || pulse.modified(lat.fields);\n      pulse.visit(mod ? pulse.ADD_MOD : pulse.ADD, set);\n    }\n    return pulse.modifies(as);\n  }\n});\n\n/**\n * Annotate items with a geopath shape generator.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(number, number): *} params.projection - The cartographic\n *   projection to apply.\n * @param {function(object): *} [params.field] - The field with GeoJSON data,\n *   or null if the tuple itself is a GeoJSON feature.\n * @param {string} [params.as='shape'] - The output field in which to store\n *   the generated path data (default 'shape').\n */\nfunction GeoShape(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nGeoShape.Definition = {\n  'type': 'GeoShape',\n  'metadata': {\n    'modifies': true,\n    'nomod': true\n  },\n  'params': [{\n    'name': 'projection',\n    'type': 'projection'\n  }, {\n    'name': 'field',\n    'type': 'field',\n    'default': 'datum'\n  }, {\n    'name': 'pointRadius',\n    'type': 'number',\n    'expr': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'shape'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(GeoShape, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var out = pulse.fork(pulse.ALL),\n      shape = this.value,\n      as = _.as || 'shape',\n      flag = out.ADD;\n    if (!shape || _.modified()) {\n      // parameters updated, reset and reflow\n      this.value = shape = shapeGenerator((0,vega_projection__WEBPACK_IMPORTED_MODULE_3__.getProjectionPath)(_.projection), _.field || (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.field)('datum'), _.pointRadius);\n      out.materialize().reflow();\n      flag = out.SOURCE;\n    }\n    out.visit(flag, t => t[as] = shape);\n    return out.modifies(as);\n  }\n});\nfunction shapeGenerator(path, field, pointRadius) {\n  const shape = pointRadius == null ? _ => path(field(_)) : _ => {\n    var prev = path.pointRadius(),\n      value = path.pointRadius(pointRadius)(field(_));\n    path.pointRadius(prev);\n    return value;\n  };\n  shape.context = _ => {\n    path.context(_);\n    return shape;\n  };\n  return shape;\n}\n\n/**\n * GeoJSON feature generator for creating graticules.\n * @constructor\n */\nfunction Graticule(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, [], params);\n  this.generator = (0,d3_geo__WEBPACK_IMPORTED_MODULE_9__[\"default\"])();\n}\nGraticule.Definition = {\n  'type': 'Graticule',\n  'metadata': {\n    'changes': true,\n    'generates': true\n  },\n  'params': [{\n    'name': 'extent',\n    'type': 'array',\n    'array': true,\n    'length': 2,\n    'content': {\n      'type': 'number',\n      'array': true,\n      'length': 2\n    }\n  }, {\n    'name': 'extentMajor',\n    'type': 'array',\n    'array': true,\n    'length': 2,\n    'content': {\n      'type': 'number',\n      'array': true,\n      'length': 2\n    }\n  }, {\n    'name': 'extentMinor',\n    'type': 'array',\n    'array': true,\n    'length': 2,\n    'content': {\n      'type': 'number',\n      'array': true,\n      'length': 2\n    }\n  }, {\n    'name': 'step',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'stepMajor',\n    'type': 'number',\n    'array': true,\n    'length': 2,\n    'default': [90, 360]\n  }, {\n    'name': 'stepMinor',\n    'type': 'number',\n    'array': true,\n    'length': 2,\n    'default': [10, 10]\n  }, {\n    'name': 'precision',\n    'type': 'number',\n    'default': 2.5\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Graticule, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    var src = this.value,\n      gen = this.generator,\n      t;\n    if (!src.length || _.modified()) {\n      for (const prop in _) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(gen[prop])) {\n          gen[prop](_[prop]);\n        }\n      }\n    }\n    t = gen();\n    if (src.length) {\n      pulse.mod.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.replace)(src[0], t));\n    } else {\n      pulse.add.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)(t));\n    }\n    src[0] = t;\n    return pulse;\n  }\n});\n\n/**\n * Render a heatmap image for input raster grid data.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} [params.field] - The field with raster grid\n *   data. If unspecified, the tuple itself is interpreted as a raster grid.\n * @param {string} [params.color] - A constant color value or function for\n *   individual pixel color. If a function, it will be invoked with an input\n *   object that includes $x, $y, $value, and $max fields for the grid.\n * @param {number} [params.opacity] - A constant opacity value or function for\n *   individual pixel opacity. If a function, it will be invoked with an input\n *   object that includes $x, $y, $value, and $max fields for the grid.\n * @param {string} [params.resolve] - The method for resolving maximum values\n *   across multiple input grids. If 'independent' (the default), maximum\n *   calculation will be performed separately for each grid. If 'shared',\n *   a single global maximum will be used for all input grids.\n * @param {string} [params.as='image'] - The output field in which to store\n *   the generated bitmap canvas images (default 'image').\n */\nfunction Heatmap(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nHeatmap.Definition = {\n  'type': 'heatmap',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'color',\n    'type': 'string',\n    'expr': true\n  }, {\n    'name': 'opacity',\n    'type': 'number',\n    'expr': true\n  }, {\n    'name': 'resolve',\n    'type': 'enum',\n    'values': ['shared', 'independent'],\n    'default': 'independent'\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'image'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Heatmap, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (!pulse.changed() && !_.modified()) {\n      return pulse.StopPropagation;\n    }\n    var source = pulse.materialize(pulse.SOURCE).source,\n      shared = _.resolve === 'shared',\n      field = _.field || vega_util__WEBPACK_IMPORTED_MODULE_1__.identity,\n      opacity = opacity_(_.opacity, _),\n      color = color_(_.color, _),\n      as = _.as || 'image',\n      obj = {\n        $x: 0,\n        $y: 0,\n        $value: 0,\n        $max: shared ? (0,d3_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(source.map(t => (0,d3_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(field(t).values))) : 0\n      };\n    source.forEach(t => {\n      const v = field(t);\n\n      // build proxy data object\n      const o = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.extend)({}, t, obj);\n      // set maximum value if not globally shared\n      if (!shared) o.$max = (0,d3_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(v.values || []);\n\n      // generate canvas image\n      // optimize color/opacity if not pixel-dependent\n      t[as] = toCanvas(v, o, color.dep ? color : (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.constant)(color(o)), opacity.dep ? opacity : (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.constant)(opacity(o)));\n    });\n    return pulse.reflow(true).modifies(as);\n  }\n});\n\n// get image color function\nfunction color_(color, _) {\n  let f;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(color)) {\n    f = obj => (0,d3_color__WEBPACK_IMPORTED_MODULE_10__.rgb)(color(obj, _));\n    f.dep = dependency(color);\n  } else {\n    // default to mid-grey\n    f = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.constant)((0,d3_color__WEBPACK_IMPORTED_MODULE_10__.rgb)(color || '#888'));\n  }\n  return f;\n}\n\n// get image opacity function\nfunction opacity_(opacity, _) {\n  let f;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(opacity)) {\n    f = obj => opacity(obj, _);\n    f.dep = dependency(opacity);\n  } else if (opacity) {\n    f = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.constant)(opacity);\n  } else {\n    // default to [0, max] opacity gradient\n    f = obj => obj.$value / obj.$max || 0;\n    f.dep = true;\n  }\n  return f;\n}\n\n// check if function depends on individual pixel data\nfunction dependency(f) {\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(f)) return false;\n  const set = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.toSet)((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.accessorFields)(f));\n  return set.$x || set.$y || set.$value || set.$max;\n}\n\n// render raster grid to canvas\nfunction toCanvas(grid, obj, color, opacity) {\n  const n = grid.width,\n    m = grid.height,\n    x1 = grid.x1 || 0,\n    y1 = grid.y1 || 0,\n    x2 = grid.x2 || n,\n    y2 = grid.y2 || m,\n    val = grid.values,\n    value = val ? i => val[i] : vega_util__WEBPACK_IMPORTED_MODULE_1__.zero,\n    can = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_4__.canvas)(x2 - x1, y2 - y1),\n    ctx = can.getContext('2d'),\n    img = ctx.getImageData(0, 0, x2 - x1, y2 - y1),\n    pix = img.data;\n  for (let j = y1, k = 0; j < y2; ++j) {\n    obj.$y = j - y1;\n    for (let i = x1, r = j * n; i < x2; ++i, k += 4) {\n      obj.$x = i - x1;\n      obj.$value = value(i + r);\n      const v = color(obj);\n      pix[k + 0] = v.r;\n      pix[k + 1] = v.g;\n      pix[k + 2] = v.b;\n      pix[k + 3] = ~~(255 * opacity(obj));\n    }\n  }\n  ctx.putImageData(img, 0, 0);\n  return can;\n}\n\n/**\n * Maintains a cartographic projection.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction Projection(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n  this.modified(true); // always treat as modified\n}\n\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Projection, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    let proj = this.value;\n    if (!proj || _.modified('type')) {\n      this.value = proj = create(_.type);\n      vega_projection__WEBPACK_IMPORTED_MODULE_3__.projectionProperties.forEach(prop => {\n        if (_[prop] != null) set(proj, prop, _[prop]);\n      });\n    } else {\n      vega_projection__WEBPACK_IMPORTED_MODULE_3__.projectionProperties.forEach(prop => {\n        if (_.modified(prop)) set(proj, prop, _[prop]);\n      });\n    }\n    if (_.pointRadius != null) proj.path.pointRadius(_.pointRadius);\n    if (_.fit) fit(proj, _);\n    return pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n  }\n});\nfunction fit(proj, _) {\n  const data = collectGeoJSON(_.fit);\n  _.extent ? proj.fitExtent(_.extent, data) : _.size ? proj.fitSize(_.size, data) : 0;\n}\nfunction create(type) {\n  const constructor = (0,vega_projection__WEBPACK_IMPORTED_MODULE_3__.projection)((type || 'mercator').toLowerCase());\n  if (!constructor) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Unrecognized projection type: ' + type);\n  return constructor();\n}\nfunction set(proj, key, value) {\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isFunction)(proj[key])) proj[key](value);\n}\nfunction collectGeoJSON(data) {\n  data = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(data);\n  return data.length === 1 ? data[0] : {\n    type: FeatureCollection,\n    features: data.reduce((a, f) => a.concat(featurize(f)), [])\n  };\n}\nfunction featurize(f) {\n  return f.type === FeatureCollection ? f.features : (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(f).filter(d => d != null).map(d => d.type === Feature ? d : {\n    type: Feature,\n    geometry: d\n  });\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-geo/build/vega-geo.module.js?");

/***/ }),

/***/ "../../node_modules/vega-hierarchy/build/vega-hierarchy.module.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-hierarchy/build/vega-hierarchy.module.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   nest: () => (/* binding */ Nest),\n/* harmony export */   pack: () => (/* binding */ Pack),\n/* harmony export */   partition: () => (/* binding */ Partition),\n/* harmony export */   stratify: () => (/* binding */ Stratify),\n/* harmony export */   tree: () => (/* binding */ Tree),\n/* harmony export */   treelinks: () => (/* binding */ TreeLinks),\n/* harmony export */   treemap: () => (/* binding */ Treemap)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/hierarchy/index.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/pack/index.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/partition.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/stratify.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/tree.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/cluster.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/binary.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/dice.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/slice.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/sliceDice.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/squarify.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/resquarify.js\");\n/* harmony import */ var d3_hierarchy__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-hierarchy */ \"../../node_modules/d3-hierarchy/src/treemap/index.js\");\n\n\n\n\n// Build lookup table mapping tuple keys to tree node instances\nfunction lookup (tree, key, filter) {\n  const map = {};\n  tree.each(node => {\n    const t = node.data;\n    if (filter(t)) map[key(t)] = node;\n  });\n  tree.lookup = map;\n  return tree;\n}\n\n/**\n * Nest tuples into a tree structure, grouped by key values.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} params.keys - The key fields to nest by, in order.\n * @param {boolean} [params.generate=false] - A boolean flag indicating if\n *   non-leaf nodes generated by this transform should be included in the\n *   output. The default (false) includes only the input data (leaf nodes)\n *   in the data stream.\n */\nfunction Nest(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nNest.Definition = {\n  'type': 'Nest',\n  'metadata': {\n    'treesource': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'keys',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'generate',\n    'type': 'boolean'\n  }]\n};\nconst children = n => n.values;\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Nest, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (!pulse.source) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Nest transform requires an upstream data source.');\n    }\n    var gen = _.generate,\n      mod = _.modified(),\n      out = pulse.clone(),\n      tree = this.value;\n    if (!tree || mod || pulse.changed()) {\n      // collect nodes to remove\n      if (tree) {\n        tree.each(node => {\n          if (node.children && (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.isTuple)(node.data)) {\n            out.rem.push(node.data);\n          }\n        });\n      }\n\n      // generate new tree structure\n      this.value = tree = (0,d3_hierarchy__WEBPACK_IMPORTED_MODULE_2__[\"default\"])({\n        values: (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(_.keys).reduce((n, k) => {\n          n.key(k);\n          return n;\n        }, nest()).entries(out.source)\n      }, children);\n\n      // collect nodes to add\n      if (gen) {\n        tree.each(node => {\n          if (node.children) {\n            node = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)(node.data);\n            out.add.push(node);\n            out.source.push(node);\n          }\n        });\n      }\n\n      // build lookup table\n      lookup(tree, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid);\n    }\n    out.source.root = tree;\n    return out;\n  }\n});\nfunction nest() {\n  const keys = [],\n    nest = {\n      entries: array => entries(apply(array, 0), 0),\n      key: d => (keys.push(d), nest)\n    };\n  function apply(array, depth) {\n    if (depth >= keys.length) {\n      return array;\n    }\n    const n = array.length,\n      key = keys[depth++],\n      valuesByKey = {},\n      result = {};\n    let i = -1,\n      keyValue,\n      value,\n      values;\n    while (++i < n) {\n      keyValue = key(value = array[i]) + '';\n      if (values = valuesByKey[keyValue]) {\n        values.push(value);\n      } else {\n        valuesByKey[keyValue] = [value];\n      }\n    }\n    for (keyValue in valuesByKey) {\n      result[keyValue] = apply(valuesByKey[keyValue], depth);\n    }\n    return result;\n  }\n  function entries(map, depth) {\n    if (++depth > keys.length) return map;\n    const array = [];\n    for (const key in map) {\n      array.push({\n        key,\n        values: entries(map[key], depth)\n      });\n    }\n    return array;\n  }\n  return nest;\n}\n\n/**\n * Abstract class for tree layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction HierarchyLayout(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nconst defaultSeparation = (a, b) => a.parent === b.parent ? 1 : 2;\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(HierarchyLayout, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (!pulse.source || !pulse.source.root) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)(this.constructor.name + ' transform requires a backing tree data source.');\n    }\n    const layout = this.layout(_.method),\n      fields = this.fields,\n      root = pulse.source.root,\n      as = _.as || fields;\n    if (_.field) root.sum(_.field);else root.count();\n    if (_.sort) root.sort((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.stableCompare)(_.sort, d => d.data));\n    setParams(layout, this.params, _);\n    if (layout.separation) {\n      layout.separation(_.separation !== false ? defaultSeparation : vega_util__WEBPACK_IMPORTED_MODULE_1__.one);\n    }\n    try {\n      this.value = layout(root);\n    } catch (err) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)(err);\n    }\n    root.each(node => setFields(node, fields, as));\n    return pulse.reflow(_.modified()).modifies(as).modifies('leaf');\n  }\n});\nfunction setParams(layout, params, _) {\n  for (let p, i = 0, n = params.length; i < n; ++i) {\n    p = params[i];\n    if (p in _) layout[p](_[p]);\n  }\n}\nfunction setFields(node, fields, as) {\n  const t = node.data,\n    n = fields.length - 1;\n  for (let i = 0; i < n; ++i) {\n    t[as[i]] = node[fields[i]];\n  }\n  t[as[n]] = node.children ? node.children.length : 0;\n}\n\nconst Output$3 = ['x', 'y', 'r', 'depth', 'children'];\n\n/**\n * Packed circle tree layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to size nodes.\n */\nfunction Pack(params) {\n  HierarchyLayout.call(this, params);\n}\nPack.Definition = {\n  'type': 'Pack',\n  'metadata': {\n    'tree': true,\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'padding',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'radius',\n    'type': 'field',\n    'default': null\n  }, {\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': Output$3.length,\n    'default': Output$3\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Pack, HierarchyLayout, {\n  layout: d3_hierarchy__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  params: ['radius', 'size', 'padding'],\n  fields: Output$3\n});\n\nconst Output$2 = ['x0', 'y0', 'x1', 'y1', 'depth', 'children'];\n\n/**\n * Partition tree layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to size nodes.\n */\nfunction Partition(params) {\n  HierarchyLayout.call(this, params);\n}\nPartition.Definition = {\n  'type': 'Partition',\n  'metadata': {\n    'tree': true,\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'padding',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'round',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': Output$2.length,\n    'default': Output$2\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Partition, HierarchyLayout, {\n  layout: d3_hierarchy__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  params: ['size', 'round', 'padding'],\n  fields: Output$2\n});\n\n/**\n * Stratify a collection of tuples into a tree structure based on\n * id and parent id fields.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.key - Unique key field for each tuple.\n * @param {function(object): *} params.parentKey - Field with key for parent tuple.\n */\nfunction Stratify(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nStratify.Definition = {\n  'type': 'Stratify',\n  'metadata': {\n    'treesource': true\n  },\n  'params': [{\n    'name': 'key',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'parentKey',\n    'type': 'field',\n    'required': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Stratify, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    if (!pulse.source) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Stratify transform requires an upstream data source.');\n    }\n    let tree = this.value;\n    const mod = _.modified(),\n      out = pulse.fork(pulse.ALL).materialize(pulse.SOURCE),\n      run = !tree || mod || pulse.changed(pulse.ADD_REM) || pulse.modified(_.key.fields) || pulse.modified(_.parentKey.fields);\n\n    // prevent upstream source pollution\n    out.source = out.source.slice();\n    if (run) {\n      tree = out.source.length ? lookup((0,d3_hierarchy__WEBPACK_IMPORTED_MODULE_5__[\"default\"])().id(_.key).parentId(_.parentKey)(out.source), _.key, vega_util__WEBPACK_IMPORTED_MODULE_1__.truthy) : lookup((0,d3_hierarchy__WEBPACK_IMPORTED_MODULE_5__[\"default\"])()([{}]), _.key, _.key);\n    }\n    out.source.root = this.value = tree;\n    return out;\n  }\n});\n\nconst Layouts = {\n  tidy: d3_hierarchy__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  cluster: d3_hierarchy__WEBPACK_IMPORTED_MODULE_7__[\"default\"]\n};\nconst Output$1 = ['x', 'y', 'depth', 'children'];\n\n/**\n * Tree layout. Depending on the method parameter, performs either\n * Reingold-Tilford 'tidy' layout or dendrogram 'cluster' layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction Tree(params) {\n  HierarchyLayout.call(this, params);\n}\nTree.Definition = {\n  'type': 'Tree',\n  'metadata': {\n    'tree': true,\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'method',\n    'type': 'enum',\n    'default': 'tidy',\n    'values': ['tidy', 'cluster']\n  }, {\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'nodeSize',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'separation',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': Output$1.length,\n    'default': Output$1\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Tree, HierarchyLayout, {\n  /**\n   * Tree layout generator. Supports both 'tidy' and 'cluster' layouts.\n   */\n  layout(method) {\n    const m = method || 'tidy';\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.hasOwnProperty)(Layouts, m)) return Layouts[m]();else (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Unrecognized Tree layout method: ' + m);\n  },\n  params: ['size', 'nodeSize'],\n  fields: Output$1\n});\n\n/**\n * Generate tuples representing links between tree nodes.\n * The resulting tuples will contain 'source' and 'target' fields,\n * which point to parent and child node tuples, respectively.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction TreeLinks(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, [], params);\n}\nTreeLinks.Definition = {\n  'type': 'TreeLinks',\n  'metadata': {\n    'tree': true,\n    'generates': true,\n    'changes': true\n  },\n  'params': []\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(TreeLinks, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const links = this.value,\n      tree = pulse.source && pulse.source.root,\n      out = pulse.fork(pulse.NO_SOURCE),\n      lut = {};\n    if (!tree) (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('TreeLinks transform requires a tree data source.');\n    if (pulse.changed(pulse.ADD_REM)) {\n      // remove previous links\n      out.rem = links;\n\n      // build lookup table of valid tuples\n      pulse.visit(pulse.SOURCE, t => lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(t)] = 1);\n\n      // generate links for all edges incident on valid tuples\n      tree.each(node => {\n        const t = node.data,\n          p = node.parent && node.parent.data;\n        if (p && lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(t)] && lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(p)]) {\n          out.add.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.ingest)({\n            source: p,\n            target: t\n          }));\n        }\n      });\n      this.value = out.add;\n    } else if (pulse.changed(pulse.MOD)) {\n      // build lookup table of modified tuples\n      pulse.visit(pulse.MOD, t => lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(t)] = 1);\n\n      // gather links incident on modified tuples\n      links.forEach(link => {\n        if (lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(link.source)] || lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.tupleid)(link.target)]) {\n          out.mod.push(link);\n        }\n      });\n    }\n    return out;\n  }\n});\n\nconst Tiles = {\n  binary: d3_hierarchy__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  dice: d3_hierarchy__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n  slice: d3_hierarchy__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n  slicedice: d3_hierarchy__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n  squarify: d3_hierarchy__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n  resquarify: d3_hierarchy__WEBPACK_IMPORTED_MODULE_13__[\"default\"]\n};\nconst Output = ['x0', 'y0', 'x1', 'y1', 'depth', 'children'];\n\n/**\n * Treemap layout.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to size nodes.\n */\nfunction Treemap(params) {\n  HierarchyLayout.call(this, params);\n}\nTreemap.Definition = {\n  'type': 'Treemap',\n  'metadata': {\n    'tree': true,\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field'\n  }, {\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'method',\n    'type': 'enum',\n    'default': 'squarify',\n    'values': ['squarify', 'resquarify', 'binary', 'dice', 'slice', 'slicedice']\n  }, {\n    'name': 'padding',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingInner',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingOuter',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingTop',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingRight',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingBottom',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'paddingLeft',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'ratio',\n    'type': 'number',\n    'default': 1.618033988749895\n  }, {\n    'name': 'round',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': Output.length,\n    'default': Output\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Treemap, HierarchyLayout, {\n  /**\n   * Treemap layout generator. Adds 'method' and 'ratio' parameters\n   * to configure the underlying tile method.\n   */\n  layout() {\n    const x = (0,d3_hierarchy__WEBPACK_IMPORTED_MODULE_14__[\"default\"])();\n    x.ratio = _ => {\n      const t = x.tile();\n      if (t.ratio) x.tile(t.ratio(_));\n    };\n    x.method = _ => {\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.hasOwnProperty)(Tiles, _)) x.tile(Tiles[_]);else (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.error)('Unrecognized Treemap layout method: ' + _);\n    };\n    return x;\n  },\n  params: ['method', 'ratio', 'size', 'round', 'padding', 'paddingInner', 'paddingOuter', 'paddingTop', 'paddingRight', 'paddingBottom', 'paddingLeft'],\n  fields: Output\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-hierarchy/build/vega-hierarchy.module.js?");

/***/ }),

/***/ "../../node_modules/vega-interpreter/build/vega-interpreter.module.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-interpreter/build/vega-interpreter.module.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   expressionInterpreter: () => (/* binding */ expression)\n/* harmony export */ });\nfunction adjustSpatial (item, encode, swap) {\n  let t;\n  if (encode.x2) {\n    if (encode.x) {\n      if (swap && item.x > item.x2) {\n        t = item.x;\n        item.x = item.x2;\n        item.x2 = t;\n      }\n      item.width = item.x2 - item.x;\n    } else {\n      item.x = item.x2 - (item.width || 0);\n    }\n  }\n  if (encode.xc) {\n    item.x = item.xc - (item.width || 0) / 2;\n  }\n  if (encode.y2) {\n    if (encode.y) {\n      if (swap && item.y > item.y2) {\n        t = item.y;\n        item.y = item.y2;\n        item.y2 = t;\n      }\n      item.height = item.y2 - item.y;\n    } else {\n      item.y = item.y2 - (item.height || 0);\n    }\n  }\n  if (encode.yc) {\n    item.y = item.yc - (item.height || 0) / 2;\n  }\n}\n\nvar Constants = {\n  NaN: NaN,\n  E: Math.E,\n  LN2: Math.LN2,\n  LN10: Math.LN10,\n  LOG2E: Math.LOG2E,\n  LOG10E: Math.LOG10E,\n  PI: Math.PI,\n  SQRT1_2: Math.SQRT1_2,\n  SQRT2: Math.SQRT2,\n  MIN_VALUE: Number.MIN_VALUE,\n  MAX_VALUE: Number.MAX_VALUE\n};\n\nvar Ops = {\n  '*': (a, b) => a * b,\n  '+': (a, b) => a + b,\n  '-': (a, b) => a - b,\n  '/': (a, b) => a / b,\n  '%': (a, b) => a % b,\n  '>': (a, b) => a > b,\n  '<': (a, b) => a < b,\n  '<=': (a, b) => a <= b,\n  '>=': (a, b) => a >= b,\n  '==': (a, b) => a == b,\n  '!=': (a, b) => a != b,\n  '===': (a, b) => a === b,\n  '!==': (a, b) => a !== b,\n  '&': (a, b) => a & b,\n  '|': (a, b) => a | b,\n  '^': (a, b) => a ^ b,\n  '<<': (a, b) => a << b,\n  '>>': (a, b) => a >> b,\n  '>>>': (a, b) => a >>> b\n};\n\nvar Unary = {\n  '+': a => +a,\n  '-': a => -a,\n  '~': a => ~a,\n  '!': a => !a\n};\n\nconst slice = Array.prototype.slice;\nconst apply = (m, args, cast) => {\n  const obj = cast ? cast(args[0]) : args[0];\n  return obj[m].apply(obj, slice.call(args, 1));\n};\nconst datetime = (y, m, d, H, M, S, ms) => new Date(y, m || 0, d != null ? d : 1, H || 0, M || 0, S || 0, ms || 0);\nvar Functions = {\n  // math functions\n  isNaN: Number.isNaN,\n  isFinite: Number.isFinite,\n  abs: Math.abs,\n  acos: Math.acos,\n  asin: Math.asin,\n  atan: Math.atan,\n  atan2: Math.atan2,\n  ceil: Math.ceil,\n  cos: Math.cos,\n  exp: Math.exp,\n  floor: Math.floor,\n  log: Math.log,\n  max: Math.max,\n  min: Math.min,\n  pow: Math.pow,\n  random: Math.random,\n  round: Math.round,\n  sin: Math.sin,\n  sqrt: Math.sqrt,\n  tan: Math.tan,\n  clamp: (a, b, c) => Math.max(b, Math.min(c, a)),\n  // date functions\n  now: Date.now,\n  utc: Date.UTC,\n  datetime: datetime,\n  date: d => new Date(d).getDate(),\n  day: d => new Date(d).getDay(),\n  year: d => new Date(d).getFullYear(),\n  month: d => new Date(d).getMonth(),\n  hours: d => new Date(d).getHours(),\n  minutes: d => new Date(d).getMinutes(),\n  seconds: d => new Date(d).getSeconds(),\n  milliseconds: d => new Date(d).getMilliseconds(),\n  time: d => new Date(d).getTime(),\n  timezoneoffset: d => new Date(d).getTimezoneOffset(),\n  utcdate: d => new Date(d).getUTCDate(),\n  utcday: d => new Date(d).getUTCDay(),\n  utcyear: d => new Date(d).getUTCFullYear(),\n  utcmonth: d => new Date(d).getUTCMonth(),\n  utchours: d => new Date(d).getUTCHours(),\n  utcminutes: d => new Date(d).getUTCMinutes(),\n  utcseconds: d => new Date(d).getUTCSeconds(),\n  utcmilliseconds: d => new Date(d).getUTCMilliseconds(),\n  // sequence functions\n  length: x => x.length,\n  join: function () {\n    return apply('join', arguments);\n  },\n  indexof: function () {\n    return apply('indexOf', arguments);\n  },\n  lastindexof: function () {\n    return apply('lastIndexOf', arguments);\n  },\n  slice: function () {\n    return apply('slice', arguments);\n  },\n  reverse: x => x.slice().reverse(),\n  // string functions\n  parseFloat: parseFloat,\n  parseInt: parseInt,\n  upper: x => String(x).toUpperCase(),\n  lower: x => String(x).toLowerCase(),\n  substring: function () {\n    return apply('substring', arguments, String);\n  },\n  split: function () {\n    return apply('split', arguments, String);\n  },\n  replace: function () {\n    return apply('replace', arguments, String);\n  },\n  trim: x => String(x).trim(),\n  // regexp functions\n  regexp: RegExp,\n  test: (r, t) => RegExp(r).test(t)\n};\n\nconst EventFunctions = ['view', 'item', 'group', 'xy', 'x', 'y'];\nconst DisallowedMethods = new Set([Function, eval, setTimeout, setInterval]);\nif (typeof setImmediate === 'function') DisallowedMethods.add(setImmediate);\nconst Visitors = {\n  Literal: ($, n) => n.value,\n  Identifier: ($, n) => {\n    const id = n.name;\n    return $.memberDepth > 0 ? id : id === 'datum' ? $.datum : id === 'event' ? $.event : id === 'item' ? $.item : Constants[id] || $.params['$' + id];\n  },\n  MemberExpression: ($, n) => {\n    const d = !n.computed,\n      o = $(n.object);\n    if (d) $.memberDepth += 1;\n    const p = $(n.property);\n    if (d) $.memberDepth -= 1;\n    if (DisallowedMethods.has(o[p])) {\n      // eslint-disable-next-line no-console\n      console.error(`Prevented interpretation of member \"${p}\" which could lead to insecure code execution`);\n      return;\n    }\n    return o[p];\n  },\n  CallExpression: ($, n) => {\n    const args = n.arguments;\n    let name = n.callee.name;\n\n    // handle special internal functions used by encoders\n    // re-route to corresponding standard function\n    if (name.startsWith('_')) {\n      name = name.slice(1);\n    }\n\n    // special case \"if\" due to conditional evaluation of branches\n    return name === 'if' ? $(args[0]) ? $(args[1]) : $(args[2]) : ($.fn[name] || Functions[name]).apply($.fn, args.map($));\n  },\n  ArrayExpression: ($, n) => n.elements.map($),\n  BinaryExpression: ($, n) => Ops[n.operator]($(n.left), $(n.right)),\n  UnaryExpression: ($, n) => Unary[n.operator]($(n.argument)),\n  ConditionalExpression: ($, n) => $(n.test) ? $(n.consequent) : $(n.alternate),\n  LogicalExpression: ($, n) => n.operator === '&&' ? $(n.left) && $(n.right) : $(n.left) || $(n.right),\n  ObjectExpression: ($, n) => n.properties.reduce((o, p) => {\n    $.memberDepth += 1;\n    const k = $(p.key);\n    $.memberDepth -= 1;\n    if (DisallowedMethods.has($(p.value))) {\n      // eslint-disable-next-line no-console\n      console.error(`Prevented interpretation of property \"${k}\" which could lead to insecure code execution`);\n    } else {\n      o[k] = $(p.value);\n    }\n    return o;\n  }, {})\n};\nfunction interpret (ast, fn, params, datum, event, item) {\n  const $ = n => Visitors[n.type]($, n);\n  $.memberDepth = 0;\n  $.fn = Object.create(fn);\n  $.params = params;\n  $.datum = datum;\n  $.event = event;\n  $.item = item;\n\n  // route event functions to annotated vega event context\n  EventFunctions.forEach(f => $.fn[f] = function () {\n    return event.vega[f](...arguments);\n  });\n  return $(ast);\n}\n\nvar expression = {\n  /**\n   * Parse an expression used to update an operator value.\n   */\n  operator(ctx, expr) {\n    const ast = expr.ast,\n      fn = ctx.functions;\n    return _ => interpret(ast, fn, _);\n  },\n  /**\n   * Parse an expression provided as an operator parameter value.\n   */\n  parameter(ctx, expr) {\n    const ast = expr.ast,\n      fn = ctx.functions;\n    return (datum, _) => interpret(ast, fn, _, datum);\n  },\n  /**\n   * Parse an expression applied to an event stream.\n   */\n  event(ctx, expr) {\n    const ast = expr.ast,\n      fn = ctx.functions;\n    return event => interpret(ast, fn, undefined, undefined, event);\n  },\n  /**\n   * Parse an expression used to handle an event-driven operator update.\n   */\n  handler(ctx, expr) {\n    const ast = expr.ast,\n      fn = ctx.functions;\n    return (_, event) => {\n      const datum = event.item && event.item.datum;\n      return interpret(ast, fn, _, datum, event);\n    };\n  },\n  /**\n   * Parse an expression that performs visual encoding.\n   */\n  encode(ctx, encode) {\n    const {\n        marktype,\n        channels\n      } = encode,\n      fn = ctx.functions,\n      swap = marktype === 'group' || marktype === 'image' || marktype === 'rect';\n    return (item, _) => {\n      const datum = item.datum;\n      let m = 0,\n        v;\n      for (const name in channels) {\n        v = interpret(channels[name].ast, fn, _, datum, undefined, item);\n        if (item[name] !== v) {\n          item[name] = v;\n          m = 1;\n        }\n      }\n      if (marktype !== 'rule') {\n        adjustSpatial(item, channels, swap);\n      }\n      return m;\n    };\n  }\n};\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-interpreter/build/vega-interpreter.module.js?");

/***/ }),

/***/ "../../node_modules/vega-label/build/vega-label.module.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-label/build/vega-label.module.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   label: () => (/* binding */ Label)\n/* harmony export */ });\n/* harmony import */ var vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-scenegraph */ \"../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js\");\n/* harmony import */ var vega_canvas__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-canvas */ \"../../node_modules/vega-canvas/build/vega-canvas.browser.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\n\n\n\n// bit mask for getting first 2 bytes of alpha value\nconst ALPHA_MASK = 0xff000000;\nfunction baseBitmaps($, data) {\n  const bitmap = $.bitmap();\n  // when there is no base mark but data points are to be avoided\n  (data || []).forEach(d => bitmap.set($(d.boundary[0]), $(d.boundary[3])));\n  return [bitmap, undefined];\n}\nfunction markBitmaps($, baseMark, avoidMarks, labelInside, isGroupArea) {\n  // create canvas\n  const width = $.width,\n    height = $.height,\n    border = labelInside || isGroupArea,\n    context = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_1__.canvas)(width, height).getContext('2d'),\n    baseMarkContext = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_1__.canvas)(width, height).getContext('2d'),\n    strokeContext = border && (0,vega_canvas__WEBPACK_IMPORTED_MODULE_1__.canvas)(width, height).getContext('2d');\n\n  // render all marks to be avoided into canvas\n  avoidMarks.forEach(items => draw(context, items, false));\n  draw(baseMarkContext, baseMark, false);\n  if (border) {\n    draw(strokeContext, baseMark, true);\n  }\n\n  // get canvas buffer, create bitmaps\n  const buffer = getBuffer(context, width, height),\n    baseMarkBuffer = getBuffer(baseMarkContext, width, height),\n    strokeBuffer = border && getBuffer(strokeContext, width, height),\n    layer1 = $.bitmap(),\n    layer2 = border && $.bitmap();\n\n  // populate bitmap layers\n  let x, y, u, v, index, alpha, strokeAlpha, baseMarkAlpha;\n  for (y = 0; y < height; ++y) {\n    for (x = 0; x < width; ++x) {\n      index = y * width + x;\n      alpha = buffer[index] & ALPHA_MASK;\n      baseMarkAlpha = baseMarkBuffer[index] & ALPHA_MASK;\n      strokeAlpha = border && strokeBuffer[index] & ALPHA_MASK;\n      if (alpha || strokeAlpha || baseMarkAlpha) {\n        u = $(x);\n        v = $(y);\n        if (!isGroupArea && (alpha || baseMarkAlpha)) layer1.set(u, v); // update interior bitmap\n        if (border && (alpha || strokeAlpha)) layer2.set(u, v); // update border bitmap\n      }\n    }\n  }\n\n  return [layer1, layer2];\n}\nfunction getBuffer(context, width, height) {\n  return new Uint32Array(context.getImageData(0, 0, width, height).data.buffer);\n}\nfunction draw(context, items, interior) {\n  if (!items.length) return;\n  const type = items[0].mark.marktype;\n  if (type === 'group') {\n    items.forEach(group => {\n      group.items.forEach(mark => draw(context, mark.items, interior));\n    });\n  } else {\n    vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.Marks[type].draw(context, {\n      items: interior ? items.map(prepare) : items\n    });\n  }\n}\n\n/**\n * Prepare item before drawing into canvas (setting stroke and opacity)\n * @param {object} source item to be prepared\n * @returns prepared item\n */\nfunction prepare(source) {\n  const item = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_2__.rederive)(source, {});\n  if (item.stroke && item.strokeOpacity !== 0 || item.fill && item.fillOpacity !== 0) {\n    return {\n      ...item,\n      strokeOpacity: 1,\n      stroke: '#000',\n      fillOpacity: 0\n    };\n  }\n  return item;\n}\n\nconst DIV = 5,\n  // bit shift from x, y index to bit vector array index\n  MOD = 31,\n  // bit mask for index lookup within a bit vector\n  SIZE = 32,\n  // individual bit vector size\n  RIGHT0 = new Uint32Array(SIZE + 1),\n  // left-anchored bit vectors, full -> 0\n  RIGHT1 = new Uint32Array(SIZE + 1); // right-anchored bit vectors, 0 -> full\n\nRIGHT1[0] = 0;\nRIGHT0[0] = ~RIGHT1[0];\nfor (let i = 1; i <= SIZE; ++i) {\n  RIGHT1[i] = RIGHT1[i - 1] << 1 | 1;\n  RIGHT0[i] = ~RIGHT1[i];\n}\nfunction Bitmap (w, h) {\n  const array = new Uint32Array(~~((w * h + SIZE) / SIZE));\n  function _set(index, mask) {\n    array[index] |= mask;\n  }\n  function _clear(index, mask) {\n    array[index] &= mask;\n  }\n  return {\n    array: array,\n    get: (x, y) => {\n      const index = y * w + x;\n      return array[index >>> DIV] & 1 << (index & MOD);\n    },\n    set: (x, y) => {\n      const index = y * w + x;\n      _set(index >>> DIV, 1 << (index & MOD));\n    },\n    clear: (x, y) => {\n      const index = y * w + x;\n      _clear(index >>> DIV, ~(1 << (index & MOD)));\n    },\n    getRange: (x, y, x2, y2) => {\n      let r = y2,\n        start,\n        end,\n        indexStart,\n        indexEnd;\n      for (; r >= y; --r) {\n        start = r * w + x;\n        end = r * w + x2;\n        indexStart = start >>> DIV;\n        indexEnd = end >>> DIV;\n        if (indexStart === indexEnd) {\n          if (array[indexStart] & RIGHT0[start & MOD] & RIGHT1[(end & MOD) + 1]) {\n            return true;\n          }\n        } else {\n          if (array[indexStart] & RIGHT0[start & MOD]) return true;\n          if (array[indexEnd] & RIGHT1[(end & MOD) + 1]) return true;\n          for (let i = indexStart + 1; i < indexEnd; ++i) {\n            if (array[i]) return true;\n          }\n        }\n      }\n      return false;\n    },\n    setRange: (x, y, x2, y2) => {\n      let start, end, indexStart, indexEnd, i;\n      for (; y <= y2; ++y) {\n        start = y * w + x;\n        end = y * w + x2;\n        indexStart = start >>> DIV;\n        indexEnd = end >>> DIV;\n        if (indexStart === indexEnd) {\n          _set(indexStart, RIGHT0[start & MOD] & RIGHT1[(end & MOD) + 1]);\n        } else {\n          _set(indexStart, RIGHT0[start & MOD]);\n          _set(indexEnd, RIGHT1[(end & MOD) + 1]);\n          for (i = indexStart + 1; i < indexEnd; ++i) _set(i, 0xffffffff);\n        }\n      }\n    },\n    clearRange: (x, y, x2, y2) => {\n      let start, end, indexStart, indexEnd, i;\n      for (; y <= y2; ++y) {\n        start = y * w + x;\n        end = y * w + x2;\n        indexStart = start >>> DIV;\n        indexEnd = end >>> DIV;\n        if (indexStart === indexEnd) {\n          _clear(indexStart, RIGHT1[start & MOD] | RIGHT0[(end & MOD) + 1]);\n        } else {\n          _clear(indexStart, RIGHT1[start & MOD]);\n          _clear(indexEnd, RIGHT0[(end & MOD) + 1]);\n          for (i = indexStart + 1; i < indexEnd; ++i) _clear(i, 0);\n        }\n      }\n    },\n    outOfBounds: (x, y, x2, y2) => x < 0 || y < 0 || y2 >= h || x2 >= w\n  };\n}\n\nfunction scaler (width, height, padding) {\n  const ratio = Math.max(1, Math.sqrt(width * height / 1e6)),\n    w = ~~((width + 2 * padding + ratio) / ratio),\n    h = ~~((height + 2 * padding + ratio) / ratio),\n    scale = _ => ~~((_ + padding) / ratio);\n  scale.invert = _ => _ * ratio - padding;\n  scale.bitmap = () => Bitmap(w, h);\n  scale.ratio = ratio;\n  scale.padding = padding;\n  scale.width = width;\n  scale.height = height;\n  return scale;\n}\n\nfunction placeAreaLabelNaive ($, bitmaps, avoidBaseMark, markIndex) {\n  const width = $.width,\n    height = $.height;\n\n  // try to place a label within an input area mark\n  return function (d) {\n    const items = d.datum.datum.items[markIndex].items,\n      // area points\n      n = items.length,\n      // number of points\n      textHeight = d.datum.fontSize,\n      // label width\n      textWidth = vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.textMetrics.width(d.datum, d.datum.text); // label height\n\n    let maxAreaWidth = 0,\n      x1,\n      x2,\n      y1,\n      y2,\n      x,\n      y,\n      areaWidth;\n\n    // for each area sample point\n    for (let i = 0; i < n; ++i) {\n      x1 = items[i].x;\n      y1 = items[i].y;\n      x2 = items[i].x2 === undefined ? x1 : items[i].x2;\n      y2 = items[i].y2 === undefined ? y1 : items[i].y2;\n      x = (x1 + x2) / 2;\n      y = (y1 + y2) / 2;\n      areaWidth = Math.abs(x2 - x1 + y2 - y1);\n      if (areaWidth >= maxAreaWidth) {\n        maxAreaWidth = areaWidth;\n        d.x = x;\n        d.y = y;\n      }\n    }\n    x = textWidth / 2;\n    y = textHeight / 2;\n    x1 = d.x - x;\n    x2 = d.x + x;\n    y1 = d.y - y;\n    y2 = d.y + y;\n    d.align = 'center';\n    if (x1 < 0 && x2 <= width) {\n      d.align = 'left';\n    } else if (0 <= x1 && width < x2) {\n      d.align = 'right';\n    }\n    d.baseline = 'middle';\n    if (y1 < 0 && y2 <= height) {\n      d.baseline = 'top';\n    } else if (0 <= y1 && height < y2) {\n      d.baseline = 'bottom';\n    }\n    return true;\n  };\n}\n\nfunction outOfBounds(x, y, textWidth, textHeight, width, height) {\n  let r = textWidth / 2;\n  return x - r < 0 || x + r > width || y - (r = textHeight / 2) < 0 || y + r > height;\n}\nfunction collision($, x, y, textHeight, textWidth, h, bm0, bm1) {\n  const w = textWidth * h / (textHeight * 2),\n    x1 = $(x - w),\n    x2 = $(x + w),\n    y1 = $(y - (h = h / 2)),\n    y2 = $(y + h);\n  return bm0.outOfBounds(x1, y1, x2, y2) || bm0.getRange(x1, y1, x2, y2) || bm1 && bm1.getRange(x1, y1, x2, y2);\n}\n\nfunction placeAreaLabelReducedSearch ($, bitmaps, avoidBaseMark, markIndex) {\n  const width = $.width,\n    height = $.height,\n    bm0 = bitmaps[0],\n    // where labels have been placed\n    bm1 = bitmaps[1]; // area outlines\n\n  function tryLabel(_x, _y, maxSize, textWidth, textHeight) {\n    const x = $.invert(_x),\n      y = $.invert(_y);\n    let lo = maxSize,\n      hi = height,\n      mid;\n    if (!outOfBounds(x, y, textWidth, textHeight, width, height) && !collision($, x, y, textHeight, textWidth, lo, bm0, bm1) && !collision($, x, y, textHeight, textWidth, textHeight, bm0, null)) {\n      // if the label fits at the current sample point,\n      // perform binary search to find the largest font size that fits\n      while (hi - lo >= 1) {\n        mid = (lo + hi) / 2;\n        if (collision($, x, y, textHeight, textWidth, mid, bm0, bm1)) {\n          hi = mid;\n        } else {\n          lo = mid;\n        }\n      }\n      // place label if current lower bound exceeds prior max font size\n      if (lo > maxSize) {\n        return [x, y, lo, true];\n      }\n    }\n  }\n\n  // try to place a label within an input area mark\n  return function (d) {\n    const items = d.datum.datum.items[markIndex].items,\n      // area points\n      n = items.length,\n      // number of points\n      textHeight = d.datum.fontSize,\n      // label width\n      textWidth = vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.textMetrics.width(d.datum, d.datum.text); // label height\n\n    let maxSize = avoidBaseMark ? textHeight : 0,\n      labelPlaced = false,\n      labelPlaced2 = false,\n      maxAreaWidth = 0,\n      x1,\n      x2,\n      y1,\n      y2,\n      x,\n      y,\n      _x,\n      _y,\n      _x1,\n      _xMid,\n      _x2,\n      _y1,\n      _yMid,\n      _y2,\n      areaWidth,\n      result,\n      swapTmp;\n\n    // for each area sample point\n    for (let i = 0; i < n; ++i) {\n      x1 = items[i].x;\n      y1 = items[i].y;\n      x2 = items[i].x2 === undefined ? x1 : items[i].x2;\n      y2 = items[i].y2 === undefined ? y1 : items[i].y2;\n      if (x1 > x2) {\n        swapTmp = x1;\n        x1 = x2;\n        x2 = swapTmp;\n      }\n      if (y1 > y2) {\n        swapTmp = y1;\n        y1 = y2;\n        y2 = swapTmp;\n      }\n      _x1 = $(x1);\n      _x2 = $(x2);\n      _xMid = ~~((_x1 + _x2) / 2);\n      _y1 = $(y1);\n      _y2 = $(y2);\n      _yMid = ~~((_y1 + _y2) / 2);\n\n      // search along the line from mid point between the 2 border to lower border\n      for (_x = _xMid; _x >= _x1; --_x) {\n        for (_y = _yMid; _y >= _y1; --_y) {\n          result = tryLabel(_x, _y, maxSize, textWidth, textHeight);\n          if (result) {\n            [d.x, d.y, maxSize, labelPlaced] = result;\n          }\n        }\n      }\n\n      // search along the line from mid point between the 2 border to upper border\n      for (_x = _xMid; _x <= _x2; ++_x) {\n        for (_y = _yMid; _y <= _y2; ++_y) {\n          result = tryLabel(_x, _y, maxSize, textWidth, textHeight);\n          if (result) {\n            [d.x, d.y, maxSize, labelPlaced] = result;\n          }\n        }\n      }\n\n      // place label at slice center if not placed through other means\n      // and if we're not avoiding overlap with other areas\n      if (!labelPlaced && !avoidBaseMark) {\n        // one span is zero, hence we can add\n        areaWidth = Math.abs(x2 - x1 + y2 - y1);\n        x = (x1 + x2) / 2;\n        y = (y1 + y2) / 2;\n\n        // place label if it fits and improves the max area width\n        if (areaWidth >= maxAreaWidth && !outOfBounds(x, y, textWidth, textHeight, width, height) && !collision($, x, y, textHeight, textWidth, textHeight, bm0, null)) {\n          maxAreaWidth = areaWidth;\n          d.x = x;\n          d.y = y;\n          labelPlaced2 = true;\n        }\n      }\n    }\n\n    // record current label placement information, update label bitmap\n    if (labelPlaced || labelPlaced2) {\n      x = textWidth / 2;\n      y = textHeight / 2;\n      bm0.setRange($(d.x - x), $(d.y - y), $(d.x + x), $(d.y + y));\n      d.align = 'center';\n      d.baseline = 'middle';\n      return true;\n    } else {\n      return false;\n    }\n  };\n}\n\n// pixel direction offsets for flood fill search\nconst X_DIR = [-1, -1, 1, 1];\nconst Y_DIR = [-1, 1, -1, 1];\nfunction placeAreaLabelFloodFill ($, bitmaps, avoidBaseMark, markIndex) {\n  const width = $.width,\n    height = $.height,\n    bm0 = bitmaps[0],\n    // where labels have been placed\n    bm1 = bitmaps[1],\n    // area outlines\n    bm2 = $.bitmap(); // flood-fill visitations\n\n  // try to place a label within an input area mark\n  return function (d) {\n    const items = d.datum.datum.items[markIndex].items,\n      // area points\n      n = items.length,\n      // number of points\n      textHeight = d.datum.fontSize,\n      // label width\n      textWidth = vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.textMetrics.width(d.datum, d.datum.text),\n      // label height\n      stack = []; // flood fill stack\n\n    let maxSize = avoidBaseMark ? textHeight : 0,\n      labelPlaced = false,\n      labelPlaced2 = false,\n      maxAreaWidth = 0,\n      x1,\n      x2,\n      y1,\n      y2,\n      x,\n      y,\n      _x,\n      _y,\n      lo,\n      hi,\n      mid,\n      areaWidth;\n\n    // for each area sample point\n    for (let i = 0; i < n; ++i) {\n      x1 = items[i].x;\n      y1 = items[i].y;\n      x2 = items[i].x2 === undefined ? x1 : items[i].x2;\n      y2 = items[i].y2 === undefined ? y1 : items[i].y2;\n\n      // add scaled center point to stack\n      stack.push([$((x1 + x2) / 2), $((y1 + y2) / 2)]);\n\n      // perform flood fill, visit points\n      while (stack.length) {\n        [_x, _y] = stack.pop();\n\n        // exit if point already marked\n        if (bm0.get(_x, _y) || bm1.get(_x, _y) || bm2.get(_x, _y)) continue;\n\n        // mark point in flood fill bitmap\n        // add search points for all (in bound) directions\n        bm2.set(_x, _y);\n        for (let j = 0; j < 4; ++j) {\n          x = _x + X_DIR[j];\n          y = _y + Y_DIR[j];\n          if (!bm2.outOfBounds(x, y, x, y)) stack.push([x, y]);\n        }\n\n        // unscale point back to x, y space\n        x = $.invert(_x);\n        y = $.invert(_y);\n        lo = maxSize;\n        hi = height; // TODO: make this bound smaller\n\n        if (!outOfBounds(x, y, textWidth, textHeight, width, height) && !collision($, x, y, textHeight, textWidth, lo, bm0, bm1) && !collision($, x, y, textHeight, textWidth, textHeight, bm0, null)) {\n          // if the label fits at the current sample point,\n          // perform binary search to find the largest font size that fits\n          while (hi - lo >= 1) {\n            mid = (lo + hi) / 2;\n            if (collision($, x, y, textHeight, textWidth, mid, bm0, bm1)) {\n              hi = mid;\n            } else {\n              lo = mid;\n            }\n          }\n          // place label if current lower bound exceeds prior max font size\n          if (lo > maxSize) {\n            d.x = x;\n            d.y = y;\n            maxSize = lo;\n            labelPlaced = true;\n          }\n        }\n      }\n\n      // place label at slice center if not placed through other means\n      // and if we're not avoiding overlap with other areas\n      if (!labelPlaced && !avoidBaseMark) {\n        // one span is zero, hence we can add\n        areaWidth = Math.abs(x2 - x1 + y2 - y1);\n        x = (x1 + x2) / 2;\n        y = (y1 + y2) / 2;\n\n        // place label if it fits and improves the max area width\n        if (areaWidth >= maxAreaWidth && !outOfBounds(x, y, textWidth, textHeight, width, height) && !collision($, x, y, textHeight, textWidth, textHeight, bm0, null)) {\n          maxAreaWidth = areaWidth;\n          d.x = x;\n          d.y = y;\n          labelPlaced2 = true;\n        }\n      }\n    }\n\n    // record current label placement information, update label bitmap\n    if (labelPlaced || labelPlaced2) {\n      x = textWidth / 2;\n      y = textHeight / 2;\n      bm0.setRange($(d.x - x), $(d.y - y), $(d.x + x), $(d.y + y));\n      d.align = 'center';\n      d.baseline = 'middle';\n      return true;\n    } else {\n      return false;\n    }\n  };\n}\n\nconst Aligns = ['right', 'center', 'left'],\n  Baselines = ['bottom', 'middle', 'top'];\nfunction placeMarkLabel ($, bitmaps, anchors, offsets) {\n  const width = $.width,\n    height = $.height,\n    bm0 = bitmaps[0],\n    bm1 = bitmaps[1],\n    n = offsets.length;\n  return function (d) {\n    const boundary = d.boundary,\n      textHeight = d.datum.fontSize;\n\n    // can not be placed if the mark is not visible in the graph bound\n    if (boundary[2] < 0 || boundary[5] < 0 || boundary[0] > width || boundary[3] > height) {\n      return false;\n    }\n    let textWidth = d.textWidth ?? 0,\n      dx,\n      dy,\n      isInside,\n      sizeFactor,\n      insideFactor,\n      x1,\n      x2,\n      y1,\n      y2,\n      xc,\n      yc,\n      _x1,\n      _x2,\n      _y1,\n      _y2;\n\n    // for each anchor and offset\n    for (let i = 0; i < n; ++i) {\n      dx = (anchors[i] & 0x3) - 1;\n      dy = (anchors[i] >>> 0x2 & 0x3) - 1;\n      isInside = dx === 0 && dy === 0 || offsets[i] < 0;\n      sizeFactor = dx && dy ? Math.SQRT1_2 : 1;\n      insideFactor = offsets[i] < 0 ? -1 : 1;\n      x1 = boundary[1 + dx] + offsets[i] * dx * sizeFactor;\n      yc = boundary[4 + dy] + insideFactor * textHeight * dy / 2 + offsets[i] * dy * sizeFactor;\n      y1 = yc - textHeight / 2;\n      y2 = yc + textHeight / 2;\n      _x1 = $(x1);\n      _y1 = $(y1);\n      _y2 = $(y2);\n      if (!textWidth) {\n        // to avoid finding width of text label,\n        if (!test(_x1, _x1, _y1, _y2, bm0, bm1, x1, x1, y1, y2, boundary, isInside)) {\n          // skip this anchor/offset option if we fail to place a label with 1px width\n          continue;\n        } else {\n          // Otherwise, find the label width\n          textWidth = vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.textMetrics.width(d.datum, d.datum.text);\n        }\n      }\n      xc = x1 + insideFactor * textWidth * dx / 2;\n      x1 = xc - textWidth / 2;\n      x2 = xc + textWidth / 2;\n      _x1 = $(x1);\n      _x2 = $(x2);\n      if (test(_x1, _x2, _y1, _y2, bm0, bm1, x1, x2, y1, y2, boundary, isInside)) {\n        // place label if the position is placeable\n        d.x = !dx ? xc : dx * insideFactor < 0 ? x2 : x1;\n        d.y = !dy ? yc : dy * insideFactor < 0 ? y2 : y1;\n        d.align = Aligns[dx * insideFactor + 1];\n        d.baseline = Baselines[dy * insideFactor + 1];\n        bm0.setRange(_x1, _y1, _x2, _y2);\n        return true;\n      }\n    }\n    return false;\n  };\n}\n\n// Test if a label with the given dimensions can be added without overlap\nfunction test(_x1, _x2, _y1, _y2, bm0, bm1, x1, x2, y1, y2, boundary, isInside) {\n  return !(bm0.outOfBounds(_x1, _y1, _x2, _y2) || (isInside && bm1 || bm0).getRange(_x1, _y1, _x2, _y2));\n}\n\n// 8-bit representation of anchors\nconst TOP = 0x0,\n  MIDDLE = 0x4,\n  BOTTOM = 0x8,\n  LEFT = 0x0,\n  CENTER = 0x1,\n  RIGHT = 0x2;\n\n// Mapping from text anchor to number representation\nconst anchorCode = {\n  'top-left': TOP + LEFT,\n  'top': TOP + CENTER,\n  'top-right': TOP + RIGHT,\n  'left': MIDDLE + LEFT,\n  'middle': MIDDLE + CENTER,\n  'right': MIDDLE + RIGHT,\n  'bottom-left': BOTTOM + LEFT,\n  'bottom': BOTTOM + CENTER,\n  'bottom-right': BOTTOM + RIGHT\n};\nconst placeAreaLabel = {\n  'naive': placeAreaLabelNaive,\n  'reduced-search': placeAreaLabelReducedSearch,\n  'floodfill': placeAreaLabelFloodFill\n};\nfunction labelLayout (texts, size, compare, offset, anchor, avoidMarks, avoidBaseMark, lineAnchor, markIndex, padding, method) {\n  // early exit for empty data\n  if (!texts.length) return texts;\n  const positions = Math.max(offset.length, anchor.length),\n    offsets = getOffsets(offset, positions),\n    anchors = getAnchors(anchor, positions),\n    marktype = markType(texts[0].datum),\n    grouptype = marktype === 'group' && texts[0].datum.items[markIndex].marktype,\n    isGroupArea = grouptype === 'area',\n    boundary = markBoundary(marktype, grouptype, lineAnchor, markIndex),\n    infPadding = padding === null || padding === Infinity,\n    isNaiveGroupArea = isGroupArea && method === 'naive';\n  let maxTextWidth = -1,\n    maxTextHeight = -1;\n\n  // prepare text mark data for placing\n  const data = texts.map(d => {\n    const textWidth = infPadding ? vega_scenegraph__WEBPACK_IMPORTED_MODULE_0__.textMetrics.width(d, d.text) : undefined;\n    maxTextWidth = Math.max(maxTextWidth, textWidth);\n    maxTextHeight = Math.max(maxTextHeight, d.fontSize);\n    return {\n      datum: d,\n      opacity: 0,\n      x: undefined,\n      y: undefined,\n      align: undefined,\n      baseline: undefined,\n      boundary: boundary(d),\n      textWidth\n    };\n  });\n  padding = padding === null || padding === Infinity ? Math.max(maxTextWidth, maxTextHeight) + Math.max(...offset) : padding;\n  const $ = scaler(size[0], size[1], padding);\n  let bitmaps;\n  if (!isNaiveGroupArea) {\n    // sort labels in priority order, if comparator is provided\n    if (compare) {\n      data.sort((a, b) => compare(a.datum, b.datum));\n    }\n\n    // flag indicating if label can be placed inside its base mark\n    let labelInside = false;\n    for (let i = 0; i < anchors.length && !labelInside; ++i) {\n      // label inside if anchor is at center\n      // label inside if offset to be inside the mark bound\n      labelInside = anchors[i] === 0x5 || offsets[i] < 0;\n    }\n\n    // extract data information from base mark when base mark is to be avoided\n    // base mark is implicitly avoided if it is a group area\n    const baseMark = (marktype && avoidBaseMark || isGroupArea) && texts.map(d => d.datum);\n\n    // generate bitmaps for layout calculation\n    bitmaps = avoidMarks.length || baseMark ? markBitmaps($, baseMark || [], avoidMarks, labelInside, isGroupArea) : baseBitmaps($, avoidBaseMark && data);\n  }\n\n  // generate label placement function\n  const place = isGroupArea ? placeAreaLabel[method]($, bitmaps, avoidBaseMark, markIndex) : placeMarkLabel($, bitmaps, anchors, offsets);\n\n  // place all labels\n  data.forEach(d => d.opacity = +place(d));\n  return data;\n}\nfunction getOffsets(_, count) {\n  const offsets = new Float64Array(count),\n    n = _.length;\n  for (let i = 0; i < n; ++i) offsets[i] = _[i] || 0;\n  for (let i = n; i < count; ++i) offsets[i] = offsets[n - 1];\n  return offsets;\n}\nfunction getAnchors(_, count) {\n  const anchors = new Int8Array(count),\n    n = _.length;\n  for (let i = 0; i < n; ++i) anchors[i] |= anchorCode[_[i]];\n  for (let i = n; i < count; ++i) anchors[i] = anchors[n - 1];\n  return anchors;\n}\nfunction markType(item) {\n  return item && item.mark && item.mark.marktype;\n}\n\n/**\n * Factory function for function for getting base mark boundary, depending\n * on mark and group type. When mark type is undefined, line or area: boundary\n * is the coordinate of each data point. When base mark is grouped line,\n * boundary is either at the start or end of the line depending on the\n * value of lineAnchor. Otherwise, use bounds of base mark.\n */\nfunction markBoundary(marktype, grouptype, lineAnchor, markIndex) {\n  const xy = d => [d.x, d.x, d.x, d.y, d.y, d.y];\n  if (!marktype) {\n    return xy; // no reactive geometry\n  } else if (marktype === 'line' || marktype === 'area') {\n    return d => xy(d.datum);\n  } else if (grouptype === 'line') {\n    return d => {\n      const items = d.datum.items[markIndex].items;\n      return xy(items.length ? items[lineAnchor === 'start' ? 0 : items.length - 1] : {\n        x: NaN,\n        y: NaN\n      });\n    };\n  } else {\n    return d => {\n      const b = d.datum.bounds;\n      return [b.x1, (b.x1 + b.x2) / 2, b.x2, b.y1, (b.y1 + b.y2) / 2, b.y2];\n    };\n  }\n}\n\nconst Output = ['x', 'y', 'opacity', 'align', 'baseline'];\nconst Anchors = ['top-left', 'left', 'bottom-left', 'top', 'bottom', 'top-right', 'right', 'bottom-right'];\n\n/**\n * Compute text label layout to annotate marks.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<number>} params.size - The size of the layout, provided as a [width, height] array.\n * @param {function(*,*): number} [params.sort] - An optional\n *   comparator function for sorting label data in priority order.\n * @param {Array<string>} [params.anchor] - Label anchor points relative to the base mark bounding box.\n *   The available options are 'top-left', 'left', 'bottom-left', 'top',\n *   'bottom', 'top-right', 'right', 'bottom-right', 'middle'.\n * @param {Array<number>} [params.offset] - Label offsets (in pixels) from the base mark bounding box.\n *   This parameter is parallel to the list of anchor points.\n * @param {number | null} [params.padding=0] - The amount (in pixels) that a label may exceed the layout size.\n *   If this parameter is null, a label may exceed the layout size without any boundary.\n * @param {string} [params.lineAnchor='end'] - For group line mark labels only, indicates the anchor\n *   position for labels. One of 'start' or 'end'.\n * @param {string} [params.markIndex=0] - For group mark labels only, an index indicating\n *   which mark within the group should be labeled.\n * @param {Array<number>} [params.avoidMarks] - A list of additional mark names for which the label\n *   layout should avoid overlap.\n * @param {boolean} [params.avoidBaseMark=true] - Boolean flag indicating if labels should avoid\n *   overlap with the underlying base mark being labeled.\n * @param {string} [params.method='naive'] - For area make labels only, a method for\n *   place labels. One of 'naive', 'reduced-search', or 'floodfill'.\n * @param {Array<string>} [params.as] - The output fields written by the transform.\n *   The default is ['x', 'y', 'opacity', 'align', 'baseline'].\n */\nfunction Label(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_2__.Transform.call(this, null, params);\n}\nLabel.Definition = {\n  type: 'Label',\n  metadata: {\n    modifies: true\n  },\n  params: [{\n    name: 'size',\n    type: 'number',\n    array: true,\n    length: 2,\n    required: true\n  }, {\n    name: 'sort',\n    type: 'compare'\n  }, {\n    name: 'anchor',\n    type: 'string',\n    array: true,\n    default: Anchors\n  }, {\n    name: 'offset',\n    type: 'number',\n    array: true,\n    default: [1]\n  }, {\n    name: 'padding',\n    type: 'number',\n    default: 0,\n    null: true\n  }, {\n    name: 'lineAnchor',\n    type: 'string',\n    values: ['start', 'end'],\n    default: 'end'\n  }, {\n    name: 'markIndex',\n    type: 'number',\n    default: 0\n  }, {\n    name: 'avoidBaseMark',\n    type: 'boolean',\n    default: true\n  }, {\n    name: 'avoidMarks',\n    type: 'data',\n    array: true\n  }, {\n    name: 'method',\n    type: 'string',\n    default: 'naive'\n  }, {\n    name: 'as',\n    type: 'string',\n    array: true,\n    length: Output.length,\n    default: Output\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_3__.inherits)(Label, vega_dataflow__WEBPACK_IMPORTED_MODULE_2__.Transform, {\n  transform(_, pulse) {\n    function modp(param) {\n      const p = _[param];\n      return (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.isFunction)(p) && pulse.modified(p.fields);\n    }\n    const mod = _.modified();\n    if (!(mod || pulse.changed(pulse.ADD_REM) || modp('sort'))) return;\n    if (!_.size || _.size.length !== 2) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.error)('Size parameter should be specified as a [width, height] array.');\n    }\n    const as = _.as || Output;\n\n    // run label layout\n    labelLayout(pulse.materialize(pulse.SOURCE).source || [], _.size, _.sort, (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.array)(_.offset == null ? 1 : _.offset), (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.array)(_.anchor || Anchors), _.avoidMarks || [], _.avoidBaseMark !== false, _.lineAnchor || 'end', _.markIndex || 0, _.padding === undefined ? 0 : _.padding, _.method || 'naive').forEach(l => {\n      // write layout results to data stream\n      const t = l.datum;\n      t[as[0]] = l.x;\n      t[as[1]] = l.y;\n      t[as[2]] = l.opacity;\n      t[as[3]] = l.align;\n      t[as[4]] = l.baseline;\n    });\n    return pulse.reflow(mod).modifies(as);\n  }\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-label/build/vega-label.module.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/aggregate.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/aggregate.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   COUNTING_OPS: () => (/* binding */ COUNTING_OPS),\n/* harmony export */   MULTIDOMAIN_SORT_OP_INDEX: () => (/* binding */ MULTIDOMAIN_SORT_OP_INDEX),\n/* harmony export */   SHARED_DOMAIN_OPS: () => (/* binding */ SHARED_DOMAIN_OPS),\n/* harmony export */   SUM_OPS: () => (/* binding */ SUM_OPS),\n/* harmony export */   isAggregateOp: () => (/* binding */ isAggregateOp),\n/* harmony export */   isArgmaxDef: () => (/* binding */ isArgmaxDef),\n/* harmony export */   isArgminDef: () => (/* binding */ isArgminDef),\n/* harmony export */   isCountingAggregateOp: () => (/* binding */ isCountingAggregateOp),\n/* harmony export */   isMinMaxOp: () => (/* binding */ isMinMaxOp)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\nconst AGGREGATE_OP_INDEX = {\n    argmax: 1,\n    argmin: 1,\n    average: 1,\n    count: 1,\n    distinct: 1,\n    product: 1,\n    max: 1,\n    mean: 1,\n    median: 1,\n    min: 1,\n    missing: 1,\n    q1: 1,\n    q3: 1,\n    ci0: 1,\n    ci1: 1,\n    stderr: 1,\n    stdev: 1,\n    stdevp: 1,\n    sum: 1,\n    valid: 1,\n    values: 1,\n    variance: 1,\n    variancep: 1\n};\nconst MULTIDOMAIN_SORT_OP_INDEX = {\n    count: 1,\n    min: 1,\n    max: 1\n};\nfunction isArgminDef(a) {\n    return !!a && !!a['argmin'];\n}\nfunction isArgmaxDef(a) {\n    return !!a && !!a['argmax'];\n}\nfunction isAggregateOp(a) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(a) && !!AGGREGATE_OP_INDEX[a];\n}\nconst COUNTING_OPS = new Set([\n    'count',\n    'valid',\n    'missing',\n    'distinct'\n]);\nfunction isCountingAggregateOp(aggregate) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(aggregate) && COUNTING_OPS.has(aggregate);\n}\nfunction isMinMaxOp(aggregate) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(aggregate) && (0,_util__WEBPACK_IMPORTED_MODULE_1__.contains)(['min', 'max'], aggregate);\n}\n/** Additive-based aggregation operations. These can be applied to stack. */\nconst SUM_OPS = new Set([\n    'count',\n    'sum',\n    'distinct',\n    'valid',\n    'missing'\n]);\n/**\n * Aggregation operators that always produce values within the range [domainMin, domainMax].\n */\nconst SHARED_DOMAIN_OPS = new Set([\n    'mean',\n    'average',\n    'median',\n    'q1',\n    'q3',\n    'min',\n    'max'\n]);\n//# sourceMappingURL=aggregate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/aggregate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/axis.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/axis.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AXIS_CONFIGS: () => (/* binding */ AXIS_CONFIGS),\n/* harmony export */   AXIS_PARTS: () => (/* binding */ AXIS_PARTS),\n/* harmony export */   AXIS_PROPERTIES: () => (/* binding */ AXIS_PROPERTIES),\n/* harmony export */   AXIS_PROPERTY_TYPE: () => (/* binding */ AXIS_PROPERTY_TYPE),\n/* harmony export */   COMMON_AXIS_PROPERTIES_INDEX: () => (/* binding */ COMMON_AXIS_PROPERTIES_INDEX),\n/* harmony export */   CONDITIONAL_AXIS_PROP_INDEX: () => (/* binding */ CONDITIONAL_AXIS_PROP_INDEX),\n/* harmony export */   isAxisProperty: () => (/* binding */ isAxisProperty),\n/* harmony export */   isConditionalAxisValue: () => (/* binding */ isConditionalAxisValue)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\nconst CONDITIONAL_AXIS_PROP_INDEX = {\n    labelAlign: {\n        part: 'labels',\n        vgProp: 'align'\n    },\n    labelBaseline: {\n        part: 'labels',\n        vgProp: 'baseline'\n    },\n    labelColor: {\n        part: 'labels',\n        vgProp: 'fill'\n    },\n    labelFont: {\n        part: 'labels',\n        vgProp: 'font'\n    },\n    labelFontSize: {\n        part: 'labels',\n        vgProp: 'fontSize'\n    },\n    labelFontStyle: {\n        part: 'labels',\n        vgProp: 'fontStyle'\n    },\n    labelFontWeight: {\n        part: 'labels',\n        vgProp: 'fontWeight'\n    },\n    labelOpacity: {\n        part: 'labels',\n        vgProp: 'opacity'\n    },\n    labelOffset: null,\n    labelPadding: null,\n    gridColor: {\n        part: 'grid',\n        vgProp: 'stroke'\n    },\n    gridDash: {\n        part: 'grid',\n        vgProp: 'strokeDash'\n    },\n    gridDashOffset: {\n        part: 'grid',\n        vgProp: 'strokeDashOffset'\n    },\n    gridOpacity: {\n        part: 'grid',\n        vgProp: 'opacity'\n    },\n    gridWidth: {\n        part: 'grid',\n        vgProp: 'strokeWidth'\n    },\n    tickColor: {\n        part: 'ticks',\n        vgProp: 'stroke'\n    },\n    tickDash: {\n        part: 'ticks',\n        vgProp: 'strokeDash'\n    },\n    tickDashOffset: {\n        part: 'ticks',\n        vgProp: 'strokeDashOffset'\n    },\n    tickOpacity: {\n        part: 'ticks',\n        vgProp: 'opacity'\n    },\n    tickSize: null,\n    tickWidth: {\n        part: 'ticks',\n        vgProp: 'strokeWidth'\n    }\n};\nfunction isConditionalAxisValue(v) {\n    return v?.condition;\n}\nconst AXIS_PARTS = ['domain', 'grid', 'labels', 'ticks', 'title'];\n/**\n * A dictionary listing whether a certain axis property is applicable for only main axes or only grid axes.\n */\nconst AXIS_PROPERTY_TYPE = {\n    grid: 'grid',\n    gridCap: 'grid',\n    gridColor: 'grid',\n    gridDash: 'grid',\n    gridDashOffset: 'grid',\n    gridOpacity: 'grid',\n    gridScale: 'grid',\n    gridWidth: 'grid',\n    orient: 'main',\n    bandPosition: 'both',\n    aria: 'main',\n    description: 'main',\n    domain: 'main',\n    domainCap: 'main',\n    domainColor: 'main',\n    domainDash: 'main',\n    domainDashOffset: 'main',\n    domainOpacity: 'main',\n    domainWidth: 'main',\n    format: 'main',\n    formatType: 'main',\n    labelAlign: 'main',\n    labelAngle: 'main',\n    labelBaseline: 'main',\n    labelBound: 'main',\n    labelColor: 'main',\n    labelFlush: 'main',\n    labelFlushOffset: 'main',\n    labelFont: 'main',\n    labelFontSize: 'main',\n    labelFontStyle: 'main',\n    labelFontWeight: 'main',\n    labelLimit: 'main',\n    labelLineHeight: 'main',\n    labelOffset: 'main',\n    labelOpacity: 'main',\n    labelOverlap: 'main',\n    labelPadding: 'main',\n    labels: 'main',\n    labelSeparation: 'main',\n    maxExtent: 'main',\n    minExtent: 'main',\n    offset: 'both',\n    position: 'main',\n    tickCap: 'main',\n    tickColor: 'main',\n    tickDash: 'main',\n    tickDashOffset: 'main',\n    tickMinStep: 'both',\n    tickOffset: 'both',\n    tickOpacity: 'main',\n    tickRound: 'both',\n    ticks: 'main',\n    tickSize: 'main',\n    tickWidth: 'both',\n    title: 'main',\n    titleAlign: 'main',\n    titleAnchor: 'main',\n    titleAngle: 'main',\n    titleBaseline: 'main',\n    titleColor: 'main',\n    titleFont: 'main',\n    titleFontSize: 'main',\n    titleFontStyle: 'main',\n    titleFontWeight: 'main',\n    titleLimit: 'main',\n    titleLineHeight: 'main',\n    titleOpacity: 'main',\n    titlePadding: 'main',\n    titleX: 'main',\n    titleY: 'main',\n    encode: 'both',\n    scale: 'both',\n    tickBand: 'both',\n    tickCount: 'both',\n    tickExtra: 'both',\n    translate: 'both',\n    values: 'both',\n    zindex: 'both' // this is actually set afterward, so it doesn't matter\n};\nconst COMMON_AXIS_PROPERTIES_INDEX = {\n    orient: 1,\n    aria: 1,\n    bandPosition: 1,\n    description: 1,\n    domain: 1,\n    domainCap: 1,\n    domainColor: 1,\n    domainDash: 1,\n    domainDashOffset: 1,\n    domainOpacity: 1,\n    domainWidth: 1,\n    format: 1,\n    formatType: 1,\n    grid: 1,\n    gridCap: 1,\n    gridColor: 1,\n    gridDash: 1,\n    gridDashOffset: 1,\n    gridOpacity: 1,\n    gridWidth: 1,\n    labelAlign: 1,\n    labelAngle: 1,\n    labelBaseline: 1,\n    labelBound: 1,\n    labelColor: 1,\n    labelFlush: 1,\n    labelFlushOffset: 1,\n    labelFont: 1,\n    labelFontSize: 1,\n    labelFontStyle: 1,\n    labelFontWeight: 1,\n    labelLimit: 1,\n    labelLineHeight: 1,\n    labelOffset: 1,\n    labelOpacity: 1,\n    labelOverlap: 1,\n    labelPadding: 1,\n    labels: 1,\n    labelSeparation: 1,\n    maxExtent: 1,\n    minExtent: 1,\n    offset: 1,\n    position: 1,\n    tickBand: 1,\n    tickCap: 1,\n    tickColor: 1,\n    tickCount: 1,\n    tickDash: 1,\n    tickDashOffset: 1,\n    tickExtra: 1,\n    tickMinStep: 1,\n    tickOffset: 1,\n    tickOpacity: 1,\n    tickRound: 1,\n    ticks: 1,\n    tickSize: 1,\n    tickWidth: 1,\n    title: 1,\n    titleAlign: 1,\n    titleAnchor: 1,\n    titleAngle: 1,\n    titleBaseline: 1,\n    titleColor: 1,\n    titleFont: 1,\n    titleFontSize: 1,\n    titleFontStyle: 1,\n    titleFontWeight: 1,\n    titleLimit: 1,\n    titleLineHeight: 1,\n    titleOpacity: 1,\n    titlePadding: 1,\n    titleX: 1,\n    titleY: 1,\n    translate: 1,\n    values: 1,\n    zindex: 1\n};\nconst AXIS_PROPERTIES_INDEX = {\n    ...COMMON_AXIS_PROPERTIES_INDEX,\n    style: 1,\n    labelExpr: 1,\n    encoding: 1\n};\nfunction isAxisProperty(prop) {\n    return !!AXIS_PROPERTIES_INDEX[prop];\n}\n// Export for dependent projects\nconst AXIS_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(AXIS_PROPERTIES_INDEX);\nconst AXIS_CONFIGS_INDEX = {\n    axis: 1,\n    axisBand: 1,\n    axisBottom: 1,\n    axisDiscrete: 1,\n    axisLeft: 1,\n    axisPoint: 1,\n    axisQuantitative: 1,\n    axisRight: 1,\n    axisTemporal: 1,\n    axisTop: 1,\n    axisX: 1,\n    axisXBand: 1,\n    axisXDiscrete: 1,\n    axisXPoint: 1,\n    axisXQuantitative: 1,\n    axisXTemporal: 1,\n    axisY: 1,\n    axisYBand: 1,\n    axisYDiscrete: 1,\n    axisYPoint: 1,\n    axisYQuantitative: 1,\n    axisYTemporal: 1\n};\nconst AXIS_CONFIGS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(AXIS_CONFIGS_INDEX);\n//# sourceMappingURL=axis.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/axis.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/bin.js":
/*!*****************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/bin.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   autoMaxBins: () => (/* binding */ autoMaxBins),\n/* harmony export */   binToString: () => (/* binding */ binToString),\n/* harmony export */   isBinParams: () => (/* binding */ isBinParams),\n/* harmony export */   isBinned: () => (/* binding */ isBinned),\n/* harmony export */   isBinning: () => (/* binding */ isBinning),\n/* harmony export */   isParameterExtent: () => (/* binding */ isParameterExtent)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n/**\n * Create a key for the bin configuration. Not for prebinned bin.\n */\nfunction binToString(bin) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean)(bin)) {\n        bin = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.normalizeBin)(bin, undefined);\n    }\n    return ('bin' +\n        (0,_util__WEBPACK_IMPORTED_MODULE_3__.keys)(bin)\n            .map(p => (isParameterExtent(bin[p]) ? (0,_util__WEBPACK_IMPORTED_MODULE_3__.varName)(`_${p}_${(0,_util__WEBPACK_IMPORTED_MODULE_3__.entries)(bin[p])}`) : (0,_util__WEBPACK_IMPORTED_MODULE_3__.varName)(`_${p}_${bin[p]}`)))\n            .join(''));\n}\n/**\n * Vega-Lite should bin the data.\n */\nfunction isBinning(bin) {\n    return bin === true || (isBinParams(bin) && !bin.binned);\n}\n/**\n * The data is already binned and so Vega-Lite should not bin it again.\n */\nfunction isBinned(bin) {\n    return bin === 'binned' || (isBinParams(bin) && bin.binned === true);\n}\nfunction isBinParams(bin) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(bin);\n}\nfunction isParameterExtent(extent) {\n    return extent?.['param'];\n}\nfunction autoMaxBins(channel) {\n    switch (channel) {\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.ROW:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.COLUMN:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.SIZE:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.COLOR:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.FILL:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.STROKE:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.STROKEWIDTH:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.OPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.FILLOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.STROKEOPACITY:\n        // Facets and Size shouldn't have too many bins\n        // We choose 6 like shape to simplify the rule [falls through]\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.SHAPE:\n            return 6; // Vega's \"shape\" has 6 distinct values\n        case _channel__WEBPACK_IMPORTED_MODULE_1__.STROKEDASH:\n            return 4; // We only provide 5 different stroke dash values (but 4 is more effective)\n        default:\n            return 10;\n    }\n}\n//# sourceMappingURL=bin.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/bin.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/channel.js":
/*!*********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/channel.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ANGLE: () => (/* binding */ ANGLE),\n/* harmony export */   CHANNELS: () => (/* binding */ CHANNELS),\n/* harmony export */   COLOR: () => (/* binding */ COLOR),\n/* harmony export */   COLUMN: () => (/* binding */ COLUMN),\n/* harmony export */   DESCRIPTION: () => (/* binding */ DESCRIPTION),\n/* harmony export */   DETAIL: () => (/* binding */ DETAIL),\n/* harmony export */   FACET: () => (/* binding */ FACET),\n/* harmony export */   FACET_CHANNELS: () => (/* binding */ FACET_CHANNELS),\n/* harmony export */   FILL: () => (/* binding */ FILL),\n/* harmony export */   FILLOPACITY: () => (/* binding */ FILLOPACITY),\n/* harmony export */   GEOPOSITION_CHANNELS: () => (/* binding */ GEOPOSITION_CHANNELS),\n/* harmony export */   HREF: () => (/* binding */ HREF),\n/* harmony export */   KEY: () => (/* binding */ KEY),\n/* harmony export */   LATITUDE: () => (/* binding */ LATITUDE),\n/* harmony export */   LATITUDE2: () => (/* binding */ LATITUDE2),\n/* harmony export */   LONGITUDE: () => (/* binding */ LONGITUDE),\n/* harmony export */   LONGITUDE2: () => (/* binding */ LONGITUDE2),\n/* harmony export */   NONPOSITION_CHANNELS: () => (/* binding */ NONPOSITION_CHANNELS),\n/* harmony export */   NONPOSITION_SCALE_CHANNELS: () => (/* binding */ NONPOSITION_SCALE_CHANNELS),\n/* harmony export */   OFFSET_SCALE_CHANNELS: () => (/* binding */ OFFSET_SCALE_CHANNELS),\n/* harmony export */   OPACITY: () => (/* binding */ OPACITY),\n/* harmony export */   ORDER: () => (/* binding */ ORDER),\n/* harmony export */   POLAR_POSITION_SCALE_CHANNELS: () => (/* binding */ POLAR_POSITION_SCALE_CHANNELS),\n/* harmony export */   POLAR_POSITION_SCALE_CHANNEL_INDEX: () => (/* binding */ POLAR_POSITION_SCALE_CHANNEL_INDEX),\n/* harmony export */   POSITION_SCALE_CHANNELS: () => (/* binding */ POSITION_SCALE_CHANNELS),\n/* harmony export */   RADIUS: () => (/* binding */ RADIUS),\n/* harmony export */   RADIUS2: () => (/* binding */ RADIUS2),\n/* harmony export */   ROW: () => (/* binding */ ROW),\n/* harmony export */   SCALE_CHANNELS: () => (/* binding */ SCALE_CHANNELS),\n/* harmony export */   SECONDARY_RANGE_CHANNEL: () => (/* binding */ SECONDARY_RANGE_CHANNEL),\n/* harmony export */   SHAPE: () => (/* binding */ SHAPE),\n/* harmony export */   SINGLE_DEF_CHANNELS: () => (/* binding */ SINGLE_DEF_CHANNELS),\n/* harmony export */   SINGLE_DEF_UNIT_CHANNELS: () => (/* binding */ SINGLE_DEF_UNIT_CHANNELS),\n/* harmony export */   SIZE: () => (/* binding */ SIZE),\n/* harmony export */   STROKE: () => (/* binding */ STROKE),\n/* harmony export */   STROKEDASH: () => (/* binding */ STROKEDASH),\n/* harmony export */   STROKEOPACITY: () => (/* binding */ STROKEOPACITY),\n/* harmony export */   STROKEWIDTH: () => (/* binding */ STROKEWIDTH),\n/* harmony export */   TEXT: () => (/* binding */ TEXT),\n/* harmony export */   THETA: () => (/* binding */ THETA),\n/* harmony export */   THETA2: () => (/* binding */ THETA2),\n/* harmony export */   TOOLTIP: () => (/* binding */ TOOLTIP),\n/* harmony export */   UNIT_CHANNELS: () => (/* binding */ UNIT_CHANNELS),\n/* harmony export */   URL: () => (/* binding */ URL),\n/* harmony export */   X: () => (/* binding */ X),\n/* harmony export */   X2: () => (/* binding */ X2),\n/* harmony export */   XOFFSET: () => (/* binding */ XOFFSET),\n/* harmony export */   Y: () => (/* binding */ Y),\n/* harmony export */   Y2: () => (/* binding */ Y2),\n/* harmony export */   YOFFSET: () => (/* binding */ YOFFSET),\n/* harmony export */   getMainChannelFromOffsetChannel: () => (/* binding */ getMainChannelFromOffsetChannel),\n/* harmony export */   getMainRangeChannel: () => (/* binding */ getMainRangeChannel),\n/* harmony export */   getOffsetChannel: () => (/* binding */ getOffsetChannel),\n/* harmony export */   getOffsetScaleChannel: () => (/* binding */ getOffsetScaleChannel),\n/* harmony export */   getPositionChannelFromLatLong: () => (/* binding */ getPositionChannelFromLatLong),\n/* harmony export */   getPositionScaleChannel: () => (/* binding */ getPositionScaleChannel),\n/* harmony export */   getSecondaryRangeChannel: () => (/* binding */ getSecondaryRangeChannel),\n/* harmony export */   getSizeChannel: () => (/* binding */ getSizeChannel),\n/* harmony export */   getVgPositionChannel: () => (/* binding */ getVgPositionChannel),\n/* harmony export */   isChannel: () => (/* binding */ isChannel),\n/* harmony export */   isColorChannel: () => (/* binding */ isColorChannel),\n/* harmony export */   isGeoPositionChannel: () => (/* binding */ isGeoPositionChannel),\n/* harmony export */   isNonPositionScaleChannel: () => (/* binding */ isNonPositionScaleChannel),\n/* harmony export */   isPolarPositionChannel: () => (/* binding */ isPolarPositionChannel),\n/* harmony export */   isScaleChannel: () => (/* binding */ isScaleChannel),\n/* harmony export */   isSecondaryRangeChannel: () => (/* binding */ isSecondaryRangeChannel),\n/* harmony export */   isSingleDefUnitChannel: () => (/* binding */ isSingleDefUnitChannel),\n/* harmony export */   isXorY: () => (/* binding */ isXorY),\n/* harmony export */   isXorYOffset: () => (/* binding */ isXorYOffset),\n/* harmony export */   rangeType: () => (/* binding */ rangeType),\n/* harmony export */   supportLegend: () => (/* binding */ supportLegend),\n/* harmony export */   supportMark: () => (/* binding */ supportMark)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/*\n * Constants and utilities for encoding channels (Visual variables)\n * such as 'x', 'y', 'color'.\n */\n\n// Facet\nconst ROW = 'row';\nconst COLUMN = 'column';\nconst FACET = 'facet';\n// Position\nconst X = 'x';\nconst Y = 'y';\nconst X2 = 'x2';\nconst Y2 = 'y2';\n// Position Offset\nconst XOFFSET = 'xOffset';\nconst YOFFSET = 'yOffset';\n// Arc-Position\nconst RADIUS = 'radius';\nconst RADIUS2 = 'radius2';\nconst THETA = 'theta';\nconst THETA2 = 'theta2';\n// Geo Position\nconst LATITUDE = 'latitude';\nconst LONGITUDE = 'longitude';\nconst LATITUDE2 = 'latitude2';\nconst LONGITUDE2 = 'longitude2';\n// Mark property with scale\nconst COLOR = 'color';\nconst FILL = 'fill';\nconst STROKE = 'stroke';\nconst SHAPE = 'shape';\nconst SIZE = 'size';\nconst ANGLE = 'angle';\nconst OPACITY = 'opacity';\nconst FILLOPACITY = 'fillOpacity';\nconst STROKEOPACITY = 'strokeOpacity';\nconst STROKEWIDTH = 'strokeWidth';\nconst STROKEDASH = 'strokeDash';\n// Non-scale channel\nconst TEXT = 'text';\nconst ORDER = 'order';\nconst DETAIL = 'detail';\nconst KEY = 'key';\nconst TOOLTIP = 'tooltip';\nconst HREF = 'href';\nconst URL = 'url';\nconst DESCRIPTION = 'description';\nconst POSITION_CHANNEL_INDEX = {\n    x: 1,\n    y: 1,\n    x2: 1,\n    y2: 1\n};\nconst POLAR_POSITION_CHANNEL_INDEX = {\n    theta: 1,\n    theta2: 1,\n    radius: 1,\n    radius2: 1\n};\nfunction isPolarPositionChannel(c) {\n    return c in POLAR_POSITION_CHANNEL_INDEX;\n}\nconst GEO_POSIITON_CHANNEL_INDEX = {\n    longitude: 1,\n    longitude2: 1,\n    latitude: 1,\n    latitude2: 1\n};\nfunction getPositionChannelFromLatLong(channel) {\n    switch (channel) {\n        case LATITUDE:\n            return 'y';\n        case LATITUDE2:\n            return 'y2';\n        case LONGITUDE:\n            return 'x';\n        case LONGITUDE2:\n            return 'x2';\n    }\n}\nfunction isGeoPositionChannel(c) {\n    return c in GEO_POSIITON_CHANNEL_INDEX;\n}\nconst GEOPOSITION_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(GEO_POSIITON_CHANNEL_INDEX);\nconst UNIT_CHANNEL_INDEX = {\n    ...POSITION_CHANNEL_INDEX,\n    ...POLAR_POSITION_CHANNEL_INDEX,\n    ...GEO_POSIITON_CHANNEL_INDEX,\n    xOffset: 1,\n    yOffset: 1,\n    // color\n    color: 1,\n    fill: 1,\n    stroke: 1,\n    // other non-position with scale\n    opacity: 1,\n    fillOpacity: 1,\n    strokeOpacity: 1,\n    strokeWidth: 1,\n    strokeDash: 1,\n    size: 1,\n    angle: 1,\n    shape: 1,\n    // channels without scales\n    order: 1,\n    text: 1,\n    detail: 1,\n    key: 1,\n    tooltip: 1,\n    href: 1,\n    url: 1,\n    description: 1\n};\nfunction isColorChannel(channel) {\n    return channel === COLOR || channel === FILL || channel === STROKE;\n}\nconst FACET_CHANNEL_INDEX = {\n    row: 1,\n    column: 1,\n    facet: 1\n};\nconst FACET_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(FACET_CHANNEL_INDEX);\nconst CHANNEL_INDEX = {\n    ...UNIT_CHANNEL_INDEX,\n    ...FACET_CHANNEL_INDEX\n};\nconst CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(CHANNEL_INDEX);\nconst { order: _o, detail: _d, tooltip: _tt1, ...SINGLE_DEF_CHANNEL_INDEX } = CHANNEL_INDEX;\nconst { row: _r, column: _c, facet: _f, ...SINGLE_DEF_UNIT_CHANNEL_INDEX } = SINGLE_DEF_CHANNEL_INDEX;\n/**\n * Channels that cannot have an array of channelDef.\n * model.fieldDef, getFieldDef only work for these channels.\n *\n * (The only two channels that can have an array of channelDefs are \"detail\" and \"order\".\n * Since there can be multiple fieldDefs for detail and order, getFieldDef/model.fieldDef\n * are not applicable for them. Similarly, selection projection won't work with \"detail\" and \"order\".)\n */\nconst SINGLE_DEF_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(SINGLE_DEF_CHANNEL_INDEX);\nconst SINGLE_DEF_UNIT_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(SINGLE_DEF_UNIT_CHANNEL_INDEX);\nfunction isSingleDefUnitChannel(str) {\n    return !!SINGLE_DEF_UNIT_CHANNEL_INDEX[str];\n}\nfunction isChannel(str) {\n    return !!CHANNEL_INDEX[str];\n}\nconst SECONDARY_RANGE_CHANNEL = [X2, Y2, LATITUDE2, LONGITUDE2, THETA2, RADIUS2];\nfunction isSecondaryRangeChannel(c) {\n    const main = getMainRangeChannel(c);\n    return main !== c;\n}\n/**\n * Get the main channel for a range channel. E.g. `x` for `x2`.\n */\nfunction getMainRangeChannel(channel) {\n    switch (channel) {\n        case X2:\n            return X;\n        case Y2:\n            return Y;\n        case LATITUDE2:\n            return LATITUDE;\n        case LONGITUDE2:\n            return LONGITUDE;\n        case THETA2:\n            return THETA;\n        case RADIUS2:\n            return RADIUS;\n    }\n    return channel;\n}\nfunction getVgPositionChannel(channel) {\n    if (isPolarPositionChannel(channel)) {\n        switch (channel) {\n            case THETA:\n                return 'startAngle';\n            case THETA2:\n                return 'endAngle';\n            case RADIUS:\n                return 'outerRadius';\n            case RADIUS2:\n                return 'innerRadius';\n        }\n    }\n    return channel;\n}\n/**\n * Get the main channel for a range channel. E.g. `x` for `x2`.\n */\nfunction getSecondaryRangeChannel(channel) {\n    switch (channel) {\n        case X:\n            return X2;\n        case Y:\n            return Y2;\n        case LATITUDE:\n            return LATITUDE2;\n        case LONGITUDE:\n            return LONGITUDE2;\n        case THETA:\n            return THETA2;\n        case RADIUS:\n            return RADIUS2;\n    }\n    return undefined;\n}\nfunction getSizeChannel(channel) {\n    switch (channel) {\n        case X:\n        case X2:\n            return 'width';\n        case Y:\n        case Y2:\n            return 'height';\n    }\n    return undefined;\n}\n/**\n * Get the main channel for a range channel. E.g. `x` for `x2`.\n */\nfunction getOffsetChannel(channel) {\n    switch (channel) {\n        case X:\n            return 'xOffset';\n        case Y:\n            return 'yOffset';\n        case X2:\n            return 'x2Offset';\n        case Y2:\n            return 'y2Offset';\n        case THETA:\n            return 'thetaOffset';\n        case RADIUS:\n            return 'radiusOffset';\n        case THETA2:\n            return 'theta2Offset';\n        case RADIUS2:\n            return 'radius2Offset';\n    }\n    return undefined;\n}\n/**\n * Get the main channel for a range channel. E.g. `x` for `x2`.\n */\nfunction getOffsetScaleChannel(channel) {\n    switch (channel) {\n        case X:\n            return 'xOffset';\n        case Y:\n            return 'yOffset';\n    }\n    return undefined;\n}\nfunction getMainChannelFromOffsetChannel(channel) {\n    switch (channel) {\n        case 'xOffset':\n            return 'x';\n        case 'yOffset':\n            return 'y';\n    }\n}\n// CHANNELS without COLUMN, ROW\nconst UNIT_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(UNIT_CHANNEL_INDEX);\n// NONPOSITION_CHANNELS = UNIT_CHANNELS without X, Y, X2, Y2;\nconst { x: _x, y: _y, \n// x2 and y2 share the same scale as x and y\nx2: _x2, y2: _y2, \n//\nxOffset: _xo, yOffset: _yo, latitude: _latitude, longitude: _longitude, latitude2: _latitude2, longitude2: _longitude2, theta: _theta, theta2: _theta2, radius: _radius, radius2: _radius2, \n// The rest of unit channels then have scale\n...NONPOSITION_CHANNEL_INDEX } = UNIT_CHANNEL_INDEX;\nconst NONPOSITION_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(NONPOSITION_CHANNEL_INDEX);\nconst POSITION_SCALE_CHANNEL_INDEX = {\n    x: 1,\n    y: 1\n};\nconst POSITION_SCALE_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(POSITION_SCALE_CHANNEL_INDEX);\nfunction isXorY(channel) {\n    return channel in POSITION_SCALE_CHANNEL_INDEX;\n}\nconst POLAR_POSITION_SCALE_CHANNEL_INDEX = {\n    theta: 1,\n    radius: 1\n};\nconst POLAR_POSITION_SCALE_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(POLAR_POSITION_SCALE_CHANNEL_INDEX);\nfunction getPositionScaleChannel(sizeType) {\n    return sizeType === 'width' ? X : Y;\n}\nconst OFFSET_SCALE_CHANNEL_INDEX = { xOffset: 1, yOffset: 1 };\nconst OFFSET_SCALE_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(OFFSET_SCALE_CHANNEL_INDEX);\nfunction isXorYOffset(channel) {\n    return channel in OFFSET_SCALE_CHANNEL_INDEX;\n}\n// NON_POSITION_SCALE_CHANNEL = SCALE_CHANNELS without position / offset\nconst { \n// x2 and y2 share the same scale as x and y\n// text and tooltip have format instead of scale,\n// href has neither format, nor scale\ntext: _t, tooltip: _tt, href: _hr, url: _u, description: _al, \n// detail and order have no scale\ndetail: _dd, key: _k, order: _oo, ...NONPOSITION_SCALE_CHANNEL_INDEX } = NONPOSITION_CHANNEL_INDEX;\nconst NONPOSITION_SCALE_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(NONPOSITION_SCALE_CHANNEL_INDEX);\nfunction isNonPositionScaleChannel(channel) {\n    return !!NONPOSITION_CHANNEL_INDEX[channel];\n}\n/**\n * @returns whether Vega supports legends for a particular channel\n */\nfunction supportLegend(channel) {\n    switch (channel) {\n        case COLOR:\n        case FILL:\n        case STROKE:\n        case SIZE:\n        case SHAPE:\n        case OPACITY:\n        case STROKEWIDTH:\n        case STROKEDASH:\n            return true;\n        case FILLOPACITY:\n        case STROKEOPACITY:\n        case ANGLE:\n            return false;\n    }\n}\n// Declare SCALE_CHANNEL_INDEX\nconst SCALE_CHANNEL_INDEX = {\n    ...POSITION_SCALE_CHANNEL_INDEX,\n    ...POLAR_POSITION_SCALE_CHANNEL_INDEX,\n    ...OFFSET_SCALE_CHANNEL_INDEX,\n    ...NONPOSITION_SCALE_CHANNEL_INDEX\n};\n/** List of channels with scales */\nconst SCALE_CHANNELS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(SCALE_CHANNEL_INDEX);\nfunction isScaleChannel(channel) {\n    return !!SCALE_CHANNEL_INDEX[channel];\n}\n/**\n * Return whether a channel supports a particular mark type.\n * @param channel  channel name\n * @param mark the mark type\n * @return whether the mark supports the channel\n */\nfunction supportMark(channel, mark) {\n    return getSupportedMark(channel)[mark];\n}\nconst ALL_MARKS = {\n    // all marks\n    arc: 'always',\n    area: 'always',\n    bar: 'always',\n    circle: 'always',\n    geoshape: 'always',\n    image: 'always',\n    line: 'always',\n    rule: 'always',\n    point: 'always',\n    rect: 'always',\n    square: 'always',\n    trail: 'always',\n    text: 'always',\n    tick: 'always'\n};\nconst { geoshape: _g, ...ALL_MARKS_EXCEPT_GEOSHAPE } = ALL_MARKS;\n/**\n * Return a dictionary showing whether a channel supports mark type.\n * @param channel\n * @return A dictionary mapping mark types to 'always', 'binned', or undefined\n */\nfunction getSupportedMark(channel) {\n    switch (channel) {\n        case COLOR:\n        case FILL:\n        case STROKE:\n        // falls through\n        case DESCRIPTION:\n        case DETAIL:\n        case KEY:\n        case TOOLTIP:\n        case HREF:\n        case ORDER: // TODO: revise (order might not support rect, which is not stackable?)\n        case OPACITY:\n        case FILLOPACITY:\n        case STROKEOPACITY:\n        case STROKEWIDTH:\n        // falls through\n        case FACET:\n        case ROW: // falls through\n        case COLUMN:\n            return ALL_MARKS;\n        case X:\n        case Y:\n        case XOFFSET:\n        case YOFFSET:\n        case LATITUDE:\n        case LONGITUDE:\n            // all marks except geoshape. geoshape does not use X, Y -- it uses a projection\n            return ALL_MARKS_EXCEPT_GEOSHAPE;\n        case X2:\n        case Y2:\n        case LATITUDE2:\n        case LONGITUDE2:\n            return {\n                area: 'always',\n                bar: 'always',\n                image: 'always',\n                rect: 'always',\n                rule: 'always',\n                circle: 'binned',\n                point: 'binned',\n                square: 'binned',\n                tick: 'binned',\n                line: 'binned',\n                trail: 'binned'\n            };\n        case SIZE:\n            return {\n                point: 'always',\n                tick: 'always',\n                rule: 'always',\n                circle: 'always',\n                square: 'always',\n                bar: 'always',\n                text: 'always',\n                line: 'always',\n                trail: 'always'\n            };\n        case STROKEDASH:\n            return {\n                line: 'always',\n                point: 'always',\n                tick: 'always',\n                rule: 'always',\n                circle: 'always',\n                square: 'always',\n                bar: 'always',\n                geoshape: 'always'\n            };\n        case SHAPE:\n            return { point: 'always', geoshape: 'always' };\n        case TEXT:\n            return { text: 'always' };\n        case ANGLE:\n            return { point: 'always', square: 'always', text: 'always' };\n        case URL:\n            return { image: 'always' };\n        case THETA:\n            return { text: 'always', arc: 'always' };\n        case RADIUS:\n            return { text: 'always', arc: 'always' };\n        case THETA2:\n        case RADIUS2:\n            return { arc: 'always' };\n    }\n}\nfunction rangeType(channel) {\n    switch (channel) {\n        case X:\n        case Y:\n        case THETA:\n        case RADIUS:\n        case XOFFSET:\n        case YOFFSET:\n        case SIZE:\n        case ANGLE:\n        case STROKEWIDTH:\n        case OPACITY:\n        case FILLOPACITY:\n        case STROKEOPACITY:\n        // X2 and Y2 use X and Y scales, so they similarly have continuous range. [falls through]\n        case X2:\n        case Y2:\n        case THETA2:\n        case RADIUS2:\n            return undefined;\n        case FACET:\n        case ROW:\n        case COLUMN:\n        case SHAPE:\n        case STROKEDASH:\n        // TEXT, TOOLTIP, URL, and HREF have no scale but have discrete output [falls through]\n        case TEXT:\n        case TOOLTIP:\n        case HREF:\n        case URL:\n        case DESCRIPTION:\n            return 'discrete';\n        // Color can be either continuous or discrete, depending on scale type.\n        case COLOR:\n        case FILL:\n        case STROKE:\n            return 'flexible';\n        // No scale, no range type.\n        case LATITUDE:\n        case LONGITUDE:\n        case LATITUDE2:\n        case LONGITUDE2:\n        case DETAIL:\n        case KEY:\n        case ORDER:\n            return undefined;\n    }\n}\n//# sourceMappingURL=channel.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/channel.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/channeldef.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/channeldef.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   binRequiresRange: () => (/* binding */ binRequiresRange),\n/* harmony export */   channelCompatibility: () => (/* binding */ channelCompatibility),\n/* harmony export */   channelDefType: () => (/* binding */ channelDefType),\n/* harmony export */   defaultTitle: () => (/* binding */ defaultTitle),\n/* harmony export */   defaultTitleFormatter: () => (/* binding */ defaultTitleFormatter),\n/* harmony export */   defaultType: () => (/* binding */ defaultType),\n/* harmony export */   functionalTitleFormatter: () => (/* binding */ functionalTitleFormatter),\n/* harmony export */   getBandPosition: () => (/* binding */ getBandPosition),\n/* harmony export */   getBandSize: () => (/* binding */ getBandSize),\n/* harmony export */   getFieldDef: () => (/* binding */ getFieldDef),\n/* harmony export */   getFieldOrDatumDef: () => (/* binding */ getFieldOrDatumDef),\n/* harmony export */   getFormatMixins: () => (/* binding */ getFormatMixins),\n/* harmony export */   getGuide: () => (/* binding */ getGuide),\n/* harmony export */   hasBandEnd: () => (/* binding */ hasBandEnd),\n/* harmony export */   hasConditionalFieldDef: () => (/* binding */ hasConditionalFieldDef),\n/* harmony export */   hasConditionalFieldOrDatumDef: () => (/* binding */ hasConditionalFieldOrDatumDef),\n/* harmony export */   hasConditionalValueDef: () => (/* binding */ hasConditionalValueDef),\n/* harmony export */   initChannelDef: () => (/* binding */ initChannelDef),\n/* harmony export */   initFieldDef: () => (/* binding */ initFieldDef),\n/* harmony export */   initFieldOrDatumDef: () => (/* binding */ initFieldOrDatumDef),\n/* harmony export */   isConditionalDef: () => (/* binding */ isConditionalDef),\n/* harmony export */   isConditionalParameter: () => (/* binding */ isConditionalParameter),\n/* harmony export */   isContinuousFieldOrDatumDef: () => (/* binding */ isContinuousFieldOrDatumDef),\n/* harmony export */   isCount: () => (/* binding */ isCount),\n/* harmony export */   isDatumDef: () => (/* binding */ isDatumDef),\n/* harmony export */   isDiscrete: () => (/* binding */ isDiscrete),\n/* harmony export */   isDiscretizing: () => (/* binding */ isDiscretizing),\n/* harmony export */   isFieldDef: () => (/* binding */ isFieldDef),\n/* harmony export */   isFieldOrDatumDef: () => (/* binding */ isFieldOrDatumDef),\n/* harmony export */   isFieldOrDatumDefForTimeFormat: () => (/* binding */ isFieldOrDatumDefForTimeFormat),\n/* harmony export */   isMarkPropFieldOrDatumDef: () => (/* binding */ isMarkPropFieldOrDatumDef),\n/* harmony export */   isNumericDataDef: () => (/* binding */ isNumericDataDef),\n/* harmony export */   isOrderOnlyDef: () => (/* binding */ isOrderOnlyDef),\n/* harmony export */   isPositionFieldOrDatumDef: () => (/* binding */ isPositionFieldOrDatumDef),\n/* harmony export */   isRepeatRef: () => (/* binding */ isRepeatRef),\n/* harmony export */   isScaleFieldDef: () => (/* binding */ isScaleFieldDef),\n/* harmony export */   isSortableFieldDef: () => (/* binding */ isSortableFieldDef),\n/* harmony export */   isStringFieldOrDatumDef: () => (/* binding */ isStringFieldOrDatumDef),\n/* harmony export */   isTimeFieldDef: () => (/* binding */ isTimeFieldDef),\n/* harmony export */   isTypedFieldDef: () => (/* binding */ isTypedFieldDef),\n/* harmony export */   isUnbinnedQuantitativeFieldOrDatumDef: () => (/* binding */ isUnbinnedQuantitativeFieldOrDatumDef),\n/* harmony export */   isValueDef: () => (/* binding */ isValueDef),\n/* harmony export */   normalizeBin: () => (/* binding */ normalizeBin),\n/* harmony export */   resetTitleFormatter: () => (/* binding */ resetTitleFormatter),\n/* harmony export */   setTitleFormatter: () => (/* binding */ setTitleFormatter),\n/* harmony export */   title: () => (/* binding */ title),\n/* harmony export */   toFieldDefBase: () => (/* binding */ toFieldDefBase),\n/* harmony export */   toStringFieldDef: () => (/* binding */ toStringFieldDef),\n/* harmony export */   valueArray: () => (/* binding */ valueArray),\n/* harmony export */   valueExpr: () => (/* binding */ valueExpr),\n/* harmony export */   verbalTitleFormatter: () => (/* binding */ verbalTitleFormatter),\n/* harmony export */   vgField: () => (/* binding */ vgField)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _compile_common__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./compile/common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _compile_format__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./compile/format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _spec_facet__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./spec/facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction isConditionalParameter(c) {\n    return c['param'];\n}\nfunction isRepeatRef(field) {\n    return field && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field) && 'repeat' in field;\n}\nfunction toFieldDefBase(fieldDef) {\n    const { field, timeUnit, bin, aggregate } = fieldDef;\n    return {\n        ...(timeUnit ? { timeUnit } : {}),\n        ...(bin ? { bin } : {}),\n        ...(aggregate ? { aggregate } : {}),\n        field\n    };\n}\nfunction isSortableFieldDef(fieldDef) {\n    return 'sort' in fieldDef;\n}\nfunction getBandPosition({ fieldDef, fieldDef2, markDef: mark, config }) {\n    if (isFieldOrDatumDef(fieldDef) && fieldDef.bandPosition !== undefined) {\n        return fieldDef.bandPosition;\n    }\n    if (isFieldDef(fieldDef)) {\n        const { timeUnit, bin } = fieldDef;\n        if (timeUnit && !fieldDef2) {\n            return (0,_mark__WEBPACK_IMPORTED_MODULE_9__.isRectBasedMark)(mark.type) ? 0 : (0,_compile_common__WEBPACK_IMPORTED_MODULE_4__.getMarkConfig)('timeUnitBandPosition', mark, config);\n        }\n        else if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n            return 0.5;\n        }\n    }\n    return undefined;\n}\nfunction getBandSize({ channel, fieldDef, fieldDef2, markDef: mark, config, scaleType, useVlSizeChannel }) {\n    const sizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.getSizeChannel)(channel);\n    const size = (0,_compile_common__WEBPACK_IMPORTED_MODULE_4__.getMarkPropOrConfig)(useVlSizeChannel ? 'size' : sizeChannel, mark, config, {\n        vgChannel: sizeChannel\n    });\n    if (size !== undefined) {\n        return size;\n    }\n    if (isFieldDef(fieldDef)) {\n        const { timeUnit, bin } = fieldDef;\n        if (timeUnit && !fieldDef2) {\n            return { band: (0,_compile_common__WEBPACK_IMPORTED_MODULE_4__.getMarkConfig)('timeUnitBandSize', mark, config) };\n        }\n        else if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin) && !(0,_scale__WEBPACK_IMPORTED_MODULE_10__.hasDiscreteDomain)(scaleType)) {\n            return { band: 1 };\n        }\n    }\n    if ((0,_mark__WEBPACK_IMPORTED_MODULE_9__.isRectBasedMark)(mark.type)) {\n        if (scaleType) {\n            if ((0,_scale__WEBPACK_IMPORTED_MODULE_10__.hasDiscreteDomain)(scaleType)) {\n                return config[mark.type]?.discreteBandSize || { band: 1 };\n            }\n            else {\n                return config[mark.type]?.continuousBandSize;\n            }\n        }\n        return config[mark.type]?.discreteBandSize;\n    }\n    return undefined;\n}\nfunction hasBandEnd(fieldDef, fieldDef2, markDef, config) {\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(fieldDef.bin) || (fieldDef.timeUnit && isTypedFieldDef(fieldDef) && fieldDef.type === 'temporal')) {\n        // Need to check bandPosition because non-rect marks (e.g., point) with timeUnit\n        // doesn't have to use bandEnd if there is no bandPosition.\n        return getBandPosition({ fieldDef, fieldDef2, markDef, config }) !== undefined;\n    }\n    return false;\n}\nfunction isOrderOnlyDef(orderDef) {\n    return orderDef && !!orderDef.sort && !orderDef['field'];\n}\nfunction isConditionalDef(channelDef) {\n    return channelDef && 'condition' in channelDef;\n}\n/**\n * Return if a channelDef is a ConditionalValueDef with ConditionFieldDef\n */\nfunction hasConditionalFieldDef(channelDef) {\n    const condition = channelDef?.['condition'];\n    return !!condition && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(condition) && isFieldDef(condition);\n}\nfunction hasConditionalFieldOrDatumDef(channelDef) {\n    const condition = channelDef?.['condition'];\n    return !!condition && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(condition) && isFieldOrDatumDef(condition);\n}\nfunction hasConditionalValueDef(channelDef) {\n    const condition = channelDef?.['condition'];\n    return !!condition && ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(condition) || isValueDef(condition));\n}\nfunction isFieldDef(channelDef) {\n    // TODO: we can't use field in channelDef here as it's somehow failing runtime test\n    return channelDef && (!!channelDef['field'] || channelDef['aggregate'] === 'count');\n}\nfunction channelDefType(channelDef) {\n    return channelDef?.['type'];\n}\nfunction isDatumDef(channelDef) {\n    return channelDef && 'datum' in channelDef;\n}\nfunction isContinuousFieldOrDatumDef(cd) {\n    // TODO: make datum support DateTime object\n    return (isTypedFieldDef(cd) && !isDiscrete(cd)) || isNumericDataDef(cd);\n}\nfunction isUnbinnedQuantitativeFieldOrDatumDef(cd) {\n    // TODO: make datum support DateTime object\n    return (isTypedFieldDef(cd) && cd.type === 'quantitative' && !cd.bin) || isNumericDataDef(cd);\n}\nfunction isNumericDataDef(cd) {\n    return isDatumDef(cd) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(cd.datum);\n}\nfunction isFieldOrDatumDef(channelDef) {\n    return isFieldDef(channelDef) || isDatumDef(channelDef);\n}\nfunction isTypedFieldDef(channelDef) {\n    return channelDef && ('field' in channelDef || channelDef['aggregate'] === 'count') && 'type' in channelDef;\n}\nfunction isValueDef(channelDef) {\n    return channelDef && 'value' in channelDef && 'value' in channelDef;\n}\nfunction isScaleFieldDef(channelDef) {\n    return channelDef && ('scale' in channelDef || 'sort' in channelDef);\n}\nfunction isPositionFieldOrDatumDef(channelDef) {\n    return channelDef && ('axis' in channelDef || 'stack' in channelDef || 'impute' in channelDef);\n}\nfunction isMarkPropFieldOrDatumDef(channelDef) {\n    return channelDef && 'legend' in channelDef;\n}\nfunction isStringFieldOrDatumDef(channelDef) {\n    return channelDef && ('format' in channelDef || 'formatType' in channelDef);\n}\nfunction toStringFieldDef(fieldDef) {\n    // omit properties that don't exist in string field defs\n    return (0,_util__WEBPACK_IMPORTED_MODULE_15__.omit)(fieldDef, ['legend', 'axis', 'header', 'scale']);\n}\nfunction isOpFieldDef(fieldDef) {\n    return 'op' in fieldDef;\n}\n/**\n * Get a Vega field reference from a Vega-Lite field def.\n */\nfunction vgField(fieldDef, opt = {}) {\n    let field = fieldDef.field;\n    const prefix = opt.prefix;\n    let suffix = opt.suffix;\n    let argAccessor = ''; // for accessing argmin/argmax field at the end without getting escaped\n    if (isCount(fieldDef)) {\n        field = (0,_util__WEBPACK_IMPORTED_MODULE_15__.internalField)('count');\n    }\n    else {\n        let fn;\n        if (!opt.nofn) {\n            if (isOpFieldDef(fieldDef)) {\n                fn = fieldDef.op;\n            }\n            else {\n                const { bin, aggregate, timeUnit } = fieldDef;\n                if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n                    fn = (0,_bin__WEBPACK_IMPORTED_MODULE_2__.binToString)(bin);\n                    suffix = (opt.binSuffix ?? '') + (opt.suffix ?? '');\n                }\n                else if (aggregate) {\n                    if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate)) {\n                        argAccessor = `[\"${field}\"]`;\n                        field = `argmax_${aggregate.argmax}`;\n                    }\n                    else if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate)) {\n                        argAccessor = `[\"${field}\"]`;\n                        field = `argmin_${aggregate.argmin}`;\n                    }\n                    else {\n                        fn = String(aggregate);\n                    }\n                }\n                else if (timeUnit && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.isBinnedTimeUnit)(timeUnit)) {\n                    fn = (0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.timeUnitToString)(timeUnit);\n                    suffix = ((!['range', 'mid'].includes(opt.binSuffix) && opt.binSuffix) || '') + (opt.suffix ?? '');\n                }\n            }\n        }\n        if (fn) {\n            field = field ? `${fn}_${field}` : fn;\n        }\n    }\n    if (suffix) {\n        field = `${field}_${suffix}`;\n    }\n    if (prefix) {\n        field = `${prefix}_${field}`;\n    }\n    if (opt.forAs) {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_15__.removePathFromField)(field);\n    }\n    else if (opt.expr) {\n        // Expression to access flattened field. No need to escape dots.\n        return (0,_util__WEBPACK_IMPORTED_MODULE_15__.flatAccessWithDatum)(field, opt.expr) + argAccessor;\n    }\n    else {\n        // We flattened all fields so paths should have become dot.\n        return (0,_util__WEBPACK_IMPORTED_MODULE_15__.replacePathInField)(field) + argAccessor;\n    }\n}\nfunction isDiscrete(def) {\n    switch (def.type) {\n        case 'nominal':\n        case 'ordinal':\n        case 'geojson':\n            return true;\n        case 'quantitative':\n            return isFieldDef(def) && !!def.bin;\n        case 'temporal':\n            return false;\n    }\n    throw new Error(_log__WEBPACK_IMPORTED_MODULE_8__.message.invalidFieldType(def.type));\n}\nfunction isDiscretizing(def) {\n    return isScaleFieldDef(def) && (0,_scale__WEBPACK_IMPORTED_MODULE_10__.isContinuousToDiscrete)(def.scale?.type);\n}\nfunction isCount(fieldDef) {\n    return fieldDef.aggregate === 'count';\n}\nfunction verbalTitleFormatter(fieldDef, config) {\n    const { field, bin, timeUnit, aggregate } = fieldDef;\n    if (aggregate === 'count') {\n        return config.countTitle;\n    }\n    else if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n        return `${field} (binned)`;\n    }\n    else if (timeUnit && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.isBinnedTimeUnit)(timeUnit)) {\n        const unit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.normalizeTimeUnit)(timeUnit)?.unit;\n        if (unit) {\n            return `${field} (${(0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.getTimeUnitParts)(unit).join('-')})`;\n        }\n    }\n    else if (aggregate) {\n        if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate)) {\n            return `${field} for max ${aggregate.argmax}`;\n        }\n        else if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate)) {\n            return `${field} for min ${aggregate.argmin}`;\n        }\n        else {\n            return `${(0,_util__WEBPACK_IMPORTED_MODULE_15__.titleCase)(aggregate)} of ${field}`;\n        }\n    }\n    return field;\n}\nfunction functionalTitleFormatter(fieldDef) {\n    const { aggregate, bin, timeUnit, field } = fieldDef;\n    if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate)) {\n        return `${field} for argmax(${aggregate.argmax})`;\n    }\n    else if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate)) {\n        return `${field} for argmin(${aggregate.argmin})`;\n    }\n    const timeUnitParams = timeUnit && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.isBinnedTimeUnit)(timeUnit) ? (0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.normalizeTimeUnit)(timeUnit) : undefined;\n    const fn = aggregate || timeUnitParams?.unit || (timeUnitParams?.maxbins && 'timeunit') || ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin) && 'bin');\n    if (fn) {\n        return `${fn.toUpperCase()}(${field})`;\n    }\n    else {\n        return field;\n    }\n}\nconst defaultTitleFormatter = (fieldDef, config) => {\n    switch (config.fieldTitle) {\n        case 'plain':\n            return fieldDef.field;\n        case 'functional':\n            return functionalTitleFormatter(fieldDef);\n        default:\n            return verbalTitleFormatter(fieldDef, config);\n    }\n};\nlet titleFormatter = defaultTitleFormatter;\nfunction setTitleFormatter(formatter) {\n    titleFormatter = formatter;\n}\nfunction resetTitleFormatter() {\n    setTitleFormatter(defaultTitleFormatter);\n}\nfunction title(fieldOrDatumDef, config, { allowDisabling, includeDefault = true }) {\n    const guideTitle = getGuide(fieldOrDatumDef)?.title;\n    if (!isFieldDef(fieldOrDatumDef)) {\n        return guideTitle ?? fieldOrDatumDef.title;\n    }\n    const fieldDef = fieldOrDatumDef;\n    const def = includeDefault ? defaultTitle(fieldDef, config) : undefined;\n    if (allowDisabling) {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_15__.getFirstDefined)(guideTitle, fieldDef.title, def);\n    }\n    else {\n        return guideTitle ?? fieldDef.title ?? def;\n    }\n}\nfunction getGuide(fieldDef) {\n    if (isPositionFieldOrDatumDef(fieldDef) && fieldDef.axis) {\n        return fieldDef.axis;\n    }\n    else if (isMarkPropFieldOrDatumDef(fieldDef) && fieldDef.legend) {\n        return fieldDef.legend;\n    }\n    else if ((0,_spec_facet__WEBPACK_IMPORTED_MODULE_12__.isFacetFieldDef)(fieldDef) && fieldDef.header) {\n        return fieldDef.header;\n    }\n    return undefined;\n}\nfunction defaultTitle(fieldDef, config) {\n    return titleFormatter(fieldDef, config);\n}\nfunction getFormatMixins(fieldDef) {\n    if (isStringFieldOrDatumDef(fieldDef)) {\n        const { format, formatType } = fieldDef;\n        return { format, formatType };\n    }\n    else {\n        const guide = getGuide(fieldDef) ?? {};\n        const { format, formatType } = guide;\n        return { format, formatType };\n    }\n}\nfunction defaultType(fieldDef, channel) {\n    switch (channel) {\n        case 'latitude':\n        case 'longitude':\n            return 'quantitative';\n        case 'row':\n        case 'column':\n        case 'facet':\n        case 'shape':\n        case 'strokeDash':\n            return 'nominal';\n        case 'order':\n            return 'ordinal';\n    }\n    if (isSortableFieldDef(fieldDef) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(fieldDef.sort)) {\n        return 'ordinal';\n    }\n    const { aggregate, bin, timeUnit } = fieldDef;\n    if (timeUnit) {\n        return 'temporal';\n    }\n    if (bin || (aggregate && !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate) && !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate))) {\n        return 'quantitative';\n    }\n    if (isScaleFieldDef(fieldDef) && fieldDef.scale?.type) {\n        switch (_scale__WEBPACK_IMPORTED_MODULE_10__.SCALE_CATEGORY_INDEX[fieldDef.scale.type]) {\n            case 'numeric':\n            case 'discretizing':\n                return 'quantitative';\n            case 'time':\n                return 'temporal';\n        }\n    }\n    return 'nominal';\n}\n/**\n * Returns the fieldDef -- either from the outer channelDef or from the condition of channelDef.\n * @param channelDef\n */\nfunction getFieldDef(channelDef) {\n    if (isFieldDef(channelDef)) {\n        return channelDef;\n    }\n    else if (hasConditionalFieldDef(channelDef)) {\n        return channelDef.condition;\n    }\n    return undefined;\n}\nfunction getFieldOrDatumDef(channelDef) {\n    if (isFieldOrDatumDef(channelDef)) {\n        return channelDef;\n    }\n    else if (hasConditionalFieldOrDatumDef(channelDef)) {\n        return channelDef.condition;\n    }\n    return undefined;\n}\n/**\n * Convert type to full, lowercase type, or augment the fieldDef with a default type if missing.\n */\nfunction initChannelDef(channelDef, channel, config, opt = {}) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(channelDef) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(channelDef) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean)(channelDef)) {\n        const primitiveType = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(channelDef) ? 'string' : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(channelDef) ? 'number' : 'boolean';\n        _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.primitiveChannelDef(channel, primitiveType, channelDef));\n        return { value: channelDef };\n    }\n    // If a fieldDef contains a field, we need type.\n    if (isFieldOrDatumDef(channelDef)) {\n        return initFieldOrDatumDef(channelDef, channel, config, opt);\n    }\n    else if (hasConditionalFieldOrDatumDef(channelDef)) {\n        return {\n            ...channelDef,\n            // Need to cast as normalizeFieldDef normally return FieldDef, but here we know that it is definitely Condition<FieldDef>\n            condition: initFieldOrDatumDef(channelDef.condition, channel, config, opt)\n        };\n    }\n    return channelDef;\n}\nfunction initFieldOrDatumDef(fd, channel, config, opt) {\n    if (isStringFieldOrDatumDef(fd)) {\n        const { format, formatType, ...rest } = fd;\n        if ((0,_compile_format__WEBPACK_IMPORTED_MODULE_5__.isCustomFormatType)(formatType) && !config.customFormatTypes) {\n            _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.customFormatTypeNotAllowed(channel));\n            return initFieldOrDatumDef(rest, channel, config, opt);\n        }\n    }\n    else {\n        const guideType = isPositionFieldOrDatumDef(fd)\n            ? 'axis'\n            : isMarkPropFieldOrDatumDef(fd)\n                ? 'legend'\n                : (0,_spec_facet__WEBPACK_IMPORTED_MODULE_12__.isFacetFieldDef)(fd)\n                    ? 'header'\n                    : null;\n        if (guideType && fd[guideType]) {\n            const { format, formatType, ...newGuide } = fd[guideType];\n            if ((0,_compile_format__WEBPACK_IMPORTED_MODULE_5__.isCustomFormatType)(formatType) && !config.customFormatTypes) {\n                _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.customFormatTypeNotAllowed(channel));\n                return initFieldOrDatumDef({ ...fd, [guideType]: newGuide }, channel, config, opt);\n            }\n        }\n    }\n    if (isFieldDef(fd)) {\n        return initFieldDef(fd, channel, opt);\n    }\n    return initDatumDef(fd);\n}\nfunction initDatumDef(datumDef) {\n    let type = datumDef['type'];\n    if (type) {\n        return datumDef;\n    }\n    const { datum } = datumDef;\n    type = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(datum) ? 'quantitative' : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(datum) ? 'nominal' : (0,_datetime__WEBPACK_IMPORTED_MODULE_6__.isDateTime)(datum) ? 'temporal' : undefined;\n    return { ...datumDef, type };\n}\nfunction initFieldDef(fd, channel, { compositeMark = false } = {}) {\n    const { aggregate, timeUnit, bin, field } = fd;\n    const fieldDef = { ...fd };\n    // Drop invalid aggregate\n    if (!compositeMark && aggregate && !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isAggregateOp)(aggregate) && !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate) && !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate)) {\n        _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.invalidAggregate(aggregate));\n        delete fieldDef.aggregate;\n    }\n    // Normalize Time Unit\n    if (timeUnit) {\n        fieldDef.timeUnit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.normalizeTimeUnit)(timeUnit);\n    }\n    if (field) {\n        fieldDef.field = `${field}`;\n    }\n    // Normalize bin\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n        fieldDef.bin = normalizeBin(bin, channel);\n    }\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinned)(bin) && !(0,_channel__WEBPACK_IMPORTED_MODULE_3__.isXorY)(channel)) {\n        _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.channelShouldNotBeUsedForBinned(channel));\n    }\n    // Normalize Type\n    if (isTypedFieldDef(fieldDef)) {\n        const { type } = fieldDef;\n        const fullType = (0,_type__WEBPACK_IMPORTED_MODULE_14__.getFullName)(type);\n        if (type !== fullType) {\n            // convert short type to full type\n            fieldDef.type = fullType;\n        }\n        if (type !== 'quantitative') {\n            if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isCountingAggregateOp)(aggregate)) {\n                _log__WEBPACK_IMPORTED_MODULE_8__.warn(_log__WEBPACK_IMPORTED_MODULE_8__.message.invalidFieldTypeForCountAggregate(type, aggregate));\n                fieldDef.type = 'quantitative';\n            }\n        }\n    }\n    else if (!(0,_channel__WEBPACK_IMPORTED_MODULE_3__.isSecondaryRangeChannel)(channel)) {\n        // If type is empty / invalid, then augment with default type\n        const newType = defaultType(fieldDef, channel);\n        fieldDef['type'] = newType;\n    }\n    if (isTypedFieldDef(fieldDef)) {\n        const { compatible, warning } = channelCompatibility(fieldDef, channel) || {};\n        if (compatible === false) {\n            _log__WEBPACK_IMPORTED_MODULE_8__.warn(warning);\n        }\n    }\n    if (isSortableFieldDef(fieldDef) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(fieldDef.sort)) {\n        const { sort } = fieldDef;\n        if ((0,_sort__WEBPACK_IMPORTED_MODULE_11__.isSortByChannel)(sort)) {\n            return {\n                ...fieldDef,\n                sort: { encoding: sort }\n            };\n        }\n        const sub = sort.substr(1);\n        if (sort.charAt(0) === '-' && (0,_sort__WEBPACK_IMPORTED_MODULE_11__.isSortByChannel)(sub)) {\n            return {\n                ...fieldDef,\n                sort: { encoding: sub, order: 'descending' }\n            };\n        }\n    }\n    if ((0,_spec_facet__WEBPACK_IMPORTED_MODULE_12__.isFacetFieldDef)(fieldDef)) {\n        const { header } = fieldDef;\n        if (header) {\n            const { orient, ...rest } = header;\n            if (orient) {\n                return {\n                    ...fieldDef,\n                    header: {\n                        ...rest,\n                        labelOrient: header.labelOrient || orient,\n                        titleOrient: header.titleOrient || orient\n                    }\n                };\n            }\n        }\n    }\n    return fieldDef;\n}\nfunction normalizeBin(bin, channel) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean)(bin)) {\n        return { maxbins: (0,_bin__WEBPACK_IMPORTED_MODULE_2__.autoMaxBins)(channel) };\n    }\n    else if (bin === 'binned') {\n        return {\n            binned: true\n        };\n    }\n    else if (!bin.maxbins && !bin.step) {\n        return { ...bin, maxbins: (0,_bin__WEBPACK_IMPORTED_MODULE_2__.autoMaxBins)(channel) };\n    }\n    else {\n        return bin;\n    }\n}\nconst COMPATIBLE = { compatible: true };\nfunction channelCompatibility(fieldDef, channel) {\n    const type = fieldDef.type;\n    if (type === 'geojson' && channel !== 'shape') {\n        return {\n            compatible: false,\n            warning: `Channel ${channel} should not be used with a geojson data.`\n        };\n    }\n    switch (channel) {\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.ROW:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.COLUMN:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.FACET:\n            if (!isDiscrete(fieldDef)) {\n                return {\n                    compatible: false,\n                    warning: _log__WEBPACK_IMPORTED_MODULE_8__.message.channelShouldBeDiscrete(channel)\n                };\n            }\n            return COMPATIBLE;\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.X:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.Y:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.XOFFSET:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.YOFFSET:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.COLOR:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.FILL:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.TEXT:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.DETAIL:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.KEY:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.TOOLTIP:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.HREF:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.URL:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.ANGLE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.THETA:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.RADIUS:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.DESCRIPTION:\n            return COMPATIBLE;\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.LONGITUDE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.LONGITUDE2:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.LATITUDE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.LATITUDE2:\n            if (type !== _type__WEBPACK_IMPORTED_MODULE_14__.QUANTITATIVE) {\n                return {\n                    compatible: false,\n                    warning: `Channel ${channel} should be used with a quantitative field only, not ${fieldDef.type} field.`\n                };\n            }\n            return COMPATIBLE;\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.OPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.FILLOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEWIDTH:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.SIZE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.THETA2:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.RADIUS2:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.X2:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.Y2:\n            if (type === 'nominal' && !fieldDef['sort']) {\n                return {\n                    compatible: false,\n                    warning: `Channel ${channel} should not be used with an unsorted discrete field.`\n                };\n            }\n            return COMPATIBLE;\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.SHAPE:\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEDASH:\n            if (!isDiscrete(fieldDef) && !isDiscretizing(fieldDef)) {\n                return {\n                    compatible: false,\n                    warning: _log__WEBPACK_IMPORTED_MODULE_8__.message.channelShouldBeDiscreteOrDiscretizing(channel)\n                };\n            }\n            return COMPATIBLE;\n        case _channel__WEBPACK_IMPORTED_MODULE_3__.ORDER:\n            if (fieldDef.type === 'nominal' && !('sort' in fieldDef)) {\n                return {\n                    compatible: false,\n                    warning: `Channel order is inappropriate for nominal field, which has no inherent order.`\n                };\n            }\n            return COMPATIBLE;\n    }\n}\n/**\n * Check if the field def uses a time format or does not use any format but is temporal\n * (this does not cover field defs that are temporal but use a number format).\n */\nfunction isFieldOrDatumDefForTimeFormat(fieldOrDatumDef) {\n    const { formatType } = getFormatMixins(fieldOrDatumDef);\n    return formatType === 'time' || (!formatType && isTimeFieldDef(fieldOrDatumDef));\n}\n/**\n * Check if field def has type `temporal`. If you want to also cover field defs that use a time format, use `isTimeFormatFieldDef`.\n */\nfunction isTimeFieldDef(def) {\n    return def && (def['type'] === 'temporal' || (isFieldDef(def) && !!def.timeUnit));\n}\n/**\n * Getting a value associated with a fielddef.\n * Convert the value to Vega expression if applicable (for datetime object, or string if the field def is temporal or has timeUnit)\n */\nfunction valueExpr(v, { timeUnit, type, wrapTime, undefinedIfExprNotRequired }) {\n    const unit = timeUnit && (0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.normalizeTimeUnit)(timeUnit)?.unit;\n    let isTime = unit || type === 'temporal';\n    let expr;\n    if ((0,_expr__WEBPACK_IMPORTED_MODULE_7__.isExprRef)(v)) {\n        expr = v.expr;\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_16__.isSignalRef)(v)) {\n        expr = v.signal;\n    }\n    else if ((0,_datetime__WEBPACK_IMPORTED_MODULE_6__.isDateTime)(v)) {\n        isTime = true;\n        expr = (0,_datetime__WEBPACK_IMPORTED_MODULE_6__.dateTimeToExpr)(v);\n    }\n    else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(v) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(v)) {\n        if (isTime) {\n            expr = `datetime(${(0,_util__WEBPACK_IMPORTED_MODULE_15__.stringify)(v)})`;\n            if ((0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.isLocalSingleTimeUnit)(unit)) {\n                // for single timeUnit, we will use dateTimeToExpr to convert number/string to match the timeUnit\n                if (((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(v) && v < 10000) || ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(v) && isNaN(Date.parse(v)))) {\n                    expr = (0,_datetime__WEBPACK_IMPORTED_MODULE_6__.dateTimeToExpr)({ [unit]: v });\n                }\n            }\n        }\n    }\n    if (expr) {\n        return wrapTime && isTime ? `time(${expr})` : expr;\n    }\n    // number or boolean or normal string\n    return undefinedIfExprNotRequired ? undefined : (0,_util__WEBPACK_IMPORTED_MODULE_15__.stringify)(v);\n}\n/**\n * Standardize value array -- convert each value to Vega expression if applicable\n */\nfunction valueArray(fieldOrDatumDef, values) {\n    const { type } = fieldOrDatumDef;\n    return values.map(v => {\n        const timeUnit = isFieldDef(fieldOrDatumDef) && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_13__.isBinnedTimeUnit)(fieldOrDatumDef.timeUnit) ? fieldOrDatumDef.timeUnit : undefined;\n        const expr = valueExpr(v, {\n            timeUnit,\n            type,\n            undefinedIfExprNotRequired: true\n        });\n        // return signal for the expression if we need an expression\n        if (expr !== undefined) {\n            return { signal: expr };\n        }\n        // otherwise just return the original value\n        return v;\n    });\n}\n/**\n * Checks whether a fieldDef for a particular channel requires a computed bin range.\n */\nfunction binRequiresRange(fieldDef, channel) {\n    if (!(0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(fieldDef.bin)) {\n        console.warn('Only call this method for binned field defs.');\n        return false;\n    }\n    // We need the range only when the user explicitly forces a binned field to be use discrete scale. In this case, bin range is used in axis and legend labels.\n    // We could check whether the axis or legend exists (not disabled) but that seems overkill.\n    return (0,_channel__WEBPACK_IMPORTED_MODULE_3__.isScaleChannel)(channel) && ['ordinal', 'nominal'].includes(fieldDef.type);\n}\n//# sourceMappingURL=channeldef.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/channeldef.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/assemble.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/assemble.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleAxes: () => (/* binding */ assembleAxes),\n/* harmony export */   assembleAxis: () => (/* binding */ assembleAxis),\n/* harmony export */   assembleAxisSignals: () => (/* binding */ assembleAxisSignals)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _axis__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../axis */ \"../../node_modules/vega-lite/build/src/axis.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _title__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../title */ \"../../node_modules/vega-lite/build/src/title.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../predicate */ \"../../node_modules/vega-lite/build/src/compile/predicate.js\");\n\n\n\n\n\n\n\n\n\nfunction assembleTitle(title, config) {\n    if (!title) {\n        return undefined;\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(title) && !(0,_title__WEBPACK_IMPORTED_MODULE_4__.isText)(title)) {\n        return title.map(fieldDef => (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.defaultTitle)(fieldDef, config)).join(', ');\n    }\n    return title;\n}\nfunction setAxisEncode(axis, part, vgProp, vgRef) {\n    var _a, _b;\n    axis.encode ?? (axis.encode = {});\n    (_a = axis.encode)[part] ?? (_a[part] = {});\n    (_b = axis.encode[part]).update ?? (_b.update = {});\n    // TODO: remove as any after https://github.com/prisma/nexus-prisma/issues/291\n    axis.encode[part].update[vgProp] = vgRef;\n}\nfunction assembleAxis(axisCmpt, kind, config, opt = { header: false }) {\n    const { disable, orient, scale, labelExpr, title, zindex, ...axis } = axisCmpt.combine();\n    if (disable) {\n        return undefined;\n    }\n    for (const prop in axis) {\n        const propType = _axis__WEBPACK_IMPORTED_MODULE_1__.AXIS_PROPERTY_TYPE[prop];\n        const propValue = axis[prop];\n        if (propType && propType !== kind && propType !== 'both') {\n            // Remove properties that are not valid for this kind of axis\n            delete axis[prop];\n        }\n        else if ((0,_axis__WEBPACK_IMPORTED_MODULE_1__.isConditionalAxisValue)(propValue)) {\n            // deal with conditional axis value\n            const { condition, ...valueOrSignalRef } = propValue;\n            const conditions = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(condition);\n            const propIndex = _axis__WEBPACK_IMPORTED_MODULE_1__.CONDITIONAL_AXIS_PROP_INDEX[prop];\n            if (propIndex) {\n                const { vgProp, part } = propIndex;\n                // If there is a corresponding Vega property for the channel,\n                // use Vega's custom axis encoding and delete the original axis property to avoid conflicts\n                const vgRef = [\n                    ...conditions.map(c => {\n                        const { test, ...valueOrSignalCRef } = c;\n                        return {\n                            test: (0,_predicate__WEBPACK_IMPORTED_MODULE_8__.expression)(null, test),\n                            ...valueOrSignalCRef\n                        };\n                    }),\n                    valueOrSignalRef\n                ];\n                setAxisEncode(axis, part, vgProp, vgRef);\n                delete axis[prop];\n            }\n            else if (propIndex === null) {\n                // If propIndex is null, this means we support conditional axis property by converting the condition to signal instead.\n                const signalRef = {\n                    signal: conditions\n                        .map(c => {\n                        const { test, ...valueOrSignalCRef } = c;\n                        return `${(0,_predicate__WEBPACK_IMPORTED_MODULE_8__.expression)(null, test)} ? ${(0,_common__WEBPACK_IMPORTED_MODULE_7__.exprFromValueRefOrSignalRef)(valueOrSignalCRef)} : `;\n                    })\n                        .join('') + (0,_common__WEBPACK_IMPORTED_MODULE_7__.exprFromValueRefOrSignalRef)(valueOrSignalRef)\n                };\n                axis[prop] = signalRef;\n            }\n        }\n        else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_6__.isSignalRef)(propValue)) {\n            const propIndex = _axis__WEBPACK_IMPORTED_MODULE_1__.CONDITIONAL_AXIS_PROP_INDEX[prop];\n            if (propIndex) {\n                const { vgProp, part } = propIndex;\n                setAxisEncode(axis, part, vgProp, propValue);\n                delete axis[prop];\n            } // else do nothing since the property already supports signal\n        }\n        // Do not pass labelAlign/Baseline = null to Vega since it won't pass the schema\n        // Note that we need to use null so the default labelAlign is preserved.\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_5__.contains)(['labelAlign', 'labelBaseline'], prop) && axis[prop] === null) {\n            delete axis[prop];\n        }\n    }\n    if (kind === 'grid') {\n        if (!axis.grid) {\n            return undefined;\n        }\n        // Remove unnecessary encode block\n        if (axis.encode) {\n            // Only need to keep encode block for grid\n            const { grid } = axis.encode;\n            axis.encode = {\n                ...(grid ? { grid } : {})\n            };\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(axis.encode)) {\n                delete axis.encode;\n            }\n        }\n        return {\n            scale,\n            orient,\n            ...axis,\n            domain: false,\n            labels: false,\n            aria: false,\n            // Always set min/maxExtent to 0 to ensure that `config.axis*.minExtent` and `config.axis*.maxExtent`\n            // would not affect gridAxis\n            maxExtent: 0,\n            minExtent: 0,\n            ticks: false,\n            zindex: (0,_util__WEBPACK_IMPORTED_MODULE_5__.getFirstDefined)(zindex, 0) // put grid behind marks by default\n        };\n    }\n    else {\n        // kind === 'main'\n        if (!opt.header && axisCmpt.mainExtracted) {\n            // if mainExtracted has been extracted to a separate facet\n            return undefined;\n        }\n        if (labelExpr !== undefined) {\n            let expr = labelExpr;\n            if (axis.encode?.labels?.update && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_6__.isSignalRef)(axis.encode.labels.update.text)) {\n                expr = (0,_util__WEBPACK_IMPORTED_MODULE_5__.replaceAll)(labelExpr, 'datum.label', axis.encode.labels.update.text.signal);\n            }\n            setAxisEncode(axis, 'labels', 'text', { signal: expr });\n        }\n        if (axis.labelAlign === null) {\n            delete axis.labelAlign;\n        }\n        // Remove unnecessary encode block\n        if (axis.encode) {\n            for (const part of _axis__WEBPACK_IMPORTED_MODULE_1__.AXIS_PARTS) {\n                if (!axisCmpt.hasAxisPart(part)) {\n                    delete axis.encode[part];\n                }\n            }\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(axis.encode)) {\n                delete axis.encode;\n            }\n        }\n        const titleString = assembleTitle(title, config);\n        return {\n            scale,\n            orient,\n            grid: false,\n            ...(titleString ? { title: titleString } : {}),\n            ...axis,\n            ...(config.aria === false ? { aria: false } : {}),\n            zindex: (0,_util__WEBPACK_IMPORTED_MODULE_5__.getFirstDefined)(zindex, 0) // put axis line above marks by default\n        };\n    }\n}\n/**\n * Add axis signals so grid line works correctly\n * (Fix https://github.com/vega/vega-lite/issues/4226)\n */\nfunction assembleAxisSignals(model) {\n    const { axes } = model.component;\n    const signals = [];\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.POSITION_SCALE_CHANNELS) {\n        if (axes[channel]) {\n            for (const axis of axes[channel]) {\n                if (!axis.get('disable') && !axis.get('gridScale')) {\n                    // If there is x-axis but no y-scale for gridScale, need to set height/width so x-axis can draw the grid with the right height. Same for y-axis and width.\n                    const sizeType = channel === 'x' ? 'height' : 'width';\n                    const update = model.getSizeSignalRef(sizeType).signal;\n                    if (sizeType !== update) {\n                        signals.push({\n                            name: sizeType,\n                            update\n                        });\n                    }\n                }\n            }\n        }\n    }\n    return signals;\n}\nfunction assembleAxes(axisComponents, config) {\n    const { x = [], y = [] } = axisComponents;\n    return [\n        ...x.map(a => assembleAxis(a, 'grid', config)),\n        ...y.map(a => assembleAxis(a, 'grid', config)),\n        ...x.map(a => assembleAxis(a, 'main', config)),\n        ...y.map(a => assembleAxis(a, 'main', config))\n    ].filter(a => a); // filter undefined\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/component.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/component.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AXIS_COMPONENT_PROPERTIES: () => (/* binding */ AXIS_COMPONENT_PROPERTIES),\n/* harmony export */   AxisComponent: () => (/* binding */ AxisComponent)\n/* harmony export */ });\n/* harmony import */ var _axis__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../axis */ \"../../node_modules/vega-lite/build/src/axis.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n\n\n\nfunction isFalseOrNull(v) {\n    return v === false || v === null;\n}\nconst AXIS_COMPONENT_PROPERTIES_INDEX = {\n    disable: 1,\n    gridScale: 1,\n    scale: 1,\n    ..._axis__WEBPACK_IMPORTED_MODULE_0__.COMMON_AXIS_PROPERTIES_INDEX,\n    labelExpr: 1,\n    encode: 1\n};\nconst AXIS_COMPONENT_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(AXIS_COMPONENT_PROPERTIES_INDEX);\nclass AxisComponent extends _split__WEBPACK_IMPORTED_MODULE_3__.Split {\n    constructor(explicit = {}, implicit = {}, mainExtracted = false) {\n        super();\n        this.explicit = explicit;\n        this.implicit = implicit;\n        this.mainExtracted = mainExtracted;\n    }\n    clone() {\n        return new AxisComponent((0,_util__WEBPACK_IMPORTED_MODULE_1__.duplicate)(this.explicit), (0,_util__WEBPACK_IMPORTED_MODULE_1__.duplicate)(this.implicit), this.mainExtracted);\n    }\n    hasAxisPart(part) {\n        // FIXME(https://github.com/vega/vega-lite/issues/2552) this method can be wrong if users use a Vega theme.\n        if (part === 'axis') {\n            // always has the axis container part\n            return true;\n        }\n        if (part === 'grid' || part === 'title') {\n            return !!this.get(part);\n        }\n        // Other parts are enabled by default, so they should not be false or null.\n        return !isFalseOrNull(this.get(part));\n    }\n    hasOrientSignalRef() {\n        return (0,_vega_schema__WEBPACK_IMPORTED_MODULE_2__.isSignalRef)(this.explicit.orient);\n    }\n}\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/config.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/config.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getAxisConfig: () => (/* binding */ getAxisConfig),\n/* harmony export */   getAxisConfigStyle: () => (/* binding */ getAxisConfigStyle),\n/* harmony export */   getAxisConfigs: () => (/* binding */ getAxisConfigs)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n\n\n\n\n\nfunction getAxisConfigFromConfigTypes(configTypes, config, channel, orient) {\n    // TODO: add special casing to add conditional value based on orient signal\n    return Object.assign.apply(null, [\n        {},\n        ...configTypes.map(configType => {\n            if (configType === 'axisOrient') {\n                const orient1 = channel === 'x' ? 'bottom' : 'left';\n                const orientConfig1 = config[channel === 'x' ? 'axisBottom' : 'axisLeft'] || {};\n                const orientConfig2 = config[channel === 'x' ? 'axisTop' : 'axisRight'] || {};\n                const props = new Set([...(0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(orientConfig1), ...(0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(orientConfig2)]);\n                const conditionalOrientAxisConfig = {};\n                for (const prop of props.values()) {\n                    conditionalOrientAxisConfig[prop] = {\n                        // orient is surely signal in this case\n                        signal: `${orient['signal']} === \"${orient1}\" ? ${(0,_common__WEBPACK_IMPORTED_MODULE_4__.signalOrStringValue)(orientConfig1[prop])} : ${(0,_common__WEBPACK_IMPORTED_MODULE_4__.signalOrStringValue)(orientConfig2[prop])}`\n                    };\n                }\n                return conditionalOrientAxisConfig;\n            }\n            return config[configType];\n        })\n    ]);\n}\nfunction getAxisConfigs(channel, scaleType, orient, config) {\n    const typeBasedConfigTypes = scaleType === 'band'\n        ? ['axisDiscrete', 'axisBand']\n        : scaleType === 'point'\n            ? ['axisDiscrete', 'axisPoint']\n            : (0,_scale__WEBPACK_IMPORTED_MODULE_1__.isQuantitative)(scaleType)\n                ? ['axisQuantitative']\n                : scaleType === 'time' || scaleType === 'utc'\n                    ? ['axisTemporal']\n                    : [];\n    const axisChannel = channel === 'x' ? 'axisX' : 'axisY';\n    const axisOrient = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_3__.isSignalRef)(orient) ? 'axisOrient' : `axis${(0,_util__WEBPACK_IMPORTED_MODULE_2__.titleCase)(orient)}`; // axisTop, axisBottom, ...\n    const vlOnlyConfigTypes = [\n        // technically Vega does have axisBand, but if we make another separation here,\n        // it will further introduce complexity in the code\n        ...typeBasedConfigTypes,\n        ...typeBasedConfigTypes.map(c => axisChannel + c.substr(4))\n    ];\n    const vgConfigTypes = ['axis', axisOrient, axisChannel];\n    return {\n        vlOnlyAxisConfig: getAxisConfigFromConfigTypes(vlOnlyConfigTypes, config, channel, orient),\n        vgAxisConfig: getAxisConfigFromConfigTypes(vgConfigTypes, config, channel, orient),\n        axisConfigStyle: getAxisConfigStyle([...vgConfigTypes, ...vlOnlyConfigTypes], config)\n    };\n}\nfunction getAxisConfigStyle(axisConfigTypes, config) {\n    const toMerge = [{}];\n    for (const configType of axisConfigTypes) {\n        // TODO: add special casing to add conditional value based on orient signal\n        let style = config[configType]?.style;\n        if (style) {\n            style = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(style);\n            for (const s of style) {\n                toMerge.push(config.style[s]);\n            }\n        }\n    }\n    return Object.assign.apply(null, toMerge);\n}\nfunction getAxisConfig(property, styleConfigIndex, style, axisConfigs = {}) {\n    const styleConfig = (0,_common__WEBPACK_IMPORTED_MODULE_4__.getStyleConfig)(property, style, styleConfigIndex);\n    if (styleConfig !== undefined) {\n        return {\n            configFrom: 'style',\n            configValue: styleConfig\n        };\n    }\n    for (const configFrom of ['vlOnlyAxisConfig', 'vgAxisConfig', 'axisConfigStyle']) {\n        if (axisConfigs[configFrom]?.[property] !== undefined) {\n            return { configFrom, configValue: axisConfigs[configFrom][property] };\n        }\n    }\n    return {};\n}\n//# sourceMappingURL=config.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/config.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/encode.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/encode.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   labels: () => (/* binding */ labels)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n\n\n\nfunction labels(model, channel, specifiedLabelsSpec) {\n    const { encoding, config } = model;\n    const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldOrDatumDef)(encoding[channel]) ?? (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldOrDatumDef)(encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSecondaryRangeChannel)(channel)]);\n    const axis = model.axis(channel) || {};\n    const { format, formatType } = axis;\n    if ((0,_format__WEBPACK_IMPORTED_MODULE_2__.isCustomFormatType)(formatType)) {\n        return {\n            text: (0,_format__WEBPACK_IMPORTED_MODULE_2__.formatCustomType)({\n                fieldOrDatumDef,\n                field: 'datum.value',\n                format,\n                formatType,\n                config\n            }),\n            ...specifiedLabelsSpec\n        };\n    }\n    else if (format === undefined && formatType === undefined && config.customFormatTypes) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.channelDefType)(fieldOrDatumDef) === 'quantitative') {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isPositionFieldOrDatumDef)(fieldOrDatumDef) &&\n                fieldOrDatumDef.stack === 'normalize' &&\n                config.normalizedNumberFormatType) {\n                return {\n                    text: (0,_format__WEBPACK_IMPORTED_MODULE_2__.formatCustomType)({\n                        fieldOrDatumDef,\n                        field: 'datum.value',\n                        format: config.normalizedNumberFormat,\n                        formatType: config.normalizedNumberFormatType,\n                        config\n                    }),\n                    ...specifiedLabelsSpec\n                };\n            }\n            else if (config.numberFormatType) {\n                return {\n                    text: (0,_format__WEBPACK_IMPORTED_MODULE_2__.formatCustomType)({\n                        fieldOrDatumDef,\n                        field: 'datum.value',\n                        format: config.numberFormat,\n                        formatType: config.numberFormatType,\n                        config\n                    }),\n                    ...specifiedLabelsSpec\n                };\n            }\n        }\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.channelDefType)(fieldOrDatumDef) === 'temporal' &&\n            config.timeFormatType &&\n            (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(fieldOrDatumDef) &&\n            !fieldOrDatumDef.timeUnit) {\n            return {\n                text: (0,_format__WEBPACK_IMPORTED_MODULE_2__.formatCustomType)({\n                    fieldOrDatumDef,\n                    field: 'datum.value',\n                    format: config.timeFormat,\n                    formatType: config.timeFormatType,\n                    config\n                }),\n                ...specifiedLabelsSpec\n            };\n        }\n    }\n    return specifiedLabelsSpec;\n}\n//# sourceMappingURL=encode.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/encode.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/parse.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/parse.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseLayerAxes: () => (/* binding */ parseLayerAxes),\n/* harmony export */   parseUnitAxes: () => (/* binding */ parseUnitAxes)\n/* harmony export */ });\n/* harmony import */ var _axis__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../axis */ \"../../node_modules/vega-lite/build/src/axis.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _guide__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../guide */ \"../../node_modules/vega-lite/build/src/compile/guide.js\");\n/* harmony import */ var _resolve__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../resolve */ \"../../node_modules/vega-lite/build/src/compile/resolve.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/axis/component.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./config */ \"../../node_modules/vega-lite/build/src/compile/axis/config.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/axis/encode.js\");\n/* harmony import */ var _properties__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./properties */ \"../../node_modules/vega-lite/build/src/compile/axis/properties.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction parseUnitAxes(model) {\n    return _channel__WEBPACK_IMPORTED_MODULE_1__.POSITION_SCALE_CHANNELS.reduce((axis, channel) => {\n        if (model.component.scales[channel]) {\n            axis[channel] = [parseAxis(channel, model)];\n        }\n        return axis;\n    }, {});\n}\nconst OPPOSITE_ORIENT = {\n    bottom: 'top',\n    top: 'bottom',\n    left: 'right',\n    right: 'left'\n};\nfunction parseLayerAxes(model) {\n    const { axes, resolve } = model.component;\n    const axisCount = { top: 0, bottom: 0, right: 0, left: 0 };\n    for (const child of model.children) {\n        child.parseAxesAndHeaders();\n        for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_3__.keys)(child.component.axes)) {\n            resolve.axis[channel] = (0,_resolve__WEBPACK_IMPORTED_MODULE_7__.parseGuideResolve)(model.component.resolve, channel);\n            if (resolve.axis[channel] === 'shared') {\n                // If the resolve says shared (and has not been overridden)\n                // We will try to merge and see if there is a conflict\n                axes[channel] = mergeAxisComponents(axes[channel], child.component.axes[channel]);\n                if (!axes[channel]) {\n                    // If merge returns nothing, there is a conflict so we cannot make the axis shared.\n                    // Thus, mark axis as independent and remove the axis component.\n                    resolve.axis[channel] = 'independent';\n                    delete axes[channel];\n                }\n            }\n        }\n    }\n    // Move axes to layer's axis component and merge shared axes\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_1__.POSITION_SCALE_CHANNELS) {\n        for (const child of model.children) {\n            if (!child.component.axes[channel]) {\n                // skip if the child does not have a particular axis\n                continue;\n            }\n            if (resolve.axis[channel] === 'independent') {\n                // If axes are independent, concat the axisComponent array.\n                axes[channel] = (axes[channel] ?? []).concat(child.component.axes[channel]);\n                // Automatically adjust orient\n                for (const axisComponent of child.component.axes[channel]) {\n                    const { value: orient, explicit } = axisComponent.getWithExplicit('orient');\n                    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(orient)) {\n                        continue;\n                    }\n                    if (axisCount[orient] > 0 && !explicit) {\n                        // Change axis orient if the number do not match\n                        const oppositeOrient = OPPOSITE_ORIENT[orient];\n                        if (axisCount[orient] > axisCount[oppositeOrient]) {\n                            axisComponent.set('orient', oppositeOrient, false);\n                        }\n                    }\n                    axisCount[orient]++;\n                    // TODO(https://github.com/vega/vega-lite/issues/2634): automatically add extra offset?\n                }\n            }\n            // After merging, make sure to remove axes from child\n            delete child.component.axes[channel];\n        }\n        // Show gridlines for first axis only for dual-axis chart\n        if (resolve.axis[channel] === 'independent' && axes[channel] && axes[channel].length > 1) {\n            for (const [index, axisCmpt] of (axes[channel] || []).entries()) {\n                if (index > 0 && !!axisCmpt.get('grid') && !axisCmpt.explicit.grid) {\n                    axisCmpt.implicit.grid = false;\n                }\n            }\n        }\n    }\n}\nfunction mergeAxisComponents(mergedAxisCmpts, childAxisCmpts) {\n    if (mergedAxisCmpts) {\n        // FIXME: this is a bit wrong once we support multiple axes\n        if (mergedAxisCmpts.length !== childAxisCmpts.length) {\n            return undefined; // Cannot merge axis component with different number of axes.\n        }\n        const length = mergedAxisCmpts.length;\n        for (let i = 0; i < length; i++) {\n            const merged = mergedAxisCmpts[i];\n            const child = childAxisCmpts[i];\n            if (!!merged !== !!child) {\n                return undefined;\n            }\n            else if (merged && child) {\n                const mergedOrient = merged.getWithExplicit('orient');\n                const childOrient = child.getWithExplicit('orient');\n                if (mergedOrient.explicit && childOrient.explicit && mergedOrient.value !== childOrient.value) {\n                    // TODO: throw warning if resolve is explicit (We don't have info about explicit/implicit resolve yet.)\n                    // Cannot merge due to inconsistent orient\n                    return undefined;\n                }\n                else {\n                    mergedAxisCmpts[i] = mergeAxisComponent(merged, child);\n                }\n            }\n        }\n    }\n    else {\n        // For first one, return a copy of the child\n        return childAxisCmpts.map(axisComponent => axisComponent.clone());\n    }\n    return mergedAxisCmpts;\n}\nfunction mergeAxisComponent(merged, child) {\n    for (const prop of _component__WEBPACK_IMPORTED_MODULE_9__.AXIS_COMPONENT_PROPERTIES) {\n        const mergedValueWithExplicit = (0,_split__WEBPACK_IMPORTED_MODULE_8__.mergeValuesWithExplicit)(merged.getWithExplicit(prop), child.getWithExplicit(prop), prop, 'axis', \n        // Tie breaker function\n        (v1, v2) => {\n            switch (prop) {\n                case 'title':\n                    return (0,_common__WEBPACK_IMPORTED_MODULE_5__.mergeTitleComponent)(v1, v2);\n                case 'gridScale':\n                    return {\n                        explicit: v1.explicit,\n                        value: (0,_util__WEBPACK_IMPORTED_MODULE_3__.getFirstDefined)(v1.value, v2.value)\n                    };\n            }\n            return (0,_split__WEBPACK_IMPORTED_MODULE_8__.defaultTieBreaker)(v1, v2, prop, 'axis');\n        });\n        merged.setWithExplicit(prop, mergedValueWithExplicit);\n    }\n    return merged;\n}\nfunction isExplicit(value, property, axis, model, channel) {\n    if (property === 'disable') {\n        return axis !== undefined; // if axis is specified or null/false, then its enable/disable state is explicit\n    }\n    axis = axis || {};\n    switch (property) {\n        case 'titleAngle':\n        case 'labelAngle':\n            return value === ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(axis.labelAngle) ? axis.labelAngle : (0,_util__WEBPACK_IMPORTED_MODULE_3__.normalizeAngle)(axis.labelAngle));\n        case 'values':\n            return !!axis.values;\n        // specified axis.values is already respected, but may get transformed.\n        case 'encode':\n            // both VL axis.encoding and axis.labelAngle affect VG axis.encode\n            return !!axis.encoding || !!axis.labelAngle;\n        case 'title':\n            // title can be explicit if fieldDef.title is set\n            if (value === (0,_properties__WEBPACK_IMPORTED_MODULE_12__.getFieldDefTitle)(model, channel)) {\n                return true;\n            }\n    }\n    // Otherwise, things are explicit if the returned value matches the specified property\n    return value === axis[property];\n}\n/**\n * Properties to always include values from config\n */\nconst propsToAlwaysIncludeConfig = new Set([\n    'grid',\n    'translate',\n    // the rest are not axis configs in Vega, but are in VL, so we need to set too.\n    'format',\n    'formatType',\n    'orient',\n    'labelExpr',\n    'tickCount',\n    'position',\n    'tickMinStep'\n]);\nfunction parseAxis(channel, model) {\n    let axis = model.axis(channel);\n    const axisComponent = new _component__WEBPACK_IMPORTED_MODULE_9__.AxisComponent();\n    const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.getFieldOrDatumDef)(model.encoding[channel]);\n    const { mark, config } = model;\n    const orient = axis?.orient ||\n        config[channel === 'x' ? 'axisX' : 'axisY']?.orient ||\n        config.axis?.orient ||\n        (0,_properties__WEBPACK_IMPORTED_MODULE_12__.defaultOrient)(channel);\n    const scaleType = model.getScaleComponent(channel).get('type');\n    const axisConfigs = (0,_config__WEBPACK_IMPORTED_MODULE_10__.getAxisConfigs)(channel, scaleType, orient, model.config);\n    const disable = axis !== undefined ? !axis : (0,_config__WEBPACK_IMPORTED_MODULE_10__.getAxisConfig)('disable', config.style, axis?.style, axisConfigs).configValue;\n    axisComponent.set('disable', disable, axis !== undefined);\n    if (disable) {\n        return axisComponent;\n    }\n    axis = axis || {};\n    const labelAngle = (0,_properties__WEBPACK_IMPORTED_MODULE_12__.getLabelAngle)(fieldOrDatumDef, axis, channel, config.style, axisConfigs);\n    const formatType = (0,_format__WEBPACK_IMPORTED_MODULE_13__.guideFormatType)(axis.formatType, fieldOrDatumDef, scaleType);\n    const format = (0,_format__WEBPACK_IMPORTED_MODULE_13__.guideFormat)(fieldOrDatumDef, fieldOrDatumDef.type, axis.format, axis.formatType, config, true);\n    const ruleParams = {\n        fieldOrDatumDef,\n        axis,\n        channel,\n        model,\n        scaleType,\n        orient,\n        labelAngle,\n        format,\n        formatType,\n        mark,\n        config\n    };\n    // 1.2. Add properties\n    for (const property of _component__WEBPACK_IMPORTED_MODULE_9__.AXIS_COMPONENT_PROPERTIES) {\n        const value = property in _properties__WEBPACK_IMPORTED_MODULE_12__.axisRules ? _properties__WEBPACK_IMPORTED_MODULE_12__.axisRules[property](ruleParams) : (0,_axis__WEBPACK_IMPORTED_MODULE_0__.isAxisProperty)(property) ? axis[property] : undefined;\n        const hasValue = value !== undefined;\n        const explicit = isExplicit(value, property, axis, model, channel);\n        if (hasValue && explicit) {\n            axisComponent.set(property, value, explicit);\n        }\n        else {\n            const { configValue = undefined, configFrom = undefined } = (0,_axis__WEBPACK_IMPORTED_MODULE_0__.isAxisProperty)(property) && property !== 'values'\n                ? (0,_config__WEBPACK_IMPORTED_MODULE_10__.getAxisConfig)(property, config.style, axis.style, axisConfigs)\n                : {};\n            const hasConfigValue = configValue !== undefined;\n            if (hasValue && !hasConfigValue) {\n                // only set property if it is explicitly set or has no config value (otherwise we will accidentally override config)\n                axisComponent.set(property, value, explicit);\n            }\n            else if (\n            // Cases need implicit values\n            // 1. Axis config that aren't available in Vega\n            !(configFrom === 'vgAxisConfig') ||\n                // 2. Certain properties are always included (see `propsToAlwaysIncludeConfig`'s declaration for more details)\n                (propsToAlwaysIncludeConfig.has(property) && hasConfigValue) ||\n                // 3. Conditional axis values and signals\n                (0,_axis__WEBPACK_IMPORTED_MODULE_0__.isConditionalAxisValue)(configValue) ||\n                (0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(configValue)) {\n                // If a config is specified and is conditional, copy conditional value from axis config\n                axisComponent.set(property, configValue, false);\n            }\n        }\n    }\n    // 2) Add guide encode definition groups\n    const axisEncoding = axis.encoding ?? {};\n    const axisEncode = _axis__WEBPACK_IMPORTED_MODULE_0__.AXIS_PARTS.reduce((e, part) => {\n        if (!axisComponent.hasAxisPart(part)) {\n            // No need to create encode for a disabled part.\n            return e;\n        }\n        const axisEncodingPart = (0,_guide__WEBPACK_IMPORTED_MODULE_6__.guideEncodeEntry)(axisEncoding[part] ?? {}, model);\n        const value = part === 'labels' ? _encode__WEBPACK_IMPORTED_MODULE_11__.labels(model, channel, axisEncodingPart) : axisEncodingPart;\n        if (value !== undefined && !(0,_util__WEBPACK_IMPORTED_MODULE_3__.isEmpty)(value)) {\n            e[part] = { update: value };\n        }\n        return e;\n    }, {});\n    // FIXME: By having encode as one property, we won't have fine grained encode merging.\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_3__.isEmpty)(axisEncode)) {\n        axisComponent.set('encode', axisEncode, !!axis.encoding || axis.labelAngle !== undefined);\n    }\n    return axisComponent;\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/axis/properties.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/axis/properties.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   axisRules: () => (/* binding */ axisRules),\n/* harmony export */   defaultGrid: () => (/* binding */ defaultGrid),\n/* harmony export */   defaultLabelAlign: () => (/* binding */ defaultLabelAlign),\n/* harmony export */   defaultLabelBaseline: () => (/* binding */ defaultLabelBaseline),\n/* harmony export */   defaultLabelFlush: () => (/* binding */ defaultLabelFlush),\n/* harmony export */   defaultLabelOverlap: () => (/* binding */ defaultLabelOverlap),\n/* harmony export */   defaultOrient: () => (/* binding */ defaultOrient),\n/* harmony export */   defaultTickCount: () => (/* binding */ defaultTickCount),\n/* harmony export */   defaultTickMinStep: () => (/* binding */ defaultTickMinStep),\n/* harmony export */   defaultZindex: () => (/* binding */ defaultZindex),\n/* harmony export */   getFieldDefTitle: () => (/* binding */ getFieldDefTitle),\n/* harmony export */   getLabelAngle: () => (/* binding */ getLabelAngle),\n/* harmony export */   gridScale: () => (/* binding */ gridScale),\n/* harmony export */   normalizeAngleExpr: () => (/* binding */ normalizeAngleExpr),\n/* harmony export */   values: () => (/* binding */ values)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./config */ \"../../node_modules/vega-lite/build/src/compile/axis/config.js\");\n\n\n\n\n\n\n\n\n\n\n\nconst axisRules = {\n    scale: ({ model, channel }) => model.scaleName(channel),\n    format: ({ format }) => format,\n    formatType: ({ formatType }) => formatType,\n    grid: ({ fieldOrDatumDef, axis, scaleType }) => axis.grid ?? defaultGrid(scaleType, fieldOrDatumDef),\n    gridScale: ({ model, channel }) => gridScale(model, channel),\n    labelAlign: ({ axis, labelAngle, orient, channel }) => axis.labelAlign || defaultLabelAlign(labelAngle, orient, channel),\n    labelAngle: ({ labelAngle }) => labelAngle,\n    labelBaseline: ({ axis, labelAngle, orient, channel }) => axis.labelBaseline || defaultLabelBaseline(labelAngle, orient, channel),\n    labelFlush: ({ axis, fieldOrDatumDef, channel }) => axis.labelFlush ?? defaultLabelFlush(fieldOrDatumDef.type, channel),\n    labelOverlap: ({ axis, fieldOrDatumDef, scaleType }) => axis.labelOverlap ??\n        defaultLabelOverlap(fieldOrDatumDef.type, scaleType, (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) && !!fieldOrDatumDef.timeUnit, (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) ? fieldOrDatumDef.sort : undefined),\n    // we already calculate orient in parse\n    orient: ({ orient }) => orient,\n    tickCount: ({ channel, model, axis, fieldOrDatumDef, scaleType }) => {\n        const sizeType = channel === 'x' ? 'width' : channel === 'y' ? 'height' : undefined;\n        const size = sizeType ? model.getSizeSignalRef(sizeType) : undefined;\n        return axis.tickCount ?? defaultTickCount({ fieldOrDatumDef, scaleType, size, values: axis.values });\n    },\n    tickMinStep: defaultTickMinStep,\n    title: ({ axis, model, channel }) => {\n        if (axis.title !== undefined) {\n            return axis.title;\n        }\n        const fieldDefTitle = getFieldDefTitle(model, channel);\n        if (fieldDefTitle !== undefined) {\n            return fieldDefTitle;\n        }\n        const fieldDef = model.typedFieldDef(channel);\n        const channel2 = channel === 'x' ? 'x2' : 'y2';\n        const fieldDef2 = model.fieldDef(channel2);\n        // If title not specified, store base parts of fieldDef (and fieldDef2 if exists)\n        return (0,_common__WEBPACK_IMPORTED_MODULE_9__.mergeTitleFieldDefs)(fieldDef ? [(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.toFieldDefBase)(fieldDef)] : [], (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldDef2) ? [(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.toFieldDefBase)(fieldDef2)] : []);\n    },\n    values: ({ axis, fieldOrDatumDef }) => values(axis, fieldOrDatumDef),\n    zindex: ({ axis, fieldOrDatumDef, mark }) => axis.zindex ?? defaultZindex(mark, fieldOrDatumDef)\n};\n// TODO: we need to refactor this method after we take care of config refactoring\n/**\n * Default rules for whether to show a grid should be shown for a channel.\n * If `grid` is unspecified, the default value is `true` for ordinal scales that are not binned\n */\nfunction defaultGrid(scaleType, fieldDef) {\n    return !(0,_scale__WEBPACK_IMPORTED_MODULE_4__.hasDiscreteDomain)(scaleType) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldDef) && !(0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldDef?.bin) && !(0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(fieldDef?.bin);\n}\nfunction gridScale(model, channel) {\n    const gridChannel = channel === 'x' ? 'y' : 'x';\n    if (model.getScaleComponent(gridChannel)) {\n        return model.scaleName(gridChannel);\n    }\n    return undefined;\n}\nfunction getLabelAngle(fieldOrDatumDef, axis, channel, styleConfig, axisConfigs) {\n    const labelAngle = axis?.labelAngle;\n    // try axis value\n    if (labelAngle !== undefined) {\n        return (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(labelAngle) ? labelAngle : (0,_util__WEBPACK_IMPORTED_MODULE_7__.normalizeAngle)(labelAngle);\n    }\n    else {\n        // try axis config value\n        const { configValue: angle } = (0,_config__WEBPACK_IMPORTED_MODULE_10__.getAxisConfig)('labelAngle', styleConfig, axis?.style, axisConfigs);\n        if (angle !== undefined) {\n            return (0,_util__WEBPACK_IMPORTED_MODULE_7__.normalizeAngle)(angle);\n        }\n        else {\n            // get default value\n            if (channel === _channel__WEBPACK_IMPORTED_MODULE_2__.X &&\n                (0,_util__WEBPACK_IMPORTED_MODULE_7__.contains)([_type__WEBPACK_IMPORTED_MODULE_6__.NOMINAL, _type__WEBPACK_IMPORTED_MODULE_6__.ORDINAL], fieldOrDatumDef.type) &&\n                !((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) && fieldOrDatumDef.timeUnit)) {\n                return 270;\n            }\n            // no default\n            return undefined;\n        }\n    }\n}\nfunction normalizeAngleExpr(angle) {\n    return `(((${angle.signal} % 360) + 360) % 360)`;\n}\nfunction defaultLabelBaseline(angle, orient, channel, alwaysIncludeMiddle) {\n    if (angle !== undefined) {\n        if (channel === 'x') {\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(angle)) {\n                const a = normalizeAngleExpr(angle);\n                const orientIsTop = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient) ? `(${orient.signal} === \"top\")` : orient === 'top';\n                return {\n                    signal: `(45 < ${a} && ${a} < 135) || (225 < ${a} && ${a} < 315) ? \"middle\" :` +\n                        `(${a} <= 45 || 315 <= ${a}) === ${orientIsTop} ? \"bottom\" : \"top\"`\n                };\n            }\n            if ((45 < angle && angle < 135) || (225 < angle && angle < 315)) {\n                return 'middle';\n            }\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient)) {\n                const op = angle <= 45 || 315 <= angle ? '===' : '!==';\n                return { signal: `${orient.signal} ${op} \"top\" ? \"bottom\" : \"top\"` };\n            }\n            return (angle <= 45 || 315 <= angle) === (orient === 'top') ? 'bottom' : 'top';\n        }\n        else {\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(angle)) {\n                const a = normalizeAngleExpr(angle);\n                const orientIsLeft = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient) ? `(${orient.signal} === \"left\")` : orient === 'left';\n                const middle = alwaysIncludeMiddle ? '\"middle\"' : 'null';\n                return {\n                    signal: `${a} <= 45 || 315 <= ${a} || (135 <= ${a} && ${a} <= 225) ? ${middle} : (45 <= ${a} && ${a} <= 135) === ${orientIsLeft} ? \"top\" : \"bottom\"`\n                };\n            }\n            if (angle <= 45 || 315 <= angle || (135 <= angle && angle <= 225)) {\n                return alwaysIncludeMiddle ? 'middle' : null;\n            }\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient)) {\n                const op = 45 <= angle && angle <= 135 ? '===' : '!==';\n                return { signal: `${orient.signal} ${op} \"left\" ? \"top\" : \"bottom\"` };\n            }\n            return (45 <= angle && angle <= 135) === (orient === 'left') ? 'top' : 'bottom';\n        }\n    }\n    return undefined;\n}\nfunction defaultLabelAlign(angle, orient, channel) {\n    if (angle === undefined) {\n        return undefined;\n    }\n    const isX = channel === 'x';\n    const startAngle = isX ? 0 : 90;\n    const mainOrient = isX ? 'bottom' : 'left';\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(angle)) {\n        const a = normalizeAngleExpr(angle);\n        const orientIsMain = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient) ? `(${orient.signal} === \"${mainOrient}\")` : orient === mainOrient;\n        return {\n            signal: `(${startAngle ? `(${a} + 90)` : a} % 180 === 0) ? ${isX ? null : '\"center\"'} :` +\n                `(${startAngle} < ${a} && ${a} < ${180 + startAngle}) === ${orientIsMain} ? \"left\" : \"right\"`\n        };\n    }\n    if ((angle + startAngle) % 180 === 0) {\n        // For bottom, use default label align so label flush still works\n        return isX ? null : 'center';\n    }\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(orient)) {\n        const op = startAngle < angle && angle < 180 + startAngle ? '===' : '!==';\n        const orientIsMain = `${orient.signal} ${op} \"${mainOrient}\"`;\n        return {\n            signal: `${orientIsMain} ? \"left\" : \"right\"`\n        };\n    }\n    if ((startAngle < angle && angle < 180 + startAngle) === (orient === mainOrient)) {\n        return 'left';\n    }\n    return 'right';\n}\nfunction defaultLabelFlush(type, channel) {\n    if (channel === 'x' && (0,_util__WEBPACK_IMPORTED_MODULE_7__.contains)(['quantitative', 'temporal'], type)) {\n        return true;\n    }\n    return undefined;\n}\nfunction defaultLabelOverlap(type, scaleType, hasTimeUnit, sort) {\n    // do not prevent overlap for nominal data because there is no way to infer what the missing labels are\n    if ((hasTimeUnit && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(sort)) || (type !== 'nominal' && type !== 'ordinal')) {\n        if (scaleType === 'log' || scaleType === 'symlog') {\n            return 'greedy';\n        }\n        return true;\n    }\n    return undefined;\n}\nfunction defaultOrient(channel) {\n    return channel === 'x' ? 'bottom' : 'left';\n}\nfunction defaultTickCount({ fieldOrDatumDef, scaleType, size, values: vals }) {\n    if (!vals && !(0,_scale__WEBPACK_IMPORTED_MODULE_4__.hasDiscreteDomain)(scaleType) && scaleType !== 'log') {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef)) {\n            if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldOrDatumDef.bin)) {\n                // for binned data, we don't want more ticks than maxbins\n                return { signal: `ceil(${size.signal}/10)` };\n            }\n            if (fieldOrDatumDef.timeUnit &&\n                (0,_util__WEBPACK_IMPORTED_MODULE_7__.contains)(['month', 'hours', 'day', 'quarter'], (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.normalizeTimeUnit)(fieldOrDatumDef.timeUnit)?.unit)) {\n                return undefined;\n            }\n        }\n        return { signal: `ceil(${size.signal}/40)` };\n    }\n    return undefined;\n}\nfunction defaultTickMinStep({ format, fieldOrDatumDef }) {\n    if (format === 'd') {\n        return 1;\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef)) {\n        const { timeUnit } = fieldOrDatumDef;\n        if (timeUnit) {\n            const signal = (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.durationExpr)(timeUnit);\n            if (signal) {\n                return { signal };\n            }\n        }\n    }\n    return undefined;\n}\nfunction getFieldDefTitle(model, channel) {\n    const channel2 = channel === 'x' ? 'x2' : 'y2';\n    const fieldDef = model.fieldDef(channel);\n    const fieldDef2 = model.fieldDef(channel2);\n    const title1 = fieldDef ? fieldDef.title : undefined;\n    const title2 = fieldDef2 ? fieldDef2.title : undefined;\n    if (title1 && title2) {\n        return (0,_common__WEBPACK_IMPORTED_MODULE_9__.mergeTitle)(title1, title2);\n    }\n    else if (title1) {\n        return title1;\n    }\n    else if (title2) {\n        return title2;\n    }\n    else if (title1 !== undefined) {\n        // falsy value to disable config\n        return title1;\n    }\n    else if (title2 !== undefined) {\n        // falsy value to disable config\n        return title2;\n    }\n    return undefined;\n}\nfunction values(axis, fieldOrDatumDef) {\n    const vals = axis.values;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(vals)) {\n        return (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.valueArray)(fieldOrDatumDef, vals);\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(vals)) {\n        return vals;\n    }\n    return undefined;\n}\nfunction defaultZindex(mark, fieldDef) {\n    if (mark === 'rect' && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isDiscrete)(fieldDef)) {\n        return 1;\n    }\n    return 0;\n}\n//# sourceMappingURL=properties.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/axis/properties.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/buildmodel.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/buildmodel.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   buildModel: () => (/* binding */ buildModel)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./concat */ \"../../node_modules/vega-lite/build/src/compile/concat.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/compile/facet.js\");\n/* harmony import */ var _layer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./layer */ \"../../node_modules/vega-lite/build/src/compile/layer.js\");\n/* harmony import */ var _unit__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./unit */ \"../../node_modules/vega-lite/build/src/compile/unit.js\");\n\n\n\n\n\n\nfunction buildModel(spec, parent, parentGivenName, unitSize, config) {\n    if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isFacetSpec)(spec)) {\n        return new _facet__WEBPACK_IMPORTED_MODULE_3__.FacetModel(spec, parent, parentGivenName, config);\n    }\n    else if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isLayerSpec)(spec)) {\n        return new _layer__WEBPACK_IMPORTED_MODULE_4__.LayerModel(spec, parent, parentGivenName, unitSize, config);\n    }\n    else if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isUnitSpec)(spec)) {\n        return new _unit__WEBPACK_IMPORTED_MODULE_5__.UnitModel(spec, parent, parentGivenName, unitSize, config);\n    }\n    else if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isAnyConcatSpec)(spec)) {\n        return new _concat__WEBPACK_IMPORTED_MODULE_2__.ConcatModel(spec, parent, parentGivenName, config);\n    }\n    throw new Error(_log__WEBPACK_IMPORTED_MODULE_0__.message.invalidSpec(spec));\n}\n//# sourceMappingURL=buildmodel.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/buildmodel.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/common.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/common.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BIN_RANGE_DELIMITER: () => (/* binding */ BIN_RANGE_DELIMITER),\n/* harmony export */   applyMarkConfig: () => (/* binding */ applyMarkConfig),\n/* harmony export */   conditionalSignalRefOrValue: () => (/* binding */ conditionalSignalRefOrValue),\n/* harmony export */   exprFromSignalRefOrValue: () => (/* binding */ exprFromSignalRefOrValue),\n/* harmony export */   exprFromValueRefOrSignalRef: () => (/* binding */ exprFromValueRefOrSignalRef),\n/* harmony export */   getMarkConfig: () => (/* binding */ getMarkConfig),\n/* harmony export */   getMarkPropOrConfig: () => (/* binding */ getMarkPropOrConfig),\n/* harmony export */   getMarkStyleConfig: () => (/* binding */ getMarkStyleConfig),\n/* harmony export */   getStyleConfig: () => (/* binding */ getStyleConfig),\n/* harmony export */   getStyles: () => (/* binding */ getStyles),\n/* harmony export */   mergeTitle: () => (/* binding */ mergeTitle),\n/* harmony export */   mergeTitleComponent: () => (/* binding */ mergeTitleComponent),\n/* harmony export */   mergeTitleFieldDefs: () => (/* binding */ mergeTitleFieldDefs),\n/* harmony export */   signalOrStringValue: () => (/* binding */ signalOrStringValue),\n/* harmony export */   signalOrValueRef: () => (/* binding */ signalOrValueRef),\n/* harmony export */   signalOrValueRefWithCondition: () => (/* binding */ signalOrValueRefWithCondition),\n/* harmony export */   signalRefOrValue: () => (/* binding */ signalRefOrValue),\n/* harmony export */   sortParams: () => (/* binding */ sortParams)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _title__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../title */ \"../../node_modules/vega-lite/build/src/title.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n\n\n\n\n\n\nconst BIN_RANGE_DELIMITER = ' \\u2013 ';\nfunction signalOrValueRefWithCondition(val) {\n    const condition = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(val.condition)\n        ? val.condition.map(conditionalSignalRefOrValue)\n        : conditionalSignalRefOrValue(val.condition);\n    return {\n        ...signalRefOrValue(val),\n        condition\n    };\n}\nfunction signalRefOrValue(value) {\n    if ((0,_expr__WEBPACK_IMPORTED_MODULE_2__.isExprRef)(value)) {\n        const { expr, ...rest } = value;\n        return { signal: expr, ...rest };\n    }\n    return value;\n}\nfunction conditionalSignalRefOrValue(value) {\n    if ((0,_expr__WEBPACK_IMPORTED_MODULE_2__.isExprRef)(value)) {\n        const { expr, ...rest } = value;\n        return { signal: expr, ...rest };\n    }\n    return value;\n}\nfunction signalOrValueRef(value) {\n    if ((0,_expr__WEBPACK_IMPORTED_MODULE_2__.isExprRef)(value)) {\n        const { expr, ...rest } = value;\n        return { signal: expr, ...rest };\n    }\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(value)) {\n        return value;\n    }\n    return value !== undefined ? { value } : undefined;\n}\nfunction exprFromSignalRefOrValue(ref) {\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(ref)) {\n        return ref.signal;\n    }\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(ref);\n}\nfunction exprFromValueRefOrSignalRef(ref) {\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(ref)) {\n        return ref.signal;\n    }\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(ref.value);\n}\nfunction signalOrStringValue(v) {\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v)) {\n        return v.signal;\n    }\n    return v == null ? null : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(v);\n}\nfunction applyMarkConfig(e, model, propsList) {\n    for (const property of propsList) {\n        const value = getMarkConfig(property, model.markDef, model.config);\n        if (value !== undefined) {\n            e[property] = signalOrValueRef(value);\n        }\n    }\n    return e;\n}\nfunction getStyles(mark) {\n    return [].concat(mark.type, mark.style ?? []);\n}\nfunction getMarkPropOrConfig(channel, mark, config, opt = {}) {\n    const { vgChannel, ignoreVgConfig } = opt;\n    if (vgChannel && mark[vgChannel] !== undefined) {\n        return mark[vgChannel];\n    }\n    else if (mark[channel] !== undefined) {\n        return mark[channel];\n    }\n    else if (ignoreVgConfig && (!vgChannel || vgChannel === channel)) {\n        return undefined;\n    }\n    return getMarkConfig(channel, mark, config, opt);\n}\n/**\n * Return property value from style or mark specific config property if exists.\n * Otherwise, return general mark specific config.\n */\nfunction getMarkConfig(channel, mark, config, { vgChannel } = {}) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_4__.getFirstDefined)(\n    // style config has highest precedence\n    vgChannel ? getMarkStyleConfig(channel, mark, config.style) : undefined, getMarkStyleConfig(channel, mark, config.style), \n    // then mark-specific config\n    vgChannel ? config[mark.type][vgChannel] : undefined, config[mark.type][channel], // Need to cast because MarkDef doesn't perfectly match with AnyMarkConfig, but if the type isn't available, we'll get nothing here, which is fine\n    // If there is vgChannel, skip vl channel.\n    // For example, vl size for text is vg fontSize, but config.mark.size is only for point size.\n    vgChannel ? config.mark[vgChannel] : config.mark[channel] // Need to cast for the same reason as above\n    );\n}\nfunction getMarkStyleConfig(prop, mark, styleConfigIndex) {\n    return getStyleConfig(prop, getStyles(mark), styleConfigIndex);\n}\nfunction getStyleConfig(p, styles, styleConfigIndex) {\n    styles = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(styles);\n    let value;\n    for (const style of styles) {\n        const styleConfig = styleConfigIndex[style];\n        if (styleConfig && styleConfig[p] !== undefined) {\n            value = styleConfig[p];\n        }\n    }\n    return value;\n}\n/**\n * Return Vega sort parameters (tuple of field and order).\n */\nfunction sortParams(orderDef, fieldRefOption) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(orderDef).reduce((s, orderChannelDef) => {\n        s.field.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(orderChannelDef, fieldRefOption));\n        s.order.push(orderChannelDef.sort ?? 'ascending');\n        return s;\n    }, { field: [], order: [] });\n}\nfunction mergeTitleFieldDefs(f1, f2) {\n    const merged = [...f1];\n    f2.forEach(fdToMerge => {\n        for (const fieldDef1 of merged) {\n            // If already exists, no need to append to merged array\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.deepEqual)(fieldDef1, fdToMerge)) {\n                return;\n            }\n        }\n        merged.push(fdToMerge);\n    });\n    return merged;\n}\nfunction mergeTitle(title1, title2) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.deepEqual)(title1, title2) || !title2) {\n        // if titles are the same or title2 is falsy\n        return title1;\n    }\n    else if (!title1) {\n        // if title1 is falsy\n        return title2;\n    }\n    else {\n        return [...(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(title1), ...(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(title2)].join(', ');\n    }\n}\nfunction mergeTitleComponent(v1, v2) {\n    const v1Val = v1.value;\n    const v2Val = v2.value;\n    if (v1Val == null || v2Val === null) {\n        return {\n            explicit: v1.explicit,\n            value: null\n        };\n    }\n    else if (((0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v1Val) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v1Val)) && ((0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v2Val) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v2Val))) {\n        return {\n            explicit: v1.explicit,\n            value: mergeTitle(v1Val, v2Val)\n        };\n    }\n    else if ((0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v1Val) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v1Val)) {\n        return {\n            explicit: v1.explicit,\n            value: v1Val\n        };\n    }\n    else if ((0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v2Val) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v2Val)) {\n        return {\n            explicit: v1.explicit,\n            value: v2Val\n        };\n    }\n    else if (!(0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v1Val) && !(0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v1Val) && !(0,_title__WEBPACK_IMPORTED_MODULE_3__.isText)(v2Val) && !(0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(v2Val)) {\n        return {\n            explicit: v1.explicit,\n            value: mergeTitleFieldDefs(v1Val, v2Val)\n        };\n    }\n    /* istanbul ignore next: Condition should not happen -- only for warning in development. */\n    throw new Error('It should never reach here');\n}\n//# sourceMappingURL=common.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/common.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/compile.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/compile.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   compile: () => (/* binding */ compile)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _normalize__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../normalize */ \"../../node_modules/vega-lite/build/src/normalize/index.js\");\n/* harmony import */ var _parameter__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../parameter */ \"../../node_modules/vega-lite/build/src/parameter.js\");\n/* harmony import */ var _spec_toplevel__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../spec/toplevel */ \"../../node_modules/vega-lite/build/src/spec/toplevel.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _buildmodel__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./buildmodel */ \"../../node_modules/vega-lite/build/src/compile/buildmodel.js\");\n/* harmony import */ var _data_assemble__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./data/assemble */ \"../../node_modules/vega-lite/build/src/compile/data/assemble.js\");\n/* harmony import */ var _data_optimize__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./data/optimize */ \"../../node_modules/vega-lite/build/src/compile/data/optimize.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * Vega-Lite's main function, for compiling Vega-Lite spec into Vega spec.\n *\n * At a high-level, we make the following transformations in different phases:\n *\n * Input spec\n *     |\n *     |  (Normalization)\n *     v\n * Normalized Spec (Row/Column channels in single-view specs becomes faceted specs, composite marks becomes layered specs.)\n *     |\n *     |  (Build Model)\n *     v\n * A model tree of the spec\n *     |\n *     |  (Parse)\n *     v\n * A model tree with parsed components (intermediate structure of visualization primitives in a format that can be easily merged)\n *     |\n *     | (Optimize)\n *     v\n * A model tree with parsed components with the data component optimized\n *     |\n *     | (Assemble)\n *     v\n * Vega spec\n *\n * @param inputSpec The Vega-Lite specification.\n * @param opt       Optional arguments passed to the Vega-Lite compiler.\n * @returns         An object containing the compiled Vega spec and normalized Vega-Lite spec.\n */\nfunction compile(inputSpec, opt = {}) {\n    // 0. Augment opt with default opts\n    if (opt.logger) {\n        // set the singleton logger to the provided logger\n        _log__WEBPACK_IMPORTED_MODULE_4__.set(opt.logger);\n    }\n    if (opt.fieldTitle) {\n        // set the singleton field title formatter\n        _channeldef__WEBPACK_IMPORTED_MODULE_2__.setTitleFormatter(opt.fieldTitle);\n    }\n    try {\n        // 1. Initialize config by deep merging default config with the config provided via option and the input spec.\n        const config = (0,_config__WEBPACK_IMPORTED_MODULE_3__.initConfig)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.mergeConfig)(opt.config, inputSpec.config));\n        // 2. Normalize: Convert input spec -> normalized spec\n        // - Decompose all extended unit specs into composition of unit spec. For example, a box plot get expanded into multiple layers of bars, ticks, and rules. The shorthand row/column channel is also expanded to a facet spec.\n        // - Normalize autosize and width or height spec\n        const spec = (0,_normalize__WEBPACK_IMPORTED_MODULE_5__.normalize)(inputSpec, config);\n        // 3. Build Model: normalized spec -> Model (a tree structure)\n        // This phases instantiates the models with default config by doing a top-down traversal. This allows us to pass properties that child models derive from their parents via their constructors.\n        // See the abstract `Model` class and its children (UnitModel, LayerModel, FacetModel, ConcatModel) for different types of models.\n        const model = (0,_buildmodel__WEBPACK_IMPORTED_MODULE_9__.buildModel)(spec, null, '', undefined, config);\n        // 4 Parse: Model --> Model with components\n        // Note that components = intermediate representations that are equivalent to Vega specs.\n        // We need these intermediate representation because we need to merge many visualization \"components\" like projections, scales, axes, and legends.\n        // We will later convert these components into actual Vega specs in the assemble phase.\n        // In this phase, we do a bottom-up traversal over the whole tree to\n        // parse for each type of components once (e.g., data, layout, mark, scale).\n        // By doing bottom-up traversal, we start parsing components of unit specs and\n        // then merge child components of parent composite specs.\n        //\n        // Please see inside model.parse() for order of different components parsed.\n        model.parse();\n        // drawDataflow(model.component.data.sources);\n        // 5. Optimize the dataflow. This will modify the data component of the model.\n        (0,_data_optimize__WEBPACK_IMPORTED_MODULE_11__.optimizeDataflow)(model.component.data, model);\n        // drawDataflow(model.component.data.sources);\n        // 6. Assemble: convert model components --> Vega Spec.\n        const vgSpec = assembleTopLevelModel(model, getTopLevelProperties(inputSpec, spec.autosize, config, model), inputSpec.datasets, inputSpec.usermeta);\n        return {\n            spec: vgSpec,\n            normalized: spec\n        };\n    }\n    finally {\n        // Reset the singleton logger if a logger is provided\n        if (opt.logger) {\n            _log__WEBPACK_IMPORTED_MODULE_4__.reset();\n        }\n        // Reset the singleton field title formatter if provided\n        if (opt.fieldTitle) {\n            _channeldef__WEBPACK_IMPORTED_MODULE_2__.resetTitleFormatter();\n        }\n    }\n}\nfunction getTopLevelProperties(inputSpec, autosize, config, model) {\n    const width = model.component.layoutSize.get('width');\n    const height = model.component.layoutSize.get('height');\n    if (autosize === undefined) {\n        autosize = { type: 'pad' };\n        if (model.hasAxisOrientSignalRef()) {\n            autosize.resize = true;\n        }\n    }\n    else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(autosize)) {\n        autosize = { type: autosize };\n    }\n    if (width && height && (0,_spec_toplevel__WEBPACK_IMPORTED_MODULE_7__.isFitType)(autosize.type)) {\n        if (width === 'step' && height === 'step') {\n            _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.droppingFit());\n            autosize.type = 'pad';\n        }\n        else if (width === 'step' || height === 'step') {\n            // effectively XOR, because else if\n            // get step dimension\n            const sizeType = width === 'step' ? 'width' : 'height';\n            // log that we're dropping fit for respective channel\n            _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.droppingFit((0,_channel__WEBPACK_IMPORTED_MODULE_1__.getPositionScaleChannel)(sizeType)));\n            // setting type to inverse fit (so if we dropped fit-x, type is now fit-y)\n            const inverseSizeType = sizeType === 'width' ? 'height' : 'width';\n            autosize.type = (0,_spec_toplevel__WEBPACK_IMPORTED_MODULE_7__.getFitType)(inverseSizeType);\n        }\n    }\n    return {\n        ...((0,_util__WEBPACK_IMPORTED_MODULE_8__.keys)(autosize).length === 1 && autosize.type\n            ? autosize.type === 'pad'\n                ? {}\n                : { autosize: autosize.type }\n            : { autosize }),\n        ...(0,_spec_toplevel__WEBPACK_IMPORTED_MODULE_7__.extractTopLevelProperties)(config, false),\n        ...(0,_spec_toplevel__WEBPACK_IMPORTED_MODULE_7__.extractTopLevelProperties)(inputSpec, true)\n    };\n}\n/*\n * Assemble the top-level model to a Vega spec.\n *\n * Note: this couldn't be `model.assemble()` since the top-level model\n * needs some special treatment to generate top-level properties.\n */\nfunction assembleTopLevelModel(model, topLevelProperties, datasets = {}, usermeta) {\n    // Config with Vega-Lite only config removed.\n    const vgConfig = model.config ? (0,_config__WEBPACK_IMPORTED_MODULE_3__.stripAndRedirectConfig)(model.config) : undefined;\n    const data = [].concat(model.assembleSelectionData([]), \n    // only assemble data in the root\n    (0,_data_assemble__WEBPACK_IMPORTED_MODULE_10__.assembleRootData)(model.component.data, datasets));\n    const projections = model.assembleProjections();\n    const title = model.assembleTitle();\n    const style = model.assembleGroupStyle();\n    const encodeEntry = model.assembleGroupEncodeEntry(true);\n    let layoutSignals = model.assembleLayoutSignals();\n    // move width and height signals with values to top level\n    layoutSignals = layoutSignals.filter(signal => {\n        if ((signal.name === 'width' || signal.name === 'height') && signal.value !== undefined) {\n            topLevelProperties[signal.name] = +signal.value;\n            return false;\n        }\n        return true;\n    });\n    const { params, ...otherTopLevelProps } = topLevelProperties;\n    return {\n        $schema: 'https://vega.github.io/schema/vega/v5.json',\n        ...(model.description ? { description: model.description } : {}),\n        ...otherTopLevelProps,\n        ...(title ? { title } : {}),\n        ...(style ? { style } : {}),\n        ...(encodeEntry ? { encode: { update: encodeEntry } } : {}),\n        data,\n        ...(projections.length > 0 ? { projections } : {}),\n        ...model.assembleGroup([\n            ...layoutSignals,\n            ...model.assembleSelectionTopLevelSignals([]),\n            ...(0,_parameter__WEBPACK_IMPORTED_MODULE_6__.assembleParameterSignals)(params)\n        ]),\n        ...(vgConfig ? { config: vgConfig } : {}),\n        ...(usermeta ? { usermeta } : {})\n    };\n}\n//# sourceMappingURL=compile.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/compile.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/concat.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/concat.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ConcatModel: () => (/* binding */ ConcatModel)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _buildmodel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./buildmodel */ \"../../node_modules/vega-lite/build/src/compile/buildmodel.js\");\n/* harmony import */ var _data_parse__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./data/parse */ \"../../node_modules/vega-lite/build/src/compile/data/parse.js\");\n/* harmony import */ var _layoutsize_assemble__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./layoutsize/assemble */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js\");\n/* harmony import */ var _layoutsize_parse__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./layoutsize/parse */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n\n\n\n\n\n\n\n\nclass ConcatModel extends _model__WEBPACK_IMPORTED_MODULE_7__.Model {\n    constructor(spec, parent, parentGivenName, config) {\n        super(spec, 'concat', parent, parentGivenName, config, spec.resolve);\n        if (spec.resolve?.axis?.x === 'shared' || spec.resolve?.axis?.y === 'shared') {\n            _log__WEBPACK_IMPORTED_MODULE_0__.warn(_log__WEBPACK_IMPORTED_MODULE_0__.message.CONCAT_CANNOT_SHARE_AXIS);\n        }\n        this.children = this.getChildren(spec).map((child, i) => {\n            return (0,_buildmodel__WEBPACK_IMPORTED_MODULE_3__.buildModel)(child, this, this.getName(`concat_${i}`), undefined, config);\n        });\n    }\n    parseData() {\n        this.component.data = (0,_data_parse__WEBPACK_IMPORTED_MODULE_4__.parseData)(this);\n        for (const child of this.children) {\n            child.parseData();\n        }\n    }\n    parseSelections() {\n        // Merge selections up the hierarchy so that they may be referenced\n        // across unit specs. Persist their definitions within each child\n        // to assemble signals which remain within output Vega unit groups.\n        this.component.selection = {};\n        for (const child of this.children) {\n            child.parseSelections();\n            for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(child.component.selection)) {\n                this.component.selection[key] = child.component.selection[key];\n            }\n        }\n    }\n    parseMarkGroup() {\n        for (const child of this.children) {\n            child.parseMarkGroup();\n        }\n    }\n    parseAxesAndHeaders() {\n        for (const child of this.children) {\n            child.parseAxesAndHeaders();\n        }\n        // TODO(#2415): support shared axes\n    }\n    getChildren(spec) {\n        if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isVConcatSpec)(spec)) {\n            return spec.vconcat;\n        }\n        else if ((0,_spec__WEBPACK_IMPORTED_MODULE_1__.isHConcatSpec)(spec)) {\n            return spec.hconcat;\n        }\n        return spec.concat;\n    }\n    parseLayoutSize() {\n        (0,_layoutsize_parse__WEBPACK_IMPORTED_MODULE_6__.parseConcatLayoutSize)(this);\n    }\n    parseAxisGroup() {\n        return null;\n    }\n    assembleSelectionTopLevelSignals(signals) {\n        return this.children.reduce((sg, child) => child.assembleSelectionTopLevelSignals(sg), signals);\n    }\n    assembleSignals() {\n        this.children.forEach(child => child.assembleSignals());\n        return [];\n    }\n    assembleLayoutSignals() {\n        const layoutSignals = (0,_layoutsize_assemble__WEBPACK_IMPORTED_MODULE_5__.assembleLayoutSignals)(this);\n        for (const child of this.children) {\n            layoutSignals.push(...child.assembleLayoutSignals());\n        }\n        return layoutSignals;\n    }\n    assembleSelectionData(data) {\n        return this.children.reduce((db, child) => child.assembleSelectionData(db), data);\n    }\n    assembleMarks() {\n        // only children have marks\n        return this.children.map(child => {\n            const title = child.assembleTitle();\n            const style = child.assembleGroupStyle();\n            const encodeEntry = child.assembleGroupEncodeEntry(false);\n            return {\n                type: 'group',\n                name: child.getName('group'),\n                ...(title ? { title } : {}),\n                ...(style ? { style } : {}),\n                ...(encodeEntry ? { encode: { update: encodeEntry } } : {}),\n                ...child.assembleGroup()\n            };\n        });\n    }\n    assembleGroupStyle() {\n        return undefined;\n    }\n    assembleDefaultLayout() {\n        const columns = this.layout.columns;\n        return {\n            ...(columns != null ? { columns } : {}),\n            bounds: 'full',\n            // Use align each so it can work with multiple plots with different size\n            align: 'each'\n        };\n    }\n}\n//# sourceMappingURL=concat.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/concat.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/aggregate.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/aggregate.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AggregateNode: () => (/* binding */ AggregateNode)\n/* harmony export */ });\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\n\n\nfunction addDimension(dims, channel, fieldDef, model) {\n    const channelDef2 = (0,_model__WEBPACK_IMPORTED_MODULE_6__.isUnitModel)(model) ? model.encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_1__.getSecondaryRangeChannel)(channel)] : undefined;\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isTypedFieldDef)(fieldDef) &&\n        (0,_model__WEBPACK_IMPORTED_MODULE_6__.isUnitModel)(model) &&\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.hasBandEnd)(fieldDef, channelDef2, model.markDef, model.config)) {\n        dims.add((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, {}));\n        dims.add((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { suffix: 'end' }));\n        if (fieldDef.bin && (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.binRequiresRange)(fieldDef, channel)) {\n            dims.add((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { binSuffix: 'range' }));\n        }\n    }\n    else if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isGeoPositionChannel)(channel)) {\n        const posChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_1__.getPositionChannelFromLatLong)(channel);\n        dims.add(model.getName(posChannel));\n    }\n    else {\n        dims.add((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef));\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isScaleFieldDef)(fieldDef) && (0,_scale__WEBPACK_IMPORTED_MODULE_4__.isFieldRange)(fieldDef.scale?.range)) {\n        dims.add(fieldDef.scale.range.field);\n    }\n    return dims;\n}\nfunction mergeMeasures(parentMeasures, childMeasures) {\n    for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(childMeasures)) {\n        // when we merge a measure, we either have to add an aggregation operator or even a new field\n        const ops = childMeasures[field];\n        for (const op of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(ops)) {\n            if (field in parentMeasures) {\n                // add operator to existing measure field\n                parentMeasures[field][op] = new Set([...(parentMeasures[field][op] ?? []), ...ops[op]]);\n            }\n            else {\n                parentMeasures[field] = { [op]: ops[op] };\n            }\n        }\n    }\n}\nclass AggregateNode extends _dataflow__WEBPACK_IMPORTED_MODULE_7__.DataFlowNode {\n    clone() {\n        return new AggregateNode(null, new Set(this.dimensions), (0,_util__WEBPACK_IMPORTED_MODULE_5__.duplicate)(this.measures));\n    }\n    /**\n     * @param dimensions string set for dimensions\n     * @param measures dictionary mapping field name => dict of aggregation functions and names to use\n     */\n    constructor(parent, dimensions, measures) {\n        super(parent);\n        this.dimensions = dimensions;\n        this.measures = measures;\n    }\n    get groupBy() {\n        return this.dimensions;\n    }\n    static makeFromEncoding(parent, model) {\n        let isAggregate = false;\n        model.forEachFieldDef(fd => {\n            if (fd.aggregate) {\n                isAggregate = true;\n            }\n        });\n        const meas = {};\n        const dims = new Set();\n        if (!isAggregate) {\n            // no need to create this node if the model has no aggregation\n            return null;\n        }\n        model.forEachFieldDef((fieldDef, channel) => {\n            const { aggregate, field } = fieldDef;\n            if (aggregate) {\n                if (aggregate === 'count') {\n                    meas['*'] ?? (meas['*'] = {});\n                    meas['*']['count'] = new Set([(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { forAs: true })]);\n                }\n                else {\n                    if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_0__.isArgminDef)(aggregate) || (0,_aggregate__WEBPACK_IMPORTED_MODULE_0__.isArgmaxDef)(aggregate)) {\n                        const op = (0,_aggregate__WEBPACK_IMPORTED_MODULE_0__.isArgminDef)(aggregate) ? 'argmin' : 'argmax';\n                        const argField = aggregate[op];\n                        meas[argField] ?? (meas[argField] = {});\n                        meas[argField][op] = new Set([(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)({ op, field: argField }, { forAs: true })]);\n                    }\n                    else {\n                        meas[field] ?? (meas[field] = {});\n                        meas[field][aggregate] = new Set([(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { forAs: true })]);\n                    }\n                    // For scale channel with domain === 'unaggregated', add min/max so we can use their union as unaggregated domain\n                    if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isScaleChannel)(channel) && model.scaleDomain(channel) === 'unaggregated') {\n                        meas[field] ?? (meas[field] = {});\n                        meas[field]['min'] = new Set([(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)({ field, aggregate: 'min' }, { forAs: true })]);\n                        meas[field]['max'] = new Set([(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)({ field, aggregate: 'max' }, { forAs: true })]);\n                    }\n                }\n            }\n            else {\n                addDimension(dims, channel, fieldDef, model);\n            }\n        });\n        if (dims.size + (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(meas).length === 0) {\n            return null;\n        }\n        return new AggregateNode(parent, dims, meas);\n    }\n    static makeFromTransform(parent, t) {\n        const dims = new Set();\n        const meas = {};\n        for (const s of t.aggregate) {\n            const { op, field, as } = s;\n            if (op) {\n                if (op === 'count') {\n                    meas['*'] ?? (meas['*'] = {});\n                    meas['*']['count'] = new Set([as ? as : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(s, { forAs: true })]);\n                }\n                else {\n                    meas[field] ?? (meas[field] = {});\n                    meas[field][op] = new Set([as ? as : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(s, { forAs: true })]);\n                }\n            }\n        }\n        for (const s of t.groupby ?? []) {\n            dims.add(s);\n        }\n        if (dims.size + (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(meas).length === 0) {\n            return null;\n        }\n        return new AggregateNode(parent, dims, meas);\n    }\n    merge(other) {\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_5__.setEqual)(this.dimensions, other.dimensions)) {\n            mergeMeasures(this.measures, other.measures);\n            return true;\n        }\n        _log__WEBPACK_IMPORTED_MODULE_3__.debug('different dimensions, cannot merge');\n        return false;\n    }\n    addDimensions(fields) {\n        fields.forEach(this.dimensions.add, this.dimensions);\n    }\n    dependentFields() {\n        return new Set([...this.dimensions, ...(0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(this.measures)]);\n    }\n    producedFields() {\n        const out = new Set();\n        for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(this.measures)) {\n            for (const op of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(this.measures[field])) {\n                const m = this.measures[field][op];\n                if (m.size === 0) {\n                    out.add(`${op}_${field}`);\n                }\n                else {\n                    m.forEach(out.add, out);\n                }\n            }\n        }\n        return out;\n    }\n    hash() {\n        return `Aggregate ${(0,_util__WEBPACK_IMPORTED_MODULE_5__.hash)({ dimensions: this.dimensions, measures: this.measures })}`;\n    }\n    assemble() {\n        const ops = [];\n        const fields = [];\n        const as = [];\n        for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(this.measures)) {\n            for (const op of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(this.measures[field])) {\n                for (const alias of this.measures[field][op]) {\n                    as.push(alias);\n                    ops.push(op);\n                    fields.push(field === '*' ? null : (0,_util__WEBPACK_IMPORTED_MODULE_5__.replacePathInField)(field));\n                }\n            }\n        }\n        const result = {\n            type: 'aggregate',\n            groupby: [...this.dimensions].map(_util__WEBPACK_IMPORTED_MODULE_5__.replacePathInField),\n            ops,\n            fields,\n            as\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=aggregate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/aggregate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/assemble.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/assemble.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleFacetData: () => (/* binding */ assembleFacetData),\n/* harmony export */   assembleRootData: () => (/* binding */ assembleRootData)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/compile/data/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _calculate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _density__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./density */ \"../../node_modules/vega-lite/build/src/compile/data/density.js\");\n/* harmony import */ var _extent__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./extent */ \"../../node_modules/vega-lite/build/src/compile/data/extent.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/compile/data/facet.js\");\n/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./filter */ \"../../node_modules/vega-lite/build/src/compile/data/filter.js\");\n/* harmony import */ var _filterinvalid__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./filterinvalid */ \"../../node_modules/vega-lite/build/src/compile/data/filterinvalid.js\");\n/* harmony import */ var _flatten__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./flatten */ \"../../node_modules/vega-lite/build/src/compile/data/flatten.js\");\n/* harmony import */ var _fold__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./fold */ \"../../node_modules/vega-lite/build/src/compile/data/fold.js\");\n/* harmony import */ var _formatparse__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./formatparse */ \"../../node_modules/vega-lite/build/src/compile/data/formatparse.js\");\n/* harmony import */ var _geojson__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./geojson */ \"../../node_modules/vega-lite/build/src/compile/data/geojson.js\");\n/* harmony import */ var _geopoint__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./geopoint */ \"../../node_modules/vega-lite/build/src/compile/data/geopoint.js\");\n/* harmony import */ var _graticule__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./graticule */ \"../../node_modules/vega-lite/build/src/compile/data/graticule.js\");\n/* harmony import */ var _identifier__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./identifier */ \"../../node_modules/vega-lite/build/src/compile/data/identifier.js\");\n/* harmony import */ var _impute__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./impute */ \"../../node_modules/vega-lite/build/src/compile/data/impute.js\");\n/* harmony import */ var _joinaggregate__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./joinaggregate */ \"../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js\");\n/* harmony import */ var _loess__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./loess */ \"../../node_modules/vega-lite/build/src/compile/data/loess.js\");\n/* harmony import */ var _lookup__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./lookup */ \"../../node_modules/vega-lite/build/src/compile/data/lookup.js\");\n/* harmony import */ var _quantile__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./quantile */ \"../../node_modules/vega-lite/build/src/compile/data/quantile.js\");\n/* harmony import */ var _regression__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./regression */ \"../../node_modules/vega-lite/build/src/compile/data/regression.js\");\n/* harmony import */ var _pivot__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./pivot */ \"../../node_modules/vega-lite/build/src/compile/data/pivot.js\");\n/* harmony import */ var _sample__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./sample */ \"../../node_modules/vega-lite/build/src/compile/data/sample.js\");\n/* harmony import */ var _sequence__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./sequence */ \"../../node_modules/vega-lite/build/src/compile/data/sequence.js\");\n/* harmony import */ var _source__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./source */ \"../../node_modules/vega-lite/build/src/compile/data/source.js\");\n/* harmony import */ var _stack__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./stack */ \"../../node_modules/vega-lite/build/src/compile/data/stack.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/compile/data/timeunit.js\");\n/* harmony import */ var _window__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./window */ \"../../node_modules/vega-lite/build/src/compile/data/window.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction makeWalkTree(data) {\n    // to name datasources\n    let datasetIndex = 0;\n    /**\n     * Recursively walk down the tree.\n     */\n    function walkTree(node, dataSource) {\n        if (node instanceof _source__WEBPACK_IMPORTED_MODULE_26__.SourceNode) {\n            // If the source is a named data source or a data source with values, we need\n            // to put it in a different data source. Otherwise, Vega may override the data.\n            if (!node.isGenerator && !(0,_data__WEBPACK_IMPORTED_MODULE_0__.isUrlData)(node.data)) {\n                data.push(dataSource);\n                const newData = {\n                    name: null,\n                    source: dataSource.name,\n                    transform: []\n                };\n                dataSource = newData;\n            }\n        }\n        if (node instanceof _formatparse__WEBPACK_IMPORTED_MODULE_12__.ParseNode) {\n            if (node.parent instanceof _source__WEBPACK_IMPORTED_MODULE_26__.SourceNode && !dataSource.source) {\n                // If node's parent is a root source and the data source does not refer to another data source, use normal format parse\n                dataSource.format = {\n                    ...(dataSource.format ?? {}),\n                    parse: node.assembleFormatParse()\n                };\n                // add calculates for all nested fields\n                dataSource.transform.push(...node.assembleTransforms(true));\n            }\n            else {\n                // Otherwise use Vega expression to parse\n                dataSource.transform.push(...node.assembleTransforms());\n            }\n        }\n        if (node instanceof _facet__WEBPACK_IMPORTED_MODULE_7__.FacetNode) {\n            if (!dataSource.name) {\n                dataSource.name = `data_${datasetIndex++}`;\n            }\n            if (!dataSource.source || dataSource.transform.length > 0) {\n                data.push(dataSource);\n                node.data = dataSource.name;\n            }\n            else {\n                node.data = dataSource.source;\n            }\n            data.push(...node.assemble());\n            // break here because the rest of the tree has to be taken care of by the facet.\n            return;\n        }\n        if (node instanceof _graticule__WEBPACK_IMPORTED_MODULE_15__.GraticuleNode ||\n            node instanceof _sequence__WEBPACK_IMPORTED_MODULE_25__.SequenceNode ||\n            node instanceof _filterinvalid__WEBPACK_IMPORTED_MODULE_9__.FilterInvalidNode ||\n            node instanceof _filter__WEBPACK_IMPORTED_MODULE_8__.FilterNode ||\n            node instanceof _calculate__WEBPACK_IMPORTED_MODULE_3__.CalculateNode ||\n            node instanceof _geopoint__WEBPACK_IMPORTED_MODULE_14__.GeoPointNode ||\n            node instanceof _aggregate__WEBPACK_IMPORTED_MODULE_1__.AggregateNode ||\n            node instanceof _lookup__WEBPACK_IMPORTED_MODULE_20__.LookupNode ||\n            node instanceof _window__WEBPACK_IMPORTED_MODULE_29__.WindowTransformNode ||\n            node instanceof _joinaggregate__WEBPACK_IMPORTED_MODULE_18__.JoinAggregateTransformNode ||\n            node instanceof _fold__WEBPACK_IMPORTED_MODULE_11__.FoldTransformNode ||\n            node instanceof _flatten__WEBPACK_IMPORTED_MODULE_10__.FlattenTransformNode ||\n            node instanceof _density__WEBPACK_IMPORTED_MODULE_5__.DensityTransformNode ||\n            node instanceof _loess__WEBPACK_IMPORTED_MODULE_19__.LoessTransformNode ||\n            node instanceof _quantile__WEBPACK_IMPORTED_MODULE_21__.QuantileTransformNode ||\n            node instanceof _regression__WEBPACK_IMPORTED_MODULE_22__.RegressionTransformNode ||\n            node instanceof _identifier__WEBPACK_IMPORTED_MODULE_16__.IdentifierNode ||\n            node instanceof _sample__WEBPACK_IMPORTED_MODULE_24__.SampleTransformNode ||\n            node instanceof _pivot__WEBPACK_IMPORTED_MODULE_23__.PivotTransformNode ||\n            node instanceof _extent__WEBPACK_IMPORTED_MODULE_6__.ExtentTransformNode) {\n            dataSource.transform.push(node.assemble());\n        }\n        if (node instanceof _bin__WEBPACK_IMPORTED_MODULE_2__.BinNode ||\n            node instanceof _timeunit__WEBPACK_IMPORTED_MODULE_28__.TimeUnitNode ||\n            node instanceof _impute__WEBPACK_IMPORTED_MODULE_17__.ImputeNode ||\n            node instanceof _stack__WEBPACK_IMPORTED_MODULE_27__.StackNode ||\n            node instanceof _geojson__WEBPACK_IMPORTED_MODULE_13__.GeoJSONNode) {\n            dataSource.transform.push(...node.assemble());\n        }\n        if (node instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode) {\n            if (dataSource.source && dataSource.transform.length === 0) {\n                node.setSource(dataSource.source);\n            }\n            else if (node.parent instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode) {\n                // Note that an output node may be required but we still do not assemble a\n                // separate data source for it.\n                node.setSource(dataSource.name);\n            }\n            else {\n                if (!dataSource.name) {\n                    dataSource.name = `data_${datasetIndex++}`;\n                }\n                // Here we set the name of the datasource we generated. From now on\n                // other assemblers can use it.\n                node.setSource(dataSource.name);\n                // if this node has more than one child, we will add a datasource automatically\n                if (node.numChildren() === 1) {\n                    data.push(dataSource);\n                    const newData = {\n                        name: null,\n                        source: dataSource.name,\n                        transform: []\n                    };\n                    dataSource = newData;\n                }\n            }\n        }\n        switch (node.numChildren()) {\n            case 0:\n                // done\n                if (node instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode && (!dataSource.source || dataSource.transform.length > 0)) {\n                    // do not push empty datasources that are simply references\n                    data.push(dataSource);\n                }\n                break;\n            case 1:\n                walkTree(node.children[0], dataSource);\n                break;\n            default: {\n                if (!dataSource.name) {\n                    dataSource.name = `data_${datasetIndex++}`;\n                }\n                let source = dataSource.name;\n                if (!dataSource.source || dataSource.transform.length > 0) {\n                    data.push(dataSource);\n                }\n                else {\n                    source = dataSource.source;\n                }\n                for (const child of node.children) {\n                    const newData = {\n                        name: null,\n                        source,\n                        transform: []\n                    };\n                    walkTree(child, newData);\n                }\n                break;\n            }\n        }\n    }\n    return walkTree;\n}\n/**\n * Assemble data sources that are derived from faceted data.\n */\nfunction assembleFacetData(root) {\n    const data = [];\n    const walkTree = makeWalkTree(data);\n    for (const child of root.children) {\n        walkTree(child, {\n            source: root.name,\n            name: null,\n            transform: []\n        });\n    }\n    return data;\n}\n/**\n * Create Vega data array from a given compiled model and append all of them to the given array\n *\n * @param  model\n * @param  data array\n * @return modified data array\n */\nfunction assembleRootData(dataComponent, datasets) {\n    const data = [];\n    // dataComponent.sources.forEach(debug);\n    // draw(dataComponent.sources);\n    const walkTree = makeWalkTree(data);\n    let sourceIndex = 0;\n    for (const root of dataComponent.sources) {\n        // assign a name if the source does not have a name yet\n        if (!root.hasName()) {\n            root.dataName = `source_${sourceIndex++}`;\n        }\n        const newData = root.assemble();\n        walkTree(root, newData);\n    }\n    // remove empty transform arrays for cleaner output\n    for (const d of data) {\n        if (d.transform.length === 0) {\n            delete d.transform;\n        }\n    }\n    // move sources without transforms (the ones that are potentially used in lookups) to the beginning\n    let whereTo = 0;\n    for (const [i, d] of data.entries()) {\n        if ((d.transform ?? []).length === 0 && !d.source) {\n            data.splice(whereTo++, 0, data.splice(i, 1)[0]);\n        }\n    }\n    // now fix the from references in lookup transforms\n    for (const d of data) {\n        for (const t of d.transform ?? []) {\n            if (t.type === 'lookup') {\n                t.from = dataComponent.outputNodes[t.from].getSource();\n            }\n        }\n    }\n    // inline values for datasets that are in the datastore\n    for (const d of data) {\n        if (d.name in datasets) {\n            d.values = datasets[d.name];\n        }\n    }\n    return data;\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/bin.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/bin.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BinNode: () => (/* binding */ BinNode),\n/* harmony export */   getBinSignalName: () => (/* binding */ getBinSignalName)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _selection_parse__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../selection/parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\n\n\nfunction rangeFormula(model, fieldDef, channel, config) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.binRequiresRange)(fieldDef, channel)) {\n        // read format from axis or legend, if there is no format then use config.numberFormat\n        const guide = (0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model)\n            ? model.axis(channel) ?? model.legend(channel) ?? {}\n            : {};\n        const startField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { expr: 'datum' });\n        const endField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { expr: 'datum', binSuffix: 'end' });\n        return {\n            formulaAs: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldDef, { binSuffix: 'range', forAs: true }),\n            formula: (0,_format__WEBPACK_IMPORTED_MODULE_4__.binFormatExpression)(startField, endField, guide.format, guide.formatType, config)\n        };\n    }\n    return {};\n}\nfunction binKey(bin, field) {\n    return `${(0,_bin__WEBPACK_IMPORTED_MODULE_1__.binToString)(bin)}_${field}`;\n}\nfunction getSignalsFromModel(model, key) {\n    return {\n        signal: model.getName(`${key}_bins`),\n        extentSignal: model.getName(`${key}_extent`)\n    };\n}\nfunction getBinSignalName(model, field, bin) {\n    const normalizedBin = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.normalizeBin)(bin, undefined) ?? {};\n    const key = binKey(normalizedBin, field);\n    return model.getName(`${key}_bins`);\n}\nfunction isBinTransform(t) {\n    return 'as' in t;\n}\nfunction createBinComponent(t, bin, model) {\n    let as;\n    let span;\n    if (isBinTransform(t)) {\n        as = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(t.as) ? [t.as, `${t.as}_end`] : [t.as[0], t.as[1]];\n    }\n    else {\n        as = [(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(t, { forAs: true }), (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(t, { binSuffix: 'end', forAs: true })];\n    }\n    const normalizedBin = { ...(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.normalizeBin)(bin, undefined) };\n    const key = binKey(normalizedBin, t.field);\n    const { signal, extentSignal } = getSignalsFromModel(model, key);\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isParameterExtent)(normalizedBin.extent)) {\n        const ext = normalizedBin.extent;\n        span = (0,_selection_parse__WEBPACK_IMPORTED_MODULE_6__.parseSelectionExtent)(model, ext.param, ext);\n        delete normalizedBin.extent; // Vega-Lite selection extent map to Vega's span property.\n    }\n    const binComponent = {\n        bin: normalizedBin,\n        field: t.field,\n        as: [as],\n        ...(signal ? { signal } : {}),\n        ...(extentSignal ? { extentSignal } : {}),\n        ...(span ? { span } : {})\n    };\n    return { key, binComponent };\n}\nclass BinNode extends _dataflow__WEBPACK_IMPORTED_MODULE_7__.DataFlowNode {\n    clone() {\n        return new BinNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.bins));\n    }\n    constructor(parent, bins) {\n        super(parent);\n        this.bins = bins;\n    }\n    static makeFromEncoding(parent, model) {\n        const bins = model.reduceFieldDef((binComponentIndex, fieldDef, channel) => {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isTypedFieldDef)(fieldDef) && (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldDef.bin)) {\n                const { key, binComponent } = createBinComponent(fieldDef, fieldDef.bin, model);\n                binComponentIndex[key] = {\n                    ...binComponent,\n                    ...binComponentIndex[key],\n                    ...rangeFormula(model, fieldDef, channel, model.config)\n                };\n            }\n            return binComponentIndex;\n        }, {});\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.isEmpty)(bins)) {\n            return null;\n        }\n        return new BinNode(parent, bins);\n    }\n    /**\n     * Creates a bin node from BinTransform.\n     * The optional parameter should provide\n     */\n    static makeFromTransform(parent, t, model) {\n        const { key, binComponent } = createBinComponent(t, t.bin, model);\n        return new BinNode(parent, {\n            [key]: binComponent\n        });\n    }\n    /**\n     * Merge bin nodes. This method either integrates the bin config from the other node\n     * or if this node already has a bin config, renames the corresponding signal in the model.\n     */\n    merge(other, renameSignal) {\n        for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_3__.keys)(other.bins)) {\n            if (key in this.bins) {\n                renameSignal(other.bins[key].signal, this.bins[key].signal);\n                // Ensure that we don't have duplicate names for signal pairs\n                this.bins[key].as = (0,_util__WEBPACK_IMPORTED_MODULE_3__.unique)([...this.bins[key].as, ...other.bins[key].as], _util__WEBPACK_IMPORTED_MODULE_3__.hash);\n            }\n            else {\n                this.bins[key] = other.bins[key];\n            }\n        }\n        for (const child of other.children) {\n            other.removeChild(child);\n            child.parent = this;\n        }\n        other.remove();\n    }\n    producedFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_3__.vals)(this.bins)\n            .map(c => c.as)\n            .flat(2));\n    }\n    dependentFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_3__.vals)(this.bins).map(c => c.field));\n    }\n    hash() {\n        return `Bin ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)(this.bins)}`;\n    }\n    assemble() {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_3__.vals)(this.bins).flatMap(bin => {\n            const transform = [];\n            const [binAs, ...remainingAs] = bin.as;\n            const { extent, ...params } = bin.bin;\n            const binTrans = {\n                type: 'bin',\n                field: (0,_util__WEBPACK_IMPORTED_MODULE_3__.replacePathInField)(bin.field),\n                as: binAs,\n                signal: bin.signal,\n                ...(!(0,_bin__WEBPACK_IMPORTED_MODULE_1__.isParameterExtent)(extent) ? { extent } : { extent: null }),\n                ...(bin.span ? { span: { signal: `span(${bin.span})` } } : {}),\n                ...params\n            };\n            if (!extent && bin.extentSignal) {\n                transform.push({\n                    type: 'extent',\n                    field: (0,_util__WEBPACK_IMPORTED_MODULE_3__.replacePathInField)(bin.field),\n                    signal: bin.extentSignal\n                });\n                binTrans.extent = { signal: bin.extentSignal };\n            }\n            transform.push(binTrans);\n            for (const as of remainingAs) {\n                for (let i = 0; i < 2; i++) {\n                    transform.push({\n                        type: 'formula',\n                        expr: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)({ field: binAs[i] }, { expr: 'datum' }),\n                        as: as[i]\n                    });\n                }\n            }\n            if (bin.formula) {\n                transform.push({\n                    type: 'formula',\n                    expr: bin.formula,\n                    as: bin.formulaAs\n                });\n            }\n            return transform;\n        });\n    }\n}\n//# sourceMappingURL=bin.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/bin.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/calculate.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/calculate.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CalculateNode: () => (/* binding */ CalculateNode),\n/* harmony export */   sortArrayIndexField: () => (/* binding */ sortArrayIndexField)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _expressions__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./expressions */ \"../../node_modules/vega-lite/build/src/compile/data/expressions.js\");\n\n\n\n\n\n\nclass CalculateNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new CalculateNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this._dependentFields = (0,_expressions__WEBPACK_IMPORTED_MODULE_5__.getDependentFields)(this.transform.calculate);\n    }\n    static parseAllForSortIndex(parent, model) {\n        // get all the encoding with sort fields from model\n        model.forEachFieldDef((fieldDef, channel) => {\n            if (!(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isScaleFieldDef)(fieldDef)) {\n                return;\n            }\n            if ((0,_sort__WEBPACK_IMPORTED_MODULE_2__.isSortArray)(fieldDef.sort)) {\n                const { field, timeUnit } = fieldDef;\n                const sort = fieldDef.sort;\n                // generate `datum[\"a\"] === val0 ? 0 : datum[\"a\"] === val1 ? 1 : ... : n` via FieldEqualPredicate\n                const calculate = sort\n                    .map((sortValue, i) => {\n                    return `${(0,_predicate__WEBPACK_IMPORTED_MODULE_1__.fieldFilterExpression)({ field, timeUnit, equal: sortValue })} ? ${i} : `;\n                })\n                    .join('') + sort.length;\n                parent = new CalculateNode(parent, {\n                    calculate,\n                    as: sortArrayIndexField(fieldDef, channel, { forAs: true })\n                });\n            }\n        });\n        return parent;\n    }\n    producedFields() {\n        return new Set([this.transform.as]);\n    }\n    dependentFields() {\n        return this._dependentFields;\n    }\n    assemble() {\n        return {\n            type: 'formula',\n            expr: this.transform.calculate,\n            as: this.transform.as\n        };\n    }\n    hash() {\n        return `Calculate ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)(this.transform)}`;\n    }\n}\nfunction sortArrayIndexField(fieldDef, channel, opt) {\n    return (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.vgField)(fieldDef, { prefix: channel, suffix: 'sort_index', ...(opt ?? {}) });\n}\n//# sourceMappingURL=calculate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/calculate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/dataflow.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/dataflow.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DataFlowNode: () => (/* binding */ DataFlowNode),\n/* harmony export */   OutputNode: () => (/* binding */ OutputNode)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n/**\n * A node in the dataflow tree.\n */\nclass DataFlowNode {\n    constructor(parent, debugName) {\n        this.debugName = debugName;\n        this._children = [];\n        this._parent = null;\n        if (parent) {\n            this.parent = parent;\n        }\n    }\n    /**\n     * Clone this node with a deep copy but don't clone links to children or parents.\n     */\n    clone() {\n        throw new Error('Cannot clone node');\n    }\n    get parent() {\n        return this._parent;\n    }\n    /**\n     * Set the parent of the node and also add this node to the parent's children.\n     */\n    set parent(parent) {\n        this._parent = parent;\n        if (parent) {\n            parent.addChild(this);\n        }\n    }\n    get children() {\n        return this._children;\n    }\n    numChildren() {\n        return this._children.length;\n    }\n    addChild(child, loc) {\n        // do not add the same child twice\n        if (this._children.includes(child)) {\n            _log__WEBPACK_IMPORTED_MODULE_0__.warn(_log__WEBPACK_IMPORTED_MODULE_0__.message.ADD_SAME_CHILD_TWICE);\n            return;\n        }\n        if (loc !== undefined) {\n            this._children.splice(loc, 0, child);\n        }\n        else {\n            this._children.push(child);\n        }\n    }\n    removeChild(oldChild) {\n        const loc = this._children.indexOf(oldChild);\n        this._children.splice(loc, 1);\n        return loc;\n    }\n    /**\n     * Remove node from the dataflow.\n     */\n    remove() {\n        let loc = this._parent.removeChild(this);\n        for (const child of this._children) {\n            // do not use the set method because we want to insert at a particular location\n            child._parent = this._parent;\n            this._parent.addChild(child, loc++);\n        }\n    }\n    /**\n     * Insert another node as a parent of this node.\n     */\n    insertAsParentOf(other) {\n        const parent = other.parent;\n        parent.removeChild(this);\n        this.parent = parent;\n        other.parent = this;\n    }\n    swapWithParent() {\n        const parent = this._parent;\n        const newParent = parent.parent;\n        // reconnect the children\n        for (const child of this._children) {\n            child.parent = parent;\n        }\n        // remove old links\n        this._children = []; // equivalent to removing every child link one by one\n        parent.removeChild(this);\n        const loc = parent.parent.removeChild(parent);\n        // swap two nodes but maintain order in children\n        this._parent = newParent;\n        newParent.addChild(this, loc);\n        parent.parent = this;\n    }\n}\nclass OutputNode extends DataFlowNode {\n    clone() {\n        const cloneObj = new this.constructor();\n        cloneObj.debugName = `clone_${this.debugName}`;\n        cloneObj._source = this._source;\n        cloneObj._name = `clone_${this._name}`;\n        cloneObj.type = this.type;\n        cloneObj.refCounts = this.refCounts;\n        cloneObj.refCounts[cloneObj._name] = 0;\n        return cloneObj;\n    }\n    /**\n     * @param source The name of the source. Will change in assemble.\n     * @param type The type of the output node.\n     * @param refCounts A global ref counter map.\n     */\n    constructor(parent, source, type, refCounts) {\n        super(parent, source);\n        this.type = type;\n        this.refCounts = refCounts;\n        this._source = this._name = source;\n        if (this.refCounts && !(this._name in this.refCounts)) {\n            this.refCounts[this._name] = 0;\n        }\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return new Set();\n    }\n    hash() {\n        if (this._hash === undefined) {\n            this._hash = `Output ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.uniqueId)()}`;\n        }\n        return this._hash;\n    }\n    /**\n     * Request the datasource name and increase the ref counter.\n     *\n     * During the parsing phase, this will return the simple name such as 'main' or 'raw'.\n     * It is crucial to request the name from an output node to mark it as a required node.\n     * If nobody ever requests the name, this datasource will not be instantiated in the assemble phase.\n     *\n     * In the assemble phase, this will return the correct name.\n     */\n    getSource() {\n        this.refCounts[this._name]++;\n        return this._source;\n    }\n    isRequired() {\n        return !!this.refCounts[this._name];\n    }\n    setSource(source) {\n        this._source = source;\n    }\n}\n//# sourceMappingURL=dataflow.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/dataflow.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/density.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/density.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DensityTransformNode: () => (/* binding */ DensityTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for density transform nodes\n */\nclass DensityTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new DensityTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const specifiedAs = this.transform.as ?? [undefined, undefined];\n        this.transform.as = [specifiedAs[0] ?? 'value', specifiedAs[1] ?? 'density'];\n        // set steps when we are grouping so that we get consitent sampling points for imputing and grouping\n        if (transform.groupby && transform.minsteps == null && transform.maxsteps == null && transform.steps == null) {\n            this.transform.steps = 200;\n        }\n    }\n    dependentFields() {\n        return new Set([this.transform.density, ...(this.transform.groupby ?? [])]);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `DensityTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { density, ...rest } = this.transform;\n        const result = {\n            type: 'kde',\n            field: density,\n            ...rest\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=density.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/density.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/expressions.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/expressions.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getDependentFields: () => (/* binding */ getDependentFields)\n/* harmony export */ });\n/* harmony import */ var vega_expression__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-expression */ \"../../node_modules/vega-expression/build/vega-expression.module.js\");\n\nfunction getName(node) {\n    const name = [];\n    if (node.type === 'Identifier') {\n        return [node.name];\n    }\n    if (node.type === 'Literal') {\n        return [node.value];\n    }\n    if (node.type === 'MemberExpression') {\n        name.push(...getName(node.object));\n        name.push(...getName(node.property));\n    }\n    return name;\n}\nfunction startsWithDatum(node) {\n    if (node.object.type === 'MemberExpression') {\n        return startsWithDatum(node.object);\n    }\n    return node.object.name === 'datum';\n}\nfunction getDependentFields(expression) {\n    const ast = (0,vega_expression__WEBPACK_IMPORTED_MODULE_0__.parseExpression)(expression);\n    const dependents = new Set();\n    // visit is missing in types https://github.com/vega/vega/issues/3298\n    ast.visit((node) => {\n        if (node.type === 'MemberExpression' && startsWithDatum(node)) {\n            dependents.add(getName(node).slice(1).join('.'));\n        }\n    });\n    return dependents;\n}\n//# sourceMappingURL=expressions.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/expressions.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/extent.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/extent.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ExtentTransformNode: () => (/* binding */ ExtentTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for flatten transform nodes\n */\nclass ExtentTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new ExtentTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform);\n    }\n    dependentFields() {\n        return new Set([this.transform.extent]);\n    }\n    producedFields() {\n        return new Set([]);\n    }\n    hash() {\n        return `ExtentTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { extent, param } = this.transform;\n        const result = {\n            type: 'extent',\n            field: extent,\n            signal: param\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=extent.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/extent.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/facet.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/facet.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FacetNode: () => (/* binding */ FacetNode)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _header_component__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../header/component */ \"../../node_modules/vega-lite/build/src/compile/header/component.js\");\n/* harmony import */ var _scale_domain__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../scale/domain */ \"../../node_modules/vega-lite/build/src/compile/scale/domain.js\");\n/* harmony import */ var _calculate__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * A node that helps us track what fields we are faceting by.\n */\nclass FacetNode extends _dataflow__WEBPACK_IMPORTED_MODULE_12__.DataFlowNode {\n    /**\n     * @param model The facet model.\n     * @param name The name that this facet source will have.\n     * @param data The source data for this facet data.\n     */\n    constructor(parent, model, name, data) {\n        super(parent);\n        this.model = model;\n        this.name = name;\n        this.data = data;\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            const fieldDef = model.facet[channel];\n            if (fieldDef) {\n                const { bin, sort } = fieldDef;\n                this[channel] = {\n                    name: model.getName(`${channel}_domain`),\n                    fields: [(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef), ...((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(bin) ? [(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, { binSuffix: 'end' })] : [])],\n                    ...((0,_sort__WEBPACK_IMPORTED_MODULE_6__.isSortField)(sort)\n                        ? { sortField: sort }\n                        : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(sort)\n                            ? { sortIndexField: (0,_calculate__WEBPACK_IMPORTED_MODULE_11__.sortArrayIndexField)(fieldDef, channel) }\n                            : {})\n                };\n            }\n        }\n        this.childModel = model.child;\n    }\n    hash() {\n        let out = `Facet`;\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            if (this[channel]) {\n                out += ` ${channel.charAt(0)}:${(0,_util__WEBPACK_IMPORTED_MODULE_7__.hash)(this[channel])}`;\n            }\n        }\n        return out;\n    }\n    get fields() {\n        const f = [];\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            if (this[channel]?.fields) {\n                f.push(...this[channel].fields);\n            }\n        }\n        return f;\n    }\n    dependentFields() {\n        const depFields = new Set(this.fields);\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            if (this[channel]) {\n                if (this[channel].sortField) {\n                    depFields.add(this[channel].sortField.field);\n                }\n                if (this[channel].sortIndexField) {\n                    depFields.add(this[channel].sortIndexField);\n                }\n            }\n        }\n        return depFields;\n    }\n    producedFields() {\n        return new Set(); // facet does not produce any new fields\n    }\n    /**\n     * The name to reference this source is its name.\n     */\n    getSource() {\n        return this.name;\n    }\n    getChildIndependentFieldsWithStep() {\n        const childIndependentFieldsWithStep = {};\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.POSITION_SCALE_CHANNELS) {\n            const childScaleComponent = this.childModel.component.scales[channel];\n            if (childScaleComponent && !childScaleComponent.merged) {\n                // independent scale\n                const type = childScaleComponent.get('type');\n                const range = childScaleComponent.get('range');\n                if ((0,_scale__WEBPACK_IMPORTED_MODULE_5__.hasDiscreteDomain)(type) && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isVgRangeStep)(range)) {\n                    const domain = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_10__.assembleDomain)(this.childModel, channel);\n                    const field = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_10__.getFieldFromDomain)(domain);\n                    if (field) {\n                        childIndependentFieldsWithStep[channel] = field;\n                    }\n                    else {\n                        _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.unknownField(channel));\n                    }\n                }\n            }\n        }\n        return childIndependentFieldsWithStep;\n    }\n    assembleRowColumnHeaderData(channel, crossedDataName, childIndependentFieldsWithStep) {\n        const childChannel = { row: 'y', column: 'x', facet: undefined }[channel];\n        const fields = [];\n        const ops = [];\n        const as = [];\n        if (childChannel && childIndependentFieldsWithStep && childIndependentFieldsWithStep[childChannel]) {\n            if (crossedDataName) {\n                // If there is a crossed data, calculate max\n                fields.push(`distinct_${childIndependentFieldsWithStep[childChannel]}`);\n                ops.push('max');\n            }\n            else {\n                // If there is no crossed data, just calculate distinct\n                fields.push(childIndependentFieldsWithStep[childChannel]);\n                ops.push('distinct');\n            }\n            // Although it is technically a max, just name it distinct so it's easier to refer to it\n            as.push(`distinct_${childIndependentFieldsWithStep[childChannel]}`);\n        }\n        const { sortField, sortIndexField } = this[channel];\n        if (sortField) {\n            const { op = _sort__WEBPACK_IMPORTED_MODULE_6__.DEFAULT_SORT_OP, field } = sortField;\n            fields.push(field);\n            ops.push(op);\n            as.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(sortField, { forAs: true }));\n        }\n        else if (sortIndexField) {\n            fields.push(sortIndexField);\n            ops.push('max');\n            as.push(sortIndexField);\n        }\n        return {\n            name: this[channel].name,\n            // Use data from the crossed one if it exist\n            source: crossedDataName ?? this.data,\n            transform: [\n                {\n                    type: 'aggregate',\n                    groupby: this[channel].fields,\n                    ...(fields.length\n                        ? {\n                            fields,\n                            ops,\n                            as\n                        }\n                        : {})\n                }\n            ]\n        };\n    }\n    assembleFacetHeaderData(childIndependentFieldsWithStep) {\n        const { columns } = this.model.layout;\n        const { layoutHeaders } = this.model.component;\n        const data = [];\n        const hasSharedAxis = {};\n        for (const headerChannel of _header_component__WEBPACK_IMPORTED_MODULE_9__.HEADER_CHANNELS) {\n            for (const headerType of _header_component__WEBPACK_IMPORTED_MODULE_9__.HEADER_TYPES) {\n                const headers = (layoutHeaders[headerChannel] && layoutHeaders[headerChannel][headerType]) ?? [];\n                for (const header of headers) {\n                    if (header.axes?.length > 0) {\n                        hasSharedAxis[headerChannel] = true;\n                        break;\n                    }\n                }\n            }\n            if (hasSharedAxis[headerChannel]) {\n                const cardinality = `length(data(\"${this.facet.name}\"))`;\n                const stop = headerChannel === 'row'\n                    ? columns\n                        ? { signal: `ceil(${cardinality} / ${columns})` }\n                        : 1\n                    : columns\n                        ? { signal: `min(${cardinality}, ${columns})` }\n                        : { signal: cardinality };\n                data.push({\n                    name: `${this.facet.name}_${headerChannel}`,\n                    transform: [\n                        {\n                            type: 'sequence',\n                            start: 0,\n                            stop\n                        }\n                    ]\n                });\n            }\n        }\n        const { row, column } = hasSharedAxis;\n        if (row || column) {\n            data.unshift(this.assembleRowColumnHeaderData('facet', null, childIndependentFieldsWithStep));\n        }\n        return data;\n    }\n    assemble() {\n        const data = [];\n        let crossedDataName = null;\n        const childIndependentFieldsWithStep = this.getChildIndependentFieldsWithStep();\n        const { column, row, facet } = this;\n        if (column && row && (childIndependentFieldsWithStep.x || childIndependentFieldsWithStep.y)) {\n            // Need to create a cross dataset to correctly calculate cardinality\n            crossedDataName = `cross_${this.column.name}_${this.row.name}`;\n            const fields = [].concat(childIndependentFieldsWithStep.x ?? [], childIndependentFieldsWithStep.y ?? []);\n            const ops = fields.map(() => 'distinct');\n            data.push({\n                name: crossedDataName,\n                source: this.data,\n                transform: [\n                    {\n                        type: 'aggregate',\n                        groupby: this.fields,\n                        fields,\n                        ops\n                    }\n                ]\n            });\n        }\n        for (const channel of [_channel__WEBPACK_IMPORTED_MODULE_2__.COLUMN, _channel__WEBPACK_IMPORTED_MODULE_2__.ROW]) {\n            if (this[channel]) {\n                data.push(this.assembleRowColumnHeaderData(channel, crossedDataName, childIndependentFieldsWithStep));\n            }\n        }\n        if (facet) {\n            const facetData = this.assembleFacetHeaderData(childIndependentFieldsWithStep);\n            if (facetData) {\n                data.push(...facetData);\n            }\n        }\n        return data;\n    }\n}\n//# sourceMappingURL=facet.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/facet.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/filter.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/filter.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FilterNode: () => (/* binding */ FilterNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../predicate */ \"../../node_modules/vega-lite/build/src/compile/predicate.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _expressions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./expressions */ \"../../node_modules/vega-lite/build/src/compile/data/expressions.js\");\n\n\n\n\nclass FilterNode extends _dataflow__WEBPACK_IMPORTED_MODULE_2__.DataFlowNode {\n    clone() {\n        return new FilterNode(null, this.model, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.filter));\n    }\n    constructor(parent, model, filter) {\n        super(parent);\n        this.model = model;\n        this.filter = filter;\n        // TODO: refactor this to not take a node and\n        // then add a static function makeFromOperand and make the constructor take only an expression\n        this.expr = (0,_predicate__WEBPACK_IMPORTED_MODULE_1__.expression)(this.model, this.filter, this);\n        this._dependentFields = (0,_expressions__WEBPACK_IMPORTED_MODULE_3__.getDependentFields)(this.expr);\n    }\n    dependentFields() {\n        return this._dependentFields;\n    }\n    producedFields() {\n        return new Set(); // filter does not produce any new fields\n    }\n    assemble() {\n        return {\n            type: 'filter',\n            expr: this.expr\n        };\n    }\n    hash() {\n        return `Filter ${this.expr}`;\n    }\n}\n//# sourceMappingURL=filter.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/filter.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/filterinvalid.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/filterinvalid.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FilterInvalidNode: () => (/* binding */ FilterInvalidNode)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\n\nclass FilterInvalidNode extends _dataflow__WEBPACK_IMPORTED_MODULE_6__.DataFlowNode {\n    clone() {\n        return new FilterInvalidNode(null, { ...this.filter });\n    }\n    constructor(parent, filter) {\n        super(parent);\n        this.filter = filter;\n    }\n    static make(parent, model) {\n        const { config, mark, markDef } = model;\n        const invalid = (0,_common__WEBPACK_IMPORTED_MODULE_5__.getMarkPropOrConfig)('invalid', markDef, config);\n        if (invalid !== 'filter') {\n            return null;\n        }\n        const filter = model.reduceFieldDef((aggregator, fieldDef, channel) => {\n            const scaleComponent = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.isScaleChannel)(channel) && model.getScaleComponent(channel);\n            if (scaleComponent) {\n                const scaleType = scaleComponent.get('type');\n                // While discrete domain scales can handle invalid values, continuous scales can't.\n                // Thus, for non-path marks, we have to filter null for scales with continuous domains.\n                // (For path marks, we will use \"defined\" property and skip these values instead.)\n                if ((0,_scale__WEBPACK_IMPORTED_MODULE_3__.hasContinuousDomain)(scaleType) && fieldDef.aggregate !== 'count' && !(0,_mark__WEBPACK_IMPORTED_MODULE_2__.isPathMark)(mark)) {\n                    aggregator[fieldDef.field] = fieldDef; // we know that the fieldDef is a typed field def\n                }\n            }\n            return aggregator;\n        }, {});\n        if (!(0,_util__WEBPACK_IMPORTED_MODULE_4__.keys)(filter).length) {\n            return null;\n        }\n        return new FilterInvalidNode(parent, filter);\n    }\n    dependentFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_4__.keys)(this.filter));\n    }\n    producedFields() {\n        return new Set(); // filter does not produce any new fields\n    }\n    hash() {\n        return `FilterInvalid ${(0,_util__WEBPACK_IMPORTED_MODULE_4__.hash)(this.filter)}`;\n    }\n    /**\n     * Create the VgTransforms for each of the filtered fields.\n     */\n    assemble() {\n        const filters = (0,_util__WEBPACK_IMPORTED_MODULE_4__.keys)(this.filter).reduce((vegaFilters, field) => {\n            const fieldDef = this.filter[field];\n            const ref = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(fieldDef, { expr: 'datum' });\n            if (fieldDef !== null) {\n                if (fieldDef.type === 'temporal') {\n                    vegaFilters.push(`(isDate(${ref}) || (isValid(${ref}) && isFinite(+${ref})))`);\n                }\n                else if (fieldDef.type === 'quantitative') {\n                    vegaFilters.push(`isValid(${ref})`);\n                    vegaFilters.push(`isFinite(+${ref})`);\n                }\n                else {\n                    // should never get here\n                }\n            }\n            return vegaFilters;\n        }, []);\n        return filters.length > 0\n            ? {\n                type: 'filter',\n                expr: filters.join(' && ')\n            }\n            : null;\n    }\n}\n//# sourceMappingURL=filterinvalid.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/filterinvalid.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/flatten.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/flatten.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FlattenTransformNode: () => (/* binding */ FlattenTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for flatten transform nodes\n */\nclass FlattenTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new FlattenTransformNode(this.parent, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const { flatten, as = [] } = this.transform;\n        this.transform.as = flatten.map((f, i) => as[i] ?? f);\n    }\n    dependentFields() {\n        return new Set(this.transform.flatten);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `FlattenTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { flatten: fields, as } = this.transform;\n        const result = {\n            type: 'flatten',\n            fields,\n            as\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=flatten.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/flatten.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/fold.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/fold.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FoldTransformNode: () => (/* binding */ FoldTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for flatten transform nodes\n */\nclass FoldTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new FoldTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const specifiedAs = this.transform.as ?? [undefined, undefined];\n        this.transform.as = [specifiedAs[0] ?? 'key', specifiedAs[1] ?? 'value'];\n    }\n    dependentFields() {\n        return new Set(this.transform.fold);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `FoldTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { fold, as } = this.transform;\n        const result = {\n            type: 'fold',\n            fields: fold,\n            as\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=fold.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/fold.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/formatparse.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/formatparse.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ParseNode: () => (/* binding */ ParseNode),\n/* harmony export */   getImplicitFromEncoding: () => (/* binding */ getImplicitFromEncoding),\n/* harmony export */   getImplicitFromFilterTransform: () => (/* binding */ getImplicitFromFilterTransform),\n/* harmony export */   getImplicitFromSelection: () => (/* binding */ getImplicitFromSelection)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _logical__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../logical */ \"../../node_modules/vega-lite/build/src/logical.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * Remove quotes from a string.\n */\nfunction unquote(pattern) {\n    if ((pattern.startsWith(\"'\") && pattern.endsWith(\"'\")) || (pattern.startsWith('\"') && pattern.endsWith('\"'))) {\n        return pattern.slice(1, -1);\n    }\n    return pattern;\n}\n/**\n * @param field The field.\n * @param parse What to parse the field as.\n */\nfunction parseExpression(field, parse) {\n    const f = (0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathWithDatum)(field);\n    if (parse === 'number') {\n        return `toNumber(${f})`;\n    }\n    else if (parse === 'boolean') {\n        return `toBoolean(${f})`;\n    }\n    else if (parse === 'string') {\n        return `toString(${f})`;\n    }\n    else if (parse === 'date') {\n        return `toDate(${f})`;\n    }\n    else if (parse === 'flatten') {\n        return f;\n    }\n    else if (parse.startsWith('date:')) {\n        const specifier = unquote(parse.slice(5, parse.length));\n        return `timeParse(${f},'${specifier}')`;\n    }\n    else if (parse.startsWith('utc:')) {\n        const specifier = unquote(parse.slice(4, parse.length));\n        return `utcParse(${f},'${specifier}')`;\n    }\n    else {\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.unrecognizedParse(parse));\n        return null;\n    }\n}\nfunction getImplicitFromFilterTransform(transform) {\n    const implicit = {};\n    (0,_logical__WEBPACK_IMPORTED_MODULE_7__.forEachLeaf)(transform.filter, filter => {\n        if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldPredicate)(filter)) {\n            // Automatically add a parse node for filters with filter objects\n            let val = null;\n            // For EqualFilter, just use the equal property.\n            // For RangeFilter and OneOfFilter, all array members should have\n            // the same type, so we only use the first one.\n            if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldEqualPredicate)(filter)) {\n                val = (0,_common__WEBPACK_IMPORTED_MODULE_12__.signalRefOrValue)(filter.equal);\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldLTEPredicate)(filter)) {\n                val = (0,_common__WEBPACK_IMPORTED_MODULE_12__.signalRefOrValue)(filter.lte);\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldLTPredicate)(filter)) {\n                val = (0,_common__WEBPACK_IMPORTED_MODULE_12__.signalRefOrValue)(filter.lt);\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldGTPredicate)(filter)) {\n                val = (0,_common__WEBPACK_IMPORTED_MODULE_12__.signalRefOrValue)(filter.gt);\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldGTEPredicate)(filter)) {\n                val = (0,_common__WEBPACK_IMPORTED_MODULE_12__.signalRefOrValue)(filter.gte);\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldRangePredicate)(filter)) {\n                val = filter.range[0];\n            }\n            else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_9__.isFieldOneOfPredicate)(filter)) {\n                val = (filter.oneOf ?? filter['in'])[0];\n            } // else -- for filter expression, we can't infer anything\n            if (val) {\n                if ((0,_datetime__WEBPACK_IMPORTED_MODULE_5__.isDateTime)(val)) {\n                    implicit[filter.field] = 'date';\n                }\n                else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(val)) {\n                    implicit[filter.field] = 'number';\n                }\n                else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(val)) {\n                    implicit[filter.field] = 'string';\n                }\n            }\n            if (filter.timeUnit) {\n                implicit[filter.field] = 'date';\n            }\n        }\n    });\n    return implicit;\n}\n/**\n * Creates a parse node for implicit parsing from a model and updates ancestorParse.\n */\nfunction getImplicitFromEncoding(model) {\n    const implicit = {};\n    function add(fieldDef) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDefForTimeFormat)(fieldDef)) {\n            implicit[fieldDef.field] = 'date';\n        }\n        else if (fieldDef.type === 'quantitative' &&\n            (0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isMinMaxOp)(fieldDef.aggregate) // we need to parse numbers to support correct min and max\n        ) {\n            implicit[fieldDef.field] = 'number';\n        }\n        else if ((0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathDepth)(fieldDef.field) > 1) {\n            // For non-date/non-number (strings and booleans), derive a flattened field for a referenced nested field.\n            // (Parsing numbers / dates already flattens numeric and temporal fields.)\n            if (!(fieldDef.field in implicit)) {\n                implicit[fieldDef.field] = 'flatten';\n            }\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isScaleFieldDef)(fieldDef) && (0,_sort__WEBPACK_IMPORTED_MODULE_10__.isSortField)(fieldDef.sort) && (0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathDepth)(fieldDef.sort.field) > 1) {\n            // Flatten fields that we sort by but that are not otherwise flattened.\n            if (!(fieldDef.sort.field in implicit)) {\n                implicit[fieldDef.sort.field] = 'flatten';\n            }\n        }\n    }\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_13__.isUnitModel)(model) || (0,_model__WEBPACK_IMPORTED_MODULE_13__.isFacetModel)(model)) {\n        // Parse encoded fields\n        model.forEachFieldDef((fieldDef, channel) => {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isTypedFieldDef)(fieldDef)) {\n                add(fieldDef);\n            }\n            else {\n                const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getMainRangeChannel)(channel);\n                const mainFieldDef = model.fieldDef(mainChannel);\n                add({\n                    ...fieldDef,\n                    type: mainFieldDef.type\n                });\n            }\n        });\n    }\n    // Parse quantitative dimension fields of path marks as numbers so that we sort them correctly.\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_13__.isUnitModel)(model)) {\n        const { mark, markDef, encoding } = model;\n        if ((0,_mark__WEBPACK_IMPORTED_MODULE_8__.isPathMark)(mark) &&\n            // No need to sort by dimension if we have a connected scatterplot (order channel is present)\n            !model.encoding.order) {\n            const dimensionChannel = markDef.orient === 'horizontal' ? 'y' : 'x';\n            const dimensionChannelDef = encoding[dimensionChannel];\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(dimensionChannelDef) &&\n                dimensionChannelDef.type === 'quantitative' &&\n                !(dimensionChannelDef.field in implicit)) {\n                implicit[dimensionChannelDef.field] = 'number';\n            }\n        }\n    }\n    return implicit;\n}\n/**\n * Creates a parse node for implicit parsing from a model and updates ancestorParse.\n */\nfunction getImplicitFromSelection(model) {\n    const implicit = {};\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_13__.isUnitModel)(model) && model.component.selection) {\n        for (const name of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(model.component.selection)) {\n            const selCmpt = model.component.selection[name];\n            for (const proj of selCmpt.project.items) {\n                if (!proj.channel && (0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathDepth)(proj.field) > 1) {\n                    implicit[proj.field] = 'flatten';\n                }\n            }\n        }\n    }\n    return implicit;\n}\nclass ParseNode extends _dataflow__WEBPACK_IMPORTED_MODULE_15__.DataFlowNode {\n    clone() {\n        return new ParseNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_11__.duplicate)(this._parse));\n    }\n    constructor(parent, parse) {\n        super(parent);\n        this._parse = parse;\n    }\n    hash() {\n        return `Parse ${(0,_util__WEBPACK_IMPORTED_MODULE_11__.hash)(this._parse)}`;\n    }\n    /**\n     * Creates a parse node from a data.format.parse and updates ancestorParse.\n     */\n    static makeExplicit(parent, model, ancestorParse) {\n        // Custom parse\n        let explicit = {};\n        const data = model.data;\n        if (!(0,_data__WEBPACK_IMPORTED_MODULE_4__.isGenerator)(data) && data?.format?.parse) {\n            explicit = data.format.parse;\n        }\n        return this.makeWithAncestors(parent, explicit, {}, ancestorParse);\n    }\n    /**\n     * Creates a parse node from \"explicit\" parse and \"implicit\" parse and updates ancestorParse.\n     */\n    static makeWithAncestors(parent, explicit, implicit, ancestorParse) {\n        // We should not parse what has already been parsed in a parent (explicitly or implicitly) or what has been derived (maked as \"derived\"). We also don't need to flatten a field that has already been parsed.\n        for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(implicit)) {\n            const parsedAs = ancestorParse.getWithExplicit(field);\n            if (parsedAs.value !== undefined) {\n                // We always ignore derived fields even if they are implicitly defined because we expect users to create the right types.\n                if (parsedAs.explicit ||\n                    parsedAs.value === implicit[field] ||\n                    parsedAs.value === 'derived' ||\n                    implicit[field] === 'flatten') {\n                    delete implicit[field];\n                }\n                else {\n                    _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.differentParse(field, implicit[field], parsedAs.value));\n                }\n            }\n        }\n        for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(explicit)) {\n            const parsedAs = ancestorParse.get(field);\n            if (parsedAs !== undefined) {\n                // Don't parse a field again if it has been parsed with the same type already.\n                if (parsedAs === explicit[field]) {\n                    delete explicit[field];\n                }\n                else {\n                    _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.differentParse(field, explicit[field], parsedAs));\n                }\n            }\n        }\n        const parse = new _split__WEBPACK_IMPORTED_MODULE_14__.Split(explicit, implicit);\n        // add the format parse from this model so that children don't parse the same field again\n        ancestorParse.copyAll(parse);\n        // copy only non-null parses\n        const p = {};\n        for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(parse.combine())) {\n            const val = parse.get(key);\n            if (val !== null) {\n                p[key] = val;\n            }\n        }\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(p).length === 0 || ancestorParse.parseNothing) {\n            return null;\n        }\n        return new ParseNode(parent, p);\n    }\n    get parse() {\n        return this._parse;\n    }\n    merge(other) {\n        this._parse = { ...this._parse, ...other.parse };\n        other.remove();\n    }\n    /**\n     * Assemble an object for Vega's format.parse property.\n     */\n    assembleFormatParse() {\n        const formatParse = {};\n        for (const field of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(this._parse)) {\n            const p = this._parse[field];\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathDepth)(field) === 1) {\n                formatParse[field] = p;\n            }\n        }\n        return formatParse;\n    }\n    // format parse depends and produces all fields in its parse\n    producedFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(this._parse));\n    }\n    dependentFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(this._parse));\n    }\n    assembleTransforms(onlyNested = false) {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(this._parse)\n            .filter(field => (onlyNested ? (0,_util__WEBPACK_IMPORTED_MODULE_11__.accessPathDepth)(field) > 1 : true))\n            .map(field => {\n            const expr = parseExpression(field, this._parse[field]);\n            if (!expr) {\n                return null;\n            }\n            const formula = {\n                type: 'formula',\n                expr,\n                as: (0,_util__WEBPACK_IMPORTED_MODULE_11__.removePathFromField)(field) // Vega output is always flattened\n            };\n            return formula;\n        })\n            .filter(t => t !== null);\n    }\n}\n//# sourceMappingURL=formatparse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/formatparse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/geojson.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/geojson.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GeoJSONNode: () => (/* binding */ GeoJSONNode)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n\nclass GeoJSONNode extends _dataflow__WEBPACK_IMPORTED_MODULE_5__.DataFlowNode {\n    clone() {\n        return new GeoJSONNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_4__.duplicate)(this.fields), this.geojson, this.signal);\n    }\n    static parseAll(parent, model) {\n        if (model.component.projection && !model.component.projection.isFit) {\n            return parent;\n        }\n        let geoJsonCounter = 0;\n        for (const coordinates of [\n            [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE],\n            [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE2, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE2]\n        ]) {\n            const pair = coordinates.map(channel => {\n                const def = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.getFieldOrDatumDef)(model.encoding[channel]);\n                return (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(def)\n                    ? def.field\n                    : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isDatumDef)(def)\n                        ? { expr: `${def.datum}` }\n                        : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isValueDef)(def)\n                            ? { expr: `${def['value']}` }\n                            : undefined;\n            });\n            if (pair[0] || pair[1]) {\n                parent = new GeoJSONNode(parent, pair, null, model.getName(`geojson_${geoJsonCounter++}`));\n            }\n        }\n        if (model.channelHasField(_channel__WEBPACK_IMPORTED_MODULE_1__.SHAPE)) {\n            const fieldDef = model.typedFieldDef(_channel__WEBPACK_IMPORTED_MODULE_1__.SHAPE);\n            if (fieldDef.type === _type__WEBPACK_IMPORTED_MODULE_3__.GEOJSON) {\n                parent = new GeoJSONNode(parent, null, fieldDef.field, model.getName(`geojson_${geoJsonCounter++}`));\n            }\n        }\n        return parent;\n    }\n    constructor(parent, fields, geojson, signal) {\n        super(parent);\n        this.fields = fields;\n        this.geojson = geojson;\n        this.signal = signal;\n    }\n    dependentFields() {\n        const fields = (this.fields ?? []).filter(vega_util__WEBPACK_IMPORTED_MODULE_0__.isString);\n        return new Set([...(this.geojson ? [this.geojson] : []), ...fields]);\n    }\n    producedFields() {\n        return new Set();\n    }\n    hash() {\n        return `GeoJSON ${this.geojson} ${this.signal} ${(0,_util__WEBPACK_IMPORTED_MODULE_4__.hash)(this.fields)}`;\n    }\n    assemble() {\n        return [\n            ...(this.geojson\n                ? [\n                    {\n                        type: 'filter',\n                        expr: `isValid(datum[\"${this.geojson}\"])`\n                    }\n                ]\n                : []),\n            {\n                type: 'geojson',\n                ...(this.fields ? { fields: this.fields } : {}),\n                ...(this.geojson ? { geojson: this.geojson } : {}),\n                signal: this.signal\n            }\n        ];\n    }\n}\n//# sourceMappingURL=geojson.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/geojson.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/geopoint.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/geopoint.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GeoPointNode: () => (/* binding */ GeoPointNode)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\nclass GeoPointNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new GeoPointNode(null, this.projection, (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.fields), (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.as));\n    }\n    constructor(parent, projection, fields, as) {\n        super(parent);\n        this.projection = projection;\n        this.fields = fields;\n        this.as = as;\n    }\n    static parseAll(parent, model) {\n        if (!model.projectionName()) {\n            return parent;\n        }\n        for (const coordinates of [\n            [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE],\n            [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE2, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE2]\n        ]) {\n            const pair = coordinates.map(channel => {\n                const def = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.getFieldOrDatumDef)(model.encoding[channel]);\n                return (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(def)\n                    ? def.field\n                    : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isDatumDef)(def)\n                        ? { expr: `${def.datum}` }\n                        : (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isValueDef)(def)\n                            ? { expr: `${def['value']}` }\n                            : undefined;\n            });\n            const suffix = coordinates[0] === _channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE2 ? '2' : '';\n            if (pair[0] || pair[1]) {\n                parent = new GeoPointNode(parent, model.projectionName(), pair, [\n                    model.getName(`x${suffix}`),\n                    model.getName(`y${suffix}`)\n                ]);\n            }\n        }\n        return parent;\n    }\n    dependentFields() {\n        return new Set(this.fields.filter(vega_util__WEBPACK_IMPORTED_MODULE_0__.isString));\n    }\n    producedFields() {\n        return new Set(this.as);\n    }\n    hash() {\n        return `Geopoint ${this.projection} ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)(this.fields)} ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)(this.as)}`;\n    }\n    assemble() {\n        return {\n            type: 'geopoint',\n            projection: this.projection,\n            fields: this.fields,\n            as: this.as\n        };\n    }\n}\n//# sourceMappingURL=geopoint.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/geopoint.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/graticule.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/graticule.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GraticuleNode: () => (/* binding */ GraticuleNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\nclass GraticuleNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new GraticuleNode(null, this.params);\n    }\n    constructor(parent, params) {\n        super(parent);\n        this.params = params;\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return undefined; // there should never be a node before graticule\n    }\n    hash() {\n        return `Graticule ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.params)}`;\n    }\n    assemble() {\n        return {\n            type: 'graticule',\n            ...(this.params === true ? {} : this.params)\n        };\n    }\n}\n//# sourceMappingURL=graticule.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/graticule.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/identifier.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/identifier.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   IdentifierNode: () => (/* binding */ IdentifierNode)\n/* harmony export */ });\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\nclass IdentifierNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new IdentifierNode(null);\n    }\n    constructor(parent) {\n        super(parent);\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return new Set([_selection__WEBPACK_IMPORTED_MODULE_0__.SELECTION_ID]);\n    }\n    hash() {\n        return 'Identifier';\n    }\n    assemble() {\n        return { type: 'identifier', as: _selection__WEBPACK_IMPORTED_MODULE_0__.SELECTION_ID };\n    }\n}\n//# sourceMappingURL=identifier.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/identifier.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/impute.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/impute.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ImputeNode: () => (/* binding */ ImputeNode)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _transform__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../transform */ \"../../node_modules/vega-lite/build/src/transform.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\nclass ImputeNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new ImputeNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n    }\n    dependentFields() {\n        return new Set([this.transform.impute, this.transform.key, ...(this.transform.groupby ?? [])]);\n    }\n    producedFields() {\n        return new Set([this.transform.impute]);\n    }\n    processSequence(keyvals) {\n        const { start = 0, stop, step } = keyvals;\n        const result = [start, stop, ...(step ? [step] : [])].join(',');\n        return { signal: `sequence(${result})` };\n    }\n    static makeFromTransform(parent, imputeTransform) {\n        return new ImputeNode(parent, imputeTransform);\n    }\n    static makeFromEncoding(parent, model) {\n        const encoding = model.encoding;\n        const xDef = encoding.x;\n        const yDef = encoding.y;\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldDef)(xDef) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldDef)(yDef)) {\n            const imputedChannel = xDef.impute ? xDef : yDef.impute ? yDef : undefined;\n            if (imputedChannel === undefined) {\n                return undefined;\n            }\n            const keyChannel = xDef.impute ? yDef : yDef.impute ? xDef : undefined;\n            const { method, value, frame, keyvals } = imputedChannel.impute;\n            const groupbyFields = (0,_encoding__WEBPACK_IMPORTED_MODULE_1__.pathGroupingFields)(model.mark, encoding);\n            return new ImputeNode(parent, {\n                impute: imputedChannel.field,\n                key: keyChannel.field,\n                ...(method ? { method } : {}),\n                ...(value !== undefined ? { value } : {}),\n                ...(frame ? { frame } : {}),\n                ...(keyvals !== undefined ? { keyvals } : {}),\n                ...(groupbyFields.length ? { groupby: groupbyFields } : {})\n            });\n        }\n        return null;\n    }\n    hash() {\n        return `Impute ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { impute, key, keyvals, method, groupby, value, frame = [null, null] } = this.transform;\n        const imputeTransform = {\n            type: 'impute',\n            field: impute,\n            key,\n            ...(keyvals ? { keyvals: (0,_transform__WEBPACK_IMPORTED_MODULE_2__.isImputeSequence)(keyvals) ? this.processSequence(keyvals) : keyvals } : {}),\n            method: 'value',\n            ...(groupby ? { groupby } : {}),\n            value: !method || method === 'value' ? value : null\n        };\n        if (method && method !== 'value') {\n            const deriveNewField = {\n                type: 'window',\n                as: [`imputed_${impute}_value`],\n                ops: [method],\n                fields: [impute],\n                frame,\n                ignorePeers: false,\n                ...(groupby ? { groupby } : {})\n            };\n            const replaceOriginal = {\n                type: 'formula',\n                expr: `datum.${impute} === null ? datum.imputed_${impute}_value : datum.${impute}`,\n                as: impute\n            };\n            return [imputeTransform, deriveNewField, replaceOriginal];\n        }\n        else {\n            return [imputeTransform];\n        }\n    }\n}\n//# sourceMappingURL=impute.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/impute.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/index.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/index.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AncestorParse: () => (/* binding */ AncestorParse)\n/* harmony export */ });\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n/**\n * Class to track interesting properties (see https://15721.courses.cs.cmu.edu/spring2016/papers/graefe-ieee1995.pdf)\n * about how fields have been parsed or whether they have been derived in a transform. We use this to not parse the\n * same field again (or differently).\n */\nclass AncestorParse extends _split__WEBPACK_IMPORTED_MODULE_0__.Split {\n    constructor(explicit = {}, implicit = {}, parseNothing = false) {\n        super(explicit, implicit);\n        this.explicit = explicit;\n        this.implicit = implicit;\n        this.parseNothing = parseNothing;\n    }\n    clone() {\n        const clone = super.clone();\n        clone.parseNothing = this.parseNothing;\n        return clone;\n    }\n}\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JoinAggregateTransformNode: () => (/* binding */ JoinAggregateTransformNode)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n/**\n * A class for the join aggregate transform nodes.\n */\nclass JoinAggregateTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_2__.DataFlowNode {\n    clone() {\n        return new JoinAggregateTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_1__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n    }\n    addDimensions(fields) {\n        this.transform.groupby = (0,_util__WEBPACK_IMPORTED_MODULE_1__.unique)(this.transform.groupby.concat(fields), d => d);\n    }\n    dependentFields() {\n        const out = new Set();\n        if (this.transform.groupby) {\n            this.transform.groupby.forEach(out.add, out);\n        }\n        this.transform.joinaggregate\n            .map(w => w.field)\n            .filter(f => f !== undefined)\n            .forEach(out.add, out);\n        return out;\n    }\n    producedFields() {\n        return new Set(this.transform.joinaggregate.map(this.getDefaultName));\n    }\n    getDefaultName(joinAggregateFieldDef) {\n        return joinAggregateFieldDef.as ?? (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.vgField)(joinAggregateFieldDef);\n    }\n    hash() {\n        return `JoinAggregateTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const fields = [];\n        const ops = [];\n        const as = [];\n        for (const joinaggregate of this.transform.joinaggregate) {\n            ops.push(joinaggregate.op);\n            as.push(this.getDefaultName(joinaggregate));\n            fields.push(joinaggregate.field === undefined ? null : joinaggregate.field);\n        }\n        const groupby = this.transform.groupby;\n        return {\n            type: 'joinaggregate',\n            as,\n            ops,\n            fields,\n            ...(groupby !== undefined ? { groupby } : {})\n        };\n    }\n}\n//# sourceMappingURL=joinaggregate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/joinaggregatefacet.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/joinaggregatefacet.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   makeJoinAggregateFromFacet: () => (/* binding */ makeJoinAggregateFromFacet)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../facet */ \"../../node_modules/vega-lite/build/src/compile/facet.js\");\n/* harmony import */ var _joinaggregate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./joinaggregate */ \"../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js\");\n\n\n\n\nfunction makeJoinAggregateFromFacet(parent, facet) {\n    const { row, column } = facet;\n    if (row && column) {\n        let newParent = null;\n        // only need to make one for crossed facet\n        for (const fieldDef of [row, column]) {\n            if ((0,_sort__WEBPACK_IMPORTED_MODULE_1__.isSortField)(fieldDef.sort)) {\n                const { field, op = _sort__WEBPACK_IMPORTED_MODULE_1__.DEFAULT_SORT_OP } = fieldDef.sort;\n                parent = newParent = new _joinaggregate__WEBPACK_IMPORTED_MODULE_3__.JoinAggregateTransformNode(parent, {\n                    joinaggregate: [\n                        {\n                            op,\n                            field,\n                            as: (0,_facet__WEBPACK_IMPORTED_MODULE_2__.facetSortFieldName)(fieldDef, fieldDef.sort, { forAs: true })\n                        }\n                    ],\n                    groupby: [(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.vgField)(fieldDef)]\n                });\n            }\n        }\n        return newParent;\n    }\n    return null;\n}\n//# sourceMappingURL=joinaggregatefacet.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/joinaggregatefacet.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/loess.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/loess.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   LoessTransformNode: () => (/* binding */ LoessTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for loess transform nodes\n */\nclass LoessTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new LoessTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const specifiedAs = this.transform.as ?? [undefined, undefined];\n        this.transform.as = [specifiedAs[0] ?? transform.on, specifiedAs[1] ?? transform.loess];\n    }\n    dependentFields() {\n        return new Set([this.transform.loess, this.transform.on, ...(this.transform.groupby ?? [])]);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `LoessTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { loess, on, ...rest } = this.transform;\n        const result = {\n            type: 'loess',\n            x: on,\n            y: loess,\n            ...rest\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=loess.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/loess.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/lookup.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/lookup.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   LookupNode: () => (/* binding */ LookupNode)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _transform__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../transform */ \"../../node_modules/vega-lite/build/src/transform.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _parse__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./parse */ \"../../node_modules/vega-lite/build/src/compile/data/parse.js\");\n/* harmony import */ var _source__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./source */ \"../../node_modules/vega-lite/build/src/compile/data/source.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n\n\n\n\n\n\n\n\nclass LookupNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new LookupNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(this.transform), this.secondary);\n    }\n    constructor(parent, transform, secondary) {\n        super(parent);\n        this.transform = transform;\n        this.secondary = secondary;\n    }\n    static make(parent, model, transform, counter) {\n        const sources = model.component.data.sources;\n        const { from } = transform;\n        let fromOutputNode = null;\n        if ((0,_transform__WEBPACK_IMPORTED_MODULE_2__.isLookupData)(from)) {\n            let fromSource = (0,_parse__WEBPACK_IMPORTED_MODULE_5__.findSource)(from.data, sources);\n            if (!fromSource) {\n                fromSource = new _source__WEBPACK_IMPORTED_MODULE_6__.SourceNode(from.data);\n                sources.push(fromSource);\n            }\n            const fromOutputName = model.getName(`lookup_${counter}`);\n            fromOutputNode = new _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode(fromSource, fromOutputName, _data__WEBPACK_IMPORTED_MODULE_7__.DataSourceType.Lookup, model.component.data.outputNodeRefCounts);\n            model.component.data.outputNodes[fromOutputName] = fromOutputNode;\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_2__.isLookupSelection)(from)) {\n            const selName = from.param;\n            transform = { as: selName, ...transform };\n            let selCmpt;\n            try {\n                selCmpt = model.getSelectionComponent((0,_util__WEBPACK_IMPORTED_MODULE_3__.varName)(selName), selName);\n            }\n            catch (e) {\n                throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.cannotLookupVariableParameter(selName));\n            }\n            fromOutputNode = selCmpt.materialized;\n            if (!fromOutputNode) {\n                throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.noSameUnitLookup(selName));\n            }\n        }\n        return new LookupNode(parent, transform, fromOutputNode.getSource());\n    }\n    dependentFields() {\n        return new Set([this.transform.lookup]);\n    }\n    producedFields() {\n        return new Set(this.transform.as ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(this.transform.as) : this.transform.from.fields);\n    }\n    hash() {\n        return `Lookup ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.hash)({ transform: this.transform, secondary: this.secondary })}`;\n    }\n    assemble() {\n        let foreign;\n        if (this.transform.from.fields) {\n            // lookup a few fields and add create a flat output\n            foreign = {\n                values: this.transform.from.fields,\n                ...(this.transform.as ? { as: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(this.transform.as) } : {})\n            };\n        }\n        else {\n            // lookup full record and nest it\n            let asName = this.transform.as;\n            if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(asName)) {\n                _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.NO_FIELDS_NEEDS_AS);\n                asName = '_lookup';\n            }\n            foreign = {\n                as: [asName]\n            };\n        }\n        return {\n            type: 'lookup',\n            from: this.secondary,\n            key: this.transform.from.key,\n            fields: [this.transform.lookup],\n            ...foreign,\n            ...(this.transform.default ? { default: this.transform.default } : {})\n        };\n    }\n}\n//# sourceMappingURL=lookup.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/lookup.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/optimize.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/optimize.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FACET_SCALE_PREFIX: () => (/* binding */ FACET_SCALE_PREFIX),\n/* harmony export */   MAX_OPTIMIZATION_RUNS: () => (/* binding */ MAX_OPTIMIZATION_RUNS),\n/* harmony export */   checkLinks: () => (/* binding */ checkLinks),\n/* harmony export */   optimizeDataflow: () => (/* binding */ optimizeDataflow)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _optimizers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./optimizers */ \"../../node_modules/vega-lite/build/src/compile/data/optimizers.js\");\n/* harmony import */ var _subtree__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./subtree */ \"../../node_modules/vega-lite/build/src/compile/data/subtree.js\");\n\n\n\nconst FACET_SCALE_PREFIX = 'scale_';\nconst MAX_OPTIMIZATION_RUNS = 5;\n/**\n * Iterates over a dataflow graph and checks whether all links are consistent.\n */\nfunction checkLinks(nodes) {\n    for (const node of nodes) {\n        for (const child of node.children) {\n            if (child.parent !== node) {\n                // log.error('Dataflow graph is inconsistent.', node, child);\n                return false;\n            }\n        }\n        if (!checkLinks(node.children)) {\n            return false;\n        }\n    }\n    return true;\n}\n/**\n * Run the specified optimizer on the provided nodes.\n *\n * @param optimizer The optimizer instance to run.\n * @param nodes A set of nodes to optimize.\n */\nfunction runOptimizer(optimizer, nodes) {\n    let modified = false;\n    for (const node of nodes) {\n        modified = optimizer.optimize(node) || modified;\n    }\n    return modified;\n}\nfunction optimizationDataflowHelper(dataComponent, model, firstPass) {\n    let roots = dataComponent.sources;\n    let modified = false;\n    modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.RemoveUnnecessaryOutputNodes(), roots) || modified;\n    modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.RemoveUnnecessaryIdentifierNodes(model), roots) || modified;\n    // remove source nodes that don't have any children because they also don't have output nodes\n    roots = roots.filter(r => r.numChildren() > 0);\n    modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.RemoveUnusedSubtrees(), roots) || modified;\n    roots = roots.filter(r => r.numChildren() > 0);\n    if (!firstPass) {\n        // Only run these optimizations after the optimizer has moved down the facet node.\n        // With this change, we can be more aggressive in the optimizations.\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MoveParseUp(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeBins(model), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.RemoveDuplicateTimeUnits(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeParse(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeAggregates(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeTimeUnits(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeIdenticalNodes(), roots) || modified;\n        modified = runOptimizer(new _optimizers__WEBPACK_IMPORTED_MODULE_1__.MergeOutputs(), roots) || modified;\n    }\n    dataComponent.sources = roots;\n    return modified;\n}\n/**\n * Optimizes the dataflow of the passed in data component.\n */\nfunction optimizeDataflow(data, model) {\n    // check before optimizations\n    checkLinks(data.sources);\n    let firstPassCounter = 0;\n    let secondPassCounter = 0;\n    for (let i = 0; i < MAX_OPTIMIZATION_RUNS; i++) {\n        if (!optimizationDataflowHelper(data, model, true)) {\n            break;\n        }\n        firstPassCounter++;\n    }\n    // move facets down and make a copy of the subtree so that we can have scales at the top level\n    data.sources.map(_subtree__WEBPACK_IMPORTED_MODULE_2__.moveFacetDown);\n    for (let i = 0; i < MAX_OPTIMIZATION_RUNS; i++) {\n        if (!optimizationDataflowHelper(data, model, false)) {\n            break;\n        }\n        secondPassCounter++;\n    }\n    // check after optimizations\n    checkLinks(data.sources);\n    if (Math.max(firstPassCounter, secondPassCounter) === MAX_OPTIMIZATION_RUNS) {\n        _log__WEBPACK_IMPORTED_MODULE_0__.warn(`Maximum optimization runs(${MAX_OPTIMIZATION_RUNS}) reached.`);\n    }\n}\n//# sourceMappingURL=optimize.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/optimize.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/optimizer.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/optimizer.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BottomUpOptimizer: () => (/* binding */ BottomUpOptimizer),\n/* harmony export */   Optimizer: () => (/* binding */ Optimizer),\n/* harmony export */   TopDownOptimizer: () => (/* binding */ TopDownOptimizer),\n/* harmony export */   isDataSourceNode: () => (/* binding */ isDataSourceNode)\n/* harmony export */ });\n/* harmony import */ var _graticule__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./graticule */ \"../../node_modules/vega-lite/build/src/compile/data/graticule.js\");\n/* harmony import */ var _sequence__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./sequence */ \"../../node_modules/vega-lite/build/src/compile/data/sequence.js\");\n/* harmony import */ var _source__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./source */ \"../../node_modules/vega-lite/build/src/compile/data/source.js\");\nvar __classPrivateFieldSet = (undefined && undefined.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {\n    if (kind === \"m\") throw new TypeError(\"Private method is not writable\");\n    if (kind === \"a\" && !f) throw new TypeError(\"Private accessor was defined without a setter\");\n    if (typeof state === \"function\" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError(\"Cannot write private member to an object whose class did not declare it\");\n    return (kind === \"a\" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;\n};\nvar __classPrivateFieldGet = (undefined && undefined.__classPrivateFieldGet) || function (receiver, state, kind, f) {\n    if (kind === \"a\" && !f) throw new TypeError(\"Private accessor was defined without a getter\");\n    if (typeof state === \"function\" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError(\"Cannot read private member from an object whose class did not declare it\");\n    return kind === \"m\" ? f : kind === \"a\" ? f.call(receiver) : f ? f.value : state.get(receiver);\n};\nvar _Optimizer_modified;\n\n\n\n/**\n * Whether this dataflow node is the source of the dataflow that produces data i.e. a source or a generator.\n */\nfunction isDataSourceNode(node) {\n    return node instanceof _source__WEBPACK_IMPORTED_MODULE_2__.SourceNode || node instanceof _graticule__WEBPACK_IMPORTED_MODULE_0__.GraticuleNode || node instanceof _sequence__WEBPACK_IMPORTED_MODULE_1__.SequenceNode;\n}\n/**\n * Abstract base class for Dataflow optimizers.\n * Contains only mutation handling logic. Subclasses need to implement iteration logic.\n */\nclass Optimizer {\n    constructor() {\n        _Optimizer_modified.set(this, void 0);\n        __classPrivateFieldSet(this, _Optimizer_modified, false, \"f\");\n    }\n    // Once true, #modified is never set to false\n    setModified() {\n        __classPrivateFieldSet(this, _Optimizer_modified, true, \"f\");\n    }\n    get modifiedFlag() {\n        return __classPrivateFieldGet(this, _Optimizer_modified, \"f\");\n    }\n}\n_Optimizer_modified = new WeakMap();\n/**\n * Starts from a node and runs the optimization function (the \"run\" method) upwards to the root,\n * depending on the continue and modified flag values returned by the optimization function.\n */\nclass BottomUpOptimizer extends Optimizer {\n    /**\n     * Compute a map of node depths that we can use to determine a topological sort order.\n     */\n    getNodeDepths(node, depth, depths) {\n        depths.set(node, depth);\n        for (const child of node.children) {\n            this.getNodeDepths(child, depth + 1, depths);\n        }\n        return depths;\n    }\n    /**\n     * Run the optimizer on all nodes starting from the leaves.\n     */\n    optimize(node) {\n        const depths = this.getNodeDepths(node, 0, new Map());\n        const topologicalSort = [...depths.entries()].sort((a, b) => b[1] - a[1]);\n        for (const tuple of topologicalSort) {\n            this.run(tuple[0]);\n        }\n        return this.modifiedFlag;\n    }\n}\n/**\n * The optimizer function (the \"run\" method), is invoked on the given node and then continues recursively.\n */\nclass TopDownOptimizer extends Optimizer {\n    /**\n     * Run the optimizer depth first on all nodes starting from the roots.\n     */\n    optimize(node) {\n        this.run(node);\n        for (const child of node.children) {\n            this.optimize(child);\n        }\n        return this.modifiedFlag;\n    }\n}\n//# sourceMappingURL=optimizer.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/optimizer.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/optimizers.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/optimizers.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MergeAggregates: () => (/* binding */ MergeAggregates),\n/* harmony export */   MergeBins: () => (/* binding */ MergeBins),\n/* harmony export */   MergeIdenticalNodes: () => (/* binding */ MergeIdenticalNodes),\n/* harmony export */   MergeOutputs: () => (/* binding */ MergeOutputs),\n/* harmony export */   MergeParse: () => (/* binding */ MergeParse),\n/* harmony export */   MergeTimeUnits: () => (/* binding */ MergeTimeUnits),\n/* harmony export */   MoveParseUp: () => (/* binding */ MoveParseUp),\n/* harmony export */   RemoveDuplicateTimeUnits: () => (/* binding */ RemoveDuplicateTimeUnits),\n/* harmony export */   RemoveUnnecessaryIdentifierNodes: () => (/* binding */ RemoveUnnecessaryIdentifierNodes),\n/* harmony export */   RemoveUnnecessaryOutputNodes: () => (/* binding */ RemoveUnnecessaryOutputNodes),\n/* harmony export */   RemoveUnusedSubtrees: () => (/* binding */ RemoveUnusedSubtrees)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../selection */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/compile/data/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/compile/data/facet.js\");\n/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./filter */ \"../../node_modules/vega-lite/build/src/compile/data/filter.js\");\n/* harmony import */ var _formatparse__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./formatparse */ \"../../node_modules/vega-lite/build/src/compile/data/formatparse.js\");\n/* harmony import */ var _identifier__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./identifier */ \"../../node_modules/vega-lite/build/src/compile/data/identifier.js\");\n/* harmony import */ var _optimizer__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./optimizer */ \"../../node_modules/vega-lite/build/src/compile/data/optimizer.js\");\n/* harmony import */ var _source__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./source */ \"../../node_modules/vega-lite/build/src/compile/data/source.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/compile/data/timeunit.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * Merge identical nodes at forks by comparing hashes.\n *\n * Does not need to iterate from leaves so we implement this with recursion as it's a bit simpler.\n */\nclass MergeIdenticalNodes extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.TopDownOptimizer {\n    mergeNodes(parent, nodes) {\n        const mergedNode = nodes.shift();\n        for (const node of nodes) {\n            parent.removeChild(node);\n            node.parent = mergedNode;\n            node.remove();\n        }\n    }\n    run(node) {\n        const hashes = node.children.map(x => x.hash());\n        const buckets = {};\n        for (let i = 0; i < hashes.length; i++) {\n            if (buckets[hashes[i]] === undefined) {\n                buckets[hashes[i]] = [node.children[i]];\n            }\n            else {\n                buckets[hashes[i]].push(node.children[i]);\n            }\n        }\n        for (const k of (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(buckets)) {\n            if (buckets[k].length > 1) {\n                this.setModified();\n                this.mergeNodes(node, buckets[k]);\n            }\n        }\n    }\n}\n/**\n * Optimizer that removes identifier nodes that are not needed for selections.\n */\nclass RemoveUnnecessaryIdentifierNodes extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.TopDownOptimizer {\n    constructor(model) {\n        super();\n        this.requiresSelectionId = model && (0,_selection__WEBPACK_IMPORTED_MODULE_1__.requiresSelectionId)(model);\n    }\n    run(node) {\n        if (node instanceof _identifier__WEBPACK_IMPORTED_MODULE_8__.IdentifierNode) {\n            // Only preserve IdentifierNodes if we have default discrete selections\n            // in our model tree, and if the nodes come after tuple producing nodes.\n            if (!(this.requiresSelectionId &&\n                ((0,_optimizer__WEBPACK_IMPORTED_MODULE_9__.isDataSourceNode)(node.parent) || node.parent instanceof _aggregate__WEBPACK_IMPORTED_MODULE_2__.AggregateNode || node.parent instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode))) {\n                this.setModified();\n                node.remove();\n            }\n        }\n    }\n}\n/**\n * Removes duplicate time unit nodes (as determined by the name of the output field) that may be generated due to\n * selections projected over time units. Only keeps the first time unit in any branch.\n *\n * This optimizer is a custom top down optimizer that keep track of produced fields in a branch.\n */\nclass RemoveDuplicateTimeUnits extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.Optimizer {\n    optimize(node) {\n        this.run(node, new Set());\n        return this.modifiedFlag;\n    }\n    run(node, timeUnitFields) {\n        let producedFields = new Set();\n        if (node instanceof _timeunit__WEBPACK_IMPORTED_MODULE_11__.TimeUnitNode) {\n            producedFields = node.producedFields();\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_0__.hasIntersection)(producedFields, timeUnitFields)) {\n                this.setModified();\n                node.removeFormulas(timeUnitFields);\n                if (node.producedFields.length === 0) {\n                    node.remove();\n                }\n            }\n        }\n        for (const child of node.children) {\n            this.run(child, new Set([...timeUnitFields, ...producedFields]));\n        }\n    }\n}\n/**\n * Remove output nodes that are not required.\n */\nclass RemoveUnnecessaryOutputNodes extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.TopDownOptimizer {\n    constructor() {\n        super();\n    }\n    run(node) {\n        if (node instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode && !node.isRequired()) {\n            this.setModified();\n            node.remove();\n        }\n    }\n}\n/**\n * Move parse nodes up to forks and merges them if possible.\n */\nclass MoveParseUp extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        if ((0,_optimizer__WEBPACK_IMPORTED_MODULE_9__.isDataSourceNode)(node)) {\n            return;\n        }\n        if (node.numChildren() > 1) {\n            // Don't move parse further up but continue with parent.\n            return;\n        }\n        for (const child of node.children) {\n            if (child instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode) {\n                if (node instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode) {\n                    this.setModified();\n                    node.merge(child);\n                }\n                else {\n                    // Don't swap with nodes that produce something that the parse node depends on (e.g. lookup).\n                    if ((0,_util__WEBPACK_IMPORTED_MODULE_0__.fieldIntersection)(node.producedFields(), child.dependentFields())) {\n                        continue;\n                    }\n                    this.setModified();\n                    child.swapWithParent();\n                }\n            }\n        }\n        return;\n    }\n}\n/**\n * Inserts an intermediate ParseNode containing all non-conflicting parse fields and removes the empty ParseNodes.\n *\n * We assume that dependent paths that do not have a parse node can be just merged.\n */\nclass MergeParse extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        const originalChildren = [...node.children];\n        const parseChildren = node.children.filter((child) => child instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode);\n        if (node.numChildren() > 1 && parseChildren.length >= 1) {\n            const commonParse = {};\n            const conflictingParse = new Set();\n            for (const parseNode of parseChildren) {\n                const parse = parseNode.parse;\n                for (const k of (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(parse)) {\n                    if (!(k in commonParse)) {\n                        commonParse[k] = parse[k];\n                    }\n                    else if (commonParse[k] !== parse[k]) {\n                        conflictingParse.add(k);\n                    }\n                }\n            }\n            for (const field of conflictingParse) {\n                delete commonParse[field];\n            }\n            if (!(0,_util__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(commonParse)) {\n                this.setModified();\n                const mergedParseNode = new _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode(node, commonParse);\n                for (const childNode of originalChildren) {\n                    if (childNode instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode) {\n                        for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(commonParse)) {\n                            delete childNode.parse[key];\n                        }\n                    }\n                    node.removeChild(childNode);\n                    childNode.parent = mergedParseNode;\n                    // remove empty parse nodes\n                    if (childNode instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode && (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(childNode.parse).length === 0) {\n                        childNode.remove();\n                    }\n                }\n            }\n        }\n    }\n}\n/**\n * Repeatedly remove leaf nodes that are not output or facet nodes.\n * The reason is that we don't need subtrees that don't have any output nodes.\n * Facet nodes are needed for the row or column domains.\n */\nclass RemoveUnusedSubtrees extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        if (node instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode || node.numChildren() > 0 || node instanceof _facet__WEBPACK_IMPORTED_MODULE_5__.FacetNode) {\n            // no need to continue with parent because it is output node or will have children (there was a fork)\n        }\n        else if (node instanceof _source__WEBPACK_IMPORTED_MODULE_10__.SourceNode) {\n            // ignore empty unused sources as they will be removed in optimizationDataflowHelper\n        }\n        else {\n            this.setModified();\n            node.remove();\n        }\n    }\n}\n/**\n * Merge adjacent time unit nodes.\n */\nclass MergeTimeUnits extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        const timeUnitChildren = node.children.filter((x) => x instanceof _timeunit__WEBPACK_IMPORTED_MODULE_11__.TimeUnitNode);\n        const combination = timeUnitChildren.pop();\n        for (const timeUnit of timeUnitChildren) {\n            this.setModified();\n            combination.merge(timeUnit);\n        }\n    }\n}\nclass MergeAggregates extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        const aggChildren = node.children.filter((child) => child instanceof _aggregate__WEBPACK_IMPORTED_MODULE_2__.AggregateNode);\n        // Object which we'll use to map the fields which an aggregate is grouped by to\n        // the set of aggregates with that grouping. This is useful as only aggregates\n        // with the same group by can be merged\n        const groupedAggregates = {};\n        // Build groupedAggregates\n        for (const agg of aggChildren) {\n            const groupBys = (0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(agg.groupBy);\n            if (!(groupBys in groupedAggregates)) {\n                groupedAggregates[groupBys] = [];\n            }\n            groupedAggregates[groupBys].push(agg);\n        }\n        // Merge aggregateNodes with same key in groupedAggregates\n        for (const group of (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(groupedAggregates)) {\n            const mergeableAggs = groupedAggregates[group];\n            if (mergeableAggs.length > 1) {\n                const mergedAggs = mergeableAggs.pop();\n                for (const agg of mergeableAggs) {\n                    if (mergedAggs.merge(agg)) {\n                        node.removeChild(agg);\n                        agg.parent = mergedAggs;\n                        agg.remove();\n                        this.setModified();\n                    }\n                }\n            }\n        }\n    }\n}\n/**\n * Merge bin nodes and move them up through forks. Stop at filters, parse, identifier as we want them to stay before the bin node.\n */\nclass MergeBins extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    constructor(model) {\n        super();\n        this.model = model;\n    }\n    run(node) {\n        const moveBinsUp = !((0,_optimizer__WEBPACK_IMPORTED_MODULE_9__.isDataSourceNode)(node) ||\n            node instanceof _filter__WEBPACK_IMPORTED_MODULE_6__.FilterNode ||\n            node instanceof _formatparse__WEBPACK_IMPORTED_MODULE_7__.ParseNode ||\n            node instanceof _identifier__WEBPACK_IMPORTED_MODULE_8__.IdentifierNode);\n        const promotableBins = [];\n        const remainingBins = [];\n        for (const child of node.children) {\n            if (child instanceof _bin__WEBPACK_IMPORTED_MODULE_3__.BinNode) {\n                if (moveBinsUp && !(0,_util__WEBPACK_IMPORTED_MODULE_0__.fieldIntersection)(node.producedFields(), child.dependentFields())) {\n                    promotableBins.push(child);\n                }\n                else {\n                    remainingBins.push(child);\n                }\n            }\n        }\n        if (promotableBins.length > 0) {\n            const promotedBin = promotableBins.pop();\n            for (const bin of promotableBins) {\n                promotedBin.merge(bin, this.model.renameSignal.bind(this.model));\n            }\n            this.setModified();\n            if (node instanceof _bin__WEBPACK_IMPORTED_MODULE_3__.BinNode) {\n                node.merge(promotedBin, this.model.renameSignal.bind(this.model));\n            }\n            else {\n                promotedBin.swapWithParent();\n            }\n        }\n        if (remainingBins.length > 1) {\n            const remainingBin = remainingBins.pop();\n            for (const bin of remainingBins) {\n                remainingBin.merge(bin, this.model.renameSignal.bind(this.model));\n            }\n            this.setModified();\n        }\n    }\n}\n/**\n * This optimizer takes output nodes that are at a fork and moves them before the fork.\n *\n * The algorithm iterates over the children and tries to find the last output node in a chain of output nodes.\n * It then moves all output nodes before that main output node. All other children (and the children of the output nodes)\n * are inserted after the main output node.\n */\nclass MergeOutputs extends _optimizer__WEBPACK_IMPORTED_MODULE_9__.BottomUpOptimizer {\n    run(node) {\n        const children = [...node.children];\n        const hasOutputChild = (0,_util__WEBPACK_IMPORTED_MODULE_0__.some)(children, child => child instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode);\n        if (!hasOutputChild || node.numChildren() <= 1) {\n            return;\n        }\n        const otherChildren = [];\n        // The output node we will connect all other nodes to.\n        // Output nodes will be added before the new node, other nodes after.\n        let mainOutput;\n        for (const child of children) {\n            if (child instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode) {\n                let lastOutput = child;\n                while (lastOutput.numChildren() === 1) {\n                    const [theChild] = lastOutput.children;\n                    if (theChild instanceof _dataflow__WEBPACK_IMPORTED_MODULE_4__.OutputNode) {\n                        lastOutput = theChild;\n                    }\n                    else {\n                        break;\n                    }\n                }\n                otherChildren.push(...lastOutput.children);\n                if (mainOutput) {\n                    // Move the output nodes before the mainOutput. We do this by setting\n                    // the parent of the first not to the parent of the main output and\n                    // the main output's parent to the last output.\n                    // note: the child is the first output\n                    node.removeChild(child);\n                    child.parent = mainOutput.parent;\n                    mainOutput.parent.removeChild(mainOutput);\n                    mainOutput.parent = lastOutput;\n                    this.setModified();\n                }\n                else {\n                    mainOutput = lastOutput;\n                }\n            }\n            else {\n                otherChildren.push(child);\n            }\n        }\n        if (otherChildren.length) {\n            this.setModified();\n            for (const child of otherChildren) {\n                child.parent.removeChild(child);\n                child.parent = mainOutput;\n            }\n        }\n    }\n}\n//# sourceMappingURL=optimizers.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/optimizers.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/parse.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/parse.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   findSource: () => (/* binding */ findSource),\n/* harmony export */   parseData: () => (/* binding */ parseData),\n/* harmony export */   parseTransformArray: () => (/* binding */ parseTransformArray)\n/* harmony export */ });\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/data/index.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _transform__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../transform */ \"../../node_modules/vega-lite/build/src/transform.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../selection */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _selection_parse__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../selection/parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/compile/data/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _calculate__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _density__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./density */ \"../../node_modules/vega-lite/build/src/compile/data/density.js\");\n/* harmony import */ var _extent__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./extent */ \"../../node_modules/vega-lite/build/src/compile/data/extent.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/compile/data/facet.js\");\n/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./filter */ \"../../node_modules/vega-lite/build/src/compile/data/filter.js\");\n/* harmony import */ var _filterinvalid__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./filterinvalid */ \"../../node_modules/vega-lite/build/src/compile/data/filterinvalid.js\");\n/* harmony import */ var _flatten__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./flatten */ \"../../node_modules/vega-lite/build/src/compile/data/flatten.js\");\n/* harmony import */ var _fold__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./fold */ \"../../node_modules/vega-lite/build/src/compile/data/fold.js\");\n/* harmony import */ var _formatparse__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./formatparse */ \"../../node_modules/vega-lite/build/src/compile/data/formatparse.js\");\n/* harmony import */ var _geojson__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./geojson */ \"../../node_modules/vega-lite/build/src/compile/data/geojson.js\");\n/* harmony import */ var _geopoint__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./geopoint */ \"../../node_modules/vega-lite/build/src/compile/data/geopoint.js\");\n/* harmony import */ var _graticule__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./graticule */ \"../../node_modules/vega-lite/build/src/compile/data/graticule.js\");\n/* harmony import */ var _identifier__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./identifier */ \"../../node_modules/vega-lite/build/src/compile/data/identifier.js\");\n/* harmony import */ var _impute__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./impute */ \"../../node_modules/vega-lite/build/src/compile/data/impute.js\");\n/* harmony import */ var _joinaggregate__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./joinaggregate */ \"../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js\");\n/* harmony import */ var _joinaggregatefacet__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./joinaggregatefacet */ \"../../node_modules/vega-lite/build/src/compile/data/joinaggregatefacet.js\");\n/* harmony import */ var _loess__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./loess */ \"../../node_modules/vega-lite/build/src/compile/data/loess.js\");\n/* harmony import */ var _lookup__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./lookup */ \"../../node_modules/vega-lite/build/src/compile/data/lookup.js\");\n/* harmony import */ var _pivot__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./pivot */ \"../../node_modules/vega-lite/build/src/compile/data/pivot.js\");\n/* harmony import */ var _quantile__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ./quantile */ \"../../node_modules/vega-lite/build/src/compile/data/quantile.js\");\n/* harmony import */ var _regression__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ./regression */ \"../../node_modules/vega-lite/build/src/compile/data/regression.js\");\n/* harmony import */ var _sample__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ./sample */ \"../../node_modules/vega-lite/build/src/compile/data/sample.js\");\n/* harmony import */ var _sequence__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ./sequence */ \"../../node_modules/vega-lite/build/src/compile/data/sequence.js\");\n/* harmony import */ var _source__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ./source */ \"../../node_modules/vega-lite/build/src/compile/data/source.js\");\n/* harmony import */ var _stack__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ./stack */ \"../../node_modules/vega-lite/build/src/compile/data/stack.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/compile/data/timeunit.js\");\n/* harmony import */ var _window__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ./window */ \"../../node_modules/vega-lite/build/src/compile/data/window.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction findSource(data, sources) {\n    for (const other of sources) {\n        const otherData = other.data;\n        // if both datasets have a name defined, we cannot merge\n        if (data.name && other.hasName() && data.name !== other.dataName) {\n            continue;\n        }\n        const formatMesh = data['format']?.mesh;\n        const otherFeature = otherData.format?.feature;\n        // feature and mesh are mutually exclusive\n        if (formatMesh && otherFeature) {\n            continue;\n        }\n        // we have to extract the same feature or mesh\n        const formatFeature = data['format']?.feature;\n        if ((formatFeature || otherFeature) && formatFeature !== otherFeature) {\n            continue;\n        }\n        const otherMesh = otherData.format?.mesh;\n        if ((formatMesh || otherMesh) && formatMesh !== otherMesh) {\n            continue;\n        }\n        if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isInlineData)(data) && (0,_data__WEBPACK_IMPORTED_MODULE_1__.isInlineData)(otherData)) {\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.deepEqual)(data.values, otherData.values)) {\n                return other;\n            }\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isUrlData)(data) && (0,_data__WEBPACK_IMPORTED_MODULE_1__.isUrlData)(otherData)) {\n            if (data.url === otherData.url) {\n                return other;\n            }\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isNamedData)(data)) {\n            if (data.name === other.dataName) {\n                return other;\n            }\n        }\n    }\n    return null;\n}\nfunction parseRoot(model, sources) {\n    if (model.data || !model.parent) {\n        // if the model defines a data source or is the root, create a source node\n        if (model.data === null) {\n            // data: null means we should ignore the parent's data so we just create a new data source\n            const source = new _source__WEBPACK_IMPORTED_MODULE_34__.SourceNode({ values: [] });\n            sources.push(source);\n            return source;\n        }\n        const existingSource = findSource(model.data, sources);\n        if (existingSource) {\n            if (!(0,_data__WEBPACK_IMPORTED_MODULE_1__.isGenerator)(model.data)) {\n                existingSource.data.format = (0,_util__WEBPACK_IMPORTED_MODULE_4__.mergeDeep)({}, model.data.format, existingSource.data.format);\n            }\n            // if the new source has a name but the existing one does not, we can set it\n            if (!existingSource.hasName() && model.data.name) {\n                existingSource.dataName = model.data.name;\n            }\n            return existingSource;\n        }\n        else {\n            const source = new _source__WEBPACK_IMPORTED_MODULE_34__.SourceNode(model.data);\n            sources.push(source);\n            return source;\n        }\n    }\n    else {\n        // If we don't have a source defined (overriding parent's data), use the parent's facet root or main.\n        return model.parent.component.data.facetRoot\n            ? model.parent.component.data.facetRoot\n            : model.parent.component.data.main;\n    }\n}\n/**\n * Parses a transform array into a chain of connected dataflow nodes.\n */\nfunction parseTransformArray(head, model, ancestorParse) {\n    let lookupCounter = 0;\n    for (const t of model.transforms) {\n        let derivedType = undefined;\n        let transformNode;\n        if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isCalculate)(t)) {\n            transformNode = head = new _calculate__WEBPACK_IMPORTED_MODULE_10__.CalculateNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isFilter)(t)) {\n            const implicit = (0,_formatparse__WEBPACK_IMPORTED_MODULE_19__.getImplicitFromFilterTransform)(t);\n            transformNode = head = _formatparse__WEBPACK_IMPORTED_MODULE_19__.ParseNode.makeWithAncestors(head, {}, implicit, ancestorParse) ?? head;\n            head = new _filter__WEBPACK_IMPORTED_MODULE_15__.FilterNode(head, model, t.filter);\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isBin)(t)) {\n            transformNode = head = _bin__WEBPACK_IMPORTED_MODULE_9__.BinNode.makeFromTransform(head, t, model);\n            derivedType = 'number';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isTimeUnit)(t)) {\n            derivedType = 'date';\n            const parsedAs = ancestorParse.getWithExplicit(t.field);\n            // Create parse node because the input to time unit is always date.\n            if (parsedAs.value === undefined) {\n                head = new _formatparse__WEBPACK_IMPORTED_MODULE_19__.ParseNode(head, { [t.field]: derivedType });\n                ancestorParse.set(t.field, derivedType, false);\n            }\n            transformNode = head = _timeunit__WEBPACK_IMPORTED_MODULE_36__.TimeUnitNode.makeFromTransform(head, t);\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isAggregate)(t)) {\n            transformNode = head = _aggregate__WEBPACK_IMPORTED_MODULE_8__.AggregateNode.makeFromTransform(head, t);\n            derivedType = 'number';\n            if ((0,_selection__WEBPACK_IMPORTED_MODULE_6__.requiresSelectionId)(model)) {\n                head = new _identifier__WEBPACK_IMPORTED_MODULE_23__.IdentifierNode(head);\n            }\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isLookup)(t)) {\n            transformNode = head = _lookup__WEBPACK_IMPORTED_MODULE_28__.LookupNode.make(head, model, t, lookupCounter++);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isWindow)(t)) {\n            transformNode = head = new _window__WEBPACK_IMPORTED_MODULE_37__.WindowTransformNode(head, t);\n            derivedType = 'number';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isJoinAggregate)(t)) {\n            transformNode = head = new _joinaggregate__WEBPACK_IMPORTED_MODULE_25__.JoinAggregateTransformNode(head, t);\n            derivedType = 'number';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isStack)(t)) {\n            transformNode = head = _stack__WEBPACK_IMPORTED_MODULE_35__.StackNode.makeFromTransform(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isFold)(t)) {\n            transformNode = head = new _fold__WEBPACK_IMPORTED_MODULE_18__.FoldTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isExtent)(t)) {\n            transformNode = head = new _extent__WEBPACK_IMPORTED_MODULE_13__.ExtentTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isFlatten)(t)) {\n            transformNode = head = new _flatten__WEBPACK_IMPORTED_MODULE_17__.FlattenTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isPivot)(t)) {\n            transformNode = head = new _pivot__WEBPACK_IMPORTED_MODULE_29__.PivotTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isSample)(t)) {\n            head = new _sample__WEBPACK_IMPORTED_MODULE_32__.SampleTransformNode(head, t);\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isImpute)(t)) {\n            transformNode = head = _impute__WEBPACK_IMPORTED_MODULE_24__.ImputeNode.makeFromTransform(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isDensity)(t)) {\n            transformNode = head = new _density__WEBPACK_IMPORTED_MODULE_12__.DensityTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isQuantile)(t)) {\n            transformNode = head = new _quantile__WEBPACK_IMPORTED_MODULE_30__.QuantileTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isRegression)(t)) {\n            transformNode = head = new _regression__WEBPACK_IMPORTED_MODULE_31__.RegressionTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else if ((0,_transform__WEBPACK_IMPORTED_MODULE_3__.isLoess)(t)) {\n            transformNode = head = new _loess__WEBPACK_IMPORTED_MODULE_27__.LoessTransformNode(head, t);\n            derivedType = 'derived';\n        }\n        else {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.invalidTransformIgnored(t));\n            continue;\n        }\n        if (transformNode && derivedType !== undefined) {\n            for (const field of transformNode.producedFields() ?? []) {\n                ancestorParse.set(field, derivedType, false);\n            }\n        }\n    }\n    return head;\n}\n/*\nDescription of the dataflow (http://asciiflow.com/):\n     +--------+\n     | Source |\n     +---+----+\n         |\n         v\n     FormatParse\n     (explicit)\n         |\n         v\n     Transforms\n(Filter, Calculate, Binning, TimeUnit, Aggregate, Window, ...)\n         |\n         v\n     FormatParse\n     (implicit)\n         |\n         v\n Binning (in `encoding`)\n         |\n         v\n Timeunit (in `encoding`)\n         |\n         v\nFormula From Sort Array\n         |\n         v\n      +--+--+\n      | Raw |\n      +-----+\n         |\n         v\n  Aggregate (in `encoding`)\n         |\n         v\n  Stack (in `encoding`)\n         |\n         v\n  Invalid Filter\n         |\n         v\n   +----------+\n   |   Main   |\n   +----------+\n         |\n         v\n     +-------+\n     | Facet |----> \"column\", \"column-layout\", and \"row\"\n     +-------+\n         |\n         v\n  ...Child data...\n*/\nfunction parseData(model) {\n    let head = parseRoot(model, model.component.data.sources);\n    const { outputNodes, outputNodeRefCounts } = model.component.data;\n    const data = model.data;\n    const newData = data && ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isGenerator)(data) || (0,_data__WEBPACK_IMPORTED_MODULE_1__.isUrlData)(data) || (0,_data__WEBPACK_IMPORTED_MODULE_1__.isInlineData)(data));\n    const ancestorParse = !newData && model.parent ? model.parent.component.data.ancestorParse.clone() : new ___WEBPACK_IMPORTED_MODULE_0__.AncestorParse();\n    if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isGenerator)(data)) {\n        // insert generator transform\n        if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isSequenceGenerator)(data)) {\n            head = new _sequence__WEBPACK_IMPORTED_MODULE_33__.SequenceNode(head, data.sequence);\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_1__.isGraticuleGenerator)(data)) {\n            head = new _graticule__WEBPACK_IMPORTED_MODULE_22__.GraticuleNode(head, data.graticule);\n        }\n        // no parsing necessary for generator\n        ancestorParse.parseNothing = true;\n    }\n    else if (data?.format?.parse === null) {\n        // format.parse: null means disable parsing\n        ancestorParse.parseNothing = true;\n    }\n    head = _formatparse__WEBPACK_IMPORTED_MODULE_19__.ParseNode.makeExplicit(head, model, ancestorParse) ?? head;\n    // Default discrete selections require an identifer transform to\n    // uniquely identify data points. Add this transform at the head of\n    // the pipeline such that the identifier field is available for all\n    // subsequent datasets. During optimization, we will remove this\n    // transform if it proves to be unnecessary. Additional identifier\n    // transforms will be necessary when new tuples are constructed\n    // (e.g., post-aggregation).\n    head = new _identifier__WEBPACK_IMPORTED_MODULE_23__.IdentifierNode(head);\n    // HACK: This is equivalent for merging bin extent for union scale.\n    // FIXME(https://github.com/vega/vega-lite/issues/2270): Correctly merge extent / bin node for shared bin scale\n    const parentIsLayer = model.parent && (0,_model__WEBPACK_IMPORTED_MODULE_5__.isLayerModel)(model.parent);\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model) || (0,_model__WEBPACK_IMPORTED_MODULE_5__.isFacetModel)(model)) {\n        if (parentIsLayer) {\n            head = _bin__WEBPACK_IMPORTED_MODULE_9__.BinNode.makeFromEncoding(head, model) ?? head;\n        }\n    }\n    if (model.transforms.length > 0) {\n        head = parseTransformArray(head, model, ancestorParse);\n    }\n    // create parse nodes for fields that need to be parsed (or flattened) implicitly\n    const implicitSelection = (0,_formatparse__WEBPACK_IMPORTED_MODULE_19__.getImplicitFromSelection)(model);\n    const implicitEncoding = (0,_formatparse__WEBPACK_IMPORTED_MODULE_19__.getImplicitFromEncoding)(model);\n    head = _formatparse__WEBPACK_IMPORTED_MODULE_19__.ParseNode.makeWithAncestors(head, {}, { ...implicitSelection, ...implicitEncoding }, ancestorParse) ?? head;\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model)) {\n        head = _geojson__WEBPACK_IMPORTED_MODULE_20__.GeoJSONNode.parseAll(head, model);\n        head = _geopoint__WEBPACK_IMPORTED_MODULE_21__.GeoPointNode.parseAll(head, model);\n    }\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model) || (0,_model__WEBPACK_IMPORTED_MODULE_5__.isFacetModel)(model)) {\n        if (!parentIsLayer) {\n            head = _bin__WEBPACK_IMPORTED_MODULE_9__.BinNode.makeFromEncoding(head, model) ?? head;\n        }\n        head = _timeunit__WEBPACK_IMPORTED_MODULE_36__.TimeUnitNode.makeFromEncoding(head, model) ?? head;\n        head = _calculate__WEBPACK_IMPORTED_MODULE_10__.CalculateNode.parseAllForSortIndex(head, model);\n    }\n    // add an output node pre aggregation\n    const rawName = model.getDataName(_data__WEBPACK_IMPORTED_MODULE_1__.DataSourceType.Raw);\n    const raw = new _dataflow__WEBPACK_IMPORTED_MODULE_11__.OutputNode(head, rawName, _data__WEBPACK_IMPORTED_MODULE_1__.DataSourceType.Raw, outputNodeRefCounts);\n    outputNodes[rawName] = raw;\n    head = raw;\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model)) {\n        const agg = _aggregate__WEBPACK_IMPORTED_MODULE_8__.AggregateNode.makeFromEncoding(head, model);\n        if (agg) {\n            head = agg;\n            if ((0,_selection__WEBPACK_IMPORTED_MODULE_6__.requiresSelectionId)(model)) {\n                head = new _identifier__WEBPACK_IMPORTED_MODULE_23__.IdentifierNode(head);\n            }\n        }\n        head = _impute__WEBPACK_IMPORTED_MODULE_24__.ImputeNode.makeFromEncoding(head, model) ?? head;\n        head = _stack__WEBPACK_IMPORTED_MODULE_35__.StackNode.makeFromEncoding(head, model) ?? head;\n    }\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model)) {\n        head = _filterinvalid__WEBPACK_IMPORTED_MODULE_16__.FilterInvalidNode.make(head, model) ?? head;\n    }\n    // output node for marks\n    const mainName = model.getDataName(_data__WEBPACK_IMPORTED_MODULE_1__.DataSourceType.Main);\n    const main = new _dataflow__WEBPACK_IMPORTED_MODULE_11__.OutputNode(head, mainName, _data__WEBPACK_IMPORTED_MODULE_1__.DataSourceType.Main, outputNodeRefCounts);\n    outputNodes[mainName] = main;\n    head = main;\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isUnitModel)(model)) {\n        (0,_selection_parse__WEBPACK_IMPORTED_MODULE_7__.materializeSelections)(model, main);\n    }\n    // add facet marker\n    let facetRoot = null;\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isFacetModel)(model)) {\n        const facetName = model.getName('facet');\n        // Derive new aggregate for facet's sort field\n        // augment data source with new fields for crossed facet\n        head = (0,_joinaggregatefacet__WEBPACK_IMPORTED_MODULE_26__.makeJoinAggregateFromFacet)(head, model.facet) ?? head;\n        facetRoot = new _facet__WEBPACK_IMPORTED_MODULE_14__.FacetNode(head, model, facetName, main.getSource());\n        outputNodes[facetName] = facetRoot;\n    }\n    return {\n        ...model.component.data,\n        outputNodes,\n        outputNodeRefCounts,\n        raw,\n        main,\n        facetRoot,\n        ancestorParse\n    };\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/pivot.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/pivot.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   PivotTransformNode: () => (/* binding */ PivotTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for pivot transform nodes.\n */\nclass PivotTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new PivotTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n    }\n    addDimensions(fields) {\n        this.transform.groupby = (0,_util__WEBPACK_IMPORTED_MODULE_0__.unique)((this.transform.groupby ?? []).concat(fields), d => d);\n    }\n    producedFields() {\n        return undefined; // return undefined so that potentially everything can depend on the pivot\n    }\n    dependentFields() {\n        return new Set([this.transform.pivot, this.transform.value, ...(this.transform.groupby ?? [])]);\n    }\n    hash() {\n        return `PivotTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { pivot, value, groupby, limit, op } = this.transform;\n        return {\n            type: 'pivot',\n            field: pivot,\n            value,\n            ...(limit !== undefined ? { limit } : {}),\n            ...(op !== undefined ? { op } : {}),\n            ...(groupby !== undefined ? { groupby } : {})\n        };\n    }\n}\n//# sourceMappingURL=pivot.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/pivot.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/quantile.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/quantile.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   QuantileTransformNode: () => (/* binding */ QuantileTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for quantile transform nodes\n */\nclass QuantileTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new QuantileTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const specifiedAs = this.transform.as ?? [undefined, undefined];\n        this.transform.as = [specifiedAs[0] ?? 'prob', specifiedAs[1] ?? 'value'];\n    }\n    dependentFields() {\n        return new Set([this.transform.quantile, ...(this.transform.groupby ?? [])]);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `QuantileTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { quantile, ...rest } = this.transform;\n        const result = {\n            type: 'quantile',\n            field: quantile,\n            ...rest\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=quantile.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/quantile.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/regression.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/regression.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   RegressionTransformNode: () => (/* binding */ RegressionTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for regression transform nodes\n */\nclass RegressionTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new RegressionTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n        this.transform = (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(transform); // duplicate to prevent side effects\n        const specifiedAs = this.transform.as ?? [undefined, undefined];\n        this.transform.as = [specifiedAs[0] ?? transform.on, specifiedAs[1] ?? transform.regression];\n    }\n    dependentFields() {\n        return new Set([this.transform.regression, this.transform.on, ...(this.transform.groupby ?? [])]);\n    }\n    producedFields() {\n        return new Set(this.transform.as);\n    }\n    hash() {\n        return `RegressionTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const { regression, on, ...rest } = this.transform;\n        const result = {\n            type: 'regression',\n            x: on,\n            y: regression,\n            ...rest\n        };\n        return result;\n    }\n}\n//# sourceMappingURL=regression.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/regression.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/sample.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/sample.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SampleTransformNode: () => (/* binding */ SampleTransformNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n/**\n * A class for the sample transform nodes\n */\nclass SampleTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new SampleTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_0__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return new Set();\n    }\n    hash() {\n        return `SampleTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.transform)}`;\n    }\n    assemble() {\n        return {\n            type: 'sample',\n            size: this.transform.sample\n        };\n    }\n}\n//# sourceMappingURL=sample.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/sample.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/sequence.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/sequence.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SequenceNode: () => (/* binding */ SequenceNode)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\nclass SequenceNode extends _dataflow__WEBPACK_IMPORTED_MODULE_1__.DataFlowNode {\n    clone() {\n        return new SequenceNode(null, this.params);\n    }\n    constructor(parent, params) {\n        super(parent);\n        this.params = params;\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return new Set([this.params.as ?? 'data']);\n    }\n    hash() {\n        return `Hash ${(0,_util__WEBPACK_IMPORTED_MODULE_0__.hash)(this.params)}`;\n    }\n    assemble() {\n        return {\n            type: 'sequence',\n            ...this.params\n        };\n    }\n}\n//# sourceMappingURL=sequence.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/sequence.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/source.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/source.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SourceNode: () => (/* binding */ SourceNode)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\nclass SourceNode extends _dataflow__WEBPACK_IMPORTED_MODULE_2__.DataFlowNode {\n    constructor(data) {\n        super(null); // source cannot have parent\n        data ?? (data = { name: 'source' });\n        let format;\n        if (!(0,_data__WEBPACK_IMPORTED_MODULE_0__.isGenerator)(data)) {\n            format = data.format ? { ...(0,_util__WEBPACK_IMPORTED_MODULE_1__.omit)(data.format, ['parse']) } : {};\n        }\n        if ((0,_data__WEBPACK_IMPORTED_MODULE_0__.isInlineData)(data)) {\n            this._data = { values: data.values };\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_0__.isUrlData)(data)) {\n            this._data = { url: data.url };\n            if (!format.type) {\n                // Extract extension from URL using snippet from\n                // http://stackoverflow.com/questions/680929/how-to-extract-extension-from-filename-string-in-javascript\n                let defaultExtension = /(?:\\.([^.]+))?$/.exec(data.url)[1];\n                if (!(0,_util__WEBPACK_IMPORTED_MODULE_1__.contains)(['json', 'csv', 'tsv', 'dsv', 'topojson'], defaultExtension)) {\n                    defaultExtension = 'json';\n                }\n                // defaultExtension has type string but we ensure that it is DataFormatType above\n                format.type = defaultExtension;\n            }\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_0__.isSphereGenerator)(data)) {\n            // hardwire GeoJSON sphere data into output specification\n            this._data = { values: [{ type: 'Sphere' }] };\n        }\n        else if ((0,_data__WEBPACK_IMPORTED_MODULE_0__.isNamedData)(data) || (0,_data__WEBPACK_IMPORTED_MODULE_0__.isGenerator)(data)) {\n            this._data = {};\n        }\n        // set flag to check if generator\n        this._generator = (0,_data__WEBPACK_IMPORTED_MODULE_0__.isGenerator)(data);\n        // any dataset can be named\n        if (data.name) {\n            this._name = data.name;\n        }\n        if (format && !(0,_util__WEBPACK_IMPORTED_MODULE_1__.isEmpty)(format)) {\n            this._data.format = format;\n        }\n    }\n    dependentFields() {\n        return new Set();\n    }\n    producedFields() {\n        return undefined; // we don't know what this source produces\n    }\n    get data() {\n        return this._data;\n    }\n    hasName() {\n        return !!this._name;\n    }\n    get isGenerator() {\n        return this._generator;\n    }\n    get dataName() {\n        return this._name;\n    }\n    set dataName(name) {\n        this._name = name;\n    }\n    set parent(parent) {\n        throw new Error('Source nodes have to be roots.');\n    }\n    remove() {\n        throw new Error('Source nodes are roots and cannot be removed.');\n    }\n    hash() {\n        throw new Error('Cannot hash sources');\n    }\n    assemble() {\n        return {\n            name: this._name,\n            ...this._data,\n            transform: []\n        };\n    }\n}\n//# sourceMappingURL=source.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/source.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/stack.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/stack.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   StackNode: () => (/* binding */ StackNode)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\nfunction getStackByFields(model) {\n    return model.stack.stackBy.reduce((fields, by) => {\n        const fieldDef = by.fieldDef;\n        const _field = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(fieldDef);\n        if (_field) {\n            fields.push(_field);\n        }\n        return fields;\n    }, []);\n}\nfunction isValidAsArray(as) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(as) && as.every(s => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(s)) && as.length > 1;\n}\nclass StackNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new StackNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_2__.duplicate)(this._stack));\n    }\n    constructor(parent, stack) {\n        super(parent);\n        this._stack = stack;\n    }\n    static makeFromTransform(parent, stackTransform) {\n        const { stack, groupby, as, offset = 'zero' } = stackTransform;\n        const sortFields = [];\n        const sortOrder = [];\n        if (stackTransform.sort !== undefined) {\n            for (const sortField of stackTransform.sort) {\n                sortFields.push(sortField.field);\n                sortOrder.push((0,_util__WEBPACK_IMPORTED_MODULE_2__.getFirstDefined)(sortField.order, 'ascending'));\n            }\n        }\n        const sort = {\n            field: sortFields,\n            order: sortOrder\n        };\n        let normalizedAs;\n        if (isValidAsArray(as)) {\n            normalizedAs = as;\n        }\n        else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(as)) {\n            normalizedAs = [as, `${as}_end`];\n        }\n        else {\n            normalizedAs = [`${stackTransform.stack}_start`, `${stackTransform.stack}_end`];\n        }\n        return new StackNode(parent, {\n            dimensionFieldDefs: [],\n            stackField: stack,\n            groupby,\n            offset,\n            sort,\n            facetby: [],\n            as: normalizedAs\n        });\n    }\n    static makeFromEncoding(parent, model) {\n        const stackProperties = model.stack;\n        const { encoding } = model;\n        if (!stackProperties) {\n            return null;\n        }\n        const { groupbyChannels, fieldChannel, offset, impute } = stackProperties;\n        const dimensionFieldDefs = groupbyChannels\n            .map(groupbyChannel => {\n            const cDef = encoding[groupbyChannel];\n            return (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldDef)(cDef);\n        })\n            .filter(def => !!def);\n        const stackby = getStackByFields(model);\n        const orderDef = model.encoding.order;\n        let sort;\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(orderDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(orderDef)) {\n            sort = (0,_common__WEBPACK_IMPORTED_MODULE_3__.sortParams)(orderDef);\n        }\n        else {\n            const sortOrder = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isOrderOnlyDef)(orderDef) ? orderDef.sort : fieldChannel === 'y' ? 'descending' : 'ascending';\n            // default = descending by stackFields\n            // FIXME is the default here correct for binned fields?\n            sort = stackby.reduce((s, field) => {\n                s.field.push(field);\n                s.order.push(sortOrder);\n                return s;\n            }, { field: [], order: [] });\n        }\n        return new StackNode(parent, {\n            dimensionFieldDefs,\n            stackField: model.vgField(fieldChannel),\n            facetby: [],\n            stackby,\n            sort,\n            offset,\n            impute,\n            as: [\n                model.vgField(fieldChannel, { suffix: 'start', forAs: true }),\n                model.vgField(fieldChannel, { suffix: 'end', forAs: true })\n            ]\n        });\n    }\n    get stack() {\n        return this._stack;\n    }\n    addDimensions(fields) {\n        this._stack.facetby.push(...fields);\n    }\n    dependentFields() {\n        const out = new Set();\n        out.add(this._stack.stackField);\n        this.getGroupbyFields().forEach(out.add, out);\n        this._stack.facetby.forEach(out.add, out);\n        this._stack.sort.field.forEach(out.add, out);\n        return out;\n    }\n    producedFields() {\n        return new Set(this._stack.as);\n    }\n    hash() {\n        return `Stack ${(0,_util__WEBPACK_IMPORTED_MODULE_2__.hash)(this._stack)}`;\n    }\n    getGroupbyFields() {\n        const { dimensionFieldDefs, impute, groupby } = this._stack;\n        if (dimensionFieldDefs.length > 0) {\n            return dimensionFieldDefs\n                .map(dimensionFieldDef => {\n                if (dimensionFieldDef.bin) {\n                    if (impute) {\n                        // For binned group by field with impute, we calculate bin_mid\n                        // as we cannot impute two fields simultaneously\n                        return [(0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { binSuffix: 'mid' })];\n                    }\n                    return [\n                        // For binned group by field without impute, we need both bin (start) and bin_end\n                        (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, {}),\n                        (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { binSuffix: 'end' })\n                    ];\n                }\n                return [(0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef)];\n            })\n                .flat();\n        }\n        return groupby ?? [];\n    }\n    assemble() {\n        const transform = [];\n        const { facetby, dimensionFieldDefs, stackField: field, stackby, sort, offset, impute, as } = this._stack;\n        // Impute\n        if (impute) {\n            for (const dimensionFieldDef of dimensionFieldDefs) {\n                const { bandPosition = 0.5, bin } = dimensionFieldDef;\n                if (bin) {\n                    // As we can only impute one field at a time, we need to calculate\n                    // mid point for a binned field\n                    const binStart = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { expr: 'datum' });\n                    const binEnd = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { expr: 'datum', binSuffix: 'end' });\n                    transform.push({\n                        type: 'formula',\n                        expr: `${bandPosition}*${binStart}+${1 - bandPosition}*${binEnd}`,\n                        as: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { binSuffix: 'mid', forAs: true })\n                    });\n                }\n                transform.push({\n                    type: 'impute',\n                    field,\n                    groupby: [...stackby, ...facetby],\n                    key: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionFieldDef, { binSuffix: 'mid' }),\n                    method: 'value',\n                    value: 0\n                });\n            }\n        }\n        // Stack\n        transform.push({\n            type: 'stack',\n            groupby: [...this.getGroupbyFields(), ...facetby],\n            field,\n            sort,\n            as,\n            offset\n        });\n        return transform;\n    }\n}\n//# sourceMappingURL=stack.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/stack.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/subtree.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/subtree.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   moveFacetDown: () => (/* binding */ moveFacetDown)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/compile/data/aggregate.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/compile/data/facet.js\");\n/* harmony import */ var _joinaggregate__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./joinaggregate */ \"../../node_modules/vega-lite/build/src/compile/data/joinaggregate.js\");\n/* harmony import */ var _optimize__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./optimize */ \"../../node_modules/vega-lite/build/src/compile/data/optimize.js\");\n/* harmony import */ var _stack__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./stack */ \"../../node_modules/vega-lite/build/src/compile/data/stack.js\");\n/* harmony import */ var _window__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./window */ \"../../node_modules/vega-lite/build/src/compile/data/window.js\");\n\n\n\n\n\n\n\n\n/**\n * Clones the subtree and ignores output nodes except for the leaves, which are renamed.\n */\nfunction cloneSubtree(facet) {\n    function clone(node) {\n        if (!(node instanceof _facet__WEBPACK_IMPORTED_MODULE_3__.FacetNode)) {\n            const copy = node.clone();\n            if (copy instanceof _dataflow__WEBPACK_IMPORTED_MODULE_2__.OutputNode) {\n                const newName = _optimize__WEBPACK_IMPORTED_MODULE_5__.FACET_SCALE_PREFIX + copy.getSource();\n                copy.setSource(newName);\n                facet.model.component.data.outputNodes[newName] = copy;\n            }\n            else if (copy instanceof _aggregate__WEBPACK_IMPORTED_MODULE_1__.AggregateNode ||\n                copy instanceof _stack__WEBPACK_IMPORTED_MODULE_6__.StackNode ||\n                copy instanceof _window__WEBPACK_IMPORTED_MODULE_7__.WindowTransformNode ||\n                copy instanceof _joinaggregate__WEBPACK_IMPORTED_MODULE_4__.JoinAggregateTransformNode) {\n                copy.addDimensions(facet.fields);\n            }\n            for (const n of node.children.flatMap(clone)) {\n                n.parent = copy;\n            }\n            return [copy];\n        }\n        return node.children.flatMap(clone);\n    }\n    return clone;\n}\n/**\n * Move facet nodes down to the next fork or output node. Also pull the main output with the facet node.\n * After moving down the facet node, make a copy of the subtree and make it a child of the main output.\n */\nfunction moveFacetDown(node) {\n    if (node instanceof _facet__WEBPACK_IMPORTED_MODULE_3__.FacetNode) {\n        if (node.numChildren() === 1 && !(node.children[0] instanceof _dataflow__WEBPACK_IMPORTED_MODULE_2__.OutputNode)) {\n            // move down until we hit a fork or output node\n            const child = node.children[0];\n            if (child instanceof _aggregate__WEBPACK_IMPORTED_MODULE_1__.AggregateNode ||\n                child instanceof _stack__WEBPACK_IMPORTED_MODULE_6__.StackNode ||\n                child instanceof _window__WEBPACK_IMPORTED_MODULE_7__.WindowTransformNode ||\n                child instanceof _joinaggregate__WEBPACK_IMPORTED_MODULE_4__.JoinAggregateTransformNode) {\n                child.addDimensions(node.fields);\n            }\n            child.swapWithParent();\n            moveFacetDown(node);\n        }\n        else {\n            // move main to facet\n            const facetMain = node.model.component.data.main;\n            moveMainDownToFacet(facetMain);\n            // replicate the subtree and place it before the facet's main node\n            const cloner = cloneSubtree(node);\n            const copy = node.children.map(cloner).flat();\n            for (const c of copy) {\n                c.parent = facetMain;\n            }\n        }\n    }\n    else {\n        node.children.map(moveFacetDown);\n    }\n}\nfunction moveMainDownToFacet(node) {\n    if (node instanceof _dataflow__WEBPACK_IMPORTED_MODULE_2__.OutputNode && node.type === _data__WEBPACK_IMPORTED_MODULE_0__.DataSourceType.Main) {\n        if (node.numChildren() === 1) {\n            const child = node.children[0];\n            if (!(child instanceof _facet__WEBPACK_IMPORTED_MODULE_3__.FacetNode)) {\n                child.swapWithParent();\n                moveMainDownToFacet(node);\n            }\n        }\n    }\n}\n//# sourceMappingURL=subtree.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/subtree.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/timeunit.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/timeunit.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TimeUnitNode: () => (/* binding */ TimeUnitNode)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n\n\n\n\n\n\nfunction isTimeUnitTransformComponent(timeUnitComponent) {\n    return timeUnitComponent.as !== undefined;\n}\nfunction offsetAs(field) {\n    return `${field}_end`;\n}\nclass TimeUnitNode extends _dataflow__WEBPACK_IMPORTED_MODULE_4__.DataFlowNode {\n    clone() {\n        return new TimeUnitNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_2__.duplicate)(this.formula));\n    }\n    constructor(parent, formula) {\n        super(parent);\n        this.formula = formula;\n    }\n    static makeFromEncoding(parent, model) {\n        const formula = model.reduceFieldDef((timeUnitComponent, fieldDef) => {\n            const { field, timeUnit } = fieldDef;\n            if (timeUnit) {\n                let component;\n                if ((0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.isBinnedTimeUnit)(timeUnit)) {\n                    // For binned time unit, only produce end if the mark is a rect-based mark (rect, bar, image, arc), which needs \"range\".\n                    if ((0,_model__WEBPACK_IMPORTED_MODULE_3__.isUnitModel)(model)) {\n                        const { mark } = model;\n                        if ((0,_mark__WEBPACK_IMPORTED_MODULE_5__.isRectBasedMark)(mark) || !!fieldDef.bandPosition) {\n                            component = {\n                                timeUnit: (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.normalizeTimeUnit)(timeUnit),\n                                field\n                            };\n                        }\n                    }\n                }\n                else {\n                    component = {\n                        as: (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.vgField)(fieldDef, { forAs: true }),\n                        field,\n                        timeUnit\n                    };\n                }\n                if (component) {\n                    timeUnitComponent[(0,_util__WEBPACK_IMPORTED_MODULE_2__.hash)(component)] = component;\n                }\n            }\n            return timeUnitComponent;\n        }, {});\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_2__.isEmpty)(formula)) {\n            return null;\n        }\n        return new TimeUnitNode(parent, formula);\n    }\n    static makeFromTransform(parent, t) {\n        const { timeUnit, ...other } = { ...t };\n        const normalizedTimeUnit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.normalizeTimeUnit)(timeUnit);\n        const component = {\n            ...other,\n            timeUnit: normalizedTimeUnit\n        };\n        return new TimeUnitNode(parent, {\n            [(0,_util__WEBPACK_IMPORTED_MODULE_2__.hash)(component)]: component\n        });\n    }\n    /**\n     * Merge together TimeUnitNodes assigning the children of `other` to `this`\n     * and removing `other`.\n     */\n    merge(other) {\n        this.formula = { ...this.formula };\n        // if the same hash happen twice, merge\n        for (const key in other.formula) {\n            if (!this.formula[key]) {\n                // copy if it's not a duplicate\n                this.formula[key] = other.formula[key];\n            }\n        }\n        for (const child of other.children) {\n            other.removeChild(child);\n            child.parent = this;\n        }\n        other.remove();\n    }\n    /**\n     * Remove time units coming from the other node.\n     */\n    removeFormulas(fields) {\n        const newFormula = {};\n        for (const [key, timeUnitComponent] of (0,_util__WEBPACK_IMPORTED_MODULE_2__.entries)(this.formula)) {\n            const fieldAs = isTimeUnitTransformComponent(timeUnitComponent)\n                ? timeUnitComponent.as\n                : `${timeUnitComponent.field}_end`;\n            if (!fields.has(fieldAs)) {\n                newFormula[key] = timeUnitComponent;\n            }\n        }\n        this.formula = newFormula;\n    }\n    producedFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_2__.vals)(this.formula).map(f => {\n            return isTimeUnitTransformComponent(f) ? f.as : offsetAs(f.field);\n        }));\n    }\n    dependentFields() {\n        return new Set((0,_util__WEBPACK_IMPORTED_MODULE_2__.vals)(this.formula).map(f => f.field));\n    }\n    hash() {\n        return `TimeUnit ${(0,_util__WEBPACK_IMPORTED_MODULE_2__.hash)(this.formula)}`;\n    }\n    assemble() {\n        const transforms = [];\n        for (const f of (0,_util__WEBPACK_IMPORTED_MODULE_2__.vals)(this.formula)) {\n            if (isTimeUnitTransformComponent(f)) {\n                const { field, as, timeUnit } = f;\n                const { unit, utc, ...params } = (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.normalizeTimeUnit)(timeUnit);\n                transforms.push({\n                    field: (0,_util__WEBPACK_IMPORTED_MODULE_2__.replacePathInField)(field),\n                    type: 'timeunit',\n                    ...(unit ? { units: (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.getTimeUnitParts)(unit) } : {}),\n                    ...(utc ? { timezone: 'utc' } : {}),\n                    ...params,\n                    as: [as, `${as}_end`]\n                });\n            }\n            else if (f) {\n                const { field, timeUnit } = f;\n                const smallestUnit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.getSmallestTimeUnitPart)(timeUnit?.unit);\n                const { part, step } = (0,_timeunit__WEBPACK_IMPORTED_MODULE_1__.getDateTimePartAndStep)(smallestUnit, timeUnit.step);\n                transforms.push({\n                    type: 'formula',\n                    expr: `timeOffset('${part}', datum['${field}'], ${step})`,\n                    as: offsetAs(field)\n                });\n            }\n        }\n        return transforms;\n    }\n}\n//# sourceMappingURL=timeunit.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/timeunit.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/data/window.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/data/window.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   WindowTransformNode: () => (/* binding */ WindowTransformNode)\n/* harmony export */ });\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _dataflow__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n\n\n\n\n\n/**\n * A class for the window transform nodes\n */\nclass WindowTransformNode extends _dataflow__WEBPACK_IMPORTED_MODULE_3__.DataFlowNode {\n    clone() {\n        return new WindowTransformNode(null, (0,_util__WEBPACK_IMPORTED_MODULE_2__.duplicate)(this.transform));\n    }\n    constructor(parent, transform) {\n        super(parent);\n        this.transform = transform;\n    }\n    addDimensions(fields) {\n        this.transform.groupby = (0,_util__WEBPACK_IMPORTED_MODULE_2__.unique)(this.transform.groupby.concat(fields), d => d);\n    }\n    dependentFields() {\n        const out = new Set();\n        (this.transform.groupby ?? []).forEach(out.add, out);\n        (this.transform.sort ?? []).forEach(m => out.add(m.field));\n        this.transform.window\n            .map(w => w.field)\n            .filter(f => f !== undefined)\n            .forEach(out.add, out);\n        return out;\n    }\n    producedFields() {\n        return new Set(this.transform.window.map(this.getDefaultName));\n    }\n    getDefaultName(windowFieldDef) {\n        return windowFieldDef.as ?? (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(windowFieldDef);\n    }\n    hash() {\n        return `WindowTransform ${(0,_util__WEBPACK_IMPORTED_MODULE_2__.hash)(this.transform)}`;\n    }\n    assemble() {\n        const fields = [];\n        const ops = [];\n        const as = [];\n        const params = [];\n        for (const window of this.transform.window) {\n            ops.push(window.op);\n            as.push(this.getDefaultName(window));\n            params.push(window.param === undefined ? null : window.param);\n            fields.push(window.field === undefined ? null : window.field);\n        }\n        const frame = this.transform.frame;\n        const groupby = this.transform.groupby;\n        if (frame && frame[0] === null && frame[1] === null && ops.every(o => (0,_aggregate__WEBPACK_IMPORTED_MODULE_0__.isAggregateOp)(o))) {\n            // when the window does not rely on any particular window ops or frame, switch to a simpler and more efficient joinaggregate\n            return {\n                type: 'joinaggregate',\n                as,\n                ops: ops,\n                fields,\n                ...(groupby !== undefined ? { groupby } : {})\n            };\n        }\n        const sortFields = [];\n        const sortOrder = [];\n        if (this.transform.sort !== undefined) {\n            for (const sortField of this.transform.sort) {\n                sortFields.push(sortField.field);\n                sortOrder.push(sortField.order ?? 'ascending');\n            }\n        }\n        const sort = {\n            field: sortFields,\n            order: sortOrder\n        };\n        const ignorePeers = this.transform.ignorePeers;\n        return {\n            type: 'window',\n            params,\n            as,\n            ops,\n            fields,\n            sort,\n            ...(ignorePeers !== undefined ? { ignorePeers } : {}),\n            ...(groupby !== undefined ? { groupby } : {}),\n            ...(frame !== undefined ? { frame } : {})\n        };\n    }\n}\n//# sourceMappingURL=window.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/data/window.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/facet.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/facet.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FacetModel: () => (/* binding */ FacetModel),\n/* harmony export */   facetSortFieldName: () => (/* binding */ facetSortFieldName)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _spec_facet__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../spec/facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _buildmodel__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./buildmodel */ \"../../node_modules/vega-lite/build/src/compile/buildmodel.js\");\n/* harmony import */ var _data_assemble__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./data/assemble */ \"../../node_modules/vega-lite/build/src/compile/data/assemble.js\");\n/* harmony import */ var _data_calculate__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./data/calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _data_parse__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./data/parse */ \"../../node_modules/vega-lite/build/src/compile/data/parse.js\");\n/* harmony import */ var _header_assemble__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./header/assemble */ \"../../node_modules/vega-lite/build/src/compile/header/assemble.js\");\n/* harmony import */ var _header_common__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./header/common */ \"../../node_modules/vega-lite/build/src/compile/header/common.js\");\n/* harmony import */ var _header_component__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./header/component */ \"../../node_modules/vega-lite/build/src/compile/header/component.js\");\n/* harmony import */ var _header_parse__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./header/parse */ \"../../node_modules/vega-lite/build/src/compile/header/parse.js\");\n/* harmony import */ var _layoutsize_parse__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./layoutsize/parse */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _scale_domain__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./scale/domain */ \"../../node_modules/vega-lite/build/src/compile/scale/domain.js\");\n/* harmony import */ var _selection_assemble__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./selection/assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction facetSortFieldName(fieldDef, sort, opt) {\n    return (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(sort, { suffix: `by_${(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef)}`, ...(opt ?? {}) });\n}\nclass FacetModel extends _model__WEBPACK_IMPORTED_MODULE_20__.ModelWithField {\n    constructor(spec, parent, parentGivenName, config) {\n        super(spec, 'facet', parent, parentGivenName, config, spec.resolve);\n        this.child = (0,_buildmodel__WEBPACK_IMPORTED_MODULE_11__.buildModel)(spec.spec, this, this.getName('child'), undefined, config);\n        this.children = [this.child];\n        this.facet = this.initFacet(spec.facet);\n    }\n    initFacet(facet) {\n        // clone to prevent side effect to the original spec\n        if (!(0,_spec_facet__WEBPACK_IMPORTED_MODULE_8__.isFacetMapping)(facet)) {\n            return { facet: this.initFacetFieldDef(facet, 'facet') };\n        }\n        const channels = (0,_util__WEBPACK_IMPORTED_MODULE_9__.keys)(facet);\n        const normalizedFacet = {};\n        for (const channel of channels) {\n            if (![_channel__WEBPACK_IMPORTED_MODULE_2__.ROW, _channel__WEBPACK_IMPORTED_MODULE_2__.COLUMN].includes(channel)) {\n                // Drop unsupported channel\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.incompatibleChannel(channel, 'facet'));\n                break;\n            }\n            const fieldDef = facet[channel];\n            if (fieldDef.field === undefined) {\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.emptyFieldDef(fieldDef, channel));\n                break;\n            }\n            normalizedFacet[channel] = this.initFacetFieldDef(fieldDef, channel);\n        }\n        return normalizedFacet;\n    }\n    initFacetFieldDef(fieldDef, channel) {\n        // Cast because we call initFieldDef, which assumes general FieldDef.\n        // However, FacetFieldDef is a bit more constrained than the general FieldDef\n        const facetFieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.initFieldDef)(fieldDef, channel);\n        if (facetFieldDef.header) {\n            facetFieldDef.header = (0,_expr__WEBPACK_IMPORTED_MODULE_4__.replaceExprRef)(facetFieldDef.header);\n        }\n        else if (facetFieldDef.header === null) {\n            facetFieldDef.header = null;\n        }\n        return facetFieldDef;\n    }\n    channelHasField(channel) {\n        return !!this.facet[channel];\n    }\n    fieldDef(channel) {\n        return this.facet[channel];\n    }\n    parseData() {\n        this.component.data = (0,_data_parse__WEBPACK_IMPORTED_MODULE_14__.parseData)(this);\n        this.child.parseData();\n    }\n    parseLayoutSize() {\n        (0,_layoutsize_parse__WEBPACK_IMPORTED_MODULE_19__.parseChildrenLayoutSize)(this);\n    }\n    parseSelections() {\n        // As a facet has a single child, the selection components are the same.\n        // The child maintains its selections to assemble signals, which remain\n        // within its unit.\n        this.child.parseSelections();\n        this.component.selection = this.child.component.selection;\n    }\n    parseMarkGroup() {\n        this.child.parseMarkGroup();\n    }\n    parseAxesAndHeaders() {\n        this.child.parseAxesAndHeaders();\n        (0,_header_parse__WEBPACK_IMPORTED_MODULE_18__.parseFacetHeaders)(this);\n    }\n    assembleSelectionTopLevelSignals(signals) {\n        return this.child.assembleSelectionTopLevelSignals(signals);\n    }\n    assembleSignals() {\n        this.child.assembleSignals();\n        return [];\n    }\n    assembleSelectionData(data) {\n        return this.child.assembleSelectionData(data);\n    }\n    getHeaderLayoutMixins() {\n        const layoutMixins = {};\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            for (const headerType of _header_component__WEBPACK_IMPORTED_MODULE_17__.HEADER_TYPES) {\n                const layoutHeaderComponent = this.component.layoutHeaders[channel];\n                const headerComponent = layoutHeaderComponent[headerType];\n                const { facetFieldDef } = layoutHeaderComponent;\n                if (facetFieldDef) {\n                    const titleOrient = (0,_header_common__WEBPACK_IMPORTED_MODULE_16__.getHeaderProperty)('titleOrient', facetFieldDef.header, this.config, channel);\n                    if (['right', 'bottom'].includes(titleOrient)) {\n                        const headerChannel = (0,_header_common__WEBPACK_IMPORTED_MODULE_16__.getHeaderChannel)(channel, titleOrient);\n                        layoutMixins.titleAnchor ?? (layoutMixins.titleAnchor = {});\n                        layoutMixins.titleAnchor[headerChannel] = 'end';\n                    }\n                }\n                if (headerComponent?.[0]) {\n                    // set header/footerBand\n                    const sizeType = channel === 'row' ? 'height' : 'width';\n                    const bandType = headerType === 'header' ? 'headerBand' : 'footerBand';\n                    if (channel !== 'facet' && !this.child.component.layoutSize.get(sizeType)) {\n                        // If facet child does not have size signal, then apply headerBand\n                        layoutMixins[bandType] ?? (layoutMixins[bandType] = {});\n                        layoutMixins[bandType][channel] = 0.5;\n                    }\n                    if (layoutHeaderComponent.title) {\n                        layoutMixins.offset ?? (layoutMixins.offset = {});\n                        layoutMixins.offset[channel === 'row' ? 'rowTitle' : 'columnTitle'] = 10;\n                    }\n                }\n            }\n        }\n        return layoutMixins;\n    }\n    assembleDefaultLayout() {\n        const { column, row } = this.facet;\n        const columns = column ? this.columnDistinctSignal() : row ? 1 : undefined;\n        let align = 'all';\n        // Do not align the cells if the scale corresponding to the direction is indepent.\n        // We always align when we facet into both row and column.\n        if (!row && this.component.resolve.scale.x === 'independent') {\n            align = 'none';\n        }\n        else if (!column && this.component.resolve.scale.y === 'independent') {\n            align = 'none';\n        }\n        return {\n            ...this.getHeaderLayoutMixins(),\n            ...(columns ? { columns } : {}),\n            bounds: 'full',\n            align\n        };\n    }\n    assembleLayoutSignals() {\n        // FIXME(https://github.com/vega/vega-lite/issues/1193): this can be incorrect if we have independent scales.\n        return this.child.assembleLayoutSignals();\n    }\n    columnDistinctSignal() {\n        if (this.parent && this.parent instanceof FacetModel) {\n            // For nested facet, we will add columns to group mark instead\n            // See discussion in https://github.com/vega/vega/issues/952\n            // and https://github.com/vega/vega-view/releases/tag/v1.2.6\n            return undefined;\n        }\n        else {\n            // In facetNode.assemble(), the name is always this.getName('column') + '_layout'.\n            const facetLayoutDataName = this.getName('column_domain');\n            return { signal: `length(data('${facetLayoutDataName}'))` };\n        }\n    }\n    assembleGroupStyle() {\n        return undefined;\n    }\n    assembleGroup(signals) {\n        if (this.parent && this.parent instanceof FacetModel) {\n            // Provide number of columns for layout.\n            // See discussion in https://github.com/vega/vega/issues/952\n            // and https://github.com/vega/vega-view/releases/tag/v1.2.6\n            return {\n                ...(this.channelHasField('column')\n                    ? {\n                        encode: {\n                            update: {\n                                // TODO(https://github.com/vega/vega-lite/issues/2759):\n                                // Correct the signal for facet of concat of facet_column\n                                columns: { field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(this.facet.column, { prefix: 'distinct' }) }\n                            }\n                        }\n                    }\n                    : {}),\n                ...super.assembleGroup(signals)\n            };\n        }\n        return super.assembleGroup(signals);\n    }\n    /**\n     * Aggregate cardinality for calculating size\n     */\n    getCardinalityAggregateForChild() {\n        const fields = [];\n        const ops = [];\n        const as = [];\n        if (this.child instanceof FacetModel) {\n            if (this.child.channelHasField('column')) {\n                const field = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(this.child.facet.column);\n                fields.push(field);\n                ops.push('distinct');\n                as.push(`distinct_${field}`);\n            }\n        }\n        else {\n            for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.POSITION_SCALE_CHANNELS) {\n                const childScaleComponent = this.child.component.scales[channel];\n                if (childScaleComponent && !childScaleComponent.merged) {\n                    const type = childScaleComponent.get('type');\n                    const range = childScaleComponent.get('range');\n                    if ((0,_scale__WEBPACK_IMPORTED_MODULE_6__.hasDiscreteDomain)(type) && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_10__.isVgRangeStep)(range)) {\n                        const domain = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_21__.assembleDomain)(this.child, channel);\n                        const field = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_21__.getFieldFromDomain)(domain);\n                        if (field) {\n                            fields.push(field);\n                            ops.push('distinct');\n                            as.push(`distinct_${field}`);\n                        }\n                        else {\n                            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.unknownField(channel));\n                        }\n                    }\n                }\n            }\n        }\n        return { fields, ops, as };\n    }\n    assembleFacet() {\n        const { name, data } = this.component.data.facetRoot;\n        const { row, column } = this.facet;\n        const { fields, ops, as } = this.getCardinalityAggregateForChild();\n        const groupby = [];\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            const fieldDef = this.facet[channel];\n            if (fieldDef) {\n                groupby.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef));\n                const { bin, sort } = fieldDef;\n                if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(bin)) {\n                    groupby.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, { binSuffix: 'end' }));\n                }\n                if ((0,_sort__WEBPACK_IMPORTED_MODULE_7__.isSortField)(sort)) {\n                    const { field, op = _sort__WEBPACK_IMPORTED_MODULE_7__.DEFAULT_SORT_OP } = sort;\n                    const outputName = facetSortFieldName(fieldDef, sort);\n                    if (row && column) {\n                        // For crossed facet, use pre-calculate field as it requires a different groupby\n                        // For each calculated field, apply max and assign them to the same name as\n                        // all values of the same group should be the same anyway.\n                        fields.push(outputName);\n                        ops.push('max');\n                        as.push(outputName);\n                    }\n                    else {\n                        fields.push(field);\n                        ops.push(op);\n                        as.push(outputName);\n                    }\n                }\n                else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(sort)) {\n                    const outputName = (0,_data_calculate__WEBPACK_IMPORTED_MODULE_13__.sortArrayIndexField)(fieldDef, channel);\n                    fields.push(outputName);\n                    ops.push('max');\n                    as.push(outputName);\n                }\n            }\n        }\n        const cross = !!row && !!column;\n        return {\n            name,\n            data,\n            groupby,\n            ...(cross || fields.length > 0\n                ? {\n                    aggregate: {\n                        ...(cross ? { cross } : {}),\n                        ...(fields.length ? { fields, ops, as } : {})\n                    }\n                }\n                : {})\n        };\n    }\n    facetSortFields(channel) {\n        const { facet } = this;\n        const fieldDef = facet[channel];\n        if (fieldDef) {\n            if ((0,_sort__WEBPACK_IMPORTED_MODULE_7__.isSortField)(fieldDef.sort)) {\n                return [facetSortFieldName(fieldDef, fieldDef.sort, { expr: 'datum' })];\n            }\n            else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(fieldDef.sort)) {\n                return [(0,_data_calculate__WEBPACK_IMPORTED_MODULE_13__.sortArrayIndexField)(fieldDef, channel, { expr: 'datum' })];\n            }\n            return [(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, { expr: 'datum' })];\n        }\n        return [];\n    }\n    facetSortOrder(channel) {\n        const { facet } = this;\n        const fieldDef = facet[channel];\n        if (fieldDef) {\n            const { sort } = fieldDef;\n            const order = ((0,_sort__WEBPACK_IMPORTED_MODULE_7__.isSortField)(sort) ? sort.order : !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(sort) && sort) || 'ascending';\n            return [order];\n        }\n        return [];\n    }\n    assembleLabelTitle() {\n        const { facet, config } = this;\n        if (facet.facet) {\n            // Facet always uses title to display labels\n            return (0,_header_assemble__WEBPACK_IMPORTED_MODULE_15__.assembleLabelTitle)(facet.facet, 'facet', config);\n        }\n        const ORTHOGONAL_ORIENT = {\n            row: ['top', 'bottom'],\n            column: ['left', 'right']\n        };\n        for (const channel of _header_component__WEBPACK_IMPORTED_MODULE_17__.HEADER_CHANNELS) {\n            if (facet[channel]) {\n                const labelOrient = (0,_header_common__WEBPACK_IMPORTED_MODULE_16__.getHeaderProperty)('labelOrient', facet[channel]?.header, config, channel);\n                if (ORTHOGONAL_ORIENT[channel].includes(labelOrient)) {\n                    // Row/Column with orthogonal labelOrient must use title to display labels\n                    return (0,_header_assemble__WEBPACK_IMPORTED_MODULE_15__.assembleLabelTitle)(facet[channel], channel, config);\n                }\n            }\n        }\n        return undefined;\n    }\n    assembleMarks() {\n        const { child } = this;\n        // If we facet by two dimensions, we need to add a cross operator to the aggregation\n        // so that we create all groups\n        const facetRoot = this.component.data.facetRoot;\n        const data = (0,_data_assemble__WEBPACK_IMPORTED_MODULE_12__.assembleFacetData)(facetRoot);\n        const encodeEntry = child.assembleGroupEncodeEntry(false);\n        const title = this.assembleLabelTitle() || child.assembleTitle();\n        const style = child.assembleGroupStyle();\n        const markGroup = {\n            name: this.getName('cell'),\n            type: 'group',\n            ...(title ? { title } : {}),\n            ...(style ? { style } : {}),\n            from: {\n                facet: this.assembleFacet()\n            },\n            // TODO: move this to after data\n            sort: {\n                field: _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS.map(c => this.facetSortFields(c)).flat(),\n                order: _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS.map(c => this.facetSortOrder(c)).flat()\n            },\n            ...(data.length > 0 ? { data } : {}),\n            ...(encodeEntry ? { encode: { update: encodeEntry } } : {}),\n            ...child.assembleGroup((0,_selection_assemble__WEBPACK_IMPORTED_MODULE_22__.assembleFacetSignals)(this, []))\n        };\n        return [markGroup];\n    }\n    getMapping() {\n        return this.facet;\n    }\n}\n//# sourceMappingURL=facet.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/facet.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/format.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/format.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BIN_RANGE_DELIMITER: () => (/* binding */ BIN_RANGE_DELIMITER),\n/* harmony export */   binFormatExpression: () => (/* binding */ binFormatExpression),\n/* harmony export */   formatCustomType: () => (/* binding */ formatCustomType),\n/* harmony export */   formatSignalRef: () => (/* binding */ formatSignalRef),\n/* harmony export */   guideFormat: () => (/* binding */ guideFormat),\n/* harmony export */   guideFormatType: () => (/* binding */ guideFormatType),\n/* harmony export */   isCustomFormatType: () => (/* binding */ isCustomFormatType),\n/* harmony export */   numberFormat: () => (/* binding */ numberFormat),\n/* harmony export */   timeFormat: () => (/* binding */ timeFormat),\n/* harmony export */   timeFormatExpression: () => (/* binding */ timeFormatExpression)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _mark_encode_valueref__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./mark/encode/valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\n\n\n\n\n\n\n\n\nfunction isCustomFormatType(formatType) {\n    return formatType && formatType !== 'number' && formatType !== 'time';\n}\nfunction customFormatExpr(formatType, field, format) {\n    return `${formatType}(${field}${format ? `, ${(0,_util__WEBPACK_IMPORTED_MODULE_7__.stringify)(format)}` : ''})`;\n}\nconst BIN_RANGE_DELIMITER = ' \\u2013 ';\nfunction formatSignalRef({ fieldOrDatumDef, format, formatType, expr, normalizeStack, config }) {\n    if (isCustomFormatType(formatType)) {\n        return formatCustomType({\n            fieldOrDatumDef,\n            format,\n            formatType,\n            expr,\n            config\n        });\n    }\n    const field = fieldToFormat(fieldOrDatumDef, expr, normalizeStack);\n    const type = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.channelDefType)(fieldOrDatumDef);\n    if (format === undefined && formatType === undefined && config.customFormatTypes) {\n        if (type === 'quantitative') {\n            if (normalizeStack && config.normalizedNumberFormatType)\n                return formatCustomType({\n                    fieldOrDatumDef,\n                    format: config.normalizedNumberFormat,\n                    formatType: config.normalizedNumberFormatType,\n                    expr,\n                    config\n                });\n            if (config.numberFormatType) {\n                return formatCustomType({\n                    fieldOrDatumDef,\n                    format: config.numberFormat,\n                    formatType: config.numberFormatType,\n                    expr,\n                    config\n                });\n            }\n        }\n        if (type === 'temporal' &&\n            config.timeFormatType &&\n            (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) &&\n            fieldOrDatumDef.timeUnit === undefined) {\n            return formatCustomType({\n                fieldOrDatumDef,\n                format: config.timeFormat,\n                formatType: config.timeFormatType,\n                expr,\n                config\n            });\n        }\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldOrDatumDefForTimeFormat)(fieldOrDatumDef)) {\n        const signal = timeFormatExpression({\n            field,\n            timeUnit: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) ? (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.normalizeTimeUnit)(fieldOrDatumDef.timeUnit)?.unit : undefined,\n            format,\n            formatType: config.timeFormatType,\n            rawTimeFormat: config.timeFormat,\n            isUTCScale: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isScaleFieldDef)(fieldOrDatumDef) && fieldOrDatumDef.scale?.type === _scale__WEBPACK_IMPORTED_MODULE_4__.ScaleType.UTC\n        });\n        return signal ? { signal } : undefined;\n    }\n    format = numberFormat({ type, specifiedFormat: format, config, normalizeStack });\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) && (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldOrDatumDef.bin)) {\n        const endField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldOrDatumDef, { expr, binSuffix: 'end' });\n        return {\n            signal: binFormatExpression(field, endField, format, formatType, config)\n        };\n    }\n    else if (format || (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.channelDefType)(fieldOrDatumDef) === 'quantitative') {\n        return {\n            signal: `${formatExpr(field, format)}`\n        };\n    }\n    else {\n        return { signal: `isValid(${field}) ? ${field} : \"\"+${field}` };\n    }\n}\nfunction fieldToFormat(fieldOrDatumDef, expr, normalizeStack) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef)) {\n        if (normalizeStack) {\n            return `${(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldOrDatumDef, { expr, suffix: 'end' })}-${(0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldOrDatumDef, {\n                expr,\n                suffix: 'start'\n            })}`;\n        }\n        else {\n            return (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldOrDatumDef, { expr });\n        }\n    }\n    else {\n        return (0,_mark_encode_valueref__WEBPACK_IMPORTED_MODULE_9__.datumDefToExpr)(fieldOrDatumDef);\n    }\n}\nfunction formatCustomType({ fieldOrDatumDef, format, formatType, expr, normalizeStack, config, field }) {\n    field ?? (field = fieldToFormat(fieldOrDatumDef, expr, normalizeStack));\n    if (field !== 'datum.value' && // For axis/legend, we can't correctly know the end of the bin from `datum`\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) &&\n        (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldOrDatumDef.bin)) {\n        const endField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(fieldOrDatumDef, { expr, binSuffix: 'end' });\n        return {\n            signal: binFormatExpression(field, endField, format, formatType, config)\n        };\n    }\n    return { signal: customFormatExpr(formatType, field, format) };\n}\nfunction guideFormat(fieldOrDatumDef, type, format, formatType, config, omitTimeFormatConfig // axis doesn't use config.timeFormat\n) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(formatType) && isCustomFormatType(formatType)) {\n        return undefined; // handled in encode block\n    }\n    else if (format === undefined && formatType === undefined && config.customFormatTypes) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.channelDefType)(fieldOrDatumDef) === 'quantitative') {\n            if (config.normalizedNumberFormatType &&\n                (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isPositionFieldOrDatumDef)(fieldOrDatumDef) &&\n                fieldOrDatumDef.stack === 'normalize') {\n                return undefined; // handled in encode block\n            }\n            if (config.numberFormatType) {\n                return undefined; // handled in encode block\n            }\n        }\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isPositionFieldOrDatumDef)(fieldOrDatumDef) &&\n        fieldOrDatumDef.stack === 'normalize' &&\n        config.normalizedNumberFormat) {\n        return numberFormat({\n            type: 'quantitative',\n            config,\n            normalizeStack: true\n        });\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldOrDatumDefForTimeFormat)(fieldOrDatumDef)) {\n        const timeUnit = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) ? (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.normalizeTimeUnit)(fieldOrDatumDef.timeUnit)?.unit : undefined;\n        if (timeUnit === undefined && config.customFormatTypes && config.timeFormatType) {\n            return undefined; // hanlded in encode block\n        }\n        return timeFormat({ specifiedFormat: format, timeUnit, config, omitTimeFormatConfig });\n    }\n    return numberFormat({ type, specifiedFormat: format, config });\n}\nfunction guideFormatType(formatType, fieldOrDatumDef, scaleType) {\n    if (formatType && ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(formatType) || formatType === 'number' || formatType === 'time')) {\n        return formatType;\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldOrDatumDefForTimeFormat)(fieldOrDatumDef) && scaleType !== 'time' && scaleType !== 'utc') {\n        return (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) && (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.normalizeTimeUnit)(fieldOrDatumDef?.timeUnit)?.utc ? 'utc' : 'time';\n    }\n    return undefined;\n}\n/**\n * Returns number format for a fieldDef.\n */\nfunction numberFormat({ type, specifiedFormat, config, normalizeStack }) {\n    // Specified format in axis/legend has higher precedence than fieldDef.format\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(specifiedFormat)) {\n        return specifiedFormat;\n    }\n    if (type === _type__WEBPACK_IMPORTED_MODULE_6__.QUANTITATIVE) {\n        // we only apply the default if the field is quantitative\n        return normalizeStack ? config.normalizedNumberFormat : config.numberFormat;\n    }\n    return undefined;\n}\n/**\n * Returns time format for a fieldDef for use in guides.\n */\nfunction timeFormat({ specifiedFormat, timeUnit, config, omitTimeFormatConfig }) {\n    if (specifiedFormat) {\n        return specifiedFormat;\n    }\n    if (timeUnit) {\n        return {\n            signal: (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.timeUnitSpecifierExpression)(timeUnit)\n        };\n    }\n    return omitTimeFormatConfig ? undefined : config.timeFormat;\n}\nfunction formatExpr(field, format) {\n    return `format(${field}, \"${format || ''}\")`;\n}\nfunction binNumberFormatExpr(field, format, formatType, config) {\n    if (isCustomFormatType(formatType)) {\n        return customFormatExpr(formatType, field, format);\n    }\n    return formatExpr(field, ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(format) ? format : undefined) ?? config.numberFormat);\n}\nfunction binFormatExpression(startField, endField, format, formatType, config) {\n    if (format === undefined && formatType === undefined && config.customFormatTypes && config.numberFormatType) {\n        return binFormatExpression(startField, endField, config.numberFormat, config.numberFormatType, config);\n    }\n    const start = binNumberFormatExpr(startField, format, formatType, config);\n    const end = binNumberFormatExpr(endField, format, formatType, config);\n    return `${(0,_predicate__WEBPACK_IMPORTED_MODULE_3__.fieldValidPredicate)(startField, false)} ? \"null\" : ${start} + \"${BIN_RANGE_DELIMITER}\" + ${end}`;\n}\n/**\n * Returns the time expression used for axis/legend labels or text mark for a temporal field\n */\nfunction timeFormatExpression({ field, timeUnit, format, formatType, rawTimeFormat, isUTCScale }) {\n    if (!timeUnit || format) {\n        // If there is no time unit, or if user explicitly specifies format for axis/legend/text.\n        if (!timeUnit && formatType) {\n            return `${formatType}(${field}, '${format}')`;\n        }\n        format = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(format) ? format : rawTimeFormat; // only use provided timeFormat if there is no timeUnit.\n        return `${isUTCScale ? 'utc' : 'time'}Format(${field}, '${format}')`;\n    }\n    else {\n        return (0,_timeunit__WEBPACK_IMPORTED_MODULE_5__.formatExpression)(timeUnit, field, isUTCScale);\n    }\n}\n//# sourceMappingURL=format.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/format.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/guide.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/guide.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   guideEncodeEntry: () => (/* binding */ guideEncodeEntry)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _mark_encode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mark/encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\n\n\nfunction guideEncodeEntry(encoding, model) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(encoding).reduce((encode, channel) => {\n        const valueDef = encoding[channel];\n        return {\n            ...encode,\n            ...(0,_mark_encode__WEBPACK_IMPORTED_MODULE_2__.wrapCondition)(model, valueDef, channel, def => (0,_common__WEBPACK_IMPORTED_MODULE_1__.signalOrValueRef)(def.value))\n        };\n    }, {});\n}\n//# sourceMappingURL=guide.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/guide.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/header/assemble.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/header/assemble.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleHeaderGroup: () => (/* binding */ assembleHeaderGroup),\n/* harmony export */   assembleHeaderGroups: () => (/* binding */ assembleHeaderGroups),\n/* harmony export */   assembleHeaderProperties: () => (/* binding */ assembleHeaderProperties),\n/* harmony export */   assembleLabelTitle: () => (/* binding */ assembleLabelTitle),\n/* harmony export */   assembleLayoutTitleBand: () => (/* binding */ assembleLayoutTitleBand),\n/* harmony export */   assembleTitleGroup: () => (/* binding */ assembleTitleGroup),\n/* harmony export */   defaultHeaderGuideAlign: () => (/* binding */ defaultHeaderGuideAlign),\n/* harmony export */   defaultHeaderGuideBaseline: () => (/* binding */ defaultHeaderGuideBaseline),\n/* harmony export */   getLayoutTitleBand: () => (/* binding */ getLayoutTitleBand)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _header__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../header */ \"../../node_modules/vega-lite/build/src/header.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _spec_facet__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../spec/facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _axis_properties__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../axis/properties */ \"../../node_modules/vega-lite/build/src/compile/axis/properties.js\");\n/* harmony import */ var _data_calculate__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../data/calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compile/header/common.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/header/component.js\");\n/**\n * Utility for generating row / column headers\n */\n\n\n\n\n\n\n\n\n\n\n\n\n\n// TODO: rename to assembleHeaderTitleGroup\nfunction assembleTitleGroup(model, channel) {\n    const title = model.component.layoutHeaders[channel].title;\n    const config = model.config ? model.config : undefined;\n    const facetFieldDef = model.component.layoutHeaders[channel].facetFieldDef\n        ? model.component.layoutHeaders[channel].facetFieldDef\n        : undefined;\n    const { titleAnchor, titleAngle: ta, titleOrient } = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderProperties)(['titleAnchor', 'titleAngle', 'titleOrient'], facetFieldDef.header, config, channel);\n    const headerChannel = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderChannel)(channel, titleOrient);\n    const titleAngle = (0,_util__WEBPACK_IMPORTED_MODULE_6__.normalizeAngle)(ta);\n    return {\n        name: `${channel}-title`,\n        type: 'group',\n        role: `${headerChannel}-title`,\n        title: {\n            text: title,\n            ...(channel === 'row' ? { orient: 'left' } : {}),\n            style: 'guide-title',\n            ...defaultHeaderGuideBaseline(titleAngle, headerChannel),\n            ...defaultHeaderGuideAlign(headerChannel, titleAngle, titleAnchor),\n            ...assembleHeaderProperties(config, facetFieldDef, channel, _header__WEBPACK_IMPORTED_MODULE_3__.HEADER_TITLE_PROPERTIES, _header__WEBPACK_IMPORTED_MODULE_3__.HEADER_TITLE_PROPERTIES_MAP)\n        }\n    };\n}\nfunction defaultHeaderGuideAlign(headerChannel, angle, anchor = 'middle') {\n    switch (anchor) {\n        case 'start':\n            return { align: 'left' };\n        case 'end':\n            return { align: 'right' };\n    }\n    const align = (0,_axis_properties__WEBPACK_IMPORTED_MODULE_7__.defaultLabelAlign)(angle, headerChannel === 'row' ? 'left' : 'top', headerChannel === 'row' ? 'y' : 'x');\n    return align ? { align } : {};\n}\nfunction defaultHeaderGuideBaseline(angle, channel) {\n    const baseline = (0,_axis_properties__WEBPACK_IMPORTED_MODULE_7__.defaultLabelBaseline)(angle, channel === 'row' ? 'left' : 'top', channel === 'row' ? 'y' : 'x', true);\n    return baseline ? { baseline } : {};\n}\nfunction assembleHeaderGroups(model, channel) {\n    const layoutHeader = model.component.layoutHeaders[channel];\n    const groups = [];\n    for (const headerType of _component__WEBPACK_IMPORTED_MODULE_12__.HEADER_TYPES) {\n        if (layoutHeader[headerType]) {\n            for (const headerComponent of layoutHeader[headerType]) {\n                const group = assembleHeaderGroup(model, channel, headerType, layoutHeader, headerComponent);\n                if (group != null) {\n                    groups.push(group);\n                }\n            }\n        }\n    }\n    return groups;\n}\nfunction getSort(facetFieldDef, channel) {\n    const { sort } = facetFieldDef;\n    if ((0,_sort__WEBPACK_IMPORTED_MODULE_4__.isSortField)(sort)) {\n        return {\n            field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(sort, { expr: 'datum' }),\n            order: sort.order ?? 'ascending'\n        };\n    }\n    else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(sort)) {\n        return {\n            field: (0,_data_calculate__WEBPACK_IMPORTED_MODULE_8__.sortArrayIndexField)(facetFieldDef, channel, { expr: 'datum' }),\n            order: 'ascending'\n        };\n    }\n    else {\n        return {\n            field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(facetFieldDef, { expr: 'datum' }),\n            order: sort ?? 'ascending'\n        };\n    }\n}\nfunction assembleLabelTitle(facetFieldDef, channel, config) {\n    const { format, formatType, labelAngle, labelAnchor, labelOrient, labelExpr } = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderProperties)(['format', 'formatType', 'labelAngle', 'labelAnchor', 'labelOrient', 'labelExpr'], facetFieldDef.header, config, channel);\n    const titleTextExpr = (0,_format__WEBPACK_IMPORTED_MODULE_9__.formatSignalRef)({\n        fieldOrDatumDef: facetFieldDef,\n        format,\n        formatType,\n        expr: 'parent',\n        config\n    }).signal;\n    const headerChannel = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderChannel)(channel, labelOrient);\n    return {\n        text: {\n            signal: labelExpr\n                ? (0,_util__WEBPACK_IMPORTED_MODULE_6__.replaceAll)((0,_util__WEBPACK_IMPORTED_MODULE_6__.replaceAll)(labelExpr, 'datum.label', titleTextExpr), 'datum.value', (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.vgField)(facetFieldDef, { expr: 'parent' }))\n                : titleTextExpr\n        },\n        ...(channel === 'row' ? { orient: 'left' } : {}),\n        style: 'guide-label',\n        frame: 'group',\n        ...defaultHeaderGuideBaseline(labelAngle, headerChannel),\n        ...defaultHeaderGuideAlign(headerChannel, labelAngle, labelAnchor),\n        ...assembleHeaderProperties(config, facetFieldDef, channel, _header__WEBPACK_IMPORTED_MODULE_3__.HEADER_LABEL_PROPERTIES, _header__WEBPACK_IMPORTED_MODULE_3__.HEADER_LABEL_PROPERTIES_MAP)\n    };\n}\nfunction assembleHeaderGroup(model, channel, headerType, layoutHeader, headerComponent) {\n    if (headerComponent) {\n        let title = null;\n        const { facetFieldDef } = layoutHeader;\n        const config = model.config ? model.config : undefined;\n        if (facetFieldDef && headerComponent.labels) {\n            const { labelOrient } = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderProperties)(['labelOrient'], facetFieldDef.header, config, channel);\n            // Include label title in the header if orient aligns with the channel\n            if ((channel === 'row' && !(0,_util__WEBPACK_IMPORTED_MODULE_6__.contains)(['top', 'bottom'], labelOrient)) ||\n                (channel === 'column' && !(0,_util__WEBPACK_IMPORTED_MODULE_6__.contains)(['left', 'right'], labelOrient))) {\n                title = assembleLabelTitle(facetFieldDef, channel, config);\n            }\n        }\n        const isFacetWithoutRowCol = (0,_model__WEBPACK_IMPORTED_MODULE_10__.isFacetModel)(model) && !(0,_spec_facet__WEBPACK_IMPORTED_MODULE_5__.isFacetMapping)(model.facet);\n        const axes = headerComponent.axes;\n        const hasAxes = axes?.length > 0;\n        if (title || hasAxes) {\n            const sizeChannel = channel === 'row' ? 'height' : 'width';\n            return {\n                name: model.getName(`${channel}_${headerType}`),\n                type: 'group',\n                role: `${channel}-${headerType}`,\n                ...(layoutHeader.facetFieldDef\n                    ? {\n                        from: { data: model.getName(`${channel}_domain`) },\n                        sort: getSort(facetFieldDef, channel)\n                    }\n                    : {}),\n                ...(hasAxes && isFacetWithoutRowCol\n                    ? {\n                        from: { data: model.getName(`facet_domain_${channel}`) }\n                    }\n                    : {}),\n                ...(title ? { title } : {}),\n                ...(headerComponent.sizeSignal\n                    ? {\n                        encode: {\n                            update: {\n                                [sizeChannel]: headerComponent.sizeSignal\n                            }\n                        }\n                    }\n                    : {}),\n                ...(hasAxes ? { axes } : {})\n            };\n        }\n    }\n    return null;\n}\nconst LAYOUT_TITLE_BAND = {\n    column: {\n        start: 0,\n        end: 1\n    },\n    row: {\n        start: 1,\n        end: 0\n    }\n};\nfunction getLayoutTitleBand(titleAnchor, headerChannel) {\n    return LAYOUT_TITLE_BAND[headerChannel][titleAnchor];\n}\nfunction assembleLayoutTitleBand(headerComponentIndex, config) {\n    const titleBand = {};\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_1__.FACET_CHANNELS) {\n        const headerComponent = headerComponentIndex[channel];\n        if (headerComponent?.facetFieldDef) {\n            const { titleAnchor, titleOrient } = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderProperties)(['titleAnchor', 'titleOrient'], headerComponent.facetFieldDef.header, config, channel);\n            const headerChannel = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderChannel)(channel, titleOrient);\n            const band = getLayoutTitleBand(titleAnchor, headerChannel);\n            if (band !== undefined) {\n                titleBand[headerChannel] = band;\n            }\n        }\n    }\n    return (0,_util__WEBPACK_IMPORTED_MODULE_6__.isEmpty)(titleBand) ? undefined : titleBand;\n}\nfunction assembleHeaderProperties(config, facetFieldDef, channel, properties, propertiesMap) {\n    const props = {};\n    for (const prop of properties) {\n        if (!propertiesMap[prop]) {\n            continue;\n        }\n        const value = (0,_common__WEBPACK_IMPORTED_MODULE_11__.getHeaderProperty)(prop, facetFieldDef?.header, config, channel);\n        if (value !== undefined) {\n            props[propertiesMap[prop]] = value;\n        }\n    }\n    return props;\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/header/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/header/common.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/header/common.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getHeaderChannel: () => (/* binding */ getHeaderChannel),\n/* harmony export */   getHeaderProperties: () => (/* binding */ getHeaderProperties),\n/* harmony export */   getHeaderProperty: () => (/* binding */ getHeaderProperty)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n/**\n * Get header channel, which can be different from facet channel when orient is specified or when the facet channel is facet.\n */\nfunction getHeaderChannel(channel, orient) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_0__.contains)(['top', 'bottom'], orient)) {\n        return 'column';\n    }\n    else if ((0,_util__WEBPACK_IMPORTED_MODULE_0__.contains)(['left', 'right'], orient)) {\n        return 'row';\n    }\n    return channel === 'row' ? 'row' : 'column';\n}\nfunction getHeaderProperty(prop, header, config, channel) {\n    const headerSpecificConfig = channel === 'row' ? config.headerRow : channel === 'column' ? config.headerColumn : config.headerFacet;\n    return (0,_util__WEBPACK_IMPORTED_MODULE_0__.getFirstDefined)((header || {})[prop], headerSpecificConfig[prop], config.header[prop]);\n}\nfunction getHeaderProperties(properties, header, config, channel) {\n    const props = {};\n    for (const prop of properties) {\n        const value = getHeaderProperty(prop, header || {}, config, channel);\n        if (value !== undefined) {\n            props[prop] = value;\n        }\n    }\n    return props;\n}\n//# sourceMappingURL=common.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/header/common.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/header/component.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/header/component.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   HEADER_CHANNELS: () => (/* binding */ HEADER_CHANNELS),\n/* harmony export */   HEADER_TYPES: () => (/* binding */ HEADER_TYPES)\n/* harmony export */ });\nconst HEADER_CHANNELS = ['row', 'column'];\nconst HEADER_TYPES = ['header', 'footer'];\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/header/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/header/parse.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/header/parse.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getHeaderType: () => (/* binding */ getHeaderType),\n/* harmony export */   parseFacetHeaders: () => (/* binding */ parseFacetHeaders)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _axis_assemble__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../axis/assemble */ \"../../node_modules/vega-lite/build/src/compile/axis/assemble.js\");\n/* harmony import */ var _resolve__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../resolve */ \"../../node_modules/vega-lite/build/src/compile/resolve.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compile/header/common.js\");\n\n\n\n\n\n\n\n\nfunction getHeaderType(orient) {\n    if (orient === 'top' || orient === 'left' || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(orient)) {\n        // we always use header for orient signal since we can't dynamically make header becomes footer\n        return 'header';\n    }\n    return 'footer';\n}\nfunction parseFacetHeaders(model) {\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_1__.FACET_CHANNELS) {\n        parseFacetHeader(model, channel);\n    }\n    mergeChildAxis(model, 'x');\n    mergeChildAxis(model, 'y');\n}\nfunction parseFacetHeader(model, channel) {\n    const { facet, config, child, component } = model;\n    if (model.channelHasField(channel)) {\n        const fieldDef = facet[channel];\n        const titleConfig = (0,_common__WEBPACK_IMPORTED_MODULE_7__.getHeaderProperty)('title', null, config, channel);\n        let title = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.title)(fieldDef, config, {\n            allowDisabling: true,\n            includeDefault: titleConfig === undefined || !!titleConfig\n        });\n        if (child.component.layoutHeaders[channel].title) {\n            // TODO: better handle multiline titles\n            title = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(title) ? title.join(', ') : title;\n            // merge title with child to produce \"Title / Subtitle / Sub-subtitle\"\n            title += ` / ${child.component.layoutHeaders[channel].title}`;\n            child.component.layoutHeaders[channel].title = null;\n        }\n        const labelOrient = (0,_common__WEBPACK_IMPORTED_MODULE_7__.getHeaderProperty)('labelOrient', fieldDef.header, config, channel);\n        const labels = fieldDef.header !== null ? (0,_util__WEBPACK_IMPORTED_MODULE_3__.getFirstDefined)(fieldDef.header?.labels, config.header.labels, true) : false;\n        const headerType = (0,_util__WEBPACK_IMPORTED_MODULE_3__.contains)(['bottom', 'right'], labelOrient) ? 'footer' : 'header';\n        component.layoutHeaders[channel] = {\n            title: fieldDef.header !== null ? title : null,\n            facetFieldDef: fieldDef,\n            [headerType]: channel === 'facet' ? [] : [makeHeaderComponent(model, channel, labels)]\n        };\n    }\n}\nfunction makeHeaderComponent(model, channel, labels) {\n    const sizeType = channel === 'row' ? 'height' : 'width';\n    return {\n        labels,\n        sizeSignal: model.child.component.layoutSize.get(sizeType) ? model.child.getSizeSignalRef(sizeType) : undefined,\n        axes: []\n    };\n}\nfunction mergeChildAxis(model, channel) {\n    const { child } = model;\n    if (child.component.axes[channel]) {\n        const { layoutHeaders, resolve } = model.component;\n        resolve.axis[channel] = (0,_resolve__WEBPACK_IMPORTED_MODULE_6__.parseGuideResolve)(resolve, channel);\n        if (resolve.axis[channel] === 'shared') {\n            // For shared axis, move the axes to facet's header or footer\n            const headerChannel = channel === 'x' ? 'column' : 'row';\n            const layoutHeader = layoutHeaders[headerChannel];\n            for (const axisComponent of child.component.axes[channel]) {\n                const headerType = getHeaderType(axisComponent.get('orient'));\n                layoutHeader[headerType] ?? (layoutHeader[headerType] = [makeHeaderComponent(model, headerChannel, false)]);\n                // FIXME: assemble shouldn't be called here, but we do it this way so we only extract the main part of the axes\n                const mainAxis = (0,_axis_assemble__WEBPACK_IMPORTED_MODULE_5__.assembleAxis)(axisComponent, 'main', model.config, { header: true });\n                if (mainAxis) {\n                    // LayoutHeader no longer keep track of property precedence, thus let's combine.\n                    layoutHeader[headerType][0].axes.push(mainAxis);\n                }\n                axisComponent.mainExtracted = true;\n            }\n        }\n        else {\n            // Otherwise do nothing for independent axes\n        }\n    }\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/header/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/layer.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/layer.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   LayerModel: () => (/* binding */ LayerModel)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _axis_assemble__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./axis/assemble */ \"../../node_modules/vega-lite/build/src/compile/axis/assemble.js\");\n/* harmony import */ var _axis_parse__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./axis/parse */ \"../../node_modules/vega-lite/build/src/compile/axis/parse.js\");\n/* harmony import */ var _data_parse__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./data/parse */ \"../../node_modules/vega-lite/build/src/compile/data/parse.js\");\n/* harmony import */ var _layoutsize_assemble__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./layoutsize/assemble */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js\");\n/* harmony import */ var _layoutsize_parse__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./layoutsize/parse */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js\");\n/* harmony import */ var _legend_assemble__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./legend/assemble */ \"../../node_modules/vega-lite/build/src/compile/legend/assemble.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _selection_assemble__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./selection/assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _unit__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./unit */ \"../../node_modules/vega-lite/build/src/compile/unit.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\nclass LayerModel extends _model__WEBPACK_IMPORTED_MODULE_10__.Model {\n    constructor(spec, parent, parentGivenName, parentGivenSize, config) {\n        super(spec, 'layer', parent, parentGivenName, config, spec.resolve, spec.view);\n        const layoutSize = {\n            ...parentGivenSize,\n            ...(spec.width ? { width: spec.width } : {}),\n            ...(spec.height ? { height: spec.height } : {})\n        };\n        this.children = spec.layer.map((layer, i) => {\n            if ((0,_spec__WEBPACK_IMPORTED_MODULE_2__.isLayerSpec)(layer)) {\n                return new LayerModel(layer, this, this.getName(`layer_${i}`), layoutSize, config);\n            }\n            else if ((0,_spec__WEBPACK_IMPORTED_MODULE_2__.isUnitSpec)(layer)) {\n                return new _unit__WEBPACK_IMPORTED_MODULE_12__.UnitModel(layer, this, this.getName(`layer_${i}`), layoutSize, config);\n            }\n            throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.invalidSpec(layer));\n        });\n    }\n    parseData() {\n        this.component.data = (0,_data_parse__WEBPACK_IMPORTED_MODULE_6__.parseData)(this);\n        for (const child of this.children) {\n            child.parseData();\n        }\n    }\n    parseLayoutSize() {\n        (0,_layoutsize_parse__WEBPACK_IMPORTED_MODULE_8__.parseLayerLayoutSize)(this);\n    }\n    parseSelections() {\n        // Merge selections up the hierarchy so that they may be referenced\n        // across unit specs. Persist their definitions within each child\n        // to assemble signals which remain within output Vega unit groups.\n        this.component.selection = {};\n        for (const child of this.children) {\n            child.parseSelections();\n            for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_3__.keys)(child.component.selection)) {\n                this.component.selection[key] = child.component.selection[key];\n            }\n        }\n    }\n    parseMarkGroup() {\n        for (const child of this.children) {\n            child.parseMarkGroup();\n        }\n    }\n    parseAxesAndHeaders() {\n        (0,_axis_parse__WEBPACK_IMPORTED_MODULE_5__.parseLayerAxes)(this);\n    }\n    assembleSelectionTopLevelSignals(signals) {\n        return this.children.reduce((sg, child) => child.assembleSelectionTopLevelSignals(sg), signals);\n    }\n    // TODO: Support same named selections across children.\n    assembleSignals() {\n        return this.children.reduce((signals, child) => {\n            return signals.concat(child.assembleSignals());\n        }, (0,_axis_assemble__WEBPACK_IMPORTED_MODULE_4__.assembleAxisSignals)(this));\n    }\n    assembleLayoutSignals() {\n        return this.children.reduce((signals, child) => {\n            return signals.concat(child.assembleLayoutSignals());\n        }, (0,_layoutsize_assemble__WEBPACK_IMPORTED_MODULE_7__.assembleLayoutSignals)(this));\n    }\n    assembleSelectionData(data) {\n        return this.children.reduce((db, child) => child.assembleSelectionData(db), data);\n    }\n    assembleGroupStyle() {\n        const uniqueStyles = new Set();\n        for (const child of this.children) {\n            for (const style of (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(child.assembleGroupStyle())) {\n                uniqueStyles.add(style);\n            }\n        }\n        const styles = Array.from(uniqueStyles);\n        return styles.length > 1 ? styles : styles.length === 1 ? styles[0] : undefined;\n    }\n    assembleTitle() {\n        let title = super.assembleTitle();\n        if (title) {\n            return title;\n        }\n        // If title does not provide layer, look into children\n        for (const child of this.children) {\n            title = child.assembleTitle();\n            if (title) {\n                return title;\n            }\n        }\n        return undefined;\n    }\n    assembleLayout() {\n        return null;\n    }\n    assembleMarks() {\n        return (0,_selection_assemble__WEBPACK_IMPORTED_MODULE_11__.assembleLayerSelectionMarks)(this, this.children.flatMap(child => {\n            return child.assembleMarks();\n        }));\n    }\n    assembleLegends() {\n        return this.children.reduce((legends, child) => {\n            return legends.concat(child.assembleLegends());\n        }, (0,_legend_assemble__WEBPACK_IMPORTED_MODULE_9__.assembleLegends)(this));\n    }\n}\n//# sourceMappingURL=layer.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/layer.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleLayoutSignals: () => (/* binding */ assembleLayoutSignals),\n/* harmony export */   sizeExpr: () => (/* binding */ sizeExpr),\n/* harmony export */   sizeSignals: () => (/* binding */ sizeSignals)\n/* harmony export */ });\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n\n\n\n\n\n\nfunction assembleLayoutSignals(model) {\n    return [\n        ...sizeSignals(model, 'width'),\n        ...sizeSignals(model, 'height'),\n        ...sizeSignals(model, 'childWidth'),\n        ...sizeSignals(model, 'childHeight')\n    ];\n}\nfunction sizeSignals(model, sizeType) {\n    const channel = sizeType === 'width' ? 'x' : 'y';\n    const size = model.component.layoutSize.get(sizeType);\n    if (!size || size === 'merged') {\n        return [];\n    }\n    // Read size signal name from name map, just in case it is the top-level size signal that got renamed.\n    const name = model.getSizeSignalRef(sizeType).signal;\n    if (size === 'step') {\n        const scaleComponent = model.getScaleComponent(channel);\n        if (scaleComponent) {\n            const type = scaleComponent.get('type');\n            const range = scaleComponent.get('range');\n            if ((0,_scale__WEBPACK_IMPORTED_MODULE_1__.hasDiscreteDomain)(type) && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_3__.isVgRangeStep)(range)) {\n                const scaleName = model.scaleName(channel);\n                if ((0,_model__WEBPACK_IMPORTED_MODULE_5__.isFacetModel)(model.parent)) {\n                    // If parent is facet and this is an independent scale, return only signal signal\n                    // as the width/height will be calculated using the cardinality from\n                    // facet's aggregate rather than reading from scale domain\n                    const parentResolve = model.parent.component.resolve;\n                    if (parentResolve.scale[channel] === 'independent') {\n                        return [stepSignal(scaleName, range)];\n                    }\n                }\n                return [\n                    stepSignal(scaleName, range),\n                    {\n                        name,\n                        update: sizeExpr(scaleName, scaleComponent, `domain('${scaleName}').length`)\n                    }\n                ];\n            }\n        }\n        /* istanbul ignore next: Condition should not happen -- only for warning in development. */\n        throw new Error('layout size is step although width/height is not step.');\n    }\n    else if (size == 'container') {\n        const isWidth = name.endsWith('width');\n        const expr = isWidth ? 'containerSize()[0]' : 'containerSize()[1]';\n        const defaultValue = (0,_config__WEBPACK_IMPORTED_MODULE_0__.getViewConfigContinuousSize)(model.config.view, isWidth ? 'width' : 'height');\n        const safeExpr = `isFinite(${expr}) ? ${expr} : ${defaultValue}`;\n        return [{ name, init: safeExpr, on: [{ update: safeExpr, events: 'window:resize' }] }];\n    }\n    else {\n        return [\n            {\n                name,\n                value: size\n            }\n        ];\n    }\n}\nfunction stepSignal(scaleName, range) {\n    const name = `${scaleName}_step`;\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_3__.isSignalRef)(range.step)) {\n        return { name, update: range.step.signal };\n    }\n    else {\n        return { name, value: range.step };\n    }\n}\nfunction sizeExpr(scaleName, scaleComponent, cardinality) {\n    const type = scaleComponent.get('type');\n    const padding = scaleComponent.get('padding');\n    const paddingOuter = (0,_util__WEBPACK_IMPORTED_MODULE_2__.getFirstDefined)(scaleComponent.get('paddingOuter'), padding);\n    let paddingInner = scaleComponent.get('paddingInner');\n    paddingInner =\n        type === 'band'\n            ? // only band has real paddingInner\n                paddingInner !== undefined\n                    ? paddingInner\n                    : padding\n            : // For point, as calculated in https://github.com/vega/vega-scale/blob/master/src/band.js#L128,\n                // it's equivalent to have paddingInner = 1 since there is only n-1 steps between n points.\n                1;\n    return `bandspace(${cardinality}, ${(0,_common__WEBPACK_IMPORTED_MODULE_4__.signalOrStringValue)(paddingInner)}, ${(0,_common__WEBPACK_IMPORTED_MODULE_4__.signalOrStringValue)(paddingOuter)}) * ${scaleName}_step`;\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/layoutsize/component.js":
/*!******************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/layoutsize/component.js ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getSizeTypeFromLayoutSizeType: () => (/* binding */ getSizeTypeFromLayoutSizeType)\n/* harmony export */ });\nfunction getSizeTypeFromLayoutSizeType(layoutSizeType) {\n    return layoutSizeType === 'childWidth' ? 'width' : layoutSizeType === 'childHeight' ? 'height' : layoutSizeType;\n}\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/layoutsize/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/layoutsize/init.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/layoutsize/init.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   initLayoutSize: () => (/* binding */ initLayoutSize)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n\n\n\n\nfunction initLayoutSize({ encoding, size }) {\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_0__.POSITION_SCALE_CHANNELS) {\n        const sizeType = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n        if ((0,_spec_base__WEBPACK_IMPORTED_MODULE_3__.isStep)(size[sizeType])) {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isContinuousFieldOrDatumDef)(encoding[channel])) {\n                delete size[sizeType];\n                _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.stepDropped(sizeType));\n            }\n        }\n    }\n    return size;\n}\n//# sourceMappingURL=init.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/layoutsize/init.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseChildrenLayoutSize: () => (/* binding */ parseChildrenLayoutSize),\n/* harmony export */   parseConcatLayoutSize: () => (/* binding */ parseConcatLayoutSize),\n/* harmony export */   parseLayerLayoutSize: () => (/* binding */ parseLayerLayoutSize),\n/* harmony export */   parseUnitLayoutSize: () => (/* binding */ parseUnitLayoutSize)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _resolve__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../resolve */ \"../../node_modules/vega-lite/build/src/compile/resolve.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/component.js\");\n\n\n\n\n\n\n\n\nfunction parseLayerLayoutSize(model) {\n    parseChildrenLayoutSize(model);\n    parseNonUnitLayoutSizeForChannel(model, 'width');\n    parseNonUnitLayoutSizeForChannel(model, 'height');\n}\nfunction parseConcatLayoutSize(model) {\n    parseChildrenLayoutSize(model);\n    // for columns === 1 (vconcat), we can completely merge width. Otherwise, we can treat merged width as childWidth.\n    const widthType = model.layout.columns === 1 ? 'width' : 'childWidth';\n    // for columns === undefined (hconcat), we can completely merge height. Otherwise, we can treat merged height as childHeight.\n    const heightType = model.layout.columns === undefined ? 'height' : 'childHeight';\n    parseNonUnitLayoutSizeForChannel(model, widthType);\n    parseNonUnitLayoutSizeForChannel(model, heightType);\n}\nfunction parseChildrenLayoutSize(model) {\n    for (const child of model.children) {\n        child.parseLayoutSize();\n    }\n}\n/**\n * Merge child layout size (width or height).\n */\nfunction parseNonUnitLayoutSizeForChannel(model, layoutSizeType) {\n    /*\n     * For concat, the parent width or height might not be the same as the children's shared height.\n     * For example, hconcat's subviews may share width, but the shared width is not the hconcat view's width.\n     *\n     * layoutSizeType represents the output of the view (could be childWidth/childHeight/width/height)\n     * while the sizeType represents the properties of the child.\n     */\n    const sizeType = (0,_component__WEBPACK_IMPORTED_MODULE_7__.getSizeTypeFromLayoutSizeType)(layoutSizeType);\n    const channel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getPositionScaleChannel)(sizeType);\n    const resolve = model.component.resolve;\n    const layoutSizeCmpt = model.component.layoutSize;\n    let mergedSize;\n    // Try to merge layout size\n    for (const child of model.children) {\n        const childSize = child.component.layoutSize.getWithExplicit(sizeType);\n        const scaleResolve = resolve.scale[channel] ?? (0,_resolve__WEBPACK_IMPORTED_MODULE_5__.defaultScaleResolve)(channel, model);\n        if (scaleResolve === 'independent' && childSize.value === 'step') {\n            // Do not merge independent scales with range-step as their size depends\n            // on the scale domains, which can be different between scales.\n            mergedSize = undefined;\n            break;\n        }\n        if (mergedSize) {\n            if (scaleResolve === 'independent' && mergedSize.value !== childSize.value) {\n                // For independent scale, only merge if all the sizes are the same.\n                // If the values are different, abandon the merge!\n                mergedSize = undefined;\n                break;\n            }\n            mergedSize = (0,_split__WEBPACK_IMPORTED_MODULE_6__.mergeValuesWithExplicit)(mergedSize, childSize, sizeType, '');\n        }\n        else {\n            mergedSize = childSize;\n        }\n    }\n    if (mergedSize) {\n        // If merged, rename size and set size of all children.\n        for (const child of model.children) {\n            model.renameSignal(child.getName(sizeType), model.getName(layoutSizeType));\n            child.component.layoutSize.set(sizeType, 'merged', false);\n        }\n        layoutSizeCmpt.setWithExplicit(layoutSizeType, mergedSize);\n    }\n    else {\n        layoutSizeCmpt.setWithExplicit(layoutSizeType, {\n            explicit: false,\n            value: undefined\n        });\n    }\n}\nfunction parseUnitLayoutSize(model) {\n    const { size, component } = model;\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_0__.POSITION_SCALE_CHANNELS) {\n        const sizeType = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n        if (size[sizeType]) {\n            const specifiedSize = size[sizeType];\n            component.layoutSize.set(sizeType, (0,_spec_base__WEBPACK_IMPORTED_MODULE_3__.isStep)(specifiedSize) ? 'step' : specifiedSize, true);\n        }\n        else {\n            const defaultSize = defaultUnitSize(model, sizeType);\n            component.layoutSize.set(sizeType, defaultSize, false);\n        }\n    }\n}\nfunction defaultUnitSize(model, sizeType) {\n    const channel = sizeType === 'width' ? 'x' : 'y';\n    const config = model.config;\n    const scaleComponent = model.getScaleComponent(channel);\n    if (scaleComponent) {\n        const scaleType = scaleComponent.get('type');\n        const range = scaleComponent.get('range');\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_2__.hasDiscreteDomain)(scaleType)) {\n            const size = (0,_config__WEBPACK_IMPORTED_MODULE_1__.getViewConfigDiscreteSize)(config.view, sizeType);\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isVgRangeStep)(range) || (0,_spec_base__WEBPACK_IMPORTED_MODULE_3__.isStep)(size)) {\n                // For discrete domain with range.step, use dynamic width/height\n                return 'step';\n            }\n            else {\n                return size;\n            }\n        }\n        else {\n            return (0,_config__WEBPACK_IMPORTED_MODULE_1__.getViewConfigContinuousSize)(config.view, sizeType);\n        }\n    }\n    else if (model.hasProjection || model.mark === 'arc') {\n        // arc should use continuous size by default otherwise the pie is extremely small\n        return (0,_config__WEBPACK_IMPORTED_MODULE_1__.getViewConfigContinuousSize)(config.view, sizeType);\n    }\n    else {\n        const size = (0,_config__WEBPACK_IMPORTED_MODULE_1__.getViewConfigDiscreteSize)(config.view, sizeType);\n        return (0,_spec_base__WEBPACK_IMPORTED_MODULE_3__.isStep)(size) ? size.step : size;\n    }\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/legend/assemble.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/legend/assemble.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleLegend: () => (/* binding */ assembleLegend),\n/* harmony export */   assembleLegends: () => (/* binding */ assembleLegends)\n/* harmony export */ });\n/* harmony import */ var _legend__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../legend */ \"../../node_modules/vega-lite/build/src/legend.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./parse */ \"../../node_modules/vega-lite/build/src/compile/legend/parse.js\");\n\n\n\n\nfunction setLegendEncode(legend, part, vgProp, vgRef) {\n    var _a, _b;\n    legend.encode ?? (legend.encode = {});\n    (_a = legend.encode)[part] ?? (_a[part] = {});\n    (_b = legend.encode[part]).update ?? (_b.update = {});\n    // TODO: remove as any after https://github.com/prisma/nexus-prisma/issues/291\n    legend.encode[part].update[vgProp] = vgRef;\n}\nfunction assembleLegends(model) {\n    const legendComponentIndex = model.component.legends;\n    const legendByDomain = {};\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(legendComponentIndex)) {\n        const scaleComponent = model.getScaleComponent(channel);\n        const domainHash = (0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(scaleComponent.get('domains'));\n        if (legendByDomain[domainHash]) {\n            for (const mergedLegendComponent of legendByDomain[domainHash]) {\n                const merged = (0,_parse__WEBPACK_IMPORTED_MODULE_3__.mergeLegendComponent)(mergedLegendComponent, legendComponentIndex[channel]);\n                if (!merged) {\n                    // If cannot merge, need to add this legend separately\n                    legendByDomain[domainHash].push(legendComponentIndex[channel]);\n                }\n            }\n        }\n        else {\n            legendByDomain[domainHash] = [legendComponentIndex[channel].clone()];\n        }\n    }\n    const legends = (0,_util__WEBPACK_IMPORTED_MODULE_1__.vals)(legendByDomain)\n        .flat()\n        .map(l => assembleLegend(l, model.config))\n        .filter(l => l !== undefined);\n    return legends;\n}\nfunction assembleLegend(legendCmpt, config) {\n    const { disable, labelExpr, selections, ...legend } = legendCmpt.combine();\n    if (disable) {\n        return undefined;\n    }\n    if (config.aria === false && legend.aria == undefined) {\n        legend.aria = false;\n    }\n    if (legend.encode?.symbols) {\n        const out = legend.encode.symbols.update;\n        if (out.fill && out.fill['value'] !== 'transparent' && !out.stroke && !legend.stroke) {\n            // For non color channel's legend, we need to override symbol stroke config from Vega config if stroke channel is not used.\n            out.stroke = { value: 'transparent' };\n        }\n        // Remove properties that the legend is encoding.\n        for (const property of _legend__WEBPACK_IMPORTED_MODULE_0__.LEGEND_SCALE_CHANNELS) {\n            if (legend[property]) {\n                delete out[property];\n            }\n        }\n    }\n    if (!legend.title) {\n        // title schema doesn't include null, ''\n        delete legend.title;\n    }\n    if (labelExpr !== undefined) {\n        let expr = labelExpr;\n        if (legend.encode?.labels?.update && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_2__.isSignalRef)(legend.encode.labels.update.text)) {\n            expr = (0,_util__WEBPACK_IMPORTED_MODULE_1__.replaceAll)(labelExpr, 'datum.label', legend.encode.labels.update.text.signal);\n        }\n        setLegendEncode(legend, 'labels', 'text', { signal: expr });\n    }\n    return legend;\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/legend/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/legend/component.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/legend/component.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   LEGEND_COMPONENT_PROPERTIES: () => (/* binding */ LEGEND_COMPONENT_PROPERTIES),\n/* harmony export */   LegendComponent: () => (/* binding */ LegendComponent)\n/* harmony export */ });\n/* harmony import */ var _legend__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../legend */ \"../../node_modules/vega-lite/build/src/legend.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n\n\nconst LEGEND_COMPONENT_PROPERTY_INDEX = {\n    ..._legend__WEBPACK_IMPORTED_MODULE_0__.COMMON_LEGEND_PROPERTY_INDEX,\n    disable: 1,\n    labelExpr: 1,\n    selections: 1,\n    // channel scales\n    opacity: 1,\n    shape: 1,\n    stroke: 1,\n    fill: 1,\n    size: 1,\n    strokeWidth: 1,\n    strokeDash: 1,\n    // encode\n    encode: 1\n};\nconst LEGEND_COMPONENT_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(LEGEND_COMPONENT_PROPERTY_INDEX);\nclass LegendComponent extends _split__WEBPACK_IMPORTED_MODULE_2__.Split {\n}\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/legend/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/legend/encode.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/legend/encode.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   entries: () => (/* binding */ entries),\n/* harmony export */   getFirstConditionValue: () => (/* binding */ getFirstConditionValue),\n/* harmony export */   gradient: () => (/* binding */ gradient),\n/* harmony export */   labels: () => (/* binding */ labels),\n/* harmony export */   legendEncodeRules: () => (/* binding */ legendEncodeRules),\n/* harmony export */   symbols: () => (/* binding */ symbols)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _mark_encode__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../mark/encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../selection */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n\n\n\n\n\n\n\n\n\nconst legendEncodeRules = {\n    symbols,\n    gradient,\n    labels,\n    entries\n};\nfunction symbols(symbolsSpec, { fieldOrDatumDef, model, channel, legendCmpt, legendType }) {\n    if (legendType !== 'symbol') {\n        return undefined;\n    }\n    const { markDef, encoding, config, mark } = model;\n    const filled = markDef.filled && mark !== 'trail';\n    let out = {\n        ...(0,_common__WEBPACK_IMPORTED_MODULE_5__.applyMarkConfig)({}, model, _mark__WEBPACK_IMPORTED_MODULE_3__.FILL_STROKE_CONFIG),\n        ..._mark_encode__WEBPACK_IMPORTED_MODULE_7__.color(model, { filled })\n    }; // FIXME: remove this when VgEncodeEntry is compatible with SymbolEncodeEntry\n    const symbolOpacity = legendCmpt.get('symbolOpacity') ?? config.legend.symbolOpacity;\n    const symbolFillColor = legendCmpt.get('symbolFillColor') ?? config.legend.symbolFillColor;\n    const symbolStrokeColor = legendCmpt.get('symbolStrokeColor') ?? config.legend.symbolStrokeColor;\n    const opacity = symbolOpacity === undefined ? getMaxValue(encoding.opacity) ?? markDef.opacity : undefined;\n    if (out.fill) {\n        // for fill legend, we don't want any fill in symbol\n        if (channel === 'fill' || (filled && channel === _channel__WEBPACK_IMPORTED_MODULE_1__.COLOR)) {\n            delete out.fill;\n        }\n        else {\n            if (out.fill['field']) {\n                // For others, set fill to some opaque value (or nothing if a color is already set)\n                if (symbolFillColor) {\n                    delete out.fill;\n                }\n                else {\n                    out.fill = (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(config.legend.symbolBaseFillColor ?? 'black');\n                    out.fillOpacity = (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(opacity ?? 1);\n                }\n            }\n            else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(out.fill)) {\n                const fill = getFirstConditionValue(encoding.fill ?? encoding.color) ?? markDef.fill ?? (filled && markDef.color);\n                if (fill) {\n                    out.fill = (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(fill);\n                }\n            }\n        }\n    }\n    if (out.stroke) {\n        if (channel === 'stroke' || (!filled && channel === _channel__WEBPACK_IMPORTED_MODULE_1__.COLOR)) {\n            delete out.stroke;\n        }\n        else {\n            if (out.stroke['field'] || symbolStrokeColor) {\n                // For others, remove stroke field\n                delete out.stroke;\n            }\n            else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(out.stroke)) {\n                const stroke = (0,_util__WEBPACK_IMPORTED_MODULE_4__.getFirstDefined)(getFirstConditionValue(encoding.stroke || encoding.color), markDef.stroke, filled ? markDef.color : undefined);\n                if (stroke) {\n                    out.stroke = { value: stroke };\n                }\n            }\n        }\n    }\n    if (channel !== _channel__WEBPACK_IMPORTED_MODULE_1__.OPACITY) {\n        const condition = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) && selectedCondition(model, legendCmpt, fieldOrDatumDef);\n        if (condition) {\n            out.opacity = [\n                { test: condition, ...(0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(opacity ?? 1) },\n                (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(config.legend.unselectedOpacity)\n            ];\n        }\n        else if (opacity) {\n            out.opacity = (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(opacity);\n        }\n    }\n    out = { ...out, ...symbolsSpec };\n    return (0,_util__WEBPACK_IMPORTED_MODULE_4__.isEmpty)(out) ? undefined : out;\n}\nfunction gradient(gradientSpec, { model, legendType, legendCmpt }) {\n    if (legendType !== 'gradient') {\n        return undefined;\n    }\n    const { config, markDef, encoding } = model;\n    let out = {};\n    const gradientOpacity = legendCmpt.get('gradientOpacity') ?? config.legend.gradientOpacity;\n    const opacity = gradientOpacity === undefined ? getMaxValue(encoding.opacity) || markDef.opacity : undefined;\n    if (opacity) {\n        // only apply opacity if it is neither zero or undefined\n        out.opacity = (0,_common__WEBPACK_IMPORTED_MODULE_5__.signalOrValueRef)(opacity);\n    }\n    out = { ...out, ...gradientSpec };\n    return (0,_util__WEBPACK_IMPORTED_MODULE_4__.isEmpty)(out) ? undefined : out;\n}\nfunction labels(specifiedlabelsSpec, { fieldOrDatumDef, model, channel, legendCmpt }) {\n    const legend = model.legend(channel) || {};\n    const config = model.config;\n    const condition = (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) ? selectedCondition(model, legendCmpt, fieldOrDatumDef) : undefined;\n    const opacity = condition ? [{ test: condition, value: 1 }, { value: config.legend.unselectedOpacity }] : undefined;\n    const { format, formatType } = legend;\n    let text = undefined;\n    if ((0,_format__WEBPACK_IMPORTED_MODULE_6__.isCustomFormatType)(formatType)) {\n        text = (0,_format__WEBPACK_IMPORTED_MODULE_6__.formatCustomType)({\n            fieldOrDatumDef,\n            field: 'datum.value',\n            format,\n            formatType,\n            config\n        });\n    }\n    else if (format === undefined && formatType === undefined && config.customFormatTypes) {\n        if (fieldOrDatumDef.type === 'quantitative' && config.numberFormatType) {\n            text = (0,_format__WEBPACK_IMPORTED_MODULE_6__.formatCustomType)({\n                fieldOrDatumDef,\n                field: 'datum.value',\n                format: config.numberFormat,\n                formatType: config.numberFormatType,\n                config\n            });\n        }\n        else if (fieldOrDatumDef.type === 'temporal' &&\n            config.timeFormatType &&\n            (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldOrDatumDef) &&\n            fieldOrDatumDef.timeUnit === undefined) {\n            text = (0,_format__WEBPACK_IMPORTED_MODULE_6__.formatCustomType)({\n                fieldOrDatumDef,\n                field: 'datum.value',\n                format: config.timeFormat,\n                formatType: config.timeFormatType,\n                config\n            });\n        }\n    }\n    const labelsSpec = {\n        ...(opacity ? { opacity } : {}),\n        ...(text ? { text } : {}),\n        ...specifiedlabelsSpec\n    };\n    return (0,_util__WEBPACK_IMPORTED_MODULE_4__.isEmpty)(labelsSpec) ? undefined : labelsSpec;\n}\nfunction entries(entriesSpec, { legendCmpt }) {\n    const selections = legendCmpt.get('selections');\n    return selections?.length ? { ...entriesSpec, fill: { value: 'transparent' } } : entriesSpec;\n}\nfunction getMaxValue(channelDef) {\n    return getConditionValue(channelDef, (v, conditionalDef) => Math.max(v, conditionalDef.value));\n}\nfunction getFirstConditionValue(channelDef) {\n    return getConditionValue(channelDef, (v, conditionalDef) => {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_4__.getFirstDefined)(v, conditionalDef.value);\n    });\n}\nfunction getConditionValue(channelDef, reducer) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.hasConditionalValueDef)(channelDef)) {\n        return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(channelDef.condition).reduce(reducer, channelDef.value);\n    }\n    else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isValueDef)(channelDef)) {\n        return channelDef.value;\n    }\n    return undefined;\n}\nfunction selectedCondition(model, legendCmpt, fieldDef) {\n    const selections = legendCmpt.get('selections');\n    if (!selections?.length)\n        return undefined;\n    const field = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(fieldDef.field);\n    return selections\n        .map(name => {\n        const store = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)((0,_util__WEBPACK_IMPORTED_MODULE_4__.varName)(name) + _selection__WEBPACK_IMPORTED_MODULE_8__.STORE);\n        return `(!length(data(${store})) || (${name}[${field}] && indexof(${name}[${field}], datum.value) >= 0))`;\n    })\n        .join(' || ');\n}\n//# sourceMappingURL=encode.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/legend/encode.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/legend/parse.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/legend/parse.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   mergeLegendComponent: () => (/* binding */ mergeLegendComponent),\n/* harmony export */   parseLegend: () => (/* binding */ parseLegend),\n/* harmony export */   parseLegendForChannel: () => (/* binding */ parseLegendForChannel)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _legend__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../legend */ \"../../node_modules/vega-lite/build/src/legend.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _guide__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../guide */ \"../../node_modules/vega-lite/build/src/compile/guide.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _resolve__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../resolve */ \"../../node_modules/vega-lite/build/src/compile/resolve.js\");\n/* harmony import */ var _selection_legends__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../selection/legends */ \"../../node_modules/vega-lite/build/src/compile/selection/legends.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/legend/component.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/legend/encode.js\");\n/* harmony import */ var _properties__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./properties */ \"../../node_modules/vega-lite/build/src/compile/legend/properties.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction parseLegend(model) {\n    const legendComponent = (0,_model__WEBPACK_IMPORTED_MODULE_8__.isUnitModel)(model) ? parseUnitLegend(model) : parseNonUnitLegend(model);\n    model.component.legends = legendComponent;\n    return legendComponent;\n}\nfunction parseUnitLegend(model) {\n    const { encoding } = model;\n    const legendComponent = {};\n    for (const channel of [_channel__WEBPACK_IMPORTED_MODULE_0__.COLOR, ..._legend__WEBPACK_IMPORTED_MODULE_2__.LEGEND_SCALE_CHANNELS]) {\n        const def = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldOrDatumDef)(encoding[channel]);\n        if (!def || !model.getScaleComponent(channel)) {\n            continue;\n        }\n        if (channel === _channel__WEBPACK_IMPORTED_MODULE_0__.SHAPE && (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(def) && def.type === _type__WEBPACK_IMPORTED_MODULE_4__.GEOJSON) {\n            continue;\n        }\n        legendComponent[channel] = parseLegendForChannel(model, channel);\n    }\n    return legendComponent;\n}\nfunction getLegendDefWithScale(model, channel) {\n    const scale = model.scaleName(channel);\n    if (model.mark === 'trail') {\n        if (channel === 'color') {\n            // trail is a filled mark, but its default symbolType (\"stroke\") should use \"stroke\"\n            return { stroke: scale };\n        }\n        else if (channel === 'size') {\n            return { strokeWidth: scale };\n        }\n    }\n    if (channel === 'color') {\n        return model.markDef.filled ? { fill: scale } : { stroke: scale };\n    }\n    return { [channel]: scale };\n}\n// eslint-disable-next-line @typescript-eslint/ban-types\nfunction isExplicit(value, property, legend, fieldDef) {\n    switch (property) {\n        case 'disable':\n            return legend !== undefined; // if axis is specified or null/false, then its enable/disable state is explicit\n        case 'values':\n            // specified legend.values is already respected, but may get transformed.\n            return !!legend?.values;\n        case 'title':\n            // title can be explicit if fieldDef.title is set\n            if (property === 'title' && value === fieldDef?.title) {\n                return true;\n            }\n    }\n    // Otherwise, things are explicit if the returned value matches the specified property\n    return value === (legend || {})[property];\n}\nfunction parseLegendForChannel(model, channel) {\n    let legend = model.legend(channel);\n    const { markDef, encoding, config } = model;\n    const legendConfig = config.legend;\n    const legendCmpt = new _component__WEBPACK_IMPORTED_MODULE_12__.LegendComponent({}, getLegendDefWithScale(model, channel));\n    (0,_selection_legends__WEBPACK_IMPORTED_MODULE_10__.parseInteractiveLegend)(model, channel, legendCmpt);\n    const disable = legend !== undefined ? !legend : legendConfig.disable;\n    legendCmpt.set('disable', disable, legend !== undefined);\n    if (disable) {\n        return legendCmpt;\n    }\n    legend = legend || {};\n    const scaleType = model.getScaleComponent(channel).get('type');\n    const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldOrDatumDef)(encoding[channel]);\n    const timeUnit = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(fieldOrDatumDef) ? (0,_timeunit__WEBPACK_IMPORTED_MODULE_3__.normalizeTimeUnit)(fieldOrDatumDef.timeUnit)?.unit : undefined;\n    const orient = legend.orient || config.legend.orient || 'right';\n    const legendType = (0,_properties__WEBPACK_IMPORTED_MODULE_14__.getLegendType)({ legend, channel, timeUnit, scaleType });\n    const direction = (0,_properties__WEBPACK_IMPORTED_MODULE_14__.getDirection)({ legend, legendType, orient, legendConfig });\n    const ruleParams = {\n        legend,\n        channel,\n        model,\n        markDef,\n        encoding,\n        fieldOrDatumDef,\n        legendConfig,\n        config,\n        scaleType,\n        orient,\n        legendType,\n        direction\n    };\n    for (const property of _component__WEBPACK_IMPORTED_MODULE_12__.LEGEND_COMPONENT_PROPERTIES) {\n        if ((legendType === 'gradient' && property.startsWith('symbol')) ||\n            (legendType === 'symbol' && property.startsWith('gradient'))) {\n            continue;\n        }\n        const value = property in _properties__WEBPACK_IMPORTED_MODULE_14__.legendRules ? _properties__WEBPACK_IMPORTED_MODULE_14__.legendRules[property](ruleParams) : legend[property];\n        if (value !== undefined) {\n            const explicit = isExplicit(value, property, legend, model.fieldDef(channel));\n            if (explicit || config.legend[property] === undefined) {\n                legendCmpt.set(property, value, explicit);\n            }\n        }\n    }\n    const legendEncoding = legend?.encoding ?? {};\n    const selections = legendCmpt.get('selections');\n    const legendEncode = {};\n    const legendEncodeParams = { fieldOrDatumDef, model, channel, legendCmpt, legendType };\n    for (const part of ['labels', 'legend', 'title', 'symbols', 'gradient', 'entries']) {\n        const legendEncodingPart = (0,_guide__WEBPACK_IMPORTED_MODULE_7__.guideEncodeEntry)(legendEncoding[part] ?? {}, model);\n        const value = part in _encode__WEBPACK_IMPORTED_MODULE_13__.legendEncodeRules\n            ? _encode__WEBPACK_IMPORTED_MODULE_13__.legendEncodeRules[part](legendEncodingPart, legendEncodeParams) // apply rule\n            : legendEncodingPart; // no rule -- just default values\n        if (value !== undefined && !(0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(value)) {\n            legendEncode[part] = {\n                ...(selections?.length && (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(fieldOrDatumDef)\n                    ? { name: `${(0,_util__WEBPACK_IMPORTED_MODULE_5__.varName)(fieldOrDatumDef.field)}_legend_${part}` }\n                    : {}),\n                ...(selections?.length ? { interactive: !!selections } : {}),\n                update: value\n            };\n        }\n    }\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(legendEncode)) {\n        legendCmpt.set('encode', legendEncode, !!legend?.encoding);\n    }\n    return legendCmpt;\n}\nfunction parseNonUnitLegend(model) {\n    const { legends, resolve } = model.component;\n    for (const child of model.children) {\n        parseLegend(child);\n        for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(child.component.legends)) {\n            resolve.legend[channel] = (0,_resolve__WEBPACK_IMPORTED_MODULE_9__.parseGuideResolve)(model.component.resolve, channel);\n            if (resolve.legend[channel] === 'shared') {\n                // If the resolve says shared (and has not been overridden)\n                // We will try to merge and see if there is a conflict\n                legends[channel] = mergeLegendComponent(legends[channel], child.component.legends[channel]);\n                if (!legends[channel]) {\n                    // If merge returns nothing, there is a conflict so we cannot make the legend shared.\n                    // Thus, mark legend as independent and remove the legend component.\n                    resolve.legend[channel] = 'independent';\n                    delete legends[channel];\n                }\n            }\n        }\n    }\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(legends)) {\n        for (const child of model.children) {\n            if (!child.component.legends[channel]) {\n                // skip if the child does not have a particular legend\n                continue;\n            }\n            if (resolve.legend[channel] === 'shared') {\n                // After merging shared legend, make sure to remove legend from child\n                delete child.component.legends[channel];\n            }\n        }\n    }\n    return legends;\n}\nfunction mergeLegendComponent(mergedLegend, childLegend) {\n    if (!mergedLegend) {\n        return childLegend.clone();\n    }\n    const mergedOrient = mergedLegend.getWithExplicit('orient');\n    const childOrient = childLegend.getWithExplicit('orient');\n    if (mergedOrient.explicit && childOrient.explicit && mergedOrient.value !== childOrient.value) {\n        // TODO: throw warning if resolve is explicit (We don't have info about explicit/implicit resolve yet.)\n        // Cannot merge due to inconsistent orient\n        return undefined;\n    }\n    let typeMerged = false;\n    // Otherwise, let's merge\n    for (const prop of _component__WEBPACK_IMPORTED_MODULE_12__.LEGEND_COMPONENT_PROPERTIES) {\n        const mergedValueWithExplicit = (0,_split__WEBPACK_IMPORTED_MODULE_11__.mergeValuesWithExplicit)(mergedLegend.getWithExplicit(prop), childLegend.getWithExplicit(prop), prop, 'legend', \n        // Tie breaker function\n        (v1, v2) => {\n            switch (prop) {\n                case 'symbolType':\n                    return mergeSymbolType(v1, v2);\n                case 'title':\n                    return (0,_common__WEBPACK_IMPORTED_MODULE_6__.mergeTitleComponent)(v1, v2);\n                case 'type':\n                    // There are only two types. If we have different types, then prefer symbol over gradient.\n                    typeMerged = true;\n                    return (0,_split__WEBPACK_IMPORTED_MODULE_11__.makeImplicit)('symbol');\n            }\n            return (0,_split__WEBPACK_IMPORTED_MODULE_11__.defaultTieBreaker)(v1, v2, prop, 'legend');\n        });\n        mergedLegend.setWithExplicit(prop, mergedValueWithExplicit);\n    }\n    if (typeMerged) {\n        if (mergedLegend.implicit?.encode?.gradient) {\n            (0,_util__WEBPACK_IMPORTED_MODULE_5__.deleteNestedProperty)(mergedLegend.implicit, ['encode', 'gradient']);\n        }\n        if (mergedLegend.explicit?.encode?.gradient) {\n            (0,_util__WEBPACK_IMPORTED_MODULE_5__.deleteNestedProperty)(mergedLegend.explicit, ['encode', 'gradient']);\n        }\n    }\n    return mergedLegend;\n}\nfunction mergeSymbolType(st1, st2) {\n    if (st2.value === 'circle') {\n        // prefer \"circle\" over \"stroke\"\n        return st2;\n    }\n    return st1;\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/legend/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/legend/properties.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/legend/properties.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   clipHeight: () => (/* binding */ clipHeight),\n/* harmony export */   defaultDirection: () => (/* binding */ defaultDirection),\n/* harmony export */   defaultGradientLength: () => (/* binding */ defaultGradientLength),\n/* harmony export */   defaultLabelOverlap: () => (/* binding */ defaultLabelOverlap),\n/* harmony export */   defaultSymbolType: () => (/* binding */ defaultSymbolType),\n/* harmony export */   defaultType: () => (/* binding */ defaultType),\n/* harmony export */   getDirection: () => (/* binding */ getDirection),\n/* harmony export */   getLegendType: () => (/* binding */ getLegendType),\n/* harmony export */   legendRules: () => (/* binding */ legendRules),\n/* harmony export */   values: () => (/* binding */ values)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/legend/encode.js\");\n\n\n\n\n\n\n\n\nconst legendRules = {\n    direction: ({ direction }) => direction,\n    format: ({ fieldOrDatumDef, legend, config }) => {\n        const { format, formatType } = legend;\n        return (0,_format__WEBPACK_IMPORTED_MODULE_6__.guideFormat)(fieldOrDatumDef, fieldOrDatumDef.type, format, formatType, config, false);\n    },\n    formatType: ({ legend, fieldOrDatumDef, scaleType }) => {\n        const { formatType } = legend;\n        return (0,_format__WEBPACK_IMPORTED_MODULE_6__.guideFormatType)(formatType, fieldOrDatumDef, scaleType);\n    },\n    gradientLength: params => {\n        const { legend, legendConfig } = params;\n        return legend.gradientLength ?? legendConfig.gradientLength ?? defaultGradientLength(params);\n    },\n    labelOverlap: ({ legend, legendConfig, scaleType }) => legend.labelOverlap ?? legendConfig.labelOverlap ?? defaultLabelOverlap(scaleType),\n    symbolType: ({ legend, markDef, channel, encoding }) => legend.symbolType ?? defaultSymbolType(markDef.type, channel, encoding.shape, markDef.shape),\n    title: ({ fieldOrDatumDef, config }) => (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.title)(fieldOrDatumDef, config, { allowDisabling: true }),\n    type: ({ legendType, scaleType, channel }) => {\n        if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isColorChannel)(channel) && (0,_scale__WEBPACK_IMPORTED_MODULE_3__.isContinuousToContinuous)(scaleType)) {\n            if (legendType === 'gradient') {\n                return undefined;\n            }\n        }\n        else if (legendType === 'symbol') {\n            return undefined;\n        }\n        return legendType;\n    },\n    values: ({ fieldOrDatumDef, legend }) => values(legend, fieldOrDatumDef)\n};\nfunction values(legend, fieldOrDatumDef) {\n    const vals = legend.values;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(vals)) {\n        return (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.valueArray)(fieldOrDatumDef, vals);\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_5__.isSignalRef)(vals)) {\n        return vals;\n    }\n    return undefined;\n}\nfunction defaultSymbolType(mark, channel, shapeChannelDef, markShape) {\n    if (channel !== 'shape') {\n        // use the value from the shape encoding or the mark config if they exist\n        const shape = (0,_encode__WEBPACK_IMPORTED_MODULE_7__.getFirstConditionValue)(shapeChannelDef) ?? markShape;\n        if (shape) {\n            return shape;\n        }\n    }\n    switch (mark) {\n        case 'bar':\n        case 'rect':\n        case 'image':\n        case 'square':\n            return 'square';\n        case 'line':\n        case 'trail':\n        case 'rule':\n            return 'stroke';\n        case 'arc':\n        case 'point':\n        case 'circle':\n        case 'tick':\n        case 'geoshape':\n        case 'area':\n        case 'text':\n            return 'circle';\n    }\n}\nfunction clipHeight(legendType) {\n    if (legendType === 'gradient') {\n        return 20;\n    }\n    return undefined;\n}\nfunction getLegendType(params) {\n    const { legend } = params;\n    return (0,_util__WEBPACK_IMPORTED_MODULE_4__.getFirstDefined)(legend.type, defaultType(params));\n}\nfunction defaultType({ channel, timeUnit, scaleType }) {\n    // Following the logic in https://github.com/vega/vega-parser/blob/master/src/parsers/legend.js\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isColorChannel)(channel)) {\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.contains)(['quarter', 'month', 'day'], timeUnit)) {\n            return 'symbol';\n        }\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_3__.isContinuousToContinuous)(scaleType)) {\n            return 'gradient';\n        }\n    }\n    return 'symbol';\n}\nfunction getDirection({ legendConfig, legendType, orient, legend }) {\n    return (legend.direction ??\n        legendConfig[legendType ? 'gradientDirection' : 'symbolDirection'] ??\n        defaultDirection(orient, legendType));\n}\nfunction defaultDirection(orient, legendType) {\n    switch (orient) {\n        case 'top':\n        case 'bottom':\n            return 'horizontal';\n        case 'left':\n        case 'right':\n        case 'none':\n        case undefined: // undefined = \"right\" in Vega\n            return undefined; // vertical is Vega's default\n        default:\n            // top-left / ...\n            // For inner legend, uses compact layout like Tableau\n            return legendType === 'gradient' ? 'horizontal' : undefined;\n    }\n}\nfunction defaultGradientLength({ legendConfig, model, direction, orient, scaleType }) {\n    const { gradientHorizontalMaxLength, gradientHorizontalMinLength, gradientVerticalMaxLength, gradientVerticalMinLength } = legendConfig;\n    if ((0,_scale__WEBPACK_IMPORTED_MODULE_3__.isContinuousToContinuous)(scaleType)) {\n        if (direction === 'horizontal') {\n            if (orient === 'top' || orient === 'bottom') {\n                return gradientLengthSignal(model, 'width', gradientHorizontalMinLength, gradientHorizontalMaxLength);\n            }\n            else {\n                return gradientHorizontalMinLength;\n            }\n        }\n        else {\n            // vertical / undefined (Vega uses vertical by default)\n            return gradientLengthSignal(model, 'height', gradientVerticalMinLength, gradientVerticalMaxLength);\n        }\n    }\n    return undefined;\n}\nfunction gradientLengthSignal(model, sizeType, min, max) {\n    const sizeSignal = model.getSizeSignalRef(sizeType).signal;\n    return { signal: `clamp(${sizeSignal}, ${min}, ${max})` };\n}\nfunction defaultLabelOverlap(scaleType) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.contains)(['quantile', 'threshold', 'log', 'symlog'], scaleType)) {\n        return 'greedy';\n    }\n    return undefined;\n}\n//# sourceMappingURL=properties.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/legend/properties.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/arc.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/arc.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   arc: () => (/* binding */ arc)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst arc = {\n    vgMark: 'arc',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                size: 'ignore',\n                orient: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('x', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('y', model, { defaultPos: 'mid' }),\n            // arcs are rectangles in polar coordinates\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'radius'),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'theta')\n        };\n    }\n};\n//# sourceMappingURL=arc.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/arc.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/area.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/area.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   area: () => (/* binding */ area)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst area = {\n    vgMark: 'area',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                orient: 'include',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointOrRangePosition('x', model, {\n                defaultPos: 'zeroOrMin',\n                defaultPos2: 'zeroOrMin',\n                range: model.markDef.orient === 'horizontal'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointOrRangePosition('y', model, {\n                defaultPos: 'zeroOrMin',\n                defaultPos2: 'zeroOrMin',\n                range: model.markDef.orient === 'vertical'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.defined(model)\n        };\n    }\n};\n//# sourceMappingURL=area.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/area.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/bar.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/bar.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bar: () => (/* binding */ bar)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst bar = {\n    vgMark: 'rect',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                orient: 'ignore',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'x'),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'y')\n        };\n    }\n};\n//# sourceMappingURL=bar.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/bar.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/aria.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/aria.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   aria: () => (/* binding */ aria),\n/* harmony export */   description: () => (/* binding */ description)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n/* harmony import */ var _text__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./text */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/text.js\");\n/* harmony import */ var _tooltip__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./tooltip */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js\");\n\n\n\n\n\n\nfunction aria(model) {\n    const { markDef, config } = model;\n    const enableAria = (0,_common__WEBPACK_IMPORTED_MODULE_1__.getMarkPropOrConfig)('aria', markDef, config);\n    // We can ignore other aria properties if ariaHidden is true.\n    if (enableAria === false) {\n        // getMarkGroups sets aria to false already so we don't have to set it in the encode block\n        return {};\n    }\n    return {\n        ...(enableAria ? { aria: enableAria } : {}),\n        ...ariaRoleDescription(model),\n        ...description(model)\n    };\n}\nfunction ariaRoleDescription(model) {\n    const { mark, markDef, config } = model;\n    if (config.aria === false) {\n        return {};\n    }\n    const ariaRoleDesc = (0,_common__WEBPACK_IMPORTED_MODULE_1__.getMarkPropOrConfig)('ariaRoleDescription', markDef, config);\n    if (ariaRoleDesc != null) {\n        return { ariaRoleDescription: { value: ariaRoleDesc } };\n    }\n    return mark in _vega_schema__WEBPACK_IMPORTED_MODULE_2__.VG_MARK_INDEX ? {} : { ariaRoleDescription: { value: mark } };\n}\nfunction description(model) {\n    const { encoding, markDef, config, stack } = model;\n    const channelDef = encoding.description;\n    if (channelDef) {\n        return (0,_conditional__WEBPACK_IMPORTED_MODULE_3__.wrapCondition)(model, channelDef, 'description', cDef => (0,_text__WEBPACK_IMPORTED_MODULE_4__.textRef)(cDef, model.config));\n    }\n    // Use default from mark def or config if defined.\n    // Functions in encode usually just return undefined but since we are defining a default below, we need to check the default here.\n    const descriptionValue = (0,_common__WEBPACK_IMPORTED_MODULE_1__.getMarkPropOrConfig)('description', markDef, config);\n    if (descriptionValue != null) {\n        return {\n            description: (0,_common__WEBPACK_IMPORTED_MODULE_1__.signalOrValueRef)(descriptionValue)\n        };\n    }\n    if (config.aria === false) {\n        return {};\n    }\n    const data = (0,_tooltip__WEBPACK_IMPORTED_MODULE_5__.tooltipData)(encoding, stack, config);\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(data)) {\n        return undefined;\n    }\n    return {\n        description: {\n            signal: (0,_util__WEBPACK_IMPORTED_MODULE_0__.entries)(data)\n                .map(([key, value], index) => `\"${index > 0 ? '; ' : ''}${key}: \" + (${value})`)\n                .join(' + ')\n        }\n    };\n}\n//# sourceMappingURL=aria.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/aria.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/base.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/base.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   baseEncodeEntry: () => (/* binding */ baseEncodeEntry),\n/* harmony export */   color: () => (/* reexport safe */ _color__WEBPACK_IMPORTED_MODULE_8__.color),\n/* harmony export */   nonPosition: () => (/* reexport safe */ _nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition),\n/* harmony export */   pointOrRangePosition: () => (/* reexport safe */ _position_range__WEBPACK_IMPORTED_MODULE_16__.pointOrRangePosition),\n/* harmony export */   pointPosition: () => (/* reexport safe */ _position_point__WEBPACK_IMPORTED_MODULE_15__.pointPosition),\n/* harmony export */   rangePosition: () => (/* reexport safe */ _position_range__WEBPACK_IMPORTED_MODULE_16__.rangePosition),\n/* harmony export */   rectPosition: () => (/* reexport safe */ _position_rect__WEBPACK_IMPORTED_MODULE_17__.rectPosition),\n/* harmony export */   text: () => (/* reexport safe */ _text__WEBPACK_IMPORTED_MODULE_10__.text),\n/* harmony export */   tooltip: () => (/* reexport safe */ _tooltip__WEBPACK_IMPORTED_MODULE_11__.tooltip),\n/* harmony export */   wrapCondition: () => (/* reexport safe */ _conditional__WEBPACK_IMPORTED_MODULE_14__.wrapCondition)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _aria__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./aria */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/aria.js\");\n/* harmony import */ var _color__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./color */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/color.js\");\n/* harmony import */ var _nonposition__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./nonposition */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js\");\n/* harmony import */ var _text__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./text */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/text.js\");\n/* harmony import */ var _tooltip__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./tooltip */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n/* harmony import */ var _zindex__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./zindex */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/zindex.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n/* harmony import */ var _position_point__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./position-point */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js\");\n/* harmony import */ var _position_range__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./position-range */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js\");\n/* harmony import */ var _position_rect__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./position-rect */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-rect.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst ALWAYS_IGNORE = new Set(['aria', 'width', 'height']);\nfunction baseEncodeEntry(model, ignore) {\n    const { fill = undefined, stroke = undefined } = ignore.color === 'include' ? (0,_color__WEBPACK_IMPORTED_MODULE_8__.color)(model) : {};\n    return {\n        ...markDefProperties(model.markDef, ignore),\n        ...wrapAllFieldsInvalid(model, 'fill', fill),\n        ...wrapAllFieldsInvalid(model, 'stroke', stroke),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition)('opacity', model),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition)('fillOpacity', model),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition)('strokeOpacity', model),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition)('strokeWidth', model),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_9__.nonPosition)('strokeDash', model),\n        ...(0,_zindex__WEBPACK_IMPORTED_MODULE_13__.zindex)(model),\n        ...(0,_tooltip__WEBPACK_IMPORTED_MODULE_11__.tooltip)(model),\n        ...(0,_text__WEBPACK_IMPORTED_MODULE_10__.text)(model, 'href'),\n        ...(0,_aria__WEBPACK_IMPORTED_MODULE_7__.aria)(model)\n    };\n}\n// TODO: mark VgValueRef[] as readonly after https://github.com/vega/vega/pull/1987\nfunction wrapAllFieldsInvalid(model, channel, valueRef) {\n    const { config, mark, markDef } = model;\n    const invalid = (0,_common__WEBPACK_IMPORTED_MODULE_6__.getMarkPropOrConfig)('invalid', markDef, config);\n    if (invalid === 'hide' && valueRef && !(0,_mark__WEBPACK_IMPORTED_MODULE_2__.isPathMark)(mark)) {\n        // For non-path marks, we have to exclude invalid values (null and NaN) for scales with continuous domains.\n        // For path marks, we will use \"defined\" property and skip these values instead.\n        const test = allFieldsInvalidPredicate(model, { invalid: true, channels: _channel__WEBPACK_IMPORTED_MODULE_1__.SCALE_CHANNELS });\n        if (test) {\n            return {\n                [channel]: [\n                    // prepend the invalid case\n                    // TODO: support custom value\n                    { test, value: null },\n                    ...(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(valueRef)\n                ]\n            };\n        }\n    }\n    return valueRef ? { [channel]: valueRef } : {};\n}\nfunction markDefProperties(mark, ignore) {\n    return _vega_schema__WEBPACK_IMPORTED_MODULE_5__.VG_MARK_CONFIGS.reduce((m, prop) => {\n        if (!ALWAYS_IGNORE.has(prop) && mark[prop] !== undefined && ignore[prop] !== 'ignore') {\n            m[prop] = (0,_common__WEBPACK_IMPORTED_MODULE_6__.signalOrValueRef)(mark[prop]);\n        }\n        return m;\n    }, {});\n}\nfunction allFieldsInvalidPredicate(model, { invalid = false, channels }) {\n    const filterIndex = channels.reduce((aggregator, channel) => {\n        const scaleComponent = model.getScaleComponent(channel);\n        if (scaleComponent) {\n            const scaleType = scaleComponent.get('type');\n            const field = model.vgField(channel, { expr: 'datum' });\n            // While discrete domain scales can handle invalid values, continuous scales can't.\n            if (field && (0,_scale__WEBPACK_IMPORTED_MODULE_3__.hasContinuousDomain)(scaleType)) {\n                aggregator[field] = true;\n            }\n        }\n        return aggregator;\n    }, {});\n    const fields = (0,_util__WEBPACK_IMPORTED_MODULE_4__.keys)(filterIndex);\n    if (fields.length > 0) {\n        const op = invalid ? '||' : '&&';\n        return fields.map(field => (0,_valueref__WEBPACK_IMPORTED_MODULE_12__.fieldInvalidPredicate)(field, invalid)).join(` ${op} `);\n    }\n    return undefined;\n}\n//# sourceMappingURL=base.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/base.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/color.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/color.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   color: () => (/* binding */ color)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _nonposition__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./nonposition */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js\");\n\n\n\n\nfunction color(model, opt = { filled: undefined }) {\n    const { markDef, encoding, config } = model;\n    const { type: markType } = markDef;\n    // Allow filled to be overridden (for trail's \"filled\")\n    const filled = opt.filled ?? (0,_common__WEBPACK_IMPORTED_MODULE_2__.getMarkPropOrConfig)('filled', markDef, config);\n    const transparentIfNeeded = (0,_util__WEBPACK_IMPORTED_MODULE_1__.contains)(['bar', 'point', 'circle', 'square', 'geoshape'], markType)\n        ? 'transparent'\n        : undefined;\n    const defaultFill = (0,_common__WEBPACK_IMPORTED_MODULE_2__.getMarkPropOrConfig)(filled === true ? 'color' : undefined, markDef, config, { vgChannel: 'fill' }) ??\n        // need to add this manually as getMarkConfig normally drops config.mark[channel] if vgChannel is specified\n        config.mark[filled === true && 'color'] ??\n        // If there is no fill, always fill symbols, bar, geoshape\n        // with transparent fills https://github.com/vega/vega-lite/issues/1316\n        transparentIfNeeded;\n    const defaultStroke = (0,_common__WEBPACK_IMPORTED_MODULE_2__.getMarkPropOrConfig)(filled === false ? 'color' : undefined, markDef, config, { vgChannel: 'stroke' }) ??\n        // need to add this manually as getMarkConfig normally drops config.mark[channel] if vgChannel is specified\n        config.mark[filled === false && 'color'];\n    const colorVgChannel = filled ? 'fill' : 'stroke';\n    const fillStrokeMarkDefAndConfig = {\n        ...(defaultFill ? { fill: (0,_common__WEBPACK_IMPORTED_MODULE_2__.signalOrValueRef)(defaultFill) } : {}),\n        ...(defaultStroke ? { stroke: (0,_common__WEBPACK_IMPORTED_MODULE_2__.signalOrValueRef)(defaultStroke) } : {})\n    };\n    if (markDef.color && (filled ? markDef.fill : markDef.stroke)) {\n        _log__WEBPACK_IMPORTED_MODULE_0__.warn(_log__WEBPACK_IMPORTED_MODULE_0__.message.droppingColor('property', { fill: 'fill' in markDef, stroke: 'stroke' in markDef }));\n    }\n    return {\n        ...fillStrokeMarkDefAndConfig,\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_3__.nonPosition)('color', model, {\n            vgChannel: colorVgChannel,\n            defaultValue: filled ? defaultFill : defaultStroke\n        }),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_3__.nonPosition)('fill', model, {\n            // if there is encoding.fill, include default fill just in case we have conditional-only fill encoding\n            defaultValue: encoding.fill ? defaultFill : undefined\n        }),\n        ...(0,_nonposition__WEBPACK_IMPORTED_MODULE_3__.nonPosition)('stroke', model, {\n            // if there is encoding.stroke, include default fill just in case we have conditional-only stroke encoding\n            defaultValue: encoding.stroke ? defaultStroke : undefined\n        })\n    };\n}\n//# sourceMappingURL=color.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/color.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   wrapCondition: () => (/* binding */ wrapCondition)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../predicate */ \"../../node_modules/vega-lite/build/src/compile/predicate.js\");\n/* harmony import */ var _selection_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../selection/parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n\n\n\n\n/**\n * Return a mixin that includes a Vega production rule for a Vega-Lite conditional channel definition\n * or a simple mixin if channel def has no condition.\n */\nfunction wrapCondition(model, channelDef, vgChannel, refFn) {\n    const condition = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isConditionalDef)(channelDef) && channelDef.condition;\n    const valueRef = refFn(channelDef);\n    if (condition) {\n        const conditions = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(condition);\n        const vgConditions = conditions.map(c => {\n            const conditionValueRef = refFn(c);\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isConditionalParameter)(c)) {\n                const { param, empty } = c;\n                const test = (0,_selection_parse__WEBPACK_IMPORTED_MODULE_3__.parseSelectionPredicate)(model, { param, empty });\n                return { test, ...conditionValueRef };\n            }\n            else {\n                const test = (0,_predicate__WEBPACK_IMPORTED_MODULE_2__.expression)(model, c.test); // FIXME: remove casting once TS is no longer dumb about it\n                return { test, ...conditionValueRef };\n            }\n        });\n        return {\n            [vgChannel]: [...vgConditions, ...(valueRef !== undefined ? [valueRef] : [])]\n        };\n    }\n    else {\n        return valueRef !== undefined ? { [vgChannel]: valueRef } : {};\n    }\n}\n//# sourceMappingURL=conditional.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/defined.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/defined.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   defined: () => (/* binding */ defined),\n/* harmony export */   valueIfDefined: () => (/* binding */ valueIfDefined)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\n\n\n\nfunction defined(model) {\n    const { config, markDef } = model;\n    const invalid = (0,_common__WEBPACK_IMPORTED_MODULE_3__.getMarkPropOrConfig)('invalid', markDef, config);\n    if (invalid) {\n        const signal = allFieldsInvalidPredicate(model, { channels: _channel__WEBPACK_IMPORTED_MODULE_0__.POSITION_SCALE_CHANNELS });\n        if (signal) {\n            return { defined: { signal } };\n        }\n    }\n    return {};\n}\nfunction allFieldsInvalidPredicate(model, { invalid = false, channels }) {\n    const filterIndex = channels.reduce((aggregator, channel) => {\n        const scaleComponent = model.getScaleComponent(channel);\n        if (scaleComponent) {\n            const scaleType = scaleComponent.get('type');\n            const field = model.vgField(channel, { expr: 'datum', binSuffix: model.stack?.impute ? 'mid' : undefined });\n            // While discrete domain scales can handle invalid values, continuous scales can't.\n            if (field && (0,_scale__WEBPACK_IMPORTED_MODULE_1__.hasContinuousDomain)(scaleType)) {\n                aggregator[field] = true;\n            }\n        }\n        return aggregator;\n    }, {});\n    const fields = (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(filterIndex);\n    if (fields.length > 0) {\n        const op = invalid ? '||' : '&&';\n        return fields.map(field => (0,_valueref__WEBPACK_IMPORTED_MODULE_4__.fieldInvalidPredicate)(field, invalid)).join(` ${op} `);\n    }\n    return undefined;\n}\nfunction valueIfDefined(prop, value) {\n    if (value !== undefined) {\n        return { [prop]: (0,_common__WEBPACK_IMPORTED_MODULE_3__.signalOrValueRef)(value) };\n    }\n    return undefined;\n}\n//# sourceMappingURL=defined.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/defined.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/index.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/index.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   aria: () => (/* reexport safe */ _aria__WEBPACK_IMPORTED_MODULE_0__.aria),\n/* harmony export */   baseEncodeEntry: () => (/* reexport safe */ _base__WEBPACK_IMPORTED_MODULE_1__.baseEncodeEntry),\n/* harmony export */   color: () => (/* reexport safe */ _color__WEBPACK_IMPORTED_MODULE_2__.color),\n/* harmony export */   defined: () => (/* reexport safe */ _defined__WEBPACK_IMPORTED_MODULE_4__.defined),\n/* harmony export */   nonPosition: () => (/* reexport safe */ _nonposition__WEBPACK_IMPORTED_MODULE_5__.nonPosition),\n/* harmony export */   pointOrRangePosition: () => (/* reexport safe */ _position_range__WEBPACK_IMPORTED_MODULE_7__.pointOrRangePosition),\n/* harmony export */   pointPosition: () => (/* reexport safe */ _position_point__WEBPACK_IMPORTED_MODULE_6__.pointPosition),\n/* harmony export */   rangePosition: () => (/* reexport safe */ _position_range__WEBPACK_IMPORTED_MODULE_7__.rangePosition),\n/* harmony export */   rectPosition: () => (/* reexport safe */ _position_rect__WEBPACK_IMPORTED_MODULE_8__.rectPosition),\n/* harmony export */   text: () => (/* reexport safe */ _text__WEBPACK_IMPORTED_MODULE_9__.text),\n/* harmony export */   tooltip: () => (/* reexport safe */ _tooltip__WEBPACK_IMPORTED_MODULE_10__.tooltip),\n/* harmony export */   tooltipRefForEncoding: () => (/* reexport safe */ _tooltip__WEBPACK_IMPORTED_MODULE_10__.tooltipRefForEncoding),\n/* harmony export */   valueIfDefined: () => (/* reexport safe */ _defined__WEBPACK_IMPORTED_MODULE_4__.valueIfDefined),\n/* harmony export */   wrapCondition: () => (/* reexport safe */ _conditional__WEBPACK_IMPORTED_MODULE_3__.wrapCondition)\n/* harmony export */ });\n/* harmony import */ var _aria__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./aria */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/aria.js\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/base.js\");\n/* harmony import */ var _color__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./color */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/color.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n/* harmony import */ var _defined__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./defined */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/defined.js\");\n/* harmony import */ var _nonposition__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./nonposition */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js\");\n/* harmony import */ var _position_point__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./position-point */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js\");\n/* harmony import */ var _position_range__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./position-range */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js\");\n/* harmony import */ var _position_rect__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./position-rect */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-rect.js\");\n/* harmony import */ var _text__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./text */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/text.js\");\n/* harmony import */ var _tooltip__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./tooltip */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js\");\n\n\n\n\n\n\n\n\n\n\n\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   nonPosition: () => (/* binding */ nonPosition)\n/* harmony export */ });\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\n\n/**\n * Return encode for non-positional channels with scales. (Text doesn't have scale.)\n */\nfunction nonPosition(channel, model, opt = {}) {\n    const { markDef, encoding, config } = model;\n    const { vgChannel } = opt;\n    let { defaultRef, defaultValue } = opt;\n    if (defaultRef === undefined) {\n        // prettier-ignore\n        defaultValue ?? (defaultValue = (0,_common__WEBPACK_IMPORTED_MODULE_0__.getMarkPropOrConfig)(channel, markDef, config, { vgChannel, ignoreVgConfig: true }));\n        if (defaultValue !== undefined) {\n            defaultRef = (0,_common__WEBPACK_IMPORTED_MODULE_0__.signalOrValueRef)(defaultValue);\n        }\n    }\n    const channelDef = encoding[channel];\n    return (0,_conditional__WEBPACK_IMPORTED_MODULE_1__.wrapCondition)(model, channelDef, vgChannel ?? channel, cDef => {\n        return _valueref__WEBPACK_IMPORTED_MODULE_2__.midPoint({\n            channel,\n            channelDef: cDef,\n            markDef,\n            config,\n            scaleName: model.scaleName(channel),\n            scale: model.getScaleComponent(channel),\n            stack: null,\n            defaultRef\n        });\n    });\n}\n//# sourceMappingURL=nonposition.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   positionOffset: () => (/* binding */ positionOffset)\n/* harmony export */ });\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\nfunction positionOffset({ channel: baseChannel, markDef, encoding = {}, model, bandPosition }) {\n    const channel = `${baseChannel}Offset`; // Need to cast as the type can't be inferred automatically\n    const defaultValue = markDef[channel];\n    const channelDef = encoding[channel];\n    if ((channel === 'xOffset' || channel === 'yOffset') && channelDef) {\n        const ref = (0,_valueref__WEBPACK_IMPORTED_MODULE_1__.midPoint)({\n            channel: channel,\n            channelDef,\n            markDef,\n            config: model?.config,\n            scaleName: model.scaleName(channel),\n            scale: model.getScaleComponent(channel),\n            stack: null,\n            defaultRef: (0,_common__WEBPACK_IMPORTED_MODULE_0__.signalOrValueRef)(defaultValue),\n            bandPosition\n        });\n        return { offsetType: 'encoding', offset: ref };\n    }\n    const markDefOffsetValue = markDef[channel];\n    if (markDefOffsetValue) {\n        return { offsetType: 'visual', offset: markDefOffsetValue };\n    }\n    return {};\n}\n//# sourceMappingURL=offset.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/position-align.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/position-align.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   vgAlignedPositionChannel: () => (/* binding */ vgAlignedPositionChannel)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n\n\n\n\nconst ALIGNED_X_CHANNEL = {\n    left: 'x',\n    center: 'xc',\n    right: 'x2'\n};\nconst BASELINED_Y_CHANNEL = {\n    top: 'y',\n    middle: 'yc',\n    bottom: 'y2'\n};\nfunction vgAlignedPositionChannel(channel, markDef, config, defaultAlign = 'middle') {\n    if (channel === 'radius' || channel === 'theta') {\n        return (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getVgPositionChannel)(channel);\n    }\n    const alignChannel = channel === 'x' ? 'align' : 'baseline';\n    const align = (0,_common__WEBPACK_IMPORTED_MODULE_3__.getMarkPropOrConfig)(alignChannel, markDef, config);\n    let alignExcludingSignal;\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_2__.isSignalRef)(align)) {\n        _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.rangeMarkAlignmentCannotBeExpression(alignChannel));\n        alignExcludingSignal = undefined;\n    }\n    else {\n        alignExcludingSignal = align;\n    }\n    if (channel === 'x') {\n        return ALIGNED_X_CHANNEL[alignExcludingSignal || (defaultAlign === 'top' ? 'left' : 'center')];\n    }\n    else {\n        return BASELINED_Y_CHANNEL[alignExcludingSignal || defaultAlign];\n    }\n}\n//# sourceMappingURL=position-align.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/position-align.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   pointPosition: () => (/* binding */ pointPosition),\n/* harmony export */   pointPositionDefaultRef: () => (/* binding */ pointPositionDefaultRef),\n/* harmony export */   positionRef: () => (/* binding */ positionRef)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _offset__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./offset */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\n\n\n\n\n\n/**\n * Return encode for point (non-band) position channels.\n */\nfunction pointPosition(channel, model, { defaultPos, vgChannel }) {\n    const { encoding, markDef, config, stack } = model;\n    const channelDef = encoding[channel];\n    const channel2Def = encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSecondaryRangeChannel)(channel)];\n    const scaleName = model.scaleName(channel);\n    const scale = model.getScaleComponent(channel);\n    const { offset, offsetType } = (0,_offset__WEBPACK_IMPORTED_MODULE_5__.positionOffset)({\n        channel,\n        markDef,\n        encoding,\n        model,\n        bandPosition: 0.5\n    });\n    // Get default position or position from mark def\n    const defaultRef = pointPositionDefaultRef({\n        model,\n        defaultPos,\n        channel,\n        scaleName,\n        scale\n    });\n    const valueRef = !channelDef && (0,_channel__WEBPACK_IMPORTED_MODULE_0__.isXorY)(channel) && (encoding.latitude || encoding.longitude)\n        ? // use geopoint output if there are lat/long and there is no point position overriding lat/long.\n            { field: model.getName(channel) }\n        : positionRef({\n            channel,\n            channelDef,\n            channel2Def,\n            markDef,\n            config,\n            scaleName,\n            scale,\n            stack,\n            offset,\n            defaultRef,\n            bandPosition: offsetType === 'encoding' ? 0 : undefined\n        });\n    return valueRef ? { [vgChannel || channel]: valueRef } : undefined;\n}\n// TODO: we need to find a way to refactor these so that scaleName is a part of scale\n// but that's complicated. For now, this is a huge step moving forward.\n/**\n * @return Vega ValueRef for normal x- or y-position without projection\n */\nfunction positionRef(params) {\n    const { channel, channelDef, scaleName, stack, offset, markDef } = params;\n    // This isn't a part of midPoint because we use midPoint for non-position too\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldOrDatumDef)(channelDef) && stack && channel === stack.fieldChannel) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(channelDef)) {\n            let bandPosition = channelDef.bandPosition;\n            if (bandPosition === undefined && markDef.type === 'text' && (channel === 'radius' || channel === 'theta')) {\n                // theta and radius of text mark should use bandPosition = 0.5 by default\n                // so that labels for arc marks are centered automatically\n                bandPosition = 0.5;\n            }\n            if (bandPosition !== undefined) {\n                return _valueref__WEBPACK_IMPORTED_MODULE_6__.interpolatedSignalRef({\n                    scaleName,\n                    fieldOrDatumDef: channelDef,\n                    startSuffix: 'start',\n                    bandPosition,\n                    offset\n                });\n            }\n        }\n        // x or y use stack_end so that stacked line's point mark use stack_end too.\n        return _valueref__WEBPACK_IMPORTED_MODULE_6__.valueRefForFieldOrDatumDef(channelDef, scaleName, { suffix: 'end' }, { offset });\n    }\n    return _valueref__WEBPACK_IMPORTED_MODULE_6__.midPointRefWithPositionInvalidTest(params);\n}\nfunction pointPositionDefaultRef({ model, defaultPos, channel, scaleName, scale }) {\n    const { markDef, config } = model;\n    return () => {\n        const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getMainRangeChannel)(channel);\n        const vgChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getVgPositionChannel)(channel);\n        const definedValueOrConfig = (0,_common__WEBPACK_IMPORTED_MODULE_4__.getMarkPropOrConfig)(channel, markDef, config, { vgChannel });\n        if (definedValueOrConfig !== undefined) {\n            return _valueref__WEBPACK_IMPORTED_MODULE_6__.widthHeightValueOrSignalRef(channel, definedValueOrConfig);\n        }\n        switch (defaultPos) {\n            case 'zeroOrMin':\n            case 'zeroOrMax':\n                if (scaleName) {\n                    const scaleType = scale.get('type');\n                    if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.contains)([_scale__WEBPACK_IMPORTED_MODULE_2__.ScaleType.LOG, _scale__WEBPACK_IMPORTED_MODULE_2__.ScaleType.TIME, _scale__WEBPACK_IMPORTED_MODULE_2__.ScaleType.UTC], scaleType)) {\n                        // Log scales cannot have zero.\n                        // Zero in time scale is arbitrary, and does not affect ratio.\n                        // (Time is an interval level of measurement, not ratio).\n                        // See https://en.wikipedia.org/wiki/Level_of_measurement for more info.\n                    }\n                    else {\n                        if (scale.domainDefinitelyIncludesZero()) {\n                            return {\n                                scale: scaleName,\n                                value: 0\n                            };\n                        }\n                    }\n                }\n                if (defaultPos === 'zeroOrMin') {\n                    return mainChannel === 'y' ? { field: { group: 'height' } } : { value: 0 };\n                }\n                else {\n                    // zeroOrMax\n                    switch (mainChannel) {\n                        case 'radius':\n                            // max of radius is min(width, height) / 2\n                            return {\n                                signal: `min(${model.width.signal},${model.height.signal})/2`\n                            };\n                        case 'theta':\n                            return { signal: '2*PI' };\n                        case 'x':\n                            return { field: { group: 'width' } };\n                        case 'y':\n                            return { value: 0 };\n                    }\n                }\n                break;\n            case 'mid': {\n                const sizeRef = model[(0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel)];\n                return { ...sizeRef, mult: 0.5 };\n            }\n        }\n        // defaultPos === null\n        return undefined;\n    };\n}\n//# sourceMappingURL=position-point.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   pointOrRangePosition: () => (/* binding */ pointOrRangePosition),\n/* harmony export */   position2Ref: () => (/* binding */ position2Ref),\n/* harmony export */   rangePosition: () => (/* binding */ rangePosition)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _offset__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./offset */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js\");\n/* harmony import */ var _position_align__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./position-align */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-align.js\");\n/* harmony import */ var _position_point__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./position-point */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n\n\n\n\n\n\n\n\n\n/**\n * Utility for area/rule position, which can be either point or range.\n * (One of the axes should be point and the other should be range.)\n */\nfunction pointOrRangePosition(channel, model, { defaultPos, defaultPos2, range }) {\n    if (range) {\n        return rangePosition(channel, model, { defaultPos, defaultPos2 });\n    }\n    return (0,_position_point__WEBPACK_IMPORTED_MODULE_7__.pointPosition)(channel, model, { defaultPos });\n}\nfunction rangePosition(channel, model, { defaultPos, defaultPos2 }) {\n    const { markDef, config } = model;\n    const channel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSecondaryRangeChannel)(channel);\n    const sizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n    const pos2Mixins = pointPosition2OrSize(model, defaultPos2, channel2);\n    const vgChannel = pos2Mixins[sizeChannel]\n        ? // If there is width/height, we need to position the marks based on the alignment.\n            (0,_position_align__WEBPACK_IMPORTED_MODULE_6__.vgAlignedPositionChannel)(channel, markDef, config)\n        : // Otherwise, make sure to apply to the right Vg Channel (for arc mark)\n            (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getVgPositionChannel)(channel);\n    return {\n        ...(0,_position_point__WEBPACK_IMPORTED_MODULE_7__.pointPosition)(channel, model, { defaultPos, vgChannel }),\n        ...pos2Mixins\n    };\n}\n/**\n * Return encode for x2, y2.\n * If channel is not specified, return one channel based on orientation.\n */\nfunction pointPosition2OrSize(model, defaultPos, channel) {\n    const { encoding, mark, markDef, stack, config } = model;\n    const baseChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getMainRangeChannel)(channel);\n    const sizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n    const vgChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getVgPositionChannel)(channel);\n    const channelDef = encoding[baseChannel];\n    const scaleName = model.scaleName(baseChannel);\n    const scale = model.getScaleComponent(baseChannel);\n    const { offset } = channel in encoding || channel in markDef\n        ? (0,_offset__WEBPACK_IMPORTED_MODULE_5__.positionOffset)({ channel, markDef, encoding, model })\n        : (0,_offset__WEBPACK_IMPORTED_MODULE_5__.positionOffset)({ channel: baseChannel, markDef, encoding, model });\n    if (!channelDef && (channel === 'x2' || channel === 'y2') && (encoding.latitude || encoding.longitude)) {\n        const vgSizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n        const size = model.markDef[vgSizeChannel];\n        if (size != null) {\n            return {\n                [vgSizeChannel]: { value: size }\n            };\n        }\n        else {\n            return {\n                [vgChannel]: { field: model.getName(channel) }\n            };\n        }\n    }\n    const valueRef = position2Ref({\n        channel,\n        channelDef,\n        channel2Def: encoding[channel],\n        markDef,\n        config,\n        scaleName,\n        scale,\n        stack,\n        offset,\n        defaultRef: undefined\n    });\n    if (valueRef !== undefined) {\n        return { [vgChannel]: valueRef };\n    }\n    // TODO: check width/height encoding here once we add them\n    // no x2/y2 encoding, then try to read x2/y2 or width/height based on precedence:\n    // markDef > config.style > mark-specific config (config[mark]) > general mark config (config.mark)\n    return (position2orSize(channel, markDef) ||\n        position2orSize(channel, {\n            [channel]: (0,_common__WEBPACK_IMPORTED_MODULE_4__.getMarkStyleConfig)(channel, markDef, config.style),\n            [sizeChannel]: (0,_common__WEBPACK_IMPORTED_MODULE_4__.getMarkStyleConfig)(sizeChannel, markDef, config.style)\n        }) ||\n        position2orSize(channel, config[mark]) ||\n        position2orSize(channel, config.mark) || {\n        [vgChannel]: (0,_position_point__WEBPACK_IMPORTED_MODULE_7__.pointPositionDefaultRef)({\n            model,\n            defaultPos,\n            channel,\n            scaleName,\n            scale\n        })()\n    });\n}\nfunction position2Ref({ channel, channelDef, channel2Def, markDef, config, scaleName, scale, stack, offset, defaultRef }) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldOrDatumDef)(channelDef) &&\n        stack &&\n        // If fieldChannel is X and channel is X2 (or Y and Y2)\n        channel.charAt(0) === stack.fieldChannel.charAt(0)) {\n        return _valueref__WEBPACK_IMPORTED_MODULE_8__.valueRefForFieldOrDatumDef(channelDef, scaleName, { suffix: 'start' }, { offset });\n    }\n    return _valueref__WEBPACK_IMPORTED_MODULE_8__.midPointRefWithPositionInvalidTest({\n        channel,\n        channelDef: channel2Def,\n        scaleName,\n        scale,\n        stack,\n        markDef,\n        config,\n        offset,\n        defaultRef\n    });\n}\nfunction position2orSize(channel, markDef) {\n    const sizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel);\n    const vgChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getVgPositionChannel)(channel);\n    if (markDef[vgChannel] !== undefined) {\n        return { [vgChannel]: _valueref__WEBPACK_IMPORTED_MODULE_8__.widthHeightValueOrSignalRef(channel, markDef[vgChannel]) };\n    }\n    else if (markDef[channel] !== undefined) {\n        return { [vgChannel]: _valueref__WEBPACK_IMPORTED_MODULE_8__.widthHeightValueOrSignalRef(channel, markDef[channel]) };\n    }\n    else if (markDef[sizeChannel]) {\n        const dimensionSize = markDef[sizeChannel];\n        if ((0,_mark__WEBPACK_IMPORTED_MODULE_3__.isRelativeBandSize)(dimensionSize)) {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.relativeBandSizeNotSupported(sizeChannel));\n        }\n        else {\n            return { [sizeChannel]: _valueref__WEBPACK_IMPORTED_MODULE_8__.widthHeightValueOrSignalRef(channel, dimensionSize) };\n        }\n    }\n    return undefined;\n}\n//# sourceMappingURL=position-range.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/position-rect.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/position-rect.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   rectBinRef: () => (/* binding */ rectBinRef),\n/* harmony export */   rectPosition: () => (/* binding */ rectPosition)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _nonposition__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./nonposition */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/nonposition.js\");\n/* harmony import */ var _offset__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./offset */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/offset.js\");\n/* harmony import */ var _position_align__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./position-align */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-align.js\");\n/* harmony import */ var _position_point__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./position-point */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-point.js\");\n/* harmony import */ var _position_range__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./position-range */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/position-range.js\");\n/* harmony import */ var _valueref__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./valueref */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction rectPosition(model, channel) {\n    const { config, encoding, markDef } = model;\n    const mark = markDef.type;\n    const channel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSecondaryRangeChannel)(channel);\n    const sizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSizeChannel)(channel);\n    const channelDef = encoding[channel];\n    const channelDef2 = encoding[channel2];\n    const scale = model.getScaleComponent(channel);\n    const scaleType = scale ? scale.get('type') : undefined;\n    const orient = markDef.orient;\n    const hasSizeDef = encoding[sizeChannel] ?? encoding.size ?? (0,_common__WEBPACK_IMPORTED_MODULE_9__.getMarkPropOrConfig)('size', markDef, config, { vgChannel: sizeChannel });\n    const offsetScaleChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getOffsetChannel)(channel);\n    const isBarBand = mark === 'bar' && (channel === 'x' ? orient === 'vertical' : orient === 'horizontal');\n    // x, x2, and width -- we must specify two of these in all conditions\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(channelDef) &&\n        ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(channelDef.bin) || (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(channelDef.bin) || (channelDef.timeUnit && !channelDef2)) &&\n        !(hasSizeDef && !(0,_mark__WEBPACK_IMPORTED_MODULE_6__.isRelativeBandSize)(hasSizeDef)) &&\n        !encoding[offsetScaleChannel] &&\n        !(0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasDiscreteDomain)(scaleType)) {\n        return rectBinPosition({\n            fieldDef: channelDef,\n            fieldDef2: channelDef2,\n            channel,\n            model\n        });\n    }\n    else if ((((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(channelDef) && (0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasDiscreteDomain)(scaleType)) || isBarBand) && !channelDef2) {\n        return positionAndSize(channelDef, channel, model);\n    }\n    else {\n        return (0,_position_range__WEBPACK_IMPORTED_MODULE_14__.rangePosition)(channel, model, { defaultPos: 'zeroOrMax', defaultPos2: 'zeroOrMin' });\n    }\n}\nfunction defaultSizeRef(sizeChannel, scaleName, scale, config, bandSize, hasFieldDef, mark) {\n    if ((0,_mark__WEBPACK_IMPORTED_MODULE_6__.isRelativeBandSize)(bandSize)) {\n        if (scale) {\n            const scaleType = scale.get('type');\n            if (scaleType === 'band') {\n                let bandWidth = `bandwidth('${scaleName}')`;\n                if (bandSize.band !== 1) {\n                    bandWidth = `${bandSize.band} * ${bandWidth}`;\n                }\n                const minBandSize = (0,_common__WEBPACK_IMPORTED_MODULE_9__.getMarkConfig)('minBandSize', { type: mark }, config);\n                return { signal: minBandSize ? `max(${(0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrStringValue)(minBandSize)}, ${bandWidth})` : bandWidth };\n            }\n            else if (bandSize.band !== 1) {\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.cannotUseRelativeBandSizeWithNonBandScale(scaleType));\n                bandSize = undefined;\n            }\n        }\n        else {\n            return {\n                mult: bandSize.band,\n                field: { group: sizeChannel }\n            };\n        }\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(bandSize)) {\n        return bandSize;\n    }\n    else if (bandSize) {\n        return { value: bandSize };\n    }\n    // no valid band size\n    if (scale) {\n        const scaleRange = scale.get('range');\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isVgRangeStep)(scaleRange) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(scaleRange.step)) {\n            return { value: scaleRange.step - 2 };\n        }\n    }\n    if (!hasFieldDef) {\n        const { bandPaddingInner, barBandPaddingInner, rectBandPaddingInner } = config.scale;\n        const padding = (0,_util__WEBPACK_IMPORTED_MODULE_16__.getFirstDefined)(bandPaddingInner, mark === 'bar' ? barBandPaddingInner : rectBandPaddingInner); // this part is like paddingInner in scale.ts\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(padding)) {\n            return { signal: `(1 - (${padding.signal})) * ${sizeChannel}` };\n        }\n        else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(padding)) {\n            return { signal: `${1 - padding} * ${sizeChannel}` };\n        }\n    }\n    const defaultStep = (0,_config__WEBPACK_IMPORTED_MODULE_4__.getViewConfigDiscreteStep)(config.view, sizeChannel);\n    return { value: defaultStep - 2 };\n}\n/**\n * Output position encoding and its size encoding for continuous, point, and band scales.\n */\nfunction positionAndSize(fieldDef, channel, model) {\n    const { markDef, encoding, config, stack } = model;\n    const orient = markDef.orient;\n    const scaleName = model.scaleName(channel);\n    const scale = model.getScaleComponent(channel);\n    const vgSizeChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSizeChannel)(channel);\n    const channel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSecondaryRangeChannel)(channel);\n    const offsetScaleChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getOffsetChannel)(channel);\n    const offsetScaleName = model.scaleName(offsetScaleChannel);\n    const offsetScale = model.getScaleComponent((0,_channel__WEBPACK_IMPORTED_MODULE_2__.getOffsetScaleChannel)(channel));\n    // use \"size\" channel for bars, if there is orient and the channel matches the right orientation\n    const useVlSizeChannel = (orient === 'horizontal' && channel === 'y') || (orient === 'vertical' && channel === 'x');\n    // Use size encoding / mark property / config if it exists\n    let sizeMixins;\n    if (encoding.size || markDef.size) {\n        if (useVlSizeChannel) {\n            sizeMixins = (0,_nonposition__WEBPACK_IMPORTED_MODULE_10__.nonPosition)('size', model, {\n                vgChannel: vgSizeChannel,\n                defaultRef: (0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrValueRef)(markDef.size)\n            });\n        }\n        else {\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.cannotApplySizeToNonOrientedMark(markDef.type));\n        }\n    }\n    const hasSizeFromMarkOrEncoding = !!sizeMixins;\n    // Otherwise, apply default value\n    const bandSize = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getBandSize)({ channel, fieldDef, markDef, config, scaleType: scale?.get('type'), useVlSizeChannel });\n    sizeMixins = sizeMixins || {\n        [vgSizeChannel]: defaultSizeRef(vgSizeChannel, offsetScaleName || scaleName, offsetScale || scale, config, bandSize, !!fieldDef, markDef.type)\n    };\n    /*\n      Band scales with size value and all point scales, use xc/yc + band=0.5\n  \n      Otherwise (band scales that has size based on a band ref), use x/y with position band = (1 - size_band) / 2.\n      In this case, size_band is the band specified in the x/y-encoding.\n      By default band is 1, so `(1 - band) / 2` = 0.\n      If band is 0.6, the the x/y position in such case should be `(1 - band) / 2` = 0.2\n     */\n    const defaultBandAlign = scale?.get('type') === 'band' && (0,_mark__WEBPACK_IMPORTED_MODULE_6__.isRelativeBandSize)(bandSize) && !hasSizeFromMarkOrEncoding ? 'top' : 'middle';\n    const vgChannel = (0,_position_align__WEBPACK_IMPORTED_MODULE_12__.vgAlignedPositionChannel)(channel, markDef, config, defaultBandAlign);\n    const center = vgChannel === 'xc' || vgChannel === 'yc';\n    const { offset, offsetType } = (0,_offset__WEBPACK_IMPORTED_MODULE_11__.positionOffset)({ channel, markDef, encoding, model, bandPosition: center ? 0.5 : 0 });\n    const posRef = _valueref__WEBPACK_IMPORTED_MODULE_15__.midPointRefWithPositionInvalidTest({\n        channel,\n        channelDef: fieldDef,\n        markDef,\n        config,\n        scaleName,\n        scale,\n        stack,\n        offset,\n        defaultRef: (0,_position_point__WEBPACK_IMPORTED_MODULE_13__.pointPositionDefaultRef)({ model, defaultPos: 'mid', channel, scaleName, scale }),\n        bandPosition: center\n            ? offsetType === 'encoding'\n                ? 0\n                : 0.5\n            : (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(bandSize)\n                ? { signal: `(1-${bandSize})/2` }\n                : (0,_mark__WEBPACK_IMPORTED_MODULE_6__.isRelativeBandSize)(bandSize)\n                    ? (1 - bandSize.band) / 2\n                    : 0\n    });\n    if (vgSizeChannel) {\n        return { [vgChannel]: posRef, ...sizeMixins };\n    }\n    else {\n        // otherwise, we must simulate size by setting position2 = position + size\n        // (for theta/radius since Vega doesn't have thetaWidth/radiusWidth)\n        const vgChannel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getVgPositionChannel)(channel2);\n        const sizeRef = sizeMixins[vgSizeChannel];\n        const sizeOffset = offset ? { ...sizeRef, offset } : sizeRef;\n        return {\n            [vgChannel]: posRef,\n            // posRef might be an array that wraps position invalid test\n            [vgChannel2]: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(posRef)\n                ? [posRef[0], { ...posRef[1], offset: sizeOffset }]\n                : {\n                    ...posRef,\n                    offset: sizeOffset\n                }\n        };\n    }\n}\nfunction getBinSpacing(channel, spacing, reverse, translate, offset, minBandSize, bandSizeExpr) {\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isPolarPositionChannel)(channel)) {\n        return 0;\n    }\n    const isEnd = channel === 'x' || channel === 'y2';\n    const spacingOffset = isEnd ? -spacing / 2 : spacing / 2;\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(reverse) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(offset) || (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(translate) || minBandSize) {\n        const reverseExpr = (0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrStringValue)(reverse);\n        const offsetExpr = (0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrStringValue)(offset);\n        const translateExpr = (0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrStringValue)(translate);\n        const minBandSizeExpr = (0,_common__WEBPACK_IMPORTED_MODULE_9__.signalOrStringValue)(minBandSize);\n        const sign = isEnd ? '' : '-';\n        const spacingAndSizeOffset = minBandSize\n            ? `(${bandSizeExpr} < ${minBandSizeExpr} ? ${sign}0.5 * (${minBandSizeExpr} - (${bandSizeExpr})) : ${spacingOffset})`\n            : spacingOffset;\n        const t = translateExpr ? `${translateExpr} + ` : '';\n        const r = reverseExpr ? `(${reverseExpr} ? -1 : 1) * ` : '';\n        const o = offsetExpr ? `(${offsetExpr} + ${spacingAndSizeOffset})` : spacingAndSizeOffset;\n        return {\n            signal: t + r + o\n        };\n    }\n    else {\n        offset = offset || 0;\n        return translate + (reverse ? -offset - spacingOffset : +offset + spacingOffset);\n    }\n}\nfunction rectBinPosition({ fieldDef, fieldDef2, channel, model }) {\n    const { config, markDef, encoding } = model;\n    const scale = model.getScaleComponent(channel);\n    const scaleName = model.scaleName(channel);\n    const scaleType = scale ? scale.get('type') : undefined;\n    const reverse = scale.get('reverse');\n    const bandSize = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getBandSize)({ channel, fieldDef, markDef, config, scaleType });\n    const axis = model.component.axes[channel]?.[0];\n    const axisTranslate = axis?.get('translate') ?? 0.5; // vega default is 0.5\n    const spacing = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel) ? (0,_common__WEBPACK_IMPORTED_MODULE_9__.getMarkPropOrConfig)('binSpacing', markDef, config) ?? 0 : 0;\n    const channel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSecondaryRangeChannel)(channel);\n    const vgChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getVgPositionChannel)(channel);\n    const vgChannel2 = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getVgPositionChannel)(channel2);\n    const minBandSize = (0,_common__WEBPACK_IMPORTED_MODULE_9__.getMarkConfig)('minBandSize', markDef, config);\n    const { offset } = (0,_offset__WEBPACK_IMPORTED_MODULE_11__.positionOffset)({ channel, markDef, encoding, model, bandPosition: 0 });\n    const { offset: offset2 } = (0,_offset__WEBPACK_IMPORTED_MODULE_11__.positionOffset)({ channel: channel2, markDef, encoding, model, bandPosition: 0 });\n    const bandSizeExpr = _valueref__WEBPACK_IMPORTED_MODULE_15__.binSizeExpr({ fieldDef, scaleName });\n    const binSpacingOffset = getBinSpacing(channel, spacing, reverse, axisTranslate, offset, minBandSize, bandSizeExpr);\n    const binSpacingOffset2 = getBinSpacing(channel2, spacing, reverse, axisTranslate, offset2 ?? offset, minBandSize, bandSizeExpr);\n    const bandPosition = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(bandSize)\n        ? { signal: `(1-${bandSize.signal})/2` }\n        : (0,_mark__WEBPACK_IMPORTED_MODULE_6__.isRelativeBandSize)(bandSize)\n            ? (1 - bandSize.band) / 2\n            : 0.5;\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(fieldDef.bin) || fieldDef.timeUnit) {\n        return {\n            [vgChannel2]: rectBinRef({\n                fieldDef,\n                scaleName,\n                bandPosition,\n                offset: binSpacingOffset2\n            }),\n            [vgChannel]: rectBinRef({\n                fieldDef,\n                scaleName,\n                bandPosition: (0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(bandPosition) ? { signal: `1-${bandPosition.signal}` } : 1 - bandPosition,\n                offset: binSpacingOffset\n            })\n        };\n    }\n    else if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(fieldDef.bin)) {\n        const startRef = _valueref__WEBPACK_IMPORTED_MODULE_15__.valueRefForFieldOrDatumDef(fieldDef, scaleName, {}, { offset: binSpacingOffset2 });\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldDef2)) {\n            return {\n                [vgChannel2]: startRef,\n                [vgChannel]: _valueref__WEBPACK_IMPORTED_MODULE_15__.valueRefForFieldOrDatumDef(fieldDef2, scaleName, {}, { offset: binSpacingOffset })\n            };\n        }\n        else if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinParams)(fieldDef.bin) && fieldDef.bin.step) {\n            return {\n                [vgChannel2]: startRef,\n                [vgChannel]: {\n                    signal: `scale(\"${scaleName}\", ${(0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, { expr: 'datum' })} + ${fieldDef.bin.step})`,\n                    offset: binSpacingOffset\n                }\n            };\n        }\n    }\n    _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.channelRequiredForBinned(channel2));\n    return undefined;\n}\n/**\n * Value Ref for binned fields\n */\nfunction rectBinRef({ fieldDef, scaleName, bandPosition, offset }) {\n    return _valueref__WEBPACK_IMPORTED_MODULE_15__.interpolatedSignalRef({\n        scaleName,\n        fieldOrDatumDef: fieldDef,\n        bandPosition,\n        offset\n    });\n}\n//# sourceMappingURL=position-rect.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/position-rect.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/text.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/text.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   text: () => (/* binding */ text),\n/* harmony export */   textRef: () => (/* binding */ textRef)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n\n\n\n\nfunction text(model, channel = 'text') {\n    const channelDef = model.encoding[channel];\n    return (0,_conditional__WEBPACK_IMPORTED_MODULE_3__.wrapCondition)(model, channelDef, channel, cDef => textRef(cDef, model.config));\n}\nfunction textRef(channelDef, config, expr = 'datum') {\n    // text\n    if (channelDef) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isValueDef)(channelDef)) {\n            return (0,_common__WEBPACK_IMPORTED_MODULE_1__.signalOrValueRef)(channelDef.value);\n        }\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(channelDef)) {\n            const { format, formatType } = (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.getFormatMixins)(channelDef);\n            return (0,_format__WEBPACK_IMPORTED_MODULE_2__.formatSignalRef)({ fieldOrDatumDef: channelDef, format, formatType, expr, config });\n        }\n    }\n    return undefined;\n}\n//# sourceMappingURL=text.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/text.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   tooltip: () => (/* binding */ tooltip),\n/* harmony export */   tooltipData: () => (/* binding */ tooltipData),\n/* harmony export */   tooltipRefForEncoding: () => (/* binding */ tooltipRefForEncoding)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _format__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../format */ \"../../node_modules/vega-lite/build/src/compile/format.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n/* harmony import */ var _text__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./text */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/text.js\");\n\n\n\n\n\n\n\n\n\n\n\nfunction tooltip(model, opt = {}) {\n    const { encoding, markDef, config, stack } = model;\n    const channelDef = encoding.tooltip;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef)) {\n        return { tooltip: tooltipRefForEncoding({ tooltip: channelDef }, stack, config, opt) };\n    }\n    else {\n        const datum = opt.reactiveGeom ? 'datum.datum' : 'datum';\n        return (0,_conditional__WEBPACK_IMPORTED_MODULE_9__.wrapCondition)(model, channelDef, 'tooltip', cDef => {\n            // use valueRef based on channelDef first\n            const tooltipRefFromChannelDef = (0,_text__WEBPACK_IMPORTED_MODULE_10__.textRef)(cDef, config, datum);\n            if (tooltipRefFromChannelDef) {\n                return tooltipRefFromChannelDef;\n            }\n            if (cDef === null) {\n                // Allow using encoding.tooltip = null to disable tooltip\n                return undefined;\n            }\n            let markTooltip = (0,_common__WEBPACK_IMPORTED_MODULE_7__.getMarkPropOrConfig)('tooltip', markDef, config);\n            if (markTooltip === true) {\n                markTooltip = { content: 'encoding' };\n            }\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(markTooltip)) {\n                return { value: markTooltip };\n            }\n            else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(markTooltip)) {\n                // `tooltip` is `{fields: 'encodings' | 'fields'}`\n                if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_6__.isSignalRef)(markTooltip)) {\n                    return markTooltip;\n                }\n                else if (markTooltip.content === 'encoding') {\n                    return tooltipRefForEncoding(encoding, stack, config, opt);\n                }\n                else {\n                    return { signal: datum };\n                }\n            }\n            return undefined;\n        });\n    }\n}\nfunction tooltipData(encoding, stack, config, { reactiveGeom } = {}) {\n    const formatConfig = { ...config, ...config.tooltipFormat };\n    const toSkip = {};\n    const expr = reactiveGeom ? 'datum.datum' : 'datum';\n    const tuples = [];\n    function add(fDef, channel) {\n        const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getMainRangeChannel)(channel);\n        const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isTypedFieldDef)(fDef)\n            ? fDef\n            : {\n                ...fDef,\n                type: encoding[mainChannel].type // for secondary field def, copy type from main channel\n            };\n        const title = fieldDef.title || (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.defaultTitle)(fieldDef, formatConfig);\n        const key = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(title).join(', ').replaceAll(/\"/g, '\\\\\"');\n        let value;\n        if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n            const channel2 = channel === 'x' ? 'x2' : 'y2';\n            const fieldDef2 = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldDef)(encoding[channel2]);\n            if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(fieldDef.bin) && fieldDef2) {\n                const startField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, { expr });\n                const endField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef2, { expr });\n                const { format, formatType } = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFormatMixins)(fieldDef);\n                value = (0,_format__WEBPACK_IMPORTED_MODULE_8__.binFormatExpression)(startField, endField, format, formatType, formatConfig);\n                toSkip[channel2] = true;\n            }\n        }\n        if (((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel) || channel === _channel__WEBPACK_IMPORTED_MODULE_2__.THETA || channel === _channel__WEBPACK_IMPORTED_MODULE_2__.RADIUS) &&\n            stack &&\n            stack.fieldChannel === channel &&\n            stack.offset === 'normalize') {\n            const { format, formatType } = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFormatMixins)(fieldDef);\n            value = (0,_format__WEBPACK_IMPORTED_MODULE_8__.formatSignalRef)({\n                fieldOrDatumDef: fieldDef,\n                format,\n                formatType,\n                expr,\n                config: formatConfig,\n                normalizeStack: true\n            }).signal;\n        }\n        value ?? (value = (0,_text__WEBPACK_IMPORTED_MODULE_10__.textRef)(fieldDef, formatConfig, expr).signal);\n        tuples.push({ channel, key, value });\n    }\n    (0,_encoding__WEBPACK_IMPORTED_MODULE_4__.forEach)(encoding, (channelDef, channel) => {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(channelDef)) {\n            add(channelDef, channel);\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.hasConditionalFieldDef)(channelDef)) {\n            add(channelDef.condition, channel);\n        }\n    });\n    const out = {};\n    for (const { channel, key, value } of tuples) {\n        if (!toSkip[channel] && !out[key]) {\n            out[key] = value;\n        }\n    }\n    return out;\n}\nfunction tooltipRefForEncoding(encoding, stack, config, { reactiveGeom } = {}) {\n    const data = tooltipData(encoding, stack, config, { reactiveGeom });\n    const keyValues = (0,_util__WEBPACK_IMPORTED_MODULE_5__.entries)(data).map(([key, value]) => `\"${key}\": ${value}`);\n    return keyValues.length > 0 ? { signal: `{${keyValues.join(', ')}}` } : undefined;\n}\n//# sourceMappingURL=tooltip.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/tooltip.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js":
/*!******************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   binSizeExpr: () => (/* binding */ binSizeExpr),\n/* harmony export */   datumDefToExpr: () => (/* binding */ datumDefToExpr),\n/* harmony export */   fieldInvalidPredicate: () => (/* binding */ fieldInvalidPredicate),\n/* harmony export */   fieldInvalidTestValueRef: () => (/* binding */ fieldInvalidTestValueRef),\n/* harmony export */   interpolatedSignalRef: () => (/* binding */ interpolatedSignalRef),\n/* harmony export */   midPoint: () => (/* binding */ midPoint),\n/* harmony export */   midPointRefWithPositionInvalidTest: () => (/* binding */ midPointRefWithPositionInvalidTest),\n/* harmony export */   valueRefForFieldOrDatumDef: () => (/* binding */ valueRefForFieldOrDatumDef),\n/* harmony export */   widthHeightValueOrSignalRef: () => (/* binding */ widthHeightValueOrSignalRef),\n/* harmony export */   wrapPositionInvalidTest: () => (/* binding */ wrapPositionInvalidTest)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../../predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction midPointRefWithPositionInvalidTest(params) {\n    const { channel, channelDef, markDef, scale, config } = params;\n    const ref = midPoint(params);\n    // Wrap to check if the positional value is invalid, if so, plot the point on the min value\n    if (\n    // Only this for field def without counting aggregate (as count wouldn't be null)\n    (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef) &&\n        !(0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isCountingAggregateOp)(channelDef.aggregate) &&\n        // and only for continuous scale\n        scale &&\n        (0,_scale__WEBPACK_IMPORTED_MODULE_10__.isContinuousToContinuous)(scale.get('type'))) {\n        return wrapPositionInvalidTest({\n            fieldDef: channelDef,\n            channel,\n            markDef,\n            ref,\n            config\n        });\n    }\n    return ref;\n}\nfunction wrapPositionInvalidTest({ fieldDef, channel, markDef, ref, config }) {\n    if ((0,_mark__WEBPACK_IMPORTED_MODULE_8__.isPathMark)(markDef.type)) {\n        // path mark already use defined to skip points, no need to do it here.\n        return ref;\n    }\n    const invalid = (0,_common__WEBPACK_IMPORTED_MODULE_14__.getMarkPropOrConfig)('invalid', markDef, config);\n    if (invalid === null) {\n        // if there is no invalid filter, don't do the invalid test\n        return [fieldInvalidTestValueRef(fieldDef, channel), ref];\n    }\n    return ref;\n}\nfunction fieldInvalidTestValueRef(fieldDef, channel) {\n    const test = fieldInvalidPredicate(fieldDef, true);\n    const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.getMainRangeChannel)(channel); // we can cast here as the output can't be other things.\n    const zeroValueRef = mainChannel === 'y'\n        ? { field: { group: 'height' } }\n        : // x / angle / radius can all use 0\n            { value: 0 };\n    return { test, ...zeroValueRef };\n}\nfunction fieldInvalidPredicate(field, invalid = true) {\n    return (0,_predicate__WEBPACK_IMPORTED_MODULE_9__.fieldValidPredicate)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field) ? field : (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(field, { expr: 'datum' }), !invalid);\n}\nfunction datumDefToExpr(datumDef) {\n    const { datum } = datumDef;\n    if ((0,_datetime__WEBPACK_IMPORTED_MODULE_5__.isDateTime)(datum)) {\n        return (0,_datetime__WEBPACK_IMPORTED_MODULE_5__.dateTimeToExpr)(datum);\n    }\n    return `${(0,_util__WEBPACK_IMPORTED_MODULE_12__.stringify)(datum)}`;\n}\nfunction valueRefForFieldOrDatumDef(fieldDef, scaleName, opt, encode) {\n    const ref = {};\n    if (scaleName) {\n        ref.scale = scaleName;\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isDatumDef)(fieldDef)) {\n        const { datum } = fieldDef;\n        if ((0,_datetime__WEBPACK_IMPORTED_MODULE_5__.isDateTime)(datum)) {\n            ref.signal = (0,_datetime__WEBPACK_IMPORTED_MODULE_5__.dateTimeToExpr)(datum);\n        }\n        else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_13__.isSignalRef)(datum)) {\n            ref.signal = datum.signal;\n        }\n        else if ((0,_expr__WEBPACK_IMPORTED_MODULE_6__.isExprRef)(datum)) {\n            ref.signal = datum.expr;\n        }\n        else {\n            ref.value = datum;\n        }\n    }\n    else {\n        ref.field = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDef, opt);\n    }\n    if (encode) {\n        const { offset, band } = encode;\n        if (offset) {\n            ref.offset = offset;\n        }\n        if (band) {\n            ref.band = band;\n        }\n    }\n    return ref;\n}\n/**\n * Signal that returns the middle of a bin from start and end field. Should only be used with x and y.\n */\nfunction interpolatedSignalRef({ scaleName, fieldOrDatumDef, fieldOrDatumDef2, offset, startSuffix, bandPosition = 0.5 }) {\n    const expr = 0 < bandPosition && bandPosition < 1 ? 'datum' : undefined;\n    const start = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldOrDatumDef, { expr, suffix: startSuffix });\n    const end = fieldOrDatumDef2 !== undefined\n        ? (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldOrDatumDef2, { expr })\n        : (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldOrDatumDef, { suffix: 'end', expr });\n    const ref = {};\n    if (bandPosition === 0 || bandPosition === 1) {\n        ref.scale = scaleName;\n        const field = bandPosition === 0 ? start : end;\n        ref.field = field;\n    }\n    else {\n        const datum = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_13__.isSignalRef)(bandPosition)\n            ? `${bandPosition.signal} * ${start} + (1-${bandPosition.signal}) * ${end}`\n            : `${bandPosition} * ${start} + ${1 - bandPosition} * ${end}`;\n        ref.signal = `scale(\"${scaleName}\", ${datum})`;\n    }\n    if (offset) {\n        ref.offset = offset;\n    }\n    return ref;\n}\nfunction binSizeExpr({ scaleName, fieldDef }) {\n    const start = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDef, { expr: 'datum' });\n    const end = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDef, { expr: 'datum', suffix: 'end' });\n    return `abs(scale(\"${scaleName}\", ${end}) - scale(\"${scaleName}\", ${start}))`;\n}\n/**\n * @returns {VgValueRef} Value Ref for xc / yc or mid point for other channels.\n */\nfunction midPoint({ channel, channelDef, channel2Def, markDef, config, scaleName, scale, stack, offset, defaultRef, bandPosition }) {\n    // TODO: datum support\n    if (channelDef) {\n        /* istanbul ignore else */\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldOrDatumDef)(channelDef)) {\n            const scaleType = scale?.get('type');\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isTypedFieldDef)(channelDef)) {\n                bandPosition ?? (bandPosition = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getBandPosition)({\n                    fieldDef: channelDef,\n                    fieldDef2: channel2Def,\n                    markDef,\n                    config\n                }));\n                const { bin, timeUnit, type } = channelDef;\n                if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin) || (bandPosition && timeUnit && type === _type__WEBPACK_IMPORTED_MODULE_11__.TEMPORAL)) {\n                    // Use middle only for x an y to place marks in the center between start and end of the bin range.\n                    // We do not use the mid point for other channels (e.g. size) so that properties of legends and marks match.\n                    if (stack?.impute) {\n                        // For stack, we computed bin_mid so we can impute.\n                        return valueRefForFieldOrDatumDef(channelDef, scaleName, { binSuffix: 'mid' }, { offset });\n                    }\n                    if (bandPosition && !(0,_scale__WEBPACK_IMPORTED_MODULE_10__.hasDiscreteDomain)(scaleType)) {\n                        // if band = 0, no need to call interpolation\n                        // For non-stack, we can just calculate bin mid on the fly using signal.\n                        return interpolatedSignalRef({ scaleName, fieldOrDatumDef: channelDef, bandPosition, offset });\n                    }\n                    return valueRefForFieldOrDatumDef(channelDef, scaleName, (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.binRequiresRange)(channelDef, channel) ? { binSuffix: 'range' } : {}, {\n                        offset\n                    });\n                }\n                else if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinned)(bin)) {\n                    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channel2Def)) {\n                        return interpolatedSignalRef({\n                            scaleName,\n                            fieldOrDatumDef: channelDef,\n                            fieldOrDatumDef2: channel2Def,\n                            bandPosition,\n                            offset\n                        });\n                    }\n                    else {\n                        const channel2 = channel === _channel__WEBPACK_IMPORTED_MODULE_3__.X ? _channel__WEBPACK_IMPORTED_MODULE_3__.X2 : _channel__WEBPACK_IMPORTED_MODULE_3__.Y2;\n                        _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.channelRequiredForBinned(channel2));\n                    }\n                }\n            }\n            return valueRefForFieldOrDatumDef(channelDef, scaleName, (0,_scale__WEBPACK_IMPORTED_MODULE_10__.hasDiscreteDomain)(scaleType) ? { binSuffix: 'range' } : {}, // no need for bin suffix if there is no scale\n            {\n                offset,\n                // For band, to get mid point, need to offset by half of the band\n                band: scaleType === 'band' ? bandPosition ?? channelDef.bandPosition ?? 0.5 : undefined\n            });\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isValueDef)(channelDef)) {\n            const value = channelDef.value;\n            const offsetMixins = offset ? { offset } : {};\n            return { ...widthHeightValueOrSignalRef(channel, value), ...offsetMixins };\n        }\n        // If channelDef is neither field def or value def, it's a condition-only def.\n        // In such case, we will use default ref.\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(defaultRef)) {\n        defaultRef = defaultRef();\n    }\n    if (defaultRef) {\n        // for non-position, ref could be undefined.\n        return {\n            ...defaultRef,\n            // only include offset when it is non-zero (zero = no offset)\n            ...(offset ? { offset } : {})\n        };\n    }\n    return defaultRef;\n}\n/**\n * Convert special \"width\" and \"height\" values in Vega-Lite into Vega value ref.\n */\nfunction widthHeightValueOrSignalRef(channel, value) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_12__.contains)(['x', 'x2'], channel) && value === 'width') {\n        return { field: { group: 'width' } };\n    }\n    else if ((0,_util__WEBPACK_IMPORTED_MODULE_12__.contains)(['y', 'y2'], channel) && value === 'height') {\n        return { field: { group: 'height' } };\n    }\n    return (0,_common__WEBPACK_IMPORTED_MODULE_14__.signalOrValueRef)(value);\n}\n//# sourceMappingURL=valueref.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/valueref.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/encode/zindex.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/encode/zindex.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   zindex: () => (/* binding */ zindex)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _conditional__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./conditional */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/conditional.js\");\n\n\n\n\nfunction zindex(model) {\n    const { encoding, mark } = model;\n    const order = encoding.order;\n    if (!(0,_mark__WEBPACK_IMPORTED_MODULE_1__.isPathMark)(mark) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isValueDef)(order)) {\n        return (0,_conditional__WEBPACK_IMPORTED_MODULE_3__.wrapCondition)(model, order, 'zindex', cd => (0,_common__WEBPACK_IMPORTED_MODULE_2__.signalOrValueRef)(cd.value));\n    }\n    return {};\n}\n//# sourceMappingURL=zindex.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/encode/zindex.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/geoshape.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/geoshape.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   geoshape: () => (/* binding */ geoshape)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\n\n\nconst geoshape = {\n    vgMark: 'shape',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_2__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                size: 'ignore',\n                orient: 'ignore',\n                theta: 'ignore'\n            })\n        };\n    },\n    postEncodingTransform: (model) => {\n        const { encoding } = model;\n        const shapeDef = encoding.shape;\n        const transform = {\n            type: 'geoshape',\n            projection: model.projectionName(),\n            // as: 'shape',\n            ...(shapeDef && (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldDef)(shapeDef) && shapeDef.type === _type__WEBPACK_IMPORTED_MODULE_1__.GEOJSON\n                ? { field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.vgField)(shapeDef, { expr: 'datum' }) }\n                : {})\n        };\n        return [transform];\n    }\n};\n//# sourceMappingURL=geoshape.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/geoshape.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/image.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/image.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   image: () => (/* binding */ image)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst image = {\n    vgMark: 'image',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'ignore',\n                orient: 'ignore',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'x'),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'y'),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.text(model, 'url')\n        };\n    }\n};\n//# sourceMappingURL=image.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/image.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/init.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/init.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   defaultFilled: () => (/* binding */ defaultFilled),\n/* harmony export */   initMarkdef: () => (/* binding */ initMarkdef)\n/* harmony export */ });\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n\n\n\n\n\n\n\n\n\nfunction initMarkdef(originalMarkDef, encoding, config) {\n    // FIXME: markDef expects that exprRefs are replaced recursively but replaceExprRef only replaces the top level\n    const markDef = (0,_expr__WEBPACK_IMPORTED_MODULE_3__.replaceExprRef)(originalMarkDef);\n    // set orient, which can be overridden by rules as sometimes the specified orient is invalid.\n    const specifiedOrient = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('orient', markDef, config);\n    markDef.orient = orient(markDef.type, encoding, specifiedOrient);\n    if (specifiedOrient !== undefined && specifiedOrient !== markDef.orient) {\n        _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.orientOverridden(markDef.orient, specifiedOrient));\n    }\n    if (markDef.type === 'bar' && markDef.orient) {\n        const cornerRadiusEnd = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('cornerRadiusEnd', markDef, config);\n        if (cornerRadiusEnd !== undefined) {\n            const newProps = (markDef.orient === 'horizontal' && encoding.x2) || (markDef.orient === 'vertical' && encoding.y2)\n                ? ['cornerRadius']\n                : _mark__WEBPACK_IMPORTED_MODULE_5__.BAR_CORNER_RADIUS_INDEX[markDef.orient];\n            for (const newProp of newProps) {\n                markDef[newProp] = cornerRadiusEnd;\n            }\n            if (markDef.cornerRadiusEnd !== undefined) {\n                delete markDef.cornerRadiusEnd; // no need to keep the original cap cornerRadius\n            }\n        }\n    }\n    // set opacity and filled if not specified in mark config\n    const specifiedOpacity = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('opacity', markDef, config);\n    if (specifiedOpacity === undefined) {\n        markDef.opacity = opacity(markDef.type, encoding);\n    }\n    // set cursor, which should be pointer if href channel is present unless otherwise specified\n    const specifiedCursor = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('cursor', markDef, config);\n    if (specifiedCursor === undefined) {\n        markDef.cursor = cursor(markDef, encoding, config);\n    }\n    return markDef;\n}\nfunction cursor(markDef, encoding, config) {\n    if (encoding.href || markDef.href || (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('href', markDef, config)) {\n        return 'pointer';\n    }\n    return markDef.cursor;\n}\nfunction opacity(mark, encoding) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_7__.contains)([_mark__WEBPACK_IMPORTED_MODULE_5__.POINT, _mark__WEBPACK_IMPORTED_MODULE_5__.TICK, _mark__WEBPACK_IMPORTED_MODULE_5__.CIRCLE, _mark__WEBPACK_IMPORTED_MODULE_5__.SQUARE], mark)) {\n        // point-based marks\n        if (!(0,_encoding__WEBPACK_IMPORTED_MODULE_2__.isAggregate)(encoding)) {\n            return 0.7;\n        }\n    }\n    return undefined;\n}\nfunction defaultFilled(markDef, config, { graticule }) {\n    if (graticule) {\n        return false;\n    }\n    const filledConfig = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkConfig)('filled', markDef, config);\n    const mark = markDef.type;\n    return (0,_util__WEBPACK_IMPORTED_MODULE_7__.getFirstDefined)(filledConfig, mark !== _mark__WEBPACK_IMPORTED_MODULE_5__.POINT && mark !== _mark__WEBPACK_IMPORTED_MODULE_5__.LINE && mark !== _mark__WEBPACK_IMPORTED_MODULE_5__.RULE);\n}\nfunction orient(mark, encoding, specifiedOrient) {\n    switch (mark) {\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.POINT:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.CIRCLE:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.SQUARE:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.TEXT:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.RECT:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.IMAGE:\n            // orient is meaningless for these marks.\n            return undefined;\n    }\n    const { x, y, x2, y2 } = encoding;\n    switch (mark) {\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.BAR:\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && ((0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(x.bin) || ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && y.aggregate && !x.aggregate))) {\n                return 'vertical';\n            }\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && ((0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(y.bin) || ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && x.aggregate && !y.aggregate))) {\n                return 'horizontal';\n            }\n            if (y2 || x2) {\n                // Ranged bar does not always have clear orientation, so we allow overriding\n                if (specifiedOrient) {\n                    return specifiedOrient;\n                }\n                // If y is range and x is non-range, non-bin Q\n                if (!x2) {\n                    if (((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && x.type === _type__WEBPACK_IMPORTED_MODULE_6__.QUANTITATIVE && !(0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinning)(x.bin)) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isNumericDataDef)(x)) {\n                        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(y.bin)) {\n                            return 'horizontal';\n                        }\n                    }\n                    return 'vertical';\n                }\n                // If x is range and y is non-range, non-bin Q\n                if (!y2) {\n                    if (((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && y.type === _type__WEBPACK_IMPORTED_MODULE_6__.QUANTITATIVE && !(0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinning)(y.bin)) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isNumericDataDef)(y)) {\n                        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(x.bin)) {\n                            return 'vertical';\n                        }\n                    }\n                    return 'horizontal';\n                }\n            }\n        // falls through\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.RULE:\n            // return undefined for line segment rule and bar with both axis ranged\n            // we have to ignore the case that the data are already binned\n            if (x2 && !((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(x.bin)) && y2 && !((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(y.bin))) {\n                return undefined;\n            }\n        // falls through\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.AREA:\n            // If there are range for both x and y, y (vertical) has higher precedence.\n            if (y2) {\n                if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(y.bin)) {\n                    return 'horizontal';\n                }\n                else {\n                    return 'vertical';\n                }\n            }\n            else if (x2) {\n                if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinned)(x.bin)) {\n                    return 'vertical';\n                }\n                else {\n                    return 'horizontal';\n                }\n            }\n            else if (mark === _mark__WEBPACK_IMPORTED_MODULE_5__.RULE) {\n                if (x && !y) {\n                    return 'vertical';\n                }\n                else if (y && !x) {\n                    return 'horizontal';\n                }\n            }\n        // falls through\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.LINE:\n        case _mark__WEBPACK_IMPORTED_MODULE_5__.TICK: {\n            const xIsMeasure = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isUnbinnedQuantitativeFieldOrDatumDef)(x);\n            const yIsMeasure = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isUnbinnedQuantitativeFieldOrDatumDef)(y);\n            if (specifiedOrient) {\n                return specifiedOrient;\n            }\n            else if (xIsMeasure && !yIsMeasure) {\n                // Tick is opposite to bar, line, area\n                return mark !== 'tick' ? 'horizontal' : 'vertical';\n            }\n            else if (!xIsMeasure && yIsMeasure) {\n                // Tick is opposite to bar, line, area\n                return mark !== 'tick' ? 'vertical' : 'horizontal';\n            }\n            else if (xIsMeasure && yIsMeasure) {\n                return 'vertical';\n            }\n            else {\n                const xIsTemporal = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isTypedFieldDef)(x) && x.type === _type__WEBPACK_IMPORTED_MODULE_6__.TEMPORAL;\n                const yIsTemporal = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isTypedFieldDef)(y) && y.type === _type__WEBPACK_IMPORTED_MODULE_6__.TEMPORAL;\n                // x: T, y: N --> vertical tick\n                if (xIsTemporal && !yIsTemporal) {\n                    return 'vertical';\n                }\n                else if (!xIsTemporal && yIsTemporal) {\n                    return 'horizontal';\n                }\n            }\n            return undefined;\n        }\n    }\n    return 'vertical';\n}\n//# sourceMappingURL=init.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/init.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/line.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/line.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   line: () => (/* binding */ line),\n/* harmony export */   trail: () => (/* binding */ trail)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst line = {\n    vgMark: 'line',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                size: 'ignore',\n                orient: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('x', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('y', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('size', model, {\n                vgChannel: 'strokeWidth' // VL's line size is strokeWidth\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.defined(model)\n        };\n    }\n};\nconst trail = {\n    vgMark: 'trail',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                size: 'include',\n                orient: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('x', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('y', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('size', model),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.defined(model)\n        };\n    }\n};\n//# sourceMappingURL=line.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/line.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/mark.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/mark.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getSort: () => (/* binding */ getSort),\n/* harmony export */   parseMarkGroups: () => (/* binding */ parseMarkGroups)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _arc__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./arc */ \"../../node_modules/vega-lite/build/src/compile/mark/arc.js\");\n/* harmony import */ var _area__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./area */ \"../../node_modules/vega-lite/build/src/compile/mark/area.js\");\n/* harmony import */ var _bar__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./bar */ \"../../node_modules/vega-lite/build/src/compile/mark/bar.js\");\n/* harmony import */ var _geoshape__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./geoshape */ \"../../node_modules/vega-lite/build/src/compile/mark/geoshape.js\");\n/* harmony import */ var _image__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./image */ \"../../node_modules/vega-lite/build/src/compile/mark/image.js\");\n/* harmony import */ var _line__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./line */ \"../../node_modules/vega-lite/build/src/compile/mark/line.js\");\n/* harmony import */ var _point__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./point */ \"../../node_modules/vega-lite/build/src/compile/mark/point.js\");\n/* harmony import */ var _rect__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./rect */ \"../../node_modules/vega-lite/build/src/compile/mark/rect.js\");\n/* harmony import */ var _rule__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./rule */ \"../../node_modules/vega-lite/build/src/compile/mark/rule.js\");\n/* harmony import */ var _text__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./text */ \"../../node_modules/vega-lite/build/src/compile/mark/text.js\");\n/* harmony import */ var _tick__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./tick */ \"../../node_modules/vega-lite/build/src/compile/mark/tick.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst markCompiler = {\n    arc: _arc__WEBPACK_IMPORTED_MODULE_9__.arc,\n    area: _area__WEBPACK_IMPORTED_MODULE_10__.area,\n    bar: _bar__WEBPACK_IMPORTED_MODULE_11__.bar,\n    circle: _point__WEBPACK_IMPORTED_MODULE_15__.circle,\n    geoshape: _geoshape__WEBPACK_IMPORTED_MODULE_12__.geoshape,\n    image: _image__WEBPACK_IMPORTED_MODULE_13__.image,\n    line: _line__WEBPACK_IMPORTED_MODULE_14__.line,\n    point: _point__WEBPACK_IMPORTED_MODULE_15__.point,\n    rect: _rect__WEBPACK_IMPORTED_MODULE_16__.rect,\n    rule: _rule__WEBPACK_IMPORTED_MODULE_17__.rule,\n    square: _point__WEBPACK_IMPORTED_MODULE_15__.square,\n    text: _text__WEBPACK_IMPORTED_MODULE_18__.text,\n    tick: _tick__WEBPACK_IMPORTED_MODULE_19__.tick,\n    trail: _line__WEBPACK_IMPORTED_MODULE_14__.trail\n};\nfunction parseMarkGroups(model) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_6__.contains)([_mark__WEBPACK_IMPORTED_MODULE_4__.LINE, _mark__WEBPACK_IMPORTED_MODULE_4__.AREA, _mark__WEBPACK_IMPORTED_MODULE_4__.TRAIL], model.mark)) {\n        const details = (0,_encoding__WEBPACK_IMPORTED_MODULE_3__.pathGroupingFields)(model.mark, model.encoding);\n        if (details.length > 0) {\n            return getPathGroups(model, details);\n        }\n        // otherwise use standard mark groups\n    }\n    else if (model.mark === _mark__WEBPACK_IMPORTED_MODULE_4__.BAR) {\n        const hasCornerRadius = _vega_schema__WEBPACK_IMPORTED_MODULE_7__.VG_CORNERRADIUS_CHANNELS.some(prop => (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)(prop, model.markDef, model.config));\n        if (model.stack && !model.fieldDef('size') && hasCornerRadius) {\n            return getGroupsForStackedBarWithCornerRadius(model);\n        }\n    }\n    return getMarkGroup(model);\n}\nconst FACETED_PATH_PREFIX = 'faceted_path_';\nfunction getPathGroups(model, details) {\n    // TODO: for non-stacked plot, map order to zindex. (Maybe rename order for layer to zindex?)\n    return [\n        {\n            name: model.getName('pathgroup'),\n            type: 'group',\n            from: {\n                facet: {\n                    name: FACETED_PATH_PREFIX + model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType.Main),\n                    data: model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType.Main),\n                    groupby: details\n                }\n            },\n            encode: {\n                update: {\n                    width: { field: { group: 'width' } },\n                    height: { field: { group: 'height' } }\n                }\n            },\n            // With subfacet for line/area group, need to use faceted data from above.\n            marks: getMarkGroup(model, { fromPrefix: FACETED_PATH_PREFIX })\n        }\n    ];\n}\nconst STACK_GROUP_PREFIX = 'stack_group_';\n/**\n * We need to put stacked bars into groups in order to enable cornerRadius for stacks.\n * If stack is used and the model doesn't have size encoding, we put the mark into groups,\n * and apply cornerRadius properties at the group.\n */\nfunction getGroupsForStackedBarWithCornerRadius(model) {\n    // Generate the mark\n    const [mark] = getMarkGroup(model, { fromPrefix: STACK_GROUP_PREFIX });\n    // Get the scale for the stacked field\n    const fieldScale = model.scaleName(model.stack.fieldChannel);\n    const stackField = (opt = {}) => model.vgField(model.stack.fieldChannel, opt);\n    // Find the min/max of the pixel value on the stacked direction\n    const stackFieldGroup = (func, expr) => {\n        const vgFieldMinMax = [\n            stackField({ prefix: 'min', suffix: 'start', expr }),\n            stackField({ prefix: 'max', suffix: 'start', expr }),\n            stackField({ prefix: 'min', suffix: 'end', expr }),\n            stackField({ prefix: 'max', suffix: 'end', expr })\n        ];\n        return `${func}(${vgFieldMinMax.map(field => `scale('${fieldScale}',${field})`).join(',')})`;\n    };\n    let groupUpdate;\n    let innerGroupUpdate;\n    // Build the encoding for group and an inner group\n    if (model.stack.fieldChannel === 'x') {\n        // Move cornerRadius, y/yc/y2/height properties to group\n        // Group x/x2 should be the min/max of the marks within\n        groupUpdate = {\n            ...(0,_util__WEBPACK_IMPORTED_MODULE_6__.pick)(mark.encode.update, ['y', 'yc', 'y2', 'height', ..._vega_schema__WEBPACK_IMPORTED_MODULE_7__.VG_CORNERRADIUS_CHANNELS]),\n            x: { signal: stackFieldGroup('min', 'datum') },\n            x2: { signal: stackFieldGroup('max', 'datum') },\n            clip: { value: true }\n        };\n        // Inner group should revert the x translation, and pass height through\n        innerGroupUpdate = {\n            x: { field: { group: 'x' }, mult: -1 },\n            height: { field: { group: 'height' } }\n        };\n        // The marks should use the same height as group, without y/yc/y2 properties (because it's already done by group)\n        // This is why size encoding is not supported yet\n        mark.encode.update = {\n            ...(0,_util__WEBPACK_IMPORTED_MODULE_6__.omit)(mark.encode.update, ['y', 'yc', 'y2']),\n            height: { field: { group: 'height' } }\n        };\n    }\n    else {\n        groupUpdate = {\n            ...(0,_util__WEBPACK_IMPORTED_MODULE_6__.pick)(mark.encode.update, ['x', 'xc', 'x2', 'width']),\n            y: { signal: stackFieldGroup('min', 'datum') },\n            y2: { signal: stackFieldGroup('max', 'datum') },\n            clip: { value: true }\n        };\n        innerGroupUpdate = {\n            y: { field: { group: 'y' }, mult: -1 },\n            width: { field: { group: 'width' } }\n        };\n        mark.encode.update = {\n            ...(0,_util__WEBPACK_IMPORTED_MODULE_6__.omit)(mark.encode.update, ['x', 'xc', 'x2']),\n            width: { field: { group: 'width' } }\n        };\n    }\n    // Deal with cornerRadius properties\n    for (const key of _vega_schema__WEBPACK_IMPORTED_MODULE_7__.VG_CORNERRADIUS_CHANNELS) {\n        const configValue = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkConfig)(key, model.markDef, model.config);\n        // Move from mark to group\n        if (mark.encode.update[key]) {\n            groupUpdate[key] = mark.encode.update[key];\n            delete mark.encode.update[key];\n        }\n        else if (configValue) {\n            groupUpdate[key] = (0,_common__WEBPACK_IMPORTED_MODULE_8__.signalOrValueRef)(configValue);\n        }\n        // Overwrite any cornerRadius on mark set by config --- they are already moved to the group\n        if (configValue) {\n            mark.encode.update[key] = { value: 0 };\n        }\n    }\n    const groupby = [];\n    if (model.stack.groupbyChannels?.length > 0) {\n        for (const groupbyChannel of model.stack.groupbyChannels) {\n            // For bin and time unit, we have to add bin/timeunit -end channels.\n            const groupByField = model.fieldDef(groupbyChannel);\n            const field = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(groupByField);\n            if (field) {\n                groupby.push(field);\n            }\n            if (groupByField?.bin || groupByField?.timeUnit) {\n                groupby.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(groupByField, { binSuffix: 'end' }));\n            }\n        }\n    }\n    const strokeProperties = [\n        'stroke',\n        'strokeWidth',\n        'strokeJoin',\n        'strokeCap',\n        'strokeDash',\n        'strokeDashOffset',\n        'strokeMiterLimit',\n        'strokeOpacity'\n    ];\n    // Generate stroke properties for the group\n    groupUpdate = strokeProperties.reduce((encode, prop) => {\n        if (mark.encode.update[prop]) {\n            return { ...encode, [prop]: mark.encode.update[prop] };\n        }\n        else {\n            const configValue = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkConfig)(prop, model.markDef, model.config);\n            if (configValue !== undefined) {\n                return { ...encode, [prop]: (0,_common__WEBPACK_IMPORTED_MODULE_8__.signalOrValueRef)(configValue) };\n            }\n            else {\n                return encode;\n            }\n        }\n    }, groupUpdate);\n    // Apply strokeForeground and strokeOffset if stroke is used\n    if (groupUpdate.stroke) {\n        groupUpdate.strokeForeground = { value: true };\n        groupUpdate.strokeOffset = { value: 0 };\n    }\n    return [\n        {\n            type: 'group',\n            from: {\n                facet: {\n                    data: model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType.Main),\n                    name: STACK_GROUP_PREFIX + model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType.Main),\n                    groupby,\n                    aggregate: {\n                        fields: [\n                            stackField({ suffix: 'start' }),\n                            stackField({ suffix: 'start' }),\n                            stackField({ suffix: 'end' }),\n                            stackField({ suffix: 'end' })\n                        ],\n                        ops: ['min', 'max', 'min', 'max']\n                    }\n                }\n            },\n            encode: {\n                update: groupUpdate\n            },\n            marks: [\n                {\n                    type: 'group',\n                    encode: { update: innerGroupUpdate },\n                    marks: [mark]\n                }\n            ]\n        }\n    ];\n}\nfunction getSort(model) {\n    const { encoding, stack, mark, markDef, config } = model;\n    const order = encoding.order;\n    if ((!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(order) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isValueDef)(order) && (0,_util__WEBPACK_IMPORTED_MODULE_6__.isNullOrFalse)(order.value)) ||\n        (!order && (0,_util__WEBPACK_IMPORTED_MODULE_6__.isNullOrFalse)((0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('order', markDef, config)))) {\n        return undefined;\n    }\n    else if (((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(order) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(order)) && !stack) {\n        // Sort by the order field if it is specified and the field is not stacked. (For stacked field, order specify stack order.)\n        return (0,_common__WEBPACK_IMPORTED_MODULE_8__.sortParams)(order, { expr: 'datum' });\n    }\n    else if ((0,_mark__WEBPACK_IMPORTED_MODULE_4__.isPathMark)(mark)) {\n        // For both line and area, we sort values based on dimension by default\n        const dimensionChannel = markDef.orient === 'horizontal' ? 'y' : 'x';\n        const dimensionChannelDef = encoding[dimensionChannel];\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(dimensionChannelDef)) {\n            const s = dimensionChannelDef.sort;\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(s)) {\n                return {\n                    field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionChannelDef, { prefix: dimensionChannel, suffix: 'sort_index', expr: 'datum' })\n                };\n            }\n            else if ((0,_sort__WEBPACK_IMPORTED_MODULE_5__.isSortField)(s)) {\n                return {\n                    field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)({\n                        // FIXME: this op might not already exist?\n                        // FIXME: what if dimensionChannel (x or y) contains custom domain?\n                        aggregate: (0,_encoding__WEBPACK_IMPORTED_MODULE_3__.isAggregate)(model.encoding) ? s.op : undefined,\n                        field: s.field\n                    }, { expr: 'datum' })\n                };\n            }\n            else if ((0,_sort__WEBPACK_IMPORTED_MODULE_5__.isSortByEncoding)(s)) {\n                const fieldDefToSort = model.fieldDef(s.encoding);\n                return {\n                    field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(fieldDefToSort, { expr: 'datum' }),\n                    order: s.order\n                };\n            }\n            else if (s === null) {\n                return undefined;\n            }\n            else {\n                return {\n                    field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(dimensionChannelDef, {\n                        // For stack with imputation, we only have bin_mid\n                        binSuffix: model.stack?.impute ? 'mid' : undefined,\n                        expr: 'datum'\n                    })\n                };\n            }\n        }\n        return undefined;\n    }\n    return undefined;\n}\nfunction getMarkGroup(model, opt = { fromPrefix: '' }) {\n    const { mark, markDef, encoding, config } = model;\n    const clip = (0,_util__WEBPACK_IMPORTED_MODULE_6__.getFirstDefined)(markDef.clip, scaleClip(model), projectionClip(model));\n    const style = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getStyles)(markDef);\n    const key = encoding.key;\n    const sort = getSort(model);\n    const interactive = interactiveFlag(model);\n    const aria = (0,_common__WEBPACK_IMPORTED_MODULE_8__.getMarkPropOrConfig)('aria', markDef, config);\n    const postEncodingTransform = markCompiler[mark].postEncodingTransform\n        ? markCompiler[mark].postEncodingTransform(model)\n        : null;\n    return [\n        {\n            name: model.getName('marks'),\n            type: markCompiler[mark].vgMark,\n            ...(clip ? { clip: true } : {}),\n            ...(style ? { style } : {}),\n            ...(key ? { key: key.field } : {}),\n            ...(sort ? { sort } : {}),\n            ...(interactive ? interactive : {}),\n            ...(aria === false ? { aria } : {}),\n            from: { data: opt.fromPrefix + model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType.Main) },\n            encode: {\n                update: markCompiler[mark].encodeEntry(model)\n            },\n            ...(postEncodingTransform\n                ? {\n                    transform: postEncodingTransform\n                }\n                : {})\n        }\n    ];\n}\n/**\n * If scales are bound to interval selections, we want to automatically clip\n * marks to account for panning/zooming interactions. We identify bound scales\n * by the selectionExtent property, which gets added during scale parsing.\n */\nfunction scaleClip(model) {\n    const xScale = model.getScaleComponent('x');\n    const yScale = model.getScaleComponent('y');\n    return xScale?.get('selectionExtent') || yScale?.get('selectionExtent') ? true : undefined;\n}\n/**\n * If we use a custom projection with auto-fitting to the geodata extent,\n * we need to clip to ensure the chart size doesn't explode.\n */\nfunction projectionClip(model) {\n    const projection = model.component.projection;\n    return projection && !projection.isFit ? true : undefined;\n}\n/**\n * Only output interactive flags if we have selections defined somewhere in our model hierarchy.\n */\nfunction interactiveFlag(model) {\n    if (!model.component.selection)\n        return null;\n    const unitCount = (0,_util__WEBPACK_IMPORTED_MODULE_6__.keys)(model.component.selection).length;\n    let parentCount = unitCount;\n    let parent = model.parent;\n    while (parent && parentCount === 0) {\n        parentCount = (0,_util__WEBPACK_IMPORTED_MODULE_6__.keys)(parent.component.selection).length;\n        parent = parent.parent;\n    }\n    return parentCount\n        ? {\n            interactive: unitCount > 0 || model.mark === 'geoshape' || !!model.encoding.tooltip\n        }\n        : null;\n}\n//# sourceMappingURL=mark.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/mark.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/point.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/point.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   circle: () => (/* binding */ circle),\n/* harmony export */   point: () => (/* binding */ point),\n/* harmony export */   shapeMixins: () => (/* binding */ shapeMixins),\n/* harmony export */   square: () => (/* binding */ square)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nfunction encodeEntry(model, fixedShape) {\n    const { config } = model;\n    return {\n        ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n            align: 'ignore',\n            baseline: 'ignore',\n            color: 'include',\n            size: 'include',\n            orient: 'ignore',\n            theta: 'ignore'\n        }),\n        ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('x', model, { defaultPos: 'mid' }),\n        ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointPosition('y', model, { defaultPos: 'mid' }),\n        ..._encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('size', model),\n        ..._encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('angle', model),\n        ...shapeMixins(model, config, fixedShape)\n    };\n}\nfunction shapeMixins(model, config, fixedShape) {\n    if (fixedShape) {\n        return { shape: { value: fixedShape } };\n    }\n    return _encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('shape', model);\n}\nconst point = {\n    vgMark: 'symbol',\n    encodeEntry: (model) => {\n        return encodeEntry(model);\n    }\n};\nconst circle = {\n    vgMark: 'symbol',\n    encodeEntry: (model) => {\n        return encodeEntry(model, 'circle');\n    }\n};\nconst square = {\n    vgMark: 'symbol',\n    encodeEntry: (model) => {\n        return encodeEntry(model, 'square');\n    }\n};\n//# sourceMappingURL=point.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/point.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/rect.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/rect.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   rect: () => (/* binding */ rect)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst rect = {\n    vgMark: 'rect',\n    encodeEntry: (model) => {\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                orient: 'ignore',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'x'),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.rectPosition(model, 'y')\n        };\n    }\n};\n//# sourceMappingURL=rect.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/rect.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/rule.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/rule.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   rule: () => (/* binding */ rule)\n/* harmony export */ });\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\nconst rule = {\n    vgMark: 'rule',\n    encodeEntry: (model) => {\n        const { markDef } = model;\n        const orient = markDef.orient;\n        if (!model.encoding.x && !model.encoding.y && !model.encoding.latitude && !model.encoding.longitude) {\n            // Show nothing if we have none of x, y, lat, and long.\n            return {};\n        }\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                orient: 'ignore',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointOrRangePosition('x', model, {\n                defaultPos: orient === 'horizontal' ? 'zeroOrMax' : 'mid',\n                defaultPos2: 'zeroOrMin',\n                range: orient !== 'vertical' // include x2 for horizontal or line segment rule\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.pointOrRangePosition('y', model, {\n                defaultPos: orient === 'vertical' ? 'zeroOrMax' : 'mid',\n                defaultPos2: 'zeroOrMin',\n                range: orient !== 'horizontal' // include y2 for vertical or line segment rule\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_0__.nonPosition('size', model, {\n                vgChannel: 'strokeWidth' // VL's rule size is strokeWidth\n            })\n        };\n    }\n};\n//# sourceMappingURL=rule.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/rule.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/text.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/text.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   text: () => (/* binding */ text)\n/* harmony export */ });\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\n\nconst text = {\n    vgMark: 'text',\n    encodeEntry: (model) => {\n        const { config, encoding } = model;\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.baseEncodeEntry(model, {\n                align: 'include',\n                baseline: 'include',\n                color: 'include',\n                size: 'ignore',\n                orient: 'ignore',\n                theta: 'include'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.pointPosition('x', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.pointPosition('y', model, { defaultPos: 'mid' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.text(model),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.nonPosition('size', model, {\n                vgChannel: 'fontSize' // VL's text size is fontSize\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.nonPosition('angle', model),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.valueIfDefined('align', align(model.markDef, encoding, config)),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.valueIfDefined('baseline', baseline(model.markDef, encoding, config)),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.pointPosition('radius', model, { defaultPos: null }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_1__.pointPosition('theta', model, { defaultPos: null })\n        };\n    }\n};\nfunction align(markDef, encoding, config) {\n    const a = (0,_common__WEBPACK_IMPORTED_MODULE_0__.getMarkPropOrConfig)('align', markDef, config);\n    if (a === undefined) {\n        return 'center';\n    }\n    // If there is a config, Vega-parser will process this already.\n    return undefined;\n}\nfunction baseline(markDef, encoding, config) {\n    const b = (0,_common__WEBPACK_IMPORTED_MODULE_0__.getMarkPropOrConfig)('baseline', markDef, config);\n    if (b === undefined) {\n        return 'middle';\n    }\n    // If there is a config, Vega-parser will process this already.\n    return undefined;\n}\n//# sourceMappingURL=text.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/text.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/mark/tick.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/mark/tick.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   tick: () => (/* binding */ tick)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _encode__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\n\n\n\n\nconst tick = {\n    vgMark: 'rect',\n    encodeEntry: (model) => {\n        const { config, markDef } = model;\n        const orient = markDef.orient;\n        const vgSizeChannel = orient === 'horizontal' ? 'width' : 'height';\n        const vgThicknessChannel = orient === 'horizontal' ? 'height' : 'width';\n        return {\n            ..._encode__WEBPACK_IMPORTED_MODULE_4__.baseEncodeEntry(model, {\n                align: 'ignore',\n                baseline: 'ignore',\n                color: 'include',\n                orient: 'ignore',\n                size: 'ignore',\n                theta: 'ignore'\n            }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_4__.pointPosition('x', model, { defaultPos: 'mid', vgChannel: 'xc' }),\n            ..._encode__WEBPACK_IMPORTED_MODULE_4__.pointPosition('y', model, { defaultPos: 'mid', vgChannel: 'yc' }),\n            // size / thickness => width / height\n            ..._encode__WEBPACK_IMPORTED_MODULE_4__.nonPosition('size', model, {\n                defaultValue: defaultSize(model),\n                vgChannel: vgSizeChannel\n            }),\n            [vgThicknessChannel]: (0,_common__WEBPACK_IMPORTED_MODULE_3__.signalOrValueRef)((0,_common__WEBPACK_IMPORTED_MODULE_3__.getMarkPropOrConfig)('thickness', markDef, config))\n        };\n    }\n};\nfunction defaultSize(model) {\n    const { config, markDef } = model;\n    const { orient } = markDef;\n    const vgSizeChannel = orient === 'horizontal' ? 'width' : 'height';\n    const scale = model.getScaleComponent(orient === 'horizontal' ? 'x' : 'y');\n    const markPropOrConfig = (0,_common__WEBPACK_IMPORTED_MODULE_3__.getMarkPropOrConfig)('size', markDef, config, { vgChannel: vgSizeChannel }) ?? config.tick.bandSize;\n    if (markPropOrConfig !== undefined) {\n        return markPropOrConfig;\n    }\n    else {\n        const scaleRange = scale ? scale.get('range') : undefined;\n        if (scaleRange && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_2__.isVgRangeStep)(scaleRange) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(scaleRange.step)) {\n            return (scaleRange.step * 3) / 4;\n        }\n        const defaultViewStep = (0,_config__WEBPACK_IMPORTED_MODULE_1__.getViewConfigDiscreteStep)(config.view, vgSizeChannel);\n        return (defaultViewStep * 3) / 4;\n    }\n}\n//# sourceMappingURL=tick.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/mark/tick.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/model.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/model.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Model: () => (/* binding */ Model),\n/* harmony export */   ModelWithField: () => (/* binding */ ModelWithField),\n/* harmony export */   NameMap: () => (/* binding */ NameMap),\n/* harmony export */   isConcatModel: () => (/* binding */ isConcatModel),\n/* harmony export */   isFacetModel: () => (/* binding */ isFacetModel),\n/* harmony export */   isLayerModel: () => (/* binding */ isLayerModel),\n/* harmony export */   isUnitModel: () => (/* binding */ isUnitModel)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n/* harmony import */ var _title__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../title */ \"../../node_modules/vega-lite/build/src/title.js\");\n/* harmony import */ var _transform__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../transform */ \"../../node_modules/vega-lite/build/src/transform.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _axis_assemble__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./axis/assemble */ \"../../node_modules/vega-lite/build/src/compile/axis/assemble.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _header_assemble__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./header/assemble */ \"../../node_modules/vega-lite/build/src/compile/header/assemble.js\");\n/* harmony import */ var _header_component__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./header/component */ \"../../node_modules/vega-lite/build/src/compile/header/component.js\");\n/* harmony import */ var _layoutsize_assemble__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./layoutsize/assemble */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js\");\n/* harmony import */ var _layoutsize_component__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./layoutsize/component */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/component.js\");\n/* harmony import */ var _legend_assemble__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./legend/assemble */ \"../../node_modules/vega-lite/build/src/compile/legend/assemble.js\");\n/* harmony import */ var _legend_parse__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./legend/parse */ \"../../node_modules/vega-lite/build/src/compile/legend/parse.js\");\n/* harmony import */ var _projection_assemble__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./projection/assemble */ \"../../node_modules/vega-lite/build/src/compile/projection/assemble.js\");\n/* harmony import */ var _projection_parse__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./projection/parse */ \"../../node_modules/vega-lite/build/src/compile/projection/parse.js\");\n/* harmony import */ var _scale_assemble__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./scale/assemble */ \"../../node_modules/vega-lite/build/src/compile/scale/assemble.js\");\n/* harmony import */ var _scale_domain__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./scale/domain */ \"../../node_modules/vega-lite/build/src/compile/scale/domain.js\");\n/* harmony import */ var _scale_parse__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./scale/parse */ \"../../node_modules/vega-lite/build/src/compile/scale/parse.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nclass NameMap {\n    constructor() {\n        this.nameMap = {};\n    }\n    rename(oldName, newName) {\n        this.nameMap[oldName] = newName;\n    }\n    has(name) {\n        return this.nameMap[name] !== undefined;\n    }\n    get(name) {\n        // If the name appears in the _nameMap, we need to read its new name.\n        // We have to loop over the dict just in case the new name also gets renamed.\n        while (this.nameMap[name] && name !== this.nameMap[name]) {\n            name = this.nameMap[name];\n        }\n        return name;\n    }\n}\n/*\n  We use type guards instead of `instanceof` as `instanceof` makes\n  different parts of the compiler depend on the actual implementation of\n  the model classes, which in turn depend on different parts of the compiler.\n  Thus, `instanceof` leads to circular dependency problems.\n\n  On the other hand, type guards only make different parts of the compiler\n  depend on the type of the model classes, but not the actual implementation.\n*/\nfunction isUnitModel(model) {\n    return model?.type === 'unit';\n}\nfunction isFacetModel(model) {\n    return model?.type === 'facet';\n}\nfunction isConcatModel(model) {\n    return model?.type === 'concat';\n}\nfunction isLayerModel(model) {\n    return model?.type === 'layer';\n}\nclass Model {\n    constructor(spec, type, parent, parentGivenName, config, resolve, view) {\n        this.type = type;\n        this.parent = parent;\n        this.config = config;\n        /**\n         * Corrects the data references in marks after assemble.\n         */\n        this.correctDataNames = (mark) => {\n            // TODO: make this correct\n            // for normal data references\n            if (mark.from?.data) {\n                mark.from.data = this.lookupDataSource(mark.from.data);\n            }\n            // for access to facet data\n            if (mark.from?.facet?.data) {\n                mark.from.facet.data = this.lookupDataSource(mark.from.facet.data);\n            }\n            return mark;\n        };\n        this.parent = parent;\n        this.config = config;\n        this.view = (0,_expr__WEBPACK_IMPORTED_MODULE_4__.replaceExprRef)(view);\n        // If name is not provided, always use parent's givenName to avoid name conflicts.\n        this.name = spec.name ?? parentGivenName;\n        this.title = (0,_title__WEBPACK_IMPORTED_MODULE_9__.isText)(spec.title) ? { text: spec.title } : spec.title ? (0,_expr__WEBPACK_IMPORTED_MODULE_4__.replaceExprRef)(spec.title) : undefined;\n        // Shared name maps\n        this.scaleNameMap = parent ? parent.scaleNameMap : new NameMap();\n        this.projectionNameMap = parent ? parent.projectionNameMap : new NameMap();\n        this.signalNameMap = parent ? parent.signalNameMap : new NameMap();\n        this.data = spec.data;\n        this.description = spec.description;\n        this.transforms = (0,_transform__WEBPACK_IMPORTED_MODULE_10__.normalizeTransform)(spec.transform ?? []);\n        this.layout = type === 'layer' || type === 'unit' ? {} : (0,_spec_base__WEBPACK_IMPORTED_MODULE_8__.extractCompositionLayout)(spec, type, config);\n        this.component = {\n            data: {\n                sources: parent ? parent.component.data.sources : [],\n                outputNodes: parent ? parent.component.data.outputNodes : {},\n                outputNodeRefCounts: parent ? parent.component.data.outputNodeRefCounts : {},\n                // data is faceted if the spec is a facet spec or the parent has faceted data and data is undefined\n                isFaceted: (0,_spec__WEBPACK_IMPORTED_MODULE_7__.isFacetSpec)(spec) || (parent?.component.data.isFaceted && spec.data === undefined)\n            },\n            layoutSize: new _split__WEBPACK_IMPORTED_MODULE_26__.Split(),\n            layoutHeaders: { row: {}, column: {}, facet: {} },\n            mark: null,\n            resolve: {\n                scale: {},\n                axis: {},\n                legend: {},\n                ...(resolve ? (0,_util__WEBPACK_IMPORTED_MODULE_11__.duplicate)(resolve) : {})\n            },\n            selection: null,\n            scales: null,\n            projection: null,\n            axes: {},\n            legends: {}\n        };\n    }\n    get width() {\n        return this.getSizeSignalRef('width');\n    }\n    get height() {\n        return this.getSizeSignalRef('height');\n    }\n    parse() {\n        this.parseScale();\n        this.parseLayoutSize(); // depends on scale\n        this.renameTopLevelLayoutSizeSignal();\n        this.parseSelections();\n        this.parseProjection();\n        this.parseData(); // (pathorder) depends on markDef; selection filters depend on parsed selections; depends on projection because some transforms require the finalized projection name.\n        this.parseAxesAndHeaders(); // depends on scale and layout size\n        this.parseLegends(); // depends on scale, markDef\n        this.parseMarkGroup(); // depends on data name, scale, layout size, axisGroup, and children's scale, axis, legend and mark.\n    }\n    parseScale() {\n        (0,_scale_parse__WEBPACK_IMPORTED_MODULE_25__.parseScales)(this);\n    }\n    parseProjection() {\n        (0,_projection_parse__WEBPACK_IMPORTED_MODULE_22__.parseProjection)(this);\n    }\n    /**\n     * Rename top-level spec's size to be just width / height, ignoring model name.\n     * This essentially merges the top-level spec's width/height signals with the width/height signals\n     * to help us reduce redundant signals declaration.\n     */\n    renameTopLevelLayoutSizeSignal() {\n        if (this.getName('width') !== 'width') {\n            this.renameSignal(this.getName('width'), 'width');\n        }\n        if (this.getName('height') !== 'height') {\n            this.renameSignal(this.getName('height'), 'height');\n        }\n    }\n    parseLegends() {\n        (0,_legend_parse__WEBPACK_IMPORTED_MODULE_20__.parseLegend)(this);\n    }\n    assembleEncodeFromView(view) {\n        // Exclude \"style\"\n        const { style: _, ...baseView } = view;\n        const e = {};\n        for (const property of (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(baseView)) {\n            const value = baseView[property];\n            if (value !== undefined) {\n                e[property] = (0,_common__WEBPACK_IMPORTED_MODULE_14__.signalOrValueRef)(value);\n            }\n        }\n        return e;\n    }\n    assembleGroupEncodeEntry(isTopLevel) {\n        let encodeEntry = {};\n        if (this.view) {\n            encodeEntry = this.assembleEncodeFromView(this.view);\n        }\n        if (!isTopLevel) {\n            // Descriptions are already added to the top-level description so we only need to add them to the inner views.\n            if (this.description) {\n                encodeEntry['description'] = (0,_common__WEBPACK_IMPORTED_MODULE_14__.signalOrValueRef)(this.description);\n            }\n            // For top-level spec, we can set the global width and height signal to adjust the group size.\n            // For other child specs, we have to manually set width and height in the encode entry.\n            if (this.type === 'unit' || this.type === 'layer') {\n                return {\n                    width: this.getSizeSignalRef('width'),\n                    height: this.getSizeSignalRef('height'),\n                    ...(encodeEntry ?? {})\n                };\n            }\n        }\n        return (0,_util__WEBPACK_IMPORTED_MODULE_11__.isEmpty)(encodeEntry) ? undefined : encodeEntry;\n    }\n    assembleLayout() {\n        if (!this.layout) {\n            return undefined;\n        }\n        const { spacing, ...layout } = this.layout;\n        const { component, config } = this;\n        const titleBand = (0,_header_assemble__WEBPACK_IMPORTED_MODULE_15__.assembleLayoutTitleBand)(component.layoutHeaders, config);\n        return {\n            padding: spacing,\n            ...this.assembleDefaultLayout(),\n            ...layout,\n            ...(titleBand ? { titleBand } : {})\n        };\n    }\n    assembleDefaultLayout() {\n        return {};\n    }\n    assembleHeaderMarks() {\n        const { layoutHeaders } = this.component;\n        let headerMarks = [];\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_0__.FACET_CHANNELS) {\n            if (layoutHeaders[channel].title) {\n                headerMarks.push((0,_header_assemble__WEBPACK_IMPORTED_MODULE_15__.assembleTitleGroup)(this, channel));\n            }\n        }\n        for (const channel of _header_component__WEBPACK_IMPORTED_MODULE_16__.HEADER_CHANNELS) {\n            headerMarks = headerMarks.concat((0,_header_assemble__WEBPACK_IMPORTED_MODULE_15__.assembleHeaderGroups)(this, channel));\n        }\n        return headerMarks;\n    }\n    assembleAxes() {\n        return (0,_axis_assemble__WEBPACK_IMPORTED_MODULE_13__.assembleAxes)(this.component.axes, this.config);\n    }\n    assembleLegends() {\n        return (0,_legend_assemble__WEBPACK_IMPORTED_MODULE_19__.assembleLegends)(this);\n    }\n    assembleProjections() {\n        return (0,_projection_assemble__WEBPACK_IMPORTED_MODULE_21__.assembleProjections)(this);\n    }\n    assembleTitle() {\n        const { encoding, ...titleNoEncoding } = this.title ?? {};\n        const title = {\n            ...(0,_title__WEBPACK_IMPORTED_MODULE_9__.extractTitleConfig)(this.config.title).nonMarkTitleProperties,\n            ...titleNoEncoding,\n            ...(encoding ? { encode: { update: encoding } } : {})\n        };\n        if (title.text) {\n            if ((0,_util__WEBPACK_IMPORTED_MODULE_11__.contains)(['unit', 'layer'], this.type)) {\n                // Unit/Layer\n                if ((0,_util__WEBPACK_IMPORTED_MODULE_11__.contains)(['middle', undefined], title.anchor)) {\n                    title.frame ?? (title.frame = 'group');\n                }\n            }\n            else {\n                // composition with Vega layout\n                // Set title = \"start\" by default for composition as \"middle\" does not look nice\n                // https://github.com/vega/vega/issues/960#issuecomment-471360328\n                title.anchor ?? (title.anchor = 'start');\n            }\n            return (0,_util__WEBPACK_IMPORTED_MODULE_11__.isEmpty)(title) ? undefined : title;\n        }\n        return undefined;\n    }\n    /**\n     * Assemble the mark group for this model. We accept optional `signals` so that we can include concat top-level signals with the top-level model's local signals.\n     */\n    assembleGroup(signals = []) {\n        const group = {};\n        signals = signals.concat(this.assembleSignals());\n        if (signals.length > 0) {\n            group.signals = signals;\n        }\n        const layout = this.assembleLayout();\n        if (layout) {\n            group.layout = layout;\n        }\n        group.marks = [].concat(this.assembleHeaderMarks(), this.assembleMarks());\n        // Only include scales if this spec is top-level or if parent is facet.\n        // (Otherwise, it will be merged with upper-level's scope.)\n        const scales = !this.parent || isFacetModel(this.parent) ? (0,_scale_assemble__WEBPACK_IMPORTED_MODULE_23__.assembleScales)(this) : [];\n        if (scales.length > 0) {\n            group.scales = scales;\n        }\n        const axes = this.assembleAxes();\n        if (axes.length > 0) {\n            group.axes = axes;\n        }\n        const legends = this.assembleLegends();\n        if (legends.length > 0) {\n            group.legends = legends;\n        }\n        return group;\n    }\n    getName(text) {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_11__.varName)((this.name ? `${this.name}_` : '') + text);\n    }\n    getDataName(type) {\n        return this.getName(_data__WEBPACK_IMPORTED_MODULE_2__.DataSourceType[type].toLowerCase());\n    }\n    /**\n     * Request a data source name for the given data source type and mark that data source as required.\n     * This method should be called in parse, so that all used data source can be correctly instantiated in assembleData().\n     * You can lookup the correct dataset name in assemble with `lookupDataSource`.\n     */\n    requestDataName(name) {\n        const fullName = this.getDataName(name);\n        // Increase ref count. This is critical because otherwise we won't create a data source.\n        // We also increase the ref counts on OutputNode.getSource() calls.\n        const refCounts = this.component.data.outputNodeRefCounts;\n        refCounts[fullName] = (refCounts[fullName] || 0) + 1;\n        return fullName;\n    }\n    getSizeSignalRef(layoutSizeType) {\n        if (isFacetModel(this.parent)) {\n            const sizeType = (0,_layoutsize_component__WEBPACK_IMPORTED_MODULE_18__.getSizeTypeFromLayoutSizeType)(layoutSizeType);\n            const channel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getPositionScaleChannel)(sizeType);\n            const scaleComponent = this.component.scales[channel];\n            if (scaleComponent && !scaleComponent.merged) {\n                // independent scale\n                const type = scaleComponent.get('type');\n                const range = scaleComponent.get('range');\n                if ((0,_scale__WEBPACK_IMPORTED_MODULE_6__.hasDiscreteDomain)(type) && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_12__.isVgRangeStep)(range)) {\n                    const scaleName = scaleComponent.get('name');\n                    const domain = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_24__.assembleDomain)(this, channel);\n                    const field = (0,_scale_domain__WEBPACK_IMPORTED_MODULE_24__.getFieldFromDomain)(domain);\n                    if (field) {\n                        const fieldRef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)({ aggregate: 'distinct', field }, { expr: 'datum' });\n                        return {\n                            signal: (0,_layoutsize_assemble__WEBPACK_IMPORTED_MODULE_17__.sizeExpr)(scaleName, scaleComponent, fieldRef)\n                        };\n                    }\n                    else {\n                        _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.unknownField(channel));\n                        return null;\n                    }\n                }\n            }\n        }\n        return {\n            signal: this.signalNameMap.get(this.getName(layoutSizeType))\n        };\n    }\n    /**\n     * Lookup the name of the datasource for an output node. You probably want to call this in assemble.\n     */\n    lookupDataSource(name) {\n        const node = this.component.data.outputNodes[name];\n        if (!node) {\n            // Name not found in map so let's just return what we got.\n            // This can happen if we already have the correct name.\n            return name;\n        }\n        return node.getSource();\n    }\n    getSignalName(oldSignalName) {\n        return this.signalNameMap.get(oldSignalName);\n    }\n    renameSignal(oldName, newName) {\n        this.signalNameMap.rename(oldName, newName);\n    }\n    renameScale(oldName, newName) {\n        this.scaleNameMap.rename(oldName, newName);\n    }\n    renameProjection(oldName, newName) {\n        this.projectionNameMap.rename(oldName, newName);\n    }\n    /**\n     * @return scale name for a given channel after the scale has been parsed and named.\n     */\n    scaleName(originalScaleName, parse) {\n        if (parse) {\n            // During the parse phase always return a value\n            // No need to refer to rename map because a scale can't be renamed\n            // before it has the original name.\n            return this.getName(originalScaleName);\n        }\n        // If there is a scale for the channel, it should either\n        // be in the scale component or exist in the name map\n        if (\n        // If there is a scale for the channel, there should be a local scale component for it\n        ((0,_channel__WEBPACK_IMPORTED_MODULE_0__.isChannel)(originalScaleName) && (0,_channel__WEBPACK_IMPORTED_MODULE_0__.isScaleChannel)(originalScaleName) && this.component.scales[originalScaleName]) ||\n            // in the scale name map (the scale get merged by its parent)\n            this.scaleNameMap.has(this.getName(originalScaleName))) {\n            return this.scaleNameMap.get(this.getName(originalScaleName));\n        }\n        return undefined;\n    }\n    /**\n     * @return projection name after the projection has been parsed and named.\n     */\n    projectionName(parse) {\n        if (parse) {\n            // During the parse phase always return a value\n            // No need to refer to rename map because a projection can't be renamed\n            // before it has the original name.\n            return this.getName('projection');\n        }\n        if ((this.component.projection && !this.component.projection.merged) ||\n            this.projectionNameMap.has(this.getName('projection'))) {\n            return this.projectionNameMap.get(this.getName('projection'));\n        }\n        return undefined;\n    }\n    /**\n     * Traverse a model's hierarchy to get the scale component for a particular channel.\n     */\n    getScaleComponent(channel) {\n        /* istanbul ignore next: This is warning for debugging test */\n        if (!this.component.scales) {\n            throw new Error('getScaleComponent cannot be called before parseScale(). Make sure you have called parseScale or use parseUnitModelWithScale().');\n        }\n        const localScaleComponent = this.component.scales[channel];\n        if (localScaleComponent && !localScaleComponent.merged) {\n            return localScaleComponent;\n        }\n        return this.parent ? this.parent.getScaleComponent(channel) : undefined;\n    }\n    /**\n     * Traverse a model's hierarchy to get a particular selection component.\n     */\n    getSelectionComponent(variableName, origName) {\n        let sel = this.component.selection[variableName];\n        if (!sel && this.parent) {\n            sel = this.parent.getSelectionComponent(variableName, origName);\n        }\n        if (!sel) {\n            throw new Error(_log__WEBPACK_IMPORTED_MODULE_5__.message.selectionNotFound(origName));\n        }\n        return sel;\n    }\n    /**\n     * Returns true if the model has a signalRef for an axis orient.\n     */\n    hasAxisOrientSignalRef() {\n        return (this.component.axes.x?.some(a => a.hasOrientSignalRef()) ||\n            this.component.axes.y?.some(a => a.hasOrientSignalRef()));\n    }\n}\n/** Abstract class for UnitModel and FacetModel. Both of which can contain fieldDefs as a part of its own specification. */\nclass ModelWithField extends Model {\n    /** Get \"field\" reference for Vega */\n    vgField(channel, opt = {}) {\n        const fieldDef = this.fieldDef(channel);\n        if (!fieldDef) {\n            return undefined;\n        }\n        return (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(fieldDef, opt);\n    }\n    reduceFieldDef(f, init) {\n        return (0,_encoding__WEBPACK_IMPORTED_MODULE_3__.reduce)(this.getMapping(), (acc, cd, c) => {\n            const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldDef)(cd);\n            if (fieldDef) {\n                return f(acc, fieldDef, c);\n            }\n            return acc;\n        }, init);\n    }\n    forEachFieldDef(f, t) {\n        (0,_encoding__WEBPACK_IMPORTED_MODULE_3__.forEach)(this.getMapping(), (cd, c) => {\n            const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldDef)(cd);\n            if (fieldDef) {\n                f(fieldDef, c);\n            }\n        }, t);\n    }\n}\n//# sourceMappingURL=model.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/model.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/predicate.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/predicate.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   expression: () => (/* binding */ expression)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _selection_parse__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./selection/parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n\n\n\n\n/**\n * Converts a predicate into an expression.\n */\n// model is only used for selection filters.\nfunction expression(model, filterOp, node) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_2__.logicalExpr)(filterOp, (predicate) => {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(predicate)) {\n            return predicate;\n        }\n        else if ((0,_predicate__WEBPACK_IMPORTED_MODULE_1__.isSelectionPredicate)(predicate)) {\n            return (0,_selection_parse__WEBPACK_IMPORTED_MODULE_3__.parseSelectionPredicate)(model, predicate, node);\n        }\n        else {\n            // Filter Object\n            return (0,_predicate__WEBPACK_IMPORTED_MODULE_1__.fieldFilterExpression)(predicate);\n        }\n    });\n}\n//# sourceMappingURL=predicate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/predicate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/projection/assemble.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/projection/assemble.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleProjectionForModel: () => (/* binding */ assembleProjectionForModel),\n/* harmony export */   assembleProjections: () => (/* binding */ assembleProjections),\n/* harmony export */   assembleProjectionsForModelAndChildren: () => (/* binding */ assembleProjectionsForModelAndChildren)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n\n\n\nfunction assembleProjections(model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_2__.isLayerModel)(model) || (0,_model__WEBPACK_IMPORTED_MODULE_2__.isConcatModel)(model)) {\n        return assembleProjectionsForModelAndChildren(model);\n    }\n    else {\n        return assembleProjectionForModel(model);\n    }\n}\nfunction assembleProjectionsForModelAndChildren(model) {\n    return model.children.reduce((projections, child) => {\n        return projections.concat(child.assembleProjections());\n    }, assembleProjectionForModel(model));\n}\nfunction assembleProjectionForModel(model) {\n    const component = model.component.projection;\n    if (!component || component.merged) {\n        return [];\n    }\n    const projection = component.combine();\n    const { name } = projection; // we need to extract name so that it is always present in the output and pass TS type validation\n    if (!component.data) {\n        // generate custom projection, no automatic fitting\n        return [\n            {\n                name,\n                // translate to center by default\n                ...{ translate: { signal: '[width / 2, height / 2]' } },\n                // parameters, overwrite default translate if specified\n                ...projection\n            }\n        ];\n    }\n    else {\n        // generate projection that uses extent fitting\n        const size = {\n            signal: `[${component.size.map(ref => ref.signal).join(', ')}]`\n        };\n        const fits = component.data.reduce((sources, data) => {\n            const source = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_1__.isSignalRef)(data) ? data.signal : `data('${model.lookupDataSource(data)}')`;\n            if (!(0,_util__WEBPACK_IMPORTED_MODULE_0__.contains)(sources, source)) {\n                // build a unique list of sources\n                sources.push(source);\n            }\n            return sources;\n        }, []);\n        if (fits.length <= 0) {\n            throw new Error(\"Projection's fit didn't find any data sources\");\n        }\n        return [\n            {\n                name,\n                size,\n                fit: {\n                    signal: fits.length > 1 ? `[${fits.join(', ')}]` : fits[0]\n                },\n                ...projection\n            }\n        ];\n    }\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/projection/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/projection/component.js":
/*!******************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/projection/component.js ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ProjectionComponent: () => (/* binding */ ProjectionComponent)\n/* harmony export */ });\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\nclass ProjectionComponent extends _split__WEBPACK_IMPORTED_MODULE_0__.Split {\n    constructor(name, specifiedProjection, size, data) {\n        super({ ...specifiedProjection }, // all explicit properties of projection\n        { name } // name as initial implicit property\n        );\n        this.specifiedProjection = specifiedProjection;\n        this.size = size;\n        this.data = data;\n        this.merged = false;\n    }\n    /**\n     * Whether the projection parameters should fit provided data.\n     */\n    get isFit() {\n        return !!this.data;\n    }\n}\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/projection/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/projection/parse.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/projection/parse.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseProjection: () => (/* binding */ parseProjection)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _projection__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../projection */ \"../../node_modules/vega-lite/build/src/projection.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/projection/component.js\");\n\n\n\n\n\n\n\n\n\n\nfunction parseProjection(model) {\n    model.component.projection = (0,_model__WEBPACK_IMPORTED_MODULE_8__.isUnitModel)(model) ? parseUnitProjection(model) : parseNonUnitProjections(model);\n}\nfunction parseUnitProjection(model) {\n    if (model.hasProjection) {\n        const proj = (0,_expr__WEBPACK_IMPORTED_MODULE_4__.replaceExprRef)(model.specifiedProjection);\n        const fit = !(proj && (proj.scale != null || proj.translate != null));\n        const size = fit ? [model.getSizeSignalRef('width'), model.getSizeSignalRef('height')] : undefined;\n        const data = fit ? gatherFitData(model) : undefined;\n        const projComp = new _component__WEBPACK_IMPORTED_MODULE_9__.ProjectionComponent(model.projectionName(true), {\n            ...((0,_expr__WEBPACK_IMPORTED_MODULE_4__.replaceExprRef)(model.config.projection) ?? {}),\n            ...(proj ?? {})\n        }, size, data);\n        if (!projComp.get('type')) {\n            projComp.set('type', 'equalEarth', false);\n        }\n        return projComp;\n    }\n    return undefined;\n}\nfunction gatherFitData(model) {\n    const data = [];\n    const { encoding } = model;\n    for (const posssiblePair of [\n        [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE],\n        [_channel__WEBPACK_IMPORTED_MODULE_1__.LONGITUDE2, _channel__WEBPACK_IMPORTED_MODULE_1__.LATITUDE2]\n    ]) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.getFieldOrDatumDef)(encoding[posssiblePair[0]]) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.getFieldOrDatumDef)(encoding[posssiblePair[1]])) {\n            data.push({\n                signal: model.getName(`geojson_${data.length}`)\n            });\n        }\n    }\n    if (model.channelHasField(_channel__WEBPACK_IMPORTED_MODULE_1__.SHAPE) && model.typedFieldDef(_channel__WEBPACK_IMPORTED_MODULE_1__.SHAPE).type === _type__WEBPACK_IMPORTED_MODULE_6__.GEOJSON) {\n        data.push({\n            signal: model.getName(`geojson_${data.length}`)\n        });\n    }\n    if (data.length === 0) {\n        // main source is geojson, so we can just use that\n        data.push(model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_3__.DataSourceType.Main));\n    }\n    return data;\n}\nfunction mergeIfNoConflict(first, second) {\n    const allPropertiesShared = (0,_util__WEBPACK_IMPORTED_MODULE_7__.every)(_projection__WEBPACK_IMPORTED_MODULE_5__.PROJECTION_PROPERTIES, prop => {\n        // neither has the property\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(first.explicit, prop) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(second.explicit, prop)) {\n            return true;\n        }\n        // both have property and an equal value for property\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(first.explicit, prop) &&\n            (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(second.explicit, prop) &&\n            // some properties might be signals or objects and require hashing for comparison\n            (0,_util__WEBPACK_IMPORTED_MODULE_7__.deepEqual)(first.get(prop), second.get(prop))) {\n            return true;\n        }\n        return false;\n    });\n    const size = (0,_util__WEBPACK_IMPORTED_MODULE_7__.deepEqual)(first.size, second.size);\n    if (size) {\n        if (allPropertiesShared) {\n            return first;\n        }\n        else if ((0,_util__WEBPACK_IMPORTED_MODULE_7__.deepEqual)(first.explicit, {})) {\n            return second;\n        }\n        else if ((0,_util__WEBPACK_IMPORTED_MODULE_7__.deepEqual)(second.explicit, {})) {\n            return first;\n        }\n    }\n    // if all properties don't match, let each unit spec have its own projection\n    return null;\n}\nfunction parseNonUnitProjections(model) {\n    if (model.children.length === 0) {\n        return undefined;\n    }\n    let nonUnitProjection;\n    // parse all children first\n    for (const child of model.children) {\n        parseProjection(child);\n    }\n    // analyze parsed projections, attempt to merge\n    const mergable = (0,_util__WEBPACK_IMPORTED_MODULE_7__.every)(model.children, child => {\n        const projection = child.component.projection;\n        if (!projection) {\n            // child layer does not use a projection\n            return true;\n        }\n        else if (!nonUnitProjection) {\n            // cached 'projection' is null, cache this one\n            nonUnitProjection = projection;\n            return true;\n        }\n        else {\n            const merge = mergeIfNoConflict(nonUnitProjection, projection);\n            if (merge) {\n                nonUnitProjection = merge;\n            }\n            return !!merge;\n        }\n    });\n    // if cached one and all other children share the same projection,\n    if (nonUnitProjection && mergable) {\n        // so we can elevate it to the layer level\n        const name = model.projectionName(true);\n        const modelProjection = new _component__WEBPACK_IMPORTED_MODULE_9__.ProjectionComponent(name, nonUnitProjection.specifiedProjection, nonUnitProjection.size, (0,_util__WEBPACK_IMPORTED_MODULE_7__.duplicate)(nonUnitProjection.data));\n        // rename and assign all others as merged\n        for (const child of model.children) {\n            const projection = child.component.projection;\n            if (projection) {\n                if (projection.isFit) {\n                    modelProjection.data.push(...child.component.projection.data);\n                }\n                child.renameProjection(projection.get('name'), name);\n                projection.merged = true;\n            }\n        }\n        return modelProjection;\n    }\n    return undefined;\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/projection/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/resolve.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/resolve.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   defaultScaleResolve: () => (/* binding */ defaultScaleResolve),\n/* harmony export */   parseGuideResolve: () => (/* binding */ parseGuideResolve)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n\n\n\nfunction defaultScaleResolve(channel, model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_2__.isFacetModel)(model)) {\n        return channel === 'theta' ? 'independent' : 'shared';\n    }\n    else if ((0,_model__WEBPACK_IMPORTED_MODULE_2__.isLayerModel)(model)) {\n        return 'shared';\n    }\n    else if ((0,_model__WEBPACK_IMPORTED_MODULE_2__.isConcatModel)(model)) {\n        return (0,_channel__WEBPACK_IMPORTED_MODULE_0__.isXorY)(channel) || channel === 'theta' || channel === 'radius' ? 'independent' : 'shared';\n    }\n    /* istanbul ignore next: should never reach here. */\n    throw new Error('invalid model type for resolve');\n}\nfunction parseGuideResolve(resolve, channel) {\n    const channelScaleResolve = resolve.scale[channel];\n    const guide = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.isXorY)(channel) ? 'axis' : 'legend';\n    if (channelScaleResolve === 'independent') {\n        if (resolve[guide][channel] === 'shared') {\n            _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.independentScaleMeansIndependentGuide(channel));\n        }\n        return 'independent';\n    }\n    return resolve[guide][channel] || 'shared';\n}\n//# sourceMappingURL=resolve.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/resolve.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/assemble.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/assemble.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleScaleRange: () => (/* binding */ assembleScaleRange),\n/* harmony export */   assembleScales: () => (/* binding */ assembleScales),\n/* harmony export */   assembleScalesForModel: () => (/* binding */ assembleScalesForModel)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _selection_assemble__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../selection/assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _domain__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./domain */ \"../../node_modules/vega-lite/build/src/compile/scale/domain.js\");\n\n\n\n\n\n\n\nfunction assembleScales(model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_4__.isLayerModel)(model) || (0,_model__WEBPACK_IMPORTED_MODULE_4__.isConcatModel)(model)) {\n        // For concat and layer, include scales of children too\n        return model.children.reduce((scales, child) => {\n            return scales.concat(assembleScales(child));\n        }, assembleScalesForModel(model));\n    }\n    else {\n        // For facet, child scales would not be included in the parent's scope.\n        // For unit, there is no child.\n        return assembleScalesForModel(model);\n    }\n}\nfunction assembleScalesForModel(model) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(model.component.scales).reduce((scales, channel) => {\n        const scaleComponent = model.component.scales[channel];\n        if (scaleComponent.merged) {\n            // Skipped merged scales\n            return scales;\n        }\n        const scale = scaleComponent.combine();\n        const { name, type, selectionExtent, domains: _d, range: _r, reverse, ...otherScaleProps } = scale;\n        const range = assembleScaleRange(scale.range, name, channel, model);\n        const domain = (0,_domain__WEBPACK_IMPORTED_MODULE_6__.assembleDomain)(model, channel);\n        const domainRaw = selectionExtent\n            ? (0,_selection_assemble__WEBPACK_IMPORTED_MODULE_5__.assembleSelectionScaleDomain)(model, selectionExtent, scaleComponent, domain)\n            : null;\n        scales.push({\n            name,\n            type,\n            ...(domain ? { domain } : {}),\n            ...(domainRaw ? { domainRaw } : {}),\n            range,\n            ...(reverse !== undefined ? { reverse: reverse } : {}),\n            ...otherScaleProps\n        });\n        return scales;\n    }, []);\n}\nfunction assembleScaleRange(scaleRange, scaleName, channel, model) {\n    // add signals to x/y range\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isXorY)(channel)) {\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_3__.isVgRangeStep)(scaleRange)) {\n            // For width/height step, use a signal created in layout assemble instead of a constant step.\n            return {\n                step: { signal: `${scaleName}_step` }\n            };\n        }\n    }\n    else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(scaleRange) && (0,_vega_schema__WEBPACK_IMPORTED_MODULE_3__.isDataRefDomain)(scaleRange)) {\n        return {\n            ...scaleRange,\n            data: model.lookupDataSource(scaleRange.data)\n        };\n    }\n    return scaleRange;\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/component.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/component.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ScaleComponent: () => (/* binding */ ScaleComponent)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n\n\nclass ScaleComponent extends _split__WEBPACK_IMPORTED_MODULE_2__.Split {\n    constructor(name, typeWithExplicit) {\n        super({}, // no initial explicit property\n        { name } // name as initial implicit property\n        );\n        this.merged = false;\n        this.setWithExplicit('type', typeWithExplicit);\n    }\n    /**\n     * Whether the scale definitely includes zero in the domain\n     */\n    domainDefinitelyIncludesZero() {\n        if (this.get('zero') !== false) {\n            return true;\n        }\n        return (0,_util__WEBPACK_IMPORTED_MODULE_1__.some)(this.get('domains'), d => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(d) && d.length === 2 && d[0] <= 0 && d[1] >= 0);\n    }\n}\n//# sourceMappingURL=component.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/component.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/domain.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/domain.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleDomain: () => (/* binding */ assembleDomain),\n/* harmony export */   canUseUnaggregatedDomain: () => (/* binding */ canUseUnaggregatedDomain),\n/* harmony export */   domainSort: () => (/* binding */ domainSort),\n/* harmony export */   getFieldFromDomain: () => (/* binding */ getFieldFromDomain),\n/* harmony export */   mergeDomains: () => (/* binding */ mergeDomains),\n/* harmony export */   parseDomainForChannel: () => (/* binding */ parseDomainForChannel),\n/* harmony export */   parseScaleDomain: () => (/* binding */ parseScaleDomain)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _data_bin__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../data/bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _data_calculate__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../data/calculate */ \"../../node_modules/vega-lite/build/src/compile/data/calculate.js\");\n/* harmony import */ var _data_optimize__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../data/optimize */ \"../../node_modules/vega-lite/build/src/compile/data/optimize.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _signal__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../signal */ \"../../node_modules/vega-lite/build/src/compile/signal.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction parseScaleDomain(model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_15__.isUnitModel)(model)) {\n        parseUnitScaleDomain(model);\n    }\n    else {\n        parseNonUnitScaleDomain(model);\n    }\n}\nfunction parseUnitScaleDomain(model) {\n    const localScaleComponents = model.component.scales;\n    for (const channel of _util__WEBPACK_IMPORTED_MODULE_10__.keys(localScaleComponents)) {\n        const domains = parseDomainForChannel(model, channel);\n        const localScaleCmpt = localScaleComponents[channel];\n        localScaleCmpt.setWithExplicit('domains', domains);\n        parseSelectionDomain(model, channel);\n        if (model.component.data.isFaceted) {\n            // get resolve from closest facet parent as this decides whether we need to refer to cloned subtree or not\n            let facetParent = model;\n            while (!(0,_model__WEBPACK_IMPORTED_MODULE_15__.isFacetModel)(facetParent) && facetParent.parent) {\n                facetParent = facetParent.parent;\n            }\n            const resolve = facetParent.component.resolve.scale[channel];\n            if (resolve === 'shared') {\n                for (const domain of domains.value) {\n                    // Replace the scale domain with data output from a cloned subtree after the facet.\n                    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(domain)) {\n                        // use data from cloned subtree (which is the same as data but with a prefix added once)\n                        domain.data = _data_optimize__WEBPACK_IMPORTED_MODULE_14__.FACET_SCALE_PREFIX + domain.data.replace(_data_optimize__WEBPACK_IMPORTED_MODULE_14__.FACET_SCALE_PREFIX, '');\n                    }\n                }\n            }\n        }\n    }\n}\nfunction parseNonUnitScaleDomain(model) {\n    for (const child of model.children) {\n        parseScaleDomain(child);\n    }\n    const localScaleComponents = model.component.scales;\n    for (const channel of _util__WEBPACK_IMPORTED_MODULE_10__.keys(localScaleComponents)) {\n        let domains;\n        let selectionExtent = null;\n        for (const child of model.children) {\n            const childComponent = child.component.scales[channel];\n            if (childComponent) {\n                if (domains === undefined) {\n                    domains = childComponent.getWithExplicit('domains');\n                }\n                else {\n                    domains = (0,_split__WEBPACK_IMPORTED_MODULE_17__.mergeValuesWithExplicit)(domains, childComponent.getWithExplicit('domains'), 'domains', 'scale', domainsTieBreaker);\n                }\n                const se = childComponent.get('selectionExtent');\n                if (selectionExtent && se && selectionExtent.param !== se.param) {\n                    _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.NEEDS_SAME_SELECTION);\n                }\n                selectionExtent = se;\n            }\n        }\n        localScaleComponents[channel].setWithExplicit('domains', domains);\n        if (selectionExtent) {\n            localScaleComponents[channel].set('selectionExtent', selectionExtent, true);\n        }\n    }\n}\n/**\n * Remove unaggregated domain if it is not applicable\n * Add unaggregated domain if domain is not specified and config.scale.useUnaggregatedDomain is true.\n */\nfunction normalizeUnaggregatedDomain(domain, fieldDef, scaleType, scaleConfig) {\n    if (domain === 'unaggregated') {\n        const { valid, reason } = canUseUnaggregatedDomain(fieldDef, scaleType);\n        if (!valid) {\n            _log__WEBPACK_IMPORTED_MODULE_6__.warn(reason);\n            return undefined;\n        }\n    }\n    else if (domain === undefined && scaleConfig.useUnaggregatedDomain) {\n        // Apply config if domain is not specified.\n        const { valid } = canUseUnaggregatedDomain(fieldDef, scaleType);\n        if (valid) {\n            return 'unaggregated';\n        }\n    }\n    return domain;\n}\nfunction parseDomainForChannel(model, channel) {\n    const scaleType = model.getScaleComponent(channel).get('type');\n    const { encoding } = model;\n    const domain = normalizeUnaggregatedDomain(model.scaleDomain(channel), model.typedFieldDef(channel), scaleType, model.config.scale);\n    if (domain !== model.scaleDomain(channel)) {\n        model.specifiedScales[channel] = {\n            ...model.specifiedScales[channel],\n            domain\n        };\n    }\n    // If channel is either X or Y then union them with X2 & Y2 if they exist\n    if (channel === 'x' && (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldOrDatumDef)(encoding.x2)) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldOrDatumDef)(encoding.x)) {\n            return (0,_split__WEBPACK_IMPORTED_MODULE_17__.mergeValuesWithExplicit)(parseSingleChannelDomain(scaleType, domain, model, 'x'), parseSingleChannelDomain(scaleType, domain, model, 'x2'), 'domain', 'scale', domainsTieBreaker);\n        }\n        else {\n            return parseSingleChannelDomain(scaleType, domain, model, 'x2');\n        }\n    }\n    else if (channel === 'y' && (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldOrDatumDef)(encoding.y2)) {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldOrDatumDef)(encoding.y)) {\n            return (0,_split__WEBPACK_IMPORTED_MODULE_17__.mergeValuesWithExplicit)(parseSingleChannelDomain(scaleType, domain, model, 'y'), parseSingleChannelDomain(scaleType, domain, model, 'y2'), 'domain', 'scale', domainsTieBreaker);\n        }\n        else {\n            return parseSingleChannelDomain(scaleType, domain, model, 'y2');\n        }\n    }\n    return parseSingleChannelDomain(scaleType, domain, model, channel);\n}\nfunction mapDomainToDataSignal(domain, type, timeUnit) {\n    return domain.map(v => {\n        const data = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.valueExpr)(v, { timeUnit, type });\n        return { signal: `{data: ${data}}` };\n    });\n}\nfunction convertDomainIfItIsDateTime(domain, type, timeUnit) {\n    // explicit value\n    const normalizedTimeUnit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_9__.normalizeTimeUnit)(timeUnit)?.unit;\n    if (type === 'temporal' || normalizedTimeUnit) {\n        return mapDomainToDataSignal(domain, type, normalizedTimeUnit);\n    }\n    return [domain]; // Date time won't make sense\n}\nfunction parseSingleChannelDomain(scaleType, domain, model, channel) {\n    const { encoding } = model;\n    const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldOrDatumDef)(encoding[channel]);\n    const { type } = fieldOrDatumDef;\n    const timeUnit = fieldOrDatumDef['timeUnit'];\n    if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.isDomainUnionWith)(domain)) {\n        const defaultDomain = parseSingleChannelDomain(scaleType, undefined, model, channel);\n        const unionWith = convertDomainIfItIsDateTime(domain.unionWith, type, timeUnit);\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeExplicit)([...unionWith, ...defaultDomain.value]);\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isSignalRef)(domain)) {\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeExplicit)([domain]);\n    }\n    else if (domain && domain !== 'unaggregated' && !(0,_scale__WEBPACK_IMPORTED_MODULE_7__.isParameterDomain)(domain)) {\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeExplicit)(convertDomainIfItIsDateTime(domain, type, timeUnit));\n    }\n    const stack = model.stack;\n    if (stack && channel === stack.fieldChannel) {\n        if (stack.offset === 'normalize') {\n            return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([[0, 1]]);\n        }\n        const data = model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main);\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n            {\n                data,\n                field: model.vgField(channel, { suffix: 'start' })\n            },\n            {\n                data,\n                field: model.vgField(channel, { suffix: 'end' })\n            }\n        ]);\n    }\n    const sort = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.isScaleChannel)(channel) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(fieldOrDatumDef) ? domainSort(model, channel, scaleType) : undefined;\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isDatumDef)(fieldOrDatumDef)) {\n        const d = convertDomainIfItIsDateTime([fieldOrDatumDef.datum], type, timeUnit);\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)(d);\n    }\n    const fieldDef = fieldOrDatumDef; // now we can be sure it's a fieldDef\n    if (domain === 'unaggregated') {\n        const data = model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main);\n        const { field } = fieldOrDatumDef;\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n            {\n                data,\n                field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)({ field, aggregate: 'min' })\n            },\n            {\n                data,\n                field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)({ field, aggregate: 'max' })\n            }\n        ]);\n    }\n    else if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(fieldDef.bin)) {\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasDiscreteDomain)(scaleType)) {\n            if (scaleType === 'bin-ordinal') {\n                // we can omit the domain as it is inferred from the `bins` property\n                return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([]);\n            }\n            // ordinal bin scale takes domain from bin_range, ordered by bin start\n            // This is useful for both axis-based scale (x/y) and legend-based scale (other channels).\n            return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n                {\n                    // If sort by aggregation of a specified sort field, we need to use RAW table,\n                    // so we can aggregate values for the scale independently from the main aggregation.\n                    data: _util__WEBPACK_IMPORTED_MODULE_10__.isBoolean(sort)\n                        ? model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main)\n                        : model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Raw),\n                    // Use range if we added it and the scale does not support computing a range as a signal.\n                    field: model.vgField(channel, (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.binRequiresRange)(fieldDef, channel) ? { binSuffix: 'range' } : {}),\n                    // we have to use a sort object if sort = true to make the sort correct by bin start\n                    sort: sort === true || !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(sort)\n                        ? {\n                            field: model.vgField(channel, {}),\n                            op: 'min' // min or max doesn't matter since we sort by the start of the bin range\n                        }\n                        : sort\n                }\n            ]);\n        }\n        else {\n            // continuous scales\n            const { bin } = fieldDef;\n            if ((0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n                const binSignal = (0,_data_bin__WEBPACK_IMPORTED_MODULE_12__.getBinSignalName)(model, fieldDef.field, bin);\n                return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n                    new _signal__WEBPACK_IMPORTED_MODULE_16__.SignalRefWrapper(() => {\n                        const signal = model.getSignalName(binSignal);\n                        return `[${signal}.start, ${signal}.stop]`;\n                    })\n                ]);\n            }\n            else {\n                return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n                    {\n                        data: model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main),\n                        field: model.vgField(channel, {})\n                    }\n                ]);\n            }\n        }\n    }\n    else if (fieldDef.timeUnit &&\n        _util__WEBPACK_IMPORTED_MODULE_10__.contains(['time', 'utc'], scaleType) &&\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.hasBandEnd)(fieldDef, (0,_model__WEBPACK_IMPORTED_MODULE_15__.isUnitModel)(model) ? model.encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_3__.getSecondaryRangeChannel)(channel)] : undefined, model.markDef, model.config)) {\n        const data = model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main);\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n            {\n                data,\n                field: model.vgField(channel)\n            },\n            {\n                data,\n                field: model.vgField(channel, { suffix: 'end' })\n            }\n        ]);\n    }\n    else if (sort) {\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n            {\n                // If sort by aggregation of a specified sort field, we need to use RAW table,\n                // so we can aggregate values for the scale independently from the main aggregation.\n                data: _util__WEBPACK_IMPORTED_MODULE_10__.isBoolean(sort)\n                    ? model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main)\n                    : model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Raw),\n                field: model.vgField(channel),\n                sort\n            }\n        ]);\n    }\n    else {\n        return (0,_split__WEBPACK_IMPORTED_MODULE_17__.makeImplicit)([\n            {\n                data: model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main),\n                field: model.vgField(channel)\n            }\n        ]);\n    }\n}\nfunction normalizeSortField(sort, isStackedMeasure) {\n    const { op, field, order } = sort;\n    return {\n        // Apply default op\n        op: op ?? (isStackedMeasure ? 'sum' : _sort__WEBPACK_IMPORTED_MODULE_8__.DEFAULT_SORT_OP),\n        // flatten nested fields\n        ...(field ? { field: _util__WEBPACK_IMPORTED_MODULE_10__.replacePathInField(field) } : {}),\n        ...(order ? { order } : {})\n    };\n}\nfunction parseSelectionDomain(model, channel) {\n    const scale = model.component.scales[channel];\n    const spec = model.specifiedScales[channel].domain;\n    const bin = model.fieldDef(channel)?.bin;\n    const domain = (0,_scale__WEBPACK_IMPORTED_MODULE_7__.isParameterDomain)(spec) && spec;\n    const extent = (0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinParams)(bin) && (0,_bin__WEBPACK_IMPORTED_MODULE_2__.isParameterExtent)(bin.extent) && bin.extent;\n    if (domain || extent) {\n        // As scale parsing occurs before selection parsing, we cannot set\n        // domainRaw directly. So instead, we store the selectionExtent on\n        // the scale component, and then add domainRaw during scale assembly.\n        scale.set('selectionExtent', domain ?? extent, true);\n    }\n}\nfunction domainSort(model, channel, scaleType) {\n    if (!(0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasDiscreteDomain)(scaleType)) {\n        return undefined;\n    }\n    // save to cast as the only exception is the geojson type for shape, which would not generate a scale\n    const fieldDef = model.fieldDef(channel);\n    const sort = fieldDef.sort;\n    // if the sort is specified with array, use the derived sort index field\n    if ((0,_sort__WEBPACK_IMPORTED_MODULE_8__.isSortArray)(sort)) {\n        return {\n            op: 'min',\n            field: (0,_data_calculate__WEBPACK_IMPORTED_MODULE_13__.sortArrayIndexField)(fieldDef, channel),\n            order: 'ascending'\n        };\n    }\n    const { stack } = model;\n    const stackDimensions = stack\n        ? new Set([...stack.groupbyFields, ...stack.stackBy.map(s => s.fieldDef.field)])\n        : undefined;\n    // Sorted based on an aggregate calculation over a specified sort field (only for ordinal scale)\n    if ((0,_sort__WEBPACK_IMPORTED_MODULE_8__.isSortField)(sort)) {\n        const isStackedMeasure = stack && !stackDimensions.has(sort.field);\n        return normalizeSortField(sort, isStackedMeasure);\n    }\n    else if ((0,_sort__WEBPACK_IMPORTED_MODULE_8__.isSortByEncoding)(sort)) {\n        const { encoding, order } = sort;\n        const fieldDefToSortBy = model.fieldDef(encoding);\n        const { aggregate, field } = fieldDefToSortBy;\n        const isStackedMeasure = stack && !stackDimensions.has(field);\n        if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggregate) || (0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggregate)) {\n            return normalizeSortField({\n                field: (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDefToSortBy),\n                order\n            }, isStackedMeasure);\n        }\n        else if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isAggregateOp)(aggregate) || !aggregate) {\n            return normalizeSortField({\n                op: aggregate,\n                field,\n                order\n            }, isStackedMeasure);\n        }\n    }\n    else if (sort === 'descending') {\n        return {\n            op: 'min',\n            field: model.vgField(channel),\n            order: 'descending'\n        };\n    }\n    else if (_util__WEBPACK_IMPORTED_MODULE_10__.contains(['ascending', undefined /* default =ascending*/], sort)) {\n        return true;\n    }\n    // sort == null\n    return undefined;\n}\n/**\n * Determine if a scale can use unaggregated domain.\n * @return {Boolean} Returns true if all of the following conditions apply:\n * 1. `scale.domain` is `unaggregated`\n * 2. Aggregation function is not `count` or `sum`\n * 3. The scale is quantitative or time scale.\n */\nfunction canUseUnaggregatedDomain(fieldDef, scaleType) {\n    const { aggregate, type } = fieldDef;\n    if (!aggregate) {\n        return {\n            valid: false,\n            reason: _log__WEBPACK_IMPORTED_MODULE_6__.message.unaggregateDomainHasNoEffectForRawField(fieldDef)\n        };\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(aggregate) && !_aggregate__WEBPACK_IMPORTED_MODULE_1__.SHARED_DOMAIN_OPS.has(aggregate)) {\n        return {\n            valid: false,\n            reason: _log__WEBPACK_IMPORTED_MODULE_6__.message.unaggregateDomainWithNonSharedDomainOp(aggregate)\n        };\n    }\n    if (type === 'quantitative') {\n        if (scaleType === 'log') {\n            return {\n                valid: false,\n                reason: _log__WEBPACK_IMPORTED_MODULE_6__.message.unaggregatedDomainWithLogScale(fieldDef)\n            };\n        }\n    }\n    return { valid: true };\n}\n/**\n * Tie breaker for mergeValuesWithExplicit for domains. We concat the specified values.\n */\nfunction domainsTieBreaker(v1, v2, property, propertyOf) {\n    if (v1.explicit && v2.explicit) {\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.mergeConflictingDomainProperty(property, propertyOf, v1.value, v2.value));\n    }\n    // If equal score, concat the domains so that we union them later.\n    return { explicit: v1.explicit, value: [...v1.value, ...v2.value] };\n}\n/**\n * Converts an array of domains to a single Vega scale domain.\n */\nfunction mergeDomains(domains) {\n    const uniqueDomains = _util__WEBPACK_IMPORTED_MODULE_10__.unique(domains.map(domain => {\n        // ignore sort property when computing the unique domains\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(domain)) {\n            const { sort: _s, ...domainWithoutSort } = domain;\n            return domainWithoutSort;\n        }\n        return domain;\n    }), _util__WEBPACK_IMPORTED_MODULE_10__.hash);\n    const sorts = _util__WEBPACK_IMPORTED_MODULE_10__.unique(domains\n        .map(d => {\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(d)) {\n            const s = d.sort;\n            if (s !== undefined && !_util__WEBPACK_IMPORTED_MODULE_10__.isBoolean(s)) {\n                if ('op' in s && s.op === 'count') {\n                    // let's make sure that if op is count, we don't use a field\n                    delete s.field;\n                }\n                if (s.order === 'ascending') {\n                    // drop order: ascending as it is the default\n                    delete s.order;\n                }\n            }\n            return s;\n        }\n        return undefined;\n    })\n        .filter(s => s !== undefined), _util__WEBPACK_IMPORTED_MODULE_10__.hash);\n    if (uniqueDomains.length === 0) {\n        return undefined;\n    }\n    else if (uniqueDomains.length === 1) {\n        const domain = domains[0];\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(domain) && sorts.length > 0) {\n            let sort = sorts[0];\n            if (sorts.length > 1) {\n                _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.MORE_THAN_ONE_SORT);\n                // Get sorts with non-default ops\n                const filteredSorts = sorts.filter(s => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(s) && 'op' in s && s.op !== 'min');\n                if (sorts.every(s => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(s) && 'op' in s) && filteredSorts.length === 1) {\n                    sort = filteredSorts[0];\n                }\n                else {\n                    sort = true;\n                }\n            }\n            else {\n                // Simplify domain sort by removing field and op when the field is the same as the domain field.\n                if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(sort) && 'field' in sort) {\n                    const sortField = sort.field;\n                    if (domain.field === sortField) {\n                        sort = sort.order ? { order: sort.order } : true;\n                    }\n                }\n            }\n            return {\n                ...domain,\n                sort\n            };\n        }\n        return domain;\n    }\n    // only keep sort properties that work with unioned domains\n    const unionDomainSorts = _util__WEBPACK_IMPORTED_MODULE_10__.unique(sorts.map(s => {\n        if (_util__WEBPACK_IMPORTED_MODULE_10__.isBoolean(s) || !('op' in s) || ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(s.op) && s.op in _aggregate__WEBPACK_IMPORTED_MODULE_1__.MULTIDOMAIN_SORT_OP_INDEX)) {\n            return s;\n        }\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.domainSortDropped(s));\n        return true;\n    }), _util__WEBPACK_IMPORTED_MODULE_10__.hash);\n    let sort;\n    if (unionDomainSorts.length === 1) {\n        sort = unionDomainSorts[0];\n    }\n    else if (unionDomainSorts.length > 1) {\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.MORE_THAN_ONE_SORT);\n        sort = true;\n    }\n    const allData = _util__WEBPACK_IMPORTED_MODULE_10__.unique(domains.map(d => {\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(d)) {\n            return d.data;\n        }\n        return null;\n    }), x => x);\n    if (allData.length === 1 && allData[0] !== null) {\n        // create a union domain of different fields with a single data source\n        const domain = {\n            data: allData[0],\n            fields: uniqueDomains.map(d => d.field),\n            ...(sort ? { sort } : {})\n        };\n        return domain;\n    }\n    return { fields: uniqueDomains, ...(sort ? { sort } : {}) };\n}\n/**\n * Return a field if a scale uses a single field.\n * Return `undefined` otherwise.\n */\nfunction getFieldFromDomain(domain) {\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(domain) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(domain.field)) {\n        return domain.field;\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefUnionedDomain)(domain)) {\n        let field;\n        for (const nonUnionDomain of domain.fields) {\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(nonUnionDomain) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(nonUnionDomain.field)) {\n                if (!field) {\n                    field = nonUnionDomain.field;\n                }\n                else if (field !== nonUnionDomain.field) {\n                    _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.FACETED_INDEPENDENT_DIFFERENT_SOURCES);\n                    return field;\n                }\n            }\n        }\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.FACETED_INDEPENDENT_SAME_FIELDS_DIFFERENT_SOURCES);\n        return field;\n    }\n    else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isFieldRefUnionDomain)(domain)) {\n        _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.FACETED_INDEPENDENT_SAME_SOURCE);\n        const field = domain.fields[0];\n        return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field) ? field : undefined;\n    }\n    return undefined;\n}\nfunction assembleDomain(model, channel) {\n    const scaleComponent = model.component.scales[channel];\n    const domains = scaleComponent.get('domains').map((domain) => {\n        // Correct references to data as the original domain's data was determined\n        // in parseScale, which happens before parseData. Thus the original data\n        // reference can be incorrect.\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_11__.isDataRefDomain)(domain)) {\n            domain.data = model.lookupDataSource(domain.data);\n        }\n        return domain;\n    });\n    // domains is an array that has to be merged into a single vega domain\n    return mergeDomains(domains);\n}\n//# sourceMappingURL=domain.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/domain.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/parse.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/parse.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseScaleCore: () => (/* binding */ parseScaleCore),\n/* harmony export */   parseScales: () => (/* binding */ parseScales)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _resolve__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../resolve */ \"../../node_modules/vega-lite/build/src/compile/resolve.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _component__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./component */ \"../../node_modules/vega-lite/build/src/compile/scale/component.js\");\n/* harmony import */ var _domain__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./domain */ \"../../node_modules/vega-lite/build/src/compile/scale/domain.js\");\n/* harmony import */ var _properties__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./properties */ \"../../node_modules/vega-lite/build/src/compile/scale/properties.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./type */ \"../../node_modules/vega-lite/build/src/compile/scale/type.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction parseScales(model, { ignoreRange } = {}) {\n    parseScaleCore(model);\n    (0,_domain__WEBPACK_IMPORTED_MODULE_12__.parseScaleDomain)(model);\n    for (const prop of _scale__WEBPACK_IMPORTED_MODULE_5__.NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTIES) {\n        (0,_properties__WEBPACK_IMPORTED_MODULE_13__.parseScaleProperty)(model, prop);\n    }\n    if (!ignoreRange) {\n        // range depends on zero\n        (0,_properties__WEBPACK_IMPORTED_MODULE_13__.parseScaleRange)(model);\n    }\n}\nfunction parseScaleCore(model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_8__.isUnitModel)(model)) {\n        model.component.scales = parseUnitScaleCore(model);\n    }\n    else {\n        model.component.scales = parseNonUnitScaleCore(model);\n    }\n}\n/**\n * Parse scales for all channels of a model.\n */\nfunction parseUnitScaleCore(model) {\n    const { encoding, mark, markDef } = model;\n    const scaleComponents = {};\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_0__.SCALE_CHANNELS) {\n        const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.getFieldOrDatumDef)(encoding[channel]); // must be typed def to have scale\n        // Don't generate scale for shape of geoshape\n        if (fieldOrDatumDef && mark === _mark__WEBPACK_IMPORTED_MODULE_4__.GEOSHAPE && channel === _channel__WEBPACK_IMPORTED_MODULE_0__.SHAPE && fieldOrDatumDef.type === _type__WEBPACK_IMPORTED_MODULE_6__.GEOJSON) {\n            continue;\n        }\n        let specifiedScale = fieldOrDatumDef && fieldOrDatumDef['scale'];\n        if ((0,_channel__WEBPACK_IMPORTED_MODULE_0__.isXorYOffset)(channel)) {\n            const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_0__.getMainChannelFromOffsetChannel)(channel);\n            if (!(0,_encoding__WEBPACK_IMPORTED_MODULE_2__.channelHasNestedOffsetScale)(encoding, mainChannel)) {\n                // Don't generate scale when the offset encoding shouldn't yield a nested scale\n                if (specifiedScale) {\n                    _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.offsetEncodingScaleIgnored(channel));\n                }\n                continue;\n            }\n        }\n        if (fieldOrDatumDef && specifiedScale !== null && specifiedScale !== false) {\n            specifiedScale ?? (specifiedScale = {});\n            const hasNestedOffsetScale = (0,_encoding__WEBPACK_IMPORTED_MODULE_2__.channelHasNestedOffsetScale)(encoding, channel);\n            const sType = (0,_type__WEBPACK_IMPORTED_MODULE_14__.scaleType)(specifiedScale, channel, fieldOrDatumDef, markDef, hasNestedOffsetScale);\n            scaleComponents[channel] = new _component__WEBPACK_IMPORTED_MODULE_11__.ScaleComponent(model.scaleName(`${channel}`, true), {\n                value: sType,\n                explicit: specifiedScale.type === sType\n            });\n        }\n    }\n    return scaleComponents;\n}\nconst scaleTypeTieBreaker = (0,_split__WEBPACK_IMPORTED_MODULE_10__.tieBreakByComparing)((st1, st2) => (0,_scale__WEBPACK_IMPORTED_MODULE_5__.scaleTypePrecedence)(st1) - (0,_scale__WEBPACK_IMPORTED_MODULE_5__.scaleTypePrecedence)(st2));\nfunction parseNonUnitScaleCore(model) {\n    var _a;\n    const scaleComponents = (model.component.scales = {});\n    const scaleTypeWithExplicitIndex = {};\n    const resolve = model.component.resolve;\n    // Parse each child scale and determine if a particular channel can be merged.\n    for (const child of model.children) {\n        parseScaleCore(child);\n        // Instead of always merging right away -- check if it is compatible to merge first!\n        for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(child.component.scales)) {\n            // if resolve is undefined, set default first\n            (_a = resolve.scale)[channel] ?? (_a[channel] = (0,_resolve__WEBPACK_IMPORTED_MODULE_9__.defaultScaleResolve)(channel, model));\n            if (resolve.scale[channel] === 'shared') {\n                const explicitScaleType = scaleTypeWithExplicitIndex[channel];\n                const childScaleType = child.component.scales[channel].getWithExplicit('type');\n                if (explicitScaleType) {\n                    if ((0,_scale__WEBPACK_IMPORTED_MODULE_5__.scaleCompatible)(explicitScaleType.value, childScaleType.value)) {\n                        // merge scale component if type are compatible\n                        scaleTypeWithExplicitIndex[channel] = (0,_split__WEBPACK_IMPORTED_MODULE_10__.mergeValuesWithExplicit)(explicitScaleType, childScaleType, 'type', 'scale', scaleTypeTieBreaker);\n                    }\n                    else {\n                        // Otherwise, update conflicting channel to be independent\n                        resolve.scale[channel] = 'independent';\n                        // Remove from the index so they don't get merged\n                        delete scaleTypeWithExplicitIndex[channel];\n                    }\n                }\n                else {\n                    scaleTypeWithExplicitIndex[channel] = childScaleType;\n                }\n            }\n        }\n    }\n    // Merge each channel listed in the index\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(scaleTypeWithExplicitIndex)) {\n        // Create new merged scale component\n        const name = model.scaleName(channel, true);\n        const typeWithExplicit = scaleTypeWithExplicitIndex[channel];\n        scaleComponents[channel] = new _component__WEBPACK_IMPORTED_MODULE_11__.ScaleComponent(name, typeWithExplicit);\n        // rename each child and mark them as merged\n        for (const child of model.children) {\n            const childScale = child.component.scales[channel];\n            if (childScale) {\n                child.renameScale(childScale.get('name'), name);\n                childScale.merged = true;\n            }\n        }\n    }\n    return scaleComponents;\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/properties.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/properties.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bins: () => (/* binding */ bins),\n/* harmony export */   interpolate: () => (/* binding */ interpolate),\n/* harmony export */   nice: () => (/* binding */ nice),\n/* harmony export */   padding: () => (/* binding */ padding),\n/* harmony export */   paddingInner: () => (/* binding */ paddingInner),\n/* harmony export */   paddingOuter: () => (/* binding */ paddingOuter),\n/* harmony export */   parseNonUnitScaleProperty: () => (/* binding */ parseNonUnitScaleProperty),\n/* harmony export */   parseScaleProperty: () => (/* binding */ parseScaleProperty),\n/* harmony export */   parseScaleRange: () => (/* binding */ parseScaleRange),\n/* harmony export */   reverse: () => (/* binding */ reverse),\n/* harmony export */   scaleRules: () => (/* binding */ scaleRules),\n/* harmony export */   zero: () => (/* binding */ zero)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _data_bin__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../data/bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _signal__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../signal */ \"../../node_modules/vega-lite/build/src/compile/signal.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _range__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./range */ \"../../node_modules/vega-lite/build/src/compile/scale/range.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction parseScaleProperty(model, property) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_11__.isUnitModel)(model)) {\n        parseUnitScaleProperty(model, property);\n    }\n    else {\n        parseNonUnitScaleProperty(model, property);\n    }\n}\nfunction parseUnitScaleProperty(model, property) {\n    const localScaleComponents = model.component.scales;\n    const { config, encoding, markDef, specifiedScales } = model;\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_8__.keys)(localScaleComponents)) {\n        const specifiedScale = specifiedScales[channel];\n        const localScaleCmpt = localScaleComponents[channel];\n        const mergedScaleCmpt = model.getScaleComponent(channel);\n        const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldOrDatumDef)(encoding[channel]);\n        const specifiedValue = specifiedScale[property];\n        const scaleType = mergedScaleCmpt.get('type');\n        const scalePadding = mergedScaleCmpt.get('padding');\n        const scalePaddingInner = mergedScaleCmpt.get('paddingInner');\n        const supportedByScaleType = (0,_scale__WEBPACK_IMPORTED_MODULE_7__.scaleTypeSupportProperty)(scaleType, property);\n        const channelIncompatability = (0,_scale__WEBPACK_IMPORTED_MODULE_7__.channelScalePropertyIncompatability)(channel, property);\n        if (specifiedValue !== undefined) {\n            // If there is a specified value, check if it is compatible with scale type and channel\n            if (!supportedByScaleType) {\n                _log__WEBPACK_IMPORTED_MODULE_6__.warn(_log__WEBPACK_IMPORTED_MODULE_6__.message.scalePropertyNotWorkWithScaleType(scaleType, property, channel));\n            }\n            else if (channelIncompatability) {\n                // channel\n                _log__WEBPACK_IMPORTED_MODULE_6__.warn(channelIncompatability);\n            }\n        }\n        if (supportedByScaleType && channelIncompatability === undefined) {\n            if (specifiedValue !== undefined) {\n                const timeUnit = fieldOrDatumDef['timeUnit'];\n                const type = fieldOrDatumDef.type;\n                switch (property) {\n                    // domainMax/Min to signal if the value is a datetime object\n                    case 'domainMax':\n                    case 'domainMin':\n                        if ((0,_datetime__WEBPACK_IMPORTED_MODULE_4__.isDateTime)(specifiedScale[property]) || type === 'temporal' || timeUnit) {\n                            localScaleCmpt.set(property, { signal: (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.valueExpr)(specifiedScale[property], { type, timeUnit }) }, true);\n                        }\n                        else {\n                            localScaleCmpt.set(property, specifiedScale[property], true);\n                        }\n                        break;\n                    default:\n                        localScaleCmpt.copyKeyFromObject(property, specifiedScale);\n                }\n            }\n            else {\n                const value = property in scaleRules\n                    ? scaleRules[property]({\n                        model,\n                        channel,\n                        fieldOrDatumDef,\n                        scaleType,\n                        scalePadding,\n                        scalePaddingInner,\n                        domain: specifiedScale.domain,\n                        domainMin: specifiedScale.domainMin,\n                        domainMax: specifiedScale.domainMax,\n                        markDef,\n                        config,\n                        hasNestedOffsetScale: (0,_encoding__WEBPACK_IMPORTED_MODULE_5__.channelHasNestedOffsetScale)(encoding, channel),\n                        hasSecondaryRangeChannel: !!encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSecondaryRangeChannel)(channel)]\n                    })\n                    : config.scale[property];\n                if (value !== undefined) {\n                    localScaleCmpt.set(property, value, false);\n                }\n            }\n        }\n    }\n}\nconst scaleRules = {\n    bins: ({ model, fieldOrDatumDef }) => ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) ? bins(model, fieldOrDatumDef) : undefined),\n    interpolate: ({ channel, fieldOrDatumDef }) => interpolate(channel, fieldOrDatumDef.type),\n    nice: ({ scaleType, channel, domain, domainMin, domainMax, fieldOrDatumDef }) => nice(scaleType, channel, domain, domainMin, domainMax, fieldOrDatumDef),\n    padding: ({ channel, scaleType, fieldOrDatumDef, markDef, config }) => padding(channel, scaleType, config.scale, fieldOrDatumDef, markDef, config.bar),\n    paddingInner: ({ scalePadding, channel, markDef, scaleType, config, hasNestedOffsetScale }) => paddingInner(scalePadding, channel, markDef.type, scaleType, config.scale, hasNestedOffsetScale),\n    paddingOuter: ({ scalePadding, channel, scaleType, scalePaddingInner, config, hasNestedOffsetScale }) => paddingOuter(scalePadding, channel, scaleType, scalePaddingInner, config.scale, hasNestedOffsetScale),\n    reverse: ({ fieldOrDatumDef, scaleType, channel, config }) => {\n        const sort = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) ? fieldOrDatumDef.sort : undefined;\n        return reverse(scaleType, sort, channel, config.scale);\n    },\n    zero: ({ channel, fieldOrDatumDef, domain, markDef, scaleType, config, hasSecondaryRangeChannel }) => zero(channel, fieldOrDatumDef, domain, markDef, scaleType, config.scale, hasSecondaryRangeChannel)\n};\n// This method is here rather than in range.ts to avoid circular dependency.\nfunction parseScaleRange(model) {\n    if ((0,_model__WEBPACK_IMPORTED_MODULE_11__.isUnitModel)(model)) {\n        (0,_range__WEBPACK_IMPORTED_MODULE_14__.parseUnitScaleRange)(model);\n    }\n    else {\n        parseNonUnitScaleProperty(model, 'range');\n    }\n}\nfunction parseNonUnitScaleProperty(model, property) {\n    const localScaleComponents = model.component.scales;\n    for (const child of model.children) {\n        if (property === 'range') {\n            parseScaleRange(child);\n        }\n        else {\n            parseScaleProperty(child, property);\n        }\n    }\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_8__.keys)(localScaleComponents)) {\n        let valueWithExplicit;\n        for (const child of model.children) {\n            const childComponent = child.component.scales[channel];\n            if (childComponent) {\n                const childValueWithExplicit = childComponent.getWithExplicit(property);\n                valueWithExplicit = (0,_split__WEBPACK_IMPORTED_MODULE_13__.mergeValuesWithExplicit)(valueWithExplicit, childValueWithExplicit, property, 'scale', (0,_split__WEBPACK_IMPORTED_MODULE_13__.tieBreakByComparing)((v1, v2) => {\n                    switch (property) {\n                        case 'range':\n                            // For step, prefer larger step\n                            if (v1.step && v2.step) {\n                                return v1.step - v2.step;\n                            }\n                            return 0;\n                        // TODO: precedence rule for other properties\n                    }\n                    return 0;\n                }));\n            }\n        }\n        localScaleComponents[channel].setWithExplicit(property, valueWithExplicit);\n    }\n}\nfunction bins(model, fieldDef) {\n    const bin = fieldDef.bin;\n    if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(bin)) {\n        const binSignal = (0,_data_bin__WEBPACK_IMPORTED_MODULE_10__.getBinSignalName)(model, fieldDef.field, bin);\n        return new _signal__WEBPACK_IMPORTED_MODULE_12__.SignalRefWrapper(() => {\n            return model.getSignalName(binSignal);\n        });\n    }\n    else if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(bin) && (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinParams)(bin) && bin.step !== undefined) {\n        // start and stop will be determined from the scale domain\n        return {\n            step: bin.step\n        };\n    }\n    return undefined;\n}\nfunction interpolate(channel, type) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_8__.contains)([_channel__WEBPACK_IMPORTED_MODULE_2__.COLOR, _channel__WEBPACK_IMPORTED_MODULE_2__.FILL, _channel__WEBPACK_IMPORTED_MODULE_2__.STROKE], channel) && type !== 'nominal') {\n        return 'hcl';\n    }\n    return undefined;\n}\nfunction nice(scaleType, channel, specifiedDomain, domainMin, domainMax, fieldOrDatumDef) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldDef)(fieldOrDatumDef)?.bin ||\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(specifiedDomain) ||\n        domainMax != null ||\n        domainMin != null ||\n        _util__WEBPACK_IMPORTED_MODULE_8__.contains([_scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.TIME, _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.UTC], scaleType)) {\n        return undefined;\n    }\n    return (0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel) ? true : undefined;\n}\nfunction padding(channel, scaleType, scaleConfig, fieldOrDatumDef, markDef, barConfig) {\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.isContinuousToContinuous)(scaleType)) {\n            if (scaleConfig.continuousPadding !== undefined) {\n                return scaleConfig.continuousPadding;\n            }\n            const { type, orient } = markDef;\n            if (type === 'bar' && !((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldOrDatumDef) && (fieldOrDatumDef.bin || fieldOrDatumDef.timeUnit))) {\n                if ((orient === 'vertical' && channel === 'x') || (orient === 'horizontal' && channel === 'y')) {\n                    return barConfig.continuousBandSize;\n                }\n            }\n        }\n        if (scaleType === _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.POINT) {\n            return scaleConfig.pointPadding;\n        }\n    }\n    return undefined;\n}\nfunction paddingInner(paddingValue, channel, mark, scaleType, scaleConfig, hasNestedOffsetScale = false) {\n    if (paddingValue !== undefined) {\n        // If user has already manually specified \"padding\", no need to add default paddingInner.\n        return undefined;\n    }\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n        // Padding is only set for X and Y by default.\n        // Basically it doesn't make sense to add padding for color and size.\n        // paddingOuter would only be called if it's a band scale, just return the default for bandScale.\n        const { bandPaddingInner, barBandPaddingInner, rectBandPaddingInner, bandWithNestedOffsetPaddingInner } = scaleConfig;\n        if (hasNestedOffsetScale) {\n            return bandWithNestedOffsetPaddingInner;\n        }\n        return (0,_util__WEBPACK_IMPORTED_MODULE_8__.getFirstDefined)(bandPaddingInner, mark === 'bar' ? barBandPaddingInner : rectBandPaddingInner);\n    }\n    else if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorYOffset)(channel)) {\n        if (scaleType === _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.BAND) {\n            return scaleConfig.offsetBandPaddingInner;\n        }\n    }\n    return undefined;\n}\nfunction paddingOuter(paddingValue, channel, scaleType, paddingInnerValue, scaleConfig, hasNestedOffsetScale = false) {\n    if (paddingValue !== undefined) {\n        // If user has already manually specified \"padding\", no need to add default paddingOuter.\n        return undefined;\n    }\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n        const { bandPaddingOuter, bandWithNestedOffsetPaddingOuter } = scaleConfig;\n        if (hasNestedOffsetScale) {\n            return bandWithNestedOffsetPaddingOuter;\n        }\n        // Padding is only set for X and Y by default.\n        // Basically it doesn't make sense to add padding for color and size.\n        if (scaleType === _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.BAND) {\n            return (0,_util__WEBPACK_IMPORTED_MODULE_8__.getFirstDefined)(bandPaddingOuter, \n            /* By default, paddingOuter is paddingInner / 2. The reason is that\n              size (width/height) = step * (cardinality - paddingInner + 2 * paddingOuter).\n              and we want the width/height to be integer by default.\n              Note that step (by default) and cardinality are integers.) */\n            (0,_vega_schema__WEBPACK_IMPORTED_MODULE_9__.isSignalRef)(paddingInnerValue) ? { signal: `${paddingInnerValue.signal}/2` } : paddingInnerValue / 2);\n        }\n    }\n    else if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorYOffset)(channel)) {\n        if (scaleType === _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.POINT) {\n            return 0.5; // so the point positions align with centers of band scales.\n        }\n        else if (scaleType === _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.BAND) {\n            return scaleConfig.offsetBandPaddingOuter;\n        }\n    }\n    return undefined;\n}\nfunction reverse(scaleType, sort, channel, scaleConfig) {\n    if (channel === 'x' && scaleConfig.xReverse !== undefined) {\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasContinuousDomain)(scaleType) && sort === 'descending') {\n            if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_9__.isSignalRef)(scaleConfig.xReverse)) {\n                return { signal: `!${scaleConfig.xReverse.signal}` };\n            }\n            else {\n                return !scaleConfig.xReverse;\n            }\n        }\n        return scaleConfig.xReverse;\n    }\n    if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasContinuousDomain)(scaleType) && sort === 'descending') {\n        // For continuous domain scales, Vega does not support domain sort.\n        // Thus, we reverse range instead if sort is descending\n        return true;\n    }\n    return undefined;\n}\nfunction zero(channel, fieldDef, specifiedDomain, markDef, scaleType, scaleConfig, hasSecondaryRangeChannel) {\n    // If users explicitly provide a domain, we should not augment zero as that will be unexpected.\n    const hasCustomDomain = !!specifiedDomain && specifiedDomain !== 'unaggregated';\n    if (hasCustomDomain) {\n        if ((0,_scale__WEBPACK_IMPORTED_MODULE_7__.hasContinuousDomain)(scaleType)) {\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(specifiedDomain)) {\n                const first = specifiedDomain[0];\n                const last = specifiedDomain[specifiedDomain.length - 1];\n                if (first <= 0 && last >= 0) {\n                    // if the domain includes zero, make zero remains true\n                    return true;\n                }\n            }\n            return false;\n        }\n    }\n    // If there is no custom domain, return configZero value (=`true` as default) only for the following cases:\n    // 1) using quantitative field with size\n    // While this can be either ratio or interval fields, our assumption is that\n    // ratio are more common. However, if the scaleType is discretizing scale, we want to return\n    // false so that range doesn't start at zero\n    if (channel === 'size' && fieldDef.type === 'quantitative' && !(0,_scale__WEBPACK_IMPORTED_MODULE_7__.isContinuousToDiscrete)(scaleType)) {\n        return true;\n    }\n    // 2) non-binned, quantitative x-scale or y-scale\n    // (For binning, we should not include zero by default because binning are calculated without zero.)\n    // (For area/bar charts with ratio scale chart, we should always include zero.)\n    if (!((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(fieldDef) && fieldDef.bin) &&\n        _util__WEBPACK_IMPORTED_MODULE_8__.contains([..._channel__WEBPACK_IMPORTED_MODULE_2__.POSITION_SCALE_CHANNELS, ..._channel__WEBPACK_IMPORTED_MODULE_2__.POLAR_POSITION_SCALE_CHANNELS], channel)) {\n        const { orient, type } = markDef;\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_8__.contains)(['bar', 'area', 'line', 'trail'], type)) {\n            if ((orient === 'horizontal' && channel === 'y') || (orient === 'vertical' && channel === 'x')) {\n                return false;\n            }\n        }\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_8__.contains)(['bar', 'area'], type) && !hasSecondaryRangeChannel) {\n            return true;\n        }\n        return scaleConfig?.zero;\n    }\n    return false;\n}\n//# sourceMappingURL=properties.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/properties.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/range.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/range.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MAX_SIZE_RANGE_STEP_RATIO: () => (/* binding */ MAX_SIZE_RANGE_STEP_RATIO),\n/* harmony export */   RANGE_PROPERTIES: () => (/* binding */ RANGE_PROPERTIES),\n/* harmony export */   defaultContinuousToDiscreteCount: () => (/* binding */ defaultContinuousToDiscreteCount),\n/* harmony export */   interpolateRange: () => (/* binding */ interpolateRange),\n/* harmony export */   parseRangeForChannel: () => (/* binding */ parseRangeForChannel),\n/* harmony export */   parseUnitScaleRange: () => (/* binding */ parseUnitScaleRange)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _data_bin__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../data/bin */ \"../../node_modules/vega-lite/build/src/compile/data/bin.js\");\n/* harmony import */ var _signal__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../signal */ \"../../node_modules/vega-lite/build/src/compile/signal.js\");\n/* harmony import */ var _split__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../split */ \"../../node_modules/vega-lite/build/src/compile/split.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst RANGE_PROPERTIES = ['range', 'scheme'];\nfunction parseUnitScaleRange(model) {\n    const localScaleComponents = model.component.scales;\n    // use SCALE_CHANNELS instead of scales[channel] to ensure that x, y come first!\n    for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.SCALE_CHANNELS) {\n        const localScaleCmpt = localScaleComponents[channel];\n        if (!localScaleCmpt) {\n            continue;\n        }\n        const rangeWithExplicit = parseRangeForChannel(channel, model);\n        localScaleCmpt.setWithExplicit('range', rangeWithExplicit);\n    }\n}\nfunction getBinStepSignal(model, channel) {\n    const fieldDef = model.fieldDef(channel);\n    if (fieldDef?.bin) {\n        const { bin, field } = fieldDef;\n        const sizeType = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSizeChannel)(channel);\n        const sizeSignal = model.getName(sizeType);\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(bin) && bin.binned && bin.step !== undefined) {\n            return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => {\n                const scaleName = model.scaleName(channel);\n                const binCount = `(domain(\"${scaleName}\")[1] - domain(\"${scaleName}\")[0]) / ${bin.step}`;\n                return `${model.getSignalName(sizeSignal)} / (${binCount})`;\n            });\n        }\n        else if ((0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinning)(bin)) {\n            const binSignal = (0,_data_bin__WEBPACK_IMPORTED_MODULE_14__.getBinSignalName)(model, field, bin);\n            // TODO: extract this to be range step signal\n            return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => {\n                const updatedName = model.getSignalName(binSignal);\n                const binCount = `(${updatedName}.stop - ${updatedName}.start) / ${updatedName}.step`;\n                return `${model.getSignalName(sizeSignal)} / (${binCount})`;\n            });\n        }\n    }\n    return undefined;\n}\n/**\n * Return mixins that includes one of the Vega range types (explicit range, range.step, range.scheme).\n */\nfunction parseRangeForChannel(channel, model) {\n    const specifiedScale = model.specifiedScales[channel];\n    const { size } = model;\n    const mergedScaleCmpt = model.getScaleComponent(channel);\n    const scaleType = mergedScaleCmpt.get('type');\n    // Check if any of the range properties is specified.\n    // If so, check if it is compatible and make sure that we only output one of the properties\n    for (const property of RANGE_PROPERTIES) {\n        if (specifiedScale[property] !== undefined) {\n            const supportedByScaleType = (0,_scale__WEBPACK_IMPORTED_MODULE_8__.scaleTypeSupportProperty)(scaleType, property);\n            const channelIncompatability = (0,_scale__WEBPACK_IMPORTED_MODULE_8__.channelScalePropertyIncompatability)(channel, property);\n            if (!supportedByScaleType) {\n                _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.scalePropertyNotWorkWithScaleType(scaleType, property, channel));\n            }\n            else if (channelIncompatability) {\n                // channel\n                _log__WEBPACK_IMPORTED_MODULE_7__.warn(channelIncompatability);\n            }\n            else {\n                switch (property) {\n                    case 'range': {\n                        const range = specifiedScale.range;\n                        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range)) {\n                            if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n                                return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)(range.map(v => {\n                                    if (v === 'width' || v === 'height') {\n                                        // get signal for width/height\n                                        // Just like default range logic below, we use SignalRefWrapper to account for potential merges and renames.\n                                        const sizeSignal = model.getName(v);\n                                        const getSignalName = model.getSignalName.bind(model);\n                                        return _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper.fromName(getSignalName, sizeSignal);\n                                    }\n                                    return v;\n                                }));\n                            }\n                        }\n                        else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(range)) {\n                            return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)({\n                                data: model.requestDataName(_data__WEBPACK_IMPORTED_MODULE_5__.DataSourceType.Main),\n                                field: range.field,\n                                sort: { op: 'min', field: model.vgField(channel) }\n                            });\n                        }\n                        return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)(range);\n                    }\n                    case 'scheme':\n                        return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)(parseScheme(specifiedScale[property]));\n                }\n            }\n        }\n    }\n    const sizeChannel = channel === _channel__WEBPACK_IMPORTED_MODULE_2__.X || channel === 'xOffset' ? 'width' : 'height';\n    const sizeValue = size[sizeChannel];\n    if ((0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isStep)(sizeValue)) {\n        if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorY)(channel)) {\n            if ((0,_scale__WEBPACK_IMPORTED_MODULE_8__.hasDiscreteDomain)(scaleType)) {\n                const step = getPositionStep(sizeValue, model, channel);\n                // Need to be explicit so layer with step wins over layer without step\n                if (step) {\n                    return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)({ step });\n                }\n            }\n            else {\n                _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.stepDropped(sizeChannel));\n            }\n        }\n        else if ((0,_channel__WEBPACK_IMPORTED_MODULE_2__.isXorYOffset)(channel)) {\n            const positionChannel = channel === _channel__WEBPACK_IMPORTED_MODULE_2__.XOFFSET ? 'x' : 'y';\n            const positionScaleCmpt = model.getScaleComponent(positionChannel);\n            const positionScaleType = positionScaleCmpt.get('type');\n            if (positionScaleType === 'band') {\n                const step = getOffsetStep(sizeValue, scaleType);\n                if (step) {\n                    return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)(step);\n                }\n            }\n        }\n    }\n    const { rangeMin, rangeMax } = specifiedScale;\n    const d = defaultRange(channel, model);\n    if ((rangeMin !== undefined || rangeMax !== undefined) &&\n        // it's ok to check just rangeMin's compatibility since rangeMin/rangeMax are the same\n        (0,_scale__WEBPACK_IMPORTED_MODULE_8__.scaleTypeSupportProperty)(scaleType, 'rangeMin') &&\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(d) &&\n        d.length === 2) {\n        return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeExplicit)([rangeMin ?? d[0], rangeMax ?? d[1]]);\n    }\n    return (0,_split__WEBPACK_IMPORTED_MODULE_16__.makeImplicit)(d);\n}\nfunction parseScheme(scheme) {\n    if ((0,_scale__WEBPACK_IMPORTED_MODULE_8__.isExtendedScheme)(scheme)) {\n        return {\n            scheme: scheme.name,\n            ..._util__WEBPACK_IMPORTED_MODULE_11__.omit(scheme, ['name'])\n        };\n    }\n    return { scheme };\n}\nfunction defaultRange(channel, model) {\n    const { size, config, mark, encoding } = model;\n    const getSignalName = model.getSignalName.bind(model);\n    const { type } = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldOrDatumDef)(encoding[channel]);\n    const mergedScaleCmpt = model.getScaleComponent(channel);\n    const scaleType = mergedScaleCmpt.get('type');\n    const { domain, domainMid } = model.specifiedScales[channel];\n    switch (channel) {\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.X:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.Y: {\n            // If there is no explicit width/height for discrete x/y scales\n            if (_util__WEBPACK_IMPORTED_MODULE_11__.contains(['point', 'band'], scaleType)) {\n                const positionSize = getDiscretePositionSize(channel, size, config.view);\n                if ((0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isStep)(positionSize)) {\n                    const step = getPositionStep(positionSize, model, channel);\n                    return { step };\n                }\n            }\n            // If step is null, use zero to width or height.\n            // Note that we use SignalRefWrapper to account for potential merges and renames.\n            const sizeType = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSizeChannel)(channel);\n            const sizeSignal = model.getName(sizeType);\n            if (channel === _channel__WEBPACK_IMPORTED_MODULE_2__.Y && (0,_scale__WEBPACK_IMPORTED_MODULE_8__.hasContinuousDomain)(scaleType)) {\n                // For y continuous scale, we have to start from the height as the bottom part has the max value.\n                return [_signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper.fromName(getSignalName, sizeSignal), 0];\n            }\n            else {\n                return [0, _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper.fromName(getSignalName, sizeSignal)];\n            }\n        }\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.XOFFSET:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.YOFFSET:\n            return getOffsetRange(channel, model, scaleType);\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.SIZE: {\n            // TODO: support custom rangeMin, rangeMax\n            const zero = model.component.scales[channel].get('zero');\n            const rangeMin = sizeRangeMin(mark, zero, config);\n            const rangeMax = sizeRangeMax(mark, size, model, config);\n            if ((0,_scale__WEBPACK_IMPORTED_MODULE_8__.isContinuousToDiscrete)(scaleType)) {\n                return interpolateRange(rangeMin, rangeMax, defaultContinuousToDiscreteCount(scaleType, config, domain, channel));\n            }\n            else {\n                return [rangeMin, rangeMax];\n            }\n        }\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.THETA:\n            return [0, Math.PI * 2];\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.ANGLE:\n            // TODO: add config.scale.min/maxAngleDegree (for point and text) and config.scale.min/maxAngleRadian (for arc) once we add arc marks.\n            // (It's weird to add just config.scale.min/maxAngleDegree for now)\n            return [0, 360];\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.RADIUS: {\n            // max radius = half od min(width,height)\n            return [\n                0,\n                new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => {\n                    const w = model.getSignalName('width');\n                    const h = model.getSignalName('height');\n                    return `min(${w},${h})/2`;\n                })\n            ];\n        }\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEWIDTH:\n            // TODO: support custom rangeMin, rangeMax\n            return [config.scale.minStrokeWidth, config.scale.maxStrokeWidth];\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEDASH:\n            return [\n                // TODO: add this to Vega's config.range?\n                [1, 0],\n                [4, 2],\n                [2, 1],\n                [1, 1],\n                [1, 2, 4, 2]\n            ];\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.SHAPE:\n            return 'symbol';\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.COLOR:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.FILL:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKE:\n            if (scaleType === 'ordinal') {\n                // Only nominal data uses ordinal scale by default\n                return type === 'nominal' ? 'category' : 'ordinal';\n            }\n            else {\n                if (domainMid !== undefined) {\n                    return 'diverging';\n                }\n                else {\n                    return mark === 'rect' || mark === 'geoshape' ? 'heatmap' : 'ramp';\n                }\n            }\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.OPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.FILLOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEOPACITY:\n            // TODO: support custom rangeMin, rangeMax\n            return [config.scale.minOpacity, config.scale.maxOpacity];\n    }\n}\nfunction getPositionStep(step, model, channel) {\n    const { encoding } = model;\n    const mergedScaleCmpt = model.getScaleComponent(channel);\n    const offsetChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getOffsetScaleChannel)(channel);\n    const offsetDef = encoding[offsetChannel];\n    const stepFor = (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.getStepFor)({ step, offsetIsDiscrete: (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(offsetDef) && (0,_type__WEBPACK_IMPORTED_MODULE_10__.isDiscrete)(offsetDef.type) });\n    if (stepFor === 'offset' && (0,_encoding__WEBPACK_IMPORTED_MODULE_6__.channelHasFieldOrDatum)(encoding, offsetChannel)) {\n        const offsetScaleCmpt = model.getScaleComponent(offsetChannel);\n        const offsetScaleName = model.scaleName(offsetChannel);\n        let stepCount = `domain('${offsetScaleName}').length`;\n        if (offsetScaleCmpt.get('type') === 'band') {\n            const offsetPaddingInner = offsetScaleCmpt.get('paddingInner') ?? offsetScaleCmpt.get('padding') ?? 0;\n            const offsetPaddingOuter = offsetScaleCmpt.get('paddingOuter') ?? offsetScaleCmpt.get('padding') ?? 0;\n            stepCount = `bandspace(${stepCount}, ${offsetPaddingInner}, ${offsetPaddingOuter})`;\n        }\n        const paddingInner = mergedScaleCmpt.get('paddingInner') ?? mergedScaleCmpt.get('padding');\n        return {\n            signal: `${step.step} * ${stepCount} / (1-${(0,_common__WEBPACK_IMPORTED_MODULE_13__.exprFromSignalRefOrValue)(paddingInner)})`\n        };\n    }\n    else {\n        return step.step;\n    }\n}\nfunction getOffsetStep(step, offsetScaleType) {\n    const stepFor = (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.getStepFor)({ step, offsetIsDiscrete: (0,_scale__WEBPACK_IMPORTED_MODULE_8__.hasDiscreteDomain)(offsetScaleType) });\n    if (stepFor === 'offset') {\n        return { step: step.step };\n    }\n    return undefined;\n}\nfunction getOffsetRange(channel, model, offsetScaleType) {\n    const positionChannel = channel === _channel__WEBPACK_IMPORTED_MODULE_2__.XOFFSET ? 'x' : 'y';\n    const positionScaleCmpt = model.getScaleComponent(positionChannel);\n    const positionScaleType = positionScaleCmpt.get('type');\n    const positionScaleName = model.scaleName(positionChannel);\n    if (positionScaleType === 'band') {\n        const size = getDiscretePositionSize(positionChannel, model.size, model.config.view);\n        if ((0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isStep)(size)) {\n            // step is for offset\n            const step = getOffsetStep(size, offsetScaleType);\n            if (step) {\n                return step;\n            }\n        }\n        // otherwise use the position\n        return [0, { signal: `bandwidth('${positionScaleName}')` }];\n    }\n    else {\n        // continuous scale\n        const positionDef = model.encoding[positionChannel];\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(positionDef) && positionDef.timeUnit) {\n            const duration = (0,_timeunit__WEBPACK_IMPORTED_MODULE_17__.durationExpr)(positionDef.timeUnit, expr => `scale('${positionScaleName}', ${expr})`);\n            const padding = model.config.scale.bandWithNestedOffsetPaddingInner;\n            if (padding) {\n                const startRatio = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_12__.isSignalRef)(padding) ? `${padding.signal}/2` : `${padding / 2}`;\n                const endRatio = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_12__.isSignalRef)(padding) ? `(1 - ${padding.signal}/2)` : `${1 - padding / 2}`;\n                return [{ signal: `${startRatio} * (${duration})` }, { signal: `${endRatio} * (${duration})` }];\n            }\n            return [0, { signal: duration }];\n        }\n        return _util__WEBPACK_IMPORTED_MODULE_11__.never(`Cannot use ${channel} scale if ${positionChannel} scale is not discrete.`);\n    }\n}\nfunction getDiscretePositionSize(channel, size, viewConfig) {\n    const sizeChannel = channel === _channel__WEBPACK_IMPORTED_MODULE_2__.X ? 'width' : 'height';\n    const sizeValue = size[sizeChannel];\n    if (sizeValue) {\n        return sizeValue;\n    }\n    return (0,_config__WEBPACK_IMPORTED_MODULE_4__.getViewConfigDiscreteSize)(viewConfig, sizeChannel);\n}\nfunction defaultContinuousToDiscreteCount(scaleType, config, domain, channel) {\n    switch (scaleType) {\n        case 'quantile':\n            return config.scale.quantileCount;\n        case 'quantize':\n            return config.scale.quantizeCount;\n        case 'threshold':\n            if (domain !== undefined && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain)) {\n                return domain.length + 1;\n            }\n            else {\n                _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.domainRequiredForThresholdScale(channel));\n                // default threshold boundaries for threshold scale since domain has cardinality of 2\n                return 3;\n            }\n    }\n}\n/**\n * Returns the linear interpolation of the range according to the cardinality\n *\n * @param rangeMin start of the range\n * @param rangeMax end of the range\n * @param cardinality number of values in the output range\n */\nfunction interpolateRange(rangeMin, rangeMax, cardinality) {\n    // always return a signal since it's better to compute the sequence in Vega later\n    const f = () => {\n        const rMax = (0,_common__WEBPACK_IMPORTED_MODULE_13__.signalOrStringValue)(rangeMax);\n        const rMin = (0,_common__WEBPACK_IMPORTED_MODULE_13__.signalOrStringValue)(rangeMin);\n        const step = `(${rMax} - ${rMin}) / (${cardinality} - 1)`;\n        return `sequence(${rMin}, ${rMax} + ${step}, ${step})`;\n    };\n    if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_12__.isSignalRef)(rangeMax)) {\n        return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(f);\n    }\n    else {\n        return { signal: f() };\n    }\n}\nfunction sizeRangeMin(mark, zero, config) {\n    if (zero) {\n        if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_12__.isSignalRef)(zero)) {\n            return { signal: `${zero.signal} ? 0 : ${sizeRangeMin(mark, false, config)}` };\n        }\n        else {\n            return 0;\n        }\n    }\n    switch (mark) {\n        case 'bar':\n        case 'tick':\n            return config.scale.minBandSize;\n        case 'line':\n        case 'trail':\n        case 'rule':\n            return config.scale.minStrokeWidth;\n        case 'text':\n            return config.scale.minFontSize;\n        case 'point':\n        case 'square':\n        case 'circle':\n            return config.scale.minSize;\n    }\n    /* istanbul ignore next: should never reach here */\n    // sizeRangeMin not implemented for the mark\n    throw new Error(_log__WEBPACK_IMPORTED_MODULE_7__.message.incompatibleChannel('size', mark));\n}\nconst MAX_SIZE_RANGE_STEP_RATIO = 0.95;\nfunction sizeRangeMax(mark, size, model, config) {\n    const xyStepSignals = {\n        x: getBinStepSignal(model, 'x'),\n        y: getBinStepSignal(model, 'y')\n    };\n    switch (mark) {\n        case 'bar':\n        case 'tick': {\n            if (config.scale.maxBandSize !== undefined) {\n                return config.scale.maxBandSize;\n            }\n            const min = minXYStep(size, xyStepSignals, config.view);\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(min)) {\n                return min - 1;\n            }\n            else {\n                return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => `${min.signal} - 1`);\n            }\n        }\n        case 'line':\n        case 'trail':\n        case 'rule':\n            return config.scale.maxStrokeWidth;\n        case 'text':\n            return config.scale.maxFontSize;\n        case 'point':\n        case 'square':\n        case 'circle': {\n            if (config.scale.maxSize) {\n                return config.scale.maxSize;\n            }\n            const pointStep = minXYStep(size, xyStepSignals, config.view);\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(pointStep)) {\n                return Math.pow(MAX_SIZE_RANGE_STEP_RATIO * pointStep, 2);\n            }\n            else {\n                return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => `pow(${MAX_SIZE_RANGE_STEP_RATIO} * ${pointStep.signal}, 2)`);\n            }\n        }\n    }\n    /* istanbul ignore next: should never reach here */\n    // sizeRangeMax not implemented for the mark\n    throw new Error(_log__WEBPACK_IMPORTED_MODULE_7__.message.incompatibleChannel('size', mark));\n}\n/**\n * @returns {number} Range step of x or y or minimum between the two if both are ordinal scale.\n */\nfunction minXYStep(size, xyStepSignals, viewConfig) {\n    const widthStep = (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isStep)(size.width) ? size.width.step : (0,_config__WEBPACK_IMPORTED_MODULE_4__.getViewConfigDiscreteStep)(viewConfig, 'width');\n    const heightStep = (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isStep)(size.height) ? size.height.step : (0,_config__WEBPACK_IMPORTED_MODULE_4__.getViewConfigDiscreteStep)(viewConfig, 'height');\n    if (xyStepSignals.x || xyStepSignals.y) {\n        return new _signal__WEBPACK_IMPORTED_MODULE_15__.SignalRefWrapper(() => {\n            const exprs = [\n                xyStepSignals.x ? xyStepSignals.x.signal : widthStep,\n                xyStepSignals.y ? xyStepSignals.y.signal : heightStep\n            ];\n            return `min(${exprs.join(', ')})`;\n        });\n    }\n    return Math.min(widthStep, heightStep);\n}\n//# sourceMappingURL=range.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/range.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/scale/type.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/scale/type.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   scaleType: () => (/* binding */ scaleType)\n/* harmony export */ });\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\n\n\n/**\n * Determine if there is a specified scale type and if it is appropriate,\n * or determine default type if type is unspecified or inappropriate.\n */\n// NOTE: CompassQL uses this method.\nfunction scaleType(specifiedScale, channel, fieldDef, mark, hasNestedOffsetScale = false) {\n    const defaultScaleType = defaultType(channel, fieldDef, mark, hasNestedOffsetScale);\n    const { type } = specifiedScale;\n    if (!(0,_channel__WEBPACK_IMPORTED_MODULE_1__.isScaleChannel)(channel)) {\n        // There is no scale for these channels\n        return null;\n    }\n    if (type !== undefined) {\n        // Check if explicitly specified scale type is supported by the channel\n        if (!(0,_scale__WEBPACK_IMPORTED_MODULE_5__.channelSupportScaleType)(channel, type)) {\n            _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.scaleTypeNotWorkWithChannel(channel, type, defaultScaleType));\n            return defaultScaleType;\n        }\n        // Check if explicitly specified scale type is supported by the data type\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldDef) && !(0,_scale__WEBPACK_IMPORTED_MODULE_5__.scaleTypeSupportDataType)(type, fieldDef.type)) {\n            _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.scaleTypeNotWorkWithFieldDef(type, defaultScaleType));\n            return defaultScaleType;\n        }\n        return type;\n    }\n    return defaultScaleType;\n}\n/**\n * Determine appropriate default scale type.\n */\n// NOTE: Voyager uses this method.\nfunction defaultType(channel, fieldDef, mark, hasNestedOffsetScale) {\n    switch (fieldDef.type) {\n        case 'nominal':\n        case 'ordinal': {\n            if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isColorChannel)(channel) || (0,_channel__WEBPACK_IMPORTED_MODULE_1__.rangeType)(channel) === 'discrete') {\n                if (channel === 'shape' && fieldDef.type === 'ordinal') {\n                    _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.discreteChannelCannotEncode(channel, 'ordinal'));\n                }\n                return 'ordinal';\n            }\n            if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isXorY)(channel) || (0,_channel__WEBPACK_IMPORTED_MODULE_1__.isXorYOffset)(channel)) {\n                if (_util__WEBPACK_IMPORTED_MODULE_7__.contains(['rect', 'bar', 'image', 'rule'], mark.type)) {\n                    // The rect/bar mark should fit into a band.\n                    // For rule, using band scale to make rule align with axis ticks better https://github.com/vega/vega-lite/issues/3429\n                    return 'band';\n                }\n                if (hasNestedOffsetScale) {\n                    // If there is a nested offset scale, then there is a \"band\" for the span of the nested scale.\n                    return 'band';\n                }\n            }\n            else if (mark.type === 'arc' && channel in _channel__WEBPACK_IMPORTED_MODULE_1__.POLAR_POSITION_SCALE_CHANNEL_INDEX) {\n                return 'band';\n            }\n            const dimensionSize = mark[(0,_channel__WEBPACK_IMPORTED_MODULE_1__.getSizeChannel)(channel)];\n            if ((0,_mark__WEBPACK_IMPORTED_MODULE_4__.isRelativeBandSize)(dimensionSize)) {\n                return 'band';\n            }\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isPositionFieldOrDatumDef)(fieldDef) && fieldDef.axis?.tickBand) {\n                return 'band';\n            }\n            // Otherwise, use ordinal point scale so we can easily get center positions of the marks.\n            return 'point';\n        }\n        case 'temporal':\n            if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isColorChannel)(channel)) {\n                return 'time';\n            }\n            else if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.rangeType)(channel) === 'discrete') {\n                _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.discreteChannelCannotEncode(channel, 'temporal'));\n                // TODO: consider using quantize (equivalent to binning) once we have it\n                return 'ordinal';\n            }\n            else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldDef) && fieldDef.timeUnit && (0,_timeunit__WEBPACK_IMPORTED_MODULE_6__.normalizeTimeUnit)(fieldDef.timeUnit).utc) {\n                return 'utc';\n            }\n            return 'time';\n        case 'quantitative':\n            if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isColorChannel)(channel)) {\n                if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(fieldDef) && (0,_bin__WEBPACK_IMPORTED_MODULE_0__.isBinning)(fieldDef.bin)) {\n                    return 'bin-ordinal';\n                }\n                return 'linear';\n            }\n            else if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.rangeType)(channel) === 'discrete') {\n                _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.discreteChannelCannotEncode(channel, 'quantitative'));\n                // TODO: consider using quantize (equivalent to binning) once we have it\n                return 'ordinal';\n            }\n            return 'linear';\n        case 'geojson':\n            return undefined;\n    }\n    /* istanbul ignore next: should never reach this */\n    throw new Error(_log__WEBPACK_IMPORTED_MODULE_3__.message.invalidFieldType(fieldDef.type));\n}\n//# sourceMappingURL=type.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/scale/type.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/assemble.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/assemble.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleFacetSignals: () => (/* binding */ assembleFacetSignals),\n/* harmony export */   assembleInit: () => (/* binding */ assembleInit),\n/* harmony export */   assembleLayerSelectionMarks: () => (/* binding */ assembleLayerSelectionMarks),\n/* harmony export */   assembleProjection: () => (/* binding */ assembleProjection),\n/* harmony export */   assembleSelectionScaleDomain: () => (/* binding */ assembleSelectionScaleDomain),\n/* harmony export */   assembleTopLevelSignals: () => (/* binding */ assembleTopLevelSignals),\n/* harmony export */   assembleUnitSelectionData: () => (/* binding */ assembleUnitSelectionData),\n/* harmony export */   assembleUnitSelectionMarks: () => (/* binding */ assembleUnitSelectionMarks),\n/* harmony export */   assembleUnitSelectionSignals: () => (/* binding */ assembleUnitSelectionSignals)\n/* harmony export */ });\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _parse__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n\n\n\n\n\n\n\n\n\nfunction assembleProjection(proj) {\n    const { signals, hasLegend, index, ...rest } = proj;\n    rest.field = (0,_util__WEBPACK_IMPORTED_MODULE_6__.replacePathInField)(rest.field);\n    return rest;\n}\nfunction assembleInit(init, isExpr = true, wrap = vega_util__WEBPACK_IMPORTED_MODULE_1__.identity) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isArray)(init)) {\n        const assembled = init.map(v => assembleInit(v, isExpr, wrap));\n        return isExpr ? `[${assembled.join(', ')}]` : assembled;\n    }\n    else if ((0,_datetime__WEBPACK_IMPORTED_MODULE_3__.isDateTime)(init)) {\n        if (isExpr) {\n            return wrap((0,_datetime__WEBPACK_IMPORTED_MODULE_3__.dateTimeToExpr)(init));\n        }\n        else {\n            return wrap((0,_datetime__WEBPACK_IMPORTED_MODULE_3__.dateTimeToTimestamp)(init));\n        }\n    }\n    return isExpr ? wrap((0,_util__WEBPACK_IMPORTED_MODULE_6__.stringify)(init)) : init;\n}\nfunction assembleUnitSelectionSignals(model, signals) {\n    for (const selCmpt of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(model.component.selection ?? {})) {\n        const name = selCmpt.name;\n        let modifyExpr = `${name}${___WEBPACK_IMPORTED_MODULE_2__.TUPLE}, ${selCmpt.resolve === 'global' ? 'true' : `{unit: ${(0,___WEBPACK_IMPORTED_MODULE_2__.unitName)(model)}}`}`;\n        for (const c of ___WEBPACK_IMPORTED_MODULE_2__.selectionCompilers) {\n            if (!c.defined(selCmpt))\n                continue;\n            if (c.signals)\n                signals = c.signals(model, selCmpt, signals);\n            if (c.modifyExpr)\n                modifyExpr = c.modifyExpr(model, selCmpt, modifyExpr);\n        }\n        signals.push({\n            name: name + ___WEBPACK_IMPORTED_MODULE_2__.MODIFY,\n            on: [\n                {\n                    events: { signal: selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.TUPLE },\n                    update: `modify(${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.STORE)}, ${modifyExpr})`\n                }\n            ]\n        });\n    }\n    return cleanupEmptyOnArray(signals);\n}\nfunction assembleFacetSignals(model, signals) {\n    if (model.component.selection && (0,_util__WEBPACK_IMPORTED_MODULE_6__.keys)(model.component.selection).length) {\n        const name = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.getName('cell'));\n        signals.unshift({\n            name: 'facet',\n            value: {},\n            on: [\n                {\n                    events: (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_0__.parseSelector)('mousemove', 'scope'),\n                    update: `isTuple(facet) ? facet : group(${name}).datum`\n                }\n            ]\n        });\n    }\n    return cleanupEmptyOnArray(signals);\n}\nfunction assembleTopLevelSignals(model, signals) {\n    let hasSelections = false;\n    for (const selCmpt of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(model.component.selection ?? {})) {\n        const name = selCmpt.name;\n        const store = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(name + ___WEBPACK_IMPORTED_MODULE_2__.STORE);\n        const hasSg = signals.filter(s => s.name === name);\n        if (hasSg.length === 0) {\n            const resolve = selCmpt.resolve === 'global' ? 'union' : selCmpt.resolve;\n            const isPoint = selCmpt.type === 'point' ? ', true, true)' : ')';\n            signals.push({\n                name: selCmpt.name,\n                update: `${___WEBPACK_IMPORTED_MODULE_2__.VL_SELECTION_RESOLVE}(${store}, ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(resolve)}${isPoint}`\n            });\n        }\n        hasSelections = true;\n        for (const c of ___WEBPACK_IMPORTED_MODULE_2__.selectionCompilers) {\n            if (c.defined(selCmpt) && c.topLevelSignals) {\n                signals = c.topLevelSignals(model, selCmpt, signals);\n            }\n        }\n    }\n    if (hasSelections) {\n        const hasUnit = signals.filter(s => s.name === 'unit');\n        if (hasUnit.length === 0) {\n            signals.unshift({\n                name: 'unit',\n                value: {},\n                on: [{ events: 'mousemove', update: 'isTuple(group()) ? group() : unit' }]\n            });\n        }\n    }\n    return cleanupEmptyOnArray(signals);\n}\nfunction assembleUnitSelectionData(model, data) {\n    const dataCopy = [...data];\n    const unit = (0,___WEBPACK_IMPORTED_MODULE_2__.unitName)(model, { escape: false });\n    for (const selCmpt of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(model.component.selection ?? {})) {\n        const store = { name: selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.STORE };\n        if (selCmpt.project.hasSelectionId) {\n            store.transform = [{ type: 'collect', sort: { field: _selection__WEBPACK_IMPORTED_MODULE_5__.SELECTION_ID } }];\n        }\n        if (selCmpt.init) {\n            const fields = selCmpt.project.items.map(assembleProjection);\n            store.values = selCmpt.project.hasSelectionId\n                ? selCmpt.init.map(i => ({ unit, [_selection__WEBPACK_IMPORTED_MODULE_5__.SELECTION_ID]: assembleInit(i, false)[0] }))\n                : selCmpt.init.map(i => ({ unit, fields, values: assembleInit(i, false) }));\n        }\n        const contains = dataCopy.filter(d => d.name === selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.STORE);\n        if (!contains.length) {\n            dataCopy.push(store);\n        }\n    }\n    return dataCopy;\n}\nfunction assembleUnitSelectionMarks(model, marks) {\n    for (const selCmpt of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(model.component.selection ?? {})) {\n        for (const c of ___WEBPACK_IMPORTED_MODULE_2__.selectionCompilers) {\n            if (c.defined(selCmpt) && c.marks) {\n                marks = c.marks(model, selCmpt, marks);\n            }\n        }\n    }\n    return marks;\n}\nfunction assembleLayerSelectionMarks(model, marks) {\n    for (const child of model.children) {\n        if ((0,_model__WEBPACK_IMPORTED_MODULE_7__.isUnitModel)(child)) {\n            marks = assembleUnitSelectionMarks(child, marks);\n        }\n    }\n    return marks;\n}\nfunction assembleSelectionScaleDomain(model, extent, scaleCmpt, domain) {\n    const parsedExtent = (0,_parse__WEBPACK_IMPORTED_MODULE_8__.parseSelectionExtent)(model, extent.param, extent);\n    return {\n        signal: (0,_scale__WEBPACK_IMPORTED_MODULE_4__.hasContinuousDomain)(scaleCmpt.get('type')) && (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isArray)(domain) && domain[0] > domain[1]\n            ? `isValid(${parsedExtent}) && reverse(${parsedExtent})`\n            : parsedExtent\n    };\n}\nfunction cleanupEmptyOnArray(signals) {\n    return signals.map(s => {\n        if (s.on && !s.on.length)\n            delete s.on;\n        return s;\n    });\n}\n//# sourceMappingURL=assemble.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/assemble.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/clear.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/clear.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _inputs__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./inputs */ \"../../node_modules/vega-lite/build/src/compile/selection/inputs.js\");\n/* harmony import */ var _toggle__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./toggle */ \"../../node_modules/vega-lite/build/src/compile/selection/toggle.js\");\n\n\n\n\n\n\nconst clear = {\n    defined: selCmpt => {\n        return selCmpt.clear !== undefined && selCmpt.clear !== false;\n    },\n    parse: (model, selCmpt) => {\n        if (selCmpt.clear) {\n            selCmpt.clear = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(selCmpt.clear) ? (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_0__.parseSelector)(selCmpt.clear, 'view') : selCmpt.clear;\n        }\n    },\n    topLevelSignals: (model, selCmpt, signals) => {\n        if (_inputs__WEBPACK_IMPORTED_MODULE_4__[\"default\"].defined(selCmpt)) {\n            for (const proj of selCmpt.project.items) {\n                const idx = signals.findIndex(n => n.name === (0,_util__WEBPACK_IMPORTED_MODULE_3__.varName)(`${selCmpt.name}_${proj.field}`));\n                if (idx !== -1) {\n                    signals[idx].on.push({ events: selCmpt.clear, update: 'null' });\n                }\n            }\n        }\n        return signals;\n    },\n    signals: (model, selCmpt, signals) => {\n        function addClear(idx, update) {\n            if (idx !== -1 && signals[idx].on) {\n                signals[idx].on.push({ events: selCmpt.clear, update });\n            }\n        }\n        // Be as minimalist as possible when adding clear triggers to minimize dataflow execution.\n        if (selCmpt.type === 'interval') {\n            for (const proj of selCmpt.project.items) {\n                const vIdx = signals.findIndex(n => n.name === proj.signals.visual);\n                addClear(vIdx, '[0, 0]');\n                if (vIdx === -1) {\n                    const dIdx = signals.findIndex(n => n.name === proj.signals.data);\n                    addClear(dIdx, 'null');\n                }\n            }\n        }\n        else {\n            let tIdx = signals.findIndex(n => n.name === selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.TUPLE);\n            addClear(tIdx, 'null');\n            if (_toggle__WEBPACK_IMPORTED_MODULE_5__[\"default\"].defined(selCmpt)) {\n                tIdx = signals.findIndex(n => n.name === selCmpt.name + _toggle__WEBPACK_IMPORTED_MODULE_5__.TOGGLE);\n                addClear(tIdx, 'false');\n            }\n        }\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (clear);\n//# sourceMappingURL=clear.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/clear.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/index.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/index.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MODIFY: () => (/* binding */ MODIFY),\n/* harmony export */   SELECTION_DOMAIN: () => (/* binding */ SELECTION_DOMAIN),\n/* harmony export */   STORE: () => (/* binding */ STORE),\n/* harmony export */   TUPLE: () => (/* binding */ TUPLE),\n/* harmony export */   VL_SELECTION_RESOLVE: () => (/* binding */ VL_SELECTION_RESOLVE),\n/* harmony export */   disableDirectManipulation: () => (/* binding */ disableDirectManipulation),\n/* harmony export */   requiresSelectionId: () => (/* binding */ requiresSelectionId),\n/* harmony export */   selectionCompilers: () => (/* binding */ selectionCompilers),\n/* harmony export */   unitName: () => (/* binding */ unitName)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./interval */ \"../../node_modules/vega-lite/build/src/compile/selection/interval.js\");\n/* harmony import */ var _point__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./point */ \"../../node_modules/vega-lite/build/src/compile/selection/point.js\");\n/* harmony import */ var _clear__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./clear */ \"../../node_modules/vega-lite/build/src/compile/selection/clear.js\");\n/* harmony import */ var _inputs__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./inputs */ \"../../node_modules/vega-lite/build/src/compile/selection/inputs.js\");\n/* harmony import */ var _nearest__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./nearest */ \"../../node_modules/vega-lite/build/src/compile/selection/nearest.js\");\n/* harmony import */ var _project__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./project */ \"../../node_modules/vega-lite/build/src/compile/selection/project.js\");\n/* harmony import */ var _scales__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./scales */ \"../../node_modules/vega-lite/build/src/compile/selection/scales.js\");\n/* harmony import */ var _legends__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./legends */ \"../../node_modules/vega-lite/build/src/compile/selection/legends.js\");\n/* harmony import */ var _toggle__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./toggle */ \"../../node_modules/vega-lite/build/src/compile/selection/toggle.js\");\n/* harmony import */ var _translate__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./translate */ \"../../node_modules/vega-lite/build/src/compile/selection/translate.js\");\n/* harmony import */ var _zoom__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./zoom */ \"../../node_modules/vega-lite/build/src/compile/selection/zoom.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst STORE = '_store';\nconst TUPLE = '_tuple';\nconst MODIFY = '_modify';\nconst SELECTION_DOMAIN = '_selection_domain_';\nconst VL_SELECTION_RESOLVE = 'vlSelectionResolve';\n// Order matters for parsing and assembly.\nconst selectionCompilers = [\n    _point__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n    _interval__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n    _project__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n    _toggle__WEBPACK_IMPORTED_MODULE_13__[\"default\"],\n    // Bindings may disable direct manipulation.\n    _inputs__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n    _scales__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n    _legends__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n    _clear__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n    _translate__WEBPACK_IMPORTED_MODULE_14__[\"default\"],\n    _zoom__WEBPACK_IMPORTED_MODULE_15__[\"default\"],\n    _nearest__WEBPACK_IMPORTED_MODULE_9__[\"default\"]\n];\nfunction getFacetModel(model) {\n    let parent = model.parent;\n    while (parent) {\n        if ((0,_model__WEBPACK_IMPORTED_MODULE_4__.isFacetModel)(parent))\n            break;\n        parent = parent.parent;\n    }\n    return parent;\n}\nfunction unitName(model, { escape } = { escape: true }) {\n    let name = escape ? (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.name) : model.name;\n    const facetModel = getFacetModel(model);\n    if (facetModel) {\n        const { facet } = facetModel;\n        for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.FACET_CHANNELS) {\n            if (facet[channel]) {\n                name += ` + '__facet_${channel}_' + (facet[${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(facetModel.vgField(channel))}])`;\n            }\n        }\n    }\n    return name;\n}\nfunction requiresSelectionId(model) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_3__.vals)(model.component.selection ?? {}).reduce((identifier, selCmpt) => {\n        return identifier || selCmpt.project.hasSelectionId;\n    }, false);\n}\n// Binding a point selection to query widgets or legends disables default direct manipulation interaction.\n// A user can choose to re-enable it by explicitly specifying triggering input events.\nfunction disableDirectManipulation(selCmpt, selDef) {\n    if ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isString)(selDef.select) || !selDef.select.on)\n        delete selCmpt.events;\n    if ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isString)(selDef.select) || !selDef.select.clear)\n        delete selCmpt.clear;\n    if ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isString)(selDef.select) || !selDef.select.toggle)\n        delete selCmpt.toggle;\n}\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/inputs.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/inputs.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _assemble__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _nearest__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./nearest */ \"../../node_modules/vega-lite/build/src/compile/selection/nearest.js\");\n/* harmony import */ var _project__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./project */ \"../../node_modules/vega-lite/build/src/compile/selection/project.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n\n\n\n\n\n\n\nconst inputBindings = {\n    defined: selCmpt => {\n        return (selCmpt.type === 'point' &&\n            selCmpt.resolve === 'global' &&\n            selCmpt.bind &&\n            selCmpt.bind !== 'scales' &&\n            !(0,_selection__WEBPACK_IMPORTED_MODULE_6__.isLegendBinding)(selCmpt.bind));\n    },\n    parse: (model, selCmpt, selDef) => (0,___WEBPACK_IMPORTED_MODULE_1__.disableDirectManipulation)(selCmpt, selDef),\n    topLevelSignals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const proj = selCmpt.project;\n        const bind = selCmpt.bind;\n        const init = selCmpt.init && selCmpt.init[0]; // Can only exist on single selections (one initial value).\n        const datum = _nearest__WEBPACK_IMPORTED_MODULE_4__[\"default\"].defined(selCmpt) ? '(item().isVoronoi ? datum.datum : datum)' : 'datum';\n        proj.items.forEach((p, i) => {\n            const sgname = (0,_util__WEBPACK_IMPORTED_MODULE_2__.varName)(`${name}_${p.field}`);\n            const hasSignal = signals.filter(s => s.name === sgname);\n            if (!hasSignal.length) {\n                signals.unshift({\n                    name: sgname,\n                    ...(init ? { init: (0,_assemble__WEBPACK_IMPORTED_MODULE_3__.assembleInit)(init[i]) } : { value: null }),\n                    on: selCmpt.events\n                        ? [\n                            {\n                                events: selCmpt.events,\n                                update: `datum && item().mark.marktype !== 'group' ? ${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(p.field)}] : null`\n                            }\n                        ]\n                        : [],\n                    bind: bind[p.field] ?? bind[p.channel] ?? bind\n                });\n            }\n        });\n        return signals;\n    },\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const proj = selCmpt.project;\n        const signal = signals.filter(s => s.name === name + ___WEBPACK_IMPORTED_MODULE_1__.TUPLE)[0];\n        const fields = name + _project__WEBPACK_IMPORTED_MODULE_5__.TUPLE_FIELDS;\n        const values = proj.items.map(p => (0,_util__WEBPACK_IMPORTED_MODULE_2__.varName)(`${name}_${p.field}`));\n        const valid = values.map(v => `${v} !== null`).join(' && ');\n        if (values.length) {\n            signal.update = `${valid} ? {fields: ${fields}, values: [${values.join(', ')}]} : null`;\n        }\n        delete signal.value;\n        delete signal.on;\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (inputBindings);\n//# sourceMappingURL=inputs.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/inputs.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/interval.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/interval.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BRUSH: () => (/* binding */ BRUSH),\n/* harmony export */   GEO_INIT_TICK: () => (/* binding */ GEO_INIT_TICK),\n/* harmony export */   SCALE_TRIGGER: () => (/* binding */ SCALE_TRIGGER),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _assemble__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _project__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./project */ \"../../node_modules/vega-lite/build/src/compile/selection/project.js\");\n/* harmony import */ var _scales__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./scales */ \"../../node_modules/vega-lite/build/src/compile/selection/scales.js\");\n\n\n\n\n\n\n\n\n\n\n\n\nconst BRUSH = '_brush';\nconst SCALE_TRIGGER = '_scale_trigger';\nconst GEO_INIT_TICK = 'geo_interval_init_tick'; // Workaround for https://github.com/vega/vega/issues/3481\nconst INIT = '_init';\nconst CENTER = '_center';\nconst interval = {\n    defined: selCmpt => selCmpt.type === 'interval',\n    parse: (model, selCmpt, selDef) => {\n        var _a;\n        if (model.hasProjection) {\n            const def = { ...((0,vega__WEBPACK_IMPORTED_MODULE_0__.isObject)(selDef.select) ? selDef.select : {}) };\n            def.fields = [_selection__WEBPACK_IMPORTED_MODULE_6__.SELECTION_ID];\n            if (!def.encodings) {\n                // Remap default x/y projection\n                def.encodings = selDef.value ? (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(selDef.value) : [_channel__WEBPACK_IMPORTED_MODULE_3__.LONGITUDE, _channel__WEBPACK_IMPORTED_MODULE_3__.LATITUDE];\n            }\n            selDef.select = { type: 'interval', ...def };\n        }\n        if (selCmpt.translate && !_scales__WEBPACK_IMPORTED_MODULE_11__[\"default\"].defined(selCmpt)) {\n            const filterExpr = `!event.item || event.item.mark.name !== ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(selCmpt.name + BRUSH)}`;\n            for (const evt of selCmpt.events) {\n                if (!evt.between) {\n                    (0,_log__WEBPACK_IMPORTED_MODULE_4__.warn)(`${evt} is not an ordered event stream for interval selections.`);\n                    continue;\n                }\n                const filters = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)(((_a = evt.between[0]).filter ?? (_a.filter = [])));\n                if (filters.indexOf(filterExpr) < 0) {\n                    filters.push(filterExpr);\n                }\n            }\n        }\n    },\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const tupleSg = name + ___WEBPACK_IMPORTED_MODULE_2__.TUPLE;\n        const channels = (0,_util__WEBPACK_IMPORTED_MODULE_7__.vals)(selCmpt.project.hasChannel).filter(p => p.channel === _channel__WEBPACK_IMPORTED_MODULE_3__.X || p.channel === _channel__WEBPACK_IMPORTED_MODULE_3__.Y);\n        const init = selCmpt.init ? selCmpt.init[0] : null;\n        signals.push(...channels.reduce((arr, proj) => arr.concat(channelSignals(model, selCmpt, proj, init && init[proj.index])), []));\n        if (!model.hasProjection) {\n            // Proxy scale reactions to ensure that an infinite loop doesn't occur\n            // when an interval selection filter touches the scale.\n            if (!_scales__WEBPACK_IMPORTED_MODULE_11__[\"default\"].defined(selCmpt)) {\n                const triggerSg = name + SCALE_TRIGGER;\n                const scaleTriggers = channels.map(proj => {\n                    const channel = proj.channel;\n                    const { data: dname, visual: vname } = proj.signals;\n                    const scaleName = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.scaleName(channel));\n                    const scaleType = model.getScaleComponent(channel).get('type');\n                    const toNum = (0,_scale__WEBPACK_IMPORTED_MODULE_5__.hasContinuousDomain)(scaleType) ? '+' : '';\n                    return (`(!isArray(${dname}) || ` +\n                        `(${toNum}invert(${scaleName}, ${vname})[0] === ${toNum}${dname}[0] && ` +\n                        `${toNum}invert(${scaleName}, ${vname})[1] === ${toNum}${dname}[1]))`);\n                });\n                if (scaleTriggers.length) {\n                    signals.push({\n                        name: triggerSg,\n                        value: {},\n                        on: [\n                            {\n                                events: channels.map(proj => ({ scale: model.scaleName(proj.channel) })),\n                                update: scaleTriggers.join(' && ') + ` ? ${triggerSg} : {}`\n                            }\n                        ]\n                    });\n                }\n            }\n            // Only add an interval to the store if it has valid data extents. Data extents\n            // are set to null if pixel extents are equal to account for intervals over\n            // ordinal/nominal domains which, when inverted, will still produce a valid datum.\n            const dataSignals = channels.map(proj => proj.signals.data);\n            const update = `unit: ${(0,___WEBPACK_IMPORTED_MODULE_2__.unitName)(model)}, fields: ${name + _project__WEBPACK_IMPORTED_MODULE_10__.TUPLE_FIELDS}, values`;\n            return signals.concat({\n                name: tupleSg,\n                ...(init ? { init: `{${update}: ${(0,_assemble__WEBPACK_IMPORTED_MODULE_9__.assembleInit)(init)}}` } : {}),\n                ...(dataSignals.length\n                    ? {\n                        on: [\n                            {\n                                events: [{ signal: dataSignals.join(' || ') }],\n                                update: `${dataSignals.join(' && ')} ? {${update}: [${dataSignals}]} : null`\n                            }\n                        ]\n                    }\n                    : {})\n            });\n        }\n        else {\n            const projection = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.projectionName());\n            const centerSg = model.projectionName() + CENTER;\n            const { x, y } = selCmpt.project.hasChannel;\n            const xvname = x && x.signals.visual;\n            const yvname = y && y.signals.visual;\n            const xinit = x ? init && init[x.index] : `${centerSg}[0]`;\n            const yinit = y ? init && init[y.index] : `${centerSg}[1]`;\n            const sizeSg = (layout) => model.getSizeSignalRef(layout).signal;\n            const bbox = `[` +\n                `[${xvname ? xvname + '[0]' : '0'}, ${yvname ? yvname + '[0]' : '0'}],` +\n                `[${xvname ? xvname + '[1]' : sizeSg('width')}, ` +\n                `${yvname ? yvname + '[1]' : sizeSg('height')}]` +\n                `]`;\n            if (init) {\n                signals.unshift({\n                    name: name + INIT,\n                    init: `[scale(${projection}, [${x ? xinit[0] : xinit}, ${y ? yinit[0] : yinit}]), ` +\n                        `scale(${projection}, [${x ? xinit[1] : xinit}, ${y ? yinit[1] : yinit}])]`\n                });\n                if (!x || !y) {\n                    // If initializing a uni-dimensional brush, use the center of the view to determine the other coord\n                    const hasCenterSg = signals.find(s => s.name === centerSg);\n                    if (!hasCenterSg) {\n                        signals.unshift({\n                            name: centerSg,\n                            update: `invert(${projection}, [${sizeSg('width')}/2, ${sizeSg('height')}/2])`\n                        });\n                    }\n                }\n            }\n            const intersect = `intersect(${bbox}, {markname: ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.getName('marks'))}}, unit.mark)`;\n            const base = `{unit: ${(0,___WEBPACK_IMPORTED_MODULE_2__.unitName)(model)}}`;\n            const update = `vlSelectionTuples(${intersect}, ${base})`;\n            const visualSignals = channels.map(proj => proj.signals.visual);\n            return signals.concat({\n                name: tupleSg,\n                on: [\n                    {\n                        events: [\n                            ...(visualSignals.length ? [{ signal: visualSignals.join(' || ') }] : []),\n                            ...(init ? [{ signal: GEO_INIT_TICK }] : [])\n                        ],\n                        update\n                    }\n                ]\n            });\n        }\n    },\n    topLevelSignals: (model, selCmpt, signals) => {\n        if ((0,_model__WEBPACK_IMPORTED_MODULE_8__.isUnitModel)(model) && model.hasProjection && selCmpt.init) {\n            // Workaround for https://github.com/vega/vega/issues/3481\n            // The scenegraph isn't populated on the first pulse. So we use a timer signal\n            // to re-pulse the dataflow as soon as possible. We return an object to ensure\n            // this only occurs once.\n            const hasTick = signals.filter(s => s.name === GEO_INIT_TICK);\n            if (!hasTick.length) {\n                signals.unshift({\n                    name: GEO_INIT_TICK,\n                    value: null,\n                    on: [\n                        {\n                            events: 'timer{1}',\n                            update: `${GEO_INIT_TICK} === null ? {} : ${GEO_INIT_TICK}`\n                        }\n                    ]\n                });\n            }\n        }\n        return signals;\n    },\n    marks: (model, selCmpt, marks) => {\n        const name = selCmpt.name;\n        const { x, y } = selCmpt.project.hasChannel;\n        const xvname = x?.signals.visual;\n        const yvname = y?.signals.visual;\n        const store = `data(${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(selCmpt.name + ___WEBPACK_IMPORTED_MODULE_2__.STORE)})`;\n        // Do not add a brush if we're binding to scales\n        // or we don't have a valid interval projection\n        if (_scales__WEBPACK_IMPORTED_MODULE_11__[\"default\"].defined(selCmpt) || (!x && !y)) {\n            return marks;\n        }\n        const update = {\n            x: x !== undefined ? { signal: `${xvname}[0]` } : { value: 0 },\n            y: y !== undefined ? { signal: `${yvname}[0]` } : { value: 0 },\n            x2: x !== undefined ? { signal: `${xvname}[1]` } : { field: { group: 'width' } },\n            y2: y !== undefined ? { signal: `${yvname}[1]` } : { field: { group: 'height' } }\n        };\n        // If the selection is resolved to global, only a single interval is in\n        // the store. Wrap brush mark's encodings with a production rule to test\n        // this based on the `unit` property. Hide the brush mark if it corresponds\n        // to a unit different from the one in the store.\n        if (selCmpt.resolve === 'global') {\n            for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(update)) {\n                update[key] = [\n                    {\n                        test: `${store}.length && ${store}[0].unit === ${(0,___WEBPACK_IMPORTED_MODULE_2__.unitName)(model)}`,\n                        ...update[key]\n                    },\n                    { value: 0 }\n                ];\n            }\n        }\n        // Two brush marks ensure that fill colors and other aesthetic choices do\n        // not interefere with the core marks, but that the brushed region can still\n        // be interacted with (e.g., dragging it around).\n        const { fill, fillOpacity, cursor, ...stroke } = selCmpt.mark;\n        const vgStroke = (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(stroke).reduce((def, k) => {\n            def[k] = [\n                {\n                    test: [x !== undefined && `${xvname}[0] !== ${xvname}[1]`, y !== undefined && `${yvname}[0] !== ${yvname}[1]`]\n                        .filter(t => t)\n                        .join(' && '),\n                    value: stroke[k]\n                },\n                { value: null }\n            ];\n            return def;\n        }, {});\n        return [\n            {\n                name: `${name + BRUSH}_bg`,\n                type: 'rect',\n                clip: true,\n                encode: {\n                    enter: {\n                        fill: { value: fill },\n                        fillOpacity: { value: fillOpacity }\n                    },\n                    update\n                }\n            },\n            ...marks,\n            {\n                name: name + BRUSH,\n                type: 'rect',\n                clip: true,\n                encode: {\n                    enter: {\n                        ...(cursor ? { cursor: { value: cursor } } : {}),\n                        fill: { value: 'transparent' }\n                    },\n                    update: { ...update, ...vgStroke }\n                }\n            }\n        ];\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (interval);\n/**\n * Returns the visual and data signals for an interval selection.\n */\nfunction channelSignals(model, selCmpt, proj, init) {\n    const scaledInterval = !model.hasProjection;\n    const channel = proj.channel;\n    const vname = proj.signals.visual;\n    const scaleName = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(scaledInterval ? model.scaleName(channel) : model.projectionName());\n    const scaled = (str) => `scale(${scaleName}, ${str})`;\n    const size = model.getSizeSignalRef(channel === _channel__WEBPACK_IMPORTED_MODULE_3__.X ? 'width' : 'height').signal;\n    const coord = `${channel}(unit)`;\n    const von = selCmpt.events.reduce((def, evt) => {\n        return [\n            ...def,\n            { events: evt.between[0], update: `[${coord}, ${coord}]` },\n            { events: evt, update: `[${vname}[0], clamp(${coord}, 0, ${size})]` } // Brush End\n        ];\n    }, []);\n    if (scaledInterval) {\n        const dname = proj.signals.data;\n        const hasScales = _scales__WEBPACK_IMPORTED_MODULE_11__[\"default\"].defined(selCmpt);\n        const scale = model.getScaleComponent(channel);\n        const scaleType = scale ? scale.get('type') : undefined;\n        const vinit = init ? { init: (0,_assemble__WEBPACK_IMPORTED_MODULE_9__.assembleInit)(init, true, scaled) } : { value: [] };\n        // React to pan/zooms of continuous scales. Non-continuous scales\n        // (band, point) cannot be pan/zoomed and any other changes\n        // to their domains (e.g., filtering) should clear the brushes.\n        von.push({\n            events: { signal: selCmpt.name + SCALE_TRIGGER },\n            update: (0,_scale__WEBPACK_IMPORTED_MODULE_5__.hasContinuousDomain)(scaleType) ? `[${scaled(`${dname}[0]`)}, ${scaled(`${dname}[1]`)}]` : `[0, 0]`\n        });\n        return hasScales\n            ? [{ name: dname, on: [] }]\n            : [\n                { name: vname, ...vinit, on: von },\n                {\n                    name: dname,\n                    ...(init ? { init: (0,_assemble__WEBPACK_IMPORTED_MODULE_9__.assembleInit)(init) } : {}),\n                    on: [\n                        {\n                            events: { signal: vname },\n                            update: `${vname}[0] === ${vname}[1] ? null : invert(${scaleName}, ${vname})`\n                        }\n                    ]\n                }\n            ];\n    }\n    else {\n        const initIdx = channel === _channel__WEBPACK_IMPORTED_MODULE_3__.X ? 0 : 1;\n        const initSg = selCmpt.name + INIT;\n        const vinit = init ? { init: `[${initSg}[0][${initIdx}], ${initSg}[1][${initIdx}]]` } : { value: [] };\n        return [{ name: vname, ...vinit, on: von }];\n    }\n}\n//# sourceMappingURL=interval.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/interval.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/legends.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/legends.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   parseInteractiveLegend: () => (/* binding */ parseInteractiveLegend)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _project__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./project */ \"../../node_modules/vega-lite/build/src/compile/selection/project.js\");\n/* harmony import */ var _toggle__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./toggle */ \"../../node_modules/vega-lite/build/src/compile/selection/toggle.js\");\n\n\n\n\n\n\n\n\n\nconst legendBindings = {\n    defined: selCmpt => {\n        const spec = selCmpt.resolve === 'global' && selCmpt.bind && (0,_selection__WEBPACK_IMPORTED_MODULE_5__.isLegendBinding)(selCmpt.bind);\n        const projLen = selCmpt.project.items.length === 1 && selCmpt.project.items[0].field !== _selection__WEBPACK_IMPORTED_MODULE_5__.SELECTION_ID;\n        if (spec && !projLen) {\n            _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.LEGEND_BINDINGS_MUST_HAVE_PROJECTION);\n        }\n        return spec && projLen;\n    },\n    parse: (model, selCmpt, selDef) => {\n        // Allow legend items to be toggleable by default even though direct manipulation is disabled.\n        const selDef_ = (0,_util__WEBPACK_IMPORTED_MODULE_6__.duplicate)(selDef);\n        selDef_.select = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isString)(selDef_.select)\n            ? { type: selDef_.select, toggle: selCmpt.toggle }\n            : { ...selDef_.select, toggle: selCmpt.toggle };\n        (0,___WEBPACK_IMPORTED_MODULE_3__.disableDirectManipulation)(selCmpt, selDef_);\n        if ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isObject)(selDef.select) && (selDef.select.on || selDef.select.clear)) {\n            const legendFilter = 'event.item && indexof(event.item.mark.role, \"legend\") < 0';\n            for (const evt of selCmpt.events) {\n                evt.filter = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.array)(evt.filter ?? []);\n                if (!evt.filter.includes(legendFilter)) {\n                    evt.filter.push(legendFilter);\n                }\n            }\n        }\n        const evt = (0,_selection__WEBPACK_IMPORTED_MODULE_5__.isLegendStreamBinding)(selCmpt.bind) ? selCmpt.bind.legend : 'click';\n        const stream = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isString)(evt) ? (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_1__.parseSelector)(evt, 'view') : (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.array)(evt);\n        selCmpt.bind = { legend: { merge: stream } };\n    },\n    topLevelSignals: (model, selCmpt, signals) => {\n        const selName = selCmpt.name;\n        const stream = (0,_selection__WEBPACK_IMPORTED_MODULE_5__.isLegendStreamBinding)(selCmpt.bind) && selCmpt.bind.legend;\n        const markName = (name) => (s) => {\n            const ds = (0,_util__WEBPACK_IMPORTED_MODULE_6__.duplicate)(s);\n            ds.markname = name;\n            return ds;\n        };\n        for (const proj of selCmpt.project.items) {\n            if (!proj.hasLegend)\n                continue;\n            const prefix = `${(0,_util__WEBPACK_IMPORTED_MODULE_6__.varName)(proj.field)}_legend`;\n            const sgName = `${selName}_${prefix}`;\n            const hasSignal = signals.filter(s => s.name === sgName);\n            if (hasSignal.length === 0) {\n                const events = stream.merge\n                    .map(markName(`${prefix}_symbols`))\n                    .concat(stream.merge.map(markName(`${prefix}_labels`)))\n                    .concat(stream.merge.map(markName(`${prefix}_entries`)));\n                signals.unshift({\n                    name: sgName,\n                    ...(!selCmpt.init ? { value: null } : {}),\n                    on: [\n                        // Legend entries do not store values, so we need to walk the scenegraph to the symbol datum.\n                        {\n                            events,\n                            update: 'isDefined(datum.value) ? datum.value : item().items[0].items[0].datum.value',\n                            force: true\n                        },\n                        { events: stream.merge, update: `!event.item || !datum ? null : ${sgName}`, force: true }\n                    ]\n                });\n            }\n        }\n        return signals;\n    },\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const proj = selCmpt.project;\n        const tuple = signals.find(s => s.name === name + ___WEBPACK_IMPORTED_MODULE_3__.TUPLE);\n        const fields = name + _project__WEBPACK_IMPORTED_MODULE_7__.TUPLE_FIELDS;\n        const values = proj.items.filter(p => p.hasLegend).map(p => (0,_util__WEBPACK_IMPORTED_MODULE_6__.varName)(`${name}_${(0,_util__WEBPACK_IMPORTED_MODULE_6__.varName)(p.field)}_legend`));\n        const valid = values.map(v => `${v} !== null`).join(' && ');\n        const update = `${valid} ? {fields: ${fields}, values: [${values.join(', ')}]} : null`;\n        if (selCmpt.events && values.length > 0) {\n            tuple.on.push({\n                events: values.map(signal => ({ signal })),\n                update\n            });\n        }\n        else if (values.length > 0) {\n            tuple.update = update;\n            delete tuple.value;\n            delete tuple.on;\n        }\n        const toggle = signals.find(s => s.name === name + _toggle__WEBPACK_IMPORTED_MODULE_8__.TOGGLE);\n        const events = (0,_selection__WEBPACK_IMPORTED_MODULE_5__.isLegendStreamBinding)(selCmpt.bind) && selCmpt.bind.legend;\n        if (toggle) {\n            if (!selCmpt.events)\n                toggle.on[0].events = events;\n            else\n                toggle.on.push({ ...toggle.on[0], events });\n        }\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (legendBindings);\nfunction parseInteractiveLegend(model, channel, legendCmpt) {\n    const field = model.fieldDef(channel)?.field;\n    for (const selCmpt of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(model.component.selection ?? {})) {\n        const proj = selCmpt.project.hasField[field] ?? selCmpt.project.hasChannel[channel];\n        if (proj && legendBindings.defined(selCmpt)) {\n            const legendSelections = legendCmpt.get('selections') ?? [];\n            legendSelections.push(selCmpt.name);\n            legendCmpt.set('selections', legendSelections, false);\n            proj.hasLegend = true;\n        }\n    }\n}\n//# sourceMappingURL=legends.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/legends.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/nearest.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/nearest.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _mark_encode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../mark/encode */ \"../../node_modules/vega-lite/build/src/compile/mark/encode/index.js\");\n\n\n\nconst VORONOI = 'voronoi';\nconst nearest = {\n    defined: selCmpt => {\n        return selCmpt.type === 'point' && selCmpt.nearest;\n    },\n    parse: (model, selCmpt) => {\n        // Scope selection events to the voronoi mark to prevent capturing\n        // events that occur on the group mark (https://github.com/vega/vega/issues/2112).\n        if (selCmpt.events) {\n            for (const s of selCmpt.events) {\n                s.markname = model.getName(VORONOI);\n            }\n        }\n    },\n    marks: (model, selCmpt, marks) => {\n        const { x, y } = selCmpt.project.hasChannel;\n        const markType = model.mark;\n        if ((0,_mark__WEBPACK_IMPORTED_MODULE_1__.isPathMark)(markType)) {\n            _log__WEBPACK_IMPORTED_MODULE_0__.warn(_log__WEBPACK_IMPORTED_MODULE_0__.message.nearestNotSupportForContinuous(markType));\n            return marks;\n        }\n        const cellDef = {\n            name: model.getName(VORONOI),\n            type: 'path',\n            interactive: true,\n            from: { data: model.getName('marks') },\n            encode: {\n                update: {\n                    fill: { value: 'transparent' },\n                    strokeWidth: { value: 0.35 },\n                    stroke: { value: 'transparent' },\n                    isVoronoi: { value: true },\n                    ...(0,_mark_encode__WEBPACK_IMPORTED_MODULE_2__.tooltip)(model, { reactiveGeom: true })\n                }\n            },\n            transform: [\n                {\n                    type: 'voronoi',\n                    x: { expr: x || !y ? 'datum.datum.x || 0' : '0' },\n                    y: { expr: y || !x ? 'datum.datum.y || 0' : '0' },\n                    size: [model.getSizeSignalRef('width'), model.getSizeSignalRef('height')]\n                }\n            ]\n        };\n        let index = 0;\n        let exists = false;\n        marks.forEach((mark, i) => {\n            const name = mark.name ?? '';\n            if (name === model.component.mark[0].name) {\n                index = i;\n            }\n            else if (name.indexOf(VORONOI) >= 0) {\n                exists = true;\n            }\n        });\n        if (!exists) {\n            marks.splice(index + 1, 0, cellDef);\n        }\n        return marks;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (nearest);\n//# sourceMappingURL=nearest.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/nearest.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/parse.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/parse.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   materializeSelections: () => (/* binding */ materializeSelections),\n/* harmony export */   parseSelectionExtent: () => (/* binding */ parseSelectionExtent),\n/* harmony export */   parseSelectionPredicate: () => (/* binding */ parseSelectionPredicate),\n/* harmony export */   parseUnitSelection: () => (/* binding */ parseUnitSelection)\n/* harmony export */ });\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _data_dataflow__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../data/dataflow */ \"../../node_modules/vega-lite/build/src/compile/data/dataflow.js\");\n/* harmony import */ var _data_filter__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../data/filter */ \"../../node_modules/vega-lite/build/src/compile/data/filter.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n\n\n\n\n\n\n\n\nfunction parseUnitSelection(model, selDefs) {\n    const selCmpts = {};\n    const selectionConfig = model.config.selection;\n    if (!selDefs || !selDefs.length)\n        return selCmpts;\n    for (const def of selDefs) {\n        const name = (0,_util__WEBPACK_IMPORTED_MODULE_4__.varName)(def.name);\n        const selDef = def.select;\n        const type = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(selDef) ? selDef : selDef.type;\n        const defaults = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(selDef) ? (0,_util__WEBPACK_IMPORTED_MODULE_4__.duplicate)(selDef) : { type };\n        // Set default values from config if a property hasn't been specified,\n        // or if it is true. E.g., \"translate\": true should use the default\n        // event handlers for translate. However, true may be a valid value for\n        // a property (e.g., \"nearest\": true).\n        const cfg = selectionConfig[type];\n        for (const key in cfg) {\n            // Project transform applies its defaults.\n            if (key === 'fields' || key === 'encodings') {\n                continue;\n            }\n            if (key === 'mark') {\n                defaults[key] = { ...cfg[key], ...defaults[key] };\n            }\n            if (defaults[key] === undefined || defaults[key] === true) {\n                defaults[key] = (0,_util__WEBPACK_IMPORTED_MODULE_4__.duplicate)(cfg[key] ?? defaults[key]);\n            }\n        }\n        const selCmpt = (selCmpts[name] = {\n            ...defaults,\n            name,\n            type,\n            init: def.value,\n            bind: def.bind,\n            events: (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(defaults.on) ? (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_0__.parseSelector)(defaults.on, 'scope') : (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.array)((0,_util__WEBPACK_IMPORTED_MODULE_4__.duplicate)(defaults.on))\n        });\n        const def_ = (0,_util__WEBPACK_IMPORTED_MODULE_4__.duplicate)(def); // defensive copy to prevent compilers from causing side effects\n        for (const c of ___WEBPACK_IMPORTED_MODULE_2__.selectionCompilers) {\n            if (c.defined(selCmpt) && c.parse) {\n                c.parse(model, selCmpt, def_);\n            }\n        }\n    }\n    return selCmpts;\n}\nfunction parseSelectionPredicate(model, pred, dfnode, datum = 'datum') {\n    const name = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(pred) ? pred : pred.param;\n    const vname = (0,_util__WEBPACK_IMPORTED_MODULE_4__.varName)(name);\n    const store = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(vname + ___WEBPACK_IMPORTED_MODULE_2__.STORE);\n    let selCmpt;\n    try {\n        selCmpt = model.getSelectionComponent(vname, name);\n    }\n    catch (e) {\n        // If a selection isn't found, treat as a variable parameter and coerce to boolean.\n        return `!!${vname}`;\n    }\n    if (selCmpt.project.timeUnit) {\n        const child = dfnode ?? model.component.data.raw;\n        const tunode = selCmpt.project.timeUnit.clone();\n        if (child.parent) {\n            tunode.insertAsParentOf(child);\n        }\n        else {\n            child.parent = tunode;\n        }\n    }\n    const fn = selCmpt.project.hasSelectionId ? 'vlSelectionIdTest(' : 'vlSelectionTest(';\n    const resolve = selCmpt.resolve === 'global' ? ')' : `, ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(selCmpt.resolve)})`;\n    const test = `${fn}${store}, ${datum}${resolve}`;\n    const length = `length(data(${store}))`;\n    return pred.empty === false ? `${length} && ${test}` : `!${length} || ${test}`;\n}\nfunction parseSelectionExtent(model, name, extent) {\n    const vname = (0,_util__WEBPACK_IMPORTED_MODULE_4__.varName)(name);\n    const encoding = extent['encoding'];\n    let field = extent['field'];\n    let selCmpt;\n    try {\n        selCmpt = model.getSelectionComponent(vname, name);\n    }\n    catch (e) {\n        // If a selection isn't found, treat it as a variable parameter.\n        return vname;\n    }\n    if (!encoding && !field) {\n        field = selCmpt.project.items[0].field;\n        if (selCmpt.project.items.length > 1) {\n            (0,_log__WEBPACK_IMPORTED_MODULE_3__.warn)('A \"field\" or \"encoding\" must be specified when using a selection as a scale domain. ' +\n                `Using \"field\": ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(field)}.`);\n        }\n    }\n    else if (encoding && !field) {\n        const encodings = selCmpt.project.items.filter(p => p.channel === encoding);\n        if (!encodings.length || encodings.length > 1) {\n            field = selCmpt.project.items[0].field;\n            (0,_log__WEBPACK_IMPORTED_MODULE_3__.warn)((!encodings.length ? 'No ' : 'Multiple ') +\n                `matching ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(encoding)} encoding found for selection ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(extent.param)}. ` +\n                `Using \"field\": ${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(field)}.`);\n        }\n        else {\n            field = encodings[0].field;\n        }\n    }\n    return `${selCmpt.name}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)((0,_util__WEBPACK_IMPORTED_MODULE_4__.replacePathInField)(field))}]`;\n}\nfunction materializeSelections(model, main) {\n    for (const [selection, selCmpt] of (0,_util__WEBPACK_IMPORTED_MODULE_4__.entries)(model.component.selection ?? {})) {\n        const lookupName = model.getName(`lookup_${selection}`);\n        model.component.data.outputNodes[lookupName] = selCmpt.materialized = new _data_dataflow__WEBPACK_IMPORTED_MODULE_5__.OutputNode(new _data_filter__WEBPACK_IMPORTED_MODULE_6__.FilterNode(main, model, { param: selection }), lookupName, _data__WEBPACK_IMPORTED_MODULE_7__.DataSourceType.Lookup, model.component.data.outputNodeRefCounts);\n    }\n}\n//# sourceMappingURL=parse.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/parse.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/point.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/point.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./interval */ \"../../node_modules/vega-lite/build/src/compile/selection/interval.js\");\n/* harmony import */ var _project__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./project */ \"../../node_modules/vega-lite/build/src/compile/selection/project.js\");\n\n\n\n\n\n\nconst point = {\n    defined: selCmpt => selCmpt.type === 'point',\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const fieldsSg = name + _project__WEBPACK_IMPORTED_MODULE_5__.TUPLE_FIELDS;\n        const project = selCmpt.project;\n        const datum = '(item().isVoronoi ? datum.datum : datum)';\n        // Only add a discrete selection to the store if a datum is present _and_\n        // the interaction isn't occurring on a group mark. This guards against\n        // polluting interactive state with invalid values in faceted displays\n        // as the group marks are also data-driven. We force the update to account\n        // for constant null states but varying toggles (e.g., shift-click in\n        // whitespace followed by a click in whitespace; the store should only\n        // be cleared on the second click).\n        const brushes = (0,_util__WEBPACK_IMPORTED_MODULE_3__.vals)(model.component.selection ?? {})\n            .reduce((acc, cmpt) => {\n            return cmpt.type === 'interval' ? acc.concat(cmpt.name + _interval__WEBPACK_IMPORTED_MODULE_4__.BRUSH) : acc;\n        }, [])\n            .map(b => `indexof(item().mark.name, '${b}') < 0`)\n            .join(' && ');\n        const test = `datum && item().mark.marktype !== 'group' && indexof(item().mark.role, 'legend') < 0${brushes ? ` && ${brushes}` : ''}`;\n        let update = `unit: ${(0,___WEBPACK_IMPORTED_MODULE_1__.unitName)(model)}, `;\n        if (selCmpt.project.hasSelectionId) {\n            update += `${_selection__WEBPACK_IMPORTED_MODULE_2__.SELECTION_ID}: ${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(_selection__WEBPACK_IMPORTED_MODULE_2__.SELECTION_ID)}]`;\n        }\n        else {\n            const values = project.items\n                .map(p => {\n                const fieldDef = model.fieldDef(p.channel);\n                // Binned fields should capture extents, for a range test against the raw field.\n                return fieldDef?.bin\n                    ? `[${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(model.vgField(p.channel, {}))}], ` +\n                        `${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(model.vgField(p.channel, { binSuffix: 'end' }))}]]`\n                    : `${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(p.field)}]`;\n            })\n                .join(', ');\n            update += `fields: ${fieldsSg}, values: [${values}]`;\n        }\n        const events = selCmpt.events;\n        return signals.concat([\n            {\n                name: name + ___WEBPACK_IMPORTED_MODULE_1__.TUPLE,\n                on: events\n                    ? [\n                        {\n                            events,\n                            update: `${test} ? {${update}} : null`,\n                            force: true\n                        }\n                    ]\n                    : []\n            }\n        ]);\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (point);\n//# sourceMappingURL=point.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/point.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/project.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/project.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SelectionProjectionComponent: () => (/* binding */ SelectionProjectionComponent),\n/* harmony export */   TUPLE_FIELDS: () => (/* binding */ TUPLE_FIELDS),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _data_timeunit__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../data/timeunit */ \"../../node_modules/vega-lite/build/src/compile/data/timeunit.js\");\n/* harmony import */ var _assemble__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n\n\n\n\n\n\n\n\n\nconst TUPLE_FIELDS = '_tuple_fields';\nclass SelectionProjectionComponent {\n    constructor(...items) {\n        this.items = items;\n        this.hasChannel = {};\n        this.hasField = {};\n        this.hasSelectionId = false;\n    }\n}\nconst project = {\n    defined: () => {\n        return true; // This transform handles its own defaults, so always run parse.\n    },\n    parse: (model, selCmpt, selDef) => {\n        const name = selCmpt.name;\n        const proj = (selCmpt.project ?? (selCmpt.project = new SelectionProjectionComponent()));\n        const parsed = {};\n        const timeUnits = {};\n        const signals = new Set();\n        const signalName = (p, range) => {\n            const suffix = range === 'visual' ? p.channel : p.field;\n            let sg = (0,_util__WEBPACK_IMPORTED_MODULE_5__.varName)(`${name}_${suffix}`);\n            for (let counter = 1; signals.has(sg); counter++) {\n                sg = (0,_util__WEBPACK_IMPORTED_MODULE_5__.varName)(`${name}_${suffix}_${counter}`);\n            }\n            signals.add(sg);\n            return { [range]: sg };\n        };\n        const type = selCmpt.type;\n        const cfg = model.config.selection[type];\n        const init = selDef.value !== undefined\n            ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(selDef.value)\n            : null;\n        // If no explicit projection (either fields or encodings) is specified, set some defaults.\n        // If an initial value is set, try to infer projections.\n        let { fields, encodings } = ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(selDef.select) ? selDef.select : {});\n        if (!fields && !encodings && init) {\n            for (const initVal of init) {\n                // initVal may be a scalar value to smoothen varParam -> pointSelection gradient.\n                if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(initVal)) {\n                    continue;\n                }\n                for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(initVal)) {\n                    if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isSingleDefUnitChannel)(key)) {\n                        (encodings || (encodings = [])).push(key);\n                    }\n                    else {\n                        if (type === 'interval') {\n                            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.INTERVAL_INITIALIZED_WITH_POS);\n                            encodings = cfg.encodings;\n                        }\n                        else {\n                            (fields ?? (fields = [])).push(key);\n                        }\n                    }\n                }\n            }\n        }\n        // If no initial value is specified, use the default configuration.\n        // We break this out as a separate if block (instead of an else condition)\n        // to account for unprojected point selections that have scalar initial values\n        if (!fields && !encodings) {\n            encodings = cfg.encodings;\n            if ('fields' in cfg) {\n                fields = cfg.fields;\n            }\n        }\n        for (const channel of encodings ?? []) {\n            const fieldDef = model.fieldDef(channel);\n            if (fieldDef) {\n                let field = fieldDef.field;\n                if (fieldDef.aggregate) {\n                    _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.cannotProjectAggregate(channel, fieldDef.aggregate));\n                    continue;\n                }\n                else if (!field) {\n                    _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.cannotProjectOnChannelWithoutField(channel));\n                    continue;\n                }\n                if (fieldDef.timeUnit && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_8__.isBinnedTimeUnit)(fieldDef.timeUnit)) {\n                    field = model.vgField(channel);\n                    // Construct TimeUnitComponents which will be combined into a\n                    // TimeUnitNode. This node may need to be inserted into the\n                    // dataflow if the selection is used across views that do not\n                    // have these time units defined.\n                    const component = {\n                        timeUnit: fieldDef.timeUnit,\n                        as: field,\n                        field: fieldDef.field\n                    };\n                    timeUnits[(0,_util__WEBPACK_IMPORTED_MODULE_5__.hash)(component)] = component;\n                }\n                // Prevent duplicate projections on the same field.\n                // TODO: what if the same field is bound to multiple channels (e.g., SPLOM diag).\n                if (!parsed[field]) {\n                    // Determine whether the tuple will store enumerated or ranged values.\n                    // Interval selections store ranges for continuous scales, and enumerations otherwise.\n                    // Single/multi selections store ranges for binned fields, and enumerations otherwise.\n                    const tplType = type === 'interval' &&\n                        (0,_channel__WEBPACK_IMPORTED_MODULE_1__.isScaleChannel)(channel) &&\n                        (0,_scale__WEBPACK_IMPORTED_MODULE_3__.hasContinuousDomain)(model.getScaleComponent(channel).get('type'))\n                        ? 'R'\n                        : fieldDef.bin\n                            ? 'R-RE'\n                            : 'E';\n                    const p = { field, channel, type: tplType, index: proj.items.length };\n                    p.signals = { ...signalName(p, 'data'), ...signalName(p, 'visual') };\n                    proj.items.push((parsed[field] = p));\n                    proj.hasField[field] = parsed[field];\n                    proj.hasSelectionId = proj.hasSelectionId || field === _selection__WEBPACK_IMPORTED_MODULE_4__.SELECTION_ID;\n                    if ((0,_channel__WEBPACK_IMPORTED_MODULE_1__.isGeoPositionChannel)(channel)) {\n                        p.geoChannel = channel;\n                        p.channel = (0,_channel__WEBPACK_IMPORTED_MODULE_1__.getPositionChannelFromLatLong)(channel);\n                        proj.hasChannel[p.channel] = parsed[field];\n                    }\n                    else {\n                        proj.hasChannel[channel] = parsed[field];\n                    }\n                }\n            }\n            else {\n                _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.cannotProjectOnChannelWithoutField(channel));\n            }\n        }\n        for (const field of fields ?? []) {\n            if (proj.hasField[field])\n                continue;\n            const p = { type: 'E', field, index: proj.items.length };\n            p.signals = { ...signalName(p, 'data') };\n            proj.items.push(p);\n            proj.hasField[field] = p;\n            proj.hasSelectionId = proj.hasSelectionId || field === _selection__WEBPACK_IMPORTED_MODULE_4__.SELECTION_ID;\n        }\n        if (init) {\n            selCmpt.init = init.map((v) => {\n                // Selections can be initialized either with a full object that maps projections to values\n                // or scalar values to smoothen the abstraction gradient from variable params to point selections.\n                return proj.items.map(p => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(v) ? (v[p.geoChannel || p.channel] !== undefined ? v[p.geoChannel || p.channel] : v[p.field]) : v);\n            });\n        }\n        if (!(0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(timeUnits)) {\n            proj.timeUnit = new _data_timeunit__WEBPACK_IMPORTED_MODULE_6__.TimeUnitNode(null, timeUnits);\n        }\n    },\n    signals: (model, selCmpt, allSignals) => {\n        const name = selCmpt.name + TUPLE_FIELDS;\n        const hasSignal = allSignals.filter(s => s.name === name);\n        return hasSignal.length > 0 || selCmpt.project.hasSelectionId\n            ? allSignals\n            : allSignals.concat({\n                name,\n                value: selCmpt.project.items.map(_assemble__WEBPACK_IMPORTED_MODULE_7__.assembleProjection)\n            });\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (project);\n//# sourceMappingURL=project.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/project.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/scales.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/scales.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   domain: () => (/* binding */ domain)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\nconst scaleBindings = {\n    defined: selCmpt => {\n        return selCmpt.type === 'interval' && selCmpt.resolve === 'global' && selCmpt.bind && selCmpt.bind === 'scales';\n    },\n    parse: (model, selCmpt) => {\n        const bound = (selCmpt.scales = []);\n        for (const proj of selCmpt.project.items) {\n            const channel = proj.channel;\n            if (!(0,_channel__WEBPACK_IMPORTED_MODULE_2__.isScaleChannel)(channel)) {\n                continue;\n            }\n            const scale = model.getScaleComponent(channel);\n            const scaleType = scale ? scale.get('type') : undefined;\n            if (!scale || !(0,_scale__WEBPACK_IMPORTED_MODULE_4__.hasContinuousDomain)(scaleType)) {\n                _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.SCALE_BINDINGS_CONTINUOUS);\n                continue;\n            }\n            scale.set('selectionExtent', { param: selCmpt.name, field: proj.field }, true);\n            bound.push(proj);\n        }\n    },\n    topLevelSignals: (model, selCmpt, signals) => {\n        const bound = selCmpt.scales.filter(proj => signals.filter(s => s.name === proj.signals.data).length === 0);\n        // Top-level signals are only needed for multiview displays and if this\n        // view's top-level signals haven't already been generated.\n        if (!model.parent || isTopLevelLayer(model) || bound.length === 0) {\n            return signals;\n        }\n        // vlSelectionResolve does not account for the behavior of bound scales in\n        // multiview displays. Each unit view adds a tuple to the store, but the\n        // state of the selection is the unit selection most recently updated. This\n        // state is captured by the top-level signals that we insert and \"push\n        // outer\" to from within the units. We need to reassemble this state into\n        // the top-level named signal, except no single selCmpt has a global view.\n        const namedSg = signals.filter(s => s.name === selCmpt.name)[0];\n        let update = namedSg.update;\n        if (update.indexOf(___WEBPACK_IMPORTED_MODULE_1__.VL_SELECTION_RESOLVE) >= 0) {\n            namedSg.update = `{${bound\n                .map(proj => `${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)((0,_util__WEBPACK_IMPORTED_MODULE_6__.replacePathInField)(proj.field))}: ${proj.signals.data}`)\n                .join(', ')}}`;\n        }\n        else {\n            for (const proj of bound) {\n                const mapping = `${(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)((0,_util__WEBPACK_IMPORTED_MODULE_6__.replacePathInField)(proj.field))}: ${proj.signals.data}`;\n                if (!update.includes(mapping)) {\n                    update = `${update.substring(0, update.length - 1)}, ${mapping}}`;\n                }\n            }\n            namedSg.update = update;\n        }\n        return signals.concat(bound.map(proj => ({ name: proj.signals.data })));\n    },\n    signals: (model, selCmpt, signals) => {\n        // Nested signals need only push to top-level signals with multiview displays.\n        if (model.parent && !isTopLevelLayer(model)) {\n            for (const proj of selCmpt.scales) {\n                const signal = signals.filter(s => s.name === proj.signals.data)[0];\n                signal.push = 'outer';\n                delete signal.value;\n                delete signal.update;\n            }\n        }\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (scaleBindings);\nfunction domain(model, channel) {\n    const scale = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(model.scaleName(channel));\n    return `domain(${scale})`;\n}\nfunction isTopLevelLayer(model) {\n    return model.parent && (0,_model__WEBPACK_IMPORTED_MODULE_5__.isLayerModel)(model.parent) && (!model.parent.parent ?? isTopLevelLayer(model.parent.parent));\n}\n//# sourceMappingURL=scales.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/scales.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/toggle.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/toggle.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TOGGLE: () => (/* binding */ TOGGLE),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! . */ \"../../node_modules/vega-lite/build/src/compile/selection/index.js\");\n\nconst TOGGLE = '_toggle';\nconst toggle = {\n    defined: selCmpt => {\n        return selCmpt.type === 'point' && !!selCmpt.toggle;\n    },\n    signals: (model, selCmpt, signals) => {\n        return signals.concat({\n            name: selCmpt.name + TOGGLE,\n            value: false,\n            on: [{ events: selCmpt.events, update: selCmpt.toggle }]\n        });\n    },\n    modifyExpr: (model, selCmpt) => {\n        const tpl = selCmpt.name + ___WEBPACK_IMPORTED_MODULE_0__.TUPLE;\n        const signal = selCmpt.name + TOGGLE;\n        return (`${signal} ? null : ${tpl}, ` +\n            (selCmpt.resolve === 'global' ? `${signal} ? null : true, ` : `${signal} ? null : {unit: ${(0,___WEBPACK_IMPORTED_MODULE_0__.unitName)(model)}}, `) +\n            `${signal} ? ${tpl} : null`);\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (toggle);\n//# sourceMappingURL=toggle.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/toggle.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/translate.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/translate.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./interval */ \"../../node_modules/vega-lite/build/src/compile/selection/interval.js\");\n/* harmony import */ var _scales__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./scales */ \"../../node_modules/vega-lite/build/src/compile/selection/scales.js\");\n\n\n\n\nconst ANCHOR = '_translate_anchor';\nconst DELTA = '_translate_delta';\nconst translate = {\n    defined: selCmpt => {\n        return selCmpt.type === 'interval' && selCmpt.translate;\n    },\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const boundScales = _scales__WEBPACK_IMPORTED_MODULE_3__[\"default\"].defined(selCmpt);\n        const anchor = name + ANCHOR;\n        const { x, y } = selCmpt.project.hasChannel;\n        let events = (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_0__.parseSelector)(selCmpt.translate, 'scope');\n        if (!boundScales) {\n            events = events.map(e => ((e.between[0].markname = name + _interval__WEBPACK_IMPORTED_MODULE_2__.BRUSH), e));\n        }\n        signals.push({\n            name: anchor,\n            value: {},\n            on: [\n                {\n                    events: events.map(e => e.between[0]),\n                    update: '{x: x(unit), y: y(unit)' +\n                        (x !== undefined ? `, extent_x: ${boundScales ? (0,_scales__WEBPACK_IMPORTED_MODULE_3__.domain)(model, _channel__WEBPACK_IMPORTED_MODULE_1__.X) : `slice(${x.signals.visual})`}` : '') +\n                        (y !== undefined ? `, extent_y: ${boundScales ? (0,_scales__WEBPACK_IMPORTED_MODULE_3__.domain)(model, _channel__WEBPACK_IMPORTED_MODULE_1__.Y) : `slice(${y.signals.visual})`}` : '') +\n                        '}'\n                }\n            ]\n        }, {\n            name: name + DELTA,\n            value: {},\n            on: [\n                {\n                    events,\n                    update: `{x: ${anchor}.x - x(unit), y: ${anchor}.y - y(unit)}`\n                }\n            ]\n        });\n        if (x !== undefined) {\n            onDelta(model, selCmpt, x, 'width', signals);\n        }\n        if (y !== undefined) {\n            onDelta(model, selCmpt, y, 'height', signals);\n        }\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (translate);\nfunction onDelta(model, selCmpt, proj, size, signals) {\n    const name = selCmpt.name;\n    const anchor = name + ANCHOR;\n    const delta = name + DELTA;\n    const channel = proj.channel;\n    const boundScales = _scales__WEBPACK_IMPORTED_MODULE_3__[\"default\"].defined(selCmpt);\n    const signal = signals.filter(s => s.name === proj.signals[boundScales ? 'data' : 'visual'])[0];\n    const sizeSg = model.getSizeSignalRef(size).signal;\n    const scaleCmpt = model.getScaleComponent(channel);\n    const scaleType = scaleCmpt && scaleCmpt.get('type');\n    const reversed = scaleCmpt && scaleCmpt.get('reverse'); // scale parsing sets this flag for fieldDef.sort\n    const sign = !boundScales ? '' : channel === _channel__WEBPACK_IMPORTED_MODULE_1__.X ? (reversed ? '' : '-') : reversed ? '-' : '';\n    const extent = `${anchor}.extent_${channel}`;\n    const offset = `${sign}${delta}.${channel} / ${boundScales ? `${sizeSg}` : `span(${extent})`}`;\n    const panFn = !boundScales || !scaleCmpt\n        ? 'panLinear'\n        : scaleType === 'log'\n            ? 'panLog'\n            : scaleType === 'symlog'\n                ? 'panSymlog'\n                : scaleType === 'pow'\n                    ? 'panPow'\n                    : 'panLinear';\n    const arg = !boundScales\n        ? ''\n        : scaleType === 'pow'\n            ? `, ${scaleCmpt.get('exponent') ?? 1}`\n            : scaleType === 'symlog'\n                ? `, ${scaleCmpt.get('constant') ?? 1}`\n                : '';\n    const update = `${panFn}(${extent}, ${offset}${arg})`;\n    signal.on.push({\n        events: { signal: delta },\n        update: boundScales ? update : `clampRange(${update}, 0, ${sizeSg})`\n    });\n}\n//# sourceMappingURL=translate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/translate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/selection/zoom.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/selection/zoom.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./interval */ \"../../node_modules/vega-lite/build/src/compile/selection/interval.js\");\n/* harmony import */ var _scales__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./scales */ \"../../node_modules/vega-lite/build/src/compile/selection/scales.js\");\n\n\n\n\n\nconst ANCHOR = '_zoom_anchor';\nconst DELTA = '_zoom_delta';\nconst zoom = {\n    defined: selCmpt => {\n        return selCmpt.type === 'interval' && selCmpt.zoom;\n    },\n    signals: (model, selCmpt, signals) => {\n        const name = selCmpt.name;\n        const boundScales = _scales__WEBPACK_IMPORTED_MODULE_4__[\"default\"].defined(selCmpt);\n        const delta = name + DELTA;\n        const { x, y } = selCmpt.project.hasChannel;\n        const sx = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.scaleName(_channel__WEBPACK_IMPORTED_MODULE_2__.X));\n        const sy = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.stringValue)(model.scaleName(_channel__WEBPACK_IMPORTED_MODULE_2__.Y));\n        let events = (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_0__.parseSelector)(selCmpt.zoom, 'scope');\n        if (!boundScales) {\n            events = events.map(e => ((e.markname = name + _interval__WEBPACK_IMPORTED_MODULE_3__.BRUSH), e));\n        }\n        signals.push({\n            name: name + ANCHOR,\n            on: [\n                {\n                    events,\n                    update: !boundScales\n                        ? `{x: x(unit), y: y(unit)}`\n                        : '{' +\n                            [sx ? `x: invert(${sx}, x(unit))` : '', sy ? `y: invert(${sy}, y(unit))` : '']\n                                .filter(expr => expr)\n                                .join(', ') +\n                            '}'\n                }\n            ]\n        }, {\n            name: delta,\n            on: [\n                {\n                    events,\n                    force: true,\n                    update: 'pow(1.001, event.deltaY * pow(16, event.deltaMode))'\n                }\n            ]\n        });\n        if (x !== undefined) {\n            onDelta(model, selCmpt, x, 'width', signals);\n        }\n        if (y !== undefined) {\n            onDelta(model, selCmpt, y, 'height', signals);\n        }\n        return signals;\n    }\n};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (zoom);\nfunction onDelta(model, selCmpt, proj, size, signals) {\n    const name = selCmpt.name;\n    const channel = proj.channel;\n    const boundScales = _scales__WEBPACK_IMPORTED_MODULE_4__[\"default\"].defined(selCmpt);\n    const signal = signals.filter(s => s.name === proj.signals[boundScales ? 'data' : 'visual'])[0];\n    const sizeSg = model.getSizeSignalRef(size).signal;\n    const scaleCmpt = model.getScaleComponent(channel);\n    const scaleType = scaleCmpt && scaleCmpt.get('type');\n    const base = boundScales ? (0,_scales__WEBPACK_IMPORTED_MODULE_4__.domain)(model, channel) : signal.name;\n    const delta = name + DELTA;\n    const anchor = `${name}${ANCHOR}.${channel}`;\n    const zoomFn = !boundScales || !scaleCmpt\n        ? 'zoomLinear'\n        : scaleType === 'log'\n            ? 'zoomLog'\n            : scaleType === 'symlog'\n                ? 'zoomSymlog'\n                : scaleType === 'pow'\n                    ? 'zoomPow'\n                    : 'zoomLinear';\n    const arg = !boundScales\n        ? ''\n        : scaleType === 'pow'\n            ? `, ${scaleCmpt.get('exponent') ?? 1}`\n            : scaleType === 'symlog'\n                ? `, ${scaleCmpt.get('constant') ?? 1}`\n                : '';\n    const update = `${zoomFn}(${base}, ${anchor}, ${delta}${arg})`;\n    signal.on.push({\n        events: { signal: delta },\n        update: boundScales ? update : `clampRange(${update}, 0, ${sizeSg})`\n    });\n}\n//# sourceMappingURL=zoom.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/selection/zoom.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/signal.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/signal.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SignalRefWrapper: () => (/* binding */ SignalRefWrapper)\n/* harmony export */ });\n/**\n * A class that behaves like a SignalRef but lazily generates the signal.\n * The provided generator function should use `Model.getSignalName` to use the correct signal name.\n */\nclass SignalRefWrapper {\n    constructor(exprGenerator) {\n        Object.defineProperty(this, 'signal', {\n            enumerable: true,\n            get: exprGenerator\n        });\n    }\n    static fromName(rename, signalName) {\n        return new SignalRefWrapper(() => rename(signalName));\n    }\n}\n//# sourceMappingURL=signal.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/signal.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/split.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/split.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Split: () => (/* binding */ Split),\n/* harmony export */   defaultTieBreaker: () => (/* binding */ defaultTieBreaker),\n/* harmony export */   makeExplicit: () => (/* binding */ makeExplicit),\n/* harmony export */   makeImplicit: () => (/* binding */ makeImplicit),\n/* harmony export */   mergeValuesWithExplicit: () => (/* binding */ mergeValuesWithExplicit),\n/* harmony export */   tieBreakByComparing: () => (/* binding */ tieBreakByComparing)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n/**\n * Generic class for storing properties that are explicitly specified\n * and implicitly determined by the compiler.\n * This is important for scale/axis/legend merging as\n * we want to prioritize properties that users explicitly specified.\n */\n// eslint-disable-next-line @typescript-eslint/ban-types\nclass Split {\n    constructor(explicit = {}, implicit = {}) {\n        this.explicit = explicit;\n        this.implicit = implicit;\n    }\n    clone() {\n        return new Split((0,_util__WEBPACK_IMPORTED_MODULE_1__.duplicate)(this.explicit), (0,_util__WEBPACK_IMPORTED_MODULE_1__.duplicate)(this.implicit));\n    }\n    combine() {\n        return {\n            ...this.explicit,\n            ...this.implicit\n        };\n    }\n    get(key) {\n        // Explicit has higher precedence\n        return (0,_util__WEBPACK_IMPORTED_MODULE_1__.getFirstDefined)(this.explicit[key], this.implicit[key]);\n    }\n    getWithExplicit(key) {\n        // Explicit has higher precedence\n        if (this.explicit[key] !== undefined) {\n            return { explicit: true, value: this.explicit[key] };\n        }\n        else if (this.implicit[key] !== undefined) {\n            return { explicit: false, value: this.implicit[key] };\n        }\n        return { explicit: false, value: undefined };\n    }\n    setWithExplicit(key, { value, explicit }) {\n        if (value !== undefined) {\n            this.set(key, value, explicit);\n        }\n    }\n    set(key, value, explicit) {\n        delete this[explicit ? 'implicit' : 'explicit'][key];\n        this[explicit ? 'explicit' : 'implicit'][key] = value;\n        return this;\n    }\n    copyKeyFromSplit(key, { explicit, implicit }) {\n        // Explicit has higher precedence\n        if (explicit[key] !== undefined) {\n            this.set(key, explicit[key], true);\n        }\n        else if (implicit[key] !== undefined) {\n            this.set(key, implicit[key], false);\n        }\n    }\n    copyKeyFromObject(key, s) {\n        // Explicit has higher precedence\n        if (s[key] !== undefined) {\n            this.set(key, s[key], true);\n        }\n    }\n    /**\n     * Merge split object into this split object. Properties from the other split\n     * overwrite properties from this split.\n     */\n    copyAll(other) {\n        for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(other.combine())) {\n            const val = other.getWithExplicit(key);\n            this.setWithExplicit(key, val);\n        }\n    }\n}\nfunction makeExplicit(value) {\n    return {\n        explicit: true,\n        value\n    };\n}\nfunction makeImplicit(value) {\n    return {\n        explicit: false,\n        value\n    };\n}\nfunction tieBreakByComparing(compare) {\n    return (v1, v2, property, propertyOf) => {\n        const diff = compare(v1.value, v2.value);\n        if (diff > 0) {\n            return v1;\n        }\n        else if (diff < 0) {\n            return v2;\n        }\n        return defaultTieBreaker(v1, v2, property, propertyOf);\n    };\n}\nfunction defaultTieBreaker(v1, v2, property, propertyOf) {\n    if (v1.explicit && v2.explicit) {\n        _log__WEBPACK_IMPORTED_MODULE_0__.warn(_log__WEBPACK_IMPORTED_MODULE_0__.message.mergeConflictingProperty(property, propertyOf, v1.value, v2.value));\n    }\n    // If equal score, prefer v1.\n    return v1;\n}\nfunction mergeValuesWithExplicit(v1, v2, property, propertyOf, tieBreaker = defaultTieBreaker) {\n    if (v1 === undefined || v1.value === undefined) {\n        // For first run\n        return v2;\n    }\n    if (v1.explicit && !v2.explicit) {\n        return v1;\n    }\n    else if (v2.explicit && !v1.explicit) {\n        return v2;\n    }\n    else if ((0,_util__WEBPACK_IMPORTED_MODULE_1__.deepEqual)(v1.value, v2.value)) {\n        return v1;\n    }\n    else {\n        return tieBreaker(v1, v2, property, propertyOf);\n    }\n}\n//# sourceMappingURL=split.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/split.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compile/unit.js":
/*!**************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compile/unit.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   UnitModel: () => (/* binding */ UnitModel)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _axis__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../axis */ \"../../node_modules/vega-lite/build/src/axis.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../data */ \"../../node_modules/vega-lite/build/src/data.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n/* harmony import */ var _stack__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../stack */ \"../../node_modules/vega-lite/build/src/stack.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _axis_assemble__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./axis/assemble */ \"../../node_modules/vega-lite/build/src/compile/axis/assemble.js\");\n/* harmony import */ var _axis_parse__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./axis/parse */ \"../../node_modules/vega-lite/build/src/compile/axis/parse.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _data_parse__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./data/parse */ \"../../node_modules/vega-lite/build/src/compile/data/parse.js\");\n/* harmony import */ var _layoutsize_assemble__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./layoutsize/assemble */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/assemble.js\");\n/* harmony import */ var _layoutsize_init__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./layoutsize/init */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/init.js\");\n/* harmony import */ var _layoutsize_parse__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./layoutsize/parse */ \"../../node_modules/vega-lite/build/src/compile/layoutsize/parse.js\");\n/* harmony import */ var _mark_init__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./mark/init */ \"../../node_modules/vega-lite/build/src/compile/mark/init.js\");\n/* harmony import */ var _mark_mark__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./mark/mark */ \"../../node_modules/vega-lite/build/src/compile/mark/mark.js\");\n/* harmony import */ var _model__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./model */ \"../../node_modules/vega-lite/build/src/compile/model.js\");\n/* harmony import */ var _selection_assemble__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./selection/assemble */ \"../../node_modules/vega-lite/build/src/compile/selection/assemble.js\");\n/* harmony import */ var _selection_parse__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./selection/parse */ \"../../node_modules/vega-lite/build/src/compile/selection/parse.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * Internal model of Vega-Lite specification for the compiler.\n */\nclass UnitModel extends _model__WEBPACK_IMPORTED_MODULE_21__.ModelWithField {\n    constructor(spec, parent, parentGivenName, parentGivenSize = {}, config) {\n        super(spec, 'unit', parent, parentGivenName, config, undefined, (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isFrameMixins)(spec) ? spec.view : undefined);\n        this.specifiedScales = {};\n        this.specifiedAxes = {};\n        this.specifiedLegends = {};\n        this.specifiedProjection = {};\n        this.selection = [];\n        this.children = [];\n        const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_7__.isMarkDef)(spec.mark) ? { ...spec.mark } : { type: spec.mark };\n        const mark = markDef.type;\n        // Need to init filled before other mark properties because encoding depends on filled but other mark properties depend on types inside encoding\n        if (markDef.filled === undefined) {\n            markDef.filled = (0,_mark_init__WEBPACK_IMPORTED_MODULE_19__.defaultFilled)(markDef, config, {\n                graticule: spec.data && (0,_data__WEBPACK_IMPORTED_MODULE_4__.isGraticuleGenerator)(spec.data)\n            });\n        }\n        const encoding = (this.encoding = (0,_encoding__WEBPACK_IMPORTED_MODULE_5__.initEncoding)(spec.encoding || {}, mark, markDef.filled, config));\n        this.markDef = (0,_mark_init__WEBPACK_IMPORTED_MODULE_19__.initMarkdef)(markDef, encoding, config);\n        this.size = (0,_layoutsize_init__WEBPACK_IMPORTED_MODULE_17__.initLayoutSize)({\n            encoding,\n            size: (0,_spec_base__WEBPACK_IMPORTED_MODULE_9__.isFrameMixins)(spec)\n                ? {\n                    ...parentGivenSize,\n                    ...(spec.width ? { width: spec.width } : {}),\n                    ...(spec.height ? { height: spec.height } : {})\n                }\n                : parentGivenSize\n        });\n        // calculate stack properties\n        this.stack = (0,_stack__WEBPACK_IMPORTED_MODULE_10__.stack)(this.markDef, encoding);\n        this.specifiedScales = this.initScales(mark, encoding);\n        this.specifiedAxes = this.initAxes(encoding);\n        this.specifiedLegends = this.initLegends(encoding);\n        this.specifiedProjection = spec.projection;\n        // Selections will be initialized upon parse.\n        this.selection = (spec.params ?? []).filter(p => (0,_selection__WEBPACK_IMPORTED_MODULE_8__.isSelectionParameter)(p));\n    }\n    get hasProjection() {\n        const { encoding } = this;\n        const isGeoShapeMark = this.mark === _mark__WEBPACK_IMPORTED_MODULE_7__.GEOSHAPE;\n        const hasGeoPosition = encoding && _channel__WEBPACK_IMPORTED_MODULE_2__.GEOPOSITION_CHANNELS.some(channel => (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(encoding[channel]));\n        return isGeoShapeMark || hasGeoPosition;\n    }\n    /**\n     * Return specified Vega-Lite scale domain for a particular channel\n     * @param channel\n     */\n    scaleDomain(channel) {\n        const scale = this.specifiedScales[channel];\n        return scale ? scale.domain : undefined;\n    }\n    axis(channel) {\n        return this.specifiedAxes[channel];\n    }\n    legend(channel) {\n        return this.specifiedLegends[channel];\n    }\n    initScales(mark, encoding) {\n        return _channel__WEBPACK_IMPORTED_MODULE_2__.SCALE_CHANNELS.reduce((scales, channel) => {\n            const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldOrDatumDef)(encoding[channel]);\n            if (fieldOrDatumDef) {\n                scales[channel] = this.initScale(fieldOrDatumDef.scale ?? {});\n            }\n            return scales;\n        }, {});\n    }\n    initScale(scale) {\n        const { domain, range } = scale;\n        // TODO: we could simplify this function if we had a recursive replace function\n        const scaleInternal = (0,_expr__WEBPACK_IMPORTED_MODULE_6__.replaceExprRef)(scale);\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain)) {\n            scaleInternal.domain = domain.map(_common__WEBPACK_IMPORTED_MODULE_14__.signalRefOrValue);\n        }\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range)) {\n            scaleInternal.range = range.map(_common__WEBPACK_IMPORTED_MODULE_14__.signalRefOrValue);\n        }\n        return scaleInternal;\n    }\n    initAxes(encoding) {\n        return _channel__WEBPACK_IMPORTED_MODULE_2__.POSITION_SCALE_CHANNELS.reduce((_axis, channel) => {\n            // Position Axis\n            // TODO: handle ConditionFieldDef\n            const channelDef = encoding[channel];\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(channelDef) ||\n                (channel === _channel__WEBPACK_IMPORTED_MODULE_2__.X && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(encoding.x2)) ||\n                (channel === _channel__WEBPACK_IMPORTED_MODULE_2__.Y && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(encoding.y2))) {\n                const axisSpec = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(channelDef) ? channelDef.axis : undefined;\n                _axis[channel] = axisSpec\n                    ? this.initAxis({ ...axisSpec }) // convert truthy value to object\n                    : axisSpec;\n            }\n            return _axis;\n        }, {});\n    }\n    initAxis(axis) {\n        const props = (0,_util__WEBPACK_IMPORTED_MODULE_11__.keys)(axis);\n        const axisInternal = {};\n        for (const prop of props) {\n            const val = axis[prop];\n            axisInternal[prop] = (0,_axis__WEBPACK_IMPORTED_MODULE_1__.isConditionalAxisValue)(val)\n                ? (0,_common__WEBPACK_IMPORTED_MODULE_14__.signalOrValueRefWithCondition)(val)\n                : (0,_common__WEBPACK_IMPORTED_MODULE_14__.signalRefOrValue)(val);\n        }\n        return axisInternal;\n    }\n    initLegends(encoding) {\n        return _channel__WEBPACK_IMPORTED_MODULE_2__.NONPOSITION_SCALE_CHANNELS.reduce((_legend, channel) => {\n            const fieldOrDatumDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldOrDatumDef)(encoding[channel]);\n            if (fieldOrDatumDef && (0,_channel__WEBPACK_IMPORTED_MODULE_2__.supportLegend)(channel)) {\n                const legend = fieldOrDatumDef.legend;\n                _legend[channel] = legend\n                    ? (0,_expr__WEBPACK_IMPORTED_MODULE_6__.replaceExprRef)(legend) // convert truthy value to object\n                    : legend;\n            }\n            return _legend;\n        }, {});\n    }\n    parseData() {\n        this.component.data = (0,_data_parse__WEBPACK_IMPORTED_MODULE_15__.parseData)(this);\n    }\n    parseLayoutSize() {\n        (0,_layoutsize_parse__WEBPACK_IMPORTED_MODULE_18__.parseUnitLayoutSize)(this);\n    }\n    parseSelections() {\n        this.component.selection = (0,_selection_parse__WEBPACK_IMPORTED_MODULE_23__.parseUnitSelection)(this, this.selection);\n    }\n    parseMarkGroup() {\n        this.component.mark = (0,_mark_mark__WEBPACK_IMPORTED_MODULE_20__.parseMarkGroups)(this);\n    }\n    parseAxesAndHeaders() {\n        this.component.axes = (0,_axis_parse__WEBPACK_IMPORTED_MODULE_13__.parseUnitAxes)(this);\n    }\n    assembleSelectionTopLevelSignals(signals) {\n        return (0,_selection_assemble__WEBPACK_IMPORTED_MODULE_22__.assembleTopLevelSignals)(this, signals);\n    }\n    assembleSignals() {\n        return [...(0,_axis_assemble__WEBPACK_IMPORTED_MODULE_12__.assembleAxisSignals)(this), ...(0,_selection_assemble__WEBPACK_IMPORTED_MODULE_22__.assembleUnitSelectionSignals)(this, [])];\n    }\n    assembleSelectionData(data) {\n        return (0,_selection_assemble__WEBPACK_IMPORTED_MODULE_22__.assembleUnitSelectionData)(this, data);\n    }\n    assembleLayout() {\n        return null;\n    }\n    assembleLayoutSignals() {\n        return (0,_layoutsize_assemble__WEBPACK_IMPORTED_MODULE_16__.assembleLayoutSignals)(this);\n    }\n    assembleMarks() {\n        let marks = this.component.mark ?? [];\n        // If this unit is part of a layer, selections should augment\n        // all in concert rather than each unit individually. This\n        // ensures correct interleaving of clipping and brushed marks.\n        if (!this.parent || !(0,_model__WEBPACK_IMPORTED_MODULE_21__.isLayerModel)(this.parent)) {\n            marks = (0,_selection_assemble__WEBPACK_IMPORTED_MODULE_22__.assembleUnitSelectionMarks)(this, marks);\n        }\n        return marks.map(this.correctDataNames);\n    }\n    assembleGroupStyle() {\n        const { style } = this.view || {};\n        if (style !== undefined) {\n            return style;\n        }\n        if (this.encoding.x || this.encoding.y) {\n            return 'cell';\n        }\n        else {\n            return 'view';\n        }\n    }\n    getMapping() {\n        return this.encoding;\n    }\n    get mark() {\n        return this.markDef.type;\n    }\n    channelHasField(channel) {\n        return _encoding__WEBPACK_IMPORTED_MODULE_5__.channelHasField(this.encoding, channel);\n    }\n    fieldDef(channel) {\n        const channelDef = this.encoding[channel];\n        return (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldDef)(channelDef);\n    }\n    typedFieldDef(channel) {\n        const fieldDef = this.fieldDef(channel);\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isTypedFieldDef)(fieldDef)) {\n            return fieldDef;\n        }\n        return null;\n    }\n}\n//# sourceMappingURL=unit.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compile/unit.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/base.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/base.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CompositeMarkNormalizer: () => (/* binding */ CompositeMarkNormalizer)\n/* harmony export */ });\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _spec_unit__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../spec/unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n\n\nclass CompositeMarkNormalizer {\n    constructor(name, run) {\n        this.name = name;\n        this.run = run;\n    }\n    hasMatchingType(spec) {\n        if ((0,_spec_unit__WEBPACK_IMPORTED_MODULE_1__.isUnitSpec)(spec)) {\n            return (0,_mark__WEBPACK_IMPORTED_MODULE_0__.getMarkType)(spec.mark) === this.name;\n        }\n        return false;\n    }\n}\n//# sourceMappingURL=base.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/base.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/boxplot.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/boxplot.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BOXPLOT: () => (/* binding */ BOXPLOT),\n/* harmony export */   BOXPLOT_PARTS: () => (/* binding */ BOXPLOT_PARTS),\n/* harmony export */   boxPlotNormalizer: () => (/* binding */ boxPlotNormalizer),\n/* harmony export */   getBoxPlotType: () => (/* binding */ getBoxPlotType),\n/* harmony export */   normalizeBoxPlot: () => (/* binding */ normalizeBoxPlot)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _compile_common__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../compile/common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./base */ \"../../node_modules/vega-lite/build/src/compositemark/base.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compositemark/common.js\");\n\n\n\n\n\n\n\n\nconst BOXPLOT = 'boxplot';\nconst BOXPLOT_PARTS = ['box', 'median', 'outliers', 'rule', 'ticks'];\nconst boxPlotNormalizer = new _base__WEBPACK_IMPORTED_MODULE_6__.CompositeMarkNormalizer(BOXPLOT, normalizeBoxPlot);\nfunction getBoxPlotType(extent) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(extent)) {\n        return 'tukey';\n    }\n    // Ham: If we ever want to, we could add another extent syntax `{kIQR: number}` for the original [Q1-k*IQR, Q3+k*IQR] whisker and call this boxPlotType = `kIQR`. However, I'm not exposing this for now.\n    return extent;\n}\nfunction normalizeBoxPlot(spec, { config }) {\n    // Need to initEncoding first so we can infer type\n    spec = {\n        ...spec,\n        encoding: (0,_encoding__WEBPACK_IMPORTED_MODULE_2__.normalizeEncoding)(spec.encoding, config)\n    };\n    const { mark, encoding: _encoding, params, projection: _p, ...outerSpec } = spec;\n    const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_4__.isMarkDef)(mark) ? mark : { type: mark };\n    // TODO(https://github.com/vega/vega-lite/issues/3702): add selection support\n    if (params) {\n        _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.selectionNotSupported('boxplot'));\n    }\n    const extent = markDef.extent ?? config.boxplot.extent;\n    const sizeValue = (0,_compile_common__WEBPACK_IMPORTED_MODULE_1__.getMarkPropOrConfig)('size', markDef, // TODO: https://github.com/vega/vega-lite/issues/6245\n    config);\n    const invalid = markDef.invalid;\n    const boxPlotType = getBoxPlotType(extent);\n    const { bins, timeUnits, transform, continuousAxisChannelDef, continuousAxis, groupby, aggregate, encodingWithoutContinuousAxis, ticksOrient, boxOrient, customTooltipWithoutAggregatedField } = boxParams(spec, extent, config);\n    const { color, size, ...encodingWithoutSizeColorAndContinuousAxis } = encodingWithoutContinuousAxis;\n    const makeBoxPlotPart = (sharedEncoding) => {\n        return (0,_common__WEBPACK_IMPORTED_MODULE_7__.makeCompositeAggregatePartFactory)(markDef, continuousAxis, continuousAxisChannelDef, sharedEncoding, config.boxplot);\n    };\n    const makeBoxPlotExtent = makeBoxPlotPart(encodingWithoutSizeColorAndContinuousAxis);\n    const makeBoxPlotBox = makeBoxPlotPart(encodingWithoutContinuousAxis);\n    const makeBoxPlotMidTick = makeBoxPlotPart({ ...encodingWithoutSizeColorAndContinuousAxis, ...(size ? { size } : {}) });\n    const fiveSummaryTooltipEncoding = (0,_common__WEBPACK_IMPORTED_MODULE_7__.getCompositeMarkTooltip)([\n        { fieldPrefix: boxPlotType === 'min-max' ? 'upper_whisker_' : 'max_', titlePrefix: 'Max' },\n        { fieldPrefix: 'upper_box_', titlePrefix: 'Q3' },\n        { fieldPrefix: 'mid_box_', titlePrefix: 'Median' },\n        { fieldPrefix: 'lower_box_', titlePrefix: 'Q1' },\n        { fieldPrefix: boxPlotType === 'min-max' ? 'lower_whisker_' : 'min_', titlePrefix: 'Min' }\n    ], continuousAxisChannelDef, encodingWithoutContinuousAxis);\n    // ## Whisker Layers\n    const endTick = { type: 'tick', color: 'black', opacity: 1, orient: ticksOrient, invalid, aria: false };\n    const whiskerTooltipEncoding = boxPlotType === 'min-max'\n        ? fiveSummaryTooltipEncoding // for min-max, show five-summary tooltip for whisker\n        : // for tukey / k-IQR, just show upper/lower-whisker\n            (0,_common__WEBPACK_IMPORTED_MODULE_7__.getCompositeMarkTooltip)([\n                { fieldPrefix: 'upper_whisker_', titlePrefix: 'Upper Whisker' },\n                { fieldPrefix: 'lower_whisker_', titlePrefix: 'Lower Whisker' }\n            ], continuousAxisChannelDef, encodingWithoutContinuousAxis);\n    const whiskerLayers = [\n        ...makeBoxPlotExtent({\n            partName: 'rule',\n            mark: { type: 'rule', invalid, aria: false },\n            positionPrefix: 'lower_whisker',\n            endPositionPrefix: 'lower_box',\n            extraEncoding: whiskerTooltipEncoding\n        }),\n        ...makeBoxPlotExtent({\n            partName: 'rule',\n            mark: { type: 'rule', invalid, aria: false },\n            positionPrefix: 'upper_box',\n            endPositionPrefix: 'upper_whisker',\n            extraEncoding: whiskerTooltipEncoding\n        }),\n        ...makeBoxPlotExtent({\n            partName: 'ticks',\n            mark: endTick,\n            positionPrefix: 'lower_whisker',\n            extraEncoding: whiskerTooltipEncoding\n        }),\n        ...makeBoxPlotExtent({\n            partName: 'ticks',\n            mark: endTick,\n            positionPrefix: 'upper_whisker',\n            extraEncoding: whiskerTooltipEncoding\n        })\n    ];\n    // ## Box Layers\n    // TODO: support hiding certain mark parts\n    const boxLayers = [\n        ...(boxPlotType !== 'tukey' ? whiskerLayers : []),\n        ...makeBoxPlotBox({\n            partName: 'box',\n            mark: {\n                type: 'bar',\n                ...(sizeValue ? { size: sizeValue } : {}),\n                orient: boxOrient,\n                invalid,\n                ariaRoleDescription: 'box'\n            },\n            positionPrefix: 'lower_box',\n            endPositionPrefix: 'upper_box',\n            extraEncoding: fiveSummaryTooltipEncoding\n        }),\n        ...makeBoxPlotMidTick({\n            partName: 'median',\n            mark: {\n                type: 'tick',\n                invalid,\n                ...((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(config.boxplot.median) && config.boxplot.median.color ? { color: config.boxplot.median.color } : {}),\n                ...(sizeValue ? { size: sizeValue } : {}),\n                orient: ticksOrient,\n                aria: false\n            },\n            positionPrefix: 'mid_box',\n            extraEncoding: fiveSummaryTooltipEncoding\n        })\n    ];\n    if (boxPlotType === 'min-max') {\n        return {\n            ...outerSpec,\n            transform: (outerSpec.transform ?? []).concat(transform),\n            layer: boxLayers\n        };\n    }\n    // Tukey Box Plot\n    const lowerBoxExpr = `datum[\"lower_box_${continuousAxisChannelDef.field}\"]`;\n    const upperBoxExpr = `datum[\"upper_box_${continuousAxisChannelDef.field}\"]`;\n    const iqrExpr = `(${upperBoxExpr} - ${lowerBoxExpr})`;\n    const lowerWhiskerExpr = `${lowerBoxExpr} - ${extent} * ${iqrExpr}`;\n    const upperWhiskerExpr = `${upperBoxExpr} + ${extent} * ${iqrExpr}`;\n    const fieldExpr = `datum[\"${continuousAxisChannelDef.field}\"]`;\n    const joinaggregateTransform = {\n        joinaggregate: boxParamsQuartiles(continuousAxisChannelDef.field),\n        groupby\n    };\n    const filteredWhiskerSpec = {\n        transform: [\n            {\n                filter: `(${lowerWhiskerExpr} <= ${fieldExpr}) && (${fieldExpr} <= ${upperWhiskerExpr})`\n            },\n            {\n                aggregate: [\n                    {\n                        op: 'min',\n                        field: continuousAxisChannelDef.field,\n                        as: `lower_whisker_${continuousAxisChannelDef.field}`\n                    },\n                    {\n                        op: 'max',\n                        field: continuousAxisChannelDef.field,\n                        as: `upper_whisker_${continuousAxisChannelDef.field}`\n                    },\n                    // preserve lower_box / upper_box\n                    {\n                        op: 'min',\n                        field: `lower_box_${continuousAxisChannelDef.field}`,\n                        as: `lower_box_${continuousAxisChannelDef.field}`\n                    },\n                    {\n                        op: 'max',\n                        field: `upper_box_${continuousAxisChannelDef.field}`,\n                        as: `upper_box_${continuousAxisChannelDef.field}`\n                    },\n                    ...aggregate\n                ],\n                groupby\n            }\n        ],\n        layer: whiskerLayers\n    };\n    const { tooltip, ...encodingWithoutSizeColorContinuousAxisAndTooltip } = encodingWithoutSizeColorAndContinuousAxis;\n    const { scale, axis } = continuousAxisChannelDef;\n    const title = (0,_common__WEBPACK_IMPORTED_MODULE_7__.getTitle)(continuousAxisChannelDef);\n    const axisWithoutTitle = (0,_util__WEBPACK_IMPORTED_MODULE_5__.omit)(axis, ['title']);\n    const outlierLayersMixins = (0,_common__WEBPACK_IMPORTED_MODULE_7__.partLayerMixins)(markDef, 'outliers', config.boxplot, {\n        transform: [{ filter: `(${fieldExpr} < ${lowerWhiskerExpr}) || (${fieldExpr} > ${upperWhiskerExpr})` }],\n        mark: 'point',\n        encoding: {\n            [continuousAxis]: {\n                field: continuousAxisChannelDef.field,\n                type: continuousAxisChannelDef.type,\n                ...(title !== undefined ? { title } : {}),\n                ...(scale !== undefined ? { scale } : {}),\n                // add axis without title since we already added the title above\n                ...((0,_util__WEBPACK_IMPORTED_MODULE_5__.isEmpty)(axisWithoutTitle) ? {} : { axis: axisWithoutTitle })\n            },\n            ...encodingWithoutSizeColorContinuousAxisAndTooltip,\n            ...(color ? { color } : {}),\n            ...(customTooltipWithoutAggregatedField ? { tooltip: customTooltipWithoutAggregatedField } : {})\n        }\n    })[0];\n    let filteredLayersMixins;\n    const filteredLayersMixinsTransforms = [...bins, ...timeUnits, joinaggregateTransform];\n    if (outlierLayersMixins) {\n        filteredLayersMixins = {\n            transform: filteredLayersMixinsTransforms,\n            layer: [outlierLayersMixins, filteredWhiskerSpec]\n        };\n    }\n    else {\n        filteredLayersMixins = filteredWhiskerSpec;\n        filteredLayersMixins.transform.unshift(...filteredLayersMixinsTransforms);\n    }\n    return {\n        ...outerSpec,\n        layer: [\n            filteredLayersMixins,\n            {\n                // boxplot\n                transform,\n                layer: boxLayers\n            }\n        ]\n    };\n}\nfunction boxParamsQuartiles(continousAxisField) {\n    return [\n        {\n            op: 'q1',\n            field: continousAxisField,\n            as: `lower_box_${continousAxisField}`\n        },\n        {\n            op: 'q3',\n            field: continousAxisField,\n            as: `upper_box_${continousAxisField}`\n        }\n    ];\n}\nfunction boxParams(spec, extent, config) {\n    const orient = (0,_common__WEBPACK_IMPORTED_MODULE_7__.compositeMarkOrient)(spec, BOXPLOT);\n    const { continuousAxisChannelDef, continuousAxis } = (0,_common__WEBPACK_IMPORTED_MODULE_7__.compositeMarkContinuousAxis)(spec, orient, BOXPLOT);\n    const continuousFieldName = continuousAxisChannelDef.field;\n    const boxPlotType = getBoxPlotType(extent);\n    const boxplotSpecificAggregate = [\n        ...boxParamsQuartiles(continuousFieldName),\n        {\n            op: 'median',\n            field: continuousFieldName,\n            as: `mid_box_${continuousFieldName}`\n        },\n        {\n            op: 'min',\n            field: continuousFieldName,\n            as: (boxPlotType === 'min-max' ? 'lower_whisker_' : 'min_') + continuousFieldName\n        },\n        {\n            op: 'max',\n            field: continuousFieldName,\n            as: (boxPlotType === 'min-max' ? 'upper_whisker_' : 'max_') + continuousFieldName\n        }\n    ];\n    const postAggregateCalculates = boxPlotType === 'min-max' || boxPlotType === 'tukey'\n        ? []\n        : [\n            // This is for the  original k-IQR, which we do not expose\n            {\n                calculate: `datum[\"upper_box_${continuousFieldName}\"] - datum[\"lower_box_${continuousFieldName}\"]`,\n                as: `iqr_${continuousFieldName}`\n            },\n            {\n                calculate: `min(datum[\"upper_box_${continuousFieldName}\"] + datum[\"iqr_${continuousFieldName}\"] * ${extent}, datum[\"max_${continuousFieldName}\"])`,\n                as: `upper_whisker_${continuousFieldName}`\n            },\n            {\n                calculate: `max(datum[\"lower_box_${continuousFieldName}\"] - datum[\"iqr_${continuousFieldName}\"] * ${extent}, datum[\"min_${continuousFieldName}\"])`,\n                as: `lower_whisker_${continuousFieldName}`\n            }\n        ];\n    const { [continuousAxis]: oldContinuousAxisChannelDef, ...oldEncodingWithoutContinuousAxis } = spec.encoding;\n    const { customTooltipWithoutAggregatedField, filteredEncoding } = (0,_common__WEBPACK_IMPORTED_MODULE_7__.filterTooltipWithAggregatedField)(oldEncodingWithoutContinuousAxis);\n    const { bins, timeUnits, aggregate, groupby, encoding: encodingWithoutContinuousAxis } = (0,_encoding__WEBPACK_IMPORTED_MODULE_2__.extractTransformsFromEncoding)(filteredEncoding, config);\n    const ticksOrient = orient === 'vertical' ? 'horizontal' : 'vertical';\n    const boxOrient = orient;\n    const transform = [\n        ...bins,\n        ...timeUnits,\n        {\n            aggregate: [...aggregate, ...boxplotSpecificAggregate],\n            groupby\n        },\n        ...postAggregateCalculates\n    ];\n    return {\n        bins,\n        timeUnits,\n        transform,\n        groupby,\n        aggregate,\n        continuousAxisChannelDef,\n        continuousAxis,\n        encodingWithoutContinuousAxis,\n        ticksOrient,\n        boxOrient,\n        customTooltipWithoutAggregatedField\n    };\n}\n//# sourceMappingURL=boxplot.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/boxplot.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/common.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/common.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   compositeMarkContinuousAxis: () => (/* binding */ compositeMarkContinuousAxis),\n/* harmony export */   compositeMarkOrient: () => (/* binding */ compositeMarkOrient),\n/* harmony export */   filterTooltipWithAggregatedField: () => (/* binding */ filterTooltipWithAggregatedField),\n/* harmony export */   getCompositeMarkTooltip: () => (/* binding */ getCompositeMarkTooltip),\n/* harmony export */   getTitle: () => (/* binding */ getTitle),\n/* harmony export */   makeCompositeAggregatePartFactory: () => (/* binding */ makeCompositeAggregatePartFactory),\n/* harmony export */   partLayerMixins: () => (/* binding */ partLayerMixins)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n\n\n\n\n\n\n\n\nfunction filterTooltipWithAggregatedField(oldEncoding) {\n    const { tooltip, ...filteredEncoding } = oldEncoding;\n    if (!tooltip) {\n        return { filteredEncoding };\n    }\n    let customTooltipWithAggregatedField;\n    let customTooltipWithoutAggregatedField;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tooltip)) {\n        for (const t of tooltip) {\n            if (t.aggregate) {\n                if (!customTooltipWithAggregatedField) {\n                    customTooltipWithAggregatedField = [];\n                }\n                customTooltipWithAggregatedField.push(t);\n            }\n            else {\n                if (!customTooltipWithoutAggregatedField) {\n                    customTooltipWithoutAggregatedField = [];\n                }\n                customTooltipWithoutAggregatedField.push(t);\n            }\n        }\n        if (customTooltipWithAggregatedField) {\n            filteredEncoding.tooltip = customTooltipWithAggregatedField;\n        }\n    }\n    else {\n        if (tooltip['aggregate']) {\n            filteredEncoding.tooltip = tooltip;\n        }\n        else {\n            customTooltipWithoutAggregatedField = tooltip;\n        }\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(customTooltipWithoutAggregatedField) && customTooltipWithoutAggregatedField.length === 1) {\n        customTooltipWithoutAggregatedField = customTooltipWithoutAggregatedField[0];\n    }\n    return { customTooltipWithoutAggregatedField, filteredEncoding };\n}\nfunction getCompositeMarkTooltip(tooltipSummary, continuousAxisChannelDef, encodingWithoutContinuousAxis, withFieldName = true) {\n    if ('tooltip' in encodingWithoutContinuousAxis) {\n        return { tooltip: encodingWithoutContinuousAxis.tooltip };\n    }\n    const fiveSummaryTooltip = tooltipSummary.map(({ fieldPrefix, titlePrefix }) => {\n        const mainTitle = withFieldName ? ` of ${getTitle(continuousAxisChannelDef)}` : '';\n        return {\n            field: fieldPrefix + continuousAxisChannelDef.field,\n            type: continuousAxisChannelDef.type,\n            title: (0,_vega_schema__WEBPACK_IMPORTED_MODULE_6__.isSignalRef)(titlePrefix) ? { signal: `${titlePrefix}\"${escape(mainTitle)}\"` } : titlePrefix + mainTitle\n        };\n    });\n    const tooltipFieldDefs = (0,_encoding__WEBPACK_IMPORTED_MODULE_2__.fieldDefs)(encodingWithoutContinuousAxis).map(_channeldef__WEBPACK_IMPORTED_MODULE_1__.toStringFieldDef);\n    return {\n        tooltip: [\n            ...fiveSummaryTooltip,\n            // need to cast because TextFieldDef supports fewer types of bin\n            ...(0,_util__WEBPACK_IMPORTED_MODULE_5__.unique)(tooltipFieldDefs, _util__WEBPACK_IMPORTED_MODULE_5__.hash)\n        ]\n    };\n}\nfunction getTitle(continuousAxisChannelDef) {\n    const { title, field } = continuousAxisChannelDef;\n    return (0,_util__WEBPACK_IMPORTED_MODULE_5__.getFirstDefined)(title, field);\n}\nfunction makeCompositeAggregatePartFactory(compositeMarkDef, continuousAxis, continuousAxisChannelDef, sharedEncoding, compositeMarkConfig) {\n    const { scale, axis } = continuousAxisChannelDef;\n    return ({ partName, mark, positionPrefix, endPositionPrefix = undefined, extraEncoding = {} }) => {\n        const title = getTitle(continuousAxisChannelDef);\n        return partLayerMixins(compositeMarkDef, partName, compositeMarkConfig, {\n            mark,\n            encoding: {\n                [continuousAxis]: {\n                    field: `${positionPrefix}_${continuousAxisChannelDef.field}`,\n                    type: continuousAxisChannelDef.type,\n                    ...(title !== undefined ? { title } : {}),\n                    ...(scale !== undefined ? { scale } : {}),\n                    ...(axis !== undefined ? { axis } : {})\n                },\n                ...((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(endPositionPrefix)\n                    ? {\n                        [`${continuousAxis}2`]: {\n                            field: `${endPositionPrefix}_${continuousAxisChannelDef.field}`\n                        }\n                    }\n                    : {}),\n                ...sharedEncoding,\n                ...extraEncoding\n            }\n        });\n    };\n}\nfunction partLayerMixins(markDef, part, compositeMarkConfig, partBaseSpec) {\n    const { clip, color, opacity } = markDef;\n    const mark = markDef.type;\n    if (markDef[part] || (markDef[part] === undefined && compositeMarkConfig[part])) {\n        return [\n            {\n                ...partBaseSpec,\n                mark: {\n                    ...compositeMarkConfig[part],\n                    ...(clip ? { clip } : {}),\n                    ...(color ? { color } : {}),\n                    ...(opacity ? { opacity } : {}),\n                    ...((0,_mark__WEBPACK_IMPORTED_MODULE_4__.isMarkDef)(partBaseSpec.mark) ? partBaseSpec.mark : { type: partBaseSpec.mark }),\n                    style: `${mark}-${String(part)}`,\n                    ...((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean)(markDef[part]) ? {} : markDef[part])\n                }\n            }\n        ];\n    }\n    return [];\n}\nfunction compositeMarkContinuousAxis(spec, orient, compositeMark) {\n    const { encoding } = spec;\n    const continuousAxis = orient === 'vertical' ? 'y' : 'x';\n    const continuousAxisChannelDef = encoding[continuousAxis]; // Safe to cast because if x is not continuous fielddef, the orient would not be horizontal.\n    const continuousAxisChannelDef2 = encoding[`${continuousAxis}2`];\n    const continuousAxisChannelDefError = encoding[`${continuousAxis}Error`];\n    const continuousAxisChannelDefError2 = encoding[`${continuousAxis}Error2`];\n    return {\n        continuousAxisChannelDef: filterAggregateFromChannelDef(continuousAxisChannelDef, compositeMark),\n        continuousAxisChannelDef2: filterAggregateFromChannelDef(continuousAxisChannelDef2, compositeMark),\n        continuousAxisChannelDefError: filterAggregateFromChannelDef(continuousAxisChannelDefError, compositeMark),\n        continuousAxisChannelDefError2: filterAggregateFromChannelDef(continuousAxisChannelDefError2, compositeMark),\n        continuousAxis\n    };\n}\nfunction filterAggregateFromChannelDef(continuousAxisChannelDef, compositeMark) {\n    if (continuousAxisChannelDef?.aggregate) {\n        const { aggregate, ...continuousAxisWithoutAggregate } = continuousAxisChannelDef;\n        if (aggregate !== compositeMark) {\n            _log__WEBPACK_IMPORTED_MODULE_3__.warn(_log__WEBPACK_IMPORTED_MODULE_3__.message.errorBarContinuousAxisHasCustomizedAggregate(aggregate, compositeMark));\n        }\n        return continuousAxisWithoutAggregate;\n    }\n    else {\n        return continuousAxisChannelDef;\n    }\n}\nfunction compositeMarkOrient(spec, compositeMark) {\n    const { mark, encoding } = spec;\n    const { x, y } = encoding;\n    if ((0,_mark__WEBPACK_IMPORTED_MODULE_4__.isMarkDef)(mark) && mark.orient) {\n        return mark.orient;\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isContinuousFieldOrDatumDef)(x)) {\n        // x is continuous\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isContinuousFieldOrDatumDef)(y)) {\n            // both x and y are continuous\n            const xAggregate = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(x) && x.aggregate;\n            const yAggregate = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(y) && y.aggregate;\n            if (!xAggregate && yAggregate === compositeMark) {\n                return 'vertical';\n            }\n            else if (!yAggregate && xAggregate === compositeMark) {\n                return 'horizontal';\n            }\n            else if (xAggregate === compositeMark && yAggregate === compositeMark) {\n                throw new Error('Both x and y cannot have aggregate');\n            }\n            else {\n                if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldOrDatumDefForTimeFormat)(y) && !(0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldOrDatumDefForTimeFormat)(x)) {\n                    // y is temporal but x is not\n                    return 'horizontal';\n                }\n                // default orientation for two continuous\n                return 'vertical';\n            }\n        }\n        return 'horizontal';\n    }\n    else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isContinuousFieldOrDatumDef)(y)) {\n        // y is continuous but x is not\n        return 'vertical';\n    }\n    else {\n        // Neither x nor y is continuous.\n        throw new Error(`Need a valid continuous axis for ${compositeMark}s`);\n    }\n}\n//# sourceMappingURL=common.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/common.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/errorband.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/errorband.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ERRORBAND: () => (/* binding */ ERRORBAND),\n/* harmony export */   ERRORBAND_PARTS: () => (/* binding */ ERRORBAND_PARTS),\n/* harmony export */   errorBandNormalizer: () => (/* binding */ errorBandNormalizer),\n/* harmony export */   normalizeErrorBand: () => (/* binding */ normalizeErrorBand)\n/* harmony export */ });\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./base */ \"../../node_modules/vega-lite/build/src/compositemark/base.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compositemark/common.js\");\n/* harmony import */ var _errorbar__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./errorbar */ \"../../node_modules/vega-lite/build/src/compositemark/errorbar.js\");\n\n\n\n\n\nconst ERRORBAND = 'errorband';\nconst ERRORBAND_PARTS = ['band', 'borders'];\nconst errorBandNormalizer = new _base__WEBPACK_IMPORTED_MODULE_2__.CompositeMarkNormalizer(ERRORBAND, normalizeErrorBand);\nfunction normalizeErrorBand(spec, { config }) {\n    // Need to initEncoding first so we can infer type\n    spec = {\n        ...spec,\n        encoding: (0,_encoding__WEBPACK_IMPORTED_MODULE_0__.normalizeEncoding)(spec.encoding, config)\n    };\n    const { transform, continuousAxisChannelDef, continuousAxis, encodingWithoutContinuousAxis, markDef, outerSpec, tooltipEncoding } = (0,_errorbar__WEBPACK_IMPORTED_MODULE_4__.errorBarParams)(spec, ERRORBAND, config);\n    const errorBandDef = markDef;\n    const makeErrorBandPart = (0,_common__WEBPACK_IMPORTED_MODULE_3__.makeCompositeAggregatePartFactory)(errorBandDef, continuousAxis, continuousAxisChannelDef, encodingWithoutContinuousAxis, config.errorband);\n    const is2D = spec.encoding.x !== undefined && spec.encoding.y !== undefined;\n    let bandMark = { type: is2D ? 'area' : 'rect' };\n    let bordersMark = { type: is2D ? 'line' : 'rule' };\n    const interpolate = {\n        ...(errorBandDef.interpolate ? { interpolate: errorBandDef.interpolate } : {}),\n        ...(errorBandDef.tension && errorBandDef.interpolate ? { tension: errorBandDef.tension } : {})\n    };\n    if (is2D) {\n        bandMark = {\n            ...bandMark,\n            ...interpolate,\n            ariaRoleDescription: 'errorband'\n        };\n        bordersMark = {\n            ...bordersMark,\n            ...interpolate,\n            aria: false\n        };\n    }\n    else if (errorBandDef.interpolate) {\n        _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.errorBand1DNotSupport('interpolate'));\n    }\n    else if (errorBandDef.tension) {\n        _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.errorBand1DNotSupport('tension'));\n    }\n    return {\n        ...outerSpec,\n        transform,\n        layer: [\n            ...makeErrorBandPart({\n                partName: 'band',\n                mark: bandMark,\n                positionPrefix: 'lower',\n                endPositionPrefix: 'upper',\n                extraEncoding: tooltipEncoding\n            }),\n            ...makeErrorBandPart({\n                partName: 'borders',\n                mark: bordersMark,\n                positionPrefix: 'lower',\n                extraEncoding: tooltipEncoding\n            }),\n            ...makeErrorBandPart({\n                partName: 'borders',\n                mark: bordersMark,\n                positionPrefix: 'upper',\n                extraEncoding: tooltipEncoding\n            })\n        ]\n    };\n}\n//# sourceMappingURL=errorband.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/errorband.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/errorbar.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/errorbar.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ERRORBAR: () => (/* binding */ ERRORBAR),\n/* harmony export */   ERRORBAR_PARTS: () => (/* binding */ ERRORBAR_PARTS),\n/* harmony export */   errorBarNormalizer: () => (/* binding */ errorBarNormalizer),\n/* harmony export */   errorBarParams: () => (/* binding */ errorBarParams),\n/* harmony export */   normalizeErrorBar: () => (/* binding */ normalizeErrorBar)\n/* harmony export */ });\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./base */ \"../../node_modules/vega-lite/build/src/compositemark/base.js\");\n/* harmony import */ var _common__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./common */ \"../../node_modules/vega-lite/build/src/compositemark/common.js\");\n\n\n\n\n\n\n\nconst ERRORBAR = 'errorbar';\nconst ERRORBAR_PARTS = ['ticks', 'rule'];\nconst errorBarNormalizer = new _base__WEBPACK_IMPORTED_MODULE_5__.CompositeMarkNormalizer(ERRORBAR, normalizeErrorBar);\nfunction normalizeErrorBar(spec, { config }) {\n    // Need to initEncoding first so we can infer type\n    spec = {\n        ...spec,\n        encoding: (0,_encoding__WEBPACK_IMPORTED_MODULE_1__.normalizeEncoding)(spec.encoding, config)\n    };\n    const { transform, continuousAxisChannelDef, continuousAxis, encodingWithoutContinuousAxis, ticksOrient, markDef, outerSpec, tooltipEncoding } = errorBarParams(spec, ERRORBAR, config);\n    delete encodingWithoutContinuousAxis['size'];\n    const makeErrorBarPart = (0,_common__WEBPACK_IMPORTED_MODULE_6__.makeCompositeAggregatePartFactory)(markDef, continuousAxis, continuousAxisChannelDef, encodingWithoutContinuousAxis, config.errorbar);\n    const thickness = markDef.thickness;\n    const size = markDef.size;\n    const tick = {\n        type: 'tick',\n        orient: ticksOrient,\n        aria: false,\n        ...(thickness !== undefined ? { thickness } : {}),\n        ...(size !== undefined ? { size } : {})\n    };\n    const layer = [\n        ...makeErrorBarPart({\n            partName: 'ticks',\n            mark: tick,\n            positionPrefix: 'lower',\n            extraEncoding: tooltipEncoding\n        }),\n        ...makeErrorBarPart({\n            partName: 'ticks',\n            mark: tick,\n            positionPrefix: 'upper',\n            extraEncoding: tooltipEncoding\n        }),\n        ...makeErrorBarPart({\n            partName: 'rule',\n            mark: {\n                type: 'rule',\n                ariaRoleDescription: 'errorbar',\n                ...(thickness !== undefined ? { size: thickness } : {})\n            },\n            positionPrefix: 'lower',\n            endPositionPrefix: 'upper',\n            extraEncoding: tooltipEncoding\n        })\n    ];\n    return {\n        ...outerSpec,\n        transform,\n        ...(layer.length > 1 ? { layer } : { ...layer[0] })\n    };\n}\nfunction errorBarOrientAndInputType(spec, compositeMark) {\n    const { encoding } = spec;\n    if (errorBarIsInputTypeRaw(encoding)) {\n        return {\n            orient: (0,_common__WEBPACK_IMPORTED_MODULE_6__.compositeMarkOrient)(spec, compositeMark),\n            inputType: 'raw'\n        };\n    }\n    const isTypeAggregatedUpperLower = errorBarIsInputTypeAggregatedUpperLower(encoding);\n    const isTypeAggregatedError = errorBarIsInputTypeAggregatedError(encoding);\n    const x = encoding.x;\n    const y = encoding.y;\n    if (isTypeAggregatedUpperLower) {\n        // type is aggregated-upper-lower\n        if (isTypeAggregatedError) {\n            throw new Error(`${compositeMark} cannot be both type aggregated-upper-lower and aggregated-error`);\n        }\n        const x2 = encoding.x2;\n        const y2 = encoding.y2;\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(x2) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(y2)) {\n            // having both x, x2 and y, y2\n            throw new Error(`${compositeMark} cannot have both x2 and y2`);\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(x2)) {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isContinuousFieldOrDatumDef)(x)) {\n                // having x, x2 quantitative and field y, y2 are not specified\n                return { orient: 'horizontal', inputType: 'aggregated-upper-lower' };\n            }\n            else {\n                // having x, x2 that are not both quantitative\n                throw new Error(`Both x and x2 have to be quantitative in ${compositeMark}`);\n            }\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(y2)) {\n            // y2 is a FieldDef\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isContinuousFieldOrDatumDef)(y)) {\n                // having y, y2 quantitative and field x, x2 are not specified\n                return { orient: 'vertical', inputType: 'aggregated-upper-lower' };\n            }\n            else {\n                // having y, y2 that are not both quantitative\n                throw new Error(`Both y and y2 have to be quantitative in ${compositeMark}`);\n            }\n        }\n        throw new Error('No ranged axis');\n    }\n    else {\n        // type is aggregated-error\n        const xError = encoding.xError;\n        const xError2 = encoding.xError2;\n        const yError = encoding.yError;\n        const yError2 = encoding.yError2;\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(xError2) && !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(xError)) {\n            // having xError2 without xError\n            throw new Error(`${compositeMark} cannot have xError2 without xError`);\n        }\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(yError2) && !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(yError)) {\n            // having yError2 without yError\n            throw new Error(`${compositeMark} cannot have yError2 without yError`);\n        }\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(xError) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(yError)) {\n            // having both xError and yError\n            throw new Error(`${compositeMark} cannot have both xError and yError with both are quantiative`);\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(xError)) {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isContinuousFieldOrDatumDef)(x)) {\n                // having x and xError that are all quantitative\n                return { orient: 'horizontal', inputType: 'aggregated-error' };\n            }\n            else {\n                // having x, xError, and xError2 that are not all quantitative\n                throw new Error('All x, xError, and xError2 (if exist) have to be quantitative');\n            }\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(yError)) {\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isContinuousFieldOrDatumDef)(y)) {\n                // having y and yError that are all quantitative\n                return { orient: 'vertical', inputType: 'aggregated-error' };\n            }\n            else {\n                // having y, yError, and yError2 that are not all quantitative\n                throw new Error('All y, yError, and yError2 (if exist) have to be quantitative');\n            }\n        }\n        throw new Error('No ranged axis');\n    }\n}\nfunction errorBarIsInputTypeRaw(encoding) {\n    return (((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.x) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.y)) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.x2) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.y2) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.xError) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.xError2) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.yError) &&\n        !(0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.yError2));\n}\nfunction errorBarIsInputTypeAggregatedUpperLower(encoding) {\n    return (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.x2) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.y2);\n}\nfunction errorBarIsInputTypeAggregatedError(encoding) {\n    return ((0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.xError) ||\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.xError2) ||\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.yError) ||\n        (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.isFieldOrDatumDef)(encoding.yError2));\n}\nfunction errorBarParams(spec, compositeMark, config) {\n    // TODO: use selection\n    const { mark, encoding, params, projection: _p, ...outerSpec } = spec;\n    const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_3__.isMarkDef)(mark) ? mark : { type: mark };\n    // TODO(https://github.com/vega/vega-lite/issues/3702): add selection support\n    if (params) {\n        _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.selectionNotSupported(compositeMark));\n    }\n    const { orient, inputType } = errorBarOrientAndInputType(spec, compositeMark);\n    const { continuousAxisChannelDef, continuousAxisChannelDef2, continuousAxisChannelDefError, continuousAxisChannelDefError2, continuousAxis } = (0,_common__WEBPACK_IMPORTED_MODULE_6__.compositeMarkContinuousAxis)(spec, orient, compositeMark);\n    const { errorBarSpecificAggregate, postAggregateCalculates, tooltipSummary, tooltipTitleWithFieldName } = errorBarAggregationAndCalculation(markDef, continuousAxisChannelDef, continuousAxisChannelDef2, continuousAxisChannelDefError, continuousAxisChannelDefError2, inputType, compositeMark, config);\n    const { [continuousAxis]: oldContinuousAxisChannelDef, [continuousAxis === 'x' ? 'x2' : 'y2']: oldContinuousAxisChannelDef2, [continuousAxis === 'x' ? 'xError' : 'yError']: oldContinuousAxisChannelDefError, [continuousAxis === 'x' ? 'xError2' : 'yError2']: oldContinuousAxisChannelDefError2, ...oldEncodingWithoutContinuousAxis } = encoding;\n    const { bins, timeUnits, aggregate: oldAggregate, groupby: oldGroupBy, encoding: encodingWithoutContinuousAxis } = (0,_encoding__WEBPACK_IMPORTED_MODULE_1__.extractTransformsFromEncoding)(oldEncodingWithoutContinuousAxis, config);\n    const aggregate = [...oldAggregate, ...errorBarSpecificAggregate];\n    const groupby = inputType !== 'raw' ? [] : oldGroupBy;\n    const tooltipEncoding = (0,_common__WEBPACK_IMPORTED_MODULE_6__.getCompositeMarkTooltip)(tooltipSummary, continuousAxisChannelDef, encodingWithoutContinuousAxis, tooltipTitleWithFieldName);\n    return {\n        transform: [\n            ...(outerSpec.transform ?? []),\n            ...bins,\n            ...timeUnits,\n            ...(aggregate.length === 0 ? [] : [{ aggregate, groupby }]),\n            ...postAggregateCalculates\n        ],\n        groupby,\n        continuousAxisChannelDef,\n        continuousAxis,\n        encodingWithoutContinuousAxis,\n        ticksOrient: orient === 'vertical' ? 'horizontal' : 'vertical',\n        markDef,\n        outerSpec,\n        tooltipEncoding\n    };\n}\nfunction errorBarAggregationAndCalculation(markDef, continuousAxisChannelDef, continuousAxisChannelDef2, continuousAxisChannelDefError, continuousAxisChannelDefError2, inputType, compositeMark, config) {\n    let errorBarSpecificAggregate = [];\n    let postAggregateCalculates = [];\n    const continuousFieldName = continuousAxisChannelDef.field;\n    let tooltipSummary;\n    let tooltipTitleWithFieldName = false;\n    if (inputType === 'raw') {\n        const center = markDef.center\n            ? markDef.center\n            : markDef.extent\n                ? markDef.extent === 'iqr'\n                    ? 'median'\n                    : 'mean'\n                : config.errorbar.center;\n        const extent = markDef.extent ? markDef.extent : center === 'mean' ? 'stderr' : 'iqr';\n        if ((center === 'median') !== (extent === 'iqr')) {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.errorBarCenterIsUsedWithWrongExtent(center, extent, compositeMark));\n        }\n        if (extent === 'stderr' || extent === 'stdev') {\n            errorBarSpecificAggregate = [\n                { op: extent, field: continuousFieldName, as: `extent_${continuousFieldName}` },\n                { op: center, field: continuousFieldName, as: `center_${continuousFieldName}` }\n            ];\n            postAggregateCalculates = [\n                {\n                    calculate: `datum[\"center_${continuousFieldName}\"] + datum[\"extent_${continuousFieldName}\"]`,\n                    as: `upper_${continuousFieldName}`\n                },\n                {\n                    calculate: `datum[\"center_${continuousFieldName}\"] - datum[\"extent_${continuousFieldName}\"]`,\n                    as: `lower_${continuousFieldName}`\n                }\n            ];\n            tooltipSummary = [\n                { fieldPrefix: 'center_', titlePrefix: (0,_util__WEBPACK_IMPORTED_MODULE_4__.titleCase)(center) },\n                { fieldPrefix: 'upper_', titlePrefix: getTitlePrefix(center, extent, '+') },\n                { fieldPrefix: 'lower_', titlePrefix: getTitlePrefix(center, extent, '-') }\n            ];\n            tooltipTitleWithFieldName = true;\n        }\n        else {\n            let centerOp;\n            let lowerExtentOp;\n            let upperExtentOp;\n            if (extent === 'ci') {\n                centerOp = 'mean';\n                lowerExtentOp = 'ci0';\n                upperExtentOp = 'ci1';\n            }\n            else {\n                centerOp = 'median';\n                lowerExtentOp = 'q1';\n                upperExtentOp = 'q3';\n            }\n            errorBarSpecificAggregate = [\n                { op: lowerExtentOp, field: continuousFieldName, as: `lower_${continuousFieldName}` },\n                { op: upperExtentOp, field: continuousFieldName, as: `upper_${continuousFieldName}` },\n                { op: centerOp, field: continuousFieldName, as: `center_${continuousFieldName}` }\n            ];\n            tooltipSummary = [\n                {\n                    fieldPrefix: 'upper_',\n                    titlePrefix: (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.title)({ field: continuousFieldName, aggregate: upperExtentOp, type: 'quantitative' }, config, {\n                        allowDisabling: false\n                    })\n                },\n                {\n                    fieldPrefix: 'lower_',\n                    titlePrefix: (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.title)({ field: continuousFieldName, aggregate: lowerExtentOp, type: 'quantitative' }, config, {\n                        allowDisabling: false\n                    })\n                },\n                {\n                    fieldPrefix: 'center_',\n                    titlePrefix: (0,_channeldef__WEBPACK_IMPORTED_MODULE_0__.title)({ field: continuousFieldName, aggregate: centerOp, type: 'quantitative' }, config, {\n                        allowDisabling: false\n                    })\n                }\n            ];\n        }\n    }\n    else {\n        if (markDef.center || markDef.extent) {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.errorBarCenterAndExtentAreNotNeeded(markDef.center, markDef.extent));\n        }\n        if (inputType === 'aggregated-upper-lower') {\n            tooltipSummary = [];\n            postAggregateCalculates = [\n                { calculate: `datum[\"${continuousAxisChannelDef2.field}\"]`, as: `upper_${continuousFieldName}` },\n                { calculate: `datum[\"${continuousFieldName}\"]`, as: `lower_${continuousFieldName}` }\n            ];\n        }\n        else if (inputType === 'aggregated-error') {\n            tooltipSummary = [{ fieldPrefix: '', titlePrefix: continuousFieldName }];\n            postAggregateCalculates = [\n                {\n                    calculate: `datum[\"${continuousFieldName}\"] + datum[\"${continuousAxisChannelDefError.field}\"]`,\n                    as: `upper_${continuousFieldName}`\n                }\n            ];\n            if (continuousAxisChannelDefError2) {\n                postAggregateCalculates.push({\n                    calculate: `datum[\"${continuousFieldName}\"] + datum[\"${continuousAxisChannelDefError2.field}\"]`,\n                    as: `lower_${continuousFieldName}`\n                });\n            }\n            else {\n                postAggregateCalculates.push({\n                    calculate: `datum[\"${continuousFieldName}\"] - datum[\"${continuousAxisChannelDefError.field}\"]`,\n                    as: `lower_${continuousFieldName}`\n                });\n            }\n        }\n        for (const postAggregateCalculate of postAggregateCalculates) {\n            tooltipSummary.push({\n                fieldPrefix: postAggregateCalculate.as.substring(0, 6),\n                titlePrefix: (0,_util__WEBPACK_IMPORTED_MODULE_4__.replaceAll)((0,_util__WEBPACK_IMPORTED_MODULE_4__.replaceAll)(postAggregateCalculate.calculate, 'datum[\"', ''), '\"]', '')\n            });\n        }\n    }\n    return { postAggregateCalculates, errorBarSpecificAggregate, tooltipSummary, tooltipTitleWithFieldName };\n}\nfunction getTitlePrefix(center, extent, operation) {\n    return `${(0,_util__WEBPACK_IMPORTED_MODULE_4__.titleCase)(center)} ${operation} ${extent}`;\n}\n//# sourceMappingURL=errorbar.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/errorbar.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/compositemark/index.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/compositemark/index.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   add: () => (/* binding */ add),\n/* harmony export */   getAllCompositeMarks: () => (/* binding */ getAllCompositeMarks),\n/* harmony export */   remove: () => (/* binding */ remove)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/vega-lite/build/src/compositemark/base.js\");\n/* harmony import */ var _boxplot__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./boxplot */ \"../../node_modules/vega-lite/build/src/compositemark/boxplot.js\");\n/* harmony import */ var _errorband__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./errorband */ \"../../node_modules/vega-lite/build/src/compositemark/errorband.js\");\n/* harmony import */ var _errorbar__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./errorbar */ \"../../node_modules/vega-lite/build/src/compositemark/errorbar.js\");\n\n\n\n\n\n/**\n * Registry index for all composite mark's normalizer\n */\nconst compositeMarkRegistry = {};\nfunction add(mark, run, parts) {\n    const normalizer = new _base__WEBPACK_IMPORTED_MODULE_1__.CompositeMarkNormalizer(mark, run);\n    compositeMarkRegistry[mark] = { normalizer, parts };\n}\nfunction remove(mark) {\n    delete compositeMarkRegistry[mark];\n}\nfunction getAllCompositeMarks() {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(compositeMarkRegistry);\n}\nadd(_boxplot__WEBPACK_IMPORTED_MODULE_2__.BOXPLOT, _boxplot__WEBPACK_IMPORTED_MODULE_2__.normalizeBoxPlot, _boxplot__WEBPACK_IMPORTED_MODULE_2__.BOXPLOT_PARTS);\nadd(_errorbar__WEBPACK_IMPORTED_MODULE_4__.ERRORBAR, _errorbar__WEBPACK_IMPORTED_MODULE_4__.normalizeErrorBar, _errorbar__WEBPACK_IMPORTED_MODULE_4__.ERRORBAR_PARTS);\nadd(_errorband__WEBPACK_IMPORTED_MODULE_3__.ERRORBAND, _errorband__WEBPACK_IMPORTED_MODULE_3__.normalizeErrorBand, _errorband__WEBPACK_IMPORTED_MODULE_3__.ERRORBAND_PARTS);\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/compositemark/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/config.js":
/*!********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/config.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DEFAULT_COLOR: () => (/* binding */ DEFAULT_COLOR),\n/* harmony export */   DEFAULT_FONT_SIZE: () => (/* binding */ DEFAULT_FONT_SIZE),\n/* harmony export */   DEFAULT_STEP: () => (/* binding */ DEFAULT_STEP),\n/* harmony export */   colorSignalConfig: () => (/* binding */ colorSignalConfig),\n/* harmony export */   defaultConfig: () => (/* binding */ defaultConfig),\n/* harmony export */   defaultViewConfig: () => (/* binding */ defaultViewConfig),\n/* harmony export */   fontConfig: () => (/* binding */ fontConfig),\n/* harmony export */   fontSizeSignalConfig: () => (/* binding */ fontSizeSignalConfig),\n/* harmony export */   getViewConfigContinuousSize: () => (/* binding */ getViewConfigContinuousSize),\n/* harmony export */   getViewConfigDiscreteSize: () => (/* binding */ getViewConfigDiscreteSize),\n/* harmony export */   getViewConfigDiscreteStep: () => (/* binding */ getViewConfigDiscreteStep),\n/* harmony export */   initConfig: () => (/* binding */ initConfig),\n/* harmony export */   isVgScheme: () => (/* binding */ isVgScheme),\n/* harmony export */   stripAndRedirectConfig: () => (/* binding */ stripAndRedirectConfig)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _axis__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./axis */ \"../../node_modules/vega-lite/build/src/axis.js\");\n/* harmony import */ var _compile_common__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./compile/common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _compositemark__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./compositemark */ \"../../node_modules/vega-lite/build/src/compositemark/index.js\");\n/* harmony import */ var _expr__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./expr */ \"../../node_modules/vega-lite/build/src/expr.js\");\n/* harmony import */ var _guide__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./guide */ \"../../node_modules/vega-lite/build/src/guide.js\");\n/* harmony import */ var _header__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./header */ \"../../node_modules/vega-lite/build/src/header.js\");\n/* harmony import */ var _legend__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./legend */ \"../../node_modules/vega-lite/build/src/legend.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _parameter__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./parameter */ \"../../node_modules/vega-lite/build/src/parameter.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _spec_base__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./spec/base */ \"../../node_modules/vega-lite/build/src/spec/base.js\");\n/* harmony import */ var _title__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./title */ \"../../node_modules/vega-lite/build/src/title.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction getViewConfigContinuousSize(viewConfig, channel) {\n    return viewConfig[channel] ?? viewConfig[channel === 'width' ? 'continuousWidth' : 'continuousHeight']; // get width/height for backwards compatibility\n}\nfunction getViewConfigDiscreteStep(viewConfig, channel) {\n    const size = getViewConfigDiscreteSize(viewConfig, channel);\n    return (0,_spec_base__WEBPACK_IMPORTED_MODULE_13__.isStep)(size) ? size.step : DEFAULT_STEP;\n}\nfunction getViewConfigDiscreteSize(viewConfig, channel) {\n    const size = viewConfig[channel] ?? viewConfig[channel === 'width' ? 'discreteWidth' : 'discreteHeight']; // get width/height for backwards compatibility\n    return (0,_util__WEBPACK_IMPORTED_MODULE_15__.getFirstDefined)(size, { step: viewConfig.step });\n}\nconst DEFAULT_STEP = 20;\nconst defaultViewConfig = {\n    continuousWidth: 200,\n    continuousHeight: 200,\n    step: DEFAULT_STEP\n};\nfunction isVgScheme(rangeScheme) {\n    return rangeScheme && !!rangeScheme['scheme'];\n}\nconst defaultConfig = {\n    background: 'white',\n    padding: 5,\n    timeFormat: '%b %d, %Y',\n    countTitle: 'Count of Records',\n    view: defaultViewConfig,\n    mark: _mark__WEBPACK_IMPORTED_MODULE_9__.defaultMarkConfig,\n    arc: {},\n    area: {},\n    bar: _mark__WEBPACK_IMPORTED_MODULE_9__.defaultBarConfig,\n    circle: {},\n    geoshape: {},\n    image: {},\n    line: {},\n    point: {},\n    rect: _mark__WEBPACK_IMPORTED_MODULE_9__.defaultRectConfig,\n    rule: { color: 'black' },\n    square: {},\n    text: { color: 'black' },\n    tick: _mark__WEBPACK_IMPORTED_MODULE_9__.defaultTickConfig,\n    trail: {},\n    boxplot: {\n        size: 14,\n        extent: 1.5,\n        box: {},\n        median: { color: 'white' },\n        outliers: {},\n        rule: {},\n        ticks: null\n    },\n    errorbar: {\n        center: 'mean',\n        rule: true,\n        ticks: false\n    },\n    errorband: {\n        band: {\n            opacity: 0.3\n        },\n        borders: false\n    },\n    scale: _scale__WEBPACK_IMPORTED_MODULE_11__.defaultScaleConfig,\n    projection: {},\n    legend: _legend__WEBPACK_IMPORTED_MODULE_8__.defaultLegendConfig,\n    header: { titlePadding: 10, labelPadding: 10 },\n    headerColumn: {},\n    headerRow: {},\n    headerFacet: {},\n    selection: _selection__WEBPACK_IMPORTED_MODULE_12__.defaultConfig,\n    style: {},\n    title: {},\n    facet: { spacing: _spec_base__WEBPACK_IMPORTED_MODULE_13__.DEFAULT_SPACING },\n    concat: { spacing: _spec_base__WEBPACK_IMPORTED_MODULE_13__.DEFAULT_SPACING },\n    normalizedNumberFormat: '.0%'\n};\n// Tableau10 color palette, copied from `vegaScale.scheme('tableau10')`\nconst tab10 = [\n    '#4c78a8',\n    '#f58518',\n    '#e45756',\n    '#72b7b2',\n    '#54a24b',\n    '#eeca3b',\n    '#b279a2',\n    '#ff9da6',\n    '#9d755d',\n    '#bab0ac'\n];\nconst DEFAULT_FONT_SIZE = {\n    text: 11,\n    guideLabel: 10,\n    guideTitle: 11,\n    groupTitle: 13,\n    groupSubtitle: 12\n};\nconst DEFAULT_COLOR = {\n    blue: tab10[0],\n    orange: tab10[1],\n    red: tab10[2],\n    teal: tab10[3],\n    green: tab10[4],\n    yellow: tab10[5],\n    purple: tab10[6],\n    pink: tab10[7],\n    brown: tab10[8],\n    gray0: '#000',\n    gray1: '#111',\n    gray2: '#222',\n    gray3: '#333',\n    gray4: '#444',\n    gray5: '#555',\n    gray6: '#666',\n    gray7: '#777',\n    gray8: '#888',\n    gray9: '#999',\n    gray10: '#aaa',\n    gray11: '#bbb',\n    gray12: '#ccc',\n    gray13: '#ddd',\n    gray14: '#eee',\n    gray15: '#fff'\n};\nfunction colorSignalConfig(color = {}) {\n    return {\n        signals: [\n            {\n                name: 'color',\n                value: (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(color) ? { ...DEFAULT_COLOR, ...color } : DEFAULT_COLOR\n            }\n        ],\n        mark: { color: { signal: 'color.blue' } },\n        rule: { color: { signal: 'color.gray0' } },\n        text: {\n            color: { signal: 'color.gray0' }\n        },\n        style: {\n            'guide-label': {\n                fill: { signal: 'color.gray0' }\n            },\n            'guide-title': {\n                fill: { signal: 'color.gray0' }\n            },\n            'group-title': {\n                fill: { signal: 'color.gray0' }\n            },\n            'group-subtitle': {\n                fill: { signal: 'color.gray0' }\n            },\n            cell: {\n                stroke: { signal: 'color.gray8' }\n            }\n        },\n        axis: {\n            domainColor: { signal: 'color.gray13' },\n            gridColor: { signal: 'color.gray8' },\n            tickColor: { signal: 'color.gray13' }\n        },\n        range: {\n            category: [\n                { signal: 'color.blue' },\n                { signal: 'color.orange' },\n                { signal: 'color.red' },\n                { signal: 'color.teal' },\n                { signal: 'color.green' },\n                { signal: 'color.yellow' },\n                { signal: 'color.purple' },\n                { signal: 'color.pink' },\n                { signal: 'color.brown' },\n                { signal: 'color.grey8' }\n            ]\n        }\n    };\n}\nfunction fontSizeSignalConfig(fontSize) {\n    return {\n        signals: [\n            {\n                name: 'fontSize',\n                value: (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(fontSize) ? { ...DEFAULT_FONT_SIZE, ...fontSize } : DEFAULT_FONT_SIZE\n            }\n        ],\n        text: {\n            fontSize: { signal: 'fontSize.text' }\n        },\n        style: {\n            'guide-label': {\n                fontSize: { signal: 'fontSize.guideLabel' }\n            },\n            'guide-title': {\n                fontSize: { signal: 'fontSize.guideTitle' }\n            },\n            'group-title': {\n                fontSize: { signal: 'fontSize.groupTitle' }\n            },\n            'group-subtitle': {\n                fontSize: { signal: 'fontSize.groupSubtitle' }\n            }\n        }\n    };\n}\nfunction fontConfig(font) {\n    return {\n        text: { font },\n        style: {\n            'guide-label': { font },\n            'guide-title': { font },\n            'group-title': { font },\n            'group-subtitle': { font }\n        }\n    };\n}\nfunction getAxisConfigInternal(axisConfig) {\n    const props = (0,_util__WEBPACK_IMPORTED_MODULE_15__.keys)(axisConfig || {});\n    const axisConfigInternal = {};\n    for (const prop of props) {\n        const val = axisConfig[prop];\n        axisConfigInternal[prop] = (0,_axis__WEBPACK_IMPORTED_MODULE_2__.isConditionalAxisValue)(val)\n            ? (0,_compile_common__WEBPACK_IMPORTED_MODULE_3__.signalOrValueRefWithCondition)(val)\n            : (0,_compile_common__WEBPACK_IMPORTED_MODULE_3__.signalRefOrValue)(val);\n    }\n    return axisConfigInternal;\n}\nfunction getStyleConfigInternal(styleConfig) {\n    const props = (0,_util__WEBPACK_IMPORTED_MODULE_15__.keys)(styleConfig);\n    const styleConfigInternal = {};\n    for (const prop of props) {\n        // We need to cast to cheat a bit here since styleConfig can be either mark config or axis config\n        styleConfigInternal[prop] = getAxisConfigInternal(styleConfig[prop]);\n    }\n    return styleConfigInternal;\n}\nconst configPropsWithExpr = [\n    ..._mark__WEBPACK_IMPORTED_MODULE_9__.MARK_CONFIGS,\n    ..._axis__WEBPACK_IMPORTED_MODULE_2__.AXIS_CONFIGS,\n    ..._header__WEBPACK_IMPORTED_MODULE_7__.HEADER_CONFIGS,\n    'background',\n    'padding',\n    'legend',\n    'lineBreak',\n    'scale',\n    'style',\n    'title',\n    'view'\n];\n/**\n * Merge specified config with default config and config for the `color` flag,\n * then replace all expressions with signals\n */\nfunction initConfig(specifiedConfig = {}) {\n    const { color, font, fontSize, selection, ...restConfig } = specifiedConfig;\n    const mergedConfig = (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.mergeConfig)({}, (0,_util__WEBPACK_IMPORTED_MODULE_15__.duplicate)(defaultConfig), font ? fontConfig(font) : {}, color ? colorSignalConfig(color) : {}, fontSize ? fontSizeSignalConfig(fontSize) : {}, restConfig || {});\n    // mergeConfig doesn't recurse and overrides object values.\n    if (selection) {\n        (0,vega__WEBPACK_IMPORTED_MODULE_0__.writeConfig)(mergedConfig, 'selection', selection, true);\n    }\n    const outputConfig = (0,_util__WEBPACK_IMPORTED_MODULE_15__.omit)(mergedConfig, configPropsWithExpr);\n    for (const prop of ['background', 'lineBreak', 'padding']) {\n        if (mergedConfig[prop]) {\n            outputConfig[prop] = (0,_compile_common__WEBPACK_IMPORTED_MODULE_3__.signalRefOrValue)(mergedConfig[prop]);\n        }\n    }\n    for (const markConfigType of _mark__WEBPACK_IMPORTED_MODULE_9__.MARK_CONFIGS) {\n        if (mergedConfig[markConfigType]) {\n            // FIXME: outputConfig[markConfigType] expects that types are replaced recursively but replaceExprRef only replaces one level deep\n            outputConfig[markConfigType] = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig[markConfigType]);\n        }\n    }\n    for (const axisConfigType of _axis__WEBPACK_IMPORTED_MODULE_2__.AXIS_CONFIGS) {\n        if (mergedConfig[axisConfigType]) {\n            outputConfig[axisConfigType] = getAxisConfigInternal(mergedConfig[axisConfigType]);\n        }\n    }\n    for (const headerConfigType of _header__WEBPACK_IMPORTED_MODULE_7__.HEADER_CONFIGS) {\n        if (mergedConfig[headerConfigType]) {\n            outputConfig[headerConfigType] = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig[headerConfigType]);\n        }\n    }\n    if (mergedConfig.legend) {\n        outputConfig.legend = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig.legend);\n    }\n    if (mergedConfig.scale) {\n        outputConfig.scale = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig.scale);\n    }\n    if (mergedConfig.style) {\n        outputConfig.style = getStyleConfigInternal(mergedConfig.style);\n    }\n    if (mergedConfig.title) {\n        outputConfig.title = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig.title);\n    }\n    if (mergedConfig.view) {\n        outputConfig.view = (0,_expr__WEBPACK_IMPORTED_MODULE_5__.replaceExprRef)(mergedConfig.view);\n    }\n    return outputConfig;\n}\nconst MARK_STYLES = new Set(['view', ..._mark__WEBPACK_IMPORTED_MODULE_9__.PRIMITIVE_MARKS]);\nconst VL_ONLY_CONFIG_PROPERTIES = [\n    'color',\n    'fontSize',\n    'background',\n    'padding',\n    'facet',\n    'concat',\n    'numberFormat',\n    'numberFormatType',\n    'normalizedNumberFormat',\n    'normalizedNumberFormatType',\n    'timeFormat',\n    'countTitle',\n    'header',\n    'axisQuantitative',\n    'axisTemporal',\n    'axisDiscrete',\n    'axisPoint',\n    'axisXBand',\n    'axisXPoint',\n    'axisXDiscrete',\n    'axisXQuantitative',\n    'axisXTemporal',\n    'axisYBand',\n    'axisYPoint',\n    'axisYDiscrete',\n    'axisYQuantitative',\n    'axisYTemporal',\n    'scale',\n    'selection',\n    'overlay' // FIXME: Redesign and unhide this\n];\nconst VL_ONLY_ALL_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX = {\n    view: ['continuousWidth', 'continuousHeight', 'discreteWidth', 'discreteHeight', 'step'],\n    ..._mark__WEBPACK_IMPORTED_MODULE_9__.VL_ONLY_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX\n};\nfunction stripAndRedirectConfig(config) {\n    config = (0,_util__WEBPACK_IMPORTED_MODULE_15__.duplicate)(config);\n    for (const prop of VL_ONLY_CONFIG_PROPERTIES) {\n        delete config[prop];\n    }\n    if (config.axis) {\n        // delete condition axis config\n        for (const prop in config.axis) {\n            if ((0,_axis__WEBPACK_IMPORTED_MODULE_2__.isConditionalAxisValue)(config.axis[prop])) {\n                delete config.axis[prop];\n            }\n        }\n    }\n    if (config.legend) {\n        for (const prop of _guide__WEBPACK_IMPORTED_MODULE_6__.VL_ONLY_LEGEND_CONFIG) {\n            delete config.legend[prop];\n        }\n    }\n    // Remove Vega-Lite only generic mark config\n    if (config.mark) {\n        for (const prop of _mark__WEBPACK_IMPORTED_MODULE_9__.VL_ONLY_MARK_CONFIG_PROPERTIES) {\n            delete config.mark[prop];\n        }\n        if (config.mark.tooltip && (0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(config.mark.tooltip)) {\n            delete config.mark.tooltip;\n        }\n    }\n    if (config.params) {\n        config.signals = (config.signals || []).concat((0,_parameter__WEBPACK_IMPORTED_MODULE_10__.assembleParameterSignals)(config.params));\n        delete config.params;\n    }\n    for (const markType of MARK_STYLES) {\n        // Remove Vega-Lite-only mark config\n        for (const prop of _mark__WEBPACK_IMPORTED_MODULE_9__.VL_ONLY_MARK_CONFIG_PROPERTIES) {\n            delete config[markType][prop];\n        }\n        // Remove Vega-Lite only mark-specific config\n        const vlOnlyMarkSpecificConfigs = VL_ONLY_ALL_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX[markType];\n        if (vlOnlyMarkSpecificConfigs) {\n            for (const prop of vlOnlyMarkSpecificConfigs) {\n                delete config[markType][prop];\n            }\n        }\n        // Redirect mark config to config.style so that mark config only affect its own mark type\n        // without affecting other marks that share the same underlying Vega marks.\n        // For example, config.rect should not affect bar marks.\n        redirectConfigToStyleConfig(config, markType);\n    }\n    for (const m of (0,_compositemark__WEBPACK_IMPORTED_MODULE_4__.getAllCompositeMarks)()) {\n        // Clean up the composite mark config as we don't need them in the output specs anymore\n        delete config[m];\n    }\n    redirectTitleConfig(config);\n    // Remove empty config objects.\n    for (const prop in config) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isObject)(config[prop]) && (0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(config[prop])) {\n            delete config[prop];\n        }\n    }\n    return (0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(config) ? undefined : config;\n}\n/**\n *\n * Redirect config.title -- so that title config do not affect header labels,\n * which also uses `title` directive to implement.\n *\n * For subtitle configs in config.title, keep them in config.title as header titles never have subtitles.\n */\nfunction redirectTitleConfig(config) {\n    const { titleMarkConfig, subtitleMarkConfig, subtitle } = (0,_title__WEBPACK_IMPORTED_MODULE_14__.extractTitleConfig)(config.title);\n    // set config.style if title/subtitleMarkConfig is not an empty object\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(titleMarkConfig)) {\n        config.style['group-title'] = {\n            ...config.style['group-title'],\n            ...titleMarkConfig // config.title has higher precedence than config.style.group-title in Vega\n        };\n    }\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(subtitleMarkConfig)) {\n        config.style['group-subtitle'] = {\n            ...config.style['group-subtitle'],\n            ...subtitleMarkConfig\n        };\n    }\n    // subtitle part can stay in config.title since header titles do not use subtitle\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(subtitle)) {\n        config.title = subtitle;\n    }\n    else {\n        delete config.title;\n    }\n}\nfunction redirectConfigToStyleConfig(config, prop, // string = composite mark\ntoProp, compositeMarkPart) {\n    const propConfig = compositeMarkPart ? config[prop][compositeMarkPart] : config[prop];\n    if (prop === 'view') {\n        toProp = 'cell'; // View's default style is \"cell\"\n    }\n    const style = {\n        ...propConfig,\n        ...config.style[toProp ?? prop]\n    };\n    // set config.style if it is not an empty object\n    if (!(0,_util__WEBPACK_IMPORTED_MODULE_15__.isEmpty)(style)) {\n        config.style[toProp ?? prop] = style;\n    }\n    if (!compositeMarkPart) {\n        // For composite mark, so don't delete the whole config yet as we have to do multiple redirections.\n        delete config[prop];\n    }\n}\n//# sourceMappingURL=config.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/config.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/data.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/data.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DataSourceType: () => (/* binding */ DataSourceType),\n/* harmony export */   isGenerator: () => (/* binding */ isGenerator),\n/* harmony export */   isGraticuleGenerator: () => (/* binding */ isGraticuleGenerator),\n/* harmony export */   isInlineData: () => (/* binding */ isInlineData),\n/* harmony export */   isNamedData: () => (/* binding */ isNamedData),\n/* harmony export */   isSequenceGenerator: () => (/* binding */ isSequenceGenerator),\n/* harmony export */   isSphereGenerator: () => (/* binding */ isSphereGenerator),\n/* harmony export */   isUrlData: () => (/* binding */ isUrlData)\n/* harmony export */ });\nfunction isUrlData(data) {\n    return 'url' in data;\n}\nfunction isInlineData(data) {\n    return 'values' in data;\n}\nfunction isNamedData(data) {\n    return 'name' in data && !isUrlData(data) && !isInlineData(data) && !isGenerator(data);\n}\nfunction isGenerator(data) {\n    return data && (isSequenceGenerator(data) || isSphereGenerator(data) || isGraticuleGenerator(data));\n}\nfunction isSequenceGenerator(data) {\n    return 'sequence' in data;\n}\nfunction isSphereGenerator(data) {\n    return 'sphere' in data;\n}\nfunction isGraticuleGenerator(data) {\n    return 'graticule' in data;\n}\nvar DataSourceType;\n(function (DataSourceType) {\n    DataSourceType[DataSourceType[\"Raw\"] = 0] = \"Raw\";\n    DataSourceType[DataSourceType[\"Main\"] = 1] = \"Main\";\n    DataSourceType[DataSourceType[\"Row\"] = 2] = \"Row\";\n    DataSourceType[DataSourceType[\"Column\"] = 3] = \"Column\";\n    DataSourceType[DataSourceType[\"Lookup\"] = 4] = \"Lookup\";\n})(DataSourceType || (DataSourceType = {}));\n//# sourceMappingURL=data.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/data.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/datetime.js":
/*!**********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/datetime.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DAYS: () => (/* binding */ DAYS),\n/* harmony export */   MONTHS: () => (/* binding */ MONTHS),\n/* harmony export */   SHORT_DAYS: () => (/* binding */ SHORT_DAYS),\n/* harmony export */   SHORT_MONTHS: () => (/* binding */ SHORT_MONTHS),\n/* harmony export */   dateTimeExprToExpr: () => (/* binding */ dateTimeExprToExpr),\n/* harmony export */   dateTimeToExpr: () => (/* binding */ dateTimeToExpr),\n/* harmony export */   dateTimeToTimestamp: () => (/* binding */ dateTimeToTimestamp),\n/* harmony export */   isDateTime: () => (/* binding */ isDateTime)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n// DateTime definition object\n\n\n\n\nfunction isDateTime(o) {\n    if (o && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(o)) {\n        for (const part of _timeunit__WEBPACK_IMPORTED_MODULE_2__.TIMEUNIT_PARTS) {\n            if (part in o) {\n                return true;\n            }\n        }\n    }\n    return false;\n}\nconst MONTHS = [\n    'january',\n    'february',\n    'march',\n    'april',\n    'may',\n    'june',\n    'july',\n    'august',\n    'september',\n    'october',\n    'november',\n    'december'\n];\nconst SHORT_MONTHS = MONTHS.map(m => m.substr(0, 3));\nconst DAYS = ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'];\nconst SHORT_DAYS = DAYS.map(d => d.substr(0, 3));\nfunction normalizeQuarter(q) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.isNumeric)(q)) {\n        q = +q;\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(q)) {\n        if (q > 4) {\n            _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.invalidTimeUnit('quarter', q));\n        }\n        // We accept 1-based quarter, so need to readjust to 0-based quarter\n        return q - 1;\n    }\n    else {\n        // Invalid quarter\n        throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.invalidTimeUnit('quarter', q));\n    }\n}\nfunction normalizeMonth(m) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.isNumeric)(m)) {\n        m = +m;\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(m)) {\n        // We accept 1-based month, so need to readjust to 0-based month\n        return m - 1;\n    }\n    else {\n        const lowerM = m.toLowerCase();\n        const monthIndex = MONTHS.indexOf(lowerM);\n        if (monthIndex !== -1) {\n            return monthIndex; // 0 for january, ...\n        }\n        const shortM = lowerM.substr(0, 3);\n        const shortMonthIndex = SHORT_MONTHS.indexOf(shortM);\n        if (shortMonthIndex !== -1) {\n            return shortMonthIndex;\n        }\n        // Invalid month\n        throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.invalidTimeUnit('month', m));\n    }\n}\nfunction normalizeDay(d) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.isNumeric)(d)) {\n        d = +d;\n    }\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(d)) {\n        // mod so that this can be both 0-based where 0 = sunday\n        // and 1-based where 7=sunday\n        return d % 7;\n    }\n    else {\n        const lowerD = d.toLowerCase();\n        const dayIndex = DAYS.indexOf(lowerD);\n        if (dayIndex !== -1) {\n            return dayIndex; // 0 for january, ...\n        }\n        const shortD = lowerD.substr(0, 3);\n        const shortDayIndex = SHORT_DAYS.indexOf(shortD);\n        if (shortDayIndex !== -1) {\n            return shortDayIndex;\n        }\n        // Invalid day\n        throw new Error(_log__WEBPACK_IMPORTED_MODULE_1__.message.invalidTimeUnit('day', d));\n    }\n}\n/**\n * @param d the date.\n * @param normalize whether to normalize quarter, month, day. This should probably be true if d is a DateTime.\n * @returns array of date time parts [year, month, day, hours, minutes, seconds, milliseconds]\n */\nfunction dateTimeParts(d, normalize) {\n    const parts = [];\n    if (normalize && d.day !== undefined) {\n        if ((0,_util__WEBPACK_IMPORTED_MODULE_3__.keys)(d).length > 1) {\n            _log__WEBPACK_IMPORTED_MODULE_1__.warn(_log__WEBPACK_IMPORTED_MODULE_1__.message.droppedDay(d));\n            d = (0,_util__WEBPACK_IMPORTED_MODULE_3__.duplicate)(d);\n            delete d.day;\n        }\n    }\n    if (d.year !== undefined) {\n        parts.push(d.year);\n    }\n    else {\n        // Just like Vega's timeunit transform, set default year to 2012, so domain conversion will be compatible with Vega\n        // Note: 2012 is a leap year (and so the date February 29 is respected) that begins on a Sunday (and so days of the week will order properly at the beginning of the year).\n        parts.push(2012);\n    }\n    if (d.month !== undefined) {\n        const month = normalize ? normalizeMonth(d.month) : d.month;\n        parts.push(month);\n    }\n    else if (d.quarter !== undefined) {\n        const quarter = normalize ? normalizeQuarter(d.quarter) : d.quarter;\n        parts.push((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(quarter) ? quarter * 3 : `${quarter}*3`);\n    }\n    else {\n        parts.push(0); // months start at zero in JS\n    }\n    if (d.date !== undefined) {\n        parts.push(d.date);\n    }\n    else if (d.day !== undefined) {\n        // HACK: Day only works as a standalone unit\n        // This is only correct because we always set year to 2006 for day\n        const day = normalize ? normalizeDay(d.day) : d.day;\n        parts.push((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(day) ? day + 1 : `${day}+1`);\n    }\n    else {\n        parts.push(1); // Date starts at 1 in JS\n    }\n    // Note: can't use TimeUnit enum here as importing it will create\n    // circular dependency problem!\n    for (const timeUnit of ['hours', 'minutes', 'seconds', 'milliseconds']) {\n        const unit = d[timeUnit];\n        parts.push(typeof unit === 'undefined' ? 0 : unit);\n    }\n    return parts;\n}\n/**\n * Return Vega expression for a date time.\n *\n * @param d the date time.\n * @returns the Vega expression.\n */\nfunction dateTimeToExpr(d) {\n    const parts = dateTimeParts(d, true);\n    const string = parts.join(', ');\n    if (d.utc) {\n        return `utc(${string})`;\n    }\n    else {\n        return `datetime(${string})`;\n    }\n}\n/**\n * Return Vega expression for a date time expression.\n *\n * @param d the internal date time object with expression.\n * @returns the Vega expression.\n */\nfunction dateTimeExprToExpr(d) {\n    const parts = dateTimeParts(d, false);\n    const string = parts.join(', ');\n    if (d.utc) {\n        return `utc(${string})`;\n    }\n    else {\n        return `datetime(${string})`;\n    }\n}\n/**\n * @param d the date time.\n * @returns the timestamp.\n */\nfunction dateTimeToTimestamp(d) {\n    const parts = dateTimeParts(d, true);\n    if (d.utc) {\n        return +new Date(Date.UTC(...parts));\n    }\n    else {\n        return +new Date(...parts);\n    }\n}\n//# sourceMappingURL=datetime.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/datetime.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/encoding.js":
/*!**********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/encoding.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   channelHasField: () => (/* binding */ channelHasField),\n/* harmony export */   channelHasFieldOrDatum: () => (/* binding */ channelHasFieldOrDatum),\n/* harmony export */   channelHasNestedOffsetScale: () => (/* binding */ channelHasNestedOffsetScale),\n/* harmony export */   extractTransformsFromEncoding: () => (/* binding */ extractTransformsFromEncoding),\n/* harmony export */   fieldDefs: () => (/* binding */ fieldDefs),\n/* harmony export */   forEach: () => (/* binding */ forEach),\n/* harmony export */   initEncoding: () => (/* binding */ initEncoding),\n/* harmony export */   isAggregate: () => (/* binding */ isAggregate),\n/* harmony export */   markChannelCompatible: () => (/* binding */ markChannelCompatible),\n/* harmony export */   normalizeEncoding: () => (/* binding */ normalizeEncoding),\n/* harmony export */   pathGroupingFields: () => (/* binding */ pathGroupingFields),\n/* harmony export */   reduce: () => (/* binding */ reduce)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n\n\n\n\n\n\n\n\n\n\nfunction channelHasField(encoding, channel) {\n    const channelDef = encoding && encoding[channel];\n    if (channelDef) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef)) {\n            return (0,_util__WEBPACK_IMPORTED_MODULE_7__.some)(channelDef, fieldDef => !!fieldDef.field);\n        }\n        else {\n            return (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.hasConditionalFieldDef)(channelDef);\n        }\n    }\n    return false;\n}\nfunction channelHasFieldOrDatum(encoding, channel) {\n    const channelDef = encoding && encoding[channel];\n    if (channelDef) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef)) {\n            return (0,_util__WEBPACK_IMPORTED_MODULE_7__.some)(channelDef, fieldDef => !!fieldDef.field);\n        }\n        else {\n            return (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isDatumDef)(channelDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.hasConditionalFieldOrDatumDef)(channelDef);\n        }\n    }\n    return false;\n}\nfunction channelHasNestedOffsetScale(encoding, channel) {\n    if ((0,_channel__WEBPACK_IMPORTED_MODULE_3__.isXorY)(channel)) {\n        const fieldDef = encoding[channel];\n        if (((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(fieldDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isDatumDef)(fieldDef)) &&\n            ((0,_type__WEBPACK_IMPORTED_MODULE_6__.isDiscrete)(fieldDef.type) || ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(fieldDef) && fieldDef.timeUnit))) {\n            const offsetChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.getOffsetScaleChannel)(channel);\n            return channelHasFieldOrDatum(encoding, offsetChannel);\n        }\n    }\n    return false;\n}\nfunction isAggregate(encoding) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_7__.some)(_channel__WEBPACK_IMPORTED_MODULE_3__.CHANNELS, channel => {\n        if (channelHasField(encoding, channel)) {\n            const channelDef = encoding[channel];\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef)) {\n                return (0,_util__WEBPACK_IMPORTED_MODULE_7__.some)(channelDef, fieldDef => !!fieldDef.aggregate);\n            }\n            else {\n                const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldDef)(channelDef);\n                return fieldDef && !!fieldDef.aggregate;\n            }\n        }\n        return false;\n    });\n}\nfunction extractTransformsFromEncoding(oldEncoding, config) {\n    const groupby = [];\n    const bins = [];\n    const timeUnits = [];\n    const aggregate = [];\n    const encoding = {};\n    forEach(oldEncoding, (channelDef, channel) => {\n        // Extract potential embedded transformations along with remaining properties\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef)) {\n            const { field, aggregate: aggOp, bin, timeUnit, ...remaining } = channelDef;\n            if (aggOp || timeUnit || bin) {\n                const guide = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getGuide)(channelDef);\n                const isTitleDefined = guide?.title;\n                let newField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(channelDef, { forAs: true });\n                const newFieldDef = {\n                    // Only add title if it doesn't exist\n                    ...(isTitleDefined ? [] : { title: (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.title)(channelDef, config, { allowDisabling: true }) }),\n                    ...remaining,\n                    // Always overwrite field\n                    field: newField\n                };\n                if (aggOp) {\n                    let op;\n                    if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgmaxDef)(aggOp)) {\n                        op = 'argmax';\n                        newField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)({ op: 'argmax', field: aggOp.argmax }, { forAs: true });\n                        newFieldDef.field = `${newField}.${field}`;\n                    }\n                    else if ((0,_aggregate__WEBPACK_IMPORTED_MODULE_1__.isArgminDef)(aggOp)) {\n                        op = 'argmin';\n                        newField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)({ op: 'argmin', field: aggOp.argmin }, { forAs: true });\n                        newFieldDef.field = `${newField}.${field}`;\n                    }\n                    else if (aggOp !== 'boxplot' && aggOp !== 'errorbar' && aggOp !== 'errorband') {\n                        op = aggOp;\n                    }\n                    if (op) {\n                        const aggregateEntry = {\n                            op,\n                            as: newField\n                        };\n                        if (field) {\n                            aggregateEntry.field = field;\n                        }\n                        aggregate.push(aggregateEntry);\n                    }\n                }\n                else {\n                    groupby.push(newField);\n                    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isTypedFieldDef)(channelDef) && (0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinning)(bin)) {\n                        bins.push({ bin, field, as: newField });\n                        // Add additional groupbys for range and end of bins\n                        groupby.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(channelDef, { binSuffix: 'end' }));\n                        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.binRequiresRange)(channelDef, channel)) {\n                            groupby.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(channelDef, { binSuffix: 'range' }));\n                        }\n                        // Create accompanying 'x2' or 'y2' field if channel is 'x' or 'y' respectively\n                        if ((0,_channel__WEBPACK_IMPORTED_MODULE_3__.isXorY)(channel)) {\n                            const secondaryChannel = {\n                                field: `${newField}_end`\n                            };\n                            encoding[`${channel}2`] = secondaryChannel;\n                        }\n                        newFieldDef.bin = 'binned';\n                        if (!(0,_channel__WEBPACK_IMPORTED_MODULE_3__.isSecondaryRangeChannel)(channel)) {\n                            newFieldDef['type'] = _type__WEBPACK_IMPORTED_MODULE_6__.QUANTITATIVE;\n                        }\n                    }\n                    else if (timeUnit && !(0,_timeunit__WEBPACK_IMPORTED_MODULE_9__.isBinnedTimeUnit)(timeUnit)) {\n                        timeUnits.push({\n                            timeUnit,\n                            field,\n                            as: newField\n                        });\n                        // define the format type for later compilation\n                        const formatType = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isTypedFieldDef)(channelDef) && channelDef.type !== _type__WEBPACK_IMPORTED_MODULE_6__.TEMPORAL && 'time';\n                        if (formatType) {\n                            if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.TEXT || channel === _channel__WEBPACK_IMPORTED_MODULE_3__.TOOLTIP) {\n                                newFieldDef['formatType'] = formatType;\n                            }\n                            else if ((0,_channel__WEBPACK_IMPORTED_MODULE_3__.isNonPositionScaleChannel)(channel)) {\n                                newFieldDef['legend'] = {\n                                    formatType,\n                                    ...newFieldDef['legend']\n                                };\n                            }\n                            else if ((0,_channel__WEBPACK_IMPORTED_MODULE_3__.isXorY)(channel)) {\n                                newFieldDef['axis'] = {\n                                    formatType,\n                                    ...newFieldDef['axis']\n                                };\n                            }\n                        }\n                    }\n                }\n                // now the field should refer to post-transformed field instead\n                encoding[channel] = newFieldDef;\n            }\n            else {\n                groupby.push(field);\n                encoding[channel] = oldEncoding[channel];\n            }\n        }\n        else {\n            // For value def / signal ref / datum def, just copy\n            encoding[channel] = oldEncoding[channel];\n        }\n    });\n    return {\n        bins,\n        timeUnits,\n        aggregate,\n        groupby,\n        encoding\n    };\n}\nfunction markChannelCompatible(encoding, channel, mark) {\n    const markSupported = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.supportMark)(channel, mark);\n    if (!markSupported) {\n        return false;\n    }\n    else if (markSupported === 'binned') {\n        const primaryFieldDef = encoding[channel === _channel__WEBPACK_IMPORTED_MODULE_3__.X2 ? _channel__WEBPACK_IMPORTED_MODULE_3__.X : _channel__WEBPACK_IMPORTED_MODULE_3__.Y];\n        // circle, point, square and tick only support x2/y2 when their corresponding x/y fieldDef\n        // has \"binned\" data and thus need x2/y2 to specify the bin-end field.\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(primaryFieldDef) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(encoding[channel]) && (0,_bin__WEBPACK_IMPORTED_MODULE_2__.isBinned)(primaryFieldDef.bin)) {\n            return true;\n        }\n        else {\n            return false;\n        }\n    }\n    return true;\n}\nfunction initEncoding(encoding, mark, filled, config) {\n    const normalizedEncoding = {};\n    for (const key of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(encoding)) {\n        if (!(0,_channel__WEBPACK_IMPORTED_MODULE_3__.isChannel)(key)) {\n            // Drop invalid channel\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.invalidEncodingChannel(key));\n        }\n    }\n    for (let channel of _channel__WEBPACK_IMPORTED_MODULE_3__.UNIT_CHANNELS) {\n        if (!encoding[channel]) {\n            continue;\n        }\n        const channelDef = encoding[channel];\n        if ((0,_channel__WEBPACK_IMPORTED_MODULE_3__.isXorYOffset)(channel)) {\n            const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_3__.getMainChannelFromOffsetChannel)(channel);\n            const positionDef = normalizedEncoding[mainChannel];\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(positionDef)) {\n                if ((0,_type__WEBPACK_IMPORTED_MODULE_6__.isContinuous)(positionDef.type)) {\n                    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef) && !positionDef.timeUnit) {\n                        // TODO: nesting continuous field instead continuous field should\n                        // behave like offsetting the data in data domain\n                        _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.offsetNestedInsideContinuousPositionScaleDropped(mainChannel));\n                        continue;\n                    }\n                }\n            }\n            else {\n                // no x/y, replace it with main channel\n                channel = mainChannel;\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.replaceOffsetWithMainChannel(mainChannel));\n            }\n        }\n        if (channel === 'angle' && mark === 'arc' && !encoding.theta) {\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.REPLACE_ANGLE_WITH_THETA);\n            channel = _channel__WEBPACK_IMPORTED_MODULE_3__.THETA;\n        }\n        if (!markChannelCompatible(encoding, channel, mark)) {\n            // Drop unsupported channel\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.incompatibleChannel(channel, mark));\n            continue;\n        }\n        // Drop line's size if the field is aggregated.\n        if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.SIZE && mark === 'line') {\n            const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldDef)(encoding[channel]);\n            if (fieldDef?.aggregate) {\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.LINE_WITH_VARYING_SIZE);\n                continue;\n            }\n        }\n        // Drop color if either fill or stroke is specified\n        if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.COLOR && (filled ? 'fill' in encoding : 'stroke' in encoding)) {\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.droppingColor('encoding', { fill: 'fill' in encoding, stroke: 'stroke' in encoding }));\n            continue;\n        }\n        if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.DETAIL ||\n            (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.ORDER && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef) && !(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isValueDef)(channelDef)) ||\n            (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.TOOLTIP && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef))) {\n            if (channelDef) {\n                if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.ORDER) {\n                    const def = encoding[channel];\n                    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isOrderOnlyDef)(def)) {\n                        normalizedEncoding[channel] = def;\n                        continue;\n                    }\n                }\n                // Array of fieldDefs for detail channel (or production rule)\n                normalizedEncoding[channel] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(channelDef).reduce((defs, fieldDef) => {\n                    if (!(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(fieldDef)) {\n                        _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.emptyFieldDef(fieldDef, channel));\n                    }\n                    else {\n                        defs.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.initFieldDef)(fieldDef, channel));\n                    }\n                    return defs;\n                }, []);\n            }\n        }\n        else {\n            if (channel === _channel__WEBPACK_IMPORTED_MODULE_3__.TOOLTIP && channelDef === null) {\n                // Preserve null so we can use it to disable tooltip\n                normalizedEncoding[channel] = null;\n            }\n            else if (!(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef) &&\n                !(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isDatumDef)(channelDef) &&\n                !(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isValueDef)(channelDef) &&\n                !(0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isConditionalDef)(channelDef) &&\n                !(0,_vega_schema__WEBPACK_IMPORTED_MODULE_8__.isSignalRef)(channelDef)) {\n                _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.emptyFieldDef(channelDef, channel));\n                continue;\n            }\n            normalizedEncoding[channel] = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.initChannelDef)(channelDef, channel, config);\n        }\n    }\n    return normalizedEncoding;\n}\n/**\n * For composite marks, we have to call initChannelDef during init so we can infer types earlier.\n */\nfunction normalizeEncoding(encoding, config) {\n    const normalizedEncoding = {};\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(encoding)) {\n        const newChannelDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.initChannelDef)(encoding[channel], channel, config, { compositeMark: true });\n        normalizedEncoding[channel] = newChannelDef;\n    }\n    return normalizedEncoding;\n}\nfunction fieldDefs(encoding) {\n    const arr = [];\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(encoding)) {\n        if (channelHasField(encoding, channel)) {\n            const channelDef = encoding[channel];\n            const channelDefArray = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(channelDef);\n            for (const def of channelDefArray) {\n                if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(def)) {\n                    arr.push(def);\n                }\n                else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.hasConditionalFieldDef)(def)) {\n                    arr.push(def.condition);\n                }\n            }\n        }\n    }\n    return arr;\n}\nfunction forEach(mapping, f, thisArg) {\n    if (!mapping) {\n        return;\n    }\n    for (const channel of (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(mapping)) {\n        const el = mapping[channel];\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(el)) {\n            for (const channelDef of el) {\n                f.call(thisArg, channelDef, channel);\n            }\n        }\n        else {\n            f.call(thisArg, el, channel);\n        }\n    }\n}\nfunction reduce(mapping, f, init, thisArg) {\n    if (!mapping) {\n        return init;\n    }\n    return (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(mapping).reduce((r, channel) => {\n        const map = mapping[channel];\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(map)) {\n            return map.reduce((r1, channelDef) => {\n                return f.call(thisArg, r1, channelDef, channel);\n            }, r);\n        }\n        else {\n            return f.call(thisArg, r, map, channel);\n        }\n    }, init);\n}\n/**\n * Returns list of path grouping fields for the given encoding\n */\nfunction pathGroupingFields(mark, encoding) {\n    return (0,_util__WEBPACK_IMPORTED_MODULE_7__.keys)(encoding).reduce((details, channel) => {\n        switch (channel) {\n            // x, y, x2, y2, lat, long, lat1, long2, order, tooltip, href, aria label, cursor should not cause lines to group\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.X:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.Y:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.HREF:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.DESCRIPTION:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.URL:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.X2:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.Y2:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.XOFFSET:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.YOFFSET:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.THETA:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.THETA2:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.RADIUS:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.RADIUS2:\n            // falls through\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.LATITUDE:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.LONGITUDE:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.LATITUDE2:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.LONGITUDE2:\n            // TODO: case 'cursor':\n            // text, shape, shouldn't be a part of line/trail/area [falls through]\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.TEXT:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.SHAPE:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.ANGLE:\n            // falls through\n            // tooltip fields should not be added to group by [falls through]\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.TOOLTIP:\n                return details;\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.ORDER:\n                // order should not group line / trail\n                if (mark === 'line' || mark === 'trail') {\n                    return details;\n                }\n            // but order should group area for stacking (falls through)\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.DETAIL:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.KEY: {\n                const channelDef = encoding[channel];\n                if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.isFieldDef)(channelDef)) {\n                    for (const fieldDef of (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(channelDef)) {\n                        if (!fieldDef.aggregate) {\n                            details.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDef, {}));\n                        }\n                    }\n                }\n                return details;\n            }\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.SIZE:\n                if (mark === 'trail') {\n                    // For trail, size should not group trail lines.\n                    return details;\n                }\n            // For line, size should group lines.\n            // falls through\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.COLOR:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.FILL:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKE:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.OPACITY:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.FILLOPACITY:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEOPACITY:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEDASH:\n            case _channel__WEBPACK_IMPORTED_MODULE_3__.STROKEWIDTH: {\n                // TODO strokeDashOffset:\n                // falls through\n                const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.getFieldDef)(encoding[channel]);\n                if (fieldDef && !fieldDef.aggregate) {\n                    details.push((0,_channeldef__WEBPACK_IMPORTED_MODULE_4__.vgField)(fieldDef, {}));\n                }\n                return details;\n            }\n        }\n    }, []);\n}\n//# sourceMappingURL=encoding.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/encoding.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/expr.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/expr.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isExprRef: () => (/* binding */ isExprRef),\n/* harmony export */   replaceExprRef: () => (/* binding */ replaceExprRef)\n/* harmony export */ });\n/* harmony import */ var _compile_common__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./compile/common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\nfunction isExprRef(o) {\n    return !!o?.expr;\n}\nfunction replaceExprRef(index) {\n    const props = (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(index || {});\n    const newIndex = {};\n    for (const prop of props) {\n        newIndex[prop] = (0,_compile_common__WEBPACK_IMPORTED_MODULE_0__.signalRefOrValue)(index[prop]);\n    }\n    return newIndex;\n}\n//# sourceMappingURL=expr.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/expr.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/guide.js":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/guide.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   VL_ONLY_LEGEND_CONFIG: () => (/* binding */ VL_ONLY_LEGEND_CONFIG)\n/* harmony export */ });\nconst VL_ONLY_LEGEND_CONFIG = [\n    'gradientHorizontalMaxLength',\n    'gradientHorizontalMinLength',\n    'gradientVerticalMaxLength',\n    'gradientVerticalMinLength',\n    'unselectedOpacity'\n];\n//# sourceMappingURL=guide.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/guide.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/header.js":
/*!********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/header.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   HEADER_CONFIGS: () => (/* binding */ HEADER_CONFIGS),\n/* harmony export */   HEADER_LABEL_PROPERTIES: () => (/* binding */ HEADER_LABEL_PROPERTIES),\n/* harmony export */   HEADER_LABEL_PROPERTIES_MAP: () => (/* binding */ HEADER_LABEL_PROPERTIES_MAP),\n/* harmony export */   HEADER_TITLE_PROPERTIES: () => (/* binding */ HEADER_TITLE_PROPERTIES),\n/* harmony export */   HEADER_TITLE_PROPERTIES_MAP: () => (/* binding */ HEADER_TITLE_PROPERTIES_MAP)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\nconst HEADER_TITLE_PROPERTIES_MAP = {\n    titleAlign: 'align',\n    titleAnchor: 'anchor',\n    titleAngle: 'angle',\n    titleBaseline: 'baseline',\n    titleColor: 'color',\n    titleFont: 'font',\n    titleFontSize: 'fontSize',\n    titleFontStyle: 'fontStyle',\n    titleFontWeight: 'fontWeight',\n    titleLimit: 'limit',\n    titleLineHeight: 'lineHeight',\n    titleOrient: 'orient',\n    titlePadding: 'offset'\n};\nconst HEADER_LABEL_PROPERTIES_MAP = {\n    labelAlign: 'align',\n    labelAnchor: 'anchor',\n    labelAngle: 'angle',\n    labelBaseline: 'baseline',\n    labelColor: 'color',\n    labelFont: 'font',\n    labelFontSize: 'fontSize',\n    labelFontStyle: 'fontStyle',\n    labelFontWeight: 'fontWeight',\n    labelLimit: 'limit',\n    labelLineHeight: 'lineHeight',\n    labelOrient: 'orient',\n    labelPadding: 'offset'\n};\nconst HEADER_TITLE_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(HEADER_TITLE_PROPERTIES_MAP);\nconst HEADER_LABEL_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(HEADER_LABEL_PROPERTIES_MAP);\nconst HEADER_CONFIGS_INDEX = {\n    header: 1,\n    headerRow: 1,\n    headerColumn: 1,\n    headerFacet: 1\n};\nconst HEADER_CONFIGS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(HEADER_CONFIGS_INDEX);\n//# sourceMappingURL=header.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/header.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/index.js":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/index.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   accessPathDepth: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.accessPathDepth),\n/* harmony export */   accessPathWithDatum: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.accessPathWithDatum),\n/* harmony export */   compile: () => (/* reexport safe */ _compile_compile__WEBPACK_IMPORTED_MODULE_1__.compile),\n/* harmony export */   contains: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.contains),\n/* harmony export */   deepEqual: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.deepEqual),\n/* harmony export */   deleteNestedProperty: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.deleteNestedProperty),\n/* harmony export */   duplicate: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.duplicate),\n/* harmony export */   entries: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.entries),\n/* harmony export */   every: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.every),\n/* harmony export */   fieldIntersection: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.fieldIntersection),\n/* harmony export */   flatAccessWithDatum: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.flatAccessWithDatum),\n/* harmony export */   getFirstDefined: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.getFirstDefined),\n/* harmony export */   hasIntersection: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.hasIntersection),\n/* harmony export */   hash: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.hash),\n/* harmony export */   internalField: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.internalField),\n/* harmony export */   isBoolean: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isBoolean),\n/* harmony export */   isEmpty: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isEmpty),\n/* harmony export */   isEqual: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isEqual),\n/* harmony export */   isInternalField: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isInternalField),\n/* harmony export */   isNullOrFalse: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isNullOrFalse),\n/* harmony export */   isNumeric: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.isNumeric),\n/* harmony export */   keys: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.keys),\n/* harmony export */   logicalExpr: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.logicalExpr),\n/* harmony export */   mergeDeep: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.mergeDeep),\n/* harmony export */   never: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.never),\n/* harmony export */   normalize: () => (/* reexport safe */ _normalize__WEBPACK_IMPORTED_MODULE_2__.normalize),\n/* harmony export */   normalizeAngle: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.normalizeAngle),\n/* harmony export */   omit: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.omit),\n/* harmony export */   pick: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.pick),\n/* harmony export */   prefixGenerator: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.prefixGenerator),\n/* harmony export */   removePathFromField: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.removePathFromField),\n/* harmony export */   replaceAll: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.replaceAll),\n/* harmony export */   replacePathInField: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.replacePathInField),\n/* harmony export */   resetIdCounter: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.resetIdCounter),\n/* harmony export */   setEqual: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.setEqual),\n/* harmony export */   some: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.some),\n/* harmony export */   stringify: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.stringify),\n/* harmony export */   titleCase: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.titleCase),\n/* harmony export */   unique: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.unique),\n/* harmony export */   uniqueId: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.uniqueId),\n/* harmony export */   vals: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.vals),\n/* harmony export */   varName: () => (/* reexport safe */ _util__WEBPACK_IMPORTED_MODULE_3__.varName),\n/* harmony export */   version: () => (/* binding */ version)\n/* harmony export */ });\n/* harmony import */ var _package_json__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../package.json */ \"../../node_modules/vega-lite/build/package.json\");\n/* harmony import */ var _compile_compile__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./compile/compile */ \"../../node_modules/vega-lite/build/src/compile/compile.js\");\n/* harmony import */ var _normalize__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./normalize */ \"../../node_modules/vega-lite/build/src/normalize/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\nconst version = _package_json__WEBPACK_IMPORTED_MODULE_0__.version;\n\n\n\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/legend.js":
/*!********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/legend.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   COMMON_LEGEND_PROPERTY_INDEX: () => (/* binding */ COMMON_LEGEND_PROPERTY_INDEX),\n/* harmony export */   LEGEND_PROPERTIES: () => (/* binding */ LEGEND_PROPERTIES),\n/* harmony export */   LEGEND_SCALE_CHANNELS: () => (/* binding */ LEGEND_SCALE_CHANNELS),\n/* harmony export */   defaultLegendConfig: () => (/* binding */ defaultLegendConfig)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\nconst LEGEND_SCALE_CHANNELS = [\n    'size',\n    'shape',\n    'fill',\n    'stroke',\n    'strokeDash',\n    'strokeWidth',\n    'opacity'\n];\nconst defaultLegendConfig = {\n    gradientHorizontalMaxLength: 200,\n    gradientHorizontalMinLength: 100,\n    gradientVerticalMaxLength: 200,\n    gradientVerticalMinLength: 64,\n    unselectedOpacity: 0.35\n};\nconst COMMON_LEGEND_PROPERTY_INDEX = {\n    aria: 1,\n    clipHeight: 1,\n    columnPadding: 1,\n    columns: 1,\n    cornerRadius: 1,\n    description: 1,\n    direction: 1,\n    fillColor: 1,\n    format: 1,\n    formatType: 1,\n    gradientLength: 1,\n    gradientOpacity: 1,\n    gradientStrokeColor: 1,\n    gradientStrokeWidth: 1,\n    gradientThickness: 1,\n    gridAlign: 1,\n    labelAlign: 1,\n    labelBaseline: 1,\n    labelColor: 1,\n    labelFont: 1,\n    labelFontSize: 1,\n    labelFontStyle: 1,\n    labelFontWeight: 1,\n    labelLimit: 1,\n    labelOffset: 1,\n    labelOpacity: 1,\n    labelOverlap: 1,\n    labelPadding: 1,\n    labelSeparation: 1,\n    legendX: 1,\n    legendY: 1,\n    offset: 1,\n    orient: 1,\n    padding: 1,\n    rowPadding: 1,\n    strokeColor: 1,\n    symbolDash: 1,\n    symbolDashOffset: 1,\n    symbolFillColor: 1,\n    symbolLimit: 1,\n    symbolOffset: 1,\n    symbolOpacity: 1,\n    symbolSize: 1,\n    symbolStrokeColor: 1,\n    symbolStrokeWidth: 1,\n    symbolType: 1,\n    tickCount: 1,\n    tickMinStep: 1,\n    title: 1,\n    titleAlign: 1,\n    titleAnchor: 1,\n    titleBaseline: 1,\n    titleColor: 1,\n    titleFont: 1,\n    titleFontSize: 1,\n    titleFontStyle: 1,\n    titleFontWeight: 1,\n    titleLimit: 1,\n    titleLineHeight: 1,\n    titleOpacity: 1,\n    titleOrient: 1,\n    titlePadding: 1,\n    type: 1,\n    values: 1,\n    zindex: 1\n};\nconst LEGEND_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(COMMON_LEGEND_PROPERTY_INDEX);\n//# sourceMappingURL=legend.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/legend.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/log/index.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/log/index.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   LocalLogger: () => (/* binding */ LocalLogger),\n/* harmony export */   debug: () => (/* binding */ debug),\n/* harmony export */   error: () => (/* binding */ error),\n/* harmony export */   info: () => (/* binding */ info),\n/* harmony export */   message: () => (/* reexport module object */ _message__WEBPACK_IMPORTED_MODULE_1__),\n/* harmony export */   reset: () => (/* binding */ reset),\n/* harmony export */   set: () => (/* binding */ set),\n/* harmony export */   warn: () => (/* binding */ warn),\n/* harmony export */   wrap: () => (/* binding */ wrap)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _message__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./message */ \"../../node_modules/vega-lite/build/src/log/message.js\");\n/**\n * Vega-Lite's singleton logger utility.\n */\nvar __classPrivateFieldSet = (undefined && undefined.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {\n    if (kind === \"m\") throw new TypeError(\"Private method is not writable\");\n    if (kind === \"a\" && !f) throw new TypeError(\"Private accessor was defined without a setter\");\n    if (typeof state === \"function\" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError(\"Cannot write private member to an object whose class did not declare it\");\n    return (kind === \"a\" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;\n};\nvar __classPrivateFieldGet = (undefined && undefined.__classPrivateFieldGet) || function (receiver, state, kind, f) {\n    if (kind === \"a\" && !f) throw new TypeError(\"Private accessor was defined without a getter\");\n    if (typeof state === \"function\" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError(\"Cannot read private member from an object whose class did not declare it\");\n    return kind === \"m\" ? f : kind === \"a\" ? f.call(receiver) : f ? f.value : state.get(receiver);\n};\nvar _LocalLogger_level;\n\n\n/**\n * Main (default) Vega Logger instance for Vega-Lite.\n */\nconst main = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.logger)(vega_util__WEBPACK_IMPORTED_MODULE_0__.Warn);\nlet current = main;\n/**\n * Logger tool for checking if the code throws correct warning.\n */\nclass LocalLogger {\n    constructor() {\n        this.warns = [];\n        this.infos = [];\n        this.debugs = [];\n        _LocalLogger_level.set(this, vega_util__WEBPACK_IMPORTED_MODULE_0__.Warn);\n    }\n    level(_) {\n        if (_) {\n            __classPrivateFieldSet(this, _LocalLogger_level, _, \"f\");\n            return this;\n        }\n        return __classPrivateFieldGet(this, _LocalLogger_level, \"f\");\n    }\n    warn(...args) {\n        if (__classPrivateFieldGet(this, _LocalLogger_level, \"f\") >= vega_util__WEBPACK_IMPORTED_MODULE_0__.Warn)\n            this.warns.push(...args);\n        return this;\n    }\n    info(...args) {\n        if (__classPrivateFieldGet(this, _LocalLogger_level, \"f\") >= vega_util__WEBPACK_IMPORTED_MODULE_0__.Info)\n            this.infos.push(...args);\n        return this;\n    }\n    debug(...args) {\n        if (__classPrivateFieldGet(this, _LocalLogger_level, \"f\") >= vega_util__WEBPACK_IMPORTED_MODULE_0__.Debug)\n            this.debugs.push(...args);\n        return this;\n    }\n    error(...args) {\n        if (__classPrivateFieldGet(this, _LocalLogger_level, \"f\") >= vega_util__WEBPACK_IMPORTED_MODULE_0__.Error)\n            throw Error(...args);\n        return this;\n    }\n}\n_LocalLogger_level = new WeakMap();\nfunction wrap(f) {\n    return () => {\n        current = new LocalLogger();\n        f(current);\n        reset();\n    };\n}\n/**\n * Set the singleton logger to be a custom logger.\n */\nfunction set(newLogger) {\n    current = newLogger;\n    return current;\n}\n/**\n * Reset the main logger to use the default Vega Logger.\n */\nfunction reset() {\n    current = main;\n    return current;\n}\nfunction error(...args) {\n    current.error(...args);\n}\nfunction warn(...args) {\n    current.warn(...args);\n}\nfunction info(...args) {\n    current.info(...args);\n}\nfunction debug(...args) {\n    current.debug(...args);\n}\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/log/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/log/message.js":
/*!*************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/log/message.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ADD_SAME_CHILD_TWICE: () => (/* binding */ ADD_SAME_CHILD_TWICE),\n/* harmony export */   CANNOT_UNION_CUSTOM_DOMAIN_WITH_FIELD_DOMAIN: () => (/* binding */ CANNOT_UNION_CUSTOM_DOMAIN_WITH_FIELD_DOMAIN),\n/* harmony export */   CONCAT_CANNOT_SHARE_AXIS: () => (/* binding */ CONCAT_CANNOT_SHARE_AXIS),\n/* harmony export */   FACETED_INDEPENDENT_DIFFERENT_SOURCES: () => (/* binding */ FACETED_INDEPENDENT_DIFFERENT_SOURCES),\n/* harmony export */   FACETED_INDEPENDENT_SAME_FIELDS_DIFFERENT_SOURCES: () => (/* binding */ FACETED_INDEPENDENT_SAME_FIELDS_DIFFERENT_SOURCES),\n/* harmony export */   FACETED_INDEPENDENT_SAME_SOURCE: () => (/* binding */ FACETED_INDEPENDENT_SAME_SOURCE),\n/* harmony export */   FIT_NON_SINGLE: () => (/* binding */ FIT_NON_SINGLE),\n/* harmony export */   INTERVAL_INITIALIZED_WITH_POS: () => (/* binding */ INTERVAL_INITIALIZED_WITH_POS),\n/* harmony export */   INVALID_CHANNEL_FOR_AXIS: () => (/* binding */ INVALID_CHANNEL_FOR_AXIS),\n/* harmony export */   LEGEND_BINDINGS_MUST_HAVE_PROJECTION: () => (/* binding */ LEGEND_BINDINGS_MUST_HAVE_PROJECTION),\n/* harmony export */   LINE_WITH_VARYING_SIZE: () => (/* binding */ LINE_WITH_VARYING_SIZE),\n/* harmony export */   MORE_THAN_ONE_SORT: () => (/* binding */ MORE_THAN_ONE_SORT),\n/* harmony export */   NEEDS_SAME_SELECTION: () => (/* binding */ NEEDS_SAME_SELECTION),\n/* harmony export */   NO_FIELDS_NEEDS_AS: () => (/* binding */ NO_FIELDS_NEEDS_AS),\n/* harmony export */   REPLACE_ANGLE_WITH_THETA: () => (/* binding */ REPLACE_ANGLE_WITH_THETA),\n/* harmony export */   SCALE_BINDINGS_CONTINUOUS: () => (/* binding */ SCALE_BINDINGS_CONTINUOUS),\n/* harmony export */   cannotApplySizeToNonOrientedMark: () => (/* binding */ cannotApplySizeToNonOrientedMark),\n/* harmony export */   cannotLookupVariableParameter: () => (/* binding */ cannotLookupVariableParameter),\n/* harmony export */   cannotProjectAggregate: () => (/* binding */ cannotProjectAggregate),\n/* harmony export */   cannotProjectOnChannelWithoutField: () => (/* binding */ cannotProjectOnChannelWithoutField),\n/* harmony export */   cannotStackNonLinearScale: () => (/* binding */ cannotStackNonLinearScale),\n/* harmony export */   cannotStackRangedMark: () => (/* binding */ cannotStackRangedMark),\n/* harmony export */   cannotUseRelativeBandSizeWithNonBandScale: () => (/* binding */ cannotUseRelativeBandSizeWithNonBandScale),\n/* harmony export */   cannotUseScalePropertyWithNonColor: () => (/* binding */ cannotUseScalePropertyWithNonColor),\n/* harmony export */   channelRequiredForBinned: () => (/* binding */ channelRequiredForBinned),\n/* harmony export */   channelShouldBeDiscrete: () => (/* binding */ channelShouldBeDiscrete),\n/* harmony export */   channelShouldBeDiscreteOrDiscretizing: () => (/* binding */ channelShouldBeDiscreteOrDiscretizing),\n/* harmony export */   channelShouldNotBeUsedForBinned: () => (/* binding */ channelShouldNotBeUsedForBinned),\n/* harmony export */   columnsNotSupportByRowCol: () => (/* binding */ columnsNotSupportByRowCol),\n/* harmony export */   containerSizeNonSingle: () => (/* binding */ containerSizeNonSingle),\n/* harmony export */   containerSizeNotCompatibleWithAutosize: () => (/* binding */ containerSizeNotCompatibleWithAutosize),\n/* harmony export */   customFormatTypeNotAllowed: () => (/* binding */ customFormatTypeNotAllowed),\n/* harmony export */   differentParse: () => (/* binding */ differentParse),\n/* harmony export */   discreteChannelCannotEncode: () => (/* binding */ discreteChannelCannotEncode),\n/* harmony export */   domainRequiredForThresholdScale: () => (/* binding */ domainRequiredForThresholdScale),\n/* harmony export */   domainSortDropped: () => (/* binding */ domainSortDropped),\n/* harmony export */   droppedDay: () => (/* binding */ droppedDay),\n/* harmony export */   droppingColor: () => (/* binding */ droppingColor),\n/* harmony export */   droppingFit: () => (/* binding */ droppingFit),\n/* harmony export */   emptyFieldDef: () => (/* binding */ emptyFieldDef),\n/* harmony export */   errorBand1DNotSupport: () => (/* binding */ errorBand1DNotSupport),\n/* harmony export */   errorBarCenterAndExtentAreNotNeeded: () => (/* binding */ errorBarCenterAndExtentAreNotNeeded),\n/* harmony export */   errorBarCenterIsUsedWithWrongExtent: () => (/* binding */ errorBarCenterIsUsedWithWrongExtent),\n/* harmony export */   errorBarContinuousAxisHasCustomizedAggregate: () => (/* binding */ errorBarContinuousAxisHasCustomizedAggregate),\n/* harmony export */   facetChannelDropped: () => (/* binding */ facetChannelDropped),\n/* harmony export */   incompatibleChannel: () => (/* binding */ incompatibleChannel),\n/* harmony export */   independentScaleMeansIndependentGuide: () => (/* binding */ independentScaleMeansIndependentGuide),\n/* harmony export */   invalidAggregate: () => (/* binding */ invalidAggregate),\n/* harmony export */   invalidEncodingChannel: () => (/* binding */ invalidEncodingChannel),\n/* harmony export */   invalidFieldType: () => (/* binding */ invalidFieldType),\n/* harmony export */   invalidFieldTypeForCountAggregate: () => (/* binding */ invalidFieldTypeForCountAggregate),\n/* harmony export */   invalidSpec: () => (/* binding */ invalidSpec),\n/* harmony export */   invalidTimeUnit: () => (/* binding */ invalidTimeUnit),\n/* harmony export */   invalidTransformIgnored: () => (/* binding */ invalidTransformIgnored),\n/* harmony export */   lineWithRange: () => (/* binding */ lineWithRange),\n/* harmony export */   mergeConflictingDomainProperty: () => (/* binding */ mergeConflictingDomainProperty),\n/* harmony export */   mergeConflictingProperty: () => (/* binding */ mergeConflictingProperty),\n/* harmony export */   missingFieldType: () => (/* binding */ missingFieldType),\n/* harmony export */   nearestNotSupportForContinuous: () => (/* binding */ nearestNotSupportForContinuous),\n/* harmony export */   noSameUnitLookup: () => (/* binding */ noSameUnitLookup),\n/* harmony export */   noSuchRepeatedValue: () => (/* binding */ noSuchRepeatedValue),\n/* harmony export */   offsetEncodingScaleIgnored: () => (/* binding */ offsetEncodingScaleIgnored),\n/* harmony export */   offsetNestedInsideContinuousPositionScaleDropped: () => (/* binding */ offsetNestedInsideContinuousPositionScaleDropped),\n/* harmony export */   orientOverridden: () => (/* binding */ orientOverridden),\n/* harmony export */   primitiveChannelDef: () => (/* binding */ primitiveChannelDef),\n/* harmony export */   projectionOverridden: () => (/* binding */ projectionOverridden),\n/* harmony export */   rangeMarkAlignmentCannotBeExpression: () => (/* binding */ rangeMarkAlignmentCannotBeExpression),\n/* harmony export */   relativeBandSizeNotSupported: () => (/* binding */ relativeBandSizeNotSupported),\n/* harmony export */   replaceOffsetWithMainChannel: () => (/* binding */ replaceOffsetWithMainChannel),\n/* harmony export */   scalePropertyNotWorkWithScaleType: () => (/* binding */ scalePropertyNotWorkWithScaleType),\n/* harmony export */   scaleTypeNotWorkWithChannel: () => (/* binding */ scaleTypeNotWorkWithChannel),\n/* harmony export */   scaleTypeNotWorkWithFieldDef: () => (/* binding */ scaleTypeNotWorkWithFieldDef),\n/* harmony export */   scaleTypeNotWorkWithMark: () => (/* binding */ scaleTypeNotWorkWithMark),\n/* harmony export */   selectionNotFound: () => (/* binding */ selectionNotFound),\n/* harmony export */   selectionNotSupported: () => (/* binding */ selectionNotSupported),\n/* harmony export */   stackNonSummativeAggregate: () => (/* binding */ stackNonSummativeAggregate),\n/* harmony export */   stepDropped: () => (/* binding */ stepDropped),\n/* harmony export */   unaggregateDomainHasNoEffectForRawField: () => (/* binding */ unaggregateDomainHasNoEffectForRawField),\n/* harmony export */   unaggregateDomainWithNonSharedDomainOp: () => (/* binding */ unaggregateDomainWithNonSharedDomainOp),\n/* harmony export */   unaggregatedDomainWithLogScale: () => (/* binding */ unaggregatedDomainWithLogScale),\n/* harmony export */   unknownField: () => (/* binding */ unknownField),\n/* harmony export */   unrecognizedParse: () => (/* binding */ unrecognizedParse)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\nfunction invalidSpec(spec) {\n    return `Invalid specification ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(spec)}. Make sure the specification includes at least one of the following properties: \"mark\", \"layer\", \"facet\", \"hconcat\", \"vconcat\", \"concat\", or \"repeat\".`;\n}\n// FIT\nconst FIT_NON_SINGLE = 'Autosize \"fit\" only works for single views and layered views.';\nfunction containerSizeNonSingle(name) {\n    const uName = name == 'width' ? 'Width' : 'Height';\n    return `${uName} \"container\" only works for single views and layered views.`;\n}\nfunction containerSizeNotCompatibleWithAutosize(name) {\n    const uName = name == 'width' ? 'Width' : 'Height';\n    const fitDirection = name == 'width' ? 'x' : 'y';\n    return `${uName} \"container\" only works well with autosize \"fit\" or \"fit-${fitDirection}\".`;\n}\nfunction droppingFit(channel) {\n    return channel\n        ? `Dropping \"fit-${channel}\" because spec has discrete ${(0,_channel__WEBPACK_IMPORTED_MODULE_0__.getSizeChannel)(channel)}.`\n        : `Dropping \"fit\" because spec has discrete size.`;\n}\n// VIEW SIZE\nfunction unknownField(channel) {\n    return `Unknown field for ${channel}. Cannot calculate view size.`;\n}\n// SELECTION\nfunction cannotProjectOnChannelWithoutField(channel) {\n    return `Cannot project a selection on encoding channel \"${channel}\", which has no field.`;\n}\nfunction cannotProjectAggregate(channel, aggregate) {\n    return `Cannot project a selection on encoding channel \"${channel}\" as it uses an aggregate function (\"${aggregate}\").`;\n}\nfunction nearestNotSupportForContinuous(mark) {\n    return `The \"nearest\" transform is not supported for ${mark} marks.`;\n}\nfunction selectionNotSupported(mark) {\n    return `Selection not supported for ${mark} yet.`;\n}\nfunction selectionNotFound(name) {\n    return `Cannot find a selection named \"${name}\".`;\n}\nconst SCALE_BINDINGS_CONTINUOUS = 'Scale bindings are currently only supported for scales with unbinned, continuous domains.';\nconst LEGEND_BINDINGS_MUST_HAVE_PROJECTION = 'Legend bindings are only supported for selections over an individual field or encoding channel.';\nfunction cannotLookupVariableParameter(name) {\n    return `Lookups can only be performed on selection parameters. \"${name}\" is a variable parameter.`;\n}\nfunction noSameUnitLookup(name) {\n    return (`Cannot define and lookup the \"${name}\" selection in the same view. ` +\n        `Try moving the lookup into a second, layered view?`);\n}\nconst NEEDS_SAME_SELECTION = 'The same selection must be used to override scale domains in a layered view.';\nconst INTERVAL_INITIALIZED_WITH_POS = 'Interval selections should be initialized using \"x\", \"y\", \"longitude\", or \"latitude\" keys.';\n// REPEAT\nfunction noSuchRepeatedValue(field) {\n    return `Unknown repeated value \"${field}\".`;\n}\nfunction columnsNotSupportByRowCol(type) {\n    return `The \"columns\" property cannot be used when \"${type}\" has nested row/column.`;\n}\n// CONCAT / REPEAT\nconst CONCAT_CANNOT_SHARE_AXIS = 'Axes cannot be shared in concatenated or repeated views yet (https://github.com/vega/vega-lite/issues/2415).';\n// DATA\nfunction unrecognizedParse(p) {\n    return `Unrecognized parse \"${p}\".`;\n}\nfunction differentParse(field, local, ancestor) {\n    return `An ancestor parsed field \"${field}\" as ${ancestor} but a child wants to parse the field as ${local}.`;\n}\nconst ADD_SAME_CHILD_TWICE = 'Attempt to add the same child twice.';\n// TRANSFORMS\nfunction invalidTransformIgnored(transform) {\n    return `Ignoring an invalid transform: ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(transform)}.`;\n}\nconst NO_FIELDS_NEEDS_AS = 'If \"from.fields\" is not specified, \"as\" has to be a string that specifies the key to be used for the data from the secondary source.';\n// ENCODING & FACET\nfunction customFormatTypeNotAllowed(channel) {\n    return `Config.customFormatTypes is not true, thus custom format type and format for channel ${channel} are dropped.`;\n}\nfunction projectionOverridden(opt) {\n    const { parentProjection, projection } = opt;\n    return `Layer's shared projection ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(parentProjection)} is overridden by a child projection ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(projection)}.`;\n}\nconst REPLACE_ANGLE_WITH_THETA = 'Arc marks uses theta channel rather than angle, replacing angle with theta.';\nfunction offsetNestedInsideContinuousPositionScaleDropped(mainChannel) {\n    return `${mainChannel}Offset dropped because ${mainChannel} is continuous`;\n}\nfunction replaceOffsetWithMainChannel(mainChannel) {\n    return `There is no ${mainChannel} encoding. Replacing ${mainChannel}Offset encoding as ${mainChannel}.`;\n}\nfunction primitiveChannelDef(channel, type, value) {\n    return `Channel ${channel} is a ${type}. Converted to {value: ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(value)}}.`;\n}\nfunction invalidFieldType(type) {\n    return `Invalid field type \"${type}\".`;\n}\nfunction invalidFieldTypeForCountAggregate(type, aggregate) {\n    return `Invalid field type \"${type}\" for aggregate: \"${aggregate}\", using \"quantitative\" instead.`;\n}\nfunction invalidAggregate(aggregate) {\n    return `Invalid aggregation operator \"${aggregate}\".`;\n}\nfunction missingFieldType(channel, newType) {\n    return `Missing type for channel \"${channel}\", using \"${newType}\" instead.`;\n}\nfunction droppingColor(type, opt) {\n    const { fill, stroke } = opt;\n    return `Dropping color ${type} as the plot also has ${fill && stroke ? 'fill and stroke' : fill ? 'fill' : 'stroke'}.`;\n}\nfunction relativeBandSizeNotSupported(sizeChannel) {\n    return `Position range does not support relative band size for ${sizeChannel}.`;\n}\nfunction emptyFieldDef(fieldDef, channel) {\n    return `Dropping ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(fieldDef)} from channel \"${channel}\" since it does not contain any data field, datum, value, or signal.`;\n}\nconst LINE_WITH_VARYING_SIZE = 'Line marks cannot encode size with a non-groupby field. You may want to use trail marks instead.';\nfunction incompatibleChannel(channel, markOrFacet, when) {\n    return `${channel} dropped as it is incompatible with \"${markOrFacet}\"${when ? ` when ${when}` : ''}.`;\n}\nfunction offsetEncodingScaleIgnored(channel) {\n    return `${channel} encoding has no scale, so specified scale is ignored.`;\n}\nfunction invalidEncodingChannel(channel) {\n    return `${channel}-encoding is dropped as ${channel} is not a valid encoding channel.`;\n}\nfunction channelShouldBeDiscrete(channel) {\n    return `${channel} encoding should be discrete (ordinal / nominal / binned).`;\n}\nfunction channelShouldBeDiscreteOrDiscretizing(channel) {\n    return `${channel} encoding should be discrete (ordinal / nominal / binned) or use a discretizing scale (e.g. threshold).`;\n}\nfunction facetChannelDropped(channels) {\n    return `Facet encoding dropped as ${channels.join(' and ')} ${channels.length > 1 ? 'are' : 'is'} also specified.`;\n}\nfunction discreteChannelCannotEncode(channel, type) {\n    return `Using discrete channel \"${channel}\" to encode \"${type}\" field can be misleading as it does not encode ${type === 'ordinal' ? 'order' : 'magnitude'}.`;\n}\n// MARK\nfunction rangeMarkAlignmentCannotBeExpression(align) {\n    return `The ${align} for range marks cannot be an expression`;\n}\nfunction lineWithRange(hasX2, hasY2) {\n    const channels = hasX2 && hasY2 ? 'x2 and y2' : hasX2 ? 'x2' : 'y2';\n    return `Line mark is for continuous lines and thus cannot be used with ${channels}. We will use the rule mark (line segments) instead.`;\n}\nfunction orientOverridden(original, actual) {\n    return `Specified orient \"${original}\" overridden with \"${actual}\".`;\n}\n// SCALE\nconst CANNOT_UNION_CUSTOM_DOMAIN_WITH_FIELD_DOMAIN = 'Custom domain scale cannot be unioned with default field-based domain.';\nfunction cannotUseScalePropertyWithNonColor(prop) {\n    return `Cannot use the scale property \"${prop}\" with non-color channel.`;\n}\nfunction cannotUseRelativeBandSizeWithNonBandScale(scaleType) {\n    return `Cannot use the relative band size with ${scaleType} scale.`;\n}\nfunction unaggregateDomainHasNoEffectForRawField(fieldDef) {\n    return `Using unaggregated domain with raw field has no effect (${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(fieldDef)}).`;\n}\nfunction unaggregateDomainWithNonSharedDomainOp(aggregate) {\n    return `Unaggregated domain not applicable for \"${aggregate}\" since it produces values outside the origin domain of the source data.`;\n}\nfunction unaggregatedDomainWithLogScale(fieldDef) {\n    return `Unaggregated domain is currently unsupported for log scale (${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(fieldDef)}).`;\n}\nfunction cannotApplySizeToNonOrientedMark(mark) {\n    return `Cannot apply size to non-oriented mark \"${mark}\".`;\n}\nfunction scaleTypeNotWorkWithChannel(channel, scaleType, defaultScaleType) {\n    return `Channel \"${channel}\" does not work with \"${scaleType}\" scale. We are using \"${defaultScaleType}\" scale instead.`;\n}\nfunction scaleTypeNotWorkWithFieldDef(scaleType, defaultScaleType) {\n    return `FieldDef does not work with \"${scaleType}\" scale. We are using \"${defaultScaleType}\" scale instead.`;\n}\nfunction scalePropertyNotWorkWithScaleType(scaleType, propName, channel) {\n    return `${channel}-scale's \"${propName}\" is dropped as it does not work with ${scaleType} scale.`;\n}\nfunction scaleTypeNotWorkWithMark(mark, scaleType) {\n    return `Scale type \"${scaleType}\" does not work with mark \"${mark}\".`;\n}\nfunction stepDropped(channel) {\n    return `The step for \"${channel}\" is dropped because the ${channel === 'width' ? 'x' : 'y'} is continuous.`;\n}\nfunction mergeConflictingProperty(property, propertyOf, v1, v2) {\n    return `Conflicting ${propertyOf.toString()} property \"${property.toString()}\" (${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(v1)} and ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(v2)}). Using ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(v1)}.`;\n}\nfunction mergeConflictingDomainProperty(property, propertyOf, v1, v2) {\n    return `Conflicting ${propertyOf.toString()} property \"${property.toString()}\" (${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(v1)} and ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(v2)}). Using the union of the two domains.`;\n}\nfunction independentScaleMeansIndependentGuide(channel) {\n    return `Setting the scale to be independent for \"${channel}\" means we also have to set the guide (axis or legend) to be independent.`;\n}\nfunction domainSortDropped(sort) {\n    return `Dropping sort property ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(sort)} as unioned domains only support boolean or op \"count\", \"min\", and \"max\".`;\n}\nconst MORE_THAN_ONE_SORT = 'Domains that should be unioned has conflicting sort properties. Sort will be set to true.';\nconst FACETED_INDEPENDENT_DIFFERENT_SOURCES = 'Detected faceted independent scales that union domain of multiple fields from different data sources. We will use the first field. The result view size may be incorrect.';\nconst FACETED_INDEPENDENT_SAME_FIELDS_DIFFERENT_SOURCES = 'Detected faceted independent scales that union domain of the same fields from different source. We will assume that this is the same field from a different fork of the same data source. However, if this is not the case, the result view size may be incorrect.';\nconst FACETED_INDEPENDENT_SAME_SOURCE = 'Detected faceted independent scales that union domain of multiple fields from the same data source. We will use the first field. The result view size may be incorrect.';\n// AXIS\nconst INVALID_CHANNEL_FOR_AXIS = 'Invalid channel for axis.';\n// STACK\nfunction cannotStackRangedMark(channel) {\n    return `Cannot stack \"${channel}\" if there is already \"${channel}2\".`;\n}\nfunction cannotStackNonLinearScale(scaleType) {\n    return `Cannot stack non-linear scale (${scaleType}).`;\n}\nfunction stackNonSummativeAggregate(aggregate) {\n    return `Stacking is applied even though the aggregate function is non-summative (\"${aggregate}\").`;\n}\n// TIMEUNIT\nfunction invalidTimeUnit(unitName, value) {\n    return `Invalid ${unitName}: ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(value)}.`;\n}\nfunction droppedDay(d) {\n    return `Dropping day from datetime ${(0,_util__WEBPACK_IMPORTED_MODULE_1__.stringify)(d)} as day cannot be combined with other units.`;\n}\nfunction errorBarCenterAndExtentAreNotNeeded(center, extent) {\n    return `${extent ? 'extent ' : ''}${extent && center ? 'and ' : ''}${center ? 'center ' : ''}${extent && center ? 'are ' : 'is '}not needed when data are aggregated.`;\n}\nfunction errorBarCenterIsUsedWithWrongExtent(center, extent, mark) {\n    return `${center} is not usually used with ${extent} for ${mark}.`;\n}\nfunction errorBarContinuousAxisHasCustomizedAggregate(aggregate, compositeMark) {\n    return `Continuous axis should not have customized aggregation function ${aggregate}; ${compositeMark} already agregates the axis.`;\n}\nfunction errorBand1DNotSupport(property) {\n    return `1D error band does not support ${property}.`;\n}\n// CHANNEL\nfunction channelRequiredForBinned(channel) {\n    return `Channel ${channel} is required for \"binned\" bin.`;\n}\nfunction channelShouldNotBeUsedForBinned(channel) {\n    return `Channel ${channel} should not be used with \"binned\" bin.`;\n}\nfunction domainRequiredForThresholdScale(channel) {\n    return `Domain for ${channel} is required for threshold scale.`;\n}\n//# sourceMappingURL=message.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/log/message.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/logical.js":
/*!*********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/logical.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   forEachLeaf: () => (/* binding */ forEachLeaf),\n/* harmony export */   isLogicalAnd: () => (/* binding */ isLogicalAnd),\n/* harmony export */   isLogicalNot: () => (/* binding */ isLogicalNot),\n/* harmony export */   isLogicalOr: () => (/* binding */ isLogicalOr),\n/* harmony export */   normalizeLogicalComposition: () => (/* binding */ normalizeLogicalComposition)\n/* harmony export */ });\nfunction isLogicalOr(op) {\n    return !!op.or;\n}\nfunction isLogicalAnd(op) {\n    return !!op.and;\n}\nfunction isLogicalNot(op) {\n    return !!op.not;\n}\nfunction forEachLeaf(op, fn) {\n    if (isLogicalNot(op)) {\n        forEachLeaf(op.not, fn);\n    }\n    else if (isLogicalAnd(op)) {\n        for (const subop of op.and) {\n            forEachLeaf(subop, fn);\n        }\n    }\n    else if (isLogicalOr(op)) {\n        for (const subop of op.or) {\n            forEachLeaf(subop, fn);\n        }\n    }\n    else {\n        fn(op);\n    }\n}\nfunction normalizeLogicalComposition(op, normalizer) {\n    if (isLogicalNot(op)) {\n        return { not: normalizeLogicalComposition(op.not, normalizer) };\n    }\n    else if (isLogicalAnd(op)) {\n        return { and: op.and.map(o => normalizeLogicalComposition(o, normalizer)) };\n    }\n    else if (isLogicalOr(op)) {\n        return { or: op.or.map(o => normalizeLogicalComposition(o, normalizer)) };\n    }\n    else {\n        return normalizer(op);\n    }\n}\n//# sourceMappingURL=logical.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/logical.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/mark.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/mark.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ARC: () => (/* binding */ ARC),\n/* harmony export */   AREA: () => (/* binding */ AREA),\n/* harmony export */   BAR: () => (/* binding */ BAR),\n/* harmony export */   BAR_CORNER_RADIUS_INDEX: () => (/* binding */ BAR_CORNER_RADIUS_INDEX),\n/* harmony export */   CIRCLE: () => (/* binding */ CIRCLE),\n/* harmony export */   FILL_CONFIG: () => (/* binding */ FILL_CONFIG),\n/* harmony export */   FILL_STROKE_CONFIG: () => (/* binding */ FILL_STROKE_CONFIG),\n/* harmony export */   GEOSHAPE: () => (/* binding */ GEOSHAPE),\n/* harmony export */   IMAGE: () => (/* binding */ IMAGE),\n/* harmony export */   LINE: () => (/* binding */ LINE),\n/* harmony export */   MARK_CONFIGS: () => (/* binding */ MARK_CONFIGS),\n/* harmony export */   Mark: () => (/* binding */ Mark),\n/* harmony export */   POINT: () => (/* binding */ POINT),\n/* harmony export */   PRIMITIVE_MARKS: () => (/* binding */ PRIMITIVE_MARKS),\n/* harmony export */   RECT: () => (/* binding */ RECT),\n/* harmony export */   RULE: () => (/* binding */ RULE),\n/* harmony export */   SQUARE: () => (/* binding */ SQUARE),\n/* harmony export */   STROKE_CONFIG: () => (/* binding */ STROKE_CONFIG),\n/* harmony export */   TEXT: () => (/* binding */ TEXT),\n/* harmony export */   TICK: () => (/* binding */ TICK),\n/* harmony export */   TRAIL: () => (/* binding */ TRAIL),\n/* harmony export */   VL_ONLY_MARK_CONFIG_PROPERTIES: () => (/* binding */ VL_ONLY_MARK_CONFIG_PROPERTIES),\n/* harmony export */   VL_ONLY_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX: () => (/* binding */ VL_ONLY_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX),\n/* harmony export */   defaultBarConfig: () => (/* binding */ defaultBarConfig),\n/* harmony export */   defaultMarkConfig: () => (/* binding */ defaultMarkConfig),\n/* harmony export */   defaultRectConfig: () => (/* binding */ defaultRectConfig),\n/* harmony export */   defaultTickConfig: () => (/* binding */ defaultTickConfig),\n/* harmony export */   getMarkType: () => (/* binding */ getMarkType),\n/* harmony export */   isMark: () => (/* binding */ isMark),\n/* harmony export */   isMarkDef: () => (/* binding */ isMarkDef),\n/* harmony export */   isPathMark: () => (/* binding */ isPathMark),\n/* harmony export */   isPrimitiveMark: () => (/* binding */ isPrimitiveMark),\n/* harmony export */   isRectBasedMark: () => (/* binding */ isRectBasedMark),\n/* harmony export */   isRelativeBandSize: () => (/* binding */ isRelativeBandSize)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n/**\n * All types of primitive marks.\n */\nconst Mark = {\n    arc: 'arc',\n    area: 'area',\n    bar: 'bar',\n    image: 'image',\n    line: 'line',\n    point: 'point',\n    rect: 'rect',\n    rule: 'rule',\n    text: 'text',\n    tick: 'tick',\n    trail: 'trail',\n    circle: 'circle',\n    square: 'square',\n    geoshape: 'geoshape'\n};\nconst ARC = Mark.arc;\nconst AREA = Mark.area;\nconst BAR = Mark.bar;\nconst IMAGE = Mark.image;\nconst LINE = Mark.line;\nconst POINT = Mark.point;\nconst RECT = Mark.rect;\nconst RULE = Mark.rule;\nconst TEXT = Mark.text;\nconst TICK = Mark.tick;\nconst TRAIL = Mark.trail;\nconst CIRCLE = Mark.circle;\nconst SQUARE = Mark.square;\nconst GEOSHAPE = Mark.geoshape;\nfunction isMark(m) {\n    return m in Mark;\n}\nfunction isPathMark(m) {\n    return ['line', 'area', 'trail'].includes(m);\n}\nfunction isRectBasedMark(m) {\n    return ['rect', 'bar', 'image', 'arc' /* arc is rect/interval in polar coordinate */].includes(m);\n}\nconst PRIMITIVE_MARKS = new Set((0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(Mark));\nfunction isMarkDef(mark) {\n    return mark['type'];\n}\nfunction isPrimitiveMark(mark) {\n    const markType = isMarkDef(mark) ? mark.type : mark;\n    return PRIMITIVE_MARKS.has(markType);\n}\nconst STROKE_CONFIG = [\n    'stroke',\n    'strokeWidth',\n    'strokeDash',\n    'strokeDashOffset',\n    'strokeOpacity',\n    'strokeJoin',\n    'strokeMiterLimit'\n];\nconst FILL_CONFIG = ['fill', 'fillOpacity'];\nconst FILL_STROKE_CONFIG = [...STROKE_CONFIG, ...FILL_CONFIG];\nconst VL_ONLY_MARK_CONFIG_INDEX = {\n    color: 1,\n    filled: 1,\n    invalid: 1,\n    order: 1,\n    radius2: 1,\n    theta2: 1,\n    timeUnitBandSize: 1,\n    timeUnitBandPosition: 1\n};\nconst VL_ONLY_MARK_CONFIG_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(VL_ONLY_MARK_CONFIG_INDEX);\nconst VL_ONLY_MARK_SPECIFIC_CONFIG_PROPERTY_INDEX = {\n    area: ['line', 'point'],\n    bar: ['binSpacing', 'continuousBandSize', 'discreteBandSize', 'minBandSize'],\n    rect: ['binSpacing', 'continuousBandSize', 'discreteBandSize', 'minBandSize'],\n    line: ['point'],\n    tick: ['bandSize', 'thickness']\n};\nconst defaultMarkConfig = {\n    color: '#4c78a8',\n    invalid: 'filter',\n    timeUnitBandSize: 1\n};\nconst MARK_CONFIG_INDEX = {\n    mark: 1,\n    arc: 1,\n    area: 1,\n    bar: 1,\n    circle: 1,\n    image: 1,\n    line: 1,\n    point: 1,\n    rect: 1,\n    rule: 1,\n    square: 1,\n    text: 1,\n    tick: 1,\n    trail: 1,\n    geoshape: 1\n};\nconst MARK_CONFIGS = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(MARK_CONFIG_INDEX);\nfunction isRelativeBandSize(o) {\n    return o && o['band'] != undefined;\n}\nconst BAR_CORNER_RADIUS_INDEX = {\n    horizontal: ['cornerRadiusTopRight', 'cornerRadiusBottomRight'],\n    vertical: ['cornerRadiusTopLeft', 'cornerRadiusTopRight']\n};\nconst DEFAULT_RECT_BAND_SIZE = 5;\nconst defaultBarConfig = {\n    binSpacing: 1,\n    continuousBandSize: DEFAULT_RECT_BAND_SIZE,\n    minBandSize: 0.25,\n    timeUnitBandPosition: 0.5\n};\nconst defaultRectConfig = {\n    binSpacing: 0,\n    continuousBandSize: DEFAULT_RECT_BAND_SIZE,\n    minBandSize: 0.25,\n    timeUnitBandPosition: 0.5\n};\nconst defaultTickConfig = {\n    thickness: 1\n};\nfunction getMarkType(m) {\n    return isMarkDef(m) ? m.type : m;\n}\n//# sourceMappingURL=mark.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/mark.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/core.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/core.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CoreNormalizer: () => (/* binding */ CoreNormalizer)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _compositemark_boxplot__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../compositemark/boxplot */ \"../../node_modules/vega-lite/build/src/compositemark/boxplot.js\");\n/* harmony import */ var _compositemark_errorband__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../compositemark/errorband */ \"../../node_modules/vega-lite/build/src/compositemark/errorband.js\");\n/* harmony import */ var _compositemark_errorbar__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../compositemark/errorbar */ \"../../node_modules/vega-lite/build/src/compositemark/errorbar.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec_facet__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../spec/facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _spec_map__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../spec/map */ \"../../node_modules/vega-lite/build/src/spec/map.js\");\n/* harmony import */ var _spec_repeat__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../spec/repeat */ \"../../node_modules/vega-lite/build/src/spec/repeat.js\");\n/* harmony import */ var _spec_unit__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../spec/unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n/* harmony import */ var _pathoverlay__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./pathoverlay */ \"../../node_modules/vega-lite/build/src/normalize/pathoverlay.js\");\n/* harmony import */ var _repeater__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./repeater */ \"../../node_modules/vega-lite/build/src/normalize/repeater.js\");\n/* harmony import */ var _ruleforrangedline__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./ruleforrangedline */ \"../../node_modules/vega-lite/build/src/normalize/ruleforrangedline.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nclass CoreNormalizer extends _spec_map__WEBPACK_IMPORTED_MODULE_9__.SpecMapper {\n    constructor() {\n        super(...arguments);\n        this.nonFacetUnitNormalizers = [\n            _compositemark_boxplot__WEBPACK_IMPORTED_MODULE_3__.boxPlotNormalizer,\n            _compositemark_errorbar__WEBPACK_IMPORTED_MODULE_5__.errorBarNormalizer,\n            _compositemark_errorband__WEBPACK_IMPORTED_MODULE_4__.errorBandNormalizer,\n            new _pathoverlay__WEBPACK_IMPORTED_MODULE_14__.PathOverlayNormalizer(),\n            new _ruleforrangedline__WEBPACK_IMPORTED_MODULE_16__.RuleForRangedLineNormalizer()\n        ];\n    }\n    map(spec, params) {\n        // Special handling for a faceted unit spec as it can return a facet spec, not just a layer or unit spec like a normal unit spec.\n        if ((0,_spec_unit__WEBPACK_IMPORTED_MODULE_11__.isUnitSpec)(spec)) {\n            const hasRow = (0,_encoding__WEBPACK_IMPORTED_MODULE_6__.channelHasField)(spec.encoding, _channel__WEBPACK_IMPORTED_MODULE_1__.ROW);\n            const hasColumn = (0,_encoding__WEBPACK_IMPORTED_MODULE_6__.channelHasField)(spec.encoding, _channel__WEBPACK_IMPORTED_MODULE_1__.COLUMN);\n            const hasFacet = (0,_encoding__WEBPACK_IMPORTED_MODULE_6__.channelHasField)(spec.encoding, _channel__WEBPACK_IMPORTED_MODULE_1__.FACET);\n            if (hasRow || hasColumn || hasFacet) {\n                return this.mapFacetedUnit(spec, params);\n            }\n        }\n        return super.map(spec, params);\n    }\n    // This is for normalizing non-facet unit\n    mapUnit(spec, params) {\n        const { parentEncoding, parentProjection } = params;\n        const encoding = (0,_repeater__WEBPACK_IMPORTED_MODULE_15__.replaceRepeaterInEncoding)(spec.encoding, params.repeater);\n        const specWithReplacedEncoding = {\n            ...spec,\n            ...(spec.name ? { name: [params.repeaterPrefix, spec.name].filter(n => n).join('_') } : {}),\n            ...(encoding ? { encoding } : {})\n        };\n        if (parentEncoding || parentProjection) {\n            return this.mapUnitWithParentEncodingOrProjection(specWithReplacedEncoding, params);\n        }\n        const normalizeLayerOrUnit = this.mapLayerOrUnit.bind(this);\n        for (const unitNormalizer of this.nonFacetUnitNormalizers) {\n            if (unitNormalizer.hasMatchingType(specWithReplacedEncoding, params.config)) {\n                return unitNormalizer.run(specWithReplacedEncoding, params, normalizeLayerOrUnit);\n            }\n        }\n        return specWithReplacedEncoding;\n    }\n    mapRepeat(spec, params) {\n        if ((0,_spec_repeat__WEBPACK_IMPORTED_MODULE_10__.isLayerRepeatSpec)(spec)) {\n            return this.mapLayerRepeat(spec, params);\n        }\n        else {\n            return this.mapNonLayerRepeat(spec, params);\n        }\n    }\n    mapLayerRepeat(spec, params) {\n        const { repeat, spec: childSpec, ...rest } = spec;\n        const { row, column, layer } = repeat;\n        const { repeater = {}, repeaterPrefix = '' } = params;\n        if (row || column) {\n            return this.mapRepeat({\n                ...spec,\n                repeat: {\n                    ...(row ? { row } : {}),\n                    ...(column ? { column } : {})\n                },\n                spec: {\n                    repeat: { layer },\n                    spec: childSpec\n                }\n            }, params);\n        }\n        else {\n            return {\n                ...rest,\n                layer: layer.map(layerValue => {\n                    const childRepeater = {\n                        ...repeater,\n                        layer: layerValue\n                    };\n                    const childName = `${(childSpec.name ? `${childSpec.name}_` : '') + repeaterPrefix}child__layer_${(0,_util__WEBPACK_IMPORTED_MODULE_12__.varName)(layerValue)}`;\n                    const child = this.mapLayerOrUnit(childSpec, { ...params, repeater: childRepeater, repeaterPrefix: childName });\n                    child.name = childName;\n                    return child;\n                })\n            };\n        }\n    }\n    mapNonLayerRepeat(spec, params) {\n        const { repeat, spec: childSpec, data, ...remainingProperties } = spec;\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat) && spec.columns) {\n            // is repeat with row/column\n            spec = (0,_util__WEBPACK_IMPORTED_MODULE_12__.omit)(spec, ['columns']);\n            _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.columnsNotSupportByRowCol('repeat'));\n        }\n        const concat = [];\n        const { repeater = {}, repeaterPrefix = '' } = params;\n        const row = (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat) && repeat.row) || [repeater ? repeater.row : null];\n        const column = (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat) && repeat.column) || [repeater ? repeater.column : null];\n        const repeatValues = ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat) && repeat) || [repeater ? repeater.repeat : null];\n        // cross product\n        for (const repeatValue of repeatValues) {\n            for (const rowValue of row) {\n                for (const columnValue of column) {\n                    const childRepeater = {\n                        repeat: repeatValue,\n                        row: rowValue,\n                        column: columnValue,\n                        layer: repeater.layer\n                    };\n                    const childName = (childSpec.name ? `${childSpec.name}_` : '') +\n                        repeaterPrefix +\n                        'child__' +\n                        ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat)\n                            ? `${(0,_util__WEBPACK_IMPORTED_MODULE_12__.varName)(repeatValue)}`\n                            : (repeat.row ? `row_${(0,_util__WEBPACK_IMPORTED_MODULE_12__.varName)(rowValue)}` : '') +\n                                (repeat.column ? `column_${(0,_util__WEBPACK_IMPORTED_MODULE_12__.varName)(columnValue)}` : ''));\n                    const child = this.map(childSpec, { ...params, repeater: childRepeater, repeaterPrefix: childName });\n                    child.name = childName;\n                    // we move data up\n                    concat.push((0,_util__WEBPACK_IMPORTED_MODULE_12__.omit)(child, ['data']));\n                }\n            }\n        }\n        const columns = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(repeat) ? spec.columns : repeat.column ? repeat.column.length : 1;\n        return {\n            data: childSpec.data ?? data,\n            align: 'all',\n            ...remainingProperties,\n            columns,\n            concat\n        };\n    }\n    mapFacet(spec, params) {\n        const { facet } = spec;\n        if ((0,_spec_facet__WEBPACK_IMPORTED_MODULE_8__.isFacetMapping)(facet) && spec.columns) {\n            // is facet with row/column\n            spec = (0,_util__WEBPACK_IMPORTED_MODULE_12__.omit)(spec, ['columns']);\n            _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.columnsNotSupportByRowCol('facet'));\n        }\n        return super.mapFacet(spec, params);\n    }\n    mapUnitWithParentEncodingOrProjection(spec, params) {\n        const { encoding, projection } = spec;\n        const { parentEncoding, parentProjection, config } = params;\n        const mergedProjection = mergeProjection({ parentProjection, projection });\n        const mergedEncoding = mergeEncoding({\n            parentEncoding,\n            encoding: (0,_repeater__WEBPACK_IMPORTED_MODULE_15__.replaceRepeaterInEncoding)(encoding, params.repeater)\n        });\n        return this.mapUnit({\n            ...spec,\n            ...(mergedProjection ? { projection: mergedProjection } : {}),\n            ...(mergedEncoding ? { encoding: mergedEncoding } : {})\n        }, { config });\n    }\n    mapFacetedUnit(spec, normParams) {\n        // New encoding in the inside spec should not contain row / column\n        // as row/column should be moved to facet\n        const { row, column, facet, ...encoding } = spec.encoding;\n        // Mark and encoding should be moved into the inner spec\n        const { mark, width, projection, height, view, params, encoding: _, ...outerSpec } = spec;\n        const { facetMapping, layout } = this.getFacetMappingAndLayout({ row, column, facet }, normParams);\n        const newEncoding = (0,_repeater__WEBPACK_IMPORTED_MODULE_15__.replaceRepeaterInEncoding)(encoding, normParams.repeater);\n        return this.mapFacet({\n            ...outerSpec,\n            ...layout,\n            // row / column has higher precedence than facet\n            facet: facetMapping,\n            spec: {\n                ...(width ? { width } : {}),\n                ...(height ? { height } : {}),\n                ...(view ? { view } : {}),\n                ...(projection ? { projection } : {}),\n                mark,\n                encoding: newEncoding,\n                ...(params ? { params } : {})\n            }\n        }, normParams);\n    }\n    getFacetMappingAndLayout(facets, params) {\n        const { row, column, facet } = facets;\n        if (row || column) {\n            if (facet) {\n                _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.facetChannelDropped([...(row ? [_channel__WEBPACK_IMPORTED_MODULE_1__.ROW] : []), ...(column ? [_channel__WEBPACK_IMPORTED_MODULE_1__.COLUMN] : [])]));\n            }\n            const facetMapping = {};\n            const layout = {};\n            for (const channel of [_channel__WEBPACK_IMPORTED_MODULE_1__.ROW, _channel__WEBPACK_IMPORTED_MODULE_1__.COLUMN]) {\n                const def = facets[channel];\n                if (def) {\n                    const { align, center, spacing, columns, ...defWithoutLayout } = def;\n                    facetMapping[channel] = defWithoutLayout;\n                    for (const prop of ['align', 'center', 'spacing']) {\n                        if (def[prop] !== undefined) {\n                            layout[prop] ?? (layout[prop] = {});\n                            layout[prop][channel] = def[prop];\n                        }\n                    }\n                }\n            }\n            return { facetMapping, layout };\n        }\n        else {\n            const { align, center, spacing, columns, ...facetMapping } = facet;\n            return {\n                facetMapping: (0,_repeater__WEBPACK_IMPORTED_MODULE_15__.replaceRepeaterInFacet)(facetMapping, params.repeater),\n                layout: {\n                    ...(align ? { align } : {}),\n                    ...(center ? { center } : {}),\n                    ...(spacing ? { spacing } : {}),\n                    ...(columns ? { columns } : {})\n                }\n            };\n        }\n    }\n    mapLayer(spec, { parentEncoding, parentProjection, ...otherParams }) {\n        // Special handling for extended layer spec\n        const { encoding, projection, ...rest } = spec;\n        const params = {\n            ...otherParams,\n            parentEncoding: mergeEncoding({ parentEncoding, encoding, layer: true }),\n            parentProjection: mergeProjection({ parentProjection, projection })\n        };\n        return super.mapLayer({\n            ...rest,\n            ...(spec.name ? { name: [params.repeaterPrefix, spec.name].filter(n => n).join('_') } : {})\n        }, params);\n    }\n}\nfunction mergeEncoding({ parentEncoding, encoding = {}, layer }) {\n    let merged = {};\n    if (parentEncoding) {\n        const channels = new Set([...(0,_util__WEBPACK_IMPORTED_MODULE_12__.keys)(parentEncoding), ...(0,_util__WEBPACK_IMPORTED_MODULE_12__.keys)(encoding)]);\n        for (const channel of channels) {\n            const channelDef = encoding[channel];\n            const parentChannelDef = parentEncoding[channel];\n            if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldOrDatumDef)(channelDef)) {\n                // Field/Datum Def can inherit properties from its parent\n                // Note that parentChannelDef doesn't have to be a field/datum def if the channelDef is already one.\n                const mergedChannelDef = {\n                    ...parentChannelDef,\n                    ...channelDef\n                };\n                merged[channel] = mergedChannelDef;\n            }\n            else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.hasConditionalFieldOrDatumDef)(channelDef)) {\n                merged[channel] = {\n                    ...channelDef,\n                    condition: {\n                        ...parentChannelDef,\n                        ...channelDef.condition\n                    }\n                };\n            }\n            else if (channelDef || channelDef === null) {\n                merged[channel] = channelDef;\n            }\n            else if (layer ||\n                (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isValueDef)(parentChannelDef) ||\n                (0,_vega_schema__WEBPACK_IMPORTED_MODULE_13__.isSignalRef)(parentChannelDef) ||\n                (0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldOrDatumDef)(parentChannelDef) ||\n                (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(parentChannelDef)) {\n                merged[channel] = parentChannelDef;\n            }\n        }\n    }\n    else {\n        merged = encoding;\n    }\n    return !merged || (0,_util__WEBPACK_IMPORTED_MODULE_12__.isEmpty)(merged) ? undefined : merged;\n}\nfunction mergeProjection(opt) {\n    const { parentProjection, projection } = opt;\n    if (parentProjection && projection) {\n        _log__WEBPACK_IMPORTED_MODULE_7__.warn(_log__WEBPACK_IMPORTED_MODULE_7__.message.projectionOverridden({ parentProjection, projection }));\n    }\n    return projection ?? parentProjection;\n}\n//# sourceMappingURL=core.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/core.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/index.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/index.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   normalize: () => (/* binding */ normalize),\n/* harmony export */   normalizeAutoSize: () => (/* binding */ normalizeAutoSize)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../config */ \"../../node_modules/vega-lite/build/src/config.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./core */ \"../../node_modules/vega-lite/build/src/normalize/core.js\");\n/* harmony import */ var _selectioncompat__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./selectioncompat */ \"../../node_modules/vega-lite/build/src/normalize/selectioncompat.js\");\n/* harmony import */ var _toplevelselection__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./toplevelselection */ \"../../node_modules/vega-lite/build/src/normalize/toplevelselection.js\");\n\n\n\n\n\n\n\n\nfunction normalize(spec, config) {\n    if (config === undefined) {\n        config = (0,_config__WEBPACK_IMPORTED_MODULE_1__.initConfig)(spec.config);\n    }\n    const normalizedSpec = normalizeGenericSpec(spec, config);\n    const { width, height } = spec;\n    const autosize = normalizeAutoSize(normalizedSpec, { width, height, autosize: spec.autosize }, config);\n    return {\n        ...normalizedSpec,\n        ...(autosize ? { autosize } : {})\n    };\n}\nconst coreNormalizer = new _core__WEBPACK_IMPORTED_MODULE_5__.CoreNormalizer();\nconst selectionCompatNormalizer = new _selectioncompat__WEBPACK_IMPORTED_MODULE_6__.SelectionCompatibilityNormalizer();\nconst topLevelSelectionNormalizer = new _toplevelselection__WEBPACK_IMPORTED_MODULE_7__.TopLevelSelectionsNormalizer();\n/**\n * Decompose extended unit specs into composition of pure unit specs.\n * And push top-level selection definitions down to unit specs.\n */\nfunction normalizeGenericSpec(spec, config = {}) {\n    const normParams = { config };\n    return topLevelSelectionNormalizer.map(coreNormalizer.map(selectionCompatNormalizer.map(spec, normParams), normParams), normParams);\n}\nfunction _normalizeAutoSize(autosize) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(autosize) ? { type: autosize } : autosize ?? {};\n}\n/**\n * Normalize autosize and deal with width or height == \"container\".\n */\nfunction normalizeAutoSize(spec, sizeInfo, config) {\n    let { width, height } = sizeInfo;\n    const isFitCompatible = (0,_spec__WEBPACK_IMPORTED_MODULE_3__.isUnitSpec)(spec) || (0,_spec__WEBPACK_IMPORTED_MODULE_3__.isLayerSpec)(spec);\n    const autosizeDefault = {};\n    if (!isFitCompatible) {\n        // If spec is not compatible with autosize == \"fit\", discard width/height == container\n        if (width == 'container') {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.containerSizeNonSingle('width'));\n            width = undefined;\n        }\n        if (height == 'container') {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.containerSizeNonSingle('height'));\n            height = undefined;\n        }\n    }\n    else {\n        // Default autosize parameters to fit when width/height is \"container\"\n        if (width == 'container' && height == 'container') {\n            autosizeDefault.type = 'fit';\n            autosizeDefault.contains = 'padding';\n        }\n        else if (width == 'container') {\n            autosizeDefault.type = 'fit-x';\n            autosizeDefault.contains = 'padding';\n        }\n        else if (height == 'container') {\n            autosizeDefault.type = 'fit-y';\n            autosizeDefault.contains = 'padding';\n        }\n    }\n    const autosize = {\n        type: 'pad',\n        ...autosizeDefault,\n        ...(config ? _normalizeAutoSize(config.autosize) : {}),\n        ..._normalizeAutoSize(spec.autosize)\n    };\n    if (autosize.type === 'fit' && !isFitCompatible) {\n        _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.FIT_NON_SINGLE);\n        autosize.type = 'pad';\n    }\n    if (width == 'container' && !(autosize.type == 'fit' || autosize.type == 'fit-x')) {\n        _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.containerSizeNotCompatibleWithAutosize('width'));\n    }\n    if (height == 'container' && !(autosize.type == 'fit' || autosize.type == 'fit-y')) {\n        _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.containerSizeNotCompatibleWithAutosize('height'));\n    }\n    // Delete autosize property if it's Vega's default\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_4__.deepEqual)(autosize, { type: 'pad' })) {\n        return undefined;\n    }\n    return autosize;\n}\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/pathoverlay.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/pathoverlay.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   PathOverlayNormalizer: () => (/* binding */ PathOverlayNormalizer)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _spec_unit__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../spec/unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n/* harmony import */ var _stack__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../stack */ \"../../node_modules/vega-lite/build/src/stack.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _compile_mark_init__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../compile/mark/init */ \"../../node_modules/vega-lite/build/src/compile/mark/init.js\");\n\n\n\n\n\n\n\nfunction dropLineAndPoint(markDef) {\n    const { point: _point, line: _line, ...mark } = markDef;\n    return (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(mark).length > 1 ? mark : mark.type;\n}\nfunction dropLineAndPointFromConfig(config) {\n    for (const mark of ['line', 'area', 'rule', 'trail']) {\n        if (config[mark]) {\n            config = {\n                ...config,\n                // TODO: remove as any\n                [mark]: (0,_util__WEBPACK_IMPORTED_MODULE_5__.omit)(config[mark], ['point', 'line'])\n            };\n        }\n    }\n    return config;\n}\nfunction getPointOverlay(markDef, markConfig = {}, encoding) {\n    if (markDef.point === 'transparent') {\n        return { opacity: 0 };\n    }\n    else if (markDef.point) {\n        // truthy : true or object\n        return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(markDef.point) ? markDef.point : {};\n    }\n    else if (markDef.point !== undefined) {\n        // false or null\n        return null;\n    }\n    else {\n        // undefined (not disabled)\n        if (markConfig.point || encoding.shape) {\n            // enable point overlay if config[mark].point is truthy or if encoding.shape is provided\n            return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(markConfig.point) ? markConfig.point : {};\n        }\n        // markDef.point is defined as falsy\n        return undefined;\n    }\n}\nfunction getLineOverlay(markDef, markConfig = {}) {\n    if (markDef.line) {\n        // true or object\n        return markDef.line === true ? {} : markDef.line;\n    }\n    else if (markDef.line !== undefined) {\n        // false or null\n        return null;\n    }\n    else {\n        // undefined (not disabled)\n        if (markConfig.line) {\n            // enable line overlay if config[mark].line is truthy\n            return markConfig.line === true ? {} : markConfig.line;\n        }\n        // markDef.point is defined as falsy\n        return undefined;\n    }\n}\nclass PathOverlayNormalizer {\n    constructor() {\n        this.name = 'path-overlay';\n    }\n    hasMatchingType(spec, config) {\n        if ((0,_spec_unit__WEBPACK_IMPORTED_MODULE_3__.isUnitSpec)(spec)) {\n            const { mark, encoding } = spec;\n            const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_2__.isMarkDef)(mark) ? mark : { type: mark };\n            switch (markDef.type) {\n                case 'line':\n                case 'rule':\n                case 'trail':\n                    return !!getPointOverlay(markDef, config[markDef.type], encoding);\n                case 'area':\n                    return (\n                    // false / null are also included as we want to remove the properties\n                    !!getPointOverlay(markDef, config[markDef.type], encoding) ||\n                        !!getLineOverlay(markDef, config[markDef.type]));\n            }\n        }\n        return false;\n    }\n    run(spec, normParams, normalize) {\n        const { config } = normParams;\n        const { params, projection, mark, name, encoding: e, ...outerSpec } = spec;\n        // Need to call normalizeEncoding because we need the inferred types to correctly determine stack\n        const encoding = (0,_encoding__WEBPACK_IMPORTED_MODULE_1__.normalizeEncoding)(e, config);\n        const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_2__.isMarkDef)(mark) ? mark : { type: mark };\n        const pointOverlay = getPointOverlay(markDef, config[markDef.type], encoding);\n        const lineOverlay = markDef.type === 'area' && getLineOverlay(markDef, config[markDef.type]);\n        const layer = [\n            {\n                name,\n                ...(params ? { params } : {}),\n                mark: dropLineAndPoint({\n                    // TODO: extract this 0.7 to be shared with default opacity for point/tick/...\n                    ...(markDef.type === 'area' && markDef.opacity === undefined && markDef.fillOpacity === undefined\n                        ? { opacity: 0.7 }\n                        : {}),\n                    ...markDef\n                }),\n                // drop shape from encoding as this might be used to trigger point overlay\n                encoding: (0,_util__WEBPACK_IMPORTED_MODULE_5__.omit)(encoding, ['shape'])\n            }\n        ];\n        // FIXME: determine rules for applying selections.\n        // Need to copy stack config to overlayed layer\n        // FIXME: normalizer shouldn't call `initMarkdef`, a method from an init phase.\n        const stackProps = (0,_stack__WEBPACK_IMPORTED_MODULE_4__.stack)((0,_compile_mark_init__WEBPACK_IMPORTED_MODULE_6__.initMarkdef)(markDef, encoding, config), encoding);\n        let overlayEncoding = encoding;\n        if (stackProps) {\n            const { fieldChannel: stackFieldChannel, offset } = stackProps;\n            overlayEncoding = {\n                ...encoding,\n                [stackFieldChannel]: {\n                    ...encoding[stackFieldChannel],\n                    ...(offset ? { stack: offset } : {})\n                }\n            };\n        }\n        // overlay line layer should be on the edge of area but passing y2/x2 makes\n        // it as \"rule\" mark so that it draws unwanted vertical/horizontal lines.\n        // point overlay also should not have y2/x2 as it does not support.\n        overlayEncoding = (0,_util__WEBPACK_IMPORTED_MODULE_5__.omit)(overlayEncoding, ['y2', 'x2']);\n        if (lineOverlay) {\n            layer.push({\n                ...(projection ? { projection } : {}),\n                mark: {\n                    type: 'line',\n                    ...(0,_util__WEBPACK_IMPORTED_MODULE_5__.pick)(markDef, ['clip', 'interpolate', 'tension', 'tooltip']),\n                    ...lineOverlay\n                },\n                encoding: overlayEncoding\n            });\n        }\n        if (pointOverlay) {\n            layer.push({\n                ...(projection ? { projection } : {}),\n                mark: {\n                    type: 'point',\n                    opacity: 1,\n                    filled: true,\n                    ...(0,_util__WEBPACK_IMPORTED_MODULE_5__.pick)(markDef, ['clip', 'tooltip']),\n                    ...pointOverlay\n                },\n                encoding: overlayEncoding\n            });\n        }\n        return normalize({\n            ...outerSpec,\n            layer\n        }, {\n            ...normParams,\n            config: dropLineAndPointFromConfig(config)\n        });\n    }\n}\n//# sourceMappingURL=pathoverlay.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/pathoverlay.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/repeater.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/repeater.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   replaceRepeaterInEncoding: () => (/* binding */ replaceRepeaterInEncoding),\n/* harmony export */   replaceRepeaterInFacet: () => (/* binding */ replaceRepeaterInFacet)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _sort__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../sort */ \"../../node_modules/vega-lite/build/src/sort.js\");\n/* harmony import */ var _spec_facet__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../spec/facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n\n\n\n\n\nfunction replaceRepeaterInFacet(facet, repeater) {\n    if (!repeater) {\n        return facet;\n    }\n    if ((0,_spec_facet__WEBPACK_IMPORTED_MODULE_4__.isFacetMapping)(facet)) {\n        return replaceRepeaterInMapping(facet, repeater);\n    }\n    return replaceRepeaterInFieldDef(facet, repeater);\n}\nfunction replaceRepeaterInEncoding(encoding, repeater) {\n    if (!repeater) {\n        return encoding;\n    }\n    return replaceRepeaterInMapping(encoding, repeater);\n}\n/**\n * Replaces repeated value and returns if the repeated value is valid.\n */\nfunction replaceRepeatInProp(prop, o, repeater) {\n    const val = o[prop];\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isRepeatRef)(val)) {\n        if (val.repeat in repeater) {\n            return { ...o, [prop]: repeater[val.repeat] };\n        }\n        else {\n            _log__WEBPACK_IMPORTED_MODULE_2__.warn(_log__WEBPACK_IMPORTED_MODULE_2__.message.noSuchRepeatedValue(val.repeat));\n            return undefined;\n        }\n    }\n    return o;\n}\n/**\n * Replace repeater values in a field def with the concrete field name.\n */\nfunction replaceRepeaterInFieldDef(fieldDef, repeater) {\n    fieldDef = replaceRepeatInProp('field', fieldDef, repeater);\n    if (fieldDef === undefined) {\n        // the field def should be ignored\n        return undefined;\n    }\n    else if (fieldDef === null) {\n        return null;\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isSortableFieldDef)(fieldDef) && (0,_sort__WEBPACK_IMPORTED_MODULE_3__.isSortField)(fieldDef.sort)) {\n        const sort = replaceRepeatInProp('field', fieldDef.sort, repeater);\n        fieldDef = {\n            ...fieldDef,\n            ...(sort ? { sort } : {})\n        };\n    }\n    return fieldDef;\n}\nfunction replaceRepeaterInFieldOrDatumDef(def, repeater) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldDef)(def)) {\n        return replaceRepeaterInFieldDef(def, repeater);\n    }\n    else {\n        const datumDef = replaceRepeatInProp('datum', def, repeater);\n        if (datumDef !== def && !datumDef.type) {\n            datumDef.type = 'nominal';\n        }\n        return datumDef;\n    }\n}\nfunction replaceRepeaterInChannelDef(channelDef, repeater) {\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isFieldOrDatumDef)(channelDef)) {\n        const fd = replaceRepeaterInFieldOrDatumDef(channelDef, repeater);\n        if (fd) {\n            return fd;\n        }\n        else if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.isConditionalDef)(channelDef)) {\n            return { condition: channelDef.condition };\n        }\n    }\n    else {\n        if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.hasConditionalFieldOrDatumDef)(channelDef)) {\n            const fd = replaceRepeaterInFieldOrDatumDef(channelDef.condition, repeater);\n            if (fd) {\n                return {\n                    ...channelDef,\n                    condition: fd\n                };\n            }\n            else {\n                const { condition, ...channelDefWithoutCondition } = channelDef;\n                return channelDefWithoutCondition;\n            }\n        }\n        return channelDef;\n    }\n    return undefined;\n}\nfunction replaceRepeaterInMapping(mapping, repeater) {\n    const out = {};\n    for (const channel in mapping) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(mapping, channel)) {\n            const channelDef = mapping[channel];\n            if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(channelDef)) {\n                // array cannot have condition\n                out[channel] = channelDef // somehow we need to cast it here\n                    .map(cd => replaceRepeaterInChannelDef(cd, repeater))\n                    .filter(cd => cd);\n            }\n            else {\n                const cd = replaceRepeaterInChannelDef(channelDef, repeater);\n                if (cd !== undefined) {\n                    out[channel] = cd;\n                }\n            }\n        }\n    }\n    return out;\n}\n//# sourceMappingURL=repeater.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/repeater.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/ruleforrangedline.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/ruleforrangedline.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   RuleForRangedLineNormalizer: () => (/* binding */ RuleForRangedLineNormalizer)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _spec_unit__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../spec/unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n\n\n\n\n\n\n\nclass RuleForRangedLineNormalizer {\n    constructor() {\n        this.name = 'RuleForRangedLine';\n    }\n    hasMatchingType(spec) {\n        if ((0,_spec_unit__WEBPACK_IMPORTED_MODULE_6__.isUnitSpec)(spec)) {\n            const { encoding, mark } = spec;\n            if (mark === 'line' || ((0,_mark__WEBPACK_IMPORTED_MODULE_5__.isMarkDef)(mark) && mark.type === 'line')) {\n                for (const channel of _channel__WEBPACK_IMPORTED_MODULE_2__.SECONDARY_RANGE_CHANNEL) {\n                    const mainChannel = (0,_channel__WEBPACK_IMPORTED_MODULE_2__.getMainRangeChannel)(channel);\n                    const mainChannelDef = encoding[mainChannel];\n                    if (encoding[channel]) {\n                        if (((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(mainChannelDef) && !(0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinned)(mainChannelDef.bin)) || (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isDatumDef)(mainChannelDef)) {\n                            return true;\n                        }\n                    }\n                }\n            }\n        }\n        return false;\n    }\n    run(spec, params, normalize) {\n        const { encoding, mark } = spec;\n        _log__WEBPACK_IMPORTED_MODULE_4__.warn(_log__WEBPACK_IMPORTED_MODULE_4__.message.lineWithRange(!!encoding.x2, !!encoding.y2));\n        return normalize({\n            ...spec,\n            mark: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(mark) ? { ...mark, type: 'rule' } : 'rule'\n        }, params);\n    }\n}\n//# sourceMappingURL=ruleforrangedline.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/ruleforrangedline.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/selectioncompat.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/selectioncompat.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SelectionCompatibilityNormalizer: () => (/* binding */ SelectionCompatibilityNormalizer)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var _bin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../bin */ \"../../node_modules/vega-lite/build/src/bin.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _logical__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../logical */ \"../../node_modules/vega-lite/build/src/logical.js\");\n/* harmony import */ var _spec_map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../spec/map */ \"../../node_modules/vega-lite/build/src/spec/map.js\");\n/* harmony import */ var _transform__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../transform */ \"../../node_modules/vega-lite/build/src/transform.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\nclass SelectionCompatibilityNormalizer extends _spec_map__WEBPACK_IMPORTED_MODULE_4__.SpecMapper {\n    map(spec, normParams) {\n        normParams.emptySelections ?? (normParams.emptySelections = {});\n        normParams.selectionPredicates ?? (normParams.selectionPredicates = {});\n        spec = normalizeTransforms(spec, normParams);\n        return super.map(spec, normParams);\n    }\n    mapLayerOrUnit(spec, normParams) {\n        spec = normalizeTransforms(spec, normParams);\n        if (spec.encoding) {\n            const encoding = {};\n            for (const [channel, enc] of (0,_util__WEBPACK_IMPORTED_MODULE_6__.entries)(spec.encoding)) {\n                encoding[channel] = normalizeChannelDef(enc, normParams);\n            }\n            spec = { ...spec, encoding };\n        }\n        return super.mapLayerOrUnit(spec, normParams);\n    }\n    mapUnit(spec, normParams) {\n        const { selection, ...rest } = spec;\n        if (selection) {\n            return {\n                ...rest,\n                params: (0,_util__WEBPACK_IMPORTED_MODULE_6__.entries)(selection).map(([name, selDef]) => {\n                    const { init: value, bind, empty, ...select } = selDef;\n                    if (select.type === 'single') {\n                        select.type = 'point';\n                        select.toggle = false;\n                    }\n                    else if (select.type === 'multi') {\n                        select.type = 'point';\n                    }\n                    // Propagate emptiness forwards and backwards\n                    normParams.emptySelections[name] = empty !== 'none';\n                    for (const pred of (0,_util__WEBPACK_IMPORTED_MODULE_6__.vals)(normParams.selectionPredicates[name] ?? {})) {\n                        pred.empty = empty !== 'none';\n                    }\n                    return { name, value, select, bind };\n                })\n            };\n        }\n        return spec;\n    }\n}\nfunction normalizeTransforms(spec, normParams) {\n    const { transform: tx, ...rest } = spec;\n    if (tx) {\n        const transform = tx.map((t) => {\n            if ((0,_transform__WEBPACK_IMPORTED_MODULE_5__.isFilter)(t)) {\n                return { filter: normalizePredicate(t, normParams) };\n            }\n            else if ((0,_transform__WEBPACK_IMPORTED_MODULE_5__.isBin)(t) && (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinParams)(t.bin)) {\n                return {\n                    ...t,\n                    bin: normalizeBinExtent(t.bin)\n                };\n            }\n            else if ((0,_transform__WEBPACK_IMPORTED_MODULE_5__.isLookup)(t)) {\n                const { selection: param, ...from } = t.from;\n                return param\n                    ? {\n                        ...t,\n                        from: { param, ...from }\n                    }\n                    : t;\n            }\n            return t;\n        });\n        return { ...rest, transform };\n    }\n    return spec;\n}\nfunction normalizeChannelDef(obj, normParams) {\n    const enc = (0,_util__WEBPACK_IMPORTED_MODULE_6__.duplicate)(obj);\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isFieldDef)(enc) && (0,_bin__WEBPACK_IMPORTED_MODULE_1__.isBinParams)(enc.bin)) {\n        enc.bin = normalizeBinExtent(enc.bin);\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isScaleFieldDef)(enc) && enc.scale?.domain?.selection) {\n        const { selection: param, ...domain } = enc.scale.domain;\n        enc.scale.domain = { ...domain, ...(param ? { param } : {}) };\n    }\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_2__.isConditionalDef)(enc)) {\n        if ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isArray)(enc.condition)) {\n            enc.condition = enc.condition.map((c) => {\n                const { selection, param, test, ...cond } = c;\n                return param ? c : { ...cond, test: normalizePredicate(c, normParams) };\n            });\n        }\n        else {\n            const { selection, param, test, ...cond } = normalizeChannelDef(enc.condition, normParams);\n            enc.condition = param\n                ? enc.condition\n                : {\n                    ...cond,\n                    test: normalizePredicate(enc.condition, normParams)\n                };\n        }\n    }\n    return enc;\n}\nfunction normalizeBinExtent(bin) {\n    const ext = bin.extent;\n    if (ext?.selection) {\n        const { selection: param, ...rest } = ext;\n        return { ...bin, extent: { ...rest, param } };\n    }\n    return bin;\n}\nfunction normalizePredicate(op, normParams) {\n    // Normalize old compositions of selection names (e.g., selection: {and: [\"one\", \"two\"]})\n    const normalizeSelectionComposition = (o) => {\n        return (0,_logical__WEBPACK_IMPORTED_MODULE_3__.normalizeLogicalComposition)(o, param => {\n            var _a;\n            const empty = normParams.emptySelections[param] ?? true;\n            const pred = { param, empty };\n            (_a = normParams.selectionPredicates)[param] ?? (_a[param] = []);\n            normParams.selectionPredicates[param].push(pred);\n            return pred;\n        });\n    };\n    return op.selection\n        ? normalizeSelectionComposition(op.selection)\n        : (0,_logical__WEBPACK_IMPORTED_MODULE_3__.normalizeLogicalComposition)(op.test || op.filter, o => o.selection ? normalizeSelectionComposition(o.selection) : o);\n}\n//# sourceMappingURL=selectioncompat.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/selectioncompat.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/normalize/toplevelselection.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/normalize/toplevelselection.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TopLevelSelectionsNormalizer: () => (/* binding */ TopLevelSelectionsNormalizer)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n/* harmony import */ var _spec__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../spec */ \"../../node_modules/vega-lite/build/src/spec/index.js\");\n/* harmony import */ var _spec_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../spec/map */ \"../../node_modules/vega-lite/build/src/spec/map.js\");\n\n\n\n\nclass TopLevelSelectionsNormalizer extends _spec_map__WEBPACK_IMPORTED_MODULE_3__.SpecMapper {\n    map(spec, normParams) {\n        const selections = normParams.selections ?? [];\n        if (spec.params && !(0,_spec__WEBPACK_IMPORTED_MODULE_2__.isUnitSpec)(spec)) {\n            const params = [];\n            for (const param of spec.params) {\n                if ((0,_selection__WEBPACK_IMPORTED_MODULE_1__.isSelectionParameter)(param)) {\n                    selections.push(param);\n                }\n                else {\n                    params.push(param);\n                }\n            }\n            spec.params = params;\n        }\n        normParams.selections = selections;\n        return super.map(spec, normParams);\n    }\n    mapUnit(spec, normParams) {\n        const selections = normParams.selections;\n        if (!selections || !selections.length)\n            return spec;\n        const path = (normParams.path ?? []).concat(spec.name);\n        const params = [];\n        for (const selection of selections) {\n            // By default, apply selections to all unit views.\n            if (!selection.views || !selection.views.length) {\n                params.push(selection);\n            }\n            else {\n                for (const view of selection.views) {\n                    // view is either a specific unit name, or a partial path through the spec tree.\n                    if (((0,vega__WEBPACK_IMPORTED_MODULE_0__.isString)(view) && (view === spec.name || path.includes(view))) ||\n                        ((0,vega__WEBPACK_IMPORTED_MODULE_0__.isArray)(view) &&\n                            // logic for backwards compatibility with view paths before we had unique names\n                            // @ts-ignore\n                            view.map(v => path.indexOf(v)).every((v, i, arr) => v !== -1 && (i === 0 || v > arr[i - 1])))) {\n                        params.push(selection);\n                    }\n                }\n            }\n        }\n        if (params.length)\n            spec.params = params;\n        return spec;\n    }\n}\nfor (const method of ['mapFacet', 'mapRepeat', 'mapHConcat', 'mapVConcat', 'mapLayer']) {\n    const proto = TopLevelSelectionsNormalizer.prototype[method];\n    TopLevelSelectionsNormalizer.prototype[method] = function (spec, params) {\n        return proto.call(this, spec, addSpecNameToParams(spec, params));\n    };\n}\nfunction addSpecNameToParams(spec, params) {\n    return spec.name\n        ? {\n            ...params,\n            path: (params.path ?? []).concat(spec.name)\n        }\n        : params;\n}\n//# sourceMappingURL=toplevelselection.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/normalize/toplevelselection.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/parameter.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/parameter.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   assembleParameterSignals: () => (/* binding */ assembleParameterSignals)\n/* harmony export */ });\n/* harmony import */ var _selection__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./selection */ \"../../node_modules/vega-lite/build/src/selection.js\");\n\nfunction assembleParameterSignals(params) {\n    const signals = [];\n    for (const param of params || []) {\n        // Selection parameters are handled separately via assembleSelectionTopLevelSignals\n        // and assembleSignals methods registered on the Model.\n        if ((0,_selection__WEBPACK_IMPORTED_MODULE_0__.isSelectionParameter)(param))\n            continue;\n        const { expr, bind, ...rest } = param;\n        if (bind && expr) {\n            // Vega's InitSignal -- apply expr to \"init\"\n            const signal = {\n                ...rest,\n                bind,\n                init: expr\n            };\n            signals.push(signal);\n        }\n        else {\n            const signal = {\n                ...rest,\n                ...(expr ? { update: expr } : {}),\n                ...(bind ? { bind } : {})\n            };\n            signals.push(signal);\n        }\n    }\n    return signals;\n}\n//# sourceMappingURL=parameter.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/parameter.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/predicate.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/predicate.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   fieldFilterExpression: () => (/* binding */ fieldFilterExpression),\n/* harmony export */   fieldValidPredicate: () => (/* binding */ fieldValidPredicate),\n/* harmony export */   isFieldEqualPredicate: () => (/* binding */ isFieldEqualPredicate),\n/* harmony export */   isFieldGTEPredicate: () => (/* binding */ isFieldGTEPredicate),\n/* harmony export */   isFieldGTPredicate: () => (/* binding */ isFieldGTPredicate),\n/* harmony export */   isFieldLTEPredicate: () => (/* binding */ isFieldLTEPredicate),\n/* harmony export */   isFieldLTPredicate: () => (/* binding */ isFieldLTPredicate),\n/* harmony export */   isFieldOneOfPredicate: () => (/* binding */ isFieldOneOfPredicate),\n/* harmony export */   isFieldPredicate: () => (/* binding */ isFieldPredicate),\n/* harmony export */   isFieldRangePredicate: () => (/* binding */ isFieldRangePredicate),\n/* harmony export */   isFieldValidPredicate: () => (/* binding */ isFieldValidPredicate),\n/* harmony export */   isSelectionPredicate: () => (/* binding */ isSelectionPredicate),\n/* harmony export */   normalizePredicate: () => (/* binding */ normalizePredicate)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _timeunit__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./timeunit */ \"../../node_modules/vega-lite/build/src/timeunit.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _vega_schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./vega.schema */ \"../../node_modules/vega-lite/build/src/vega.schema.js\");\n\n\n\n\n\nfunction isSelectionPredicate(predicate) {\n    return predicate?.['param'];\n}\nfunction isFieldEqualPredicate(predicate) {\n    return !!predicate?.field && predicate.equal !== undefined;\n}\nfunction isFieldLTPredicate(predicate) {\n    return !!predicate?.field && predicate.lt !== undefined;\n}\nfunction isFieldLTEPredicate(predicate) {\n    return !!predicate?.field && predicate.lte !== undefined;\n}\nfunction isFieldGTPredicate(predicate) {\n    return !!predicate?.field && predicate.gt !== undefined;\n}\nfunction isFieldGTEPredicate(predicate) {\n    return !!predicate?.field && predicate.gte !== undefined;\n}\nfunction isFieldRangePredicate(predicate) {\n    if (predicate?.field) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(predicate.range) && predicate.range.length === 2) {\n            return true;\n        }\n        else if ((0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(predicate.range)) {\n            return true;\n        }\n    }\n    return false;\n}\nfunction isFieldOneOfPredicate(predicate) {\n    return (!!predicate?.field && ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(predicate.oneOf) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(predicate.in)) // backward compatibility\n    );\n}\nfunction isFieldValidPredicate(predicate) {\n    return !!predicate?.field && predicate.valid !== undefined;\n}\nfunction isFieldPredicate(predicate) {\n    return (isFieldOneOfPredicate(predicate) ||\n        isFieldEqualPredicate(predicate) ||\n        isFieldRangePredicate(predicate) ||\n        isFieldLTPredicate(predicate) ||\n        isFieldGTPredicate(predicate) ||\n        isFieldLTEPredicate(predicate) ||\n        isFieldGTEPredicate(predicate));\n}\nfunction predicateValueExpr(v, timeUnit) {\n    return (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.valueExpr)(v, { timeUnit, wrapTime: true });\n}\nfunction predicateValuesExpr(vals, timeUnit) {\n    return vals.map(v => predicateValueExpr(v, timeUnit));\n}\n// This method is used by Voyager. Do not change its behavior without changing Voyager.\nfunction fieldFilterExpression(predicate, useInRange = true) {\n    const { field } = predicate;\n    const normalizedTimeUnit = (0,_timeunit__WEBPACK_IMPORTED_MODULE_2__.normalizeTimeUnit)(predicate.timeUnit);\n    const { unit, binned } = normalizedTimeUnit || {};\n    const rawFieldExpr = (0,_channeldef__WEBPACK_IMPORTED_MODULE_1__.vgField)(predicate, { expr: 'datum' });\n    const fieldExpr = unit\n        ? // For timeUnit, cast into integer with time() so we can use ===, inrange, indexOf to compare values directly.\n            // TODO: We calculate timeUnit on the fly here. Consider if we would like to consolidate this with timeUnit pipeline\n            // TODO: support utc\n            `time(${!binned ? (0,_timeunit__WEBPACK_IMPORTED_MODULE_2__.fieldExpr)(unit, field) : rawFieldExpr})`\n        : rawFieldExpr;\n    if (isFieldEqualPredicate(predicate)) {\n        return `${fieldExpr}===${predicateValueExpr(predicate.equal, unit)}`;\n    }\n    else if (isFieldLTPredicate(predicate)) {\n        const upper = predicate.lt;\n        return `${fieldExpr}<${predicateValueExpr(upper, unit)}`;\n    }\n    else if (isFieldGTPredicate(predicate)) {\n        const lower = predicate.gt;\n        return `${fieldExpr}>${predicateValueExpr(lower, unit)}`;\n    }\n    else if (isFieldLTEPredicate(predicate)) {\n        const upper = predicate.lte;\n        return `${fieldExpr}<=${predicateValueExpr(upper, unit)}`;\n    }\n    else if (isFieldGTEPredicate(predicate)) {\n        const lower = predicate.gte;\n        return `${fieldExpr}>=${predicateValueExpr(lower, unit)}`;\n    }\n    else if (isFieldOneOfPredicate(predicate)) {\n        return `indexof([${predicateValuesExpr(predicate.oneOf, unit).join(',')}], ${fieldExpr}) !== -1`;\n    }\n    else if (isFieldValidPredicate(predicate)) {\n        return fieldValidPredicate(fieldExpr, predicate.valid);\n    }\n    else if (isFieldRangePredicate(predicate)) {\n        const { range } = predicate;\n        const lower = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(range) ? { signal: `${range.signal}[0]` } : range[0];\n        const upper = (0,_vega_schema__WEBPACK_IMPORTED_MODULE_4__.isSignalRef)(range) ? { signal: `${range.signal}[1]` } : range[1];\n        if (lower !== null && upper !== null && useInRange) {\n            return ('inrange(' + fieldExpr + ', [' + predicateValueExpr(lower, unit) + ', ' + predicateValueExpr(upper, unit) + '])');\n        }\n        const exprs = [];\n        if (lower !== null) {\n            exprs.push(`${fieldExpr} >= ${predicateValueExpr(lower, unit)}`);\n        }\n        if (upper !== null) {\n            exprs.push(`${fieldExpr} <= ${predicateValueExpr(upper, unit)}`);\n        }\n        return exprs.length > 0 ? exprs.join(' && ') : 'true';\n    }\n    /* istanbul ignore next: it should never reach here */\n    throw new Error(`Invalid field predicate: ${(0,_util__WEBPACK_IMPORTED_MODULE_3__.stringify)(predicate)}`);\n}\nfunction fieldValidPredicate(fieldExpr, valid = true) {\n    if (valid) {\n        return `isValid(${fieldExpr}) && isFinite(+${fieldExpr})`;\n    }\n    else {\n        return `!isValid(${fieldExpr}) || !isFinite(+${fieldExpr})`;\n    }\n}\nfunction normalizePredicate(f) {\n    if (isFieldPredicate(f) && f.timeUnit) {\n        return {\n            ...f,\n            timeUnit: (0,_timeunit__WEBPACK_IMPORTED_MODULE_2__.normalizeTimeUnit)(f.timeUnit)\n        };\n    }\n    return f;\n}\n//# sourceMappingURL=predicate.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/predicate.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/projection.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/projection.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   PROJECTION_PROPERTIES: () => (/* binding */ PROJECTION_PROPERTIES)\n/* harmony export */ });\nconst PROJECTION_PROPERTIES = [\n    'type',\n    'clipAngle',\n    'clipExtent',\n    'center',\n    'rotate',\n    'precision',\n    'reflectX',\n    'reflectY',\n    'coefficient',\n    'distance',\n    'fraction',\n    'lobes',\n    'parallel',\n    'radius',\n    'ratio',\n    'spacing',\n    'tilt'\n];\n//# sourceMappingURL=projection.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/projection.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/scale.js":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/scale.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CONTINUOUS_DOMAIN_SCALES: () => (/* binding */ CONTINUOUS_DOMAIN_SCALES),\n/* harmony export */   CONTINUOUS_TO_CONTINUOUS_SCALES: () => (/* binding */ CONTINUOUS_TO_CONTINUOUS_SCALES),\n/* harmony export */   CONTINUOUS_TO_DISCRETE_SCALES: () => (/* binding */ CONTINUOUS_TO_DISCRETE_SCALES),\n/* harmony export */   DISCRETE_DOMAIN_SCALES: () => (/* binding */ DISCRETE_DOMAIN_SCALES),\n/* harmony export */   NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTIES: () => (/* binding */ NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTIES),\n/* harmony export */   QUANTITATIVE_SCALES: () => (/* binding */ QUANTITATIVE_SCALES),\n/* harmony export */   SCALE_CATEGORY_INDEX: () => (/* binding */ SCALE_CATEGORY_INDEX),\n/* harmony export */   SCALE_PROPERTIES: () => (/* binding */ SCALE_PROPERTIES),\n/* harmony export */   SCALE_TYPES: () => (/* binding */ SCALE_TYPES),\n/* harmony export */   ScaleType: () => (/* binding */ ScaleType),\n/* harmony export */   TIME_SCALE_TYPES: () => (/* binding */ TIME_SCALE_TYPES),\n/* harmony export */   channelScalePropertyIncompatability: () => (/* binding */ channelScalePropertyIncompatability),\n/* harmony export */   channelSupportScaleType: () => (/* binding */ channelSupportScaleType),\n/* harmony export */   defaultScaleConfig: () => (/* binding */ defaultScaleConfig),\n/* harmony export */   hasContinuousDomain: () => (/* binding */ hasContinuousDomain),\n/* harmony export */   hasDiscreteDomain: () => (/* binding */ hasDiscreteDomain),\n/* harmony export */   isContinuousToContinuous: () => (/* binding */ isContinuousToContinuous),\n/* harmony export */   isContinuousToDiscrete: () => (/* binding */ isContinuousToDiscrete),\n/* harmony export */   isDomainUnionWith: () => (/* binding */ isDomainUnionWith),\n/* harmony export */   isExtendedScheme: () => (/* binding */ isExtendedScheme),\n/* harmony export */   isFieldRange: () => (/* binding */ isFieldRange),\n/* harmony export */   isParameterDomain: () => (/* binding */ isParameterDomain),\n/* harmony export */   isQuantitative: () => (/* binding */ isQuantitative),\n/* harmony export */   scaleCompatible: () => (/* binding */ scaleCompatible),\n/* harmony export */   scaleTypePrecedence: () => (/* binding */ scaleTypePrecedence),\n/* harmony export */   scaleTypeSupportDataType: () => (/* binding */ scaleTypeSupportDataType),\n/* harmony export */   scaleTypeSupportProperty: () => (/* binding */ scaleTypeSupportProperty)\n/* harmony export */ });\n/* harmony import */ var vega__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega */ \"../../node_modules/vega/build/vega.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./type */ \"../../node_modules/vega-lite/build/src/type.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n\n\n\n\nconst ScaleType = {\n    // Continuous - Quantitative\n    LINEAR: 'linear',\n    LOG: 'log',\n    POW: 'pow',\n    SQRT: 'sqrt',\n    SYMLOG: 'symlog',\n    IDENTITY: 'identity',\n    SEQUENTIAL: 'sequential',\n    // Continuous - Time\n    TIME: 'time',\n    UTC: 'utc',\n    // Discretizing scales\n    QUANTILE: 'quantile',\n    QUANTIZE: 'quantize',\n    THRESHOLD: 'threshold',\n    BIN_ORDINAL: 'bin-ordinal',\n    // Discrete scales\n    ORDINAL: 'ordinal',\n    POINT: 'point',\n    BAND: 'band'\n};\n/**\n * Index for scale categories -- only scale of the same categories can be merged together.\n * Current implementation is trying to be conservative and avoid merging scale type that might not work together\n */\nconst SCALE_CATEGORY_INDEX = {\n    linear: 'numeric',\n    log: 'numeric',\n    pow: 'numeric',\n    sqrt: 'numeric',\n    symlog: 'numeric',\n    identity: 'numeric',\n    sequential: 'numeric',\n    time: 'time',\n    utc: 'time',\n    ordinal: 'ordinal',\n    'bin-ordinal': 'bin-ordinal',\n    point: 'ordinal-position',\n    band: 'ordinal-position',\n    quantile: 'discretizing',\n    quantize: 'discretizing',\n    threshold: 'discretizing'\n};\nconst SCALE_TYPES = (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(SCALE_CATEGORY_INDEX);\n/**\n * Whether the two given scale types can be merged together.\n */\nfunction scaleCompatible(scaleType1, scaleType2) {\n    const scaleCategory1 = SCALE_CATEGORY_INDEX[scaleType1];\n    const scaleCategory2 = SCALE_CATEGORY_INDEX[scaleType2];\n    return (scaleCategory1 === scaleCategory2 ||\n        (scaleCategory1 === 'ordinal-position' && scaleCategory2 === 'time') ||\n        (scaleCategory2 === 'ordinal-position' && scaleCategory1 === 'time'));\n}\n/**\n * Index for scale precedence -- high score = higher priority for merging.\n */\nconst SCALE_PRECEDENCE_INDEX = {\n    // numeric\n    linear: 0,\n    log: 1,\n    pow: 1,\n    sqrt: 1,\n    symlog: 1,\n    identity: 1,\n    sequential: 1,\n    // time\n    time: 0,\n    utc: 0,\n    // ordinal-position -- these have higher precedence than continuous scales as they support more types of data\n    point: 10,\n    band: 11,\n    // non grouped types\n    ordinal: 0,\n    'bin-ordinal': 0,\n    quantile: 0,\n    quantize: 0,\n    threshold: 0\n};\n/**\n * Return scale categories -- only scale of the same categories can be merged together.\n */\nfunction scaleTypePrecedence(scaleType) {\n    return SCALE_PRECEDENCE_INDEX[scaleType];\n}\nconst QUANTITATIVE_SCALES = new Set([\n    'linear',\n    'log',\n    'pow',\n    'sqrt',\n    'symlog'\n]);\nconst CONTINUOUS_TO_CONTINUOUS_SCALES = new Set([\n    ...QUANTITATIVE_SCALES,\n    'time',\n    'utc'\n]);\nfunction isQuantitative(type) {\n    return QUANTITATIVE_SCALES.has(type);\n}\nconst CONTINUOUS_TO_DISCRETE_SCALES = new Set([\n    'quantile',\n    'quantize',\n    'threshold'\n]);\nconst CONTINUOUS_DOMAIN_SCALES = new Set([\n    ...CONTINUOUS_TO_CONTINUOUS_SCALES,\n    ...CONTINUOUS_TO_DISCRETE_SCALES,\n    'sequential',\n    'identity'\n]);\nconst DISCRETE_DOMAIN_SCALES = new Set([\n    'ordinal',\n    'bin-ordinal',\n    'point',\n    'band'\n]);\nconst TIME_SCALE_TYPES = new Set(['time', 'utc']);\nfunction hasDiscreteDomain(type) {\n    return DISCRETE_DOMAIN_SCALES.has(type);\n}\nfunction hasContinuousDomain(type) {\n    return CONTINUOUS_DOMAIN_SCALES.has(type);\n}\nfunction isContinuousToContinuous(type) {\n    return CONTINUOUS_TO_CONTINUOUS_SCALES.has(type);\n}\nfunction isContinuousToDiscrete(type) {\n    return CONTINUOUS_TO_DISCRETE_SCALES.has(type);\n}\nconst defaultScaleConfig = {\n    pointPadding: 0.5,\n    barBandPaddingInner: 0.1,\n    rectBandPaddingInner: 0,\n    bandWithNestedOffsetPaddingInner: 0.2,\n    bandWithNestedOffsetPaddingOuter: 0.2,\n    minBandSize: 2,\n    minFontSize: 8,\n    maxFontSize: 40,\n    minOpacity: 0.3,\n    maxOpacity: 0.8,\n    // FIXME: revise if these *can* become ratios of width/height step\n    minSize: 9,\n    minStrokeWidth: 1,\n    maxStrokeWidth: 4,\n    quantileCount: 4,\n    quantizeCount: 4,\n    zero: true\n};\nfunction isExtendedScheme(scheme) {\n    return !(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.isString)(scheme) && !!scheme['name'];\n}\nfunction isParameterDomain(domain) {\n    return domain?.['param'];\n}\nfunction isDomainUnionWith(domain) {\n    return domain?.['unionWith'];\n}\nfunction isFieldRange(range) {\n    return (0,vega__WEBPACK_IMPORTED_MODULE_0__.isObject)(range) && 'field' in range;\n}\nconst SCALE_PROPERTY_INDEX = {\n    type: 1,\n    domain: 1,\n    domainMax: 1,\n    domainMin: 1,\n    domainMid: 1,\n    domainRaw: 1,\n    align: 1,\n    range: 1,\n    rangeMax: 1,\n    rangeMin: 1,\n    scheme: 1,\n    bins: 1,\n    // Other properties\n    reverse: 1,\n    round: 1,\n    // quantitative / time\n    clamp: 1,\n    nice: 1,\n    // quantitative\n    base: 1,\n    exponent: 1,\n    constant: 1,\n    interpolate: 1,\n    zero: 1,\n    // band/point\n    padding: 1,\n    paddingInner: 1,\n    paddingOuter: 1\n};\nconst SCALE_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(SCALE_PROPERTY_INDEX);\nconst { type, domain, range, rangeMax, rangeMin, scheme, ...NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTY_INDEX } = SCALE_PROPERTY_INDEX;\nconst NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_5__.keys)(NON_TYPE_DOMAIN_RANGE_VEGA_SCALE_PROPERTY_INDEX);\nfunction scaleTypeSupportProperty(scaleType, propName) {\n    switch (propName) {\n        case 'type':\n        case 'domain':\n        case 'reverse':\n        case 'range':\n            return true;\n        case 'scheme':\n        case 'interpolate':\n            return !['point', 'band', 'identity'].includes(scaleType);\n        case 'bins':\n            return !['point', 'band', 'identity', 'ordinal'].includes(scaleType);\n        case 'round':\n            return isContinuousToContinuous(scaleType) || scaleType === 'band' || scaleType === 'point';\n        case 'padding':\n        case 'rangeMin':\n        case 'rangeMax':\n            return isContinuousToContinuous(scaleType) || ['point', 'band'].includes(scaleType);\n        case 'paddingOuter':\n        case 'align':\n            return ['point', 'band'].includes(scaleType);\n        case 'paddingInner':\n            return scaleType === 'band';\n        case 'domainMax':\n        case 'domainMid':\n        case 'domainMin':\n        case 'domainRaw':\n        case 'clamp':\n            return isContinuousToContinuous(scaleType);\n        case 'nice':\n            return isContinuousToContinuous(scaleType) || scaleType === 'quantize' || scaleType === 'threshold';\n        case 'exponent':\n            return scaleType === 'pow';\n        case 'base':\n            return scaleType === 'log';\n        case 'constant':\n            return scaleType === 'symlog';\n        case 'zero':\n            return (hasContinuousDomain(scaleType) &&\n                !(0,_util__WEBPACK_IMPORTED_MODULE_5__.contains)([\n                    'log',\n                    'time',\n                    'utc',\n                    'threshold',\n                    'quantile' // quantile depends on distribution so zero does not matter\n                ], scaleType));\n    }\n}\n/**\n * Returns undefined if the input channel supports the input scale property name\n */\nfunction channelScalePropertyIncompatability(channel, propName) {\n    switch (propName) {\n        case 'interpolate':\n        case 'scheme':\n        case 'domainMid':\n            if (!(0,_channel__WEBPACK_IMPORTED_MODULE_2__.isColorChannel)(channel)) {\n                return _log__WEBPACK_IMPORTED_MODULE_3__.message.cannotUseScalePropertyWithNonColor(propName);\n            }\n            return undefined;\n        case 'align':\n        case 'type':\n        case 'bins':\n        case 'domain':\n        case 'domainMax':\n        case 'domainMin':\n        case 'domainRaw':\n        case 'range':\n        case 'base':\n        case 'exponent':\n        case 'constant':\n        case 'nice':\n        case 'padding':\n        case 'paddingInner':\n        case 'paddingOuter':\n        case 'rangeMax':\n        case 'rangeMin':\n        case 'reverse':\n        case 'round':\n        case 'clamp':\n        case 'zero':\n            return undefined; // GOOD!\n    }\n}\nfunction scaleTypeSupportDataType(specifiedType, fieldDefType) {\n    if ((0,_util__WEBPACK_IMPORTED_MODULE_5__.contains)([_type__WEBPACK_IMPORTED_MODULE_4__.ORDINAL, _type__WEBPACK_IMPORTED_MODULE_4__.NOMINAL], fieldDefType)) {\n        return specifiedType === undefined || hasDiscreteDomain(specifiedType);\n    }\n    else if (fieldDefType === _type__WEBPACK_IMPORTED_MODULE_4__.TEMPORAL) {\n        return (0,_util__WEBPACK_IMPORTED_MODULE_5__.contains)([ScaleType.TIME, ScaleType.UTC, undefined], specifiedType);\n    }\n    else if (fieldDefType === _type__WEBPACK_IMPORTED_MODULE_4__.QUANTITATIVE) {\n        return isQuantitative(specifiedType) || isContinuousToDiscrete(specifiedType) || specifiedType === undefined;\n    }\n    return true;\n}\nfunction channelSupportScaleType(channel, scaleType, hasNestedOffsetScale = false) {\n    if (!_channel__WEBPACK_IMPORTED_MODULE_2__.isScaleChannel(channel)) {\n        return false;\n    }\n    switch (channel) {\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.X:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.Y:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.XOFFSET:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.YOFFSET:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.THETA:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.RADIUS:\n            if (isContinuousToContinuous(scaleType)) {\n                return true;\n            }\n            else if (scaleType === 'band') {\n                return true;\n            }\n            else if (scaleType === 'point') {\n                /*\n                  Point scale can't be use if the position has a nested offset scale\n                  because if there is a nested scale, then it's band.\n                */\n                return !hasNestedOffsetScale;\n            }\n            return false;\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.SIZE: // TODO: size and opacity can support ordinal with more modification\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEWIDTH:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.OPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.FILLOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEOPACITY:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.ANGLE:\n            // Although it generally doesn't make sense to use band with size and opacity,\n            // it can also work since we use band: 0.5 to get midpoint.\n            return (isContinuousToContinuous(scaleType) ||\n                isContinuousToDiscrete(scaleType) ||\n                (0,_util__WEBPACK_IMPORTED_MODULE_5__.contains)(['band', 'point', 'ordinal'], scaleType));\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.COLOR:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.FILL:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKE:\n            return scaleType !== 'band'; // band does not make sense with color\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.STROKEDASH:\n        case _channel__WEBPACK_IMPORTED_MODULE_2__.SHAPE:\n            return scaleType === 'ordinal' || isContinuousToDiscrete(scaleType);\n    }\n}\n//# sourceMappingURL=scale.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/scale.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/selection.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/selection.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SELECTION_ID: () => (/* binding */ SELECTION_ID),\n/* harmony export */   defaultConfig: () => (/* binding */ defaultConfig),\n/* harmony export */   isLegendBinding: () => (/* binding */ isLegendBinding),\n/* harmony export */   isLegendStreamBinding: () => (/* binding */ isLegendStreamBinding),\n/* harmony export */   isSelectionParameter: () => (/* binding */ isSelectionParameter)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\nconst SELECTION_ID = '_vgsid_';\nconst defaultConfig = {\n    point: {\n        on: 'click',\n        fields: [SELECTION_ID],\n        toggle: 'event.shiftKey',\n        resolve: 'global',\n        clear: 'dblclick'\n    },\n    interval: {\n        on: '[mousedown, window:mouseup] > window:mousemove!',\n        encodings: ['x', 'y'],\n        translate: '[mousedown, window:mouseup] > window:mousemove!',\n        zoom: 'wheel!',\n        mark: { fill: '#333', fillOpacity: 0.125, stroke: 'white' },\n        resolve: 'global',\n        clear: 'dblclick'\n    }\n};\nfunction isLegendBinding(bind) {\n    return bind === 'legend' || !!bind?.legend;\n}\nfunction isLegendStreamBinding(bind) {\n    return isLegendBinding(bind) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(bind);\n}\nfunction isSelectionParameter(param) {\n    return !!param?.['select'];\n}\n//# sourceMappingURL=selection.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/selection.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/sort.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/sort.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DEFAULT_SORT_OP: () => (/* binding */ DEFAULT_SORT_OP),\n/* harmony export */   isSortArray: () => (/* binding */ isSortArray),\n/* harmony export */   isSortByChannel: () => (/* binding */ isSortByChannel),\n/* harmony export */   isSortByEncoding: () => (/* binding */ isSortByEncoding),\n/* harmony export */   isSortField: () => (/* binding */ isSortField)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\nconst DEFAULT_SORT_OP = 'min';\nconst SORT_BY_CHANNEL_INDEX = {\n    x: 1,\n    y: 1,\n    color: 1,\n    fill: 1,\n    stroke: 1,\n    strokeWidth: 1,\n    size: 1,\n    shape: 1,\n    fillOpacity: 1,\n    strokeOpacity: 1,\n    opacity: 1,\n    text: 1\n};\nfunction isSortByChannel(c) {\n    return c in SORT_BY_CHANNEL_INDEX;\n}\nfunction isSortByEncoding(sort) {\n    return !!sort?.['encoding'];\n}\nfunction isSortField(sort) {\n    return sort && (sort['op'] === 'count' || !!sort['field']);\n}\nfunction isSortArray(sort) {\n    return sort && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(sort);\n}\n//# sourceMappingURL=sort.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/sort.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/base.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/base.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DEFAULT_SPACING: () => (/* binding */ DEFAULT_SPACING),\n/* harmony export */   extractCompositionLayout: () => (/* binding */ extractCompositionLayout),\n/* harmony export */   getStepFor: () => (/* binding */ getStepFor),\n/* harmony export */   isFrameMixins: () => (/* binding */ isFrameMixins),\n/* harmony export */   isStep: () => (/* binding */ isStep)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util */ \"../../node_modules/vega-lite/build/src/util.js\");\n/* harmony import */ var _concat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./concat */ \"../../node_modules/vega-lite/build/src/spec/concat.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n\n\n\n\nfunction getStepFor({ step, offsetIsDiscrete }) {\n    if (offsetIsDiscrete) {\n        return step.for ?? 'offset';\n    }\n    else {\n        return 'position';\n    }\n}\nfunction isStep(size) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(size) && size['step'] !== undefined;\n}\nfunction isFrameMixins(o) {\n    return o['view'] || o['width'] || o['height'];\n}\nconst DEFAULT_SPACING = 20;\nconst COMPOSITION_LAYOUT_INDEX = {\n    align: 1,\n    bounds: 1,\n    center: 1,\n    columns: 1,\n    spacing: 1\n};\nconst COMPOSITION_LAYOUT_PROPERTIES = (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(COMPOSITION_LAYOUT_INDEX);\nfunction extractCompositionLayout(spec, specType, config) {\n    const compositionConfig = config[specType];\n    const layout = {};\n    // Apply config first\n    const { spacing: spacingConfig, columns } = compositionConfig;\n    if (spacingConfig !== undefined) {\n        layout.spacing = spacingConfig;\n    }\n    if (columns !== undefined) {\n        if (((0,_facet__WEBPACK_IMPORTED_MODULE_3__.isFacetSpec)(spec) && !(0,_facet__WEBPACK_IMPORTED_MODULE_3__.isFacetMapping)(spec.facet)) || (0,_concat__WEBPACK_IMPORTED_MODULE_2__.isConcatSpec)(spec)) {\n            layout.columns = columns;\n        }\n    }\n    if ((0,_concat__WEBPACK_IMPORTED_MODULE_2__.isVConcatSpec)(spec)) {\n        layout.columns = 1;\n    }\n    // Then copy properties from the spec\n    for (const prop of COMPOSITION_LAYOUT_PROPERTIES) {\n        if (spec[prop] !== undefined) {\n            if (prop === 'spacing') {\n                const spacing = spec[prop];\n                layout[prop] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(spacing)\n                    ? spacing\n                    : {\n                        row: spacing.row ?? spacingConfig,\n                        column: spacing.column ?? spacingConfig\n                    };\n            }\n            else {\n                layout[prop] = spec[prop];\n            }\n        }\n    }\n    return layout;\n}\n//# sourceMappingURL=base.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/base.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/concat.js":
/*!*************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/concat.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isAnyConcatSpec: () => (/* binding */ isAnyConcatSpec),\n/* harmony export */   isConcatSpec: () => (/* binding */ isConcatSpec),\n/* harmony export */   isHConcatSpec: () => (/* binding */ isHConcatSpec),\n/* harmony export */   isVConcatSpec: () => (/* binding */ isVConcatSpec)\n/* harmony export */ });\nfunction isAnyConcatSpec(spec) {\n    return isVConcatSpec(spec) || isHConcatSpec(spec) || isConcatSpec(spec);\n}\nfunction isConcatSpec(spec) {\n    return 'concat' in spec;\n}\nfunction isVConcatSpec(spec) {\n    return 'vconcat' in spec;\n}\nfunction isHConcatSpec(spec) {\n    return 'hconcat' in spec;\n}\n//# sourceMappingURL=concat.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/concat.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/facet.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/facet.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isFacetFieldDef: () => (/* binding */ isFacetFieldDef),\n/* harmony export */   isFacetMapping: () => (/* binding */ isFacetMapping),\n/* harmony export */   isFacetSpec: () => (/* binding */ isFacetSpec)\n/* harmony export */ });\nfunction isFacetMapping(f) {\n    return 'row' in f || 'column' in f;\n}\nfunction isFacetFieldDef(channelDef) {\n    return !!channelDef && 'header' in channelDef;\n}\nfunction isFacetSpec(spec) {\n    return 'facet' in spec;\n}\n//# sourceMappingURL=facet.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/facet.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/index.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/index.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isAnyConcatSpec: () => (/* reexport safe */ _concat__WEBPACK_IMPORTED_MODULE_0__.isAnyConcatSpec),\n/* harmony export */   isFacetSpec: () => (/* reexport safe */ _facet__WEBPACK_IMPORTED_MODULE_1__.isFacetSpec),\n/* harmony export */   isHConcatSpec: () => (/* reexport safe */ _concat__WEBPACK_IMPORTED_MODULE_0__.isHConcatSpec),\n/* harmony export */   isLayerSpec: () => (/* reexport safe */ _layer__WEBPACK_IMPORTED_MODULE_2__.isLayerSpec),\n/* harmony export */   isRepeatSpec: () => (/* reexport safe */ _repeat__WEBPACK_IMPORTED_MODULE_3__.isRepeatSpec),\n/* harmony export */   isUnitSpec: () => (/* reexport safe */ _unit__WEBPACK_IMPORTED_MODULE_4__.isUnitSpec),\n/* harmony export */   isVConcatSpec: () => (/* reexport safe */ _concat__WEBPACK_IMPORTED_MODULE_0__.isVConcatSpec)\n/* harmony export */ });\n/* harmony import */ var _concat__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./concat */ \"../../node_modules/vega-lite/build/src/spec/concat.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _layer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./layer */ \"../../node_modules/vega-lite/build/src/spec/layer.js\");\n/* harmony import */ var _repeat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./repeat */ \"../../node_modules/vega-lite/build/src/spec/repeat.js\");\n/* harmony import */ var _unit__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n\n\n\n\n\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/index.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/layer.js":
/*!************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/layer.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isLayerSpec: () => (/* binding */ isLayerSpec)\n/* harmony export */ });\nfunction isLayerSpec(spec) {\n    return 'layer' in spec;\n}\n//# sourceMappingURL=layer.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/layer.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/map.js":
/*!**********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/map.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SpecMapper: () => (/* binding */ SpecMapper)\n/* harmony export */ });\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _concat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./concat */ \"../../node_modules/vega-lite/build/src/spec/concat.js\");\n/* harmony import */ var _facet__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./facet */ \"../../node_modules/vega-lite/build/src/spec/facet.js\");\n/* harmony import */ var _layer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./layer */ \"../../node_modules/vega-lite/build/src/spec/layer.js\");\n/* harmony import */ var _repeat__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./repeat */ \"../../node_modules/vega-lite/build/src/spec/repeat.js\");\n/* harmony import */ var _unit__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./unit */ \"../../node_modules/vega-lite/build/src/spec/unit.js\");\n\n\n\n\n\n\nclass SpecMapper {\n    map(spec, params) {\n        if ((0,_facet__WEBPACK_IMPORTED_MODULE_2__.isFacetSpec)(spec)) {\n            return this.mapFacet(spec, params);\n        }\n        else if ((0,_repeat__WEBPACK_IMPORTED_MODULE_4__.isRepeatSpec)(spec)) {\n            return this.mapRepeat(spec, params);\n        }\n        else if ((0,_concat__WEBPACK_IMPORTED_MODULE_1__.isHConcatSpec)(spec)) {\n            return this.mapHConcat(spec, params);\n        }\n        else if ((0,_concat__WEBPACK_IMPORTED_MODULE_1__.isVConcatSpec)(spec)) {\n            return this.mapVConcat(spec, params);\n        }\n        else if ((0,_concat__WEBPACK_IMPORTED_MODULE_1__.isConcatSpec)(spec)) {\n            return this.mapConcat(spec, params);\n        }\n        else {\n            return this.mapLayerOrUnit(spec, params);\n        }\n    }\n    mapLayerOrUnit(spec, params) {\n        if ((0,_layer__WEBPACK_IMPORTED_MODULE_3__.isLayerSpec)(spec)) {\n            return this.mapLayer(spec, params);\n        }\n        else if ((0,_unit__WEBPACK_IMPORTED_MODULE_5__.isUnitSpec)(spec)) {\n            return this.mapUnit(spec, params);\n        }\n        throw new Error(_log__WEBPACK_IMPORTED_MODULE_0__.message.invalidSpec(spec));\n    }\n    mapLayer(spec, params) {\n        return {\n            ...spec,\n            layer: spec.layer.map(subspec => this.mapLayerOrUnit(subspec, params))\n        };\n    }\n    mapHConcat(spec, params) {\n        return {\n            ...spec,\n            hconcat: spec.hconcat.map(subspec => this.map(subspec, params))\n        };\n    }\n    mapVConcat(spec, params) {\n        return {\n            ...spec,\n            vconcat: spec.vconcat.map(subspec => this.map(subspec, params))\n        };\n    }\n    mapConcat(spec, params) {\n        const { concat, ...rest } = spec;\n        return {\n            ...rest,\n            concat: concat.map(subspec => this.map(subspec, params))\n        };\n    }\n    mapFacet(spec, params) {\n        return {\n            // as any is required here since TS cannot infer that FO may only be FieldName or Field, but not RepeatRef\n            ...spec,\n            // TODO: remove \"any\" once we support all facet listed in https://github.com/vega/vega-lite/issues/2760\n            spec: this.map(spec.spec, params)\n        };\n    }\n    mapRepeat(spec, params) {\n        return {\n            ...spec,\n            // as any is required here since TS cannot infer that the output type satisfies the input type\n            spec: this.map(spec.spec, params)\n        };\n    }\n}\n//# sourceMappingURL=map.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/map.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/repeat.js":
/*!*************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/repeat.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isLayerRepeatSpec: () => (/* binding */ isLayerRepeatSpec),\n/* harmony export */   isRepeatSpec: () => (/* binding */ isRepeatSpec)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\nfunction isRepeatSpec(spec) {\n    return 'repeat' in spec;\n}\nfunction isLayerRepeatSpec(spec) {\n    return !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(spec.repeat) && spec.repeat['layer'];\n}\n//# sourceMappingURL=repeat.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/repeat.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/toplevel.js":
/*!***************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/toplevel.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   extractTopLevelProperties: () => (/* binding */ extractTopLevelProperties),\n/* harmony export */   getFitType: () => (/* binding */ getFitType),\n/* harmony export */   isFitType: () => (/* binding */ isFitType)\n/* harmony export */ });\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _compile_common__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../compile/common */ \"../../node_modules/vega-lite/build/src/compile/common.js\");\n\n\nfunction isFitType(autoSizeType) {\n    return autoSizeType === 'fit' || autoSizeType === 'fit-x' || autoSizeType === 'fit-y';\n}\nfunction getFitType(sizeType) {\n    return sizeType ? `fit-${(0,_channel__WEBPACK_IMPORTED_MODULE_0__.getPositionScaleChannel)(sizeType)}` : 'fit';\n}\nconst TOP_LEVEL_PROPERTIES = [\n    'background',\n    'padding'\n    // We do not include \"autosize\" here as it is supported by only unit and layer specs and thus need to be normalized\n];\nfunction extractTopLevelProperties(t, includeParams) {\n    const o = {};\n    for (const p of TOP_LEVEL_PROPERTIES) {\n        if (t && t[p] !== undefined) {\n            o[p] = (0,_compile_common__WEBPACK_IMPORTED_MODULE_1__.signalRefOrValue)(t[p]);\n        }\n    }\n    if (includeParams) {\n        o.params = t.params;\n    }\n    return o;\n}\n//# sourceMappingURL=toplevel.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/toplevel.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/spec/unit.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/spec/unit.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isUnitSpec: () => (/* binding */ isUnitSpec)\n/* harmony export */ });\nfunction isUnitSpec(spec) {\n    return 'mark' in spec;\n}\n//# sourceMappingURL=unit.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/spec/unit.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/stack.js":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/stack.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   STACKABLE_MARKS: () => (/* binding */ STACKABLE_MARKS),\n/* harmony export */   STACK_BY_DEFAULT_MARKS: () => (/* binding */ STACK_BY_DEFAULT_MARKS),\n/* harmony export */   isStackOffset: () => (/* binding */ isStackOffset),\n/* harmony export */   stack: () => (/* binding */ stack)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _aggregate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./aggregate */ \"../../node_modules/vega-lite/build/src/aggregate.js\");\n/* harmony import */ var _channel__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./channel */ \"../../node_modules/vega-lite/build/src/channel.js\");\n/* harmony import */ var _channeldef__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./channeldef */ \"../../node_modules/vega-lite/build/src/channeldef.js\");\n/* harmony import */ var _encoding__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./encoding */ \"../../node_modules/vega-lite/build/src/encoding.js\");\n/* harmony import */ var _log__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./log */ \"../../node_modules/vega-lite/build/src/log/index.js\");\n/* harmony import */ var _mark__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./mark */ \"../../node_modules/vega-lite/build/src/mark.js\");\n/* harmony import */ var _scale__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./scale */ \"../../node_modules/vega-lite/build/src/scale.js\");\n\n\n\n\n\n\n\n\nconst STACK_OFFSET_INDEX = {\n    zero: 1,\n    center: 1,\n    normalize: 1\n};\nfunction isStackOffset(s) {\n    return s in STACK_OFFSET_INDEX;\n}\nconst STACKABLE_MARKS = new Set([_mark__WEBPACK_IMPORTED_MODULE_6__.ARC, _mark__WEBPACK_IMPORTED_MODULE_6__.BAR, _mark__WEBPACK_IMPORTED_MODULE_6__.AREA, _mark__WEBPACK_IMPORTED_MODULE_6__.RULE, _mark__WEBPACK_IMPORTED_MODULE_6__.POINT, _mark__WEBPACK_IMPORTED_MODULE_6__.CIRCLE, _mark__WEBPACK_IMPORTED_MODULE_6__.SQUARE, _mark__WEBPACK_IMPORTED_MODULE_6__.LINE, _mark__WEBPACK_IMPORTED_MODULE_6__.TEXT, _mark__WEBPACK_IMPORTED_MODULE_6__.TICK]);\nconst STACK_BY_DEFAULT_MARKS = new Set([_mark__WEBPACK_IMPORTED_MODULE_6__.BAR, _mark__WEBPACK_IMPORTED_MODULE_6__.AREA, _mark__WEBPACK_IMPORTED_MODULE_6__.ARC]);\nfunction isUnbinnedQuantitative(channelDef) {\n    return (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(channelDef) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.channelDefType)(channelDef) === 'quantitative' && !channelDef.bin;\n}\nfunction potentialStackedChannel(encoding, x, { orient, type: mark }) {\n    const y = x === 'x' ? 'y' : 'radius';\n    const isCartesian = x === 'x';\n    const xDef = encoding[x];\n    const yDef = encoding[y];\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(xDef) && (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(yDef)) {\n        if (isUnbinnedQuantitative(xDef) && isUnbinnedQuantitative(yDef)) {\n            if (xDef.stack) {\n                return x;\n            }\n            else if (yDef.stack) {\n                return y;\n            }\n            const xAggregate = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(xDef) && !!xDef.aggregate;\n            const yAggregate = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(yDef) && !!yDef.aggregate;\n            // if there is no explicit stacking, only apply stack if there is only one aggregate for x or y\n            if (xAggregate !== yAggregate) {\n                return xAggregate ? x : y;\n            }\n            if (isCartesian && ['bar', 'area'].includes(mark)) {\n                if (orient === 'vertical') {\n                    return y;\n                }\n                else if (orient === 'horizontal') {\n                    return x;\n                }\n            }\n        }\n        else if (isUnbinnedQuantitative(xDef)) {\n            return x;\n        }\n        else if (isUnbinnedQuantitative(yDef)) {\n            return y;\n        }\n    }\n    else if (isUnbinnedQuantitative(xDef)) {\n        return x;\n    }\n    else if (isUnbinnedQuantitative(yDef)) {\n        return y;\n    }\n    return undefined;\n}\nfunction getDimensionChannel(channel) {\n    switch (channel) {\n        case 'x':\n            return 'y';\n        case 'y':\n            return 'x';\n        case 'theta':\n            return 'radius';\n        case 'radius':\n            return 'theta';\n    }\n}\nfunction stack(m, encoding) {\n    const markDef = (0,_mark__WEBPACK_IMPORTED_MODULE_6__.isMarkDef)(m) ? m : { type: m };\n    const mark = markDef.type;\n    // Should have stackable mark\n    if (!STACKABLE_MARKS.has(mark)) {\n        return null;\n    }\n    // Run potential stacked twice, one for Cartesian and another for Polar,\n    // so text marks can be stacked in any of the coordinates.\n    // Note: The logic here is not perfectly correct.  If we want to support stacked dot plots where each dot is a pie chart with label, we have to change the stack logic here to separate Cartesian stacking for polar stacking.\n    // However, since we probably never want to do that, let's just note the limitation here.\n    const fieldChannel = potentialStackedChannel(encoding, 'x', markDef) || potentialStackedChannel(encoding, 'theta', markDef);\n    if (!fieldChannel) {\n        return null;\n    }\n    const stackedFieldDef = encoding[fieldChannel];\n    const stackedField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(stackedFieldDef) ? (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(stackedFieldDef, {}) : undefined;\n    const dimensionChannel = getDimensionChannel(fieldChannel);\n    const groupbyChannels = [];\n    const groupbyFields = new Set();\n    if (encoding[dimensionChannel]) {\n        const dimensionDef = encoding[dimensionChannel];\n        const dimensionField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(dimensionDef) ? (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(dimensionDef, {}) : undefined;\n        if (dimensionField && dimensionField !== stackedField) {\n            // avoid grouping by the stacked field\n            groupbyChannels.push(dimensionChannel);\n            groupbyFields.add(dimensionField);\n        }\n        const dimensionOffsetChannel = dimensionChannel === 'x' ? 'xOffset' : 'yOffset';\n        const dimensionOffsetDef = encoding[dimensionOffsetChannel];\n        const dimensionOffsetField = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(dimensionOffsetDef) ? (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(dimensionOffsetDef, {}) : undefined;\n        if (dimensionOffsetField && dimensionOffsetField !== stackedField) {\n            // avoid grouping by the stacked field\n            groupbyChannels.push(dimensionOffsetChannel);\n            groupbyFields.add(dimensionOffsetField);\n        }\n    }\n    // If the dimension has offset, don't stack anymore\n    // Should have grouping level of detail that is different from the dimension field\n    const stackBy = _channel__WEBPACK_IMPORTED_MODULE_2__.NONPOSITION_CHANNELS.reduce((sc, channel) => {\n        // Ignore tooltip in stackBy (https://github.com/vega/vega-lite/issues/4001)\n        if (channel !== 'tooltip' && (0,_encoding__WEBPACK_IMPORTED_MODULE_4__.channelHasField)(encoding, channel)) {\n            const channelDef = encoding[channel];\n            for (const cDef of (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(channelDef)) {\n                const fieldDef = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.getFieldDef)(cDef);\n                if (fieldDef.aggregate) {\n                    continue;\n                }\n                // Check whether the channel's field is identical to x/y's field or if the channel is a repeat\n                const f = (0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.vgField)(fieldDef, {});\n                if (\n                // if fielddef is a repeat, just include it in the stack by\n                !f ||\n                    // otherwise, the field must be different from the groupBy fields.\n                    !groupbyFields.has(f)) {\n                    sc.push({ channel, fieldDef });\n                }\n            }\n        }\n        return sc;\n    }, []);\n    // Automatically determine offset\n    let offset;\n    if (stackedFieldDef.stack !== undefined) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean)(stackedFieldDef.stack)) {\n            offset = stackedFieldDef.stack ? 'zero' : null;\n        }\n        else {\n            offset = stackedFieldDef.stack;\n        }\n    }\n    else if (STACK_BY_DEFAULT_MARKS.has(mark)) {\n        offset = 'zero';\n    }\n    if (!offset || !isStackOffset(offset)) {\n        return null;\n    }\n    if ((0,_encoding__WEBPACK_IMPORTED_MODULE_4__.isAggregate)(encoding) && stackBy.length === 0) {\n        return null;\n    }\n    // warn when stacking non-linear\n    if (stackedFieldDef?.scale?.type && stackedFieldDef?.scale?.type !== _scale__WEBPACK_IMPORTED_MODULE_7__.ScaleType.LINEAR) {\n        if (stackedFieldDef?.stack) {\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.cannotStackNonLinearScale(stackedFieldDef.scale.type));\n        }\n        return null;\n    }\n    // Check if it is a ranged mark\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldOrDatumDef)(encoding[(0,_channel__WEBPACK_IMPORTED_MODULE_2__.getSecondaryRangeChannel)(fieldChannel)])) {\n        if (stackedFieldDef.stack !== undefined) {\n            _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.cannotStackRangedMark(fieldChannel));\n        }\n        return null;\n    }\n    // Warn if stacking non-summative aggregate\n    if ((0,_channeldef__WEBPACK_IMPORTED_MODULE_3__.isFieldDef)(stackedFieldDef) &&\n        stackedFieldDef.aggregate &&\n        !_aggregate__WEBPACK_IMPORTED_MODULE_1__.SUM_OPS.has(stackedFieldDef.aggregate)) {\n        _log__WEBPACK_IMPORTED_MODULE_5__.warn(_log__WEBPACK_IMPORTED_MODULE_5__.message.stackNonSummativeAggregate(stackedFieldDef.aggregate));\n    }\n    return {\n        groupbyChannels,\n        groupbyFields,\n        fieldChannel,\n        impute: stackedFieldDef.impute === null ? false : (0,_mark__WEBPACK_IMPORTED_MODULE_6__.isPathMark)(mark),\n        stackBy,\n        offset\n    };\n}\n//# sourceMappingURL=stack.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/stack.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/timeunit.js":
/*!**********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/timeunit.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BINNED_TIMEUNIT_INDEX: () => (/* binding */ BINNED_TIMEUNIT_INDEX),\n/* harmony export */   LOCAL_MULTI_TIMEUNIT_INDEX: () => (/* binding */ LOCAL_MULTI_TIMEUNIT_INDEX),\n/* harmony export */   LOCAL_SINGLE_TIMEUNIT_INDEX: () => (/* binding */ LOCAL_SINGLE_TIMEUNIT_INDEX),\n/* harmony export */   TIMEUNIT_PARTS: () => (/* binding */ TIMEUNIT_PARTS),\n/* harmony export */   UTC_MULTI_TIMEUNIT_INDEX: () => (/* binding */ UTC_MULTI_TIMEUNIT_INDEX),\n/* harmony export */   UTC_SINGLE_TIMEUNIT_INDEX: () => (/* binding */ UTC_SINGLE_TIMEUNIT_INDEX),\n/* harmony export */   VEGALITE_TIMEFORMAT: () => (/* binding */ VEGALITE_TIMEFORMAT),\n/* harmony export */   containsTimeUnit: () => (/* binding */ containsTimeUnit),\n/* harmony export */   durationExpr: () => (/* binding */ durationExpr),\n/* harmony export */   fieldExpr: () => (/* binding */ fieldExpr),\n/* harmony export */   formatExpression: () => (/* binding */ formatExpression),\n/* harmony export */   getDateTimePartAndStep: () => (/* binding */ getDateTimePartAndStep),\n/* harmony export */   getLocalTimeUnitFromUTCTimeUnit: () => (/* binding */ getLocalTimeUnitFromUTCTimeUnit),\n/* harmony export */   getSmallestTimeUnitPart: () => (/* binding */ getSmallestTimeUnitPart),\n/* harmony export */   getTimeUnitParts: () => (/* binding */ getTimeUnitParts),\n/* harmony export */   isBinnedTimeUnit: () => (/* binding */ isBinnedTimeUnit),\n/* harmony export */   isBinnedTimeUnitString: () => (/* binding */ isBinnedTimeUnitString),\n/* harmony export */   isDatePart: () => (/* binding */ isDatePart),\n/* harmony export */   isLocalSingleTimeUnit: () => (/* binding */ isLocalSingleTimeUnit),\n/* harmony export */   isUTCTimeUnit: () => (/* binding */ isUTCTimeUnit),\n/* harmony export */   normalizeTimeUnit: () => (/* binding */ normalizeTimeUnit),\n/* harmony export */   timeUnitSpecifierExpression: () => (/* binding */ timeUnitSpecifierExpression),\n/* harmony export */   timeUnitToString: () => (/* binding */ timeUnitToString)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./datetime */ \"../../node_modules/vega-lite/build/src/datetime.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\n\n/** Time Unit that only corresponds to only one part of Date objects. */\nconst LOCAL_SINGLE_TIMEUNIT_INDEX = {\n    year: 1,\n    quarter: 1,\n    month: 1,\n    week: 1,\n    day: 1,\n    dayofyear: 1,\n    date: 1,\n    hours: 1,\n    minutes: 1,\n    seconds: 1,\n    milliseconds: 1\n};\nconst TIMEUNIT_PARTS = (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(LOCAL_SINGLE_TIMEUNIT_INDEX);\nfunction isLocalSingleTimeUnit(timeUnit) {\n    return !!LOCAL_SINGLE_TIMEUNIT_INDEX[timeUnit];\n}\nconst UTC_SINGLE_TIMEUNIT_INDEX = {\n    utcyear: 1,\n    utcquarter: 1,\n    utcmonth: 1,\n    utcweek: 1,\n    utcday: 1,\n    utcdayofyear: 1,\n    utcdate: 1,\n    utchours: 1,\n    utcminutes: 1,\n    utcseconds: 1,\n    utcmilliseconds: 1\n};\nconst LOCAL_MULTI_TIMEUNIT_INDEX = {\n    yearquarter: 1,\n    yearquartermonth: 1,\n    yearmonth: 1,\n    yearmonthdate: 1,\n    yearmonthdatehours: 1,\n    yearmonthdatehoursminutes: 1,\n    yearmonthdatehoursminutesseconds: 1,\n    yearweek: 1,\n    yearweekday: 1,\n    yearweekdayhours: 1,\n    yearweekdayhoursminutes: 1,\n    yearweekdayhoursminutesseconds: 1,\n    yeardayofyear: 1,\n    quartermonth: 1,\n    monthdate: 1,\n    monthdatehours: 1,\n    monthdatehoursminutes: 1,\n    monthdatehoursminutesseconds: 1,\n    weekday: 1,\n    weeksdayhours: 1,\n    weekdayhoursminutes: 1,\n    weekdayhoursminutesseconds: 1,\n    dayhours: 1,\n    dayhoursminutes: 1,\n    dayhoursminutesseconds: 1,\n    hoursminutes: 1,\n    hoursminutesseconds: 1,\n    minutesseconds: 1,\n    secondsmilliseconds: 1\n};\nconst BINNED_LOCAL_TIMEUNIT_INDEX = {\n    binnedyear: 1,\n    binnedyearquarter: 1,\n    binnedyearquartermonth: 1,\n    binnedyearmonth: 1,\n    binnedyearmonthdate: 1,\n    binnedyearmonthdatehours: 1,\n    binnedyearmonthdatehoursminutes: 1,\n    binnedyearmonthdatehoursminutesseconds: 1,\n    binnedyearweek: 1,\n    binnedyearweekday: 1,\n    binnedyearweekdayhours: 1,\n    binnedyearweekdayhoursminutes: 1,\n    binnedyearweekdayhoursminutesseconds: 1,\n    binnedyeardayofyear: 1\n};\nconst BINNED_UTC_TIMEUNIT_INDEX = {\n    binnedutcyear: 1,\n    binnedutcyearquarter: 1,\n    binnedutcyearquartermonth: 1,\n    binnedutcyearmonth: 1,\n    binnedutcyearmonthdate: 1,\n    binnedutcyearmonthdatehours: 1,\n    binnedutcyearmonthdatehoursminutes: 1,\n    binnedutcyearmonthdatehoursminutesseconds: 1,\n    binnedutcyearweek: 1,\n    binnedutcyearweekday: 1,\n    binnedutcyearweekdayhours: 1,\n    binnedutcyearweekdayhoursminutes: 1,\n    binnedutcyearweekdayhoursminutesseconds: 1,\n    binnedutcyeardayofyear: 1\n};\nconst BINNED_TIMEUNIT_INDEX = {\n    ...BINNED_LOCAL_TIMEUNIT_INDEX,\n    ...BINNED_UTC_TIMEUNIT_INDEX\n};\nfunction isBinnedTimeUnit(timeUnit) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(timeUnit)) {\n        return timeUnit.binned;\n    }\n    return isBinnedTimeUnitString(timeUnit);\n}\nfunction isBinnedTimeUnitString(timeUnit) {\n    return timeUnit && timeUnit.startsWith('binned');\n}\nconst UTC_MULTI_TIMEUNIT_INDEX = {\n    utcyearquarter: 1,\n    utcyearquartermonth: 1,\n    utcyearmonth: 1,\n    utcyearmonthdate: 1,\n    utcyearmonthdatehours: 1,\n    utcyearmonthdatehoursminutes: 1,\n    utcyearmonthdatehoursminutesseconds: 1,\n    utcyearweek: 1,\n    utcyearweekday: 1,\n    utcyearweekdayhours: 1,\n    utcyearweekdayhoursminutes: 1,\n    utcyearweekdayhoursminutesseconds: 1,\n    utcyeardayofyear: 1,\n    utcquartermonth: 1,\n    utcmonthdate: 1,\n    utcmonthdatehours: 1,\n    utcmonthdatehoursminutes: 1,\n    utcmonthdatehoursminutesseconds: 1,\n    utcweekday: 1,\n    utcweeksdayhours: 1,\n    utcweekdayhoursminutes: 1,\n    utcweekdayhoursminutesseconds: 1,\n    utcdayhours: 1,\n    utcdayhoursminutes: 1,\n    utcdayhoursminutesseconds: 1,\n    utchoursminutes: 1,\n    utchoursminutesseconds: 1,\n    utcminutesseconds: 1,\n    utcsecondsmilliseconds: 1\n};\nfunction isUTCTimeUnit(t) {\n    return t.startsWith('utc');\n}\nfunction getLocalTimeUnitFromUTCTimeUnit(t) {\n    return t.substring(3);\n}\n// In order of increasing specificity\nconst VEGALITE_TIMEFORMAT = {\n    'year-month': '%b %Y ',\n    'year-month-date': '%b %d, %Y '\n};\nfunction getTimeUnitParts(timeUnit) {\n    return TIMEUNIT_PARTS.filter(part => containsTimeUnit(timeUnit, part));\n}\nfunction getSmallestTimeUnitPart(timeUnit) {\n    const parts = getTimeUnitParts(timeUnit);\n    return parts[parts.length - 1];\n}\n/** Returns true if fullTimeUnit contains the timeUnit, false otherwise. */\nfunction containsTimeUnit(fullTimeUnit, timeUnit) {\n    const index = fullTimeUnit.indexOf(timeUnit);\n    if (index < 0) {\n        return false;\n    }\n    // exclude milliseconds\n    if (index > 0 && timeUnit === 'seconds' && fullTimeUnit.charAt(index - 1) === 'i') {\n        return false;\n    }\n    // exclude dayofyear\n    if (fullTimeUnit.length > index + 3 && timeUnit === 'day' && fullTimeUnit.charAt(index + 3) === 'o') {\n        return false;\n    }\n    if (index > 0 && timeUnit === 'year' && fullTimeUnit.charAt(index - 1) === 'f') {\n        return false;\n    }\n    return true;\n}\n/**\n * Returns Vega expression for a given timeUnit and fieldRef\n */\nfunction fieldExpr(fullTimeUnit, field, { end } = { end: false }) {\n    const fieldRef = (0,_util__WEBPACK_IMPORTED_MODULE_2__.accessPathWithDatum)(field);\n    const utc = isUTCTimeUnit(fullTimeUnit) ? 'utc' : '';\n    function func(timeUnit) {\n        if (timeUnit === 'quarter') {\n            // quarter starting at 0 (0,3,6,9).\n            return `(${utc}quarter(${fieldRef})-1)`;\n        }\n        else {\n            return `${utc}${timeUnit}(${fieldRef})`;\n        }\n    }\n    let lastTimeUnit;\n    const dateExpr = {};\n    for (const part of TIMEUNIT_PARTS) {\n        if (containsTimeUnit(fullTimeUnit, part)) {\n            dateExpr[part] = func(part);\n            lastTimeUnit = part;\n        }\n    }\n    if (end) {\n        dateExpr[lastTimeUnit] += '+1';\n    }\n    return (0,_datetime__WEBPACK_IMPORTED_MODULE_1__.dateTimeExprToExpr)(dateExpr);\n}\nfunction timeUnitSpecifierExpression(timeUnit) {\n    if (!timeUnit) {\n        return undefined;\n    }\n    const timeUnitParts = getTimeUnitParts(timeUnit);\n    return `timeUnitSpecifier(${(0,_util__WEBPACK_IMPORTED_MODULE_2__.stringify)(timeUnitParts)}, ${(0,_util__WEBPACK_IMPORTED_MODULE_2__.stringify)(VEGALITE_TIMEFORMAT)})`;\n}\n/**\n * Returns the signal expression used for axis labels for a time unit.\n */\nfunction formatExpression(timeUnit, field, isUTCScale) {\n    if (!timeUnit) {\n        return undefined;\n    }\n    const expr = timeUnitSpecifierExpression(timeUnit);\n    // We only use utcFormat for utc scale\n    // For utc time units, the data is already converted as a part of timeUnit transform.\n    // Thus, utc time units should use timeFormat to avoid shifting the time twice.\n    const utc = isUTCScale || isUTCTimeUnit(timeUnit);\n    return `${utc ? 'utc' : 'time'}Format(${field}, ${expr})`;\n}\nfunction normalizeTimeUnit(timeUnit) {\n    if (!timeUnit) {\n        return undefined;\n    }\n    let params;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(timeUnit)) {\n        if (isBinnedTimeUnitString(timeUnit)) {\n            params = {\n                unit: timeUnit.substring(6),\n                binned: true\n            };\n        }\n        else {\n            params = {\n                unit: timeUnit\n            };\n        }\n    }\n    else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(timeUnit)) {\n        params = {\n            ...timeUnit,\n            ...(timeUnit.unit ? { unit: timeUnit.unit } : {})\n        };\n    }\n    if (isUTCTimeUnit(params.unit)) {\n        params.utc = true;\n        params.unit = getLocalTimeUnitFromUTCTimeUnit(params.unit);\n    }\n    return params;\n}\nfunction timeUnitToString(tu) {\n    const { utc, ...rest } = normalizeTimeUnit(tu);\n    if (rest.unit) {\n        return ((utc ? 'utc' : '') +\n            (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(rest)\n                .map(p => (0,_util__WEBPACK_IMPORTED_MODULE_2__.varName)(`${p === 'unit' ? '' : `_${p}_`}${rest[p]}`))\n                .join(''));\n    }\n    else {\n        // when maxbins is specified instead of units\n        return ((utc ? 'utc' : '') +\n            'timeunit' +\n            (0,_util__WEBPACK_IMPORTED_MODULE_2__.keys)(rest)\n                .map(p => (0,_util__WEBPACK_IMPORTED_MODULE_2__.varName)(`_${p}_${rest[p]}`))\n                .join(''));\n    }\n}\nfunction durationExpr(timeUnit, wrap = x => x) {\n    const normalizedTimeUnit = normalizeTimeUnit(timeUnit);\n    const smallestUnitPart = getSmallestTimeUnitPart(normalizedTimeUnit.unit);\n    if (smallestUnitPart && smallestUnitPart !== 'day') {\n        const startDate = {\n            year: 2001,\n            month: 1,\n            date: 1,\n            hours: 0,\n            minutes: 0,\n            seconds: 0,\n            milliseconds: 0\n        };\n        const { step, part } = getDateTimePartAndStep(smallestUnitPart, normalizedTimeUnit.step);\n        const endDate = {\n            ...startDate,\n            [part]: +startDate[part] + step\n        };\n        // Calculate timestamp duration for the smallest unit listed\n        return `${wrap((0,_datetime__WEBPACK_IMPORTED_MODULE_1__.dateTimeToExpr)(endDate))} - ${wrap((0,_datetime__WEBPACK_IMPORTED_MODULE_1__.dateTimeToExpr)(startDate))}`;\n    }\n    return undefined;\n}\nconst DATE_PARTS = {\n    year: 1,\n    month: 1,\n    date: 1,\n    hours: 1,\n    minutes: 1,\n    seconds: 1,\n    milliseconds: 1\n};\nfunction isDatePart(timeUnit) {\n    return !!DATE_PARTS[timeUnit];\n}\nfunction getDateTimePartAndStep(timeUnit, step = 1) {\n    if (isDatePart(timeUnit)) {\n        return { part: timeUnit, step };\n    }\n    switch (timeUnit) {\n        case 'day':\n        case 'dayofyear':\n            return { part: 'date', step };\n        case 'quarter':\n            return { part: 'month', step: step * 3 };\n        case 'week':\n            return { part: 'date', step: step * 7 };\n    }\n}\n//# sourceMappingURL=timeunit.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/timeunit.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/title.js":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/title.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   extractTitleConfig: () => (/* binding */ extractTitleConfig),\n/* harmony export */   isText: () => (/* binding */ isText)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\nfunction extractTitleConfig(titleConfig) {\n    const { \n    // These are non-mark title config that need to be hardcoded\n    anchor, frame, offset, orient, angle, limit, \n    // color needs to be redirect to fill\n    color, \n    // subtitle properties\n    subtitleColor, subtitleFont, subtitleFontSize, subtitleFontStyle, subtitleFontWeight, subtitleLineHeight, subtitlePadding, \n    // The rest are mark config.\n    ...rest } = titleConfig;\n    const titleMarkConfig = {\n        ...rest,\n        ...(color ? { fill: color } : {})\n    };\n    // These are non-mark title config that need to be hardcoded\n    const nonMarkTitleProperties = {\n        ...(anchor ? { anchor } : {}),\n        ...(frame ? { frame } : {}),\n        ...(offset ? { offset } : {}),\n        ...(orient ? { orient } : {}),\n        ...(angle !== undefined ? { angle } : {}),\n        ...(limit !== undefined ? { limit } : {})\n    };\n    // subtitle part can stay in config.title since header titles do not use subtitle\n    const subtitle = {\n        ...(subtitleColor ? { subtitleColor } : {}),\n        ...(subtitleFont ? { subtitleFont } : {}),\n        ...(subtitleFontSize ? { subtitleFontSize } : {}),\n        ...(subtitleFontStyle ? { subtitleFontStyle } : {}),\n        ...(subtitleFontWeight ? { subtitleFontWeight } : {}),\n        ...(subtitleLineHeight ? { subtitleLineHeight } : {}),\n        ...(subtitlePadding ? { subtitlePadding } : {})\n    };\n    const subtitleMarkConfig = (0,_util__WEBPACK_IMPORTED_MODULE_1__.pick)(titleConfig, ['align', 'baseline', 'dx', 'dy', 'limit']);\n    return { titleMarkConfig, subtitleMarkConfig, nonMarkTitleProperties, subtitle };\n}\nfunction isText(v) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(v) || ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(v) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(v[0]));\n}\n//# sourceMappingURL=title.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/title.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/transform.js":
/*!***********************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/transform.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   isAggregate: () => (/* binding */ isAggregate),\n/* harmony export */   isBin: () => (/* binding */ isBin),\n/* harmony export */   isCalculate: () => (/* binding */ isCalculate),\n/* harmony export */   isDensity: () => (/* binding */ isDensity),\n/* harmony export */   isExtent: () => (/* binding */ isExtent),\n/* harmony export */   isFilter: () => (/* binding */ isFilter),\n/* harmony export */   isFlatten: () => (/* binding */ isFlatten),\n/* harmony export */   isFold: () => (/* binding */ isFold),\n/* harmony export */   isImpute: () => (/* binding */ isImpute),\n/* harmony export */   isImputeSequence: () => (/* binding */ isImputeSequence),\n/* harmony export */   isJoinAggregate: () => (/* binding */ isJoinAggregate),\n/* harmony export */   isLoess: () => (/* binding */ isLoess),\n/* harmony export */   isLookup: () => (/* binding */ isLookup),\n/* harmony export */   isLookupData: () => (/* binding */ isLookupData),\n/* harmony export */   isLookupSelection: () => (/* binding */ isLookupSelection),\n/* harmony export */   isPivot: () => (/* binding */ isPivot),\n/* harmony export */   isQuantile: () => (/* binding */ isQuantile),\n/* harmony export */   isRegression: () => (/* binding */ isRegression),\n/* harmony export */   isSample: () => (/* binding */ isSample),\n/* harmony export */   isStack: () => (/* binding */ isStack),\n/* harmony export */   isTimeUnit: () => (/* binding */ isTimeUnit),\n/* harmony export */   isWindow: () => (/* binding */ isWindow),\n/* harmony export */   normalizeTransform: () => (/* binding */ normalizeTransform)\n/* harmony export */ });\n/* harmony import */ var _logical__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./logical */ \"../../node_modules/vega-lite/build/src/logical.js\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./predicate */ \"../../node_modules/vega-lite/build/src/predicate.js\");\n\n\nfunction isFilter(t) {\n    return 'filter' in t;\n}\nfunction isImputeSequence(t) {\n    return t?.['stop'] !== undefined;\n}\nfunction isLookup(t) {\n    return 'lookup' in t;\n}\nfunction isLookupData(from) {\n    return 'data' in from;\n}\nfunction isLookupSelection(from) {\n    return 'param' in from;\n}\nfunction isPivot(t) {\n    return 'pivot' in t;\n}\nfunction isDensity(t) {\n    return 'density' in t;\n}\nfunction isQuantile(t) {\n    return 'quantile' in t;\n}\nfunction isRegression(t) {\n    return 'regression' in t;\n}\nfunction isLoess(t) {\n    return 'loess' in t;\n}\nfunction isSample(t) {\n    return 'sample' in t;\n}\nfunction isWindow(t) {\n    return 'window' in t;\n}\nfunction isJoinAggregate(t) {\n    return 'joinaggregate' in t;\n}\nfunction isFlatten(t) {\n    return 'flatten' in t;\n}\nfunction isCalculate(t) {\n    return 'calculate' in t;\n}\nfunction isBin(t) {\n    return 'bin' in t;\n}\nfunction isImpute(t) {\n    return 'impute' in t;\n}\nfunction isTimeUnit(t) {\n    return 'timeUnit' in t;\n}\nfunction isAggregate(t) {\n    return 'aggregate' in t;\n}\nfunction isStack(t) {\n    return 'stack' in t;\n}\nfunction isFold(t) {\n    return 'fold' in t;\n}\nfunction isExtent(t) {\n    return 'extent' in t && !('density' in t);\n}\nfunction normalizeTransform(transform) {\n    return transform.map(t => {\n        if (isFilter(t)) {\n            return {\n                filter: (0,_logical__WEBPACK_IMPORTED_MODULE_0__.normalizeLogicalComposition)(t.filter, _predicate__WEBPACK_IMPORTED_MODULE_1__.normalizePredicate)\n            };\n        }\n        return t;\n    });\n}\n//# sourceMappingURL=transform.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/transform.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/type.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/type.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GEOJSON: () => (/* binding */ GEOJSON),\n/* harmony export */   NOMINAL: () => (/* binding */ NOMINAL),\n/* harmony export */   ORDINAL: () => (/* binding */ ORDINAL),\n/* harmony export */   QUANTITATIVE: () => (/* binding */ QUANTITATIVE),\n/* harmony export */   TEMPORAL: () => (/* binding */ TEMPORAL),\n/* harmony export */   TYPES: () => (/* binding */ TYPES),\n/* harmony export */   Type: () => (/* binding */ Type),\n/* harmony export */   getFullName: () => (/* binding */ getFullName),\n/* harmony export */   isContinuous: () => (/* binding */ isContinuous),\n/* harmony export */   isDiscrete: () => (/* binding */ isDiscrete),\n/* harmony export */   isType: () => (/* binding */ isType)\n/* harmony export */ });\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n/**\n * Data type based on level of measurement\n */\nconst Type = {\n    quantitative: 'quantitative',\n    ordinal: 'ordinal',\n    temporal: 'temporal',\n    nominal: 'nominal',\n    geojson: 'geojson'\n};\nfunction isType(t) {\n    return t in Type;\n}\nfunction isContinuous(type) {\n    return type === 'quantitative' || type === 'temporal';\n}\nfunction isDiscrete(type) {\n    return type === 'ordinal' || type === 'nominal';\n}\nconst QUANTITATIVE = Type.quantitative;\nconst ORDINAL = Type.ordinal;\nconst TEMPORAL = Type.temporal;\nconst NOMINAL = Type.nominal;\nconst GEOJSON = Type.geojson;\nconst TYPES = (0,_util__WEBPACK_IMPORTED_MODULE_0__.keys)(Type);\n/**\n * Get full, lowercase type name for a given type.\n * @param  type\n * @return Full type name.\n */\nfunction getFullName(type) {\n    if (type) {\n        type = type.toLowerCase();\n        switch (type) {\n            case 'q':\n            case QUANTITATIVE:\n                return 'quantitative';\n            case 't':\n            case TEMPORAL:\n                return 'temporal';\n            case 'o':\n            case ORDINAL:\n                return 'ordinal';\n            case 'n':\n            case NOMINAL:\n                return 'nominal';\n            case GEOJSON:\n                return 'geojson';\n        }\n    }\n    // If we get invalid input, return undefined type.\n    return undefined;\n}\n//# sourceMappingURL=type.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/type.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/util.js":
/*!******************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/util.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   accessPathDepth: () => (/* binding */ accessPathDepth),\n/* harmony export */   accessPathWithDatum: () => (/* binding */ accessPathWithDatum),\n/* harmony export */   contains: () => (/* binding */ contains),\n/* harmony export */   deepEqual: () => (/* binding */ deepEqual),\n/* harmony export */   deleteNestedProperty: () => (/* binding */ deleteNestedProperty),\n/* harmony export */   duplicate: () => (/* binding */ duplicate),\n/* harmony export */   entries: () => (/* binding */ entries),\n/* harmony export */   every: () => (/* binding */ every),\n/* harmony export */   fieldIntersection: () => (/* binding */ fieldIntersection),\n/* harmony export */   flatAccessWithDatum: () => (/* binding */ flatAccessWithDatum),\n/* harmony export */   getFirstDefined: () => (/* binding */ getFirstDefined),\n/* harmony export */   hasIntersection: () => (/* binding */ hasIntersection),\n/* harmony export */   hash: () => (/* binding */ hash),\n/* harmony export */   internalField: () => (/* binding */ internalField),\n/* harmony export */   isBoolean: () => (/* binding */ isBoolean),\n/* harmony export */   isEmpty: () => (/* binding */ isEmpty),\n/* harmony export */   isEqual: () => (/* binding */ isEqual),\n/* harmony export */   isInternalField: () => (/* binding */ isInternalField),\n/* harmony export */   isNullOrFalse: () => (/* binding */ isNullOrFalse),\n/* harmony export */   isNumeric: () => (/* binding */ isNumeric),\n/* harmony export */   keys: () => (/* binding */ keys),\n/* harmony export */   logicalExpr: () => (/* binding */ logicalExpr),\n/* harmony export */   mergeDeep: () => (/* binding */ mergeDeep),\n/* harmony export */   never: () => (/* binding */ never),\n/* harmony export */   normalizeAngle: () => (/* binding */ normalizeAngle),\n/* harmony export */   omit: () => (/* binding */ omit),\n/* harmony export */   pick: () => (/* binding */ pick),\n/* harmony export */   prefixGenerator: () => (/* binding */ prefixGenerator),\n/* harmony export */   removePathFromField: () => (/* binding */ removePathFromField),\n/* harmony export */   replaceAll: () => (/* binding */ replaceAll),\n/* harmony export */   replacePathInField: () => (/* binding */ replacePathInField),\n/* harmony export */   resetIdCounter: () => (/* binding */ resetIdCounter),\n/* harmony export */   setEqual: () => (/* binding */ setEqual),\n/* harmony export */   some: () => (/* binding */ some),\n/* harmony export */   stringify: () => (/* binding */ stringify),\n/* harmony export */   titleCase: () => (/* binding */ titleCase),\n/* harmony export */   unique: () => (/* binding */ unique),\n/* harmony export */   uniqueId: () => (/* binding */ uniqueId),\n/* harmony export */   vals: () => (/* binding */ vals),\n/* harmony export */   varName: () => (/* binding */ varName)\n/* harmony export */ });\n/* harmony import */ var clone__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! clone */ \"../../node_modules/vega-lite/node_modules/clone/clone.js\");\n/* harmony import */ var clone__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(clone__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var fast_deep_equal__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! fast-deep-equal */ \"../../node_modules/fast-deep-equal/index.js\");\n/* harmony import */ var fast_deep_equal__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(fast_deep_equal__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! fast-json-stable-stringify */ \"../../node_modules/fast-json-stable-stringify/index.js\");\n/* harmony import */ var fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _logical__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./logical */ \"../../node_modules/vega-lite/build/src/logical.js\");\n\n\n\n\n\nconst deepEqual = (fast_deep_equal__WEBPACK_IMPORTED_MODULE_1___default());\nconst duplicate = (clone__WEBPACK_IMPORTED_MODULE_0___default());\nfunction never(message) {\n    throw new Error(message);\n}\n/**\n * Creates an object composed of the picked object properties.\n *\n * var object = {'a': 1, 'b': '2', 'c': 3};\n * pick(object, ['a', 'c']);\n * // → {'a': 1, 'c': 3}\n */\n// eslint-disable-next-line @typescript-eslint/ban-types\nfunction pick(obj, props) {\n    const copy = {};\n    for (const prop of props) {\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_3__.hasOwnProperty)(obj, prop)) {\n            copy[prop] = obj[prop];\n        }\n    }\n    return copy;\n}\n/**\n * The opposite of _.pick; this method creates an object composed of the own\n * and inherited enumerable string keyed properties of object that are not omitted.\n */\n// eslint-disable-next-line @typescript-eslint/ban-types\nfunction omit(obj, props) {\n    const copy = { ...obj };\n    for (const prop of props) {\n        delete copy[prop];\n    }\n    return copy;\n}\n/**\n * Monkey patch Set so that `stringify` produces a string representation of sets.\n */\nSet.prototype['toJSON'] = function () {\n    return `Set(${[...this].map(x => fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2___default()(x)).join(',')})`;\n};\n/**\n * Converts any object to a string representation that can be consumed by humans.\n */\nconst stringify = (fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2___default());\n/**\n * Converts any object to a string of limited size, or a number.\n */\nfunction hash(a) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_3__.isNumber)(a)) {\n        return a;\n    }\n    const str = (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.isString)(a) ? a : fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_2___default()(a);\n    // short strings can be used as hash directly, longer strings are hashed to reduce memory usage\n    if (str.length < 250) {\n        return str;\n    }\n    // from http://werxltd.com/wp/2010/05/13/javascript-implementation-of-javas-string-hashcode-method/\n    let h = 0;\n    for (let i = 0; i < str.length; i++) {\n        const char = str.charCodeAt(i);\n        h = (h << 5) - h + char;\n        h = h & h; // Convert to 32bit integer\n    }\n    return h;\n}\nfunction isNullOrFalse(x) {\n    return x === false || x === null;\n}\nfunction contains(array, item) {\n    return array.includes(item);\n}\n/**\n * Returns true if any item returns true.\n */\nfunction some(arr, f) {\n    let i = 0;\n    for (const [k, a] of arr.entries()) {\n        if (f(a, k, i++)) {\n            return true;\n        }\n    }\n    return false;\n}\n/**\n * Returns true if all items return true.\n */\nfunction every(arr, f) {\n    let i = 0;\n    for (const [k, a] of arr.entries()) {\n        if (!f(a, k, i++)) {\n            return false;\n        }\n    }\n    return true;\n}\n/**\n * recursively merges src into dest\n */\nfunction mergeDeep(dest, ...src) {\n    for (const s of src) {\n        deepMerge_(dest, s ?? {});\n    }\n    return dest;\n}\nfunction deepMerge_(dest, src) {\n    for (const property of keys(src)) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.writeConfig)(dest, property, src[property], true);\n    }\n}\nfunction unique(values, f) {\n    const results = [];\n    const u = {};\n    let v;\n    for (const val of values) {\n        v = f(val);\n        if (v in u) {\n            continue;\n        }\n        u[v] = 1;\n        results.push(val);\n    }\n    return results;\n}\n/**\n * Returns true if the two dictionaries disagree. Applies only to defined values.\n */\nfunction isEqual(dict, other) {\n    const dictKeys = keys(dict);\n    const otherKeys = keys(other);\n    if (dictKeys.length !== otherKeys.length) {\n        return false;\n    }\n    for (const key of dictKeys) {\n        if (dict[key] !== other[key]) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction setEqual(a, b) {\n    if (a.size !== b.size) {\n        return false;\n    }\n    for (const e of a) {\n        if (!b.has(e)) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction hasIntersection(a, b) {\n    for (const key of a) {\n        if (b.has(key)) {\n            return true;\n        }\n    }\n    return false;\n}\nfunction prefixGenerator(a) {\n    const prefixes = new Set();\n    for (const x of a) {\n        const splitField = (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(x);\n        // Wrap every element other than the first in `[]`\n        const wrappedWithAccessors = splitField.map((y, i) => (i === 0 ? y : `[${y}]`));\n        const computedPrefixes = wrappedWithAccessors.map((_, i) => wrappedWithAccessors.slice(0, i + 1).join(''));\n        for (const y of computedPrefixes) {\n            prefixes.add(y);\n        }\n    }\n    return prefixes;\n}\n/**\n * Returns true if a and b have an intersection. Also return true if a or b are undefined\n * since this means we don't know what fields a node produces or depends on.\n */\nfunction fieldIntersection(a, b) {\n    if (a === undefined || b === undefined) {\n        return true;\n    }\n    return hasIntersection(prefixGenerator(a), prefixGenerator(b));\n}\n// eslint-disable-next-line @typescript-eslint/ban-types\nfunction isEmpty(obj) {\n    return keys(obj).length === 0;\n}\n// This is a stricter version of Object.keys but with better types. See https://github.com/Microsoft/TypeScript/pull/12253#issuecomment-263132208\nconst keys = Object.keys;\nconst vals = Object.values;\nconst entries = Object.entries;\nfunction isBoolean(b) {\n    return b === true || b === false;\n}\n/**\n * Convert a string into a valid variable name\n */\nfunction varName(s) {\n    // Replace non-alphanumeric characters (anything besides a-zA-Z0-9_) with _\n    const alphanumericS = s.replace(/\\W/g, '_');\n    // Add _ if the string has leading numbers.\n    return (s.match(/^\\d+/) ? '_' : '') + alphanumericS;\n}\nfunction logicalExpr(op, cb) {\n    if ((0,_logical__WEBPACK_IMPORTED_MODULE_4__.isLogicalNot)(op)) {\n        return `!(${logicalExpr(op.not, cb)})`;\n    }\n    else if ((0,_logical__WEBPACK_IMPORTED_MODULE_4__.isLogicalAnd)(op)) {\n        return `(${op.and.map((and) => logicalExpr(and, cb)).join(') && (')})`;\n    }\n    else if ((0,_logical__WEBPACK_IMPORTED_MODULE_4__.isLogicalOr)(op)) {\n        return `(${op.or.map((or) => logicalExpr(or, cb)).join(') || (')})`;\n    }\n    else {\n        return cb(op);\n    }\n}\n/**\n * Delete nested property of an object, and delete the ancestors of the property if they become empty.\n */\nfunction deleteNestedProperty(obj, orderedProps) {\n    if (orderedProps.length === 0) {\n        return true;\n    }\n    const prop = orderedProps.shift(); // eslint-disable-line @typescript-eslint/no-non-null-assertion\n    if (prop in obj && deleteNestedProperty(obj[prop], orderedProps)) {\n        delete obj[prop];\n    }\n    return isEmpty(obj);\n}\nfunction titleCase(s) {\n    return s.charAt(0).toUpperCase() + s.substr(1);\n}\n/**\n * Converts a path to an access path with datum.\n * @param path The field name.\n * @param datum The string to use for `datum`.\n */\nfunction accessPathWithDatum(path, datum = 'datum') {\n    const pieces = (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(path);\n    const prefixes = [];\n    for (let i = 1; i <= pieces.length; i++) {\n        const prefix = `[${pieces.slice(0, i).map(vega_util__WEBPACK_IMPORTED_MODULE_3__.stringValue).join('][')}]`;\n        prefixes.push(`${datum}${prefix}`);\n    }\n    return prefixes.join(' && ');\n}\n/**\n * Return access with datum to the flattened field.\n *\n * @param path The field name.\n * @param datum The string to use for `datum`.\n */\nfunction flatAccessWithDatum(path, datum = 'datum') {\n    return `${datum}[${(0,vega_util__WEBPACK_IMPORTED_MODULE_3__.stringValue)((0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(path).join('.'))}]`;\n}\nfunction escapePathAccess(string) {\n    return string.replace(/(\\[|\\]|\\.|'|\")/g, '\\\\$1');\n}\n/**\n * Replaces path accesses with access to non-nested field.\n * For example, `foo[\"bar\"].baz` becomes `foo\\\\.bar\\\\.baz`.\n */\nfunction replacePathInField(path) {\n    return `${(0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(path).map(escapePathAccess).join('\\\\.')}`;\n}\n/**\n * Replace all occurrences of a string with another string.\n *\n * @param string the string to replace in\n * @param find the string to replace\n * @param replacement the replacement\n */\nfunction replaceAll(string, find, replacement) {\n    return string.replace(new RegExp(find.replace(/[-/\\\\^$*+?.()|[\\]{}]/g, '\\\\$&'), 'g'), replacement);\n}\n/**\n * Remove path accesses with access from field.\n * For example, `foo[\"bar\"].baz` becomes `foo.bar.baz`.\n */\nfunction removePathFromField(path) {\n    return `${(0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(path).join('.')}`;\n}\n/**\n * Count the depth of the path. Returns 1 for fields that are not nested.\n */\nfunction accessPathDepth(path) {\n    if (!path) {\n        return 0;\n    }\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_3__.splitAccessPath)(path).length;\n}\n/**\n * This is a replacement for chained || for numeric properties or properties that respect null so that 0 will be included.\n */\nfunction getFirstDefined(...args) {\n    for (const arg of args) {\n        if (arg !== undefined) {\n            return arg;\n        }\n    }\n    return undefined;\n}\n// variable used to generate id\nlet idCounter = 42;\n/**\n * Returns a new random id every time it gets called.\n *\n * Has side effect!\n */\nfunction uniqueId(prefix) {\n    const id = ++idCounter;\n    return prefix ? String(prefix) + id : id;\n}\n/**\n * Resets the id counter used in uniqueId. This can be useful for testing.\n */\nfunction resetIdCounter() {\n    idCounter = 42;\n}\nfunction internalField(name) {\n    return isInternalField(name) ? name : `__${name}`;\n}\nfunction isInternalField(name) {\n    return name.startsWith('__');\n}\n/**\n * Normalize angle to be within [0,360).\n */\nfunction normalizeAngle(angle) {\n    if (angle === undefined) {\n        return undefined;\n    }\n    return ((angle % 360) + 360) % 360;\n}\n/**\n * Returns whether the passed in value is a valid number.\n */\nfunction isNumeric(value) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_3__.isNumber)(value)) {\n        return true;\n    }\n    return !isNaN(value) && !isNaN(parseFloat(value));\n}\n//# sourceMappingURL=util.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/util.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/src/vega.schema.js":
/*!*************************************************************!*\
  !*** ../../node_modules/vega-lite/build/src/vega.schema.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   VG_CORNERRADIUS_CHANNELS: () => (/* binding */ VG_CORNERRADIUS_CHANNELS),\n/* harmony export */   VG_MARK_CONFIGS: () => (/* binding */ VG_MARK_CONFIGS),\n/* harmony export */   VG_MARK_INDEX: () => (/* binding */ VG_MARK_INDEX),\n/* harmony export */   isDataRefDomain: () => (/* binding */ isDataRefDomain),\n/* harmony export */   isDataRefUnionedDomain: () => (/* binding */ isDataRefUnionedDomain),\n/* harmony export */   isFieldRefUnionDomain: () => (/* binding */ isFieldRefUnionDomain),\n/* harmony export */   isSignalRef: () => (/* binding */ isSignalRef),\n/* harmony export */   isVgRangeStep: () => (/* binding */ isVgRangeStep)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util */ \"../../node_modules/vega-lite/build/src/util.js\");\n\n\nfunction isSignalRef(o) {\n    return !!o?.signal;\n}\nfunction isVgRangeStep(range) {\n    return !!range['step'];\n}\nfunction isDataRefUnionedDomain(domain) {\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain)) {\n        return 'fields' in domain && !('data' in domain);\n    }\n    return false;\n}\nfunction isFieldRefUnionDomain(domain) {\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain)) {\n        return 'fields' in domain && 'data' in domain;\n    }\n    return false;\n}\nfunction isDataRefDomain(domain) {\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain)) {\n        return 'field' in domain && 'data' in domain;\n    }\n    return false;\n}\nconst VG_MARK_CONFIG_INDEX = {\n    aria: 1,\n    description: 1,\n    ariaRole: 1,\n    ariaRoleDescription: 1,\n    blend: 1,\n    opacity: 1,\n    fill: 1,\n    fillOpacity: 1,\n    stroke: 1,\n    strokeCap: 1,\n    strokeWidth: 1,\n    strokeOpacity: 1,\n    strokeDash: 1,\n    strokeDashOffset: 1,\n    strokeJoin: 1,\n    strokeOffset: 1,\n    strokeMiterLimit: 1,\n    startAngle: 1,\n    endAngle: 1,\n    padAngle: 1,\n    innerRadius: 1,\n    outerRadius: 1,\n    size: 1,\n    shape: 1,\n    interpolate: 1,\n    tension: 1,\n    orient: 1,\n    align: 1,\n    baseline: 1,\n    text: 1,\n    dir: 1,\n    dx: 1,\n    dy: 1,\n    ellipsis: 1,\n    limit: 1,\n    radius: 1,\n    theta: 1,\n    angle: 1,\n    font: 1,\n    fontSize: 1,\n    fontWeight: 1,\n    fontStyle: 1,\n    lineBreak: 1,\n    lineHeight: 1,\n    cursor: 1,\n    href: 1,\n    tooltip: 1,\n    cornerRadius: 1,\n    cornerRadiusTopLeft: 1,\n    cornerRadiusTopRight: 1,\n    cornerRadiusBottomLeft: 1,\n    cornerRadiusBottomRight: 1,\n    aspect: 1,\n    width: 1,\n    height: 1,\n    url: 1,\n    smooth: 1\n    // commented below are vg channel that do not have mark config.\n    // x: 1,\n    // y: 1,\n    // x2: 1,\n    // y2: 1,\n    // xc'|'yc'\n    // clip: 1,\n    // path: 1,\n    // url: 1,\n};\nconst VG_MARK_CONFIGS = (0,_util__WEBPACK_IMPORTED_MODULE_1__.keys)(VG_MARK_CONFIG_INDEX);\nconst VG_MARK_INDEX = {\n    arc: 1,\n    area: 1,\n    group: 1,\n    image: 1,\n    line: 1,\n    path: 1,\n    rect: 1,\n    rule: 1,\n    shape: 1,\n    symbol: 1,\n    text: 1,\n    trail: 1\n};\n// Vega's cornerRadius channels.\nconst VG_CORNERRADIUS_CHANNELS = [\n    'cornerRadius',\n    'cornerRadiusTopLeft',\n    'cornerRadiusTopRight',\n    'cornerRadiusBottomLeft',\n    'cornerRadiusBottomRight'\n];\n//# sourceMappingURL=vega.schema.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/src/vega.schema.js?");

/***/ }),

/***/ "../../node_modules/vega-lite/node_modules/clone/clone.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-lite/node_modules/clone/clone.js ***!
  \****************************************************************/
/***/ ((module) => {

eval("var clone = (function() {\n'use strict';\n\nfunction _instanceof(obj, type) {\n  return type != null && obj instanceof type;\n}\n\nvar nativeMap;\ntry {\n  nativeMap = Map;\n} catch(_) {\n  // maybe a reference error because no `Map`. Give it a dummy value that no\n  // value will ever be an instanceof.\n  nativeMap = function() {};\n}\n\nvar nativeSet;\ntry {\n  nativeSet = Set;\n} catch(_) {\n  nativeSet = function() {};\n}\n\nvar nativePromise;\ntry {\n  nativePromise = Promise;\n} catch(_) {\n  nativePromise = function() {};\n}\n\n/**\n * Clones (copies) an Object using deep copying.\n *\n * This function supports circular references by default, but if you are certain\n * there are no circular references in your object, you can save some CPU time\n * by calling clone(obj, false).\n *\n * Caution: if `circular` is false and `parent` contains circular references,\n * your program may enter an infinite loop and crash.\n *\n * @param `parent` - the object to be cloned\n * @param `circular` - set to true if the object to be cloned may contain\n *    circular references. (optional - true by default)\n * @param `depth` - set to a number if the object is only to be cloned to\n *    a particular depth. (optional - defaults to Infinity)\n * @param `prototype` - sets the prototype to be used when cloning an object.\n *    (optional - defaults to parent prototype).\n * @param `includeNonEnumerable` - set to true if the non-enumerable properties\n *    should be cloned as well. Non-enumerable properties on the prototype\n *    chain will be ignored. (optional - false by default)\n*/\nfunction clone(parent, circular, depth, prototype, includeNonEnumerable) {\n  if (typeof circular === 'object') {\n    depth = circular.depth;\n    prototype = circular.prototype;\n    includeNonEnumerable = circular.includeNonEnumerable;\n    circular = circular.circular;\n  }\n  // maintain two arrays for circular references, where corresponding parents\n  // and children have the same index\n  var allParents = [];\n  var allChildren = [];\n\n  var useBuffer = typeof Buffer != 'undefined';\n\n  if (typeof circular == 'undefined')\n    circular = true;\n\n  if (typeof depth == 'undefined')\n    depth = Infinity;\n\n  // recurse this function so we don't reset allParents and allChildren\n  function _clone(parent, depth) {\n    // cloning null always returns null\n    if (parent === null)\n      return null;\n\n    if (depth === 0)\n      return parent;\n\n    var child;\n    var proto;\n    if (typeof parent != 'object') {\n      return parent;\n    }\n\n    if (_instanceof(parent, nativeMap)) {\n      child = new nativeMap();\n    } else if (_instanceof(parent, nativeSet)) {\n      child = new nativeSet();\n    } else if (_instanceof(parent, nativePromise)) {\n      child = new nativePromise(function (resolve, reject) {\n        parent.then(function(value) {\n          resolve(_clone(value, depth - 1));\n        }, function(err) {\n          reject(_clone(err, depth - 1));\n        });\n      });\n    } else if (clone.__isArray(parent)) {\n      child = [];\n    } else if (clone.__isRegExp(parent)) {\n      child = new RegExp(parent.source, __getRegExpFlags(parent));\n      if (parent.lastIndex) child.lastIndex = parent.lastIndex;\n    } else if (clone.__isDate(parent)) {\n      child = new Date(parent.getTime());\n    } else if (useBuffer && Buffer.isBuffer(parent)) {\n      if (Buffer.allocUnsafe) {\n        // Node.js >= 4.5.0\n        child = Buffer.allocUnsafe(parent.length);\n      } else {\n        // Older Node.js versions\n        child = new Buffer(parent.length);\n      }\n      parent.copy(child);\n      return child;\n    } else if (_instanceof(parent, Error)) {\n      child = Object.create(parent);\n    } else {\n      if (typeof prototype == 'undefined') {\n        proto = Object.getPrototypeOf(parent);\n        child = Object.create(proto);\n      }\n      else {\n        child = Object.create(prototype);\n        proto = prototype;\n      }\n    }\n\n    if (circular) {\n      var index = allParents.indexOf(parent);\n\n      if (index != -1) {\n        return allChildren[index];\n      }\n      allParents.push(parent);\n      allChildren.push(child);\n    }\n\n    if (_instanceof(parent, nativeMap)) {\n      parent.forEach(function(value, key) {\n        var keyChild = _clone(key, depth - 1);\n        var valueChild = _clone(value, depth - 1);\n        child.set(keyChild, valueChild);\n      });\n    }\n    if (_instanceof(parent, nativeSet)) {\n      parent.forEach(function(value) {\n        var entryChild = _clone(value, depth - 1);\n        child.add(entryChild);\n      });\n    }\n\n    for (var i in parent) {\n      var attrs;\n      if (proto) {\n        attrs = Object.getOwnPropertyDescriptor(proto, i);\n      }\n\n      if (attrs && attrs.set == null) {\n        continue;\n      }\n      child[i] = _clone(parent[i], depth - 1);\n    }\n\n    if (Object.getOwnPropertySymbols) {\n      var symbols = Object.getOwnPropertySymbols(parent);\n      for (var i = 0; i < symbols.length; i++) {\n        // Don't need to worry about cloning a symbol because it is a primitive,\n        // like a number or string.\n        var symbol = symbols[i];\n        var descriptor = Object.getOwnPropertyDescriptor(parent, symbol);\n        if (descriptor && !descriptor.enumerable && !includeNonEnumerable) {\n          continue;\n        }\n        child[symbol] = _clone(parent[symbol], depth - 1);\n        if (!descriptor.enumerable) {\n          Object.defineProperty(child, symbol, {\n            enumerable: false\n          });\n        }\n      }\n    }\n\n    if (includeNonEnumerable) {\n      var allPropertyNames = Object.getOwnPropertyNames(parent);\n      for (var i = 0; i < allPropertyNames.length; i++) {\n        var propertyName = allPropertyNames[i];\n        var descriptor = Object.getOwnPropertyDescriptor(parent, propertyName);\n        if (descriptor && descriptor.enumerable) {\n          continue;\n        }\n        child[propertyName] = _clone(parent[propertyName], depth - 1);\n        Object.defineProperty(child, propertyName, {\n          enumerable: false\n        });\n      }\n    }\n\n    return child;\n  }\n\n  return _clone(parent, depth);\n}\n\n/**\n * Simple flat clone using prototype, accepts only objects, usefull for property\n * override on FLAT configuration object (no nested props).\n *\n * USE WITH CAUTION! This may not behave as you wish if you do not know how this\n * works.\n */\nclone.clonePrototype = function clonePrototype(parent) {\n  if (parent === null)\n    return null;\n\n  var c = function () {};\n  c.prototype = parent;\n  return new c();\n};\n\n// private utility functions\n\nfunction __objToStr(o) {\n  return Object.prototype.toString.call(o);\n}\nclone.__objToStr = __objToStr;\n\nfunction __isDate(o) {\n  return typeof o === 'object' && __objToStr(o) === '[object Date]';\n}\nclone.__isDate = __isDate;\n\nfunction __isArray(o) {\n  return typeof o === 'object' && __objToStr(o) === '[object Array]';\n}\nclone.__isArray = __isArray;\n\nfunction __isRegExp(o) {\n  return typeof o === 'object' && __objToStr(o) === '[object RegExp]';\n}\nclone.__isRegExp = __isRegExp;\n\nfunction __getRegExpFlags(re) {\n  var flags = '';\n  if (re.global) flags += 'g';\n  if (re.ignoreCase) flags += 'i';\n  if (re.multiline) flags += 'm';\n  return flags;\n}\nclone.__getRegExpFlags = __getRegExpFlags;\n\nreturn clone;\n})();\n\nif ( true && module.exports) {\n  module.exports = clone;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/node_modules/clone/clone.js?");

/***/ }),

/***/ "../../node_modules/vega-loader/build/vega-loader.browser.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-loader/build/vega-loader.browser.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   format: () => (/* binding */ format),\n/* harmony export */   formats: () => (/* binding */ formats),\n/* harmony export */   inferType: () => (/* binding */ inferType),\n/* harmony export */   inferTypes: () => (/* binding */ inferTypes),\n/* harmony export */   loader: () => (/* binding */ loader),\n/* harmony export */   read: () => (/* binding */ read),\n/* harmony export */   responseType: () => (/* binding */ responseType),\n/* harmony export */   typeParsers: () => (/* binding */ typeParsers)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_dsv__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-dsv */ \"../../node_modules/d3-dsv/src/dsv.js\");\n/* harmony import */ var topojson_client__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! topojson-client */ \"../../node_modules/topojson-client/src/index.js\");\n/* harmony import */ var vega_format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-format */ \"../../node_modules/vega-format/build/vega-format.module.js\");\n\n\n\n\n\n// Matches absolute URLs with optional protocol\n//   https://...    file://...    //...\nconst protocol_re = /^(data:|([A-Za-z]+:)?\\/\\/)/;\n\n// Matches allowed URIs. From https://github.com/cure53/DOMPurify/blob/master/src/regexp.js with added file://\nconst allowed_re = /^(?:(?:(?:f|ht)tps?|mailto|tel|callto|cid|xmpp|file|data):|[^a-z]|[a-z+.\\-]+(?:[^a-z+.\\-:]|$))/i; // eslint-disable-line no-useless-escape\nconst whitespace_re = /[\\u0000-\\u0020\\u00A0\\u1680\\u180E\\u2000-\\u2029\\u205f\\u3000]/g; // eslint-disable-line no-control-regex\n\n// Special treatment in node.js for the file: protocol\nconst fileProtocol = 'file://';\n\n/**\n * Factory for a loader constructor that provides methods for requesting\n * files from either the network or disk, and for sanitizing request URIs.\n * @param {function} fetch - The Fetch API for HTTP network requests.\n *   If null or undefined, HTTP loading will be disabled.\n * @param {object} fs - The file system interface for file loading.\n *   If null or undefined, local file loading will be disabled.\n * @return {function} A loader constructor with the following signature:\n *   param {object} [options] - Optional default loading options to use.\n *   return {object} - A new loader instance.\n */\nfunction loaderFactory (fetch, fs) {\n  return options => ({\n    options: options || {},\n    sanitize: sanitize,\n    load: load,\n    fileAccess: !!fs,\n    file: fileLoader(fs),\n    http: httpLoader(fetch)\n  });\n}\n\n/**\n * Load an external resource, typically either from the web or from the local\n * filesystem. This function uses {@link sanitize} to first sanitize the uri,\n * then calls either {@link http} (for web requests) or {@link file} (for\n * filesystem loading).\n * @param {string} uri - The resource indicator (e.g., URL or filename).\n * @param {object} [options] - Optional loading options. These options will\n *   override any existing default options.\n * @return {Promise} - A promise that resolves to the loaded content.\n */\nasync function load(uri, options) {\n  const opt = await this.sanitize(uri, options),\n    url = opt.href;\n  return opt.localFile ? this.file(url) : this.http(url, options);\n}\n\n/**\n * URI sanitizer function.\n * @param {string} uri - The uri (url or filename) to check.\n * @param {object} options - An options hash.\n * @return {Promise} - A promise that resolves to an object containing\n *  sanitized uri data, or rejects it the input uri is deemed invalid.\n *  The properties of the resolved object are assumed to be\n *  valid attributes for an HTML 'a' tag. The sanitized uri *must* be\n *  provided by the 'href' property of the returned object.\n */\nasync function sanitize(uri, options) {\n  options = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, this.options, options);\n  const fileAccess = this.fileAccess,\n    result = {\n      href: null\n    };\n  let isFile, loadFile, base;\n  const isAllowed = allowed_re.test(uri.replace(whitespace_re, ''));\n  if (uri == null || typeof uri !== 'string' || !isAllowed) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Sanitize failure, invalid URI: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(uri));\n  }\n  const hasProtocol = protocol_re.test(uri);\n\n  // if relative url (no protocol/host), prepend baseURL\n  if ((base = options.baseURL) && !hasProtocol) {\n    // Ensure that there is a slash between the baseURL (e.g. hostname) and url\n    if (!uri.startsWith('/') && !base.endsWith('/')) {\n      uri = '/' + uri;\n    }\n    uri = base + uri;\n  }\n\n  // should we load from file system?\n  loadFile = (isFile = uri.startsWith(fileProtocol)) || options.mode === 'file' || options.mode !== 'http' && !hasProtocol && fileAccess;\n  if (isFile) {\n    // strip file protocol\n    uri = uri.slice(fileProtocol.length);\n  } else if (uri.startsWith('//')) {\n    if (options.defaultProtocol === 'file') {\n      // if is file, strip protocol and set loadFile flag\n      uri = uri.slice(2);\n      loadFile = true;\n    } else {\n      // if relative protocol (starts with '//'), prepend default protocol\n      uri = (options.defaultProtocol || 'http') + ':' + uri;\n    }\n  }\n\n  // set non-enumerable mode flag to indicate local file load\n  Object.defineProperty(result, 'localFile', {\n    value: !!loadFile\n  });\n\n  // set uri\n  result.href = uri;\n\n  // set default result target, if specified\n  if (options.target) {\n    result.target = options.target + '';\n  }\n\n  // set default result rel, if specified (#1542)\n  if (options.rel) {\n    result.rel = options.rel + '';\n  }\n\n  // provide control over cross-origin image handling (#2238)\n  // https://developer.mozilla.org/en-US/docs/Web/HTML/CORS_enabled_image\n  if (options.context === 'image' && options.crossOrigin) {\n    result.crossOrigin = options.crossOrigin + '';\n  }\n\n  // return\n  return result;\n}\n\n/**\n * File system loader factory.\n * @param {object} fs - The file system interface.\n * @return {function} - A file loader with the following signature:\n *   param {string} filename - The file system path to load.\n *   param {string} filename - The file system path to load.\n *   return {Promise} A promise that resolves to the file contents.\n */\nfunction fileLoader(fs) {\n  return fs ? filename => new Promise((accept, reject) => {\n    fs.readFile(filename, (error, data) => {\n      if (error) reject(error);else accept(data);\n    });\n  }) : fileReject;\n}\n\n/**\n * Default file system loader that simply rejects.\n */\nasync function fileReject() {\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('No file system access.');\n}\n\n/**\n * HTTP request handler factory.\n * @param {function} fetch - The Fetch API method.\n * @return {function} - An http loader with the following signature:\n *   param {string} url - The url to request.\n *   param {object} options - An options hash.\n *   return {Promise} - A promise that resolves to the file contents.\n */\nfunction httpLoader(fetch) {\n  return fetch ? async function (url, options) {\n    const opt = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, this.options.http, options),\n      type = options && options.response,\n      response = await fetch(url, opt);\n    return !response.ok ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)(response.status + '' + response.statusText) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(response[type]) ? response[type]() : response.text();\n  } : httpReject;\n}\n\n/**\n * Default http request handler that simply rejects.\n */\nasync function httpReject() {\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('No HTTP fetch method available.');\n}\n\nconst isValid = _ => _ != null && _ === _;\nconst isBoolean = _ => _ === 'true' || _ === 'false' || _ === true || _ === false;\nconst isDate = _ => !Number.isNaN(Date.parse(_));\nconst isNumber = _ => !Number.isNaN(+_) && !(_ instanceof Date);\nconst isInteger = _ => isNumber(_) && Number.isInteger(+_);\nconst typeParsers = {\n  boolean: vega_util__WEBPACK_IMPORTED_MODULE_0__.toBoolean,\n  integer: vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber,\n  number: vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber,\n  date: vega_util__WEBPACK_IMPORTED_MODULE_0__.toDate,\n  string: vega_util__WEBPACK_IMPORTED_MODULE_0__.toString,\n  unknown: vega_util__WEBPACK_IMPORTED_MODULE_0__.identity\n};\nconst typeTests = [isBoolean, isInteger, isNumber, isDate];\nconst typeList = ['boolean', 'integer', 'number', 'date'];\nfunction inferType(values, field) {\n  if (!values || !values.length) return 'unknown';\n  const n = values.length,\n    m = typeTests.length,\n    a = typeTests.map((_, i) => i + 1);\n  for (let i = 0, t = 0, j, value; i < n; ++i) {\n    value = field ? values[i][field] : values[i];\n    for (j = 0; j < m; ++j) {\n      if (a[j] && isValid(value) && !typeTests[j](value)) {\n        a[j] = 0;\n        ++t;\n        if (t === typeTests.length) return 'string';\n      }\n    }\n  }\n  return typeList[a.reduce((u, v) => u === 0 ? v : u, 0) - 1];\n}\nfunction inferTypes(data, fields) {\n  return fields.reduce((types, field) => {\n    types[field] = inferType(data, field);\n    return types;\n  }, {});\n}\n\nfunction delimitedFormat(delimiter) {\n  const parse = function (data, format) {\n    const delim = {\n      delimiter: delimiter\n    };\n    return dsv(data, format ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(format, delim) : delim);\n  };\n  parse.responseType = 'text';\n  return parse;\n}\nfunction dsv(data, format) {\n  if (format.header) {\n    data = format.header.map(vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue).join(format.delimiter) + '\\n' + data;\n  }\n  return (0,d3_dsv__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(format.delimiter).parse(data + '');\n}\ndsv.responseType = 'text';\n\nfunction isBuffer(_) {\n  return typeof Buffer === 'function' && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(Buffer.isBuffer) ? Buffer.isBuffer(_) : false;\n}\nfunction json(data, format) {\n  const prop = format && format.property ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(format.property) : vega_util__WEBPACK_IMPORTED_MODULE_0__.identity;\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(data) && !isBuffer(data) ? parseJSON(prop(data), format) : prop(JSON.parse(data));\n}\njson.responseType = 'json';\nfunction parseJSON(data, format) {\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(data) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isIterable)(data)) {\n    data = [...data];\n  }\n  return format && format.copy ? JSON.parse(JSON.stringify(data)) : data;\n}\n\nconst filters = {\n  interior: (a, b) => a !== b,\n  exterior: (a, b) => a === b\n};\nfunction topojson(data, format) {\n  let method, object, property, filter;\n  data = json(data, format);\n  if (format && format.feature) {\n    method = topojson_client__WEBPACK_IMPORTED_MODULE_1__.feature;\n    property = format.feature;\n  } else if (format && format.mesh) {\n    method = topojson_client__WEBPACK_IMPORTED_MODULE_1__.mesh;\n    property = format.mesh;\n    filter = filters[format.filter];\n  } else {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing TopoJSON feature or mesh parameter.');\n  }\n  object = (object = data.objects[property]) ? method(data, object, filter) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid TopoJSON object: ' + property);\n  return object && object.features || [object];\n}\ntopojson.responseType = 'json';\n\nconst format = {\n  dsv: dsv,\n  csv: delimitedFormat(','),\n  tsv: delimitedFormat('\\t'),\n  json: json,\n  topojson: topojson\n};\nfunction formats(name, reader) {\n  if (arguments.length > 1) {\n    format[name] = reader;\n    return this;\n  } else {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(format, name) ? format[name] : null;\n  }\n}\nfunction responseType(type) {\n  const f = formats(type);\n  return f && f.responseType || 'text';\n}\n\nfunction read (data, schema, timeParser, utcParser) {\n  schema = schema || {};\n  const reader = formats(schema.type || 'json');\n  if (!reader) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unknown data format type: ' + schema.type);\n  data = reader(data, schema);\n  if (schema.parse) parse(data, schema.parse, timeParser, utcParser);\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(data, 'columns')) delete data.columns;\n  return data;\n}\nfunction parse(data, types, timeParser, utcParser) {\n  if (!data.length) return; // early exit for empty data\n\n  const locale = (0,vega_format__WEBPACK_IMPORTED_MODULE_2__.timeFormatDefaultLocale)();\n  timeParser = timeParser || locale.timeParse;\n  utcParser = utcParser || locale.utcParse;\n  let fields = data.columns || Object.keys(data[0]),\n    datum,\n    field,\n    i,\n    j,\n    n,\n    m;\n  if (types === 'auto') types = inferTypes(data, fields);\n  fields = Object.keys(types);\n  const parsers = fields.map(field => {\n    const type = types[field];\n    let parts, pattern;\n    if (type && (type.startsWith('date:') || type.startsWith('utc:'))) {\n      parts = type.split(/:(.+)?/, 2); // split on first :\n      pattern = parts[1];\n      if (pattern[0] === '\\'' && pattern[pattern.length - 1] === '\\'' || pattern[0] === '\"' && pattern[pattern.length - 1] === '\"') {\n        pattern = pattern.slice(1, -1);\n      }\n      const parse = parts[0] === 'utc' ? utcParser : timeParser;\n      return parse(pattern);\n    }\n    if (!typeParsers[type]) {\n      throw Error('Illegal format pattern: ' + field + ':' + type);\n    }\n    return typeParsers[type];\n  });\n  for (i = 0, n = data.length, m = fields.length; i < n; ++i) {\n    datum = data[i];\n    for (j = 0; j < m; ++j) {\n      field = fields[j];\n      datum[field] = parsers[j](datum[field]);\n    }\n  }\n}\n\nconst loader = loaderFactory(typeof fetch !== 'undefined' && fetch,\n// use built-in fetch API\nnull // no file system access\n);\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-loader/build/vega-loader.browser.module.js?");

/***/ }),

/***/ "../../node_modules/vega-parser/build/vega-parser.module.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-parser/build/vega-parser.module.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AxisDomainRole: () => (/* binding */ AxisDomainRole),\n/* harmony export */   AxisGridRole: () => (/* binding */ AxisGridRole),\n/* harmony export */   AxisLabelRole: () => (/* binding */ AxisLabelRole),\n/* harmony export */   AxisRole: () => (/* binding */ AxisRole),\n/* harmony export */   AxisTickRole: () => (/* binding */ AxisTickRole),\n/* harmony export */   AxisTitleRole: () => (/* binding */ AxisTitleRole),\n/* harmony export */   DataScope: () => (/* binding */ DataScope),\n/* harmony export */   FrameRole: () => (/* binding */ FrameRole),\n/* harmony export */   LegendEntryRole: () => (/* binding */ LegendEntryRole),\n/* harmony export */   LegendLabelRole: () => (/* binding */ LegendLabelRole),\n/* harmony export */   LegendRole: () => (/* binding */ LegendRole),\n/* harmony export */   LegendSymbolRole: () => (/* binding */ LegendSymbolRole),\n/* harmony export */   LegendTitleRole: () => (/* binding */ LegendTitleRole),\n/* harmony export */   MarkRole: () => (/* binding */ MarkRole),\n/* harmony export */   Scope: () => (/* binding */ Scope),\n/* harmony export */   ScopeRole: () => (/* binding */ ScopeRole),\n/* harmony export */   config: () => (/* binding */ defaults),\n/* harmony export */   parse: () => (/* binding */ parse),\n/* harmony export */   signal: () => (/* binding */ parseSignal),\n/* harmony export */   signalUpdates: () => (/* binding */ parseSignalUpdates),\n/* harmony export */   stream: () => (/* binding */ parseStream)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_functions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-functions */ \"../../node_modules/vega-functions/build/vega-functions.module.js\");\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n\n\n\n\n\n\nfunction parseAutosize (spec) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(spec) ? spec : {\n    type: spec || 'pad'\n  };\n}\n\nconst number = _ => +_ || 0;\nconst paddingObject = _ => ({\n  top: _,\n  bottom: _,\n  left: _,\n  right: _\n});\nfunction parsePadding (spec) {\n  return !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(spec) ? paddingObject(number(spec)) : spec.signal ? spec : {\n    top: number(spec.top),\n    bottom: number(spec.bottom),\n    left: number(spec.left),\n    right: number(spec.right)\n  };\n}\n\nconst encoder = _ => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(_) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, _) : {\n  value: _\n};\nfunction addEncode(object, name, value, set) {\n  if (value != null) {\n    const isEncoder = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) && value.length && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value[0]);\n\n    // Always assign signal to update, even if the signal is from the enter block\n    if (isEncoder) {\n      object.update[name] = value;\n    } else {\n      object[set || 'enter'][name] = {\n        value: value\n      };\n    }\n    return 1;\n  } else {\n    return 0;\n  }\n}\nfunction addEncoders(object, enter, update) {\n  for (const name in enter) {\n    addEncode(object, name, enter[name]);\n  }\n  for (const name in update) {\n    addEncode(object, name, update[name], 'update');\n  }\n}\nfunction extendEncode(encode, extra, skip) {\n  for (const name in extra) {\n    if (skip && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(skip, name)) continue;\n    encode[name] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(encode[name] || {}, extra[name]);\n  }\n  return encode;\n}\nfunction has(key, encode) {\n  return encode && (encode.enter && encode.enter[key] || encode.update && encode.update[key]);\n}\n\nconst MarkRole = 'mark';\nconst FrameRole = 'frame';\nconst ScopeRole = 'scope';\nconst AxisRole = 'axis';\nconst AxisDomainRole = 'axis-domain';\nconst AxisGridRole = 'axis-grid';\nconst AxisLabelRole = 'axis-label';\nconst AxisTickRole = 'axis-tick';\nconst AxisTitleRole = 'axis-title';\nconst LegendRole = 'legend';\nconst LegendBandRole = 'legend-band';\nconst LegendEntryRole = 'legend-entry';\nconst LegendGradientRole = 'legend-gradient';\nconst LegendLabelRole = 'legend-label';\nconst LegendSymbolRole = 'legend-symbol';\nconst LegendTitleRole = 'legend-title';\nconst TitleRole = 'title';\nconst TitleTextRole = 'title-text';\nconst TitleSubtitleRole = 'title-subtitle';\n\nfunction applyDefaults (encode, type, role, style, config) {\n  const defaults = {},\n    enter = {};\n  let update, key, skip, props;\n\n  // if text mark, apply global lineBreak settings (#2370)\n  key = 'lineBreak';\n  if (type === 'text' && config[key] != null && !has(key, encode)) {\n    applyDefault(defaults, key, config[key]);\n  }\n\n  // ignore legend and axis roles\n  if (role == 'legend' || String(role).startsWith('axis')) {\n    role = null;\n  }\n\n  // resolve mark config\n  props = role === FrameRole ? config.group : role === MarkRole ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, config.mark, config[type]) : null;\n  for (key in props) {\n    // do not apply defaults if relevant fields are defined\n    skip = has(key, encode) || (key === 'fill' || key === 'stroke') && (has('fill', encode) || has('stroke', encode));\n    if (!skip) applyDefault(defaults, key, props[key]);\n  }\n\n  // resolve styles, apply with increasing precedence\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(style).forEach(name => {\n    const props = config.style && config.style[name];\n    for (const key in props) {\n      if (!has(key, encode)) {\n        applyDefault(defaults, key, props[key]);\n      }\n    }\n  });\n  encode = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, encode); // defensive copy\n  for (key in defaults) {\n    props = defaults[key];\n    if (props.signal) {\n      (update = update || {})[key] = props;\n    } else {\n      enter[key] = props;\n    }\n  }\n  encode.enter = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(enter, encode.enter);\n  if (update) encode.update = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(update, encode.update);\n  return encode;\n}\nfunction applyDefault(defaults, key, value) {\n  defaults[key] = value && value.signal ? {\n    signal: value.signal\n  } : {\n    value: value\n  };\n}\n\nconst scaleRef = scale => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(scale) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(scale) : scale.signal ? `(${scale.signal})` : field(scale);\nfunction entry$1(enc) {\n  if (enc.gradient != null) {\n    return gradient(enc);\n  }\n  let value = enc.signal ? `(${enc.signal})` : enc.color ? color(enc.color) : enc.field != null ? field(enc.field) : enc.value !== undefined ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(enc.value) : undefined;\n  if (enc.scale != null) {\n    value = scale(enc, value);\n  }\n  if (value === undefined) {\n    value = null;\n  }\n  if (enc.exponent != null) {\n    value = `pow(${value},${property(enc.exponent)})`;\n  }\n  if (enc.mult != null) {\n    value += `*${property(enc.mult)}`;\n  }\n  if (enc.offset != null) {\n    value += `+${property(enc.offset)}`;\n  }\n  if (enc.round) {\n    value = `round(${value})`;\n  }\n  return value;\n}\nconst _color = (type, x, y, z) => `(${type}(${[x, y, z].map(entry$1).join(',')})+'')`;\nfunction color(enc) {\n  return enc.c ? _color('hcl', enc.h, enc.c, enc.l) : enc.h || enc.s ? _color('hsl', enc.h, enc.s, enc.l) : enc.l || enc.a ? _color('lab', enc.l, enc.a, enc.b) : enc.r || enc.g || enc.b ? _color('rgb', enc.r, enc.g, enc.b) : null;\n}\nfunction gradient(enc) {\n  // map undefined to null; expression lang does not allow undefined\n  const args = [enc.start, enc.stop, enc.count].map(_ => _ == null ? null : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(_));\n\n  // trim null inputs from the end\n  while (args.length && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(args) == null) args.pop();\n  args.unshift(scaleRef(enc.gradient));\n  return `gradient(${args.join(',')})`;\n}\nfunction property(property) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(property) ? '(' + entry$1(property) + ')' : property;\n}\nfunction field(ref) {\n  return resolveField((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(ref) ? ref : {\n    datum: ref\n  });\n}\nfunction resolveField(ref) {\n  let object, level, field;\n  if (ref.signal) {\n    object = 'datum';\n    field = ref.signal;\n  } else if (ref.group || ref.parent) {\n    level = Math.max(1, ref.level || 1);\n    object = 'item';\n    while (level-- > 0) {\n      object += '.mark.group';\n    }\n    if (ref.parent) {\n      field = ref.parent;\n      object += '.datum';\n    } else {\n      field = ref.group;\n    }\n  } else if (ref.datum) {\n    object = 'datum';\n    field = ref.datum;\n  } else {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid field reference: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(ref));\n  }\n  if (!ref.signal) {\n    field = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.splitAccessPath)(field).map(vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue).join('][') : resolveField(field);\n  }\n  return object + '[' + field + ']';\n}\nfunction scale(enc, value) {\n  const scale = scaleRef(enc.scale);\n  if (enc.range != null) {\n    // pull value from scale range\n    value = `lerp(_range(${scale}), ${+enc.range})`;\n  } else {\n    // run value through scale and/or pull scale bandwidth\n    if (value !== undefined) value = `_scale(${scale}, ${value})`;\n    if (enc.band) {\n      value = (value ? value + '+' : '') + `_bandwidth(${scale})` + (+enc.band === 1 ? '' : '*' + property(enc.band));\n      if (enc.extra) {\n        // include logic to handle extraneous elements\n        value = `(datum.extra ? _scale(${scale}, datum.extra.value) : ${value})`;\n      }\n    }\n    if (value == null) value = '0';\n  }\n  return value;\n}\n\nfunction rule (enc) {\n  let code = '';\n  enc.forEach(rule => {\n    const value = entry$1(rule);\n    code += rule.test ? `(${rule.test})?${value}:` : value;\n  });\n\n  // if no else clause, terminate with null (#1366)\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(code) === ':') {\n    code += 'null';\n  }\n  return code;\n}\n\nfunction parseEncode (encode, type, role, style, scope, params) {\n  const enc = {};\n  params = params || {};\n  params.encoders = {\n    $encode: enc\n  };\n  encode = applyDefaults(encode, type, role, style, scope.config);\n  for (const key in encode) {\n    enc[key] = parseBlock(encode[key], type, params, scope);\n  }\n  return params;\n}\nfunction parseBlock(block, marktype, params, scope) {\n  const channels = {},\n    fields = {};\n  for (const name in block) {\n    if (block[name] != null) {\n      // skip any null entries\n      channels[name] = parse$1(expr(block[name]), scope, params, fields);\n    }\n  }\n  return {\n    $expr: {\n      marktype,\n      channels\n    },\n    $fields: Object.keys(fields),\n    $output: Object.keys(block)\n  };\n}\nfunction expr(enc) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(enc) ? rule(enc) : entry$1(enc);\n}\nfunction parse$1(code, scope, params, fields) {\n  const expr = (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(code, scope);\n  expr.$fields.forEach(name => fields[name] = 1);\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(params, expr.$params);\n  return expr.$expr;\n}\n\nconst OUTER = 'outer',\n  OUTER_INVALID = ['value', 'update', 'init', 'react', 'bind'];\nfunction outerError(prefix, name) {\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)(prefix + ' for \"outer\" push: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n}\nfunction parseSignal (signal, scope) {\n  const name = signal.name;\n  if (signal.push === OUTER) {\n    // signal must already be defined, raise error if not\n    if (!scope.signals[name]) outerError('No prior signal definition', name);\n    // signal push must not use properties reserved for standard definition\n    OUTER_INVALID.forEach(prop => {\n      if (signal[prop] !== undefined) outerError('Invalid property ', prop);\n    });\n  } else {\n    // define a new signal in the current scope\n    const op = scope.addSignal(name, signal.value);\n    if (signal.react === false) op.react = false;\n    if (signal.bind) scope.addBinding(name, signal.bind);\n  }\n}\n\nfunction Entry(type, value, params, parent) {\n  this.id = -1;\n  this.type = type;\n  this.value = value;\n  this.params = params;\n  if (parent) this.parent = parent;\n}\nfunction entry(type, value, params, parent) {\n  return new Entry(type, value, params, parent);\n}\nfunction operator(value, params) {\n  return entry('operator', value, params);\n}\n\n// -----\n\nfunction ref(op) {\n  const ref = {\n    $ref: op.id\n  };\n  // if operator not yet registered, cache ref to resolve later\n  if (op.id < 0) (op.refs = op.refs || []).push(ref);\n  return ref;\n}\nfunction fieldRef$1(field, name) {\n  return name ? {\n    $field: field,\n    $name: name\n  } : {\n    $field: field\n  };\n}\nconst keyFieldRef = fieldRef$1('key');\nfunction compareRef(fields, orders) {\n  return {\n    $compare: fields,\n    $order: orders\n  };\n}\nfunction keyRef(fields, flat) {\n  const ref = {\n    $key: fields\n  };\n  if (flat) ref.$flat = true;\n  return ref;\n}\n\n// -----\n\nconst Ascending = 'ascending';\nconst Descending = 'descending';\nfunction sortKey(sort) {\n  return !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(sort) ? '' : (sort.order === Descending ? '-' : '+') + aggrField(sort.op, sort.field);\n}\nfunction aggrField(op, field) {\n  return (op && op.signal ? '$' + op.signal : op || '') + (op && field ? '_' : '') + (field && field.signal ? '$' + field.signal : field || '');\n}\n\n// -----\n\nconst Scope$1 = 'scope';\nconst View = 'view';\nfunction isSignal(_) {\n  return _ && _.signal;\n}\nfunction isExpr$1(_) {\n  return _ && _.expr;\n}\nfunction hasSignal(_) {\n  if (isSignal(_)) return true;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(_)) for (const key in _) {\n    if (hasSignal(_[key])) return true;\n  }\n  return false;\n}\nfunction value(specValue, defaultValue) {\n  return specValue != null ? specValue : defaultValue;\n}\nfunction deref(v) {\n  return v && v.signal || v;\n}\n\nconst Timer = 'timer';\nfunction parseStream(stream, scope) {\n  const method = stream.merge ? mergeStream : stream.stream ? nestedStream : stream.type ? eventStream : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid stream specification: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(stream));\n  return method(stream, scope);\n}\nfunction eventSource(source) {\n  return source === Scope$1 ? View : source || View;\n}\nfunction mergeStream(stream, scope) {\n  const list = stream.merge.map(s => parseStream(s, scope)),\n    entry = streamParameters({\n      merge: list\n    }, stream, scope);\n  return scope.addStream(entry).id;\n}\nfunction nestedStream(stream, scope) {\n  const id = parseStream(stream.stream, scope),\n    entry = streamParameters({\n      stream: id\n    }, stream, scope);\n  return scope.addStream(entry).id;\n}\nfunction eventStream(stream, scope) {\n  let id;\n  if (stream.type === Timer) {\n    id = scope.event(Timer, stream.throttle);\n    stream = {\n      between: stream.between,\n      filter: stream.filter\n    };\n  } else {\n    id = scope.event(eventSource(stream.source), stream.type);\n  }\n  const entry = streamParameters({\n    stream: id\n  }, stream, scope);\n  return Object.keys(entry).length === 1 ? id : scope.addStream(entry).id;\n}\nfunction streamParameters(entry, stream, scope) {\n  let param = stream.between;\n  if (param) {\n    if (param.length !== 2) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Stream \"between\" parameter must have 2 entries: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(stream));\n    }\n    entry.between = [parseStream(param[0], scope), parseStream(param[1], scope)];\n  }\n  param = stream.filter ? [].concat(stream.filter) : [];\n  if (stream.marktype || stream.markname || stream.markrole) {\n    // add filter for mark type, name and/or role\n    param.push(filterMark(stream.marktype, stream.markname, stream.markrole));\n  }\n  if (stream.source === Scope$1) {\n    // add filter to limit events from sub-scope only\n    param.push('inScope(event.item)');\n  }\n  if (param.length) {\n    entry.filter = (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)('(' + param.join(')&&(') + ')', scope).$expr;\n  }\n  if ((param = stream.throttle) != null) {\n    entry.throttle = +param;\n  }\n  if ((param = stream.debounce) != null) {\n    entry.debounce = +param;\n  }\n  if (stream.consume) {\n    entry.consume = true;\n  }\n  return entry;\n}\nfunction filterMark(type, name, role) {\n  const item = 'event.item';\n  return item + (type && type !== '*' ? '&&' + item + '.mark.marktype===\\'' + type + '\\'' : '') + (role ? '&&' + item + '.mark.role===\\'' + role + '\\'' : '') + (name ? '&&' + item + '.mark.name===\\'' + name + '\\'' : '');\n}\n\n// bypass expression parser for internal operator references\nconst OP_VALUE_EXPR = {\n  code: '_.$value',\n  ast: {\n    type: 'Identifier',\n    value: 'value'\n  }\n};\nfunction parseUpdate (spec, scope, target) {\n  const encode = spec.encode,\n    entry = {\n      target: target\n    };\n  let events = spec.events,\n    update = spec.update,\n    sources = [];\n  if (!events) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Signal update missing events specification.');\n  }\n\n  // interpret as an event selector string\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(events)) {\n    events = (0,vega_event_selector__WEBPACK_IMPORTED_MODULE_2__.parseSelector)(events, scope.isSubscope() ? Scope$1 : View);\n  }\n\n  // separate event streams from signal updates\n  events = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(events).filter(s => s.signal || s.scale ? (sources.push(s), 0) : 1);\n\n  // merge internal operator listeners\n  if (sources.length > 1) {\n    sources = [mergeSources(sources)];\n  }\n\n  // merge event streams, include as source\n  if (events.length) {\n    sources.push(events.length > 1 ? {\n      merge: events\n    } : events[0]);\n  }\n  if (encode != null) {\n    if (update) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Signal encode and update are mutually exclusive.');\n    update = 'encode(item(),' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(encode) + ')';\n  }\n\n  // resolve update value\n  entry.update = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(update) ? (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(update, scope) : update.expr != null ? (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(update.expr, scope) : update.value != null ? update.value : update.signal != null ? {\n    $expr: OP_VALUE_EXPR,\n    $params: {\n      $value: scope.signalRef(update.signal)\n    }\n  } : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid signal update specification.');\n  if (spec.force) {\n    entry.options = {\n      force: true\n    };\n  }\n  sources.forEach(source => scope.addUpdate((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(streamSource(source, scope), entry)));\n}\nfunction streamSource(stream, scope) {\n  return {\n    source: stream.signal ? scope.signalRef(stream.signal) : stream.scale ? scope.scaleRef(stream.scale) : parseStream(stream, scope)\n  };\n}\nfunction mergeSources(sources) {\n  return {\n    signal: '[' + sources.map(s => s.scale ? 'scale(\"' + s.scale + '\")' : s.signal) + ']'\n  };\n}\n\nfunction parseSignalUpdates (signal, scope) {\n  const op = scope.getSignal(signal.name);\n  let expr = signal.update;\n  if (signal.init) {\n    if (expr) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Signals can not include both init and update expressions.');\n    } else {\n      expr = signal.init;\n      op.initonly = true;\n    }\n  }\n  if (expr) {\n    expr = (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(expr, scope);\n    op.update = expr.$expr;\n    op.params = expr.$params;\n  }\n  if (signal.on) {\n    signal.on.forEach(_ => parseUpdate(_, scope, op.id));\n  }\n}\n\nconst transform = name => (params, value, parent) => entry(name, value, params || undefined, parent);\nconst Aggregate = transform('aggregate');\nconst AxisTicks = transform('axisticks');\nconst Bound = transform('bound');\nconst Collect = transform('collect');\nconst Compare = transform('compare');\nconst DataJoin = transform('datajoin');\nconst Encode = transform('encode');\nconst Expression = transform('expression');\nconst Facet = transform('facet');\nconst Field = transform('field');\nconst Key = transform('key');\nconst LegendEntries = transform('legendentries');\nconst Load = transform('load');\nconst Mark = transform('mark');\nconst MultiExtent = transform('multiextent');\nconst MultiValues = transform('multivalues');\nconst Overlap = transform('overlap');\nconst Params = transform('params');\nconst PreFacet = transform('prefacet');\nconst Projection = transform('projection');\nconst Proxy = transform('proxy');\nconst Relay = transform('relay');\nconst Render = transform('render');\nconst Scale = transform('scale');\nconst Sieve = transform('sieve');\nconst SortItems = transform('sortitems');\nconst ViewLayout = transform('viewlayout');\nconst Values = transform('values');\n\nlet FIELD_REF_ID = 0;\nconst MULTIDOMAIN_SORT_OPS = {\n  min: 'min',\n  max: 'max',\n  count: 'sum'\n};\nfunction initScale(spec, scope) {\n  const type = spec.type || 'linear';\n  if (!(0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isValidScaleType)(type)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized scale type: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(type));\n  }\n  scope.addScale(spec.name, {\n    type,\n    domain: undefined\n  });\n}\nfunction parseScale(spec, scope) {\n  const params = scope.getScale(spec.name).params;\n  let key;\n  params.domain = parseScaleDomain(spec.domain, spec, scope);\n  if (spec.range != null) {\n    params.range = parseScaleRange(spec, scope, params);\n  }\n  if (spec.interpolate != null) {\n    parseScaleInterpolate(spec.interpolate, params);\n  }\n  if (spec.nice != null) {\n    params.nice = parseScaleNice(spec.nice);\n  }\n  if (spec.bins != null) {\n    params.bins = parseScaleBins(spec.bins, scope);\n  }\n  for (key in spec) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(params, key) || key === 'name') continue;\n    params[key] = parseLiteral(spec[key], scope);\n  }\n}\nfunction parseLiteral(v, scope) {\n  return !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(v) ? v : v.signal ? scope.signalRef(v.signal) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported object: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(v));\n}\nfunction parseArray(v, scope) {\n  return v.signal ? scope.signalRef(v.signal) : v.map(v => parseLiteral(v, scope));\n}\nfunction dataLookupError(name) {\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Can not find data set: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n}\n\n// -- SCALE DOMAIN ----\n\nfunction parseScaleDomain(domain, spec, scope) {\n  if (!domain) {\n    if (spec.domainMin != null || spec.domainMax != null) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('No scale domain defined for domainMin/domainMax to override.');\n    }\n    return; // default domain\n  }\n\n  return domain.signal ? scope.signalRef(domain.signal) : ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(domain) ? explicitDomain : domain.fields ? multipleDomain : singularDomain)(domain, spec, scope);\n}\nfunction explicitDomain(domain, spec, scope) {\n  return domain.map(v => parseLiteral(v, scope));\n}\nfunction singularDomain(domain, spec, scope) {\n  const data = scope.getData(domain.data);\n  if (!data) dataLookupError(domain.data);\n  return (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscrete)(spec.type) ? data.valuesRef(scope, domain.field, parseSort(domain.sort, false)) : (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isQuantile)(spec.type) ? data.domainRef(scope, domain.field) : data.extentRef(scope, domain.field);\n}\nfunction multipleDomain(domain, spec, scope) {\n  const data = domain.data,\n    fields = domain.fields.reduce((dom, d) => {\n      d = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(d) ? {\n        data: data,\n        field: d\n      } : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(d) || d.signal ? fieldRef(d, scope) : d;\n      dom.push(d);\n      return dom;\n    }, []);\n  return ((0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscrete)(spec.type) ? ordinalMultipleDomain : (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isQuantile)(spec.type) ? quantileMultipleDomain : numericMultipleDomain)(domain, scope, fields);\n}\nfunction fieldRef(data, scope) {\n  const name = '_:vega:_' + FIELD_REF_ID++,\n    coll = Collect({});\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(data)) {\n    coll.value = {\n      $ingest: data\n    };\n  } else if (data.signal) {\n    const code = 'setdata(' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name) + ',' + data.signal + ')';\n    coll.params.input = scope.signalRef(code);\n  }\n  scope.addDataPipeline(name, [coll, Sieve({})]);\n  return {\n    data: name,\n    field: 'data'\n  };\n}\nfunction ordinalMultipleDomain(domain, scope, fields) {\n  const sort = parseSort(domain.sort, true);\n  let a, v;\n\n  // get value counts for each domain field\n  const counts = fields.map(f => {\n    const data = scope.getData(f.data);\n    if (!data) dataLookupError(f.data);\n    return data.countsRef(scope, f.field, sort);\n  });\n\n  // aggregate the results from each domain field\n  const p = {\n    groupby: keyFieldRef,\n    pulse: counts\n  };\n  if (sort) {\n    a = sort.op || 'count';\n    v = sort.field ? aggrField(a, sort.field) : 'count';\n    p.ops = [MULTIDOMAIN_SORT_OPS[a]];\n    p.fields = [scope.fieldRef(v)];\n    p.as = [v];\n  }\n  a = scope.add(Aggregate(p));\n\n  // collect aggregate output\n  const c = scope.add(Collect({\n    pulse: ref(a)\n  }));\n\n  // extract values for combined domain\n  v = scope.add(Values({\n    field: keyFieldRef,\n    sort: scope.sortRef(sort),\n    pulse: ref(c)\n  }));\n  return ref(v);\n}\nfunction parseSort(sort, multidomain) {\n  if (sort) {\n    if (!sort.field && !sort.op) {\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(sort)) sort.field = 'key';else sort = {\n        field: 'key'\n      };\n    } else if (!sort.field && sort.op !== 'count') {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('No field provided for sort aggregate op: ' + sort.op);\n    } else if (multidomain && sort.field) {\n      if (sort.op && !MULTIDOMAIN_SORT_OPS[sort.op]) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Multiple domain scales can not be sorted using ' + sort.op);\n      }\n    }\n  }\n  return sort;\n}\nfunction quantileMultipleDomain(domain, scope, fields) {\n  // get value arrays for each domain field\n  const values = fields.map(f => {\n    const data = scope.getData(f.data);\n    if (!data) dataLookupError(f.data);\n    return data.domainRef(scope, f.field);\n  });\n\n  // combine value arrays\n  return ref(scope.add(MultiValues({\n    values: values\n  })));\n}\nfunction numericMultipleDomain(domain, scope, fields) {\n  // get extents for each domain field\n  const extents = fields.map(f => {\n    const data = scope.getData(f.data);\n    if (!data) dataLookupError(f.data);\n    return data.extentRef(scope, f.field);\n  });\n\n  // combine extents\n  return ref(scope.add(MultiExtent({\n    extents: extents\n  })));\n}\n\n// -- SCALE BINS -----\n\nfunction parseScaleBins(v, scope) {\n  return v.signal || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(v) ? parseArray(v, scope) : scope.objectProperty(v);\n}\n\n// -- SCALE NICE -----\n\nfunction parseScaleNice(nice) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(nice) ? {\n    interval: parseLiteral(nice.interval),\n    step: parseLiteral(nice.step)\n  } : parseLiteral(nice);\n}\n\n// -- SCALE INTERPOLATION -----\n\nfunction parseScaleInterpolate(interpolate, params) {\n  params.interpolate = parseLiteral(interpolate.type || interpolate);\n  if (interpolate.gamma != null) {\n    params.interpolateGamma = parseLiteral(interpolate.gamma);\n  }\n}\n\n// -- SCALE RANGE -----\n\nfunction parseScaleRange(spec, scope, params) {\n  const config = scope.config.range;\n  let range = spec.range;\n  if (range.signal) {\n    return scope.signalRef(range.signal);\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(range)) {\n    if (config && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(config, range)) {\n      spec = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, spec, {\n        range: config[range]\n      });\n      return parseScaleRange(spec, scope, params);\n    } else if (range === 'width') {\n      range = [0, {\n        signal: 'width'\n      }];\n    } else if (range === 'height') {\n      range = (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscrete)(spec.type) ? [0, {\n        signal: 'height'\n      }] : [{\n        signal: 'height'\n      }, 0];\n    } else {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized scale range value: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(range));\n    }\n  } else if (range.scheme) {\n    params.scheme = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range.scheme) ? parseArray(range.scheme, scope) : parseLiteral(range.scheme, scope);\n    if (range.extent) params.schemeExtent = parseArray(range.extent, scope);\n    if (range.count) params.schemeCount = parseLiteral(range.count, scope);\n    return;\n  } else if (range.step) {\n    params.rangeStep = parseLiteral(range.step, scope);\n    return;\n  } else if ((0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscrete)(spec.type) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range)) {\n    return parseScaleDomain(range, spec, scope);\n  } else if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(range)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported range type: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(range));\n  }\n  return range.map(v => ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(v) ? parseArray : parseLiteral)(v, scope));\n}\n\nfunction parseProjection (proj, scope) {\n  const config = scope.config.projection || {},\n    params = {};\n  for (const name in proj) {\n    if (name === 'name') continue;\n    params[name] = parseParameter$1(proj[name], name, scope);\n  }\n\n  // apply projection defaults from config\n  for (const name in config) {\n    if (params[name] == null) {\n      params[name] = parseParameter$1(config[name], name, scope);\n    }\n  }\n  scope.addProjection(proj.name, params);\n}\nfunction parseParameter$1(_, name, scope) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_) ? _.map(_ => parseParameter$1(_, name, scope)) : !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(_) ? _ : _.signal ? scope.signalRef(_.signal) : name === 'fit' ? _ : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported parameter object: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(_));\n}\n\nconst Top = 'top';\nconst Left = 'left';\nconst Right = 'right';\nconst Bottom = 'bottom';\nconst Center = 'center';\nconst Vertical = 'vertical';\nconst Start = 'start';\nconst Middle = 'middle';\nconst End = 'end';\nconst Index = 'index';\nconst Label = 'label';\nconst Offset = 'offset';\nconst Perc = 'perc';\nconst Perc2 = 'perc2';\nconst Value = 'value';\nconst GuideLabelStyle = 'guide-label';\nconst GuideTitleStyle = 'guide-title';\nconst GroupTitleStyle = 'group-title';\nconst GroupSubtitleStyle = 'group-subtitle';\nconst Symbols = 'symbol';\nconst Gradient = 'gradient';\nconst Discrete = 'discrete';\nconst Size = 'size';\nconst Shape = 'shape';\nconst Fill = 'fill';\nconst Stroke = 'stroke';\nconst StrokeWidth = 'strokeWidth';\nconst StrokeDash = 'strokeDash';\nconst Opacity = 'opacity';\n\n// Encoding channels supported by legends\n// In priority order of 'canonical' scale\nconst LegendScales = [Size, Shape, Fill, Stroke, StrokeWidth, StrokeDash, Opacity];\nconst Skip = {\n  name: 1,\n  style: 1,\n  interactive: 1\n};\nconst zero = {\n  value: 0\n};\nconst one = {\n  value: 1\n};\n\nconst GroupMark = 'group';\nconst RectMark = 'rect';\nconst RuleMark = 'rule';\nconst SymbolMark = 'symbol';\nconst TextMark = 'text';\n\nfunction guideGroup (mark) {\n  mark.type = GroupMark;\n  mark.interactive = mark.interactive || false;\n  return mark;\n}\n\nfunction lookup(spec, config) {\n  const _ = (name, dflt) => value(spec[name], value(config[name], dflt));\n  _.isVertical = s => Vertical === value(spec.direction, config.direction || (s ? config.symbolDirection : config.gradientDirection));\n  _.gradientLength = () => value(spec.gradientLength, config.gradientLength || config.gradientWidth);\n  _.gradientThickness = () => value(spec.gradientThickness, config.gradientThickness || config.gradientHeight);\n  _.entryColumns = () => value(spec.columns, value(config.columns, +_.isVertical(true)));\n  return _;\n}\nfunction getEncoding(name, encode) {\n  const v = encode && (encode.update && encode.update[name] || encode.enter && encode.enter[name]);\n  return v && v.signal ? v : v ? v.value : null;\n}\nfunction getStyle(name, scope, style) {\n  const s = scope.config.style[style];\n  return s && s[name];\n}\nfunction anchorExpr(s, e, m) {\n  return `item.anchor === '${Start}' ? ${s} : item.anchor === '${End}' ? ${e} : ${m}`;\n}\nconst alignExpr$1 = anchorExpr((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(Left), (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(Right), (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(Center));\nfunction tickBand(_) {\n  const v = _('tickBand');\n  let offset = _('tickOffset'),\n    band,\n    extra;\n  if (!v) {\n    // if no tick band entry, fall back on other properties\n    band = _('bandPosition');\n    extra = _('tickExtra');\n  } else if (v.signal) {\n    // if signal, augment code to interpret values\n    band = {\n      signal: `(${v.signal}) === 'extent' ? 1 : 0.5`\n    };\n    extra = {\n      signal: `(${v.signal}) === 'extent'`\n    };\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(offset)) {\n      offset = {\n        signal: `(${v.signal}) === 'extent' ? 0 : ${offset}`\n      };\n    }\n  } else if (v === 'extent') {\n    // if constant, simply set values\n    band = 1;\n    extra = true;\n    offset = 0;\n  } else {\n    band = 0.5;\n    extra = false;\n  }\n  return {\n    extra,\n    band,\n    offset\n  };\n}\nfunction extendOffset(value, offset) {\n  return !offset ? value : !value ? offset : !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) ? {\n    value,\n    offset\n  } : Object.assign({}, value, {\n    offset: extendOffset(value.offset, offset)\n  });\n}\n\nfunction guideMark (mark, extras) {\n  if (extras) {\n    mark.name = extras.name;\n    mark.style = extras.style || mark.style;\n    mark.interactive = !!extras.interactive;\n    mark.encode = extendEncode(mark.encode, extras, Skip);\n  } else {\n    mark.interactive = false;\n  }\n  return mark;\n}\n\nfunction legendGradient (spec, scale, config, userEncode) {\n  const _ = lookup(spec, config),\n    vertical = _.isVertical(),\n    thickness = _.gradientThickness(),\n    length = _.gradientLength();\n  let enter, start, stop, width, height;\n  if (vertical) {\n    start = [0, 1];\n    stop = [0, 0];\n    width = thickness;\n    height = length;\n  } else {\n    start = [0, 0];\n    stop = [1, 0];\n    width = length;\n    height = thickness;\n  }\n  const encode = {\n    enter: enter = {\n      opacity: zero,\n      x: zero,\n      y: zero,\n      width: encoder(width),\n      height: encoder(height)\n    },\n    update: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, enter, {\n      opacity: one,\n      fill: {\n        gradient: scale,\n        start: start,\n        stop: stop\n      }\n    }),\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    stroke: _('gradientStrokeColor'),\n    strokeWidth: _('gradientStrokeWidth')\n  }, {\n    // update\n    opacity: _('gradientOpacity')\n  });\n  return guideMark({\n    type: RectMark,\n    role: LegendGradientRole,\n    encode\n  }, userEncode);\n}\n\nfunction legendGradientDiscrete (spec, scale, config, userEncode, dataRef) {\n  const _ = lookup(spec, config),\n    vertical = _.isVertical(),\n    thickness = _.gradientThickness(),\n    length = _.gradientLength();\n  let u,\n    v,\n    uu,\n    vv,\n    adjust = '';\n  vertical ? (u = 'y', uu = 'y2', v = 'x', vv = 'width', adjust = '1-') : (u = 'x', uu = 'x2', v = 'y', vv = 'height');\n  const enter = {\n    opacity: zero,\n    fill: {\n      scale: scale,\n      field: Value\n    }\n  };\n  enter[u] = {\n    signal: adjust + 'datum.' + Perc,\n    mult: length\n  };\n  enter[v] = zero;\n  enter[uu] = {\n    signal: adjust + 'datum.' + Perc2,\n    mult: length\n  };\n  enter[vv] = encoder(thickness);\n  const encode = {\n    enter: enter,\n    update: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, enter, {\n      opacity: one\n    }),\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    stroke: _('gradientStrokeColor'),\n    strokeWidth: _('gradientStrokeWidth')\n  }, {\n    // update\n    opacity: _('gradientOpacity')\n  });\n  return guideMark({\n    type: RectMark,\n    role: LegendBandRole,\n    key: Value,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\n\nconst alignExpr = `datum.${Perc}<=0?\"${Left}\":datum.${Perc}>=1?\"${Right}\":\"${Center}\"`,\n  baselineExpr = `datum.${Perc}<=0?\"${Bottom}\":datum.${Perc}>=1?\"${Top}\":\"${Middle}\"`;\nfunction legendGradientLabels (spec, config, userEncode, dataRef) {\n  const _ = lookup(spec, config),\n    vertical = _.isVertical(),\n    thickness = encoder(_.gradientThickness()),\n    length = _.gradientLength();\n  let overlap = _('labelOverlap'),\n    enter,\n    update,\n    u,\n    v,\n    adjust = '';\n  const encode = {\n    enter: enter = {\n      opacity: zero\n    },\n    update: update = {\n      opacity: one,\n      text: {\n        field: Label\n      }\n    },\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    fill: _('labelColor'),\n    fillOpacity: _('labelOpacity'),\n    font: _('labelFont'),\n    fontSize: _('labelFontSize'),\n    fontStyle: _('labelFontStyle'),\n    fontWeight: _('labelFontWeight'),\n    limit: value(spec.labelLimit, config.gradientLabelLimit)\n  });\n  if (vertical) {\n    enter.align = {\n      value: 'left'\n    };\n    enter.baseline = update.baseline = {\n      signal: baselineExpr\n    };\n    u = 'y';\n    v = 'x';\n    adjust = '1-';\n  } else {\n    enter.align = update.align = {\n      signal: alignExpr\n    };\n    enter.baseline = {\n      value: 'top'\n    };\n    u = 'x';\n    v = 'y';\n  }\n  enter[u] = update[u] = {\n    signal: adjust + 'datum.' + Perc,\n    mult: length\n  };\n  enter[v] = update[v] = thickness;\n  thickness.offset = value(spec.labelOffset, config.gradientLabelOffset) || 0;\n  overlap = overlap ? {\n    separation: _('labelSeparation'),\n    method: overlap,\n    order: 'datum.' + Index\n  } : undefined;\n\n  // type, role, style, key, dataRef, encode, extras\n  return guideMark({\n    type: TextMark,\n    role: LegendLabelRole,\n    style: GuideLabelStyle,\n    key: Value,\n    from: dataRef,\n    encode,\n    overlap\n  }, userEncode);\n}\n\n// userEncode is top-level, includes entries, symbols, labels\nfunction legendSymbolGroups (spec, config, userEncode, dataRef, columns) {\n  const _ = lookup(spec, config),\n    entries = userEncode.entries,\n    interactive = !!(entries && entries.interactive),\n    name = entries ? entries.name : undefined,\n    height = _('clipHeight'),\n    symbolOffset = _('symbolOffset'),\n    valueRef = {\n      data: 'value'\n    },\n    xSignal = `(${columns}) ? datum.${Offset} : datum.${Size}`,\n    yEncode = height ? encoder(height) : {\n      field: Size\n    },\n    index = `datum.${Index}`,\n    ncols = `max(1, ${columns})`;\n  let encode, enter, update, nrows, sort;\n  yEncode.mult = 0.5;\n\n  // -- LEGEND SYMBOLS --\n  encode = {\n    enter: enter = {\n      opacity: zero,\n      x: {\n        signal: xSignal,\n        mult: 0.5,\n        offset: symbolOffset\n      },\n      y: yEncode\n    },\n    update: update = {\n      opacity: one,\n      x: enter.x,\n      y: enter.y\n    },\n    exit: {\n      opacity: zero\n    }\n  };\n  let baseFill = null,\n    baseStroke = null;\n  if (!spec.fill) {\n    baseFill = config.symbolBaseFillColor;\n    baseStroke = config.symbolBaseStrokeColor;\n  }\n  addEncoders(encode, {\n    fill: _('symbolFillColor', baseFill),\n    shape: _('symbolType'),\n    size: _('symbolSize'),\n    stroke: _('symbolStrokeColor', baseStroke),\n    strokeDash: _('symbolDash'),\n    strokeDashOffset: _('symbolDashOffset'),\n    strokeWidth: _('symbolStrokeWidth')\n  }, {\n    // update\n    opacity: _('symbolOpacity')\n  });\n  LegendScales.forEach(scale => {\n    if (spec[scale]) {\n      update[scale] = enter[scale] = {\n        scale: spec[scale],\n        field: Value\n      };\n    }\n  });\n  const symbols = guideMark({\n    type: SymbolMark,\n    role: LegendSymbolRole,\n    key: Value,\n    from: valueRef,\n    clip: height ? true : undefined,\n    encode\n  }, userEncode.symbols);\n\n  // -- LEGEND LABELS --\n  const labelOffset = encoder(symbolOffset);\n  labelOffset.offset = _('labelOffset');\n  encode = {\n    enter: enter = {\n      opacity: zero,\n      x: {\n        signal: xSignal,\n        offset: labelOffset\n      },\n      y: yEncode\n    },\n    update: update = {\n      opacity: one,\n      text: {\n        field: Label\n      },\n      x: enter.x,\n      y: enter.y\n    },\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    align: _('labelAlign'),\n    baseline: _('labelBaseline'),\n    fill: _('labelColor'),\n    fillOpacity: _('labelOpacity'),\n    font: _('labelFont'),\n    fontSize: _('labelFontSize'),\n    fontStyle: _('labelFontStyle'),\n    fontWeight: _('labelFontWeight'),\n    limit: _('labelLimit')\n  });\n  const labels = guideMark({\n    type: TextMark,\n    role: LegendLabelRole,\n    style: GuideLabelStyle,\n    key: Value,\n    from: valueRef,\n    encode\n  }, userEncode.labels);\n\n  // -- LEGEND ENTRY GROUPS --\n  encode = {\n    enter: {\n      noBound: {\n        value: !height\n      },\n      // ignore width/height in bounds calc\n      width: zero,\n      height: height ? encoder(height) : zero,\n      opacity: zero\n    },\n    exit: {\n      opacity: zero\n    },\n    update: update = {\n      opacity: one,\n      row: {\n        signal: null\n      },\n      column: {\n        signal: null\n      }\n    }\n  };\n\n  // annotate and sort groups to ensure correct ordering\n  if (_.isVertical(true)) {\n    nrows = `ceil(item.mark.items.length / ${ncols})`;\n    update.row.signal = `${index}%${nrows}`;\n    update.column.signal = `floor(${index} / ${nrows})`;\n    sort = {\n      field: ['row', index]\n    };\n  } else {\n    update.row.signal = `floor(${index} / ${ncols})`;\n    update.column.signal = `${index} % ${ncols}`;\n    sort = {\n      field: index\n    };\n  }\n  // handle zero column case (implies infinite columns)\n  update.column.signal = `(${columns})?${update.column.signal}:${index}`;\n\n  // facet legend entries into sub-groups\n  dataRef = {\n    facet: {\n      data: dataRef,\n      name: 'value',\n      groupby: Index\n    }\n  };\n  return guideGroup({\n    role: ScopeRole,\n    from: dataRef,\n    encode: extendEncode(encode, entries, Skip),\n    marks: [symbols, labels],\n    name,\n    interactive,\n    sort\n  });\n}\nfunction legendSymbolLayout(spec, config) {\n  const _ = lookup(spec, config);\n\n  // layout parameters for legend entries\n  return {\n    align: _('gridAlign'),\n    columns: _.entryColumns(),\n    center: {\n      row: true,\n      column: false\n    },\n    padding: {\n      row: _('rowPadding'),\n      column: _('columnPadding')\n    }\n  };\n}\n\n// expression logic for align, anchor, angle, and baseline calculation\nconst isL = 'item.orient === \"left\"',\n  isR = 'item.orient === \"right\"',\n  isLR = `(${isL} || ${isR})`,\n  isVG = `datum.vgrad && ${isLR}`,\n  baseline = anchorExpr('\"top\"', '\"bottom\"', '\"middle\"'),\n  alignFlip = anchorExpr('\"right\"', '\"left\"', '\"center\"'),\n  exprAlign = `datum.vgrad && ${isR} ? (${alignFlip}) : (${isLR} && !(datum.vgrad && ${isL})) ? \"left\" : ${alignExpr$1}`,\n  exprAnchor = `item._anchor || (${isLR} ? \"middle\" : \"start\")`,\n  exprAngle = `${isVG} ? (${isL} ? -90 : 90) : 0`,\n  exprBaseline = `${isLR} ? (datum.vgrad ? (${isR} ? \"bottom\" : \"top\") : ${baseline}) : \"top\"`;\nfunction legendTitle (spec, config, userEncode, dataRef) {\n  const _ = lookup(spec, config);\n  const encode = {\n    enter: {\n      opacity: zero\n    },\n    update: {\n      opacity: one,\n      x: {\n        field: {\n          group: 'padding'\n        }\n      },\n      y: {\n        field: {\n          group: 'padding'\n        }\n      }\n    },\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    orient: _('titleOrient'),\n    _anchor: _('titleAnchor'),\n    anchor: {\n      signal: exprAnchor\n    },\n    angle: {\n      signal: exprAngle\n    },\n    align: {\n      signal: exprAlign\n    },\n    baseline: {\n      signal: exprBaseline\n    },\n    text: spec.title,\n    fill: _('titleColor'),\n    fillOpacity: _('titleOpacity'),\n    font: _('titleFont'),\n    fontSize: _('titleFontSize'),\n    fontStyle: _('titleFontStyle'),\n    fontWeight: _('titleFontWeight'),\n    limit: _('titleLimit'),\n    lineHeight: _('titleLineHeight')\n  }, {\n    // require update\n    align: _('titleAlign'),\n    baseline: _('titleBaseline')\n  });\n  return guideMark({\n    type: TextMark,\n    role: LegendTitleRole,\n    style: GuideTitleStyle,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\n\nfunction clip (clip, scope) {\n  let expr;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(clip)) {\n    if (clip.signal) {\n      expr = clip.signal;\n    } else if (clip.path) {\n      expr = 'pathShape(' + param(clip.path) + ')';\n    } else if (clip.sphere) {\n      expr = 'geoShape(' + param(clip.sphere) + ', {type: \"Sphere\"})';\n    }\n  }\n  return expr ? scope.signalRef(expr) : !!clip;\n}\nfunction param(value) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) && value.signal ? value.signal : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(value);\n}\n\nfunction getRole (spec) {\n  const role = spec.role || '';\n  return !role.indexOf('axis') || !role.indexOf('legend') || !role.indexOf('title') ? role : spec.type === GroupMark ? ScopeRole : role || MarkRole;\n}\n\nfunction definition (spec) {\n  return {\n    marktype: spec.type,\n    name: spec.name || undefined,\n    role: spec.role || getRole(spec),\n    zindex: +spec.zindex || undefined,\n    aria: spec.aria,\n    description: spec.description\n  };\n}\n\nfunction interactive (spec, scope) {\n  return spec && spec.signal ? scope.signalRef(spec.signal) : spec === false ? false : true;\n}\n\n/**\n * Parse a data transform specification.\n */\nfunction parseTransform (spec, scope) {\n  const def = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_4__.definition)(spec.type);\n  if (!def) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized transform type: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(spec.type));\n  const t = entry(def.type.toLowerCase(), null, parseParameters(def, spec, scope));\n  if (spec.signal) scope.addSignal(spec.signal, scope.proxy(t));\n  t.metadata = def.metadata || {};\n  return t;\n}\n\n/**\n * Parse all parameters of a data transform.\n */\nfunction parseParameters(def, spec, scope) {\n  const params = {},\n    n = def.params.length;\n  for (let i = 0; i < n; ++i) {\n    const pdef = def.params[i];\n    params[pdef.name] = parseParameter(pdef, spec, scope);\n  }\n  return params;\n}\n\n/**\n * Parse a data transform parameter.\n */\nfunction parseParameter(def, spec, scope) {\n  const type = def.type,\n    value = spec[def.name];\n  if (type === 'index') {\n    return parseIndexParameter(def, spec, scope);\n  } else if (value === undefined) {\n    if (def.required) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing required ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(spec.type) + ' parameter: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(def.name));\n    }\n    return;\n  } else if (type === 'param') {\n    return parseSubParameters(def, spec, scope);\n  } else if (type === 'projection') {\n    return scope.projectionRef(spec[def.name]);\n  }\n  return def.array && !isSignal(value) ? value.map(v => parameterValue(def, v, scope)) : parameterValue(def, value, scope);\n}\n\n/**\n * Parse a single parameter value.\n */\nfunction parameterValue(def, value, scope) {\n  const type = def.type;\n  if (isSignal(value)) {\n    return isExpr(type) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Expression references can not be signals.') : isField(type) ? scope.fieldRef(value) : isCompare(type) ? scope.compareRef(value) : scope.signalRef(value.signal);\n  } else {\n    const expr = def.expr || isField(type);\n    return expr && outerExpr(value) ? scope.exprRef(value.expr, value.as) : expr && outerField(value) ? fieldRef$1(value.field, value.as) : isExpr(type) ? (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(value, scope) : isData(type) ? ref(scope.getData(value).values) : isField(type) ? fieldRef$1(value) : isCompare(type) ? scope.compareRef(value) : value;\n  }\n}\n\n/**\n * Parse parameter for accessing an index of another data set.\n */\nfunction parseIndexParameter(def, spec, scope) {\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(spec.from)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Lookup \"from\" parameter must be a string literal.');\n  }\n  return scope.getData(spec.from).lookupRef(scope, spec.key);\n}\n\n/**\n * Parse a parameter that contains one or more sub-parameter objects.\n */\nfunction parseSubParameters(def, spec, scope) {\n  const value = spec[def.name];\n  if (def.array) {\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value)) {\n      // signals not allowed!\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Expected an array of sub-parameters. Instead: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(value));\n    }\n    return value.map(v => parseSubParameter(def, v, scope));\n  } else {\n    return parseSubParameter(def, value, scope);\n  }\n}\n\n/**\n * Parse a sub-parameter object.\n */\nfunction parseSubParameter(def, value, scope) {\n  const n = def.params.length;\n  let pdef;\n\n  // loop over defs to find matching key\n  for (let i = 0; i < n; ++i) {\n    pdef = def.params[i];\n    for (const k in pdef.key) {\n      if (pdef.key[k] !== value[k]) {\n        pdef = null;\n        break;\n      }\n    }\n    if (pdef) break;\n  }\n  // raise error if matching key not found\n  if (!pdef) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported parameter: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(value));\n\n  // parse params, create Params transform, return ref\n  const params = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(parseParameters(pdef, value, scope), pdef.key);\n  return ref(scope.add(Params(params)));\n}\n\n// -- Utilities -----\n\nconst outerExpr = _ => _ && _.expr;\nconst outerField = _ => _ && _.field;\nconst isData = _ => _ === 'data';\nconst isExpr = _ => _ === 'expr';\nconst isField = _ => _ === 'field';\nconst isCompare = _ => _ === 'compare';\n\nfunction parseData$1 (from, group, scope) {\n  let facet, key, op, dataRef, parent;\n\n  // if no source data, generate singleton datum\n  if (!from) {\n    dataRef = ref(scope.add(Collect(null, [{}])));\n  }\n\n  // if faceted, process facet specification\n  else if (facet = from.facet) {\n    if (!group) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Only group marks can be faceted.');\n\n    // use pre-faceted source data, if available\n    if (facet.field != null) {\n      dataRef = parent = getDataRef(facet, scope);\n    } else {\n      // generate facet aggregates if no direct data specification\n      if (!from.data) {\n        op = parseTransform((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n          type: 'aggregate',\n          groupby: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(facet.groupby)\n        }, facet.aggregate), scope);\n        op.params.key = scope.keyRef(facet.groupby);\n        op.params.pulse = getDataRef(facet, scope);\n        dataRef = parent = ref(scope.add(op));\n      } else {\n        parent = ref(scope.getData(from.data).aggregate);\n      }\n      key = scope.keyRef(facet.groupby, true);\n    }\n  }\n\n  // if not yet defined, get source data reference\n  if (!dataRef) {\n    dataRef = getDataRef(from, scope);\n  }\n  return {\n    key: key,\n    pulse: dataRef,\n    parent: parent\n  };\n}\nfunction getDataRef(from, scope) {\n  return from.$ref ? from : from.data && from.data.$ref ? from.data : ref(scope.getData(from.data).output);\n}\n\nfunction DataScope(scope, input, output, values, aggr) {\n  this.scope = scope; // parent scope object\n  this.input = input; // first operator in pipeline (tuple input)\n  this.output = output; // last operator in pipeline (tuple output)\n  this.values = values; // operator for accessing tuples (but not tuple flow)\n\n  // last aggregate in transform pipeline\n  this.aggregate = aggr;\n\n  // lookup table of field indices\n  this.index = {};\n}\nDataScope.fromEntries = function (scope, entries) {\n  const n = entries.length,\n    values = entries[n - 1],\n    output = entries[n - 2];\n  let input = entries[0],\n    aggr = null,\n    i = 1;\n  if (input && input.type === 'load') {\n    input = entries[1];\n  }\n\n  // add operator entries to this scope, wire up pulse chain\n  scope.add(entries[0]);\n  for (; i < n; ++i) {\n    entries[i].params.pulse = ref(entries[i - 1]);\n    scope.add(entries[i]);\n    if (entries[i].type === 'aggregate') aggr = entries[i];\n  }\n  return new DataScope(scope, input, output, values, aggr);\n};\nfunction fieldKey(field) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field) ? field : null;\n}\nfunction addSortField(scope, p, sort) {\n  const as = aggrField(sort.op, sort.field);\n  let s;\n  if (p.ops) {\n    for (let i = 0, n = p.as.length; i < n; ++i) {\n      if (p.as[i] === as) return;\n    }\n  } else {\n    p.ops = ['count'];\n    p.fields = [null];\n    p.as = ['count'];\n  }\n  if (sort.op) {\n    p.ops.push((s = sort.op.signal) ? scope.signalRef(s) : sort.op);\n    p.fields.push(scope.fieldRef(sort.field));\n    p.as.push(as);\n  }\n}\nfunction cache(scope, ds, name, optype, field, counts, index) {\n  const cache = ds[name] || (ds[name] = {}),\n    sort = sortKey(counts);\n  let k = fieldKey(field),\n    v,\n    op;\n  if (k != null) {\n    scope = ds.scope;\n    k = k + (sort ? '|' + sort : '');\n    v = cache[k];\n  }\n  if (!v) {\n    const params = counts ? {\n      field: keyFieldRef,\n      pulse: ds.countsRef(scope, field, counts)\n    } : {\n      field: scope.fieldRef(field),\n      pulse: ref(ds.output)\n    };\n    if (sort) params.sort = scope.sortRef(counts);\n    op = scope.add(entry(optype, undefined, params));\n    if (index) ds.index[field] = op;\n    v = ref(op);\n    if (k != null) cache[k] = v;\n  }\n  return v;\n}\nDataScope.prototype = {\n  countsRef(scope, field, sort) {\n    const ds = this,\n      cache = ds.counts || (ds.counts = {}),\n      k = fieldKey(field);\n    let v, a, p;\n    if (k != null) {\n      scope = ds.scope;\n      v = cache[k];\n    }\n    if (!v) {\n      p = {\n        groupby: scope.fieldRef(field, 'key'),\n        pulse: ref(ds.output)\n      };\n      if (sort && sort.field) addSortField(scope, p, sort);\n      a = scope.add(Aggregate(p));\n      v = scope.add(Collect({\n        pulse: ref(a)\n      }));\n      v = {\n        agg: a,\n        ref: ref(v)\n      };\n      if (k != null) cache[k] = v;\n    } else if (sort && sort.field) {\n      addSortField(scope, v.agg.params, sort);\n    }\n    return v.ref;\n  },\n  tuplesRef() {\n    return ref(this.values);\n  },\n  extentRef(scope, field) {\n    return cache(scope, this, 'extent', 'extent', field, false);\n  },\n  domainRef(scope, field) {\n    return cache(scope, this, 'domain', 'values', field, false);\n  },\n  valuesRef(scope, field, sort) {\n    return cache(scope, this, 'vals', 'values', field, sort || true);\n  },\n  lookupRef(scope, field) {\n    return cache(scope, this, 'lookup', 'tupleindex', field, false);\n  },\n  indataRef(scope, field) {\n    return cache(scope, this, 'indata', 'tupleindex', field, true, true);\n  }\n};\n\nfunction parseFacet (spec, scope, group) {\n  const facet = spec.from.facet,\n    name = facet.name,\n    data = getDataRef(facet, scope);\n  let op;\n  if (!facet.name) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Facet must have a name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(facet));\n  }\n  if (!facet.data) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Facet must reference a data set: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(facet));\n  }\n  if (facet.field) {\n    op = scope.add(PreFacet({\n      field: scope.fieldRef(facet.field),\n      pulse: data\n    }));\n  } else if (facet.groupby) {\n    op = scope.add(Facet({\n      key: scope.keyRef(facet.groupby),\n      group: ref(scope.proxy(group.parent)),\n      pulse: data\n    }));\n  } else {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Facet must specify groupby or field: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(facet));\n  }\n\n  // initialize facet subscope\n  const subscope = scope.fork(),\n    source = subscope.add(Collect()),\n    values = subscope.add(Sieve({\n      pulse: ref(source)\n    }));\n  subscope.addData(name, new DataScope(subscope, source, source, values));\n  subscope.addSignal('parent', null);\n\n  // parse faceted subflow\n  op.params.subflow = {\n    $subflow: subscope.parse(spec).toRuntime()\n  };\n}\n\nfunction parseSubflow (spec, scope, input) {\n  const op = scope.add(PreFacet({\n      pulse: input.pulse\n    })),\n    subscope = scope.fork();\n  subscope.add(Sieve());\n  subscope.addSignal('parent', null);\n\n  // parse group mark subflow\n  op.params.subflow = {\n    $subflow: subscope.parse(spec).toRuntime()\n  };\n}\n\nfunction parseTrigger (spec, scope, name) {\n  const remove = spec.remove,\n    insert = spec.insert,\n    toggle = spec.toggle,\n    modify = spec.modify,\n    values = spec.values,\n    op = scope.add(operator());\n  const update = 'if(' + spec.trigger + ',modify(\"' + name + '\",' + [insert, remove, toggle, modify, values].map(_ => _ == null ? 'null' : _).join(',') + '),0)';\n  const expr = (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(update, scope);\n  op.update = expr.$expr;\n  op.params = expr.$params;\n}\n\nfunction parseMark (spec, scope) {\n  const role = getRole(spec),\n    group = spec.type === GroupMark,\n    facet = spec.from && spec.from.facet,\n    overlap = spec.overlap;\n  let layout = spec.layout || role === ScopeRole || role === FrameRole,\n    ops,\n    op,\n    store,\n    enc,\n    name,\n    layoutRef,\n    boundRef;\n  const nested = role === MarkRole || layout || facet;\n\n  // resolve input data\n  const input = parseData$1(spec.from, group, scope);\n\n  // data join to map tuples to visual items\n  op = scope.add(DataJoin({\n    key: input.key || (spec.key ? fieldRef$1(spec.key) : undefined),\n    pulse: input.pulse,\n    clean: !group\n  }));\n  const joinRef = ref(op);\n\n  // collect visual items\n  op = store = scope.add(Collect({\n    pulse: joinRef\n  }));\n\n  // connect visual items to scenegraph\n  op = scope.add(Mark({\n    markdef: definition(spec),\n    interactive: interactive(spec.interactive, scope),\n    clip: clip(spec.clip, scope),\n    context: {\n      $context: true\n    },\n    groups: scope.lookup(),\n    parent: scope.signals.parent ? scope.signalRef('parent') : null,\n    index: scope.markpath(),\n    pulse: ref(op)\n  }));\n  const markRef = ref(op);\n\n  // add visual encoders\n  op = enc = scope.add(Encode(parseEncode(spec.encode, spec.type, role, spec.style, scope, {\n    mod: false,\n    pulse: markRef\n  })));\n\n  // monitor parent marks to propagate changes\n  op.params.parent = scope.encode();\n\n  // add post-encoding transforms, if defined\n  if (spec.transform) {\n    spec.transform.forEach(_ => {\n      const tx = parseTransform(_, scope),\n        md = tx.metadata;\n      if (md.generates || md.changes) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Mark transforms should not generate new data.');\n      }\n      if (!md.nomod) enc.params.mod = true; // update encode mod handling\n      tx.params.pulse = ref(op);\n      scope.add(op = tx);\n    });\n  }\n\n  // if item sort specified, perform post-encoding\n  if (spec.sort) {\n    op = scope.add(SortItems({\n      sort: scope.compareRef(spec.sort),\n      pulse: ref(op)\n    }));\n  }\n  const encodeRef = ref(op);\n\n  // add view layout operator if needed\n  if (facet || layout) {\n    layout = scope.add(ViewLayout({\n      layout: scope.objectProperty(spec.layout),\n      legends: scope.legends,\n      mark: markRef,\n      pulse: encodeRef\n    }));\n    layoutRef = ref(layout);\n  }\n\n  // compute bounding boxes\n  const bound = scope.add(Bound({\n    mark: markRef,\n    pulse: layoutRef || encodeRef\n  }));\n  boundRef = ref(bound);\n\n  // if group mark, recurse to parse nested content\n  if (group) {\n    // juggle layout & bounds to ensure they run *after* any faceting transforms\n    if (nested) {\n      ops = scope.operators;\n      ops.pop();\n      if (layout) ops.pop();\n    }\n    scope.pushState(encodeRef, layoutRef || boundRef, joinRef);\n    facet ? parseFacet(spec, scope, input) // explicit facet\n    : nested ? parseSubflow(spec, scope, input) // standard mark group\n    : scope.parse(spec); // guide group, we can avoid nested scopes\n    scope.popState();\n    if (nested) {\n      if (layout) ops.push(layout);\n      ops.push(bound);\n    }\n  }\n\n  // if requested, add overlap removal transform\n  if (overlap) {\n    boundRef = parseOverlap(overlap, boundRef, scope);\n  }\n\n  // render / sieve items\n  const render = scope.add(Render({\n      pulse: boundRef\n    })),\n    sieve = scope.add(Sieve({\n      pulse: ref(render)\n    }, undefined, scope.parent()));\n\n  // if mark is named, make accessible as reactive geometry\n  // add trigger updates if defined\n  if (spec.name != null) {\n    name = spec.name;\n    scope.addData(name, new DataScope(scope, store, render, sieve));\n    if (spec.on) spec.on.forEach(on => {\n      if (on.insert || on.remove || on.toggle) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Marks only support modify triggers.');\n      }\n      parseTrigger(on, scope, name);\n    });\n  }\n}\nfunction parseOverlap(overlap, source, scope) {\n  const method = overlap.method,\n    bound = overlap.bound,\n    sep = overlap.separation;\n  const params = {\n    separation: isSignal(sep) ? scope.signalRef(sep.signal) : sep,\n    method: isSignal(method) ? scope.signalRef(method.signal) : method,\n    pulse: source\n  };\n  if (overlap.order) {\n    params.sort = scope.compareRef({\n      field: overlap.order\n    });\n  }\n  if (bound) {\n    const tol = bound.tolerance;\n    params.boundTolerance = isSignal(tol) ? scope.signalRef(tol.signal) : +tol;\n    params.boundScale = scope.scaleRef(bound.scale);\n    params.boundOrient = bound.orient;\n  }\n  return ref(scope.add(Overlap(params)));\n}\n\nfunction parseLegend (spec, scope) {\n  const config = scope.config.legend,\n    encode = spec.encode || {},\n    _ = lookup(spec, config),\n    legendEncode = encode.legend || {},\n    name = legendEncode.name || undefined,\n    interactive = legendEncode.interactive,\n    style = legendEncode.style,\n    scales = {};\n  let scale = 0,\n    entryLayout,\n    params,\n    children;\n\n  // resolve scales and 'canonical' scale name\n  LegendScales.forEach(s => spec[s] ? (scales[s] = spec[s], scale = scale || spec[s]) : 0);\n  if (!scale) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing valid scale for legend.');\n\n  // resolve legend type (symbol, gradient, or discrete gradient)\n  const type = legendType(spec, scope.scaleType(scale));\n\n  // single-element data source for legend group\n  const datum = {\n    title: spec.title != null,\n    scales: scales,\n    type: type,\n    vgrad: type !== 'symbol' && _.isVertical()\n  };\n  const dataRef = ref(scope.add(Collect(null, [datum])));\n\n  // encoding properties for legend entry sub-group\n  const entryEncode = {\n    enter: {\n      x: {\n        value: 0\n      },\n      y: {\n        value: 0\n      }\n    }\n  };\n\n  // data source for legend values\n  const entryRef = ref(scope.add(LegendEntries(params = {\n    type: type,\n    scale: scope.scaleRef(scale),\n    count: scope.objectProperty(_('tickCount')),\n    limit: scope.property(_('symbolLimit')),\n    values: scope.objectProperty(spec.values),\n    minstep: scope.property(spec.tickMinStep),\n    formatType: scope.property(spec.formatType),\n    formatSpecifier: scope.property(spec.format)\n  })));\n\n  // continuous gradient legend\n  if (type === Gradient) {\n    children = [legendGradient(spec, scale, config, encode.gradient), legendGradientLabels(spec, config, encode.labels, entryRef)];\n    // adjust default tick count based on the gradient length\n    params.count = params.count || scope.signalRef(`max(2,2*floor((${deref(_.gradientLength())})/100))`);\n  }\n\n  // discrete gradient legend\n  else if (type === Discrete) {\n    children = [legendGradientDiscrete(spec, scale, config, encode.gradient, entryRef), legendGradientLabels(spec, config, encode.labels, entryRef)];\n  }\n\n  // symbol legend\n  else {\n    // determine legend symbol group layout\n    entryLayout = legendSymbolLayout(spec, config);\n    children = [legendSymbolGroups(spec, config, encode, entryRef, deref(entryLayout.columns))];\n    // pass symbol size information to legend entry generator\n    params.size = sizeExpression(spec, scope, children[0].marks);\n  }\n\n  // generate legend marks\n  children = [guideGroup({\n    role: LegendEntryRole,\n    from: dataRef,\n    encode: entryEncode,\n    marks: children,\n    layout: entryLayout,\n    interactive\n  })];\n\n  // include legend title if defined\n  if (datum.title) {\n    children.push(legendTitle(spec, config, encode.title, dataRef));\n  }\n\n  // parse legend specification\n  return parseMark(guideGroup({\n    role: LegendRole,\n    from: dataRef,\n    encode: extendEncode(buildLegendEncode(_, spec, config), legendEncode, Skip),\n    marks: children,\n    aria: _('aria'),\n    description: _('description'),\n    zindex: _('zindex'),\n    name,\n    interactive,\n    style\n  }), scope);\n}\nfunction legendType(spec, scaleType) {\n  let type = spec.type || Symbols;\n  if (!spec.type && scaleCount(spec) === 1 && (spec.fill || spec.stroke)) {\n    type = (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isContinuous)(scaleType) ? Gradient : (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscretizing)(scaleType) ? Discrete : Symbols;\n  }\n  return type !== Gradient ? type : (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.isDiscretizing)(scaleType) ? Discrete : Gradient;\n}\nfunction scaleCount(spec) {\n  return LegendScales.reduce((count, type) => count + (spec[type] ? 1 : 0), 0);\n}\nfunction buildLegendEncode(_, spec, config) {\n  const encode = {\n    enter: {},\n    update: {}\n  };\n  addEncoders(encode, {\n    orient: _('orient'),\n    offset: _('offset'),\n    padding: _('padding'),\n    titlePadding: _('titlePadding'),\n    cornerRadius: _('cornerRadius'),\n    fill: _('fillColor'),\n    stroke: _('strokeColor'),\n    strokeWidth: config.strokeWidth,\n    strokeDash: config.strokeDash,\n    x: _('legendX'),\n    y: _('legendY'),\n    // accessibility support\n    format: spec.format,\n    formatType: spec.formatType\n  });\n  return encode;\n}\nfunction sizeExpression(spec, scope, marks) {\n  const size = deref(getChannel('size', spec, marks)),\n    strokeWidth = deref(getChannel('strokeWidth', spec, marks)),\n    fontSize = deref(getFontSize(marks[1].encode, scope, GuideLabelStyle));\n  return (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(`max(ceil(sqrt(${size})+${strokeWidth}),${fontSize})`, scope);\n}\nfunction getChannel(name, spec, marks) {\n  return spec[name] ? `scale(\"${spec[name]}\",datum)` : getEncoding(name, marks[0].encode);\n}\nfunction getFontSize(encode, scope, style) {\n  return getEncoding('fontSize', encode) || getStyle('fontSize', scope, style);\n}\n\nconst angleExpr = `item.orient===\"${Left}\"?-90:item.orient===\"${Right}\"?90:0`;\nfunction parseTitle (spec, scope) {\n  spec = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(spec) ? {\n    text: spec\n  } : spec;\n  const _ = lookup(spec, scope.config.title),\n    encode = spec.encode || {},\n    userEncode = encode.group || {},\n    name = userEncode.name || undefined,\n    interactive = userEncode.interactive,\n    style = userEncode.style,\n    children = [];\n\n  // single-element data source for group title\n  const datum = {},\n    dataRef = ref(scope.add(Collect(null, [datum])));\n\n  // include title text\n  children.push(buildTitle(spec, _, titleEncode(spec), dataRef));\n\n  // include subtitle text\n  if (spec.subtitle) {\n    children.push(buildSubTitle(spec, _, encode.subtitle, dataRef));\n  }\n\n  // parse title specification\n  return parseMark(guideGroup({\n    role: TitleRole,\n    from: dataRef,\n    encode: groupEncode(_, userEncode),\n    marks: children,\n    aria: _('aria'),\n    description: _('description'),\n    zindex: _('zindex'),\n    name,\n    interactive,\n    style\n  }), scope);\n}\n\n// provide backwards-compatibility for title custom encode;\n// the top-level encode block has been *deprecated*.\nfunction titleEncode(spec) {\n  const encode = spec.encode;\n  return encode && encode.title || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n    name: spec.name,\n    interactive: spec.interactive,\n    style: spec.style\n  }, encode);\n}\nfunction groupEncode(_, userEncode) {\n  const encode = {\n    enter: {},\n    update: {}\n  };\n  addEncoders(encode, {\n    orient: _('orient'),\n    anchor: _('anchor'),\n    align: {\n      signal: alignExpr$1\n    },\n    angle: {\n      signal: angleExpr\n    },\n    limit: _('limit'),\n    frame: _('frame'),\n    offset: _('offset') || 0,\n    padding: _('subtitlePadding')\n  });\n  return extendEncode(encode, userEncode, Skip);\n}\nfunction buildTitle(spec, _, userEncode, dataRef) {\n  const zero = {\n      value: 0\n    },\n    text = spec.text,\n    encode = {\n      enter: {\n        opacity: zero\n      },\n      update: {\n        opacity: {\n          value: 1\n        }\n      },\n      exit: {\n        opacity: zero\n      }\n    };\n  addEncoders(encode, {\n    text: text,\n    align: {\n      signal: 'item.mark.group.align'\n    },\n    angle: {\n      signal: 'item.mark.group.angle'\n    },\n    limit: {\n      signal: 'item.mark.group.limit'\n    },\n    baseline: 'top',\n    dx: _('dx'),\n    dy: _('dy'),\n    fill: _('color'),\n    font: _('font'),\n    fontSize: _('fontSize'),\n    fontStyle: _('fontStyle'),\n    fontWeight: _('fontWeight'),\n    lineHeight: _('lineHeight')\n  }, {\n    // update\n    align: _('align'),\n    angle: _('angle'),\n    baseline: _('baseline')\n  });\n  return guideMark({\n    type: TextMark,\n    role: TitleTextRole,\n    style: GroupTitleStyle,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\nfunction buildSubTitle(spec, _, userEncode, dataRef) {\n  const zero = {\n      value: 0\n    },\n    text = spec.subtitle,\n    encode = {\n      enter: {\n        opacity: zero\n      },\n      update: {\n        opacity: {\n          value: 1\n        }\n      },\n      exit: {\n        opacity: zero\n      }\n    };\n  addEncoders(encode, {\n    text: text,\n    align: {\n      signal: 'item.mark.group.align'\n    },\n    angle: {\n      signal: 'item.mark.group.angle'\n    },\n    limit: {\n      signal: 'item.mark.group.limit'\n    },\n    baseline: 'top',\n    dx: _('dx'),\n    dy: _('dy'),\n    fill: _('subtitleColor'),\n    font: _('subtitleFont'),\n    fontSize: _('subtitleFontSize'),\n    fontStyle: _('subtitleFontStyle'),\n    fontWeight: _('subtitleFontWeight'),\n    lineHeight: _('subtitleLineHeight')\n  }, {\n    // update\n    align: _('align'),\n    angle: _('angle'),\n    baseline: _('baseline')\n  });\n  return guideMark({\n    type: TextMark,\n    role: TitleSubtitleRole,\n    style: GroupSubtitleStyle,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\n\nfunction parseData(data, scope) {\n  const transforms = [];\n  if (data.transform) {\n    data.transform.forEach(tx => {\n      transforms.push(parseTransform(tx, scope));\n    });\n  }\n  if (data.on) {\n    data.on.forEach(on => {\n      parseTrigger(on, scope, data.name);\n    });\n  }\n  scope.addDataPipeline(data.name, analyze(data, scope, transforms));\n}\n\n/**\n * Analyze a data pipeline, add needed operators.\n */\nfunction analyze(data, scope, ops) {\n  const output = [];\n  let source = null,\n    modify = false,\n    generate = false,\n    upstream,\n    i,\n    n,\n    t,\n    m;\n  if (data.values) {\n    // hard-wired input data set\n    if (isSignal(data.values) || hasSignal(data.format)) {\n      // if either values is signal or format has signal, use dynamic loader\n      output.push(load(scope, data));\n      output.push(source = collect());\n    } else {\n      // otherwise, ingest upon dataflow init\n      output.push(source = collect({\n        $ingest: data.values,\n        $format: data.format\n      }));\n    }\n  } else if (data.url) {\n    // load data from external source\n    if (hasSignal(data.url) || hasSignal(data.format)) {\n      // if either url or format has signal, use dynamic loader\n      output.push(load(scope, data));\n      output.push(source = collect());\n    } else {\n      // otherwise, request load upon dataflow init\n      output.push(source = collect({\n        $request: data.url,\n        $format: data.format\n      }));\n    }\n  } else if (data.source) {\n    // derives from one or more other data sets\n    source = upstream = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(data.source).map(d => ref(scope.getData(d).output));\n    output.push(null); // populate later\n  }\n\n  // scan data transforms, add collectors as needed\n  for (i = 0, n = ops.length; i < n; ++i) {\n    t = ops[i];\n    m = t.metadata;\n    if (!source && !m.source) {\n      output.push(source = collect());\n    }\n    output.push(t);\n    if (m.generates) generate = true;\n    if (m.modifies && !generate) modify = true;\n    if (m.source) source = t;else if (m.changes) source = null;\n  }\n  if (upstream) {\n    n = upstream.length - 1;\n    output[0] = Relay({\n      derive: modify,\n      pulse: n ? upstream : upstream[0]\n    });\n    if (modify || n) {\n      // collect derived and multi-pulse tuples\n      output.splice(1, 0, collect());\n    }\n  }\n  if (!source) output.push(collect());\n  output.push(Sieve({}));\n  return output;\n}\nfunction collect(values) {\n  const s = Collect({}, values);\n  s.metadata = {\n    source: true\n  };\n  return s;\n}\nfunction load(scope, data) {\n  return Load({\n    url: data.url ? scope.property(data.url) : undefined,\n    async: data.async ? scope.property(data.async) : undefined,\n    values: data.values ? scope.property(data.values) : undefined,\n    format: scope.objectProperty(data.format)\n  });\n}\n\nconst isX = orient => orient === Bottom || orient === Top;\n\n// get sign coefficient based on axis orient\nconst getSign = (orient, a, b) => isSignal(orient) ? ifLeftTopExpr(orient.signal, a, b) : orient === Left || orient === Top ? a : b;\n\n// condition on axis x-direction\nconst ifX = (orient, a, b) => isSignal(orient) ? ifXEnc(orient.signal, a, b) : isX(orient) ? a : b;\n\n// condition on axis y-direction\nconst ifY = (orient, a, b) => isSignal(orient) ? ifYEnc(orient.signal, a, b) : isX(orient) ? b : a;\nconst ifTop = (orient, a, b) => isSignal(orient) ? ifTopExpr(orient.signal, a, b) : orient === Top ? {\n  value: a\n} : {\n  value: b\n};\nconst ifRight = (orient, a, b) => isSignal(orient) ? ifRightExpr(orient.signal, a, b) : orient === Right ? {\n  value: a\n} : {\n  value: b\n};\nconst ifXEnc = ($orient, a, b) => ifEnc(`${$orient} === '${Top}' || ${$orient} === '${Bottom}'`, a, b);\nconst ifYEnc = ($orient, a, b) => ifEnc(`${$orient} !== '${Top}' && ${$orient} !== '${Bottom}'`, a, b);\nconst ifLeftTopExpr = ($orient, a, b) => ifExpr(`${$orient} === '${Left}' || ${$orient} === '${Top}'`, a, b);\nconst ifTopExpr = ($orient, a, b) => ifExpr(`${$orient} === '${Top}'`, a, b);\nconst ifRightExpr = ($orient, a, b) => ifExpr(`${$orient} === '${Right}'`, a, b);\nconst ifEnc = (test, a, b) => {\n  // ensure inputs are encoder objects (or null)\n  a = a != null ? encoder(a) : a;\n  b = b != null ? encoder(b) : b;\n  if (isSimple(a) && isSimple(b)) {\n    // if possible generate simple signal expression\n    a = a ? a.signal || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(a.value) : null;\n    b = b ? b.signal || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(b.value) : null;\n    return {\n      signal: `${test} ? (${a}) : (${b})`\n    };\n  } else {\n    // otherwise generate rule set\n    return [(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n      test\n    }, a)].concat(b || []);\n  }\n};\nconst isSimple = enc => enc == null || Object.keys(enc).length === 1;\nconst ifExpr = (test, a, b) => ({\n  signal: `${test} ? (${toExpr(a)}) : (${toExpr(b)})`\n});\nconst ifOrient = ($orient, t, b, l, r) => ({\n  signal: (l != null ? `${$orient} === '${Left}' ? (${toExpr(l)}) : ` : '') + (b != null ? `${$orient} === '${Bottom}' ? (${toExpr(b)}) : ` : '') + (r != null ? `${$orient} === '${Right}' ? (${toExpr(r)}) : ` : '') + (t != null ? `${$orient} === '${Top}' ? (${toExpr(t)}) : ` : '') + '(null)'\n});\nconst toExpr = v => isSignal(v) ? v.signal : v == null ? null : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(v);\nconst mult = (sign, value) => value === 0 ? 0 : isSignal(sign) ? {\n  signal: `(${sign.signal}) * ${value}`\n} : {\n  value: sign * value\n};\nconst patch = (value, base) => {\n  const s = value.signal;\n  return s && s.endsWith('(null)') ? {\n    signal: s.slice(0, -6) + base.signal\n  } : value;\n};\n\nfunction fallback(prop, config, axisConfig, style) {\n  let styleProp;\n  if (config && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(config, prop)) {\n    return config[prop];\n  } else if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(axisConfig, prop)) {\n    return axisConfig[prop];\n  } else if (prop.startsWith('title')) {\n    switch (prop) {\n      case 'titleColor':\n        styleProp = 'fill';\n        break;\n      case 'titleFont':\n      case 'titleFontSize':\n      case 'titleFontWeight':\n        styleProp = prop[5].toLowerCase() + prop.slice(6);\n    }\n    return style[GuideTitleStyle][styleProp];\n  } else if (prop.startsWith('label')) {\n    switch (prop) {\n      case 'labelColor':\n        styleProp = 'fill';\n        break;\n      case 'labelFont':\n      case 'labelFontSize':\n        styleProp = prop[5].toLowerCase() + prop.slice(6);\n    }\n    return style[GuideLabelStyle][styleProp];\n  }\n  return null;\n}\nfunction keys(objects) {\n  const map = {};\n  for (const obj of objects) {\n    if (!obj) continue;\n    for (const key in obj) map[key] = 1;\n  }\n  return Object.keys(map);\n}\nfunction axisConfig (spec, scope) {\n  var config = scope.config,\n    style = config.style,\n    axis = config.axis,\n    band = scope.scaleType(spec.scale) === 'band' && config.axisBand,\n    orient = spec.orient,\n    xy,\n    or,\n    key;\n  if (isSignal(orient)) {\n    const xyKeys = keys([config.axisX, config.axisY]),\n      orientKeys = keys([config.axisTop, config.axisBottom, config.axisLeft, config.axisRight]);\n    xy = {};\n    for (key of xyKeys) {\n      xy[key] = ifX(orient, fallback(key, config.axisX, axis, style), fallback(key, config.axisY, axis, style));\n    }\n    or = {};\n    for (key of orientKeys) {\n      or[key] = ifOrient(orient.signal, fallback(key, config.axisTop, axis, style), fallback(key, config.axisBottom, axis, style), fallback(key, config.axisLeft, axis, style), fallback(key, config.axisRight, axis, style));\n    }\n  } else {\n    xy = orient === Top || orient === Bottom ? config.axisX : config.axisY;\n    or = config['axis' + orient[0].toUpperCase() + orient.slice(1)];\n  }\n  const result = xy || or || band ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, axis, xy, or, band) : axis;\n  return result;\n}\n\nfunction axisDomain (spec, config, userEncode, dataRef) {\n  const _ = lookup(spec, config),\n    orient = spec.orient;\n  let enter, update;\n  const encode = {\n    enter: enter = {\n      opacity: zero\n    },\n    update: update = {\n      opacity: one\n    },\n    exit: {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    stroke: _('domainColor'),\n    strokeCap: _('domainCap'),\n    strokeDash: _('domainDash'),\n    strokeDashOffset: _('domainDashOffset'),\n    strokeWidth: _('domainWidth'),\n    strokeOpacity: _('domainOpacity')\n  });\n  const pos0 = position(spec, 0);\n  const pos1 = position(spec, 1);\n  enter.x = update.x = ifX(orient, pos0, zero);\n  enter.x2 = update.x2 = ifX(orient, pos1);\n  enter.y = update.y = ifY(orient, pos0, zero);\n  enter.y2 = update.y2 = ifY(orient, pos1);\n  return guideMark({\n    type: RuleMark,\n    role: AxisDomainRole,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\nfunction position(spec, pos) {\n  return {\n    scale: spec.scale,\n    range: pos\n  };\n}\n\nfunction axisGrid (spec, config, userEncode, dataRef, band) {\n  const _ = lookup(spec, config),\n    orient = spec.orient,\n    vscale = spec.gridScale,\n    sign = getSign(orient, 1, -1),\n    offset = offsetValue(spec.offset, sign);\n  let enter, exit, update;\n  const encode = {\n    enter: enter = {\n      opacity: zero\n    },\n    update: update = {\n      opacity: one\n    },\n    exit: exit = {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    stroke: _('gridColor'),\n    strokeCap: _('gridCap'),\n    strokeDash: _('gridDash'),\n    strokeDashOffset: _('gridDashOffset'),\n    strokeOpacity: _('gridOpacity'),\n    strokeWidth: _('gridWidth')\n  });\n  const tickPos = {\n    scale: spec.scale,\n    field: Value,\n    band: band.band,\n    extra: band.extra,\n    offset: band.offset,\n    round: _('tickRound')\n  };\n  const sz = ifX(orient, {\n    signal: 'height'\n  }, {\n    signal: 'width'\n  });\n  const gridStart = vscale ? {\n    scale: vscale,\n    range: 0,\n    mult: sign,\n    offset: offset\n  } : {\n    value: 0,\n    offset: offset\n  };\n  const gridEnd = vscale ? {\n    scale: vscale,\n    range: 1,\n    mult: sign,\n    offset: offset\n  } : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(sz, {\n    mult: sign,\n    offset: offset\n  });\n  enter.x = update.x = ifX(orient, tickPos, gridStart);\n  enter.y = update.y = ifY(orient, tickPos, gridStart);\n  enter.x2 = update.x2 = ifY(orient, gridEnd);\n  enter.y2 = update.y2 = ifX(orient, gridEnd);\n  exit.x = ifX(orient, tickPos);\n  exit.y = ifY(orient, tickPos);\n  return guideMark({\n    type: RuleMark,\n    role: AxisGridRole,\n    key: Value,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\nfunction offsetValue(offset, sign) {\n  if (sign === 1) ; else if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(offset)) {\n    offset = isSignal(sign) ? {\n      signal: `(${sign.signal}) * (${offset || 0})`\n    } : sign * (offset || 0);\n  } else {\n    let entry = offset = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, offset);\n    while (entry.mult != null) {\n      if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(entry.mult)) {\n        entry.mult = isSignal(sign) // no offset if sign === 1\n        ? {\n          signal: `(${entry.mult}) * (${sign.signal})`\n        } : entry.mult * sign;\n        return offset;\n      } else {\n        entry = entry.mult = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, entry.mult);\n      }\n    }\n    entry.mult = sign;\n  }\n  return offset;\n}\n\nfunction axisTicks (spec, config, userEncode, dataRef, size, band) {\n  const _ = lookup(spec, config),\n    orient = spec.orient,\n    sign = getSign(orient, -1, 1);\n  let enter, exit, update;\n  const encode = {\n    enter: enter = {\n      opacity: zero\n    },\n    update: update = {\n      opacity: one\n    },\n    exit: exit = {\n      opacity: zero\n    }\n  };\n  addEncoders(encode, {\n    stroke: _('tickColor'),\n    strokeCap: _('tickCap'),\n    strokeDash: _('tickDash'),\n    strokeDashOffset: _('tickDashOffset'),\n    strokeOpacity: _('tickOpacity'),\n    strokeWidth: _('tickWidth')\n  });\n  const tickSize = encoder(size);\n  tickSize.mult = sign;\n  const tickPos = {\n    scale: spec.scale,\n    field: Value,\n    band: band.band,\n    extra: band.extra,\n    offset: band.offset,\n    round: _('tickRound')\n  };\n  update.y = enter.y = ifX(orient, zero, tickPos);\n  update.y2 = enter.y2 = ifX(orient, tickSize);\n  exit.x = ifX(orient, tickPos);\n  update.x = enter.x = ifY(orient, zero, tickPos);\n  update.x2 = enter.x2 = ifY(orient, tickSize);\n  exit.y = ifY(orient, tickPos);\n  return guideMark({\n    type: RuleMark,\n    role: AxisTickRole,\n    key: Value,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\n\nfunction flushExpr(scale, threshold, a, b, c) {\n  return {\n    signal: 'flush(range(\"' + scale + '\"), ' + 'scale(\"' + scale + '\", datum.value), ' + threshold + ',' + a + ',' + b + ',' + c + ')'\n  };\n}\nfunction axisLabels (spec, config, userEncode, dataRef, size, band) {\n  const _ = lookup(spec, config),\n    orient = spec.orient,\n    scale = spec.scale,\n    sign = getSign(orient, -1, 1),\n    flush = deref(_('labelFlush')),\n    flushOffset = deref(_('labelFlushOffset')),\n    labelAlign = _('labelAlign'),\n    labelBaseline = _('labelBaseline');\n  let flushOn = flush === 0 || !!flush,\n    update;\n  const tickSize = encoder(size);\n  tickSize.mult = sign;\n  tickSize.offset = encoder(_('labelPadding') || 0);\n  tickSize.offset.mult = sign;\n  const tickPos = {\n    scale: scale,\n    field: Value,\n    band: 0.5,\n    offset: extendOffset(band.offset, _('labelOffset'))\n  };\n  const align = ifX(orient, flushOn ? flushExpr(scale, flush, '\"left\"', '\"right\"', '\"center\"') : {\n    value: 'center'\n  }, ifRight(orient, 'left', 'right'));\n  const baseline = ifX(orient, ifTop(orient, 'bottom', 'top'), flushOn ? flushExpr(scale, flush, '\"top\"', '\"bottom\"', '\"middle\"') : {\n    value: 'middle'\n  });\n  const offsetExpr = flushExpr(scale, flush, `-(${flushOffset})`, flushOffset, 0);\n  flushOn = flushOn && flushOffset;\n  const enter = {\n    opacity: zero,\n    x: ifX(orient, tickPos, tickSize),\n    y: ifY(orient, tickPos, tickSize)\n  };\n  const encode = {\n    enter: enter,\n    update: update = {\n      opacity: one,\n      text: {\n        field: Label\n      },\n      x: enter.x,\n      y: enter.y,\n      align,\n      baseline\n    },\n    exit: {\n      opacity: zero,\n      x: enter.x,\n      y: enter.y\n    }\n  };\n  addEncoders(encode, {\n    dx: !labelAlign && flushOn ? ifX(orient, offsetExpr) : null,\n    dy: !labelBaseline && flushOn ? ifY(orient, offsetExpr) : null\n  });\n  addEncoders(encode, {\n    angle: _('labelAngle'),\n    fill: _('labelColor'),\n    fillOpacity: _('labelOpacity'),\n    font: _('labelFont'),\n    fontSize: _('labelFontSize'),\n    fontWeight: _('labelFontWeight'),\n    fontStyle: _('labelFontStyle'),\n    limit: _('labelLimit'),\n    lineHeight: _('labelLineHeight')\n  }, {\n    align: labelAlign,\n    baseline: labelBaseline\n  });\n  const bound = _('labelBound');\n  let overlap = _('labelOverlap');\n\n  // if overlap method or bound defined, request label overlap removal\n  overlap = overlap || bound ? {\n    separation: _('labelSeparation'),\n    method: overlap,\n    order: 'datum.index',\n    bound: bound ? {\n      scale,\n      orient,\n      tolerance: bound\n    } : null\n  } : undefined;\n  if (update.align !== align) {\n    update.align = patch(update.align, align);\n  }\n  if (update.baseline !== baseline) {\n    update.baseline = patch(update.baseline, baseline);\n  }\n  return guideMark({\n    type: TextMark,\n    role: AxisLabelRole,\n    style: GuideLabelStyle,\n    key: Value,\n    from: dataRef,\n    encode,\n    overlap\n  }, userEncode);\n}\n\nfunction axisTitle (spec, config, userEncode, dataRef) {\n  const _ = lookup(spec, config),\n    orient = spec.orient,\n    sign = getSign(orient, -1, 1);\n  let enter, update;\n  const encode = {\n    enter: enter = {\n      opacity: zero,\n      anchor: encoder(_('titleAnchor', null)),\n      align: {\n        signal: alignExpr$1\n      }\n    },\n    update: update = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, enter, {\n      opacity: one,\n      text: encoder(spec.title)\n    }),\n    exit: {\n      opacity: zero\n    }\n  };\n  const titlePos = {\n    signal: `lerp(range(\"${spec.scale}\"), ${anchorExpr(0, 1, 0.5)})`\n  };\n  update.x = ifX(orient, titlePos);\n  update.y = ifY(orient, titlePos);\n  enter.angle = ifX(orient, zero, mult(sign, 90));\n  enter.baseline = ifX(orient, ifTop(orient, Bottom, Top), {\n    value: Bottom\n  });\n  update.angle = enter.angle;\n  update.baseline = enter.baseline;\n  addEncoders(encode, {\n    fill: _('titleColor'),\n    fillOpacity: _('titleOpacity'),\n    font: _('titleFont'),\n    fontSize: _('titleFontSize'),\n    fontStyle: _('titleFontStyle'),\n    fontWeight: _('titleFontWeight'),\n    limit: _('titleLimit'),\n    lineHeight: _('titleLineHeight')\n  }, {\n    // require update\n    align: _('titleAlign'),\n    angle: _('titleAngle'),\n    baseline: _('titleBaseline')\n  });\n  autoLayout(_, orient, encode, userEncode);\n  encode.update.align = patch(encode.update.align, enter.align);\n  encode.update.angle = patch(encode.update.angle, enter.angle);\n  encode.update.baseline = patch(encode.update.baseline, enter.baseline);\n  return guideMark({\n    type: TextMark,\n    role: AxisTitleRole,\n    style: GuideTitleStyle,\n    from: dataRef,\n    encode\n  }, userEncode);\n}\nfunction autoLayout(_, orient, encode, userEncode) {\n  const auto = (value, dim) => value != null ? (encode.update[dim] = patch(encoder(value), encode.update[dim]), false) : !has(dim, userEncode) ? true : false;\n  const autoY = auto(_('titleX'), 'x'),\n    autoX = auto(_('titleY'), 'y');\n  encode.enter.auto = autoX === autoY ? encoder(autoX) : ifX(orient, encoder(autoX), encoder(autoY));\n}\n\nfunction parseAxis (spec, scope) {\n  const config = axisConfig(spec, scope),\n    encode = spec.encode || {},\n    axisEncode = encode.axis || {},\n    name = axisEncode.name || undefined,\n    interactive = axisEncode.interactive,\n    style = axisEncode.style,\n    _ = lookup(spec, config),\n    band = tickBand(_);\n\n  // single-element data source for axis group\n  const datum = {\n    scale: spec.scale,\n    ticks: !!_('ticks'),\n    labels: !!_('labels'),\n    grid: !!_('grid'),\n    domain: !!_('domain'),\n    title: spec.title != null\n  };\n  const dataRef = ref(scope.add(Collect({}, [datum])));\n\n  // data source for axis ticks\n  const ticksRef = ref(scope.add(AxisTicks({\n    scale: scope.scaleRef(spec.scale),\n    extra: scope.property(band.extra),\n    count: scope.objectProperty(spec.tickCount),\n    values: scope.objectProperty(spec.values),\n    minstep: scope.property(spec.tickMinStep),\n    formatType: scope.property(spec.formatType),\n    formatSpecifier: scope.property(spec.format)\n  })));\n\n  // generate axis marks\n  const children = [];\n  let size;\n\n  // include axis gridlines if requested\n  if (datum.grid) {\n    children.push(axisGrid(spec, config, encode.grid, ticksRef, band));\n  }\n\n  // include axis ticks if requested\n  if (datum.ticks) {\n    size = _('tickSize');\n    children.push(axisTicks(spec, config, encode.ticks, ticksRef, size, band));\n  }\n\n  // include axis labels if requested\n  if (datum.labels) {\n    size = datum.ticks ? size : 0;\n    children.push(axisLabels(spec, config, encode.labels, ticksRef, size, band));\n  }\n\n  // include axis domain path if requested\n  if (datum.domain) {\n    children.push(axisDomain(spec, config, encode.domain, dataRef));\n  }\n\n  // include axis title if defined\n  if (datum.title) {\n    children.push(axisTitle(spec, config, encode.title, dataRef));\n  }\n\n  // parse axis specification\n  return parseMark(guideGroup({\n    role: AxisRole,\n    from: dataRef,\n    encode: extendEncode(buildAxisEncode(_, spec), axisEncode, Skip),\n    marks: children,\n    aria: _('aria'),\n    description: _('description'),\n    zindex: _('zindex'),\n    name,\n    interactive,\n    style\n  }), scope);\n}\nfunction buildAxisEncode(_, spec) {\n  const encode = {\n    enter: {},\n    update: {}\n  };\n  addEncoders(encode, {\n    orient: _('orient'),\n    offset: _('offset') || 0,\n    position: value(spec.position, 0),\n    titlePadding: _('titlePadding'),\n    minExtent: _('minExtent'),\n    maxExtent: _('maxExtent'),\n    range: {\n      signal: `abs(span(range(\"${spec.scale}\")))`\n    },\n    translate: _('translate'),\n    // accessibility support\n    format: spec.format,\n    formatType: spec.formatType\n  });\n  return encode;\n}\n\nfunction parseScope (spec, scope, preprocessed) {\n  const signals = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.signals),\n    scales = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.scales);\n\n  // parse signal definitions, if not already preprocessed\n  if (!preprocessed) signals.forEach(_ => parseSignal(_, scope));\n\n  // parse cartographic projection definitions\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.projections).forEach(_ => parseProjection(_, scope));\n\n  // initialize scale references\n  scales.forEach(_ => initScale(_, scope));\n\n  // parse data sources\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.data).forEach(_ => parseData(_, scope));\n\n  // parse scale definitions\n  scales.forEach(_ => parseScale(_, scope));\n\n  // parse signal updates\n  (preprocessed || signals).forEach(_ => parseSignalUpdates(_, scope));\n\n  // parse axis definitions\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.axes).forEach(_ => parseAxis(_, scope));\n\n  // parse mark definitions\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.marks).forEach(_ => parseMark(_, scope));\n\n  // parse legend definitions\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.legends).forEach(_ => parseLegend(_, scope));\n\n  // parse title, if defined\n  if (spec.title) parseTitle(spec.title, scope);\n\n  // parse collected lambda (anonymous) expressions\n  scope.parseLambdas();\n  return scope;\n}\n\nconst rootEncode = spec => extendEncode({\n  enter: {\n    x: {\n      value: 0\n    },\n    y: {\n      value: 0\n    }\n  },\n  update: {\n    width: {\n      signal: 'width'\n    },\n    height: {\n      signal: 'height'\n    }\n  }\n}, spec);\nfunction parseView(spec, scope) {\n  const config = scope.config;\n\n  // add scenegraph root\n  const root = ref(scope.root = scope.add(operator()));\n\n  // parse top-level signal definitions\n  const signals = collectSignals(spec, config);\n  signals.forEach(_ => parseSignal(_, scope));\n\n  // assign description, event, legend, and locale configuration\n  scope.description = spec.description || config.description;\n  scope.eventConfig = config.events;\n  scope.legends = scope.objectProperty(config.legend && config.legend.layout);\n  scope.locale = config.locale;\n\n  // store root group item\n  const input = scope.add(Collect());\n\n  // encode root group item\n  const encode = scope.add(Encode(parseEncode(rootEncode(spec.encode), GroupMark, FrameRole, spec.style, scope, {\n    pulse: ref(input)\n  })));\n\n  // perform view layout\n  const parent = scope.add(ViewLayout({\n    layout: scope.objectProperty(spec.layout),\n    legends: scope.legends,\n    autosize: scope.signalRef('autosize'),\n    mark: root,\n    pulse: ref(encode)\n  }));\n  scope.operators.pop();\n\n  // parse remainder of specification\n  scope.pushState(ref(encode), ref(parent), null);\n  parseScope(spec, scope, signals);\n  scope.operators.push(parent);\n\n  // bound / render / sieve root item\n  let op = scope.add(Bound({\n    mark: root,\n    pulse: ref(parent)\n  }));\n  op = scope.add(Render({\n    pulse: ref(op)\n  }));\n  op = scope.add(Sieve({\n    pulse: ref(op)\n  }));\n\n  // track metadata for root item\n  scope.addData('root', new DataScope(scope, input, input, op));\n  return scope;\n}\nfunction signalObject(name, value) {\n  return value && value.signal ? {\n    name,\n    update: value.signal\n  } : {\n    name,\n    value\n  };\n}\n\n/**\n * Collect top-level signals, merging values as needed. Signals\n * defined in the config signals arrays are added only if that\n * signal is not explicitly defined in the specification.\n * Built-in signals (autosize, background, padding, width, height)\n * receive special treatment. They are initialized using the\n * top-level spec property, or, if undefined in the spec, using\n * the corresponding top-level config property. If this property\n * is a signal reference object, the signal expression maps to the\n * signal 'update' property. If the spec's top-level signal array\n * contains an entry that matches a built-in signal, that entry\n * will be merged with the built-in specification, potentially\n * overwriting existing 'value' or 'update' properties.\n */\nfunction collectSignals(spec, config) {\n  const _ = name => value(spec[name], config[name]),\n    signals = [signalObject('background', _('background')), signalObject('autosize', parseAutosize(_('autosize'))), signalObject('padding', parsePadding(_('padding'))), signalObject('width', _('width') || 0), signalObject('height', _('height') || 0)],\n    pre = signals.reduce((p, s) => (p[s.name] = s, p), {}),\n    map = {};\n\n  // add spec signal array\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(spec.signals).forEach(s => {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(pre, s.name)) {\n      // merge if built-in signal\n      s = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(pre[s.name], s);\n    } else {\n      // otherwise add to signal list\n      signals.push(s);\n    }\n    map[s.name] = s;\n  });\n\n  // add config signal array\n  (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(config.signals).forEach(s => {\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(map, s.name) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(pre, s.name)) {\n      // add to signal list if not already defined\n      signals.push(s);\n    }\n  });\n  return signals;\n}\n\nfunction Scope(config, options) {\n  this.config = config || {};\n  this.options = options || {};\n  this.bindings = [];\n  this.field = {};\n  this.signals = {};\n  this.lambdas = {};\n  this.scales = {};\n  this.events = {};\n  this.data = {};\n  this.streams = [];\n  this.updates = [];\n  this.operators = [];\n  this.eventConfig = null;\n  this.locale = null;\n  this._id = 0;\n  this._subid = 0;\n  this._nextsub = [0];\n  this._parent = [];\n  this._encode = [];\n  this._lookup = [];\n  this._markpath = [];\n}\nfunction Subscope(scope) {\n  this.config = scope.config;\n  this.options = scope.options;\n  this.legends = scope.legends;\n  this.field = Object.create(scope.field);\n  this.signals = Object.create(scope.signals);\n  this.lambdas = Object.create(scope.lambdas);\n  this.scales = Object.create(scope.scales);\n  this.events = Object.create(scope.events);\n  this.data = Object.create(scope.data);\n  this.streams = [];\n  this.updates = [];\n  this.operators = [];\n  this._id = 0;\n  this._subid = ++scope._nextsub[0];\n  this._nextsub = scope._nextsub;\n  this._parent = scope._parent.slice();\n  this._encode = scope._encode.slice();\n  this._lookup = scope._lookup.slice();\n  this._markpath = scope._markpath;\n}\nScope.prototype = Subscope.prototype = {\n  parse(spec) {\n    return parseScope(spec, this);\n  },\n  fork() {\n    return new Subscope(this);\n  },\n  isSubscope() {\n    return this._subid > 0;\n  },\n  toRuntime() {\n    this.finish();\n    return {\n      description: this.description,\n      operators: this.operators,\n      streams: this.streams,\n      updates: this.updates,\n      bindings: this.bindings,\n      eventConfig: this.eventConfig,\n      locale: this.locale\n    };\n  },\n  id() {\n    return (this._subid ? this._subid + ':' : 0) + this._id++;\n  },\n  add(op) {\n    this.operators.push(op);\n    op.id = this.id();\n    // if pre-registration references exist, resolve them now\n    if (op.refs) {\n      op.refs.forEach(ref => {\n        ref.$ref = op.id;\n      });\n      op.refs = null;\n    }\n    return op;\n  },\n  proxy(op) {\n    const vref = op instanceof Entry ? ref(op) : op;\n    return this.add(Proxy({\n      value: vref\n    }));\n  },\n  addStream(stream) {\n    this.streams.push(stream);\n    stream.id = this.id();\n    return stream;\n  },\n  addUpdate(update) {\n    this.updates.push(update);\n    return update;\n  },\n  // Apply metadata\n  finish() {\n    let name, ds;\n\n    // annotate root\n    if (this.root) this.root.root = true;\n\n    // annotate signals\n    for (name in this.signals) {\n      this.signals[name].signal = name;\n    }\n\n    // annotate scales\n    for (name in this.scales) {\n      this.scales[name].scale = name;\n    }\n\n    // annotate data sets\n    function annotate(op, name, type) {\n      let data, list;\n      if (op) {\n        data = op.data || (op.data = {});\n        list = data[name] || (data[name] = []);\n        list.push(type);\n      }\n    }\n    for (name in this.data) {\n      ds = this.data[name];\n      annotate(ds.input, name, 'input');\n      annotate(ds.output, name, 'output');\n      annotate(ds.values, name, 'values');\n      for (const field in ds.index) {\n        annotate(ds.index[field], name, 'index:' + field);\n      }\n    }\n    return this;\n  },\n  // ----\n\n  pushState(encode, parent, lookup) {\n    this._encode.push(ref(this.add(Sieve({\n      pulse: encode\n    }))));\n    this._parent.push(parent);\n    this._lookup.push(lookup ? ref(this.proxy(lookup)) : null);\n    this._markpath.push(-1);\n  },\n  popState() {\n    this._encode.pop();\n    this._parent.pop();\n    this._lookup.pop();\n    this._markpath.pop();\n  },\n  parent() {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(this._parent);\n  },\n  encode() {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(this._encode);\n  },\n  lookup() {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(this._lookup);\n  },\n  markpath() {\n    const p = this._markpath;\n    return ++p[p.length - 1];\n  },\n  // ----\n\n  fieldRef(field, name) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(field)) return fieldRef$1(field, name);\n    if (!field.signal) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unsupported field reference: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(field));\n    }\n    const s = field.signal;\n    let f = this.field[s];\n    if (!f) {\n      const params = {\n        name: this.signalRef(s)\n      };\n      if (name) params.as = name;\n      this.field[s] = f = ref(this.add(Field(params)));\n    }\n    return f;\n  },\n  compareRef(cmp) {\n    let signal = false;\n    const check = _ => isSignal(_) ? (signal = true, this.signalRef(_.signal)) : isExpr$1(_) ? (signal = true, this.exprRef(_.expr)) : _;\n    const fields = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(cmp.field).map(check),\n      orders = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(cmp.order).map(check);\n    return signal ? ref(this.add(Compare({\n      fields: fields,\n      orders: orders\n    }))) : compareRef(fields, orders);\n  },\n  keyRef(fields, flat) {\n    let signal = false;\n    const check = _ => isSignal(_) ? (signal = true, ref(sig[_.signal])) : _;\n    const sig = this.signals;\n    fields = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(fields).map(check);\n    return signal ? ref(this.add(Key({\n      fields: fields,\n      flat: flat\n    }))) : keyRef(fields, flat);\n  },\n  sortRef(sort) {\n    if (!sort) return sort;\n\n    // including id ensures stable sorting\n    const a = aggrField(sort.op, sort.field),\n      o = sort.order || Ascending;\n    return o.signal ? ref(this.add(Compare({\n      fields: a,\n      orders: this.signalRef(o.signal)\n    }))) : compareRef(a, o);\n  },\n  // ----\n\n  event(source, type) {\n    const key = source + ':' + type;\n    if (!this.events[key]) {\n      const id = this.id();\n      this.streams.push({\n        id: id,\n        source: source,\n        type: type\n      });\n      this.events[key] = id;\n    }\n    return this.events[key];\n  },\n  // ----\n\n  hasOwnSignal(name) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(this.signals, name);\n  },\n  addSignal(name, value) {\n    if (this.hasOwnSignal(name)) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Duplicate signal name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    const op = value instanceof Entry ? value : this.add(operator(value));\n    return this.signals[name] = op;\n  },\n  getSignal(name) {\n    if (!this.signals[name]) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized signal name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    return this.signals[name];\n  },\n  signalRef(s) {\n    if (this.signals[s]) {\n      return ref(this.signals[s]);\n    } else if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(this.lambdas, s)) {\n      this.lambdas[s] = this.add(operator(null));\n    }\n    return ref(this.lambdas[s]);\n  },\n  parseLambdas() {\n    const code = Object.keys(this.lambdas);\n    for (let i = 0, n = code.length; i < n; ++i) {\n      const s = code[i],\n        e = (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(s, this),\n        op = this.lambdas[s];\n      op.params = e.$params;\n      op.update = e.$expr;\n    }\n  },\n  property(spec) {\n    return spec && spec.signal ? this.signalRef(spec.signal) : spec;\n  },\n  objectProperty(spec) {\n    return !spec || !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(spec) ? spec : this.signalRef(spec.signal || propertyLambda(spec));\n  },\n  exprRef(code, name) {\n    const params = {\n      expr: (0,vega_functions__WEBPACK_IMPORTED_MODULE_1__.parseExpression)(code, this)\n    };\n    if (name) params.expr.$name = name;\n    return ref(this.add(Expression(params)));\n  },\n  addBinding(name, bind) {\n    if (!this.bindings) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Nested signals do not support binding: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    this.bindings.push((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n      signal: name\n    }, bind));\n  },\n  // ----\n\n  addScaleProj(name, transform) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(this.scales, name)) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Duplicate scale or projection name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    this.scales[name] = this.add(transform);\n  },\n  addScale(name, params) {\n    this.addScaleProj(name, Scale(params));\n  },\n  addProjection(name, params) {\n    this.addScaleProj(name, Projection(params));\n  },\n  getScale(name) {\n    if (!this.scales[name]) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized scale name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    return this.scales[name];\n  },\n  scaleRef(name) {\n    return ref(this.getScale(name));\n  },\n  scaleType(name) {\n    return this.getScale(name).params.type;\n  },\n  projectionRef(name) {\n    return this.scaleRef(name);\n  },\n  projectionType(name) {\n    return this.scaleType(name);\n  },\n  // ----\n\n  addData(name, dataScope) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(this.data, name)) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Duplicate data set name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    return this.data[name] = dataScope;\n  },\n  getData(name) {\n    if (!this.data[name]) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Undefined data set name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    return this.data[name];\n  },\n  addDataPipeline(name, entries) {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(this.data, name)) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Duplicate data set name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n    }\n    return this.addData(name, DataScope.fromEntries(this, entries));\n  }\n};\nfunction propertyLambda(spec) {\n  return ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(spec) ? arrayLambda : objectLambda)(spec);\n}\nfunction arrayLambda(array) {\n  const n = array.length;\n  let code = '[';\n  for (let i = 0; i < n; ++i) {\n    const value = array[i];\n    code += (i > 0 ? ',' : '') + ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) ? value.signal || propertyLambda(value) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(value));\n  }\n  return code + ']';\n}\nfunction objectLambda(obj) {\n  let code = '{',\n    i = 0,\n    key,\n    value;\n  for (key in obj) {\n    value = obj[key];\n    code += (++i > 1 ? ',' : '') + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(key) + ':' + ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) ? value.signal || propertyLambda(value) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(value));\n  }\n  return code + '}';\n}\n\n/**\n * Standard configuration defaults for Vega specification parsing.\n * Users can provide their own (sub-)set of these default values\n * by passing in a config object to the top-level parse method.\n */\nfunction defaults () {\n  const defaultFont = 'sans-serif',\n    defaultSymbolSize = 30,\n    defaultStrokeWidth = 2,\n    defaultColor = '#4c78a8',\n    black = '#000',\n    gray = '#888',\n    lightGray = '#ddd';\n  return {\n    // default visualization description\n    description: 'Vega visualization',\n    // default padding around visualization\n    padding: 0,\n    // default for automatic sizing; options: 'none', 'pad', 'fit'\n    // or provide an object (e.g., {'type': 'pad', 'resize': true})\n    autosize: 'pad',\n    // default view background color\n    // covers the entire view component\n    background: null,\n    // default event handling configuration\n    // preventDefault for view-sourced event types except 'wheel'\n    events: {\n      defaults: {\n        allow: ['wheel']\n      }\n    },\n    // defaults for top-level group marks\n    // accepts mark properties (fill, stroke, etc)\n    // covers the data rectangle within group width/height\n    group: null,\n    // defaults for basic mark types\n    // each subset accepts mark properties (fill, stroke, etc)\n    mark: null,\n    arc: {\n      fill: defaultColor\n    },\n    area: {\n      fill: defaultColor\n    },\n    image: null,\n    line: {\n      stroke: defaultColor,\n      strokeWidth: defaultStrokeWidth\n    },\n    path: {\n      stroke: defaultColor\n    },\n    rect: {\n      fill: defaultColor\n    },\n    rule: {\n      stroke: black\n    },\n    shape: {\n      stroke: defaultColor\n    },\n    symbol: {\n      fill: defaultColor,\n      size: 64\n    },\n    text: {\n      fill: black,\n      font: defaultFont,\n      fontSize: 11\n    },\n    trail: {\n      fill: defaultColor,\n      size: defaultStrokeWidth\n    },\n    // style definitions\n    style: {\n      // axis & legend labels\n      'guide-label': {\n        fill: black,\n        font: defaultFont,\n        fontSize: 10\n      },\n      // axis & legend titles\n      'guide-title': {\n        fill: black,\n        font: defaultFont,\n        fontSize: 11,\n        fontWeight: 'bold'\n      },\n      // headers, including chart title\n      'group-title': {\n        fill: black,\n        font: defaultFont,\n        fontSize: 13,\n        fontWeight: 'bold'\n      },\n      // chart subtitle\n      'group-subtitle': {\n        fill: black,\n        font: defaultFont,\n        fontSize: 12\n      },\n      // defaults for styled point marks in Vega-Lite\n      point: {\n        size: defaultSymbolSize,\n        strokeWidth: defaultStrokeWidth,\n        shape: 'circle'\n      },\n      circle: {\n        size: defaultSymbolSize,\n        strokeWidth: defaultStrokeWidth\n      },\n      square: {\n        size: defaultSymbolSize,\n        strokeWidth: defaultStrokeWidth,\n        shape: 'square'\n      },\n      // defaults for styled group marks in Vega-Lite\n      cell: {\n        fill: 'transparent',\n        stroke: lightGray\n      },\n      view: {\n        fill: 'transparent'\n      }\n    },\n    // defaults for title\n    title: {\n      orient: 'top',\n      anchor: 'middle',\n      offset: 4,\n      subtitlePadding: 3\n    },\n    // defaults for axes\n    axis: {\n      minExtent: 0,\n      maxExtent: 200,\n      bandPosition: 0.5,\n      domain: true,\n      domainWidth: 1,\n      domainColor: gray,\n      grid: false,\n      gridWidth: 1,\n      gridColor: lightGray,\n      labels: true,\n      labelAngle: 0,\n      labelLimit: 180,\n      labelOffset: 0,\n      labelPadding: 2,\n      ticks: true,\n      tickColor: gray,\n      tickOffset: 0,\n      tickRound: true,\n      tickSize: 5,\n      tickWidth: 1,\n      titlePadding: 4\n    },\n    // correction for centering bias\n    axisBand: {\n      tickOffset: -0.5\n    },\n    // defaults for cartographic projection\n    projection: {\n      type: 'mercator'\n    },\n    // defaults for legends\n    legend: {\n      orient: 'right',\n      padding: 0,\n      gridAlign: 'each',\n      columnPadding: 10,\n      rowPadding: 2,\n      symbolDirection: 'vertical',\n      gradientDirection: 'vertical',\n      gradientLength: 200,\n      gradientThickness: 16,\n      gradientStrokeColor: lightGray,\n      gradientStrokeWidth: 0,\n      gradientLabelOffset: 2,\n      labelAlign: 'left',\n      labelBaseline: 'middle',\n      labelLimit: 160,\n      labelOffset: 4,\n      labelOverlap: true,\n      symbolLimit: 30,\n      symbolType: 'circle',\n      symbolSize: 100,\n      symbolOffset: 0,\n      symbolStrokeWidth: 1.5,\n      symbolBaseFillColor: 'transparent',\n      symbolBaseStrokeColor: gray,\n      titleLimit: 180,\n      titleOrient: 'top',\n      titlePadding: 5,\n      layout: {\n        offset: 18,\n        direction: 'horizontal',\n        left: {\n          direction: 'vertical'\n        },\n        right: {\n          direction: 'vertical'\n        }\n      }\n    },\n    // defaults for scale ranges\n    range: {\n      category: {\n        scheme: 'tableau10'\n      },\n      ordinal: {\n        scheme: 'blues'\n      },\n      heatmap: {\n        scheme: 'yellowgreenblue'\n      },\n      ramp: {\n        scheme: 'blues'\n      },\n      diverging: {\n        scheme: 'blueorange',\n        extent: [1, 0]\n      },\n      symbol: ['circle', 'square', 'triangle-up', 'cross', 'diamond', 'triangle-right', 'triangle-down', 'triangle-left']\n    }\n  };\n}\n\nfunction parse (spec, config, options) {\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(spec)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Input Vega specification must be an object.');\n  }\n  config = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.mergeConfig)(defaults(), config, spec.config);\n  return parseView(spec, new Scope(config, options)).toRuntime();\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-parser/build/vega-parser.module.js?");

/***/ }),

/***/ "../../node_modules/vega-projection/build/vega-projection.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-projection/build/vega-projection.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getProjectionPath: () => (/* binding */ getProjectionPath),\n/* harmony export */   projection: () => (/* binding */ projection),\n/* harmony export */   projectionProperties: () => (/* binding */ projectionProperties)\n/* harmony export */ });\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/path/index.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/albers.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/albersUsa.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/azimuthalEqualArea.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/azimuthalEquidistant.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/conicConformal.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/conicEqualArea.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/conicEquidistant.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/equalEarth.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/equirectangular.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/gnomonic.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/identity.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/mercator.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/naturalEarth1.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/orthographic.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/stereographic.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/transverseMercator.js\");\n/* harmony import */ var d3_geo_projection__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-geo-projection */ \"../../node_modules/d3-geo-projection/src/mollweide.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n\n\n\n\nconst defaultPath = (0,d3_geo__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\nconst projectionProperties = [\n// standard properties in d3-geo\n'clipAngle', 'clipExtent', 'scale', 'translate', 'center', 'rotate', 'parallels', 'precision', 'reflectX', 'reflectY',\n// extended properties in d3-geo-projections\n'coefficient', 'distance', 'fraction', 'lobes', 'parallel', 'radius', 'ratio', 'spacing', 'tilt'];\n\n/**\n * Augment projections with their type and a copy method.\n */\nfunction create(type, constructor) {\n  return function projection() {\n    const p = constructor();\n    p.type = type;\n    p.path = (0,d3_geo__WEBPACK_IMPORTED_MODULE_1__[\"default\"])().projection(p);\n    p.copy = p.copy || function () {\n      const c = projection();\n      projectionProperties.forEach(prop => {\n        if (p[prop]) c[prop](p[prop]());\n      });\n      c.path.pointRadius(p.path.pointRadius());\n      return c;\n    };\n    return (0,vega_scale__WEBPACK_IMPORTED_MODULE_0__.registerScale)(p);\n  };\n}\nfunction projection(type, proj) {\n  if (!type || typeof type !== 'string') {\n    throw new Error('Projection type must be a name string.');\n  }\n  type = type.toLowerCase();\n  if (arguments.length > 1) {\n    projections[type] = create(type, proj);\n    return this;\n  } else {\n    return projections[type] || null;\n  }\n}\nfunction getProjectionPath(proj) {\n  return proj && proj.path || defaultPath;\n}\nconst projections = {\n  // base d3-geo projection types\n  albers: d3_geo__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  albersusa: d3_geo__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  azimuthalequalarea: d3_geo__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  azimuthalequidistant: d3_geo__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  conicconformal: d3_geo__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  conicequalarea: d3_geo__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  conicequidistant: d3_geo__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  equalEarth: d3_geo__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n  equirectangular: d3_geo__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n  gnomonic: d3_geo__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n  identity: d3_geo__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n  mercator: d3_geo__WEBPACK_IMPORTED_MODULE_13__[\"default\"],\n  mollweide: d3_geo_projection__WEBPACK_IMPORTED_MODULE_14__[\"default\"],\n  naturalEarth1: d3_geo__WEBPACK_IMPORTED_MODULE_15__[\"default\"],\n  orthographic: d3_geo__WEBPACK_IMPORTED_MODULE_16__[\"default\"],\n  stereographic: d3_geo__WEBPACK_IMPORTED_MODULE_17__[\"default\"],\n  transversemercator: d3_geo__WEBPACK_IMPORTED_MODULE_18__[\"default\"]\n};\nfor (const key in projections) {\n  projection(key, projections[key]);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-projection/build/vega-projection.module.js?");

/***/ }),

/***/ "../../node_modules/vega-regression/build/vega-regression.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-regression/build/vega-regression.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   loess: () => (/* binding */ Loess),\n/* harmony export */   regression: () => (/* binding */ Regression)\n/* harmony export */ });\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\n\n\nfunction partition (data, groupby) {\n  var groups = [],\n    get = function (f) {\n      return f(t);\n    },\n    map,\n    i,\n    n,\n    t,\n    k,\n    g;\n\n  // partition data points into stack groups\n  if (groupby == null) {\n    groups.push(data);\n  } else {\n    for (map = {}, i = 0, n = data.length; i < n; ++i) {\n      t = data[i];\n      k = groupby.map(get);\n      g = map[k];\n      if (!g) {\n        map[k] = g = [];\n        g.dims = k;\n        groups.push(g);\n      }\n      g.push(t);\n    }\n  }\n  return groups;\n}\n\n/**\n * Compute locally-weighted regression fits for one or more data groups.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.x - An accessor for the predictor data field.\n * @param {function(object): *} params.y - An accessor for the predicted data field.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors to groupby.\n * @param {number} [params.bandwidth=0.3] - The loess bandwidth.\n */\nfunction Loess(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nLoess.Definition = {\n  'type': 'Loess',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'x',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'y',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'bandwidth',\n    'type': 'number',\n    'default': 0.3\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Loess, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n    if (!this.value || pulse.changed() || _.modified()) {\n      const source = pulse.materialize(pulse.SOURCE).source,\n        groups = partition(source, _.groupby),\n        names = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName),\n        m = names.length,\n        as = _.as || [(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName)(_.x), (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName)(_.y)],\n        values = [];\n      groups.forEach(g => {\n        (0,vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionLoess)(g, _.x, _.y, _.bandwidth || 0.3).forEach(p => {\n          const t = {};\n          for (let i = 0; i < m; ++i) {\n            t[names[i]] = g.dims[i];\n          }\n          t[as[0]] = p[0];\n          t[as[1]] = p[1];\n          values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n        });\n      });\n      if (this.value) out.rem = this.value;\n      this.value = out.add = out.source = values;\n    }\n    return out;\n  }\n});\n\nconst Methods = {\n  constant: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionConstant,\n  linear: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionLinear,\n  log: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionLog,\n  exp: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionExp,\n  pow: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionPow,\n  quad: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionQuad,\n  poly: vega_statistics__WEBPACK_IMPORTED_MODULE_0__.regressionPoly\n};\nconst degreesOfFreedom = (method, order) => method === 'poly' ? order : method === 'quad' ? 2 : 1;\n\n/**\n * Compute regression fits for one or more data groups.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.x - An accessor for the predictor data field.\n * @param {function(object): *} params.y - An accessor for the predicted data field.\n * @param {string} [params.method='linear'] - The regression method to apply.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors to groupby.\n * @param {Array<number>} [params.extent] - The domain extent over which to plot the regression line.\n * @param {number} [params.order=3] - The polynomial order. Only applies to the 'poly' method.\n */\nfunction Regression(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nRegression.Definition = {\n  'type': 'Regression',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'x',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'y',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'method',\n    'type': 'string',\n    'default': 'linear',\n    'values': Object.keys(Methods)\n  }, {\n    'name': 'order',\n    'type': 'number',\n    'default': 3\n  }, {\n    'name': 'extent',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'params',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Regression, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n    if (!this.value || pulse.changed() || _.modified()) {\n      const source = pulse.materialize(pulse.SOURCE).source,\n        groups = partition(source, _.groupby),\n        names = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName),\n        method = _.method || 'linear',\n        order = _.order == null ? 3 : _.order,\n        dof = degreesOfFreedom(method, order),\n        as = _.as || [(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName)(_.x), (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.accessorName)(_.y)],\n        fit = Methods[method],\n        values = [];\n      let domain = _.extent;\n      if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.hasOwnProperty)(Methods, method)) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('Invalid regression method: ' + method);\n      }\n      if (domain != null) {\n        if (method === 'log' && domain[0] <= 0) {\n          pulse.dataflow.warn('Ignoring extent with values <= 0 for log regression.');\n          domain = null;\n        }\n      }\n      groups.forEach(g => {\n        const n = g.length;\n        if (n <= dof) {\n          pulse.dataflow.warn('Skipping regression with more parameters than data points.');\n          return;\n        }\n        const model = fit(g, _.x, _.y, order);\n        if (_.params) {\n          // if parameter vectors requested return those\n          values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)({\n            keys: g.dims,\n            coef: model.coef,\n            rSquared: model.rSquared\n          }));\n          return;\n        }\n        const dom = domain || (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.extent)(g, _.x),\n          add = p => {\n            const t = {};\n            for (let i = 0; i < names.length; ++i) {\n              t[names[i]] = g.dims[i];\n            }\n            t[as[0]] = p[0];\n            t[as[1]] = p[1];\n            values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n          };\n        if (method === 'linear' || method === 'constant') {\n          // for linear or constant regression we only need the end points\n          dom.forEach(x => add([x, model.predict(x)]));\n        } else {\n          // otherwise return trend line sample points\n          (0,vega_statistics__WEBPACK_IMPORTED_MODULE_0__.sampleCurve)(model.predict, dom, 25, 200).forEach(add);\n        }\n      });\n      if (this.value) out.rem = this.value;\n      this.value = out.add = out.source = values;\n    }\n    return out;\n  }\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-regression/build/vega-regression.module.js?");

/***/ }),

/***/ "../../node_modules/vega-runtime/build/vega-runtime.module.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-runtime/build/vega-runtime.module.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   context: () => (/* binding */ context)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n\n\n\n/**\n * Parse a serialized dataflow specification.\n */\nfunction parse (spec) {\n  const ctx = this,\n    operators = spec.operators || [];\n\n  // parse background\n  if (spec.background) {\n    ctx.background = spec.background;\n  }\n\n  // parse event configuration\n  if (spec.eventConfig) {\n    ctx.eventConfig = spec.eventConfig;\n  }\n\n  // parse locale configuration\n  if (spec.locale) {\n    ctx.locale = spec.locale;\n  }\n\n  // parse operators\n  operators.forEach(entry => ctx.parseOperator(entry));\n\n  // parse operator parameters\n  operators.forEach(entry => ctx.parseOperatorParameters(entry));\n\n  // parse streams\n  (spec.streams || []).forEach(entry => ctx.parseStream(entry));\n\n  // parse updates\n  (spec.updates || []).forEach(entry => ctx.parseUpdate(entry));\n  return ctx.resolve();\n}\n\nconst Skip = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(['rule']),\n  Swap = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(['group', 'image', 'rect']);\nfunction adjustSpatial(encode, marktype) {\n  let code = '';\n  if (Skip[marktype]) return code;\n  if (encode.x2) {\n    if (encode.x) {\n      if (Swap[marktype]) {\n        code += 'if(o.x>o.x2)$=o.x,o.x=o.x2,o.x2=$;';\n      }\n      code += 'o.width=o.x2-o.x;';\n    } else {\n      code += 'o.x=o.x2-(o.width||0);';\n    }\n  }\n  if (encode.xc) {\n    code += 'o.x=o.xc-(o.width||0)/2;';\n  }\n  if (encode.y2) {\n    if (encode.y) {\n      if (Swap[marktype]) {\n        code += 'if(o.y>o.y2)$=o.y,o.y=o.y2,o.y2=$;';\n      }\n      code += 'o.height=o.y2-o.y;';\n    } else {\n      code += 'o.y=o.y2-(o.height||0);';\n    }\n  }\n  if (encode.yc) {\n    code += 'o.y=o.yc-(o.height||0)/2;';\n  }\n  return code;\n}\nfunction canonicalType(type) {\n  return (type + '').toLowerCase();\n}\nfunction isOperator(type) {\n  return canonicalType(type) === 'operator';\n}\nfunction isCollect(type) {\n  return canonicalType(type) === 'collect';\n}\n\nfunction expression(ctx, args, code) {\n  // wrap code in return statement if expression does not terminate\n  if (!code.endsWith(';')) {\n    code = 'return(' + code + ');';\n  }\n  const fn = Function(...args.concat(code));\n  return ctx && ctx.functions ? fn.bind(ctx.functions) : fn;\n}\n\n// generate code for comparing a single field\nfunction _compare(u, v, lt, gt) {\n  return `((u = ${u}) < (v = ${v}) || u == null) && v != null ? ${lt}\n  : (u > v || v == null) && u != null ? ${gt}\n  : ((v = v instanceof Date ? +v : v), (u = u instanceof Date ? +u : u)) !== u && v === v ? ${lt}\n  : v !== v && u === u ? ${gt} : `;\n}\nvar expressionCodegen = {\n  /**\n   * Parse an expression used to update an operator value.\n   */\n  operator: (ctx, expr) => expression(ctx, ['_'], expr.code),\n  /**\n   * Parse an expression provided as an operator parameter value.\n   */\n  parameter: (ctx, expr) => expression(ctx, ['datum', '_'], expr.code),\n  /**\n   * Parse an expression applied to an event stream.\n   */\n  event: (ctx, expr) => expression(ctx, ['event'], expr.code),\n  /**\n   * Parse an expression used to handle an event-driven operator update.\n   */\n  handler: (ctx, expr) => {\n    const code = `var datum=event.item&&event.item.datum;return ${expr.code};`;\n    return expression(ctx, ['_', 'event'], code);\n  },\n  /**\n   * Parse an expression that performs visual encoding.\n   */\n  encode: (ctx, encode) => {\n    const {\n      marktype,\n      channels\n    } = encode;\n    let code = 'var o=item,datum=o.datum,m=0,$;';\n    for (const name in channels) {\n      const o = 'o[' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name) + ']';\n      code += `$=${channels[name].code};if(${o}!==$)${o}=$,m=1;`;\n    }\n    code += adjustSpatial(channels, marktype);\n    code += 'return m;';\n    return expression(ctx, ['item', '_'], code);\n  },\n  /**\n   * Optimized code generators for access and comparison.\n   */\n  codegen: {\n    get(path) {\n      const ref = `[${path.map(vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue).join('][')}]`;\n      const get = Function('_', `return _${ref};`);\n      get.path = ref;\n      return get;\n    },\n    comparator(fields, orders) {\n      let t;\n      const map = (f, i) => {\n        const o = orders[i];\n        let u, v;\n        if (f.path) {\n          u = `a${f.path}`;\n          v = `b${f.path}`;\n        } else {\n          (t = t || {})['f' + i] = f;\n          u = `this.f${i}(a)`;\n          v = `this.f${i}(b)`;\n        }\n        return _compare(u, v, -o, o);\n      };\n      const fn = Function('a', 'b', 'var u, v; return ' + fields.map(map).join('') + '0;');\n      return t ? fn.bind(t) : fn;\n    }\n  }\n};\n\n/**\n * Parse a dataflow operator.\n */\nfunction parseOperator(spec) {\n  const ctx = this;\n  if (isOperator(spec.type) || !spec.type) {\n    ctx.operator(spec, spec.update ? ctx.operatorExpression(spec.update) : null);\n  } else {\n    ctx.transform(spec, spec.type);\n  }\n}\n\n/**\n * Parse and assign operator parameters.\n */\nfunction parseOperatorParameters(spec) {\n  const ctx = this;\n  if (spec.params) {\n    const op = ctx.get(spec.id);\n    if (!op) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid operator id: ' + spec.id);\n    ctx.dataflow.connect(op, op.parameters(ctx.parseParameters(spec.params), spec.react, spec.initonly));\n  }\n}\n\n/**\n * Parse a set of operator parameters.\n */\nfunction parseParameters(spec, params) {\n  params = params || {};\n  const ctx = this;\n  for (const key in spec) {\n    const value = spec[key];\n    params[key] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) ? value.map(v => parseParameter(v, ctx, params)) : parseParameter(value, ctx, params);\n  }\n  return params;\n}\n\n/**\n * Parse a single parameter.\n */\nfunction parseParameter(spec, ctx, params) {\n  if (!spec || !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(spec)) return spec;\n  for (let i = 0, n = PARSERS.length, p; i < n; ++i) {\n    p = PARSERS[i];\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(spec, p.key)) {\n      return p.parse(spec, ctx, params);\n    }\n  }\n  return spec;\n}\n\n/** Reference parsers. */\nvar PARSERS = [{\n  key: '$ref',\n  parse: getOperator\n}, {\n  key: '$key',\n  parse: getKey\n}, {\n  key: '$expr',\n  parse: getExpression\n}, {\n  key: '$field',\n  parse: getField\n}, {\n  key: '$encode',\n  parse: getEncode\n}, {\n  key: '$compare',\n  parse: getCompare\n}, {\n  key: '$context',\n  parse: getContext\n}, {\n  key: '$subflow',\n  parse: getSubflow\n}, {\n  key: '$tupleid',\n  parse: getTupleId\n}];\n\n/**\n * Resolve an operator reference.\n */\nfunction getOperator(_, ctx) {\n  return ctx.get(_.$ref) || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Operator not defined: ' + _.$ref);\n}\n\n/**\n * Resolve an expression reference.\n */\nfunction getExpression(_, ctx, params) {\n  if (_.$params) {\n    // parse expression parameters\n    ctx.parseParameters(_.$params, params);\n  }\n  const k = 'e:' + _.$expr.code;\n  return ctx.fn[k] || (ctx.fn[k] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor)(ctx.parameterExpression(_.$expr), _.$fields));\n}\n\n/**\n * Resolve a key accessor reference.\n */\nfunction getKey(_, ctx) {\n  const k = 'k:' + _.$key + '_' + !!_.$flat;\n  return ctx.fn[k] || (ctx.fn[k] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.key)(_.$key, _.$flat, ctx.expr.codegen));\n}\n\n/**\n * Resolve a field accessor reference.\n */\nfunction getField(_, ctx) {\n  if (!_.$field) return null;\n  const k = 'f:' + _.$field + '_' + _.$name;\n  return ctx.fn[k] || (ctx.fn[k] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(_.$field, _.$name, ctx.expr.codegen));\n}\n\n/**\n * Resolve a comparator function reference.\n */\nfunction getCompare(_, ctx) {\n  // As of Vega 5.5.3, $tupleid sort is no longer used.\n  // Keep here for now for backwards compatibility.\n  const k = 'c:' + _.$compare + '_' + _.$order,\n    c = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.$compare).map(_ => _ && _.$tupleid ? vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid : _);\n  return ctx.fn[k] || (ctx.fn[k] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.compare)(c, _.$order, ctx.expr.codegen));\n}\n\n/**\n * Resolve an encode operator reference.\n */\nfunction getEncode(_, ctx) {\n  const spec = _.$encode,\n    encode = {};\n  for (const name in spec) {\n    const enc = spec[name];\n    encode[name] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor)(ctx.encodeExpression(enc.$expr), enc.$fields);\n    encode[name].output = enc.$output;\n  }\n  return encode;\n}\n\n/**\n * Resolve a context reference.\n */\nfunction getContext(_, ctx) {\n  return ctx;\n}\n\n/**\n * Resolve a recursive subflow specification.\n */\nfunction getSubflow(_, ctx) {\n  const spec = _.$subflow;\n  return function (dataflow, key, parent) {\n    const subctx = ctx.fork().parse(spec),\n      op = subctx.get(spec.operators[0].id),\n      p = subctx.signals.parent;\n    if (p) p.set(parent);\n    op.detachSubflow = () => ctx.detach(subctx);\n    return op;\n  };\n}\n\n/**\n * Resolve a tuple id reference.\n */\nfunction getTupleId() {\n  return vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid;\n}\n\n/**\n * Parse an event stream specification.\n */\nfunction parseStream (spec) {\n  var ctx = this,\n    filter = spec.filter != null ? ctx.eventExpression(spec.filter) : undefined,\n    stream = spec.stream != null ? ctx.get(spec.stream) : undefined,\n    args;\n  if (spec.source) {\n    stream = ctx.events(spec.source, spec.type, filter);\n  } else if (spec.merge) {\n    args = spec.merge.map(_ => ctx.get(_));\n    stream = args[0].merge.apply(args[0], args.slice(1));\n  }\n  if (spec.between) {\n    args = spec.between.map(_ => ctx.get(_));\n    stream = stream.between(args[0], args[1]);\n  }\n  if (spec.filter) {\n    stream = stream.filter(filter);\n  }\n  if (spec.throttle != null) {\n    stream = stream.throttle(+spec.throttle);\n  }\n  if (spec.debounce != null) {\n    stream = stream.debounce(+spec.debounce);\n  }\n  if (stream == null) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid stream definition: ' + JSON.stringify(spec));\n  }\n  if (spec.consume) stream.consume(true);\n  ctx.stream(spec, stream);\n}\n\n/**\n * Parse an event-driven operator update.\n */\nfunction parseUpdate (spec) {\n  var ctx = this,\n    srcid = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(srcid = spec.source) ? srcid.$ref : srcid,\n    source = ctx.get(srcid),\n    target = null,\n    update = spec.update,\n    params = undefined;\n  if (!source) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Source not defined: ' + spec.source);\n  target = spec.target && spec.target.$expr ? ctx.eventExpression(spec.target.$expr) : ctx.get(spec.target);\n  if (update && update.$expr) {\n    if (update.$params) {\n      params = ctx.parseParameters(update.$params);\n    }\n    update = ctx.handlerExpression(update.$expr);\n  }\n  ctx.update(spec, source, target, update, params);\n}\n\nconst SKIP = {\n  skip: true\n};\nfunction getState(options) {\n  var ctx = this,\n    state = {};\n  if (options.signals) {\n    var signals = state.signals = {};\n    Object.keys(ctx.signals).forEach(key => {\n      const op = ctx.signals[key];\n      if (options.signals(key, op)) {\n        signals[key] = op.value;\n      }\n    });\n  }\n  if (options.data) {\n    var data = state.data = {};\n    Object.keys(ctx.data).forEach(key => {\n      const dataset = ctx.data[key];\n      if (options.data(key, dataset)) {\n        data[key] = dataset.input.value;\n      }\n    });\n  }\n  if (ctx.subcontext && options.recurse !== false) {\n    state.subcontext = ctx.subcontext.map(ctx => ctx.getState(options));\n  }\n  return state;\n}\nfunction setState(state) {\n  var ctx = this,\n    df = ctx.dataflow,\n    data = state.data,\n    signals = state.signals;\n  Object.keys(signals || {}).forEach(key => {\n    df.update(ctx.signals[key], signals[key], SKIP);\n  });\n  Object.keys(data || {}).forEach(key => {\n    df.pulse(ctx.data[key].input, df.changeset().remove(vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy).insert(data[key]));\n  });\n  (state.subcontext || []).forEach((substate, i) => {\n    const subctx = ctx.subcontext[i];\n    if (subctx) subctx.setState(substate);\n  });\n}\n\n/**\n * Context objects store the current parse state.\n * Enables lookup of parsed operators, event streams, accessors, etc.\n * Provides a 'fork' method for creating child contexts for subflows.\n */\nfunction context (df, transforms, functions, expr) {\n  return new Context(df, transforms, functions, expr);\n}\nfunction Context(df, transforms, functions, expr) {\n  this.dataflow = df;\n  this.transforms = transforms;\n  this.events = df.events.bind(df);\n  this.expr = expr || expressionCodegen, this.signals = {};\n  this.scales = {};\n  this.nodes = {};\n  this.data = {};\n  this.fn = {};\n  if (functions) {\n    this.functions = Object.create(functions);\n    this.functions.context = this;\n  }\n}\nfunction Subcontext(ctx) {\n  this.dataflow = ctx.dataflow;\n  this.transforms = ctx.transforms;\n  this.events = ctx.events;\n  this.expr = ctx.expr;\n  this.signals = Object.create(ctx.signals);\n  this.scales = Object.create(ctx.scales);\n  this.nodes = Object.create(ctx.nodes);\n  this.data = Object.create(ctx.data);\n  this.fn = Object.create(ctx.fn);\n  if (ctx.functions) {\n    this.functions = Object.create(ctx.functions);\n    this.functions.context = this;\n  }\n}\nContext.prototype = Subcontext.prototype = {\n  fork() {\n    const ctx = new Subcontext(this);\n    (this.subcontext || (this.subcontext = [])).push(ctx);\n    return ctx;\n  },\n  detach(ctx) {\n    this.subcontext = this.subcontext.filter(c => c !== ctx);\n\n    // disconnect all nodes in the subcontext\n    // wipe out targets first for better efficiency\n    const keys = Object.keys(ctx.nodes);\n    for (const key of keys) ctx.nodes[key]._targets = null;\n    for (const key of keys) ctx.nodes[key].detach();\n    ctx.nodes = null;\n  },\n  get(id) {\n    return this.nodes[id];\n  },\n  set(id, node) {\n    return this.nodes[id] = node;\n  },\n  add(spec, op) {\n    const ctx = this,\n      df = ctx.dataflow,\n      data = spec.value;\n    ctx.set(spec.id, op);\n    if (isCollect(spec.type) && data) {\n      if (data.$ingest) {\n        df.ingest(op, data.$ingest, data.$format);\n      } else if (data.$request) {\n        df.preload(op, data.$request, data.$format);\n      } else {\n        df.pulse(op, df.changeset().insert(data));\n      }\n    }\n    if (spec.root) {\n      ctx.root = op;\n    }\n    if (spec.parent) {\n      let p = ctx.get(spec.parent.$ref);\n      if (p) {\n        df.connect(p, [op]);\n        op.targets().add(p);\n      } else {\n        (ctx.unresolved = ctx.unresolved || []).push(() => {\n          p = ctx.get(spec.parent.$ref);\n          df.connect(p, [op]);\n          op.targets().add(p);\n        });\n      }\n    }\n    if (spec.signal) {\n      ctx.signals[spec.signal] = op;\n    }\n    if (spec.scale) {\n      ctx.scales[spec.scale] = op;\n    }\n    if (spec.data) {\n      for (const name in spec.data) {\n        const data = ctx.data[name] || (ctx.data[name] = {});\n        spec.data[name].forEach(role => data[role] = op);\n      }\n    }\n  },\n  resolve() {\n    (this.unresolved || []).forEach(fn => fn());\n    delete this.unresolved;\n    return this;\n  },\n  operator(spec, update) {\n    this.add(spec, this.dataflow.add(spec.value, update));\n  },\n  transform(spec, type) {\n    this.add(spec, this.dataflow.add(this.transforms[canonicalType(type)]));\n  },\n  stream(spec, stream) {\n    this.set(spec.id, stream);\n  },\n  update(spec, stream, target, update, params) {\n    this.dataflow.on(stream, target, update, params, spec.options);\n  },\n  // expression parsing\n  operatorExpression(expr) {\n    return this.expr.operator(this, expr);\n  },\n  parameterExpression(expr) {\n    return this.expr.parameter(this, expr);\n  },\n  eventExpression(expr) {\n    return this.expr.event(this, expr);\n  },\n  handlerExpression(expr) {\n    return this.expr.handler(this, expr);\n  },\n  encodeExpression(encode) {\n    return this.expr.encode(this, encode);\n  },\n  // parse methods\n  parse,\n  parseOperator,\n  parseOperatorParameters,\n  parseParameters,\n  parseStream,\n  parseUpdate,\n  // state methods\n  getState,\n  setState\n};\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-runtime/build/vega-runtime.module.js?");

/***/ }),

/***/ "../../node_modules/vega-scale/build/vega-scale.module.js":
/*!****************************************************************!*\
  !*** ../../node_modules/vega-scale/build/vega-scale.module.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Band: () => (/* binding */ Band),\n/* harmony export */   BinOrdinal: () => (/* binding */ BinOrdinal),\n/* harmony export */   DiscreteLegend: () => (/* binding */ DiscreteLegend),\n/* harmony export */   Diverging: () => (/* binding */ Diverging),\n/* harmony export */   GradientLegend: () => (/* binding */ GradientLegend),\n/* harmony export */   Identity: () => (/* binding */ Identity),\n/* harmony export */   Linear: () => (/* binding */ Linear),\n/* harmony export */   Log: () => (/* binding */ Log),\n/* harmony export */   Ordinal: () => (/* binding */ Ordinal),\n/* harmony export */   Point: () => (/* binding */ Point),\n/* harmony export */   Pow: () => (/* binding */ Pow),\n/* harmony export */   Quantile: () => (/* binding */ Quantile),\n/* harmony export */   Quantize: () => (/* binding */ Quantize),\n/* harmony export */   Sequential: () => (/* binding */ Sequential),\n/* harmony export */   Sqrt: () => (/* binding */ Sqrt),\n/* harmony export */   SymbolLegend: () => (/* binding */ SymbolLegend),\n/* harmony export */   Symlog: () => (/* binding */ Symlog),\n/* harmony export */   Threshold: () => (/* binding */ Threshold),\n/* harmony export */   Time: () => (/* binding */ Time),\n/* harmony export */   UTC: () => (/* binding */ UTC),\n/* harmony export */   bandSpace: () => (/* binding */ bandSpace),\n/* harmony export */   domainCaption: () => (/* binding */ domainCaption),\n/* harmony export */   interpolate: () => (/* binding */ interpolate),\n/* harmony export */   interpolateColors: () => (/* binding */ interpolateColors),\n/* harmony export */   interpolateRange: () => (/* binding */ interpolateRange),\n/* harmony export */   isContinuous: () => (/* binding */ isContinuous),\n/* harmony export */   isDiscrete: () => (/* binding */ isDiscrete),\n/* harmony export */   isDiscretizing: () => (/* binding */ isDiscretizing),\n/* harmony export */   isInterpolating: () => (/* binding */ isInterpolating),\n/* harmony export */   isLogarithmic: () => (/* binding */ isLogarithmic),\n/* harmony export */   isQuantile: () => (/* binding */ isQuantile),\n/* harmony export */   isRegisteredScale: () => (/* binding */ isRegisteredScale),\n/* harmony export */   isTemporal: () => (/* binding */ isTemporal),\n/* harmony export */   isValidScaleType: () => (/* binding */ isValidScaleType),\n/* harmony export */   labelFormat: () => (/* binding */ labelFormat),\n/* harmony export */   labelFraction: () => (/* binding */ labelFraction),\n/* harmony export */   labelValues: () => (/* binding */ labelValues),\n/* harmony export */   quantizeInterpolator: () => (/* binding */ quantizeInterpolator),\n/* harmony export */   registerScale: () => (/* binding */ registerScale),\n/* harmony export */   scale: () => (/* binding */ scale),\n/* harmony export */   scaleCopy: () => (/* binding */ scaleCopy),\n/* harmony export */   scaleFraction: () => (/* binding */ scaleFraction),\n/* harmony export */   scaleImplicit: () => (/* reexport safe */ d3_scale__WEBPACK_IMPORTED_MODULE_1__.implicit),\n/* harmony export */   scheme: () => (/* binding */ scheme),\n/* harmony export */   tickCount: () => (/* binding */ tickCount),\n/* harmony export */   tickFormat: () => (/* binding */ tickFormat),\n/* harmony export */   tickValues: () => (/* binding */ tickValues),\n/* harmony export */   validTicks: () => (/* binding */ validTicks)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/identity.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/log.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/pow.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/symlog.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/time.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/utcTime.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/sequential.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/diverging.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/quantile.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/quantize.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/threshold.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/ordinal.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-scale */ \"../../node_modules/d3-scale/src/tickFormat.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/piecewise.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/index.js\");\n/* harmony import */ var vega_time__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-time */ \"../../node_modules/vega-time/build/vega-time.module.js\");\n\n\n\n\n\n\n\n\nfunction bandSpace (count, paddingInner, paddingOuter) {\n  const space = count - paddingInner + paddingOuter * 2;\n  return count ? space > 0 ? space : 1 : 0;\n}\n\nconst Identity = 'identity';\nconst Linear = 'linear';\nconst Log = 'log';\nconst Pow = 'pow';\nconst Sqrt = 'sqrt';\nconst Symlog = 'symlog';\nconst Time = 'time';\nconst UTC = 'utc';\nconst Sequential = 'sequential';\nconst Diverging = 'diverging';\nconst Quantile = 'quantile';\nconst Quantize = 'quantize';\nconst Threshold = 'threshold';\nconst Ordinal = 'ordinal';\nconst Point = 'point';\nconst Band = 'band';\nconst BinOrdinal = 'bin-ordinal';\n\n// categories\nconst Continuous = 'continuous';\nconst Discrete = 'discrete';\nconst Discretizing = 'discretizing';\nconst Interpolating = 'interpolating';\nconst Temporal = 'temporal';\n\nfunction invertRange (scale) {\n  return function (_) {\n    let lo = _[0],\n      hi = _[1],\n      t;\n    if (hi < lo) {\n      t = lo;\n      lo = hi;\n      hi = t;\n    }\n    return [scale.invert(lo), scale.invert(hi)];\n  };\n}\n\nfunction invertRangeExtent (scale) {\n  return function (_) {\n    const range = scale.range();\n    let lo = _[0],\n      hi = _[1],\n      min = -1,\n      max,\n      t,\n      i,\n      n;\n    if (hi < lo) {\n      t = lo;\n      lo = hi;\n      hi = t;\n    }\n    for (i = 0, n = range.length; i < n; ++i) {\n      if (range[i] >= lo && range[i] <= hi) {\n        if (min < 0) min = i;\n        max = i;\n      }\n    }\n    if (min < 0) return undefined;\n    lo = scale.invertExtent(range[min]);\n    hi = scale.invertExtent(range[max]);\n    return [lo[0] === undefined ? lo[1] : lo[0], hi[1] === undefined ? hi[0] : hi[1]];\n  };\n}\n\nfunction band() {\n  const scale = (0,d3_scale__WEBPACK_IMPORTED_MODULE_1__[\"default\"])().unknown(undefined),\n    domain = scale.domain,\n    ordinalRange = scale.range;\n  let range$1 = [0, 1],\n    step,\n    bandwidth,\n    round = false,\n    paddingInner = 0,\n    paddingOuter = 0,\n    align = 0.5;\n  delete scale.unknown;\n  function rescale() {\n    const n = domain().length,\n      reverse = range$1[1] < range$1[0],\n      stop = range$1[1 - reverse],\n      space = bandSpace(n, paddingInner, paddingOuter);\n    let start = range$1[reverse - 0];\n    step = (stop - start) / (space || 1);\n    if (round) {\n      step = Math.floor(step);\n    }\n    start += (stop - start - step * (n - paddingInner)) * align;\n    bandwidth = step * (1 - paddingInner);\n    if (round) {\n      start = Math.round(start);\n      bandwidth = Math.round(bandwidth);\n    }\n    const values = (0,d3_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(n).map(i => start + step * i);\n    return ordinalRange(reverse ? values.reverse() : values);\n  }\n  scale.domain = function (_) {\n    if (arguments.length) {\n      domain(_);\n      return rescale();\n    } else {\n      return domain();\n    }\n  };\n  scale.range = function (_) {\n    if (arguments.length) {\n      range$1 = [+_[0], +_[1]];\n      return rescale();\n    } else {\n      return range$1.slice();\n    }\n  };\n  scale.rangeRound = function (_) {\n    range$1 = [+_[0], +_[1]];\n    round = true;\n    return rescale();\n  };\n  scale.bandwidth = function () {\n    return bandwidth;\n  };\n  scale.step = function () {\n    return step;\n  };\n  scale.round = function (_) {\n    if (arguments.length) {\n      round = !!_;\n      return rescale();\n    } else {\n      return round;\n    }\n  };\n  scale.padding = function (_) {\n    if (arguments.length) {\n      paddingOuter = Math.max(0, Math.min(1, _));\n      paddingInner = paddingOuter;\n      return rescale();\n    } else {\n      return paddingInner;\n    }\n  };\n  scale.paddingInner = function (_) {\n    if (arguments.length) {\n      paddingInner = Math.max(0, Math.min(1, _));\n      return rescale();\n    } else {\n      return paddingInner;\n    }\n  };\n  scale.paddingOuter = function (_) {\n    if (arguments.length) {\n      paddingOuter = Math.max(0, Math.min(1, _));\n      return rescale();\n    } else {\n      return paddingOuter;\n    }\n  };\n  scale.align = function (_) {\n    if (arguments.length) {\n      align = Math.max(0, Math.min(1, _));\n      return rescale();\n    } else {\n      return align;\n    }\n  };\n  scale.invertRange = function (_) {\n    // bail if range has null or undefined values\n    if (_[0] == null || _[1] == null) return;\n    const reverse = range$1[1] < range$1[0],\n      values = reverse ? ordinalRange().reverse() : ordinalRange(),\n      n = values.length - 1;\n    let lo = +_[0],\n      hi = +_[1],\n      a,\n      b,\n      t;\n\n    // bail if either range endpoint is invalid\n    if (lo !== lo || hi !== hi) return;\n\n    // order range inputs, bail if outside of scale range\n    if (hi < lo) {\n      t = lo;\n      lo = hi;\n      hi = t;\n    }\n    if (hi < values[0] || lo > range$1[1 - reverse]) return;\n\n    // binary search to index into scale range\n    a = Math.max(0, (0,d3_array__WEBPACK_IMPORTED_MODULE_4__.bisectRight)(values, lo) - 1);\n    b = lo === hi ? a : (0,d3_array__WEBPACK_IMPORTED_MODULE_4__.bisectRight)(values, hi) - 1;\n\n    // increment index a if lo is within padding gap\n    if (lo - values[a] > bandwidth + 1e-10) ++a;\n    if (reverse) {\n      // map + swap\n      t = a;\n      a = n - b;\n      b = n - t;\n    }\n    return a > b ? undefined : domain().slice(a, b + 1);\n  };\n  scale.invert = function (_) {\n    const value = scale.invertRange([_, _]);\n    return value ? value[0] : value;\n  };\n  scale.copy = function () {\n    return band().domain(domain()).range(range$1).round(round).paddingInner(paddingInner).paddingOuter(paddingOuter).align(align);\n  };\n  return rescale();\n}\nfunction pointish(scale) {\n  const copy = scale.copy;\n  scale.padding = scale.paddingOuter;\n  delete scale.paddingInner;\n  scale.copy = function () {\n    return pointish(copy());\n  };\n  return scale;\n}\nfunction point() {\n  return pointish(band().paddingInner(1));\n}\n\nvar map = Array.prototype.map;\nfunction numbers(_) {\n  return map.call(_, vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber);\n}\n\nconst slice = Array.prototype.slice;\n\nfunction scaleBinOrdinal() {\n  let domain = [],\n    range = [];\n  function scale(x) {\n    return x == null || x !== x ? undefined : range[((0,d3_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(domain, x) - 1) % range.length];\n  }\n  scale.domain = function (_) {\n    if (arguments.length) {\n      domain = numbers(_);\n      return scale;\n    } else {\n      return domain.slice();\n    }\n  };\n  scale.range = function (_) {\n    if (arguments.length) {\n      range = slice.call(_);\n      return scale;\n    } else {\n      return range.slice();\n    }\n  };\n  scale.tickFormat = function (count, specifier) {\n    return (0,d3_scale__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(domain[0], (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(domain), count == null ? 10 : count, specifier);\n  };\n  scale.copy = function () {\n    return scaleBinOrdinal().domain(scale.domain()).range(scale.range());\n  };\n  return scale;\n}\n\n/** Private scale registry: should not be exported */\nconst scales = new Map();\nconst VEGA_SCALE = Symbol('vega_scale');\nfunction registerScale(scale) {\n  scale[VEGA_SCALE] = true;\n  return scale;\n}\n\n/**\n * Return true if object was created by a constructor from the vega-scale `scale` function.\n */\nfunction isRegisteredScale(scale) {\n  return scale && scale[VEGA_SCALE] === true;\n}\n\n/**\n * Augment scales with their type and needed inverse methods.\n */\nfunction create(type, constructor, metadata) {\n  const ctr = function scale() {\n    const s = constructor();\n    if (!s.invertRange) {\n      s.invertRange = s.invert ? invertRange(s) : s.invertExtent ? invertRangeExtent(s) : undefined;\n    }\n    s.type = type;\n    return registerScale(s);\n  };\n  ctr.metadata = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(metadata));\n  return ctr;\n}\n\n/**\n * Registry function for adding and accessing scale constructor functions.\n * The *type* argument is a String indicating the name of the scale type.\n *\n * If the *scale* argument is not specified, this method returns the matching scale constructor in the registry, or `null` if not found.\n * If the *scale* argument is provided, it must be a scale constructor function to add to the registry under the given *type* name.\n * The *metadata* argument provides additional information to guide appropriate use of scales within Vega.\n *\n *  *metadata* can be either a string or string array. The valid string values are:\n * - `\"continuous\"` - the scale is defined over a continuous-valued domain.\n * - `\"discrete\"` - the scale is defined over a discrete domain and range.\n * - `\"discretizing\"` - the scale discretizes a continuous domain to a discrete range.\n * - `\"interpolating\"` - the scale range is defined using a color interpolator.\n * - `\"log\"` - the scale performs a logarithmic transform of the continuous domain.\n * - `\"temporal\"` - the scale domain is defined over date-time values.\n */\nfunction scale(type, scale, metadata) {\n  if (arguments.length > 1) {\n    scales.set(type, create(type, scale, metadata));\n    return this;\n  } else {\n    return isValidScaleType(type) ? scales.get(type) : undefined;\n  }\n}\n\n// identity scale\nscale(Identity, d3_scale__WEBPACK_IMPORTED_MODULE_6__[\"default\"]);\n\n// continuous scales\nscale(Linear, d3_scale__WEBPACK_IMPORTED_MODULE_7__[\"default\"], Continuous);\nscale(Log, d3_scale__WEBPACK_IMPORTED_MODULE_8__[\"default\"], [Continuous, Log]);\nscale(Pow, d3_scale__WEBPACK_IMPORTED_MODULE_9__[\"default\"], Continuous);\nscale(Sqrt, d3_scale__WEBPACK_IMPORTED_MODULE_9__.sqrt, Continuous);\nscale(Symlog, d3_scale__WEBPACK_IMPORTED_MODULE_10__[\"default\"], Continuous);\nscale(Time, d3_scale__WEBPACK_IMPORTED_MODULE_11__[\"default\"], [Continuous, Temporal]);\nscale(UTC, d3_scale__WEBPACK_IMPORTED_MODULE_12__[\"default\"], [Continuous, Temporal]);\n\n// sequential scales\nscale(Sequential, d3_scale__WEBPACK_IMPORTED_MODULE_13__[\"default\"], [Continuous, Interpolating]); // backwards compat\nscale(`${Sequential}-${Linear}`, d3_scale__WEBPACK_IMPORTED_MODULE_13__[\"default\"], [Continuous, Interpolating]);\nscale(`${Sequential}-${Log}`, d3_scale__WEBPACK_IMPORTED_MODULE_13__.sequentialLog, [Continuous, Interpolating, Log]);\nscale(`${Sequential}-${Pow}`, d3_scale__WEBPACK_IMPORTED_MODULE_13__.sequentialPow, [Continuous, Interpolating]);\nscale(`${Sequential}-${Sqrt}`, d3_scale__WEBPACK_IMPORTED_MODULE_13__.sequentialSqrt, [Continuous, Interpolating]);\nscale(`${Sequential}-${Symlog}`, d3_scale__WEBPACK_IMPORTED_MODULE_13__.sequentialSymlog, [Continuous, Interpolating]);\n\n// diverging scales\nscale(`${Diverging}-${Linear}`, d3_scale__WEBPACK_IMPORTED_MODULE_14__[\"default\"], [Continuous, Interpolating]);\nscale(`${Diverging}-${Log}`, d3_scale__WEBPACK_IMPORTED_MODULE_14__.divergingLog, [Continuous, Interpolating, Log]);\nscale(`${Diverging}-${Pow}`, d3_scale__WEBPACK_IMPORTED_MODULE_14__.divergingPow, [Continuous, Interpolating]);\nscale(`${Diverging}-${Sqrt}`, d3_scale__WEBPACK_IMPORTED_MODULE_14__.divergingSqrt, [Continuous, Interpolating]);\nscale(`${Diverging}-${Symlog}`, d3_scale__WEBPACK_IMPORTED_MODULE_14__.divergingSymlog, [Continuous, Interpolating]);\n\n// discretizing scales\nscale(Quantile, d3_scale__WEBPACK_IMPORTED_MODULE_15__[\"default\"], [Discretizing, Quantile]);\nscale(Quantize, d3_scale__WEBPACK_IMPORTED_MODULE_16__[\"default\"], Discretizing);\nscale(Threshold, d3_scale__WEBPACK_IMPORTED_MODULE_17__[\"default\"], Discretizing);\n\n// discrete scales\nscale(BinOrdinal, scaleBinOrdinal, [Discrete, Discretizing]);\nscale(Ordinal, d3_scale__WEBPACK_IMPORTED_MODULE_1__[\"default\"], Discrete);\nscale(Band, band, Discrete);\nscale(Point, point, Discrete);\nfunction isValidScaleType(type) {\n  return scales.has(type);\n}\nfunction hasType(key, type) {\n  const s = scales.get(key);\n  return s && s.metadata[type];\n}\nfunction isContinuous(key) {\n  return hasType(key, Continuous);\n}\nfunction isDiscrete(key) {\n  return hasType(key, Discrete);\n}\nfunction isDiscretizing(key) {\n  return hasType(key, Discretizing);\n}\nfunction isLogarithmic(key) {\n  return hasType(key, Log);\n}\nfunction isTemporal(key) {\n  return hasType(key, Temporal);\n}\nfunction isInterpolating(key) {\n  return hasType(key, Interpolating);\n}\nfunction isQuantile(key) {\n  return hasType(key, Quantile);\n}\n\nconst scaleProps = ['clamp', 'base', 'constant', 'exponent'];\nfunction interpolateRange(interpolator, range) {\n  const start = range[0],\n    span = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(range) - start;\n  return function (i) {\n    return interpolator(start + i * span);\n  };\n}\nfunction interpolateColors(colors, type, gamma) {\n  return d3_interpolate__WEBPACK_IMPORTED_MODULE_18__[\"default\"](interpolate(type || 'rgb', gamma), colors);\n}\nfunction quantizeInterpolator(interpolator, count) {\n  const samples = new Array(count),\n    n = count + 1;\n  for (let i = 0; i < count;) samples[i] = interpolator(++i / n);\n  return samples;\n}\nfunction scaleCopy(scale) {\n  const t = scale.type,\n    s = scale.copy();\n  s.type = t;\n  return s;\n}\nfunction scaleFraction(scale$1, min, max) {\n  const delta = max - min;\n  let i, t, s;\n  if (!delta || !Number.isFinite(delta)) {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(0.5);\n  } else {\n    i = (t = scale$1.type).indexOf('-');\n    t = i < 0 ? t : t.slice(i + 1);\n    s = scale(t)().domain([min, max]).range([0, 1]);\n    scaleProps.forEach(m => scale$1[m] ? s[m](scale$1[m]()) : 0);\n    return s;\n  }\n}\nfunction interpolate(type, gamma) {\n  const interp = d3_interpolate__WEBPACK_IMPORTED_MODULE_19__[method(type)];\n  return gamma != null && interp && interp.gamma ? interp.gamma(gamma) : interp;\n}\nfunction method(type) {\n  return 'interpolate' + type.toLowerCase().split('-').map(s => s[0].toUpperCase() + s.slice(1)).join('');\n}\n\nconst continuous = {\n  blues: 'cfe1f2bed8eca8cee58fc1de74b2d75ba3cf4592c63181bd206fb2125ca40a4a90',\n  greens: 'd3eecdc0e6baabdda594d3917bc77d60ba6c46ab5e329a512089430e7735036429',\n  greys: 'e2e2e2d4d4d4c4c4c4b1b1b19d9d9d8888887575756262624d4d4d3535351e1e1e',\n  oranges: 'fdd8b3fdc998fdb87bfda55efc9244f87f2cf06b18e4580bd14904b93d029f3303',\n  purples: 'e2e1efd4d4e8c4c5e0b4b3d6a3a0cc928ec3827cb97566ae684ea25c3696501f8c',\n  reds: 'fdc9b4fcb49afc9e80fc8767fa7051f6573fec3f2fdc2a25c81b1db21218970b13',\n  blueGreen: 'd5efedc1e8e0a7ddd18bd2be70c6a958ba9144ad77319c5d2089460e7736036429',\n  bluePurple: 'ccddecbad0e4a8c2dd9ab0d4919cc98d85be8b6db28a55a6873c99822287730f71',\n  greenBlue: 'd3eecec5e8c3b1e1bb9bd8bb82cec269c2ca51b2cd3c9fc7288abd1675b10b60a1',\n  orangeRed: 'fddcaffdcf9bfdc18afdad77fb9562f67d53ee6545e24932d32d1ebf130da70403',\n  purpleBlue: 'dbdaebc8cee4b1c3de97b7d87bacd15b9fc93a90c01e7fb70b70ab056199045281',\n  purpleBlueGreen: 'dbd8eac8cee4b0c3de93b7d872acd1549fc83892bb1c88a3097f8702736b016353',\n  purpleRed: 'dcc9e2d3b3d7ce9eccd186c0da6bb2e14da0e23189d91e6fc61159ab07498f023a',\n  redPurple: 'fccfccfcbec0faa9b8f98faff571a5ec539ddb3695c41b8aa908808d0179700174',\n  yellowGreen: 'e4f4acd1eca0b9e2949ed68880c97c62bb6e47aa5e3297502083440e723b036034',\n  yellowOrangeBrown: 'feeaa1fedd84fecc63feb746fca031f68921eb7215db5e0bc54c05ab3d038f3204',\n  yellowOrangeRed: 'fee087fed16ffebd59fea849fd903efc7335f9522bee3423de1b20ca0b22af0225',\n  blueOrange: '134b852f78b35da2cb9dcae1d2e5eff2f0ebfce0bafbbf74e8932fc5690d994a07',\n  brownBlueGreen: '704108a0651ac79548e3c78af3e6c6eef1eac9e9e48ed1c74da79e187a72025147',\n  purpleGreen: '5b1667834792a67fb6c9aed3e6d6e8eff0efd9efd5aedda971bb75368e490e5e29',\n  purpleOrange: '4114696647968f83b7b9b4d6dadbebf3eeeafce0bafbbf74e8932fc5690d994a07',\n  redBlue: '8c0d25bf363adf745ef4ae91fbdbc9f2efeed2e5ef9dcae15da2cb2f78b3134b85',\n  redGrey: '8c0d25bf363adf745ef4ae91fcdccbfaf4f1e2e2e2c0c0c0969696646464343434',\n  yellowGreenBlue: 'eff9bddbf1b4bde5b594d5b969c5be45b4c22c9ec02182b82163aa23479c1c3185',\n  redYellowBlue: 'a50026d4322cf16e43fcac64fedd90faf8c1dcf1ecabd6e875abd04a74b4313695',\n  redYellowGreen: 'a50026d4322cf16e43fcac63fedd8df9f7aed7ee8ea4d86e64bc6122964f006837',\n  pinkYellowGreen: '8e0152c0267edd72adf0b3d6faddedf5f3efe1f2cab6de8780bb474f9125276419',\n  spectral: '9e0142d13c4bf0704afcac63fedd8dfbf8b0e0f3a1a9dda269bda94288b55e4fa2',\n  viridis: '440154470e61481a6c482575472f7d443a834144873d4e8a39568c35608d31688e2d708e2a788e27818e23888e21918d1f988b1fa08822a8842ab07f35b77943bf7154c56866cc5d7ad1518fd744a5db36bcdf27d2e21be9e51afde725',\n  magma: '0000040404130b0924150e3720114b2c11603b0f704a107957157e651a80721f817f24828c29819a2e80a8327db6377ac43c75d1426fde4968e95462f1605df76f5cfa7f5efc8f65fe9f6dfeaf78febf84fece91fddea0fcedaffcfdbf',\n  inferno: '0000040403130c0826170c3b240c4f330a5f420a68500d6c5d126e6b176e781c6d86216b932667a12b62ae305cbb3755c73e4cd24644dd513ae65c30ed6925f3771af8850ffb9506fca50afcb519fac62df6d645f2e661f3f484fcffa4',\n  plasma: '0d088723069033059742039d5002a25d01a66a00a87801a88405a7900da49c179ea72198b12a90ba3488c33d80cb4779d35171da5a69e16462e76e5bed7953f2834cf68f44fa9a3dfca636fdb32ffec029fcce25f9dc24f5ea27f0f921',\n  cividis: '00205100235800265d002961012b65042e670831690d346b11366c16396d1c3c6e213f6e26426e2c456e31476e374a6e3c4d6e42506e47536d4c566d51586e555b6e5a5e6e5e616e62646f66676f6a6a706e6d717270717573727976737c79747f7c75827f758682768985778c8877908b78938e789691789a94789e9778a19b78a59e77a9a177aea575b2a874b6ab73bbaf71c0b26fc5b66dc9b96acebd68d3c065d8c462ddc85fe2cb5ce7cf58ebd355f0d652f3da4ff7de4cfae249fce647',\n  rainbow: '6e40aa883eb1a43db3bf3cafd83fa4ee4395fe4b83ff576eff6659ff7847ff8c38f3a130e2b72fcfcc36bee044aff05b8ff4576ff65b52f6673af27828ea8d1ddfa319d0b81cbecb23abd82f96e03d82e14c6edb5a5dd0664dbf6e40aa',\n  sinebow: 'ff4040fc582af47218e78d0bd5a703bfbf00a7d5038de70b72f41858fc2a40ff402afc5818f4720be78d03d5a700bfbf03a7d50b8de71872f42a58fc4040ff582afc7218f48d0be7a703d5bf00bfd503a7e70b8df41872fc2a58ff4040',\n  turbo: '23171b32204a3e2a71453493493eae4b49c54a53d7485ee44569ee4074f53c7ff8378af93295f72e9ff42ba9ef28b3e926bce125c5d925cdcf27d5c629dcbc2de3b232e9a738ee9d3ff39347f68950f9805afc7765fd6e70fe667cfd5e88fc5795fb51a1f84badf545b9f140c5ec3cd0e637dae034e4d931ecd12ef4c92bfac029ffb626ffad24ffa223ff9821ff8d1fff821dff771cfd6c1af76118f05616e84b14df4111d5380fcb2f0dc0260ab61f07ac1805a313029b0f00950c00910b00',\n  browns: 'eedbbdecca96e9b97ae4a865dc9856d18954c7784cc0673fb85536ad44339f3632',\n  tealBlues: 'bce4d89dd3d181c3cb65b3c245a2b9368fae347da0306a932c5985',\n  teals: 'bbdfdfa2d4d58ac9c975bcbb61b0af4da5a43799982b8b8c1e7f7f127273006667',\n  warmGreys: 'dcd4d0cec5c1c0b8b4b3aaa7a59c9998908c8b827f7e7673726866665c5a59504e',\n  goldGreen: 'f4d166d5ca60b6c35c98bb597cb25760a6564b9c533f8f4f33834a257740146c36',\n  goldOrange: 'f4d166f8be5cf8aa4cf5983bf3852aef701be2621fd65322c54923b142239e3a26',\n  goldRed: 'f4d166f6be59f9aa51fc964ef6834bee734ae56249db5247cf4244c43141b71d3e',\n  lightGreyRed: 'efe9e6e1dad7d5cbc8c8bdb9bbaea9cd967ddc7b43e15f19df4011dc000b',\n  lightGreyTeal: 'e4eaead6dcddc8ced2b7c2c7a6b4bc64b0bf22a6c32295c11f85be1876bc',\n  lightMulti: 'e0f1f2c4e9d0b0de9fd0e181f6e072f6c053f3993ef77440ef4a3c',\n  lightOrange: 'f2e7daf7d5baf9c499fab184fa9c73f68967ef7860e8645bde515bd43d5b',\n  lightTealBlue: 'e3e9e0c0dccf9aceca7abfc859afc0389fb9328dad2f7ca0276b95255988',\n  darkBlue: '3232322d46681a5c930074af008cbf05a7ce25c0dd38daed50f3faffffff',\n  darkGold: '3c3c3c584b37725e348c7631ae8b2bcfa424ecc31ef9de30fff184ffffff',\n  darkGreen: '3a3a3a215748006f4d048942489e4276b340a6c63dd2d836ffeb2cffffaa',\n  darkMulti: '3737371f5287197d8c29a86995ce3fffe800ffffff',\n  darkRed: '3434347036339e3c38cc4037e75d1eec8620eeab29f0ce32ffeb2c'\n};\nconst discrete = {\n  category10: '1f77b4ff7f0e2ca02cd627289467bd8c564be377c27f7f7fbcbd2217becf',\n  category20: '1f77b4aec7e8ff7f0effbb782ca02c98df8ad62728ff98969467bdc5b0d58c564bc49c94e377c2f7b6d27f7f7fc7c7c7bcbd22dbdb8d17becf9edae5',\n  category20b: '393b795254a36b6ecf9c9ede6379398ca252b5cf6bcedb9c8c6d31bd9e39e7ba52e7cb94843c39ad494ad6616be7969c7b4173a55194ce6dbdde9ed6',\n  category20c: '3182bd6baed69ecae1c6dbefe6550dfd8d3cfdae6bfdd0a231a35474c476a1d99bc7e9c0756bb19e9ac8bcbddcdadaeb636363969696bdbdbdd9d9d9',\n  tableau10: '4c78a8f58518e4575672b7b254a24beeca3bb279a2ff9da69d755dbab0ac',\n  tableau20: '4c78a89ecae9f58518ffbf7954a24b88d27ab79a20f2cf5b43989483bcb6e45756ff9d9879706ebab0acd67195fcbfd2b279a2d6a5c99e765fd8b5a5',\n  accent: '7fc97fbeaed4fdc086ffff99386cb0f0027fbf5b17666666',\n  dark2: '1b9e77d95f027570b3e7298a66a61ee6ab02a6761d666666',\n  paired: 'a6cee31f78b4b2df8a33a02cfb9a99e31a1cfdbf6fff7f00cab2d66a3d9affff99b15928',\n  pastel1: 'fbb4aeb3cde3ccebc5decbe4fed9a6ffffcce5d8bdfddaecf2f2f2',\n  pastel2: 'b3e2cdfdcdaccbd5e8f4cae4e6f5c9fff2aef1e2cccccccc',\n  set1: 'e41a1c377eb84daf4a984ea3ff7f00ffff33a65628f781bf999999',\n  set2: '66c2a5fc8d628da0cbe78ac3a6d854ffd92fe5c494b3b3b3',\n  set3: '8dd3c7ffffb3bebadafb807280b1d3fdb462b3de69fccde5d9d9d9bc80bdccebc5ffed6f'\n};\n\nfunction colors(palette) {\n  const n = palette.length / 6 | 0,\n    c = new Array(n);\n  for (let i = 0; i < n;) {\n    c[i] = '#' + palette.slice(i * 6, ++i * 6);\n  }\n  return c;\n}\nfunction apply(_, f) {\n  for (const k in _) scheme(k, f(_[k]));\n}\nconst schemes = {};\napply(discrete, colors);\napply(continuous, _ => interpolateColors(colors(_)));\nfunction scheme(name, scheme) {\n  name = name && name.toLowerCase();\n  if (arguments.length > 1) {\n    schemes[name] = scheme;\n    return this;\n  } else {\n    return schemes[name];\n  }\n}\n\nconst SymbolLegend = 'symbol';\nconst DiscreteLegend = 'discrete';\nconst GradientLegend = 'gradient';\n\nconst defaultFormatter = value => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) ? value.map(v => String(v)) : String(value);\nconst ascending = (a, b) => a[1] - b[1];\nconst descending = (a, b) => b[1] - a[1];\n\n/**\n * Determine the tick count or interval function.\n * @param {Scale} scale - The scale for which to generate tick values.\n * @param {*} count - The desired tick count or interval specifier.\n * @param {number} minStep - The desired minimum step between tick values.\n * @return {*} - The tick count or interval function.\n */\nfunction tickCount(scale, count, minStep) {\n  let step;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(count)) {\n    if (scale.bins) {\n      count = Math.max(count, scale.bins.length);\n    }\n    if (minStep != null) {\n      count = Math.min(count, Math.floor((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.span)(scale.domain()) / minStep || 1));\n    }\n  }\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(count)) {\n    step = count.step;\n    count = count.interval;\n  }\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(count)) {\n    count = scale.type === Time ? (0,vega_time__WEBPACK_IMPORTED_MODULE_2__.timeInterval)(count) : scale.type == UTC ? (0,vega_time__WEBPACK_IMPORTED_MODULE_2__.utcInterval)(count) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Only time and utc scales accept interval strings.');\n    if (step) count = count.every(step);\n  }\n  return count;\n}\n\n/**\n * Filter a set of candidate tick values, ensuring that only tick values\n * that lie within the scale range are included.\n * @param {Scale} scale - The scale for which to generate tick values.\n * @param {Array<*>} ticks - The candidate tick values.\n * @param {*} count - The tick count or interval function.\n * @return {Array<*>} - The filtered tick values.\n */\nfunction validTicks(scale, ticks, count) {\n  let range = scale.range(),\n    lo = range[0],\n    hi = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(range),\n    cmp = ascending;\n  if (lo > hi) {\n    range = hi;\n    hi = lo;\n    lo = range;\n    cmp = descending;\n  }\n  lo = Math.floor(lo);\n  hi = Math.ceil(hi);\n\n  // filter ticks to valid values within the range\n  // additionally sort ticks in range order (#2579)\n  ticks = ticks.map(v => [v, scale(v)]).filter(_ => lo <= _[1] && _[1] <= hi).sort(cmp).map(_ => _[0]);\n  if (count > 0 && ticks.length > 1) {\n    const endpoints = [ticks[0], (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(ticks)];\n    while (ticks.length > count && ticks.length >= 3) {\n      ticks = ticks.filter((_, i) => !(i % 2));\n    }\n    if (ticks.length < 3) {\n      ticks = endpoints;\n    }\n  }\n  return ticks;\n}\n\n/**\n * Generate tick values for the given scale and approximate tick count or\n * interval value. If the scale has a 'ticks' method, it will be used to\n * generate the ticks, with the count argument passed as a parameter. If the\n * scale lacks a 'ticks' method, the full scale domain will be returned.\n * @param {Scale} scale - The scale for which to generate tick values.\n * @param {*} [count] - The approximate number of desired ticks.\n * @return {Array<*>} - The generated tick values.\n */\nfunction tickValues(scale, count) {\n  return scale.bins ? validTicks(scale, scale.bins) : scale.ticks ? scale.ticks(count) : scale.domain();\n}\n\n/**\n * Generate a label format function for a scale. If the scale has a\n * 'tickFormat' method, it will be used to generate the formatter, with the\n * count and specifier arguments passed as parameters. If the scale lacks a\n * 'tickFormat' method, the returned formatter performs simple string coercion.\n * If the input scale is a logarithmic scale and the format specifier does not\n * indicate a desired decimal precision, a special variable precision formatter\n * that automatically trims trailing zeroes will be generated.\n * @param {Scale} scale - The scale for which to generate the label formatter.\n * @param {*} [count] - The approximate number of desired ticks.\n * @param {string} [specifier] - The format specifier. Must be a legal d3\n *   specifier string (see https://github.com/d3/d3-format#formatSpecifier) or\n *   time multi-format specifier object.\n * @return {function(*):string} - The generated label formatter.\n */\nfunction tickFormat(locale, scale, count, specifier, formatType, noSkip) {\n  const type = scale.type;\n  let format = defaultFormatter;\n  if (type === Time || formatType === Time) {\n    format = locale.timeFormat(specifier);\n  } else if (type === UTC || formatType === UTC) {\n    format = locale.utcFormat(specifier);\n  } else if (isLogarithmic(type)) {\n    const varfmt = locale.formatFloat(specifier);\n    if (noSkip || scale.bins) {\n      format = varfmt;\n    } else {\n      const test = tickLog(scale, count, false);\n      format = _ => test(_) ? varfmt(_) : '';\n    }\n  } else if (scale.tickFormat) {\n    // if d3 scale has tickFormat, it must be continuous\n    const d = scale.domain();\n    format = locale.formatSpan(d[0], d[d.length - 1], count, specifier);\n  } else if (specifier) {\n    format = locale.format(specifier);\n  }\n  return format;\n}\nfunction tickLog(scale, count, values) {\n  const ticks = tickValues(scale, count),\n    base = scale.base(),\n    logb = Math.log(base),\n    k = Math.max(1, base * count / ticks.length);\n\n  // apply d3-scale's log format filter criteria\n  const test = d => {\n    let i = d / Math.pow(base, Math.round(Math.log(d) / logb));\n    if (i * base < base - 0.5) i *= base;\n    return i <= k;\n  };\n  return values ? ticks.filter(test) : test;\n}\n\nconst symbols = {\n  [Quantile]: 'quantiles',\n  [Quantize]: 'thresholds',\n  [Threshold]: 'domain'\n};\nconst formats = {\n  [Quantile]: 'quantiles',\n  [Quantize]: 'domain'\n};\nfunction labelValues(scale, count) {\n  return scale.bins ? binValues(scale.bins) : scale.type === Log ? tickLog(scale, count, true) : symbols[scale.type] ? thresholdValues(scale[symbols[scale.type]]()) : tickValues(scale, count);\n}\nfunction thresholdFormat(locale, scale, specifier) {\n  const _ = scale[formats[scale.type]](),\n    n = _.length;\n  let d = n > 1 ? _[1] - _[0] : _[0],\n    i;\n  for (i = 1; i < n; ++i) {\n    d = Math.min(d, _[i] - _[i - 1]);\n  }\n\n  // tickCount = 3 ticks times 10 for increased resolution\n  return locale.formatSpan(0, d, 3 * 10, specifier);\n}\nfunction thresholdValues(thresholds) {\n  const values = [-Infinity].concat(thresholds);\n  values.max = +Infinity;\n  return values;\n}\nfunction binValues(bins) {\n  const values = bins.slice(0, -1);\n  values.max = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(bins);\n  return values;\n}\nconst isDiscreteRange = scale => symbols[scale.type] || scale.bins;\nfunction labelFormat(locale, scale, count, type, specifier, formatType, noSkip) {\n  const format = formats[scale.type] && formatType !== Time && formatType !== UTC ? thresholdFormat(locale, scale, specifier) : tickFormat(locale, scale, count, specifier, formatType, noSkip);\n  return type === SymbolLegend && isDiscreteRange(scale) ? formatRange(format) : type === DiscreteLegend ? formatDiscrete(format) : formatPoint(format);\n}\nconst formatRange = format => (value, index, array) => {\n  const limit = get(array[index + 1], get(array.max, +Infinity)),\n    lo = formatValue(value, format),\n    hi = formatValue(limit, format);\n  return lo && hi ? lo + ' \\u2013 ' + hi : hi ? '< ' + hi : '\\u2265 ' + lo;\n};\nconst get = (value, dflt) => value != null ? value : dflt;\nconst formatDiscrete = format => (value, index) => index ? format(value) : null;\nconst formatPoint = format => value => format(value);\nconst formatValue = (value, format) => Number.isFinite(value) ? format(value) : null;\nfunction labelFraction(scale) {\n  const domain = scale.domain(),\n    count = domain.length - 1;\n  let lo = +domain[0],\n    hi = +(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(domain),\n    span = hi - lo;\n  if (scale.type === Threshold) {\n    const adjust = count ? span / count : 0.1;\n    lo -= adjust;\n    hi += adjust;\n    span = hi - lo;\n  }\n  return value => (value - lo) / span;\n}\n\nfunction format(locale, scale, specifier, formatType) {\n  const type = formatType || scale.type;\n\n  // replace abbreviated time specifiers to improve screen reader experience\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(specifier) && isTemporal(type)) {\n    specifier = specifier.replace(/%a/g, '%A').replace(/%b/g, '%B');\n  }\n  return !specifier && type === Time ? locale.timeFormat('%A, %d %B %Y, %X') : !specifier && type === UTC ? locale.utcFormat('%A, %d %B %Y, %X UTC') : labelFormat(locale, scale, 5, null, specifier, formatType, true);\n}\nfunction domainCaption(locale, scale, opt) {\n  opt = opt || {};\n  const max = Math.max(3, opt.maxlen || 7),\n    fmt = format(locale, scale, opt.format, opt.formatType);\n\n  // if scale breaks domain into bins, describe boundaries\n  if (isDiscretizing(scale.type)) {\n    const v = labelValues(scale).slice(1).map(fmt),\n      n = v.length;\n    return `${n} boundar${n === 1 ? 'y' : 'ies'}: ${v.join(', ')}`;\n  }\n\n  // if scale domain is discrete, list values\n  else if (isDiscrete(scale.type)) {\n    const d = scale.domain(),\n      n = d.length,\n      v = n > max ? d.slice(0, max - 2).map(fmt).join(', ') + ', ending with ' + d.slice(-1).map(fmt) : d.map(fmt).join(', ');\n    return `${n} value${n === 1 ? '' : 's'}: ${v}`;\n  }\n\n  // if scale domain is continuous, describe value range\n  else {\n    const d = scale.domain();\n    return `values from ${fmt(d[0])} to ${fmt((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(d))}`;\n  }\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-scale/build/vega-scale.module.js?");

/***/ }),

/***/ "../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Bounds: () => (/* binding */ Bounds),\n/* harmony export */   CanvasHandler: () => (/* binding */ CanvasHandler),\n/* harmony export */   CanvasRenderer: () => (/* binding */ CanvasRenderer),\n/* harmony export */   Gradient: () => (/* binding */ Gradient),\n/* harmony export */   GroupItem: () => (/* binding */ GroupItem),\n/* harmony export */   Handler: () => (/* binding */ Handler),\n/* harmony export */   Item: () => (/* binding */ Item),\n/* harmony export */   Marks: () => (/* binding */ Marks),\n/* harmony export */   RenderType: () => (/* binding */ RenderType),\n/* harmony export */   Renderer: () => (/* binding */ Renderer),\n/* harmony export */   ResourceLoader: () => (/* binding */ ResourceLoader),\n/* harmony export */   SVGHandler: () => (/* binding */ SVGHandler),\n/* harmony export */   SVGRenderer: () => (/* binding */ SVGRenderer),\n/* harmony export */   SVGStringRenderer: () => (/* binding */ SVGStringRenderer),\n/* harmony export */   Scenegraph: () => (/* binding */ Scenegraph),\n/* harmony export */   boundClip: () => (/* binding */ boundClip),\n/* harmony export */   boundContext: () => (/* binding */ boundContext),\n/* harmony export */   boundItem: () => (/* binding */ boundItem),\n/* harmony export */   boundMark: () => (/* binding */ boundMark),\n/* harmony export */   boundStroke: () => (/* binding */ boundStroke),\n/* harmony export */   domChild: () => (/* binding */ domChild),\n/* harmony export */   domClear: () => (/* binding */ domClear),\n/* harmony export */   domCreate: () => (/* binding */ domCreate),\n/* harmony export */   domFind: () => (/* binding */ domFind),\n/* harmony export */   font: () => (/* binding */ font),\n/* harmony export */   fontFamily: () => (/* binding */ fontFamily),\n/* harmony export */   fontSize: () => (/* binding */ fontSize),\n/* harmony export */   intersect: () => (/* binding */ intersect),\n/* harmony export */   intersectBoxLine: () => (/* binding */ intersectBoxLine),\n/* harmony export */   intersectPath: () => (/* binding */ intersectPath),\n/* harmony export */   intersectPoint: () => (/* binding */ intersectPoint),\n/* harmony export */   intersectRule: () => (/* binding */ intersectRule),\n/* harmony export */   lineHeight: () => (/* binding */ lineHeight),\n/* harmony export */   markup: () => (/* binding */ markup),\n/* harmony export */   multiLineOffset: () => (/* binding */ multiLineOffset),\n/* harmony export */   path: () => (/* reexport safe */ d3_path__WEBPACK_IMPORTED_MODULE_1__.path),\n/* harmony export */   pathCurves: () => (/* binding */ curves),\n/* harmony export */   pathEqual: () => (/* binding */ pathEqual),\n/* harmony export */   pathParse: () => (/* binding */ parse),\n/* harmony export */   pathRectangle: () => (/* binding */ vg_rect),\n/* harmony export */   pathRender: () => (/* binding */ pathRender),\n/* harmony export */   pathSymbols: () => (/* binding */ symbols),\n/* harmony export */   pathTrail: () => (/* binding */ vg_trail),\n/* harmony export */   point: () => (/* binding */ point),\n/* harmony export */   renderModule: () => (/* binding */ renderModule),\n/* harmony export */   resetSVGClipId: () => (/* binding */ resetSVGClipId),\n/* harmony export */   resetSVGDefIds: () => (/* binding */ resetSVGDefIds),\n/* harmony export */   sceneEqual: () => (/* binding */ sceneEqual),\n/* harmony export */   sceneFromJSON: () => (/* binding */ sceneFromJSON),\n/* harmony export */   scenePickVisit: () => (/* binding */ pickVisit),\n/* harmony export */   sceneToJSON: () => (/* binding */ sceneToJSON),\n/* harmony export */   sceneVisit: () => (/* binding */ visit),\n/* harmony export */   sceneZOrder: () => (/* binding */ zorder),\n/* harmony export */   serializeXML: () => (/* binding */ serializeXML),\n/* harmony export */   textMetrics: () => (/* binding */ textMetrics)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/basis.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/basisClosed.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/basisOpen.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/bundle.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/cardinal.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/cardinalOpen.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/cardinalClosed.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/catmullRom.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/catmullRomClosed.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/catmullRomOpen.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/linear.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/linearClosed.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/monotone.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/natural.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/curve/step.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/arc.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/area.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/line.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! d3-shape */ \"../../node_modules/d3-shape/src/symbol.js\");\n/* harmony import */ var d3_path__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-path */ \"../../node_modules/d3-path/src/path.js\");\n/* harmony import */ var vega_canvas__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-canvas */ \"../../node_modules/vega-canvas/build/vega-canvas.browser.module.js\");\n/* harmony import */ var vega_loader__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-loader */ \"../../node_modules/vega-loader/build/vega-loader.browser.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n\n\n\n\n\n\n\n\nlet gradient_id = 0;\nfunction resetSVGGradientId() {\n  gradient_id = 0;\n}\nconst patternPrefix = 'p_';\nfunction isGradient(value) {\n  return value && value.gradient;\n}\nfunction gradientRef(g, defs, base) {\n  const type = g.gradient;\n  let id = g.id,\n    prefix = type === 'radial' ? patternPrefix : '';\n\n  // check id, assign default values as needed\n  if (!id) {\n    id = g.id = 'gradient_' + gradient_id++;\n    if (type === 'radial') {\n      g.x1 = get(g.x1, 0.5);\n      g.y1 = get(g.y1, 0.5);\n      g.r1 = get(g.r1, 0);\n      g.x2 = get(g.x2, 0.5);\n      g.y2 = get(g.y2, 0.5);\n      g.r2 = get(g.r2, 0.5);\n      prefix = patternPrefix;\n    } else {\n      g.x1 = get(g.x1, 0);\n      g.y1 = get(g.y1, 0);\n      g.x2 = get(g.x2, 1);\n      g.y2 = get(g.y2, 0);\n    }\n  }\n\n  // register definition\n  defs[id] = g;\n\n  // return url reference\n  return 'url(' + (base || '') + '#' + prefix + id + ')';\n}\nfunction get(val, def) {\n  return val != null ? val : def;\n}\nfunction Gradient (p0, p1) {\n  var stops = [],\n    gradient;\n  return gradient = {\n    gradient: 'linear',\n    x1: p0 ? p0[0] : 0,\n    y1: p0 ? p0[1] : 0,\n    x2: p1 ? p1[0] : 1,\n    y2: p1 ? p1[1] : 0,\n    stops: stops,\n    stop: function (offset, color) {\n      stops.push({\n        offset: offset,\n        color: color\n      });\n      return gradient;\n    }\n  };\n}\n\nconst lookup = {\n  'basis': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_5__[\"default\"]\n  },\n  'basis-closed': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_6__[\"default\"]\n  },\n  'basis-open': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_7__[\"default\"]\n  },\n  'bundle': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n    tension: 'beta',\n    value: 0.85\n  },\n  'cardinal': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n    tension: 'tension',\n    value: 0\n  },\n  'cardinal-open': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n    tension: 'tension',\n    value: 0\n  },\n  'cardinal-closed': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n    tension: 'tension',\n    value: 0\n  },\n  'catmull-rom': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n    tension: 'alpha',\n    value: 0.5\n  },\n  'catmull-rom-closed': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_13__[\"default\"],\n    tension: 'alpha',\n    value: 0.5\n  },\n  'catmull-rom-open': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_14__[\"default\"],\n    tension: 'alpha',\n    value: 0.5\n  },\n  'linear': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_15__[\"default\"]\n  },\n  'linear-closed': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_16__[\"default\"]\n  },\n  'monotone': {\n    horizontal: d3_shape__WEBPACK_IMPORTED_MODULE_17__.monotoneY,\n    vertical: d3_shape__WEBPACK_IMPORTED_MODULE_17__.monotoneX\n  },\n  'natural': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_18__[\"default\"]\n  },\n  'step': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_19__[\"default\"]\n  },\n  'step-after': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_19__.stepAfter\n  },\n  'step-before': {\n    curve: d3_shape__WEBPACK_IMPORTED_MODULE_19__.stepBefore\n  }\n};\nfunction curves(type, orientation, tension) {\n  var entry = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(lookup, type) && lookup[type],\n    curve = null;\n  if (entry) {\n    curve = entry.curve || entry[orientation || 'vertical'];\n    if (entry.tension && tension != null) {\n      curve = curve[entry.tension](tension);\n    }\n  }\n  return curve;\n}\n\nconst paramCounts = {\n  m: 2,\n  l: 2,\n  h: 1,\n  v: 1,\n  z: 0,\n  c: 6,\n  s: 4,\n  q: 4,\n  t: 2,\n  a: 7\n};\nconst commandPattern = /[mlhvzcsqta]([^mlhvzcsqta]+|$)/gi;\nconst numberPattern = /^[+-]?(([0-9]*\\.[0-9]+)|([0-9]+\\.)|([0-9]+))([eE][+-]?[0-9]+)?/;\nconst spacePattern = /^((\\s+,?\\s*)|(,\\s*))/;\nconst flagPattern = /^[01]/;\nfunction parse(path) {\n  const commands = [];\n  const matches = path.match(commandPattern) || [];\n  matches.forEach(str => {\n    let cmd = str[0];\n    const type = cmd.toLowerCase();\n\n    // parse parameters\n    const paramCount = paramCounts[type];\n    const params = parseParams(type, paramCount, str.slice(1).trim());\n    const count = params.length;\n\n    // error checking based on parameter count\n    if (count < paramCount || count && count % paramCount !== 0) {\n      throw Error('Invalid SVG path, incorrect parameter count');\n    }\n\n    // register the command\n    commands.push([cmd, ...params.slice(0, paramCount)]);\n\n    // exit now if we're done, also handles zero-param 'z'\n    if (count === paramCount) {\n      return;\n    }\n\n    // handle implicit line-to\n    if (type === 'm') {\n      cmd = cmd === 'M' ? 'L' : 'l';\n    }\n\n    // repeat command when given extended param list\n    for (let i = paramCount; i < count; i += paramCount) {\n      commands.push([cmd, ...params.slice(i, i + paramCount)]);\n    }\n  });\n  return commands;\n}\nfunction parseParams(type, paramCount, segment) {\n  const params = [];\n  for (let index = 0; paramCount && index < segment.length;) {\n    for (let i = 0; i < paramCount; ++i) {\n      const pattern = type === 'a' && (i === 3 || i === 4) ? flagPattern : numberPattern;\n      const match = segment.slice(index).match(pattern);\n      if (match === null) {\n        throw Error('Invalid SVG path, incorrect parameter type');\n      }\n      index += match[0].length;\n      params.push(+match[0]);\n      const ws = segment.slice(index).match(spacePattern);\n      if (ws !== null) {\n        index += ws[0].length;\n      }\n    }\n  }\n  return params;\n}\n\nconst DegToRad = Math.PI / 180;\nconst Epsilon = 1e-14;\nconst HalfPi = Math.PI / 2;\nconst Tau = Math.PI * 2;\nconst HalfSqrt3 = Math.sqrt(3) / 2;\n\nvar segmentCache = {};\nvar bezierCache = {};\nvar join = [].join;\n\n// Copied from Inkscape svgtopdf, thanks!\nfunction segments(x, y, rx, ry, large, sweep, rotateX, ox, oy) {\n  const key = join.call(arguments);\n  if (segmentCache[key]) {\n    return segmentCache[key];\n  }\n  const th = rotateX * DegToRad;\n  const sin_th = Math.sin(th);\n  const cos_th = Math.cos(th);\n  rx = Math.abs(rx);\n  ry = Math.abs(ry);\n  const px = cos_th * (ox - x) * 0.5 + sin_th * (oy - y) * 0.5;\n  const py = cos_th * (oy - y) * 0.5 - sin_th * (ox - x) * 0.5;\n  let pl = px * px / (rx * rx) + py * py / (ry * ry);\n  if (pl > 1) {\n    pl = Math.sqrt(pl);\n    rx *= pl;\n    ry *= pl;\n  }\n  const a00 = cos_th / rx;\n  const a01 = sin_th / rx;\n  const a10 = -sin_th / ry;\n  const a11 = cos_th / ry;\n  const x0 = a00 * ox + a01 * oy;\n  const y0 = a10 * ox + a11 * oy;\n  const x1 = a00 * x + a01 * y;\n  const y1 = a10 * x + a11 * y;\n  const d = (x1 - x0) * (x1 - x0) + (y1 - y0) * (y1 - y0);\n  let sfactor_sq = 1 / d - 0.25;\n  if (sfactor_sq < 0) sfactor_sq = 0;\n  let sfactor = Math.sqrt(sfactor_sq);\n  if (sweep == large) sfactor = -sfactor;\n  const xc = 0.5 * (x0 + x1) - sfactor * (y1 - y0);\n  const yc = 0.5 * (y0 + y1) + sfactor * (x1 - x0);\n  const th0 = Math.atan2(y0 - yc, x0 - xc);\n  const th1 = Math.atan2(y1 - yc, x1 - xc);\n  let th_arc = th1 - th0;\n  if (th_arc < 0 && sweep === 1) {\n    th_arc += Tau;\n  } else if (th_arc > 0 && sweep === 0) {\n    th_arc -= Tau;\n  }\n  const segs = Math.ceil(Math.abs(th_arc / (HalfPi + 0.001)));\n  const result = [];\n  for (let i = 0; i < segs; ++i) {\n    const th2 = th0 + i * th_arc / segs;\n    const th3 = th0 + (i + 1) * th_arc / segs;\n    result[i] = [xc, yc, th2, th3, rx, ry, sin_th, cos_th];\n  }\n  return segmentCache[key] = result;\n}\nfunction bezier(params) {\n  const key = join.call(params);\n  if (bezierCache[key]) {\n    return bezierCache[key];\n  }\n  var cx = params[0],\n    cy = params[1],\n    th0 = params[2],\n    th1 = params[3],\n    rx = params[4],\n    ry = params[5],\n    sin_th = params[6],\n    cos_th = params[7];\n  const a00 = cos_th * rx;\n  const a01 = -sin_th * ry;\n  const a10 = sin_th * rx;\n  const a11 = cos_th * ry;\n  const cos_th0 = Math.cos(th0);\n  const sin_th0 = Math.sin(th0);\n  const cos_th1 = Math.cos(th1);\n  const sin_th1 = Math.sin(th1);\n  const th_half = 0.5 * (th1 - th0);\n  const sin_th_h2 = Math.sin(th_half * 0.5);\n  const t = 8 / 3 * sin_th_h2 * sin_th_h2 / Math.sin(th_half);\n  const x1 = cx + cos_th0 - t * sin_th0;\n  const y1 = cy + sin_th0 + t * cos_th0;\n  const x3 = cx + cos_th1;\n  const y3 = cy + sin_th1;\n  const x2 = x3 + t * sin_th1;\n  const y2 = y3 - t * cos_th1;\n  return bezierCache[key] = [a00 * x1 + a01 * y1, a10 * x1 + a11 * y1, a00 * x2 + a01 * y2, a10 * x2 + a11 * y2, a00 * x3 + a01 * y3, a10 * x3 + a11 * y3];\n}\n\nconst temp = ['l', 0, 0, 0, 0, 0, 0, 0];\nfunction scale$1(current, sX, sY) {\n  const c = temp[0] = current[0];\n  if (c === 'a' || c === 'A') {\n    temp[1] = sX * current[1];\n    temp[2] = sY * current[2];\n    temp[3] = current[3];\n    temp[4] = current[4];\n    temp[5] = current[5];\n    temp[6] = sX * current[6];\n    temp[7] = sY * current[7];\n  } else if (c === 'h' || c === 'H') {\n    temp[1] = sX * current[1];\n  } else if (c === 'v' || c === 'V') {\n    temp[1] = sY * current[1];\n  } else {\n    for (var i = 1, n = current.length; i < n; ++i) {\n      temp[i] = (i % 2 == 1 ? sX : sY) * current[i];\n    }\n  }\n  return temp;\n}\nfunction pathRender (context, path, l, t, sX, sY) {\n  var current,\n    // current instruction\n    previous = null,\n    x = 0,\n    // current x\n    y = 0,\n    // current y\n    controlX = 0,\n    // current control point x\n    controlY = 0,\n    // current control point y\n    tempX,\n    tempY,\n    tempControlX,\n    tempControlY,\n    anchorX = 0,\n    anchorY = 0;\n  if (l == null) l = 0;\n  if (t == null) t = 0;\n  if (sX == null) sX = 1;\n  if (sY == null) sY = sX;\n  if (context.beginPath) context.beginPath();\n  for (var i = 0, len = path.length; i < len; ++i) {\n    current = path[i];\n    if (sX !== 1 || sY !== 1) {\n      current = scale$1(current, sX, sY);\n    }\n    switch (current[0]) {\n      // first letter\n\n      case 'l':\n        // lineto, relative\n        x += current[1];\n        y += current[2];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'L':\n        // lineto, absolute\n        x = current[1];\n        y = current[2];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'h':\n        // horizontal lineto, relative\n        x += current[1];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'H':\n        // horizontal lineto, absolute\n        x = current[1];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'v':\n        // vertical lineto, relative\n        y += current[1];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'V':\n        // verical lineto, absolute\n        y = current[1];\n        context.lineTo(x + l, y + t);\n        break;\n      case 'm':\n        // moveTo, relative\n        x += current[1];\n        y += current[2];\n        anchorX = x;\n        anchorY = y;\n        context.moveTo(x + l, y + t);\n        break;\n      case 'M':\n        // moveTo, absolute\n        x = current[1];\n        y = current[2];\n        anchorX = x;\n        anchorY = y;\n        context.moveTo(x + l, y + t);\n        break;\n      case 'c':\n        // bezierCurveTo, relative\n        tempX = x + current[5];\n        tempY = y + current[6];\n        controlX = x + current[3];\n        controlY = y + current[4];\n        context.bezierCurveTo(x + current[1] + l,\n        // x1\n        y + current[2] + t,\n        // y1\n        controlX + l,\n        // x2\n        controlY + t,\n        // y2\n        tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        break;\n      case 'C':\n        // bezierCurveTo, absolute\n        x = current[5];\n        y = current[6];\n        controlX = current[3];\n        controlY = current[4];\n        context.bezierCurveTo(current[1] + l, current[2] + t, controlX + l, controlY + t, x + l, y + t);\n        break;\n      case 's':\n        // shorthand cubic bezierCurveTo, relative\n        // transform to absolute x,y\n        tempX = x + current[3];\n        tempY = y + current[4];\n        // calculate reflection of previous control points\n        controlX = 2 * x - controlX;\n        controlY = 2 * y - controlY;\n        context.bezierCurveTo(controlX + l, controlY + t, x + current[1] + l, y + current[2] + t, tempX + l, tempY + t);\n\n        // set control point to 2nd one of this command\n        // the first control point is assumed to be the reflection of\n        // the second control point on the previous command relative\n        // to the current point.\n        controlX = x + current[1];\n        controlY = y + current[2];\n        x = tempX;\n        y = tempY;\n        break;\n      case 'S':\n        // shorthand cubic bezierCurveTo, absolute\n        tempX = current[3];\n        tempY = current[4];\n        // calculate reflection of previous control points\n        controlX = 2 * x - controlX;\n        controlY = 2 * y - controlY;\n        context.bezierCurveTo(controlX + l, controlY + t, current[1] + l, current[2] + t, tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        // set control point to 2nd one of this command\n        // the first control point is assumed to be the reflection of\n        // the second control point on the previous command relative\n        // to the current point.\n        controlX = current[1];\n        controlY = current[2];\n        break;\n      case 'q':\n        // quadraticCurveTo, relative\n        // transform to absolute x,y\n        tempX = x + current[3];\n        tempY = y + current[4];\n        controlX = x + current[1];\n        controlY = y + current[2];\n        context.quadraticCurveTo(controlX + l, controlY + t, tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        break;\n      case 'Q':\n        // quadraticCurveTo, absolute\n        tempX = current[3];\n        tempY = current[4];\n        context.quadraticCurveTo(current[1] + l, current[2] + t, tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        controlX = current[1];\n        controlY = current[2];\n        break;\n      case 't':\n        // shorthand quadraticCurveTo, relative\n\n        // transform to absolute x,y\n        tempX = x + current[1];\n        tempY = y + current[2];\n        if (previous[0].match(/[QqTt]/) === null) {\n          // If there is no previous command or if the previous command was not a Q, q, T or t,\n          // assume the control point is coincident with the current point\n          controlX = x;\n          controlY = y;\n        } else if (previous[0] === 't') {\n          // calculate reflection of previous control points for t\n          controlX = 2 * x - tempControlX;\n          controlY = 2 * y - tempControlY;\n        } else if (previous[0] === 'q') {\n          // calculate reflection of previous control points for q\n          controlX = 2 * x - controlX;\n          controlY = 2 * y - controlY;\n        }\n        tempControlX = controlX;\n        tempControlY = controlY;\n        context.quadraticCurveTo(controlX + l, controlY + t, tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        controlX = x + current[1];\n        controlY = y + current[2];\n        break;\n      case 'T':\n        tempX = current[1];\n        tempY = current[2];\n\n        // calculate reflection of previous control points\n        controlX = 2 * x - controlX;\n        controlY = 2 * y - controlY;\n        context.quadraticCurveTo(controlX + l, controlY + t, tempX + l, tempY + t);\n        x = tempX;\n        y = tempY;\n        break;\n      case 'a':\n        drawArc(context, x + l, y + t, [current[1], current[2], current[3], current[4], current[5], current[6] + x + l, current[7] + y + t]);\n        x += current[6];\n        y += current[7];\n        break;\n      case 'A':\n        drawArc(context, x + l, y + t, [current[1], current[2], current[3], current[4], current[5], current[6] + l, current[7] + t]);\n        x = current[6];\n        y = current[7];\n        break;\n      case 'z':\n      case 'Z':\n        x = anchorX;\n        y = anchorY;\n        context.closePath();\n        break;\n    }\n    previous = current;\n  }\n}\nfunction drawArc(context, x, y, coords) {\n  const seg = segments(coords[5],\n  // end x\n  coords[6],\n  // end y\n  coords[0],\n  // radius x\n  coords[1],\n  // radius y\n  coords[3],\n  // large flag\n  coords[4],\n  // sweep flag\n  coords[2],\n  // rotation\n  x, y);\n  for (let i = 0; i < seg.length; ++i) {\n    const bez = bezier(seg[i]);\n    context.bezierCurveTo(bez[0], bez[1], bez[2], bez[3], bez[4], bez[5]);\n  }\n}\n\nconst Tan30 = 0.5773502691896257;\nconst builtins = {\n  'circle': {\n    draw: function (context, size) {\n      const r = Math.sqrt(size) / 2;\n      context.moveTo(r, 0);\n      context.arc(0, 0, r, 0, Tau);\n    }\n  },\n  'cross': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        s = r / 2.5;\n      context.moveTo(-r, -s);\n      context.lineTo(-r, s);\n      context.lineTo(-s, s);\n      context.lineTo(-s, r);\n      context.lineTo(s, r);\n      context.lineTo(s, s);\n      context.lineTo(r, s);\n      context.lineTo(r, -s);\n      context.lineTo(s, -s);\n      context.lineTo(s, -r);\n      context.lineTo(-s, -r);\n      context.lineTo(-s, -s);\n      context.closePath();\n    }\n  },\n  'diamond': {\n    draw: function (context, size) {\n      const r = Math.sqrt(size) / 2;\n      context.moveTo(-r, 0);\n      context.lineTo(0, -r);\n      context.lineTo(r, 0);\n      context.lineTo(0, r);\n      context.closePath();\n    }\n  },\n  'square': {\n    draw: function (context, size) {\n      var w = Math.sqrt(size),\n        x = -w / 2;\n      context.rect(x, x, w, w);\n    }\n  },\n  'arrow': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        s = r / 7,\n        t = r / 2.5,\n        v = r / 8;\n      context.moveTo(-s, r);\n      context.lineTo(s, r);\n      context.lineTo(s, -v);\n      context.lineTo(t, -v);\n      context.lineTo(0, -r);\n      context.lineTo(-t, -v);\n      context.lineTo(-s, -v);\n      context.closePath();\n    }\n  },\n  'wedge': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r,\n        o = h - r * Tan30,\n        b = r / 4;\n      context.moveTo(0, -h - o);\n      context.lineTo(-b, h - o);\n      context.lineTo(b, h - o);\n      context.closePath();\n    }\n  },\n  'triangle': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r,\n        o = h - r * Tan30;\n      context.moveTo(0, -h - o);\n      context.lineTo(-r, h - o);\n      context.lineTo(r, h - o);\n      context.closePath();\n    }\n  },\n  'triangle-up': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r;\n      context.moveTo(0, -h);\n      context.lineTo(-r, h);\n      context.lineTo(r, h);\n      context.closePath();\n    }\n  },\n  'triangle-down': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r;\n      context.moveTo(0, h);\n      context.lineTo(-r, -h);\n      context.lineTo(r, -h);\n      context.closePath();\n    }\n  },\n  'triangle-right': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r;\n      context.moveTo(h, 0);\n      context.lineTo(-h, -r);\n      context.lineTo(-h, r);\n      context.closePath();\n    }\n  },\n  'triangle-left': {\n    draw: function (context, size) {\n      var r = Math.sqrt(size) / 2,\n        h = HalfSqrt3 * r;\n      context.moveTo(-h, 0);\n      context.lineTo(h, -r);\n      context.lineTo(h, r);\n      context.closePath();\n    }\n  },\n  'stroke': {\n    draw: function (context, size) {\n      const r = Math.sqrt(size) / 2;\n      context.moveTo(-r, 0);\n      context.lineTo(r, 0);\n    }\n  }\n};\nfunction symbols(_) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(builtins, _) ? builtins[_] : customSymbol(_);\n}\nvar custom = {};\nfunction customSymbol(path) {\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(custom, path)) {\n    const parsed = parse(path);\n    custom[path] = {\n      draw: function (context, size) {\n        pathRender(context, parsed, 0, 0, Math.sqrt(size) / 2);\n      }\n    };\n  }\n  return custom[path];\n}\n\n// See http://spencermortensen.com/articles/bezier-circle/\nconst C = 0.448084975506; // C = 1 - c\n\nfunction rectangleX(d) {\n  return d.x;\n}\nfunction rectangleY(d) {\n  return d.y;\n}\nfunction rectangleWidth(d) {\n  return d.width;\n}\nfunction rectangleHeight(d) {\n  return d.height;\n}\nfunction number(_) {\n  return typeof _ === 'function' ? _ : () => +_;\n}\nfunction clamp(value, min, max) {\n  return Math.max(min, Math.min(value, max));\n}\nfunction vg_rect () {\n  var x = rectangleX,\n    y = rectangleY,\n    width = rectangleWidth,\n    height = rectangleHeight,\n    crTL = number(0),\n    crTR = crTL,\n    crBL = crTL,\n    crBR = crTL,\n    context = null;\n  function rectangle(_, x0, y0) {\n    var buffer,\n      x1 = x0 != null ? x0 : +x.call(this, _),\n      y1 = y0 != null ? y0 : +y.call(this, _),\n      w = +width.call(this, _),\n      h = +height.call(this, _),\n      s = Math.min(w, h) / 2,\n      tl = clamp(+crTL.call(this, _), 0, s),\n      tr = clamp(+crTR.call(this, _), 0, s),\n      bl = clamp(+crBL.call(this, _), 0, s),\n      br = clamp(+crBR.call(this, _), 0, s);\n    if (!context) context = buffer = (0,d3_path__WEBPACK_IMPORTED_MODULE_1__.path)();\n    if (tl <= 0 && tr <= 0 && bl <= 0 && br <= 0) {\n      context.rect(x1, y1, w, h);\n    } else {\n      var x2 = x1 + w,\n        y2 = y1 + h;\n      context.moveTo(x1 + tl, y1);\n      context.lineTo(x2 - tr, y1);\n      context.bezierCurveTo(x2 - C * tr, y1, x2, y1 + C * tr, x2, y1 + tr);\n      context.lineTo(x2, y2 - br);\n      context.bezierCurveTo(x2, y2 - C * br, x2 - C * br, y2, x2 - br, y2);\n      context.lineTo(x1 + bl, y2);\n      context.bezierCurveTo(x1 + C * bl, y2, x1, y2 - C * bl, x1, y2 - bl);\n      context.lineTo(x1, y1 + tl);\n      context.bezierCurveTo(x1, y1 + C * tl, x1 + C * tl, y1, x1 + tl, y1);\n      context.closePath();\n    }\n    if (buffer) {\n      context = null;\n      return buffer + '' || null;\n    }\n  }\n  rectangle.x = function (_) {\n    if (arguments.length) {\n      x = number(_);\n      return rectangle;\n    } else {\n      return x;\n    }\n  };\n  rectangle.y = function (_) {\n    if (arguments.length) {\n      y = number(_);\n      return rectangle;\n    } else {\n      return y;\n    }\n  };\n  rectangle.width = function (_) {\n    if (arguments.length) {\n      width = number(_);\n      return rectangle;\n    } else {\n      return width;\n    }\n  };\n  rectangle.height = function (_) {\n    if (arguments.length) {\n      height = number(_);\n      return rectangle;\n    } else {\n      return height;\n    }\n  };\n  rectangle.cornerRadius = function (tl, tr, br, bl) {\n    if (arguments.length) {\n      crTL = number(tl);\n      crTR = tr != null ? number(tr) : crTL;\n      crBR = br != null ? number(br) : crTL;\n      crBL = bl != null ? number(bl) : crTR;\n      return rectangle;\n    } else {\n      return crTL;\n    }\n  };\n  rectangle.context = function (_) {\n    if (arguments.length) {\n      context = _ == null ? null : _;\n      return rectangle;\n    } else {\n      return context;\n    }\n  };\n  return rectangle;\n}\n\nfunction vg_trail () {\n  var x,\n    y,\n    size,\n    defined,\n    context = null,\n    ready,\n    x1,\n    y1,\n    r1;\n  function point(x2, y2, w2) {\n    const r2 = w2 / 2;\n    if (ready) {\n      var ux = y1 - y2,\n        uy = x2 - x1;\n      if (ux || uy) {\n        // get normal vector\n        var ud = Math.sqrt(ux * ux + uy * uy),\n          rx = (ux /= ud) * r1,\n          ry = (uy /= ud) * r1,\n          t = Math.atan2(uy, ux);\n\n        // draw segment\n        context.moveTo(x1 - rx, y1 - ry);\n        context.lineTo(x2 - ux * r2, y2 - uy * r2);\n        context.arc(x2, y2, r2, t - Math.PI, t);\n        context.lineTo(x1 + rx, y1 + ry);\n        context.arc(x1, y1, r1, t, t + Math.PI);\n      } else {\n        context.arc(x2, y2, r2, 0, Tau);\n      }\n      context.closePath();\n    } else {\n      ready = 1;\n    }\n    x1 = x2;\n    y1 = y2;\n    r1 = r2;\n  }\n  function trail(data) {\n    var i,\n      n = data.length,\n      d,\n      defined0 = false,\n      buffer;\n    if (context == null) context = buffer = (0,d3_path__WEBPACK_IMPORTED_MODULE_1__.path)();\n    for (i = 0; i <= n; ++i) {\n      if (!(i < n && defined(d = data[i], i, data)) === defined0) {\n        if (defined0 = !defined0) ready = 0;\n      }\n      if (defined0) point(+x(d, i, data), +y(d, i, data), +size(d, i, data));\n    }\n    if (buffer) {\n      context = null;\n      return buffer + '' || null;\n    }\n  }\n  trail.x = function (_) {\n    if (arguments.length) {\n      x = _;\n      return trail;\n    } else {\n      return x;\n    }\n  };\n  trail.y = function (_) {\n    if (arguments.length) {\n      y = _;\n      return trail;\n    } else {\n      return y;\n    }\n  };\n  trail.size = function (_) {\n    if (arguments.length) {\n      size = _;\n      return trail;\n    } else {\n      return size;\n    }\n  };\n  trail.defined = function (_) {\n    if (arguments.length) {\n      defined = _;\n      return trail;\n    } else {\n      return defined;\n    }\n  };\n  trail.context = function (_) {\n    if (arguments.length) {\n      if (_ == null) {\n        context = null;\n      } else {\n        context = _;\n      }\n      return trail;\n    } else {\n      return context;\n    }\n  };\n  return trail;\n}\n\nfunction value$1(a, b) {\n  return a != null ? a : b;\n}\nconst x = item => item.x || 0,\n  y = item => item.y || 0,\n  w = item => item.width || 0,\n  h = item => item.height || 0,\n  xw = item => (item.x || 0) + (item.width || 0),\n  yh = item => (item.y || 0) + (item.height || 0),\n  sa = item => item.startAngle || 0,\n  ea = item => item.endAngle || 0,\n  pa = item => item.padAngle || 0,\n  ir = item => item.innerRadius || 0,\n  or = item => item.outerRadius || 0,\n  cr = item => item.cornerRadius || 0,\n  tl = item => value$1(item.cornerRadiusTopLeft, item.cornerRadius) || 0,\n  tr = item => value$1(item.cornerRadiusTopRight, item.cornerRadius) || 0,\n  br = item => value$1(item.cornerRadiusBottomRight, item.cornerRadius) || 0,\n  bl = item => value$1(item.cornerRadiusBottomLeft, item.cornerRadius) || 0,\n  sz = item => value$1(item.size, 64),\n  ts = item => item.size || 1,\n  def = item => !(item.defined === false),\n  type = item => symbols(item.shape || 'circle');\nconst arcShape = (0,d3_shape__WEBPACK_IMPORTED_MODULE_20__[\"default\"])().startAngle(sa).endAngle(ea).padAngle(pa).innerRadius(ir).outerRadius(or).cornerRadius(cr),\n  areavShape = (0,d3_shape__WEBPACK_IMPORTED_MODULE_21__[\"default\"])().x(x).y1(y).y0(yh).defined(def),\n  areahShape = (0,d3_shape__WEBPACK_IMPORTED_MODULE_21__[\"default\"])().y(y).x1(x).x0(xw).defined(def),\n  lineShape = (0,d3_shape__WEBPACK_IMPORTED_MODULE_22__[\"default\"])().x(x).y(y).defined(def),\n  rectShape = vg_rect().x(x).y(y).width(w).height(h).cornerRadius(tl, tr, br, bl),\n  symbolShape = (0,d3_shape__WEBPACK_IMPORTED_MODULE_23__[\"default\"])().type(type).size(sz),\n  trailShape = vg_trail().x(x).y(y).defined(def).size(ts);\nfunction hasCornerRadius(item) {\n  return item.cornerRadius || item.cornerRadiusTopLeft || item.cornerRadiusTopRight || item.cornerRadiusBottomRight || item.cornerRadiusBottomLeft;\n}\nfunction arc$1(context, item) {\n  return arcShape.context(context)(item);\n}\nfunction area$1(context, items) {\n  const item = items[0],\n    interp = item.interpolate || 'linear';\n  return (item.orient === 'horizontal' ? areahShape : areavShape).curve(curves(interp, item.orient, item.tension)).context(context)(items);\n}\nfunction line$1(context, items) {\n  const item = items[0],\n    interp = item.interpolate || 'linear';\n  return lineShape.curve(curves(interp, item.orient, item.tension)).context(context)(items);\n}\nfunction rectangle(context, item, x, y) {\n  return rectShape.context(context)(item, x, y);\n}\nfunction shape$1(context, item) {\n  return (item.mark.shape || item.shape).context(context)(item);\n}\nfunction symbol$1(context, item) {\n  return symbolShape.context(context)(item);\n}\nfunction trail$1(context, items) {\n  return trailShape.context(context)(items);\n}\n\nvar clip_id = 1;\nfunction resetSVGClipId() {\n  clip_id = 1;\n}\nfunction clip$1 (renderer, item, size) {\n  var clip = item.clip,\n    defs = renderer._defs,\n    id = item.clip_id || (item.clip_id = 'clip' + clip_id++),\n    c = defs.clipping[id] || (defs.clipping[id] = {\n      id: id\n    });\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(clip)) {\n    c.path = clip(null);\n  } else if (hasCornerRadius(size)) {\n    c.path = rectangle(null, size, 0, 0);\n  } else {\n    c.width = size.width || 0;\n    c.height = size.height || 0;\n  }\n  return 'url(#' + id + ')';\n}\n\nfunction Bounds(b) {\n  this.clear();\n  if (b) this.union(b);\n}\nBounds.prototype = {\n  clone() {\n    return new Bounds(this);\n  },\n  clear() {\n    this.x1 = +Number.MAX_VALUE;\n    this.y1 = +Number.MAX_VALUE;\n    this.x2 = -Number.MAX_VALUE;\n    this.y2 = -Number.MAX_VALUE;\n    return this;\n  },\n  empty() {\n    return this.x1 === +Number.MAX_VALUE && this.y1 === +Number.MAX_VALUE && this.x2 === -Number.MAX_VALUE && this.y2 === -Number.MAX_VALUE;\n  },\n  equals(b) {\n    return this.x1 === b.x1 && this.y1 === b.y1 && this.x2 === b.x2 && this.y2 === b.y2;\n  },\n  set(x1, y1, x2, y2) {\n    if (x2 < x1) {\n      this.x2 = x1;\n      this.x1 = x2;\n    } else {\n      this.x1 = x1;\n      this.x2 = x2;\n    }\n    if (y2 < y1) {\n      this.y2 = y1;\n      this.y1 = y2;\n    } else {\n      this.y1 = y1;\n      this.y2 = y2;\n    }\n    return this;\n  },\n  add(x, y) {\n    if (x < this.x1) this.x1 = x;\n    if (y < this.y1) this.y1 = y;\n    if (x > this.x2) this.x2 = x;\n    if (y > this.y2) this.y2 = y;\n    return this;\n  },\n  expand(d) {\n    this.x1 -= d;\n    this.y1 -= d;\n    this.x2 += d;\n    this.y2 += d;\n    return this;\n  },\n  round() {\n    this.x1 = Math.floor(this.x1);\n    this.y1 = Math.floor(this.y1);\n    this.x2 = Math.ceil(this.x2);\n    this.y2 = Math.ceil(this.y2);\n    return this;\n  },\n  scale(s) {\n    this.x1 *= s;\n    this.y1 *= s;\n    this.x2 *= s;\n    this.y2 *= s;\n    return this;\n  },\n  translate(dx, dy) {\n    this.x1 += dx;\n    this.x2 += dx;\n    this.y1 += dy;\n    this.y2 += dy;\n    return this;\n  },\n  rotate(angle, x, y) {\n    const p = this.rotatedPoints(angle, x, y);\n    return this.clear().add(p[0], p[1]).add(p[2], p[3]).add(p[4], p[5]).add(p[6], p[7]);\n  },\n  rotatedPoints(angle, x, y) {\n    var {\n        x1,\n        y1,\n        x2,\n        y2\n      } = this,\n      cos = Math.cos(angle),\n      sin = Math.sin(angle),\n      cx = x - x * cos + y * sin,\n      cy = y - x * sin - y * cos;\n    return [cos * x1 - sin * y1 + cx, sin * x1 + cos * y1 + cy, cos * x1 - sin * y2 + cx, sin * x1 + cos * y2 + cy, cos * x2 - sin * y1 + cx, sin * x2 + cos * y1 + cy, cos * x2 - sin * y2 + cx, sin * x2 + cos * y2 + cy];\n  },\n  union(b) {\n    if (b.x1 < this.x1) this.x1 = b.x1;\n    if (b.y1 < this.y1) this.y1 = b.y1;\n    if (b.x2 > this.x2) this.x2 = b.x2;\n    if (b.y2 > this.y2) this.y2 = b.y2;\n    return this;\n  },\n  intersect(b) {\n    if (b.x1 > this.x1) this.x1 = b.x1;\n    if (b.y1 > this.y1) this.y1 = b.y1;\n    if (b.x2 < this.x2) this.x2 = b.x2;\n    if (b.y2 < this.y2) this.y2 = b.y2;\n    return this;\n  },\n  encloses(b) {\n    return b && this.x1 <= b.x1 && this.x2 >= b.x2 && this.y1 <= b.y1 && this.y2 >= b.y2;\n  },\n  alignsWith(b) {\n    return b && (this.x1 == b.x1 || this.x2 == b.x2 || this.y1 == b.y1 || this.y2 == b.y2);\n  },\n  intersects(b) {\n    return b && !(this.x2 < b.x1 || this.x1 > b.x2 || this.y2 < b.y1 || this.y1 > b.y2);\n  },\n  contains(x, y) {\n    return !(x < this.x1 || x > this.x2 || y < this.y1 || y > this.y2);\n  },\n  width() {\n    return this.x2 - this.x1;\n  },\n  height() {\n    return this.y2 - this.y1;\n  }\n};\n\nfunction Item(mark) {\n  this.mark = mark;\n  this.bounds = this.bounds || new Bounds();\n}\n\nfunction GroupItem(mark) {\n  Item.call(this, mark);\n  this.items = this.items || [];\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(GroupItem, Item);\n\nfunction ResourceLoader(customLoader) {\n  this._pending = 0;\n  this._loader = customLoader || (0,vega_loader__WEBPACK_IMPORTED_MODULE_3__.loader)();\n}\nfunction increment(loader) {\n  loader._pending += 1;\n}\nfunction decrement(loader) {\n  loader._pending -= 1;\n}\nResourceLoader.prototype = {\n  pending() {\n    return this._pending;\n  },\n  sanitizeURL(uri) {\n    const loader = this;\n    increment(loader);\n    return loader._loader.sanitize(uri, {\n      context: 'href'\n    }).then(opt => {\n      decrement(loader);\n      return opt;\n    }).catch(() => {\n      decrement(loader);\n      return null;\n    });\n  },\n  loadImage(uri) {\n    const loader = this,\n      Image = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_2__.image)();\n    increment(loader);\n    return loader._loader.sanitize(uri, {\n      context: 'image'\n    }).then(opt => {\n      const url = opt.href;\n      if (!url || !Image) throw {\n        url: url\n      };\n      const img = new Image();\n\n      // set crossOrigin only if cors is defined; empty string sets anonymous mode\n      // https://developer.mozilla.org/en-US/docs/Web/API/HTMLImageElement/crossOrigin\n      const cors = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(opt, 'crossOrigin') ? opt.crossOrigin : 'anonymous';\n      if (cors != null) img.crossOrigin = cors;\n\n      // attempt to load image resource\n      img.onload = () => decrement(loader);\n      img.onerror = () => decrement(loader);\n      img.src = url;\n      return img;\n    }).catch(e => {\n      decrement(loader);\n      return {\n        complete: false,\n        width: 0,\n        height: 0,\n        src: e && e.url || ''\n      };\n    });\n  },\n  ready() {\n    const loader = this;\n    return new Promise(accept => {\n      function poll(value) {\n        if (!loader.pending()) accept(value);else setTimeout(() => {\n          poll(true);\n        }, 10);\n      }\n      poll(false);\n    });\n  }\n};\n\nfunction boundStroke (bounds, item, miter) {\n  if (item.stroke && item.opacity !== 0 && item.strokeOpacity !== 0) {\n    const sw = item.strokeWidth != null ? +item.strokeWidth : 1;\n    bounds.expand(sw + (miter ? miterAdjustment(item, sw) : 0));\n  }\n  return bounds;\n}\nfunction miterAdjustment(item, strokeWidth) {\n  // TODO: more sophisticated adjustment? Or miter support in boundContext?\n  return item.strokeJoin && item.strokeJoin !== 'miter' ? 0 : strokeWidth;\n}\n\nconst circleThreshold = Tau - 1e-8;\nlet bounds, lx, ly, rot, ma, mb, mc, md;\nconst add = (x, y) => bounds.add(x, y);\nconst addL = (x, y) => add(lx = x, ly = y);\nconst addX = x => add(x, bounds.y1);\nconst addY = y => add(bounds.x1, y);\nconst px = (x, y) => ma * x + mc * y;\nconst py = (x, y) => mb * x + md * y;\nconst addp = (x, y) => add(px(x, y), py(x, y));\nconst addpL = (x, y) => addL(px(x, y), py(x, y));\nfunction boundContext (_, deg) {\n  bounds = _;\n  if (deg) {\n    rot = deg * DegToRad;\n    ma = md = Math.cos(rot);\n    mb = Math.sin(rot);\n    mc = -mb;\n  } else {\n    ma = md = 1;\n    rot = mb = mc = 0;\n  }\n  return context$1;\n}\nconst context$1 = {\n  beginPath() {},\n  closePath() {},\n  moveTo: addpL,\n  lineTo: addpL,\n  rect(x, y, w, h) {\n    if (rot) {\n      addp(x + w, y);\n      addp(x + w, y + h);\n      addp(x, y + h);\n      addpL(x, y);\n    } else {\n      add(x + w, y + h);\n      addL(x, y);\n    }\n  },\n  quadraticCurveTo(x1, y1, x2, y2) {\n    const px1 = px(x1, y1),\n      py1 = py(x1, y1),\n      px2 = px(x2, y2),\n      py2 = py(x2, y2);\n    quadExtrema(lx, px1, px2, addX);\n    quadExtrema(ly, py1, py2, addY);\n    addL(px2, py2);\n  },\n  bezierCurveTo(x1, y1, x2, y2, x3, y3) {\n    const px1 = px(x1, y1),\n      py1 = py(x1, y1),\n      px2 = px(x2, y2),\n      py2 = py(x2, y2),\n      px3 = px(x3, y3),\n      py3 = py(x3, y3);\n    cubicExtrema(lx, px1, px2, px3, addX);\n    cubicExtrema(ly, py1, py2, py3, addY);\n    addL(px3, py3);\n  },\n  arc(cx, cy, r, sa, ea, ccw) {\n    sa += rot;\n    ea += rot;\n\n    // store last point on path\n    lx = r * Math.cos(ea) + cx;\n    ly = r * Math.sin(ea) + cy;\n    if (Math.abs(ea - sa) > circleThreshold) {\n      // treat as full circle\n      add(cx - r, cy - r);\n      add(cx + r, cy + r);\n    } else {\n      const update = a => add(r * Math.cos(a) + cx, r * Math.sin(a) + cy);\n      let s, i;\n\n      // sample end points\n      update(sa);\n      update(ea);\n\n      // sample interior points aligned with 90 degrees\n      if (ea !== sa) {\n        sa = sa % Tau;\n        if (sa < 0) sa += Tau;\n        ea = ea % Tau;\n        if (ea < 0) ea += Tau;\n        if (ea < sa) {\n          ccw = !ccw; // flip direction\n          s = sa;\n          sa = ea;\n          ea = s; // swap end-points\n        }\n\n        if (ccw) {\n          ea -= Tau;\n          s = sa - sa % HalfPi;\n          for (i = 0; i < 4 && s > ea; ++i, s -= HalfPi) update(s);\n        } else {\n          s = sa - sa % HalfPi + HalfPi;\n          for (i = 0; i < 4 && s < ea; ++i, s = s + HalfPi) update(s);\n        }\n      }\n    }\n  }\n};\nfunction quadExtrema(x0, x1, x2, cb) {\n  const t = (x0 - x1) / (x0 + x2 - 2 * x1);\n  if (0 < t && t < 1) cb(x0 + (x1 - x0) * t);\n}\nfunction cubicExtrema(x0, x1, x2, x3, cb) {\n  const a = x3 - x0 + 3 * x1 - 3 * x2,\n    b = x0 + x2 - 2 * x1,\n    c = x0 - x1;\n  let t0 = 0,\n    t1 = 0,\n    r;\n\n  // solve for parameter t\n  if (Math.abs(a) > Epsilon) {\n    // quadratic equation\n    r = b * b + c * a;\n    if (r >= 0) {\n      r = Math.sqrt(r);\n      t0 = (-b + r) / a;\n      t1 = (-b - r) / a;\n    }\n  } else {\n    // linear equation\n    t0 = 0.5 * c / b;\n  }\n\n  // calculate position\n  if (0 < t0 && t0 < 1) cb(cubic(t0, x0, x1, x2, x3));\n  if (0 < t1 && t1 < 1) cb(cubic(t1, x0, x1, x2, x3));\n}\nfunction cubic(t, x0, x1, x2, x3) {\n  const s = 1 - t,\n    s2 = s * s,\n    t2 = t * t;\n  return s2 * s * x0 + 3 * s2 * t * x1 + 3 * s * t2 * x2 + t2 * t * x3;\n}\n\nvar context = (context = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_2__.canvas)(1, 1)) ? context.getContext('2d') : null;\n\nconst b = new Bounds();\nfunction intersectPath(draw) {\n  return function (item, brush) {\n    // rely on (inaccurate) bounds intersection if no context\n    if (!context) return true;\n\n    // add path to offscreen graphics context\n    draw(context, item);\n\n    // get bounds intersection region\n    b.clear().union(item.bounds).intersect(brush).round();\n    const {\n      x1,\n      y1,\n      x2,\n      y2\n    } = b;\n\n    // iterate over intersection region\n    // perform fine grained inclusion test\n    for (let y = y1; y <= y2; ++y) {\n      for (let x = x1; x <= x2; ++x) {\n        if (context.isPointInPath(x, y)) {\n          return true;\n        }\n      }\n    }\n\n    // false if no hits in intersection region\n    return false;\n  };\n}\nfunction intersectPoint(item, box) {\n  return box.contains(item.x || 0, item.y || 0);\n}\nfunction intersectRect(item, box) {\n  const x = item.x || 0,\n    y = item.y || 0,\n    w = item.width || 0,\n    h = item.height || 0;\n  return box.intersects(b.set(x, y, x + w, y + h));\n}\nfunction intersectRule(item, box) {\n  const x = item.x || 0,\n    y = item.y || 0,\n    x2 = item.x2 != null ? item.x2 : x,\n    y2 = item.y2 != null ? item.y2 : y;\n  return intersectBoxLine(box, x, y, x2, y2);\n}\nfunction intersectBoxLine(box, x, y, u, v) {\n  const {\n      x1,\n      y1,\n      x2,\n      y2\n    } = box,\n    dx = u - x,\n    dy = v - y;\n  let t0 = 0,\n    t1 = 1,\n    p,\n    q,\n    r,\n    e;\n  for (e = 0; e < 4; ++e) {\n    if (e === 0) {\n      p = -dx;\n      q = -(x1 - x);\n    }\n    if (e === 1) {\n      p = dx;\n      q = x2 - x;\n    }\n    if (e === 2) {\n      p = -dy;\n      q = -(y1 - y);\n    }\n    if (e === 3) {\n      p = dy;\n      q = y2 - y;\n    }\n    if (Math.abs(p) < 1e-10 && q < 0) return false;\n    r = q / p;\n    if (p < 0) {\n      if (r > t1) return false;else if (r > t0) t0 = r;\n    } else if (p > 0) {\n      if (r < t0) return false;else if (r < t1) t1 = r;\n    }\n  }\n  return true;\n}\n\nfunction blend (context, item) {\n  context.globalCompositeOperation = item.blend || 'source-over';\n}\n\nfunction value (value, dflt) {\n  return value == null ? dflt : value;\n}\n\nfunction addStops(gradient, stops) {\n  const n = stops.length;\n  for (let i = 0; i < n; ++i) {\n    gradient.addColorStop(stops[i].offset, stops[i].color);\n  }\n  return gradient;\n}\nfunction gradient (context, spec, bounds) {\n  const w = bounds.width(),\n    h = bounds.height();\n  let gradient;\n  if (spec.gradient === 'radial') {\n    gradient = context.createRadialGradient(bounds.x1 + value(spec.x1, 0.5) * w, bounds.y1 + value(spec.y1, 0.5) * h, Math.max(w, h) * value(spec.r1, 0), bounds.x1 + value(spec.x2, 0.5) * w, bounds.y1 + value(spec.y2, 0.5) * h, Math.max(w, h) * value(spec.r2, 0.5));\n  } else {\n    // linear gradient\n    const x1 = value(spec.x1, 0),\n      y1 = value(spec.y1, 0),\n      x2 = value(spec.x2, 1),\n      y2 = value(spec.y2, 0);\n    if (x1 === x2 || y1 === y2 || w === h) {\n      // axis aligned: use normal gradient\n      gradient = context.createLinearGradient(bounds.x1 + x1 * w, bounds.y1 + y1 * h, bounds.x1 + x2 * w, bounds.y1 + y2 * h);\n    } else {\n      // not axis aligned: render gradient into a pattern (#2365)\n      // this allows us to use normalized bounding box coordinates\n      const image = (0,vega_canvas__WEBPACK_IMPORTED_MODULE_2__.canvas)(Math.ceil(w), Math.ceil(h)),\n        ictx = image.getContext('2d');\n      ictx.scale(w, h);\n      ictx.fillStyle = addStops(ictx.createLinearGradient(x1, y1, x2, y2), spec.stops);\n      ictx.fillRect(0, 0, w, h);\n      return context.createPattern(image, 'no-repeat');\n    }\n  }\n  return addStops(gradient, spec.stops);\n}\n\nfunction color (context, item, value) {\n  return isGradient(value) ? gradient(context, value, item.bounds) : value;\n}\n\nfunction fill (context, item, opacity) {\n  opacity *= item.fillOpacity == null ? 1 : item.fillOpacity;\n  if (opacity > 0) {\n    context.globalAlpha = opacity;\n    context.fillStyle = color(context, item, item.fill);\n    return true;\n  } else {\n    return false;\n  }\n}\n\nvar Empty = [];\nfunction stroke (context, item, opacity) {\n  var lw = (lw = item.strokeWidth) != null ? lw : 1;\n  if (lw <= 0) return false;\n  opacity *= item.strokeOpacity == null ? 1 : item.strokeOpacity;\n  if (opacity > 0) {\n    context.globalAlpha = opacity;\n    context.strokeStyle = color(context, item, item.stroke);\n    context.lineWidth = lw;\n    context.lineCap = item.strokeCap || 'butt';\n    context.lineJoin = item.strokeJoin || 'miter';\n    context.miterLimit = item.strokeMiterLimit || 10;\n    if (context.setLineDash) {\n      context.setLineDash(item.strokeDash || Empty);\n      context.lineDashOffset = item.strokeDashOffset || 0;\n    }\n    return true;\n  } else {\n    return false;\n  }\n}\n\nfunction compare(a, b) {\n  return a.zindex - b.zindex || a.index - b.index;\n}\nfunction zorder(scene) {\n  if (!scene.zdirty) return scene.zitems;\n  var items = scene.items,\n    output = [],\n    item,\n    i,\n    n;\n  for (i = 0, n = items.length; i < n; ++i) {\n    item = items[i];\n    item.index = i;\n    if (item.zindex) output.push(item);\n  }\n  scene.zdirty = false;\n  return scene.zitems = output.sort(compare);\n}\nfunction visit(scene, visitor) {\n  var items = scene.items,\n    i,\n    n;\n  if (!items || !items.length) return;\n  const zitems = zorder(scene);\n  if (zitems && zitems.length) {\n    for (i = 0, n = items.length; i < n; ++i) {\n      if (!items[i].zindex) visitor(items[i]);\n    }\n    items = zitems;\n  }\n  for (i = 0, n = items.length; i < n; ++i) {\n    visitor(items[i]);\n  }\n}\nfunction pickVisit(scene, visitor) {\n  var items = scene.items,\n    hit,\n    i;\n  if (!items || !items.length) return null;\n  const zitems = zorder(scene);\n  if (zitems && zitems.length) items = zitems;\n  for (i = items.length; --i >= 0;) {\n    if (hit = visitor(items[i])) return hit;\n  }\n  if (items === zitems) {\n    for (items = scene.items, i = items.length; --i >= 0;) {\n      if (!items[i].zindex) {\n        if (hit = visitor(items[i])) return hit;\n      }\n    }\n  }\n  return null;\n}\n\nfunction drawAll(path) {\n  return function (context, scene, bounds) {\n    visit(scene, item => {\n      if (!bounds || bounds.intersects(item.bounds)) {\n        drawPath(path, context, item, item);\n      }\n    });\n  };\n}\nfunction drawOne(path) {\n  return function (context, scene, bounds) {\n    if (scene.items.length && (!bounds || bounds.intersects(scene.bounds))) {\n      drawPath(path, context, scene.items[0], scene.items);\n    }\n  };\n}\nfunction drawPath(path, context, item, items) {\n  var opacity = item.opacity == null ? 1 : item.opacity;\n  if (opacity === 0) return;\n  if (path(context, items)) return;\n  blend(context, item);\n  if (item.fill && fill(context, item, opacity)) {\n    context.fill();\n  }\n  if (item.stroke && stroke(context, item, opacity)) {\n    context.stroke();\n  }\n}\n\nfunction pick$1(test) {\n  test = test || vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy;\n  return function (context, scene, x, y, gx, gy) {\n    x *= context.pixelRatio;\n    y *= context.pixelRatio;\n    return pickVisit(scene, item => {\n      const b = item.bounds;\n      // first hit test against bounding box\n      if (b && !b.contains(gx, gy) || !b) return;\n      // if in bounding box, perform more careful test\n      if (test(context, item, x, y, gx, gy)) return item;\n    });\n  };\n}\nfunction hitPath(path, filled) {\n  return function (context, o, x, y) {\n    var item = Array.isArray(o) ? o[0] : o,\n      fill = filled == null ? item.fill : filled,\n      stroke = item.stroke && context.isPointInStroke,\n      lw,\n      lc;\n    if (stroke) {\n      lw = item.strokeWidth;\n      lc = item.strokeCap;\n      context.lineWidth = lw != null ? lw : 1;\n      context.lineCap = lc != null ? lc : 'butt';\n    }\n    return path(context, o) ? false : fill && context.isPointInPath(x, y) || stroke && context.isPointInStroke(x, y);\n  };\n}\nfunction pickPath(path) {\n  return pick$1(hitPath(path));\n}\n\nfunction translate(x, y) {\n  return 'translate(' + x + ',' + y + ')';\n}\nfunction rotate(a) {\n  return 'rotate(' + a + ')';\n}\nfunction scale(scaleX, scaleY) {\n  return 'scale(' + scaleX + ',' + scaleY + ')';\n}\nfunction translateItem(item) {\n  return translate(item.x || 0, item.y || 0);\n}\nfunction rotateItem(item) {\n  return translate(item.x || 0, item.y || 0) + (item.angle ? ' ' + rotate(item.angle) : '');\n}\nfunction transformItem(item) {\n  return translate(item.x || 0, item.y || 0) + (item.angle ? ' ' + rotate(item.angle) : '') + (item.scaleX || item.scaleY ? ' ' + scale(item.scaleX || 1, item.scaleY || 1) : '');\n}\n\nfunction markItemPath (type, shape, isect) {\n  function attr(emit, item) {\n    emit('transform', rotateItem(item));\n    emit('d', shape(null, item));\n  }\n  function bound(bounds, item) {\n    shape(boundContext(bounds, item.angle), item);\n    return boundStroke(bounds, item).translate(item.x || 0, item.y || 0);\n  }\n  function draw(context, item) {\n    var x = item.x || 0,\n      y = item.y || 0,\n      a = item.angle || 0;\n    context.translate(x, y);\n    if (a) context.rotate(a *= DegToRad);\n    context.beginPath();\n    shape(context, item);\n    if (a) context.rotate(-a);\n    context.translate(-x, -y);\n  }\n  return {\n    type: type,\n    tag: 'path',\n    nested: false,\n    attr: attr,\n    bound: bound,\n    draw: drawAll(draw),\n    pick: pickPath(draw),\n    isect: isect || intersectPath(draw)\n  };\n}\n\nvar arc = markItemPath('arc', arc$1);\n\nfunction pickArea(a, p) {\n  var v = a[0].orient === 'horizontal' ? p[1] : p[0],\n    z = a[0].orient === 'horizontal' ? 'y' : 'x',\n    i = a.length,\n    min = +Infinity,\n    hit,\n    d;\n  while (--i >= 0) {\n    if (a[i].defined === false) continue;\n    d = Math.abs(a[i][z] - v);\n    if (d < min) {\n      min = d;\n      hit = a[i];\n    }\n  }\n  return hit;\n}\nfunction pickLine(a, p) {\n  var t = Math.pow(a[0].strokeWidth || 1, 2),\n    i = a.length,\n    dx,\n    dy,\n    dd;\n  while (--i >= 0) {\n    if (a[i].defined === false) continue;\n    dx = a[i].x - p[0];\n    dy = a[i].y - p[1];\n    dd = dx * dx + dy * dy;\n    if (dd < t) return a[i];\n  }\n  return null;\n}\nfunction pickTrail(a, p) {\n  var i = a.length,\n    dx,\n    dy,\n    dd;\n  while (--i >= 0) {\n    if (a[i].defined === false) continue;\n    dx = a[i].x - p[0];\n    dy = a[i].y - p[1];\n    dd = dx * dx + dy * dy;\n    dx = a[i].size || 1;\n    if (dd < dx * dx) return a[i];\n  }\n  return null;\n}\n\nfunction markMultiItemPath (type, shape, tip) {\n  function attr(emit, item) {\n    var items = item.mark.items;\n    if (items.length) emit('d', shape(null, items));\n  }\n  function bound(bounds, mark) {\n    var items = mark.items;\n    if (items.length === 0) {\n      return bounds;\n    } else {\n      shape(boundContext(bounds), items);\n      return boundStroke(bounds, items[0]);\n    }\n  }\n  function draw(context, items) {\n    context.beginPath();\n    shape(context, items);\n  }\n  const hit = hitPath(draw);\n  function pick(context, scene, x, y, gx, gy) {\n    var items = scene.items,\n      b = scene.bounds;\n    if (!items || !items.length || b && !b.contains(gx, gy)) {\n      return null;\n    }\n    x *= context.pixelRatio;\n    y *= context.pixelRatio;\n    return hit(context, items, x, y) ? items[0] : null;\n  }\n  return {\n    type: type,\n    tag: 'path',\n    nested: true,\n    attr: attr,\n    bound: bound,\n    draw: drawOne(draw),\n    pick: pick,\n    isect: intersectPoint,\n    tip: tip\n  };\n}\n\nvar area = markMultiItemPath('area', area$1, pickArea);\n\nfunction clip (context, scene) {\n  var clip = scene.clip;\n  context.save();\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(clip)) {\n    context.beginPath();\n    clip(context);\n    context.clip();\n  } else {\n    clipGroup(context, scene.group);\n  }\n}\nfunction clipGroup(context, group) {\n  context.beginPath();\n  hasCornerRadius(group) ? rectangle(context, group, 0, 0) : context.rect(0, 0, group.width || 0, group.height || 0);\n  context.clip();\n}\n\nfunction offset$1(item) {\n  const sw = value(item.strokeWidth, 1);\n  return item.strokeOffset != null ? item.strokeOffset : item.stroke && sw > 0.5 && sw < 1.5 ? 0.5 - Math.abs(sw - 1) : 0;\n}\nfunction attr$5(emit, item) {\n  emit('transform', translateItem(item));\n}\nfunction emitRectangle(emit, item) {\n  const off = offset$1(item);\n  emit('d', rectangle(null, item, off, off));\n}\nfunction background(emit, item) {\n  emit('class', 'background');\n  emit('aria-hidden', true);\n  emitRectangle(emit, item);\n}\nfunction foreground(emit, item) {\n  emit('class', 'foreground');\n  emit('aria-hidden', true);\n  if (item.strokeForeground) {\n    emitRectangle(emit, item);\n  } else {\n    emit('d', '');\n  }\n}\nfunction content(emit, item, renderer) {\n  const url = item.clip ? clip$1(renderer, item, item) : null;\n  emit('clip-path', url);\n}\nfunction bound$5(bounds, group) {\n  if (!group.clip && group.items) {\n    const items = group.items,\n      m = items.length;\n    for (let j = 0; j < m; ++j) {\n      bounds.union(items[j].bounds);\n    }\n  }\n  if ((group.clip || group.width || group.height) && !group.noBound) {\n    bounds.add(0, 0).add(group.width || 0, group.height || 0);\n  }\n  boundStroke(bounds, group);\n  return bounds.translate(group.x || 0, group.y || 0);\n}\nfunction rectanglePath(context, group, x, y) {\n  const off = offset$1(group);\n  context.beginPath();\n  rectangle(context, group, (x || 0) + off, (y || 0) + off);\n}\nconst hitBackground = hitPath(rectanglePath);\nconst hitForeground = hitPath(rectanglePath, false);\nconst hitCorner = hitPath(rectanglePath, true);\nfunction draw$4(context, scene, bounds) {\n  visit(scene, group => {\n    const gx = group.x || 0,\n      gy = group.y || 0,\n      fore = group.strokeForeground,\n      opacity = group.opacity == null ? 1 : group.opacity;\n\n    // draw group background\n    if ((group.stroke || group.fill) && opacity) {\n      rectanglePath(context, group, gx, gy);\n      blend(context, group);\n      if (group.fill && fill(context, group, opacity)) {\n        context.fill();\n      }\n      if (group.stroke && !fore && stroke(context, group, opacity)) {\n        context.stroke();\n      }\n    }\n\n    // setup graphics context, set clip and bounds\n    context.save();\n    context.translate(gx, gy);\n    if (group.clip) clipGroup(context, group);\n    if (bounds) bounds.translate(-gx, -gy);\n\n    // draw group contents\n    visit(group, item => {\n      this.draw(context, item, bounds);\n    });\n\n    // restore graphics context\n    if (bounds) bounds.translate(gx, gy);\n    context.restore();\n\n    // draw group foreground\n    if (fore && group.stroke && opacity) {\n      rectanglePath(context, group, gx, gy);\n      blend(context, group);\n      if (stroke(context, group, opacity)) {\n        context.stroke();\n      }\n    }\n  });\n}\nfunction pick(context, scene, x, y, gx, gy) {\n  if (scene.bounds && !scene.bounds.contains(gx, gy) || !scene.items) {\n    return null;\n  }\n  const cx = x * context.pixelRatio,\n    cy = y * context.pixelRatio;\n  return pickVisit(scene, group => {\n    let hit, dx, dy;\n\n    // first hit test bounding box\n    const b = group.bounds;\n    if (b && !b.contains(gx, gy)) return;\n\n    // passed bounds check, test rectangular clip\n    dx = group.x || 0;\n    dy = group.y || 0;\n    const dw = dx + (group.width || 0),\n      dh = dy + (group.height || 0),\n      c = group.clip;\n    if (c && (gx < dx || gx > dw || gy < dy || gy > dh)) return;\n\n    // adjust coordinate system\n    context.save();\n    context.translate(dx, dy);\n    dx = gx - dx;\n    dy = gy - dy;\n\n    // test background for rounded corner clip\n    if (c && hasCornerRadius(group) && !hitCorner(context, group, cx, cy)) {\n      context.restore();\n      return null;\n    }\n    const fore = group.strokeForeground,\n      ix = scene.interactive !== false;\n\n    // hit test against group foreground\n    if (ix && fore && group.stroke && hitForeground(context, group, cx, cy)) {\n      context.restore();\n      return group;\n    }\n\n    // hit test against contained marks\n    hit = pickVisit(group, mark => pickMark(mark, dx, dy) ? this.pick(mark, x, y, dx, dy) : null);\n\n    // hit test against group background\n    if (!hit && ix && (group.fill || !fore && group.stroke) && hitBackground(context, group, cx, cy)) {\n      hit = group;\n    }\n\n    // restore state and return\n    context.restore();\n    return hit || null;\n  });\n}\nfunction pickMark(mark, x, y) {\n  return (mark.interactive !== false || mark.marktype === 'group') && mark.bounds && mark.bounds.contains(x, y);\n}\nvar group = {\n  type: 'group',\n  tag: 'g',\n  nested: false,\n  attr: attr$5,\n  bound: bound$5,\n  draw: draw$4,\n  pick: pick,\n  isect: intersectRect,\n  content: content,\n  background: background,\n  foreground: foreground\n};\n\nvar metadata = {\n  'xmlns': 'http://www.w3.org/2000/svg',\n  'xmlns:xlink': 'http://www.w3.org/1999/xlink',\n  'version': '1.1'\n};\n\nfunction getImage(item, renderer) {\n  var image = item.image;\n  if (!image || item.url && item.url !== image.url) {\n    image = {\n      complete: false,\n      width: 0,\n      height: 0\n    };\n    renderer.loadImage(item.url).then(image => {\n      item.image = image;\n      item.image.url = item.url;\n    });\n  }\n  return image;\n}\nfunction imageWidth(item, image) {\n  return item.width != null ? item.width : !image || !image.width ? 0 : item.aspect !== false && item.height ? item.height * image.width / image.height : image.width;\n}\nfunction imageHeight(item, image) {\n  return item.height != null ? item.height : !image || !image.height ? 0 : item.aspect !== false && item.width ? item.width * image.height / image.width : image.height;\n}\nfunction imageXOffset(align, w) {\n  return align === 'center' ? w / 2 : align === 'right' ? w : 0;\n}\nfunction imageYOffset(baseline, h) {\n  return baseline === 'middle' ? h / 2 : baseline === 'bottom' ? h : 0;\n}\nfunction attr$4(emit, item, renderer) {\n  const img = getImage(item, renderer),\n    w = imageWidth(item, img),\n    h = imageHeight(item, img),\n    x = (item.x || 0) - imageXOffset(item.align, w),\n    y = (item.y || 0) - imageYOffset(item.baseline, h),\n    i = !img.src && img.toDataURL ? img.toDataURL() : img.src || '';\n  emit('href', i, metadata['xmlns:xlink'], 'xlink:href');\n  emit('transform', translate(x, y));\n  emit('width', w);\n  emit('height', h);\n  emit('preserveAspectRatio', item.aspect === false ? 'none' : 'xMidYMid');\n}\nfunction bound$4(bounds, item) {\n  const img = item.image,\n    w = imageWidth(item, img),\n    h = imageHeight(item, img),\n    x = (item.x || 0) - imageXOffset(item.align, w),\n    y = (item.y || 0) - imageYOffset(item.baseline, h);\n  return bounds.set(x, y, x + w, y + h);\n}\nfunction draw$3(context, scene, bounds) {\n  visit(scene, item => {\n    if (bounds && !bounds.intersects(item.bounds)) return; // bounds check\n\n    const img = getImage(item, this);\n    let w = imageWidth(item, img);\n    let h = imageHeight(item, img);\n    if (w === 0 || h === 0) return; // early exit\n\n    let x = (item.x || 0) - imageXOffset(item.align, w),\n      y = (item.y || 0) - imageYOffset(item.baseline, h),\n      opacity,\n      ar0,\n      ar1,\n      t;\n    if (item.aspect !== false) {\n      ar0 = img.width / img.height;\n      ar1 = item.width / item.height;\n      if (ar0 === ar0 && ar1 === ar1 && ar0 !== ar1) {\n        if (ar1 < ar0) {\n          t = w / ar0;\n          y += (h - t) / 2;\n          h = t;\n        } else {\n          t = h * ar0;\n          x += (w - t) / 2;\n          w = t;\n        }\n      }\n    }\n    if (img.complete || img.toDataURL) {\n      blend(context, item);\n      context.globalAlpha = (opacity = item.opacity) != null ? opacity : 1;\n      context.imageSmoothingEnabled = item.smooth !== false;\n      context.drawImage(img, x, y, w, h);\n    }\n  });\n}\nvar image = {\n  type: 'image',\n  tag: 'image',\n  nested: false,\n  attr: attr$4,\n  bound: bound$4,\n  draw: draw$3,\n  pick: pick$1(),\n  isect: vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy,\n  // bounds check is sufficient\n  get: getImage,\n  xOffset: imageXOffset,\n  yOffset: imageYOffset\n};\n\nvar line = markMultiItemPath('line', line$1, pickLine);\n\nfunction attr$3(emit, item) {\n  var sx = item.scaleX || 1,\n    sy = item.scaleY || 1;\n  if (sx !== 1 || sy !== 1) {\n    emit('vector-effect', 'non-scaling-stroke');\n  }\n  emit('transform', transformItem(item));\n  emit('d', item.path);\n}\nfunction path$1(context, item) {\n  var path = item.path;\n  if (path == null) return true;\n  var x = item.x || 0,\n    y = item.y || 0,\n    sx = item.scaleX || 1,\n    sy = item.scaleY || 1,\n    a = (item.angle || 0) * DegToRad,\n    cache = item.pathCache;\n  if (!cache || cache.path !== path) {\n    (item.pathCache = cache = parse(path)).path = path;\n  }\n  if (a && context.rotate && context.translate) {\n    context.translate(x, y);\n    context.rotate(a);\n    pathRender(context, cache, 0, 0, sx, sy);\n    context.rotate(-a);\n    context.translate(-x, -y);\n  } else {\n    pathRender(context, cache, x, y, sx, sy);\n  }\n}\nfunction bound$3(bounds, item) {\n  return path$1(boundContext(bounds, item.angle), item) ? bounds.set(0, 0, 0, 0) : boundStroke(bounds, item, true);\n}\nvar path$2 = {\n  type: 'path',\n  tag: 'path',\n  nested: false,\n  attr: attr$3,\n  bound: bound$3,\n  draw: drawAll(path$1),\n  pick: pickPath(path$1),\n  isect: intersectPath(path$1)\n};\n\nfunction attr$2(emit, item) {\n  emit('d', rectangle(null, item));\n}\nfunction bound$2(bounds, item) {\n  var x, y;\n  return boundStroke(bounds.set(x = item.x || 0, y = item.y || 0, x + item.width || 0, y + item.height || 0), item);\n}\nfunction draw$2(context, item) {\n  context.beginPath();\n  rectangle(context, item);\n}\nvar rect = {\n  type: 'rect',\n  tag: 'path',\n  nested: false,\n  attr: attr$2,\n  bound: bound$2,\n  draw: drawAll(draw$2),\n  pick: pickPath(draw$2),\n  isect: intersectRect\n};\n\nfunction attr$1(emit, item) {\n  emit('transform', translateItem(item));\n  emit('x2', item.x2 != null ? item.x2 - (item.x || 0) : 0);\n  emit('y2', item.y2 != null ? item.y2 - (item.y || 0) : 0);\n}\nfunction bound$1(bounds, item) {\n  var x1, y1;\n  return boundStroke(bounds.set(x1 = item.x || 0, y1 = item.y || 0, item.x2 != null ? item.x2 : x1, item.y2 != null ? item.y2 : y1), item);\n}\nfunction path(context, item, opacity) {\n  var x1, y1, x2, y2;\n  if (item.stroke && stroke(context, item, opacity)) {\n    x1 = item.x || 0;\n    y1 = item.y || 0;\n    x2 = item.x2 != null ? item.x2 : x1;\n    y2 = item.y2 != null ? item.y2 : y1;\n    context.beginPath();\n    context.moveTo(x1, y1);\n    context.lineTo(x2, y2);\n    return true;\n  }\n  return false;\n}\nfunction draw$1(context, scene, bounds) {\n  visit(scene, item => {\n    if (bounds && !bounds.intersects(item.bounds)) return; // bounds check\n    var opacity = item.opacity == null ? 1 : item.opacity;\n    if (opacity && path(context, item, opacity)) {\n      blend(context, item);\n      context.stroke();\n    }\n  });\n}\nfunction hit$1(context, item, x, y) {\n  if (!context.isPointInStroke) return false;\n  return path(context, item, 1) && context.isPointInStroke(x, y);\n}\nvar rule = {\n  type: 'rule',\n  tag: 'line',\n  nested: false,\n  attr: attr$1,\n  bound: bound$1,\n  draw: draw$1,\n  pick: pick$1(hit$1),\n  isect: intersectRule\n};\n\nvar shape = markItemPath('shape', shape$1);\n\nvar symbol = markItemPath('symbol', symbol$1, intersectPoint);\n\n// memoize text width measurement\nconst widthCache = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.lruCache)();\nvar textMetrics = {\n  height: fontSize,\n  measureWidth: measureWidth,\n  estimateWidth: estimateWidth,\n  width: estimateWidth,\n  canvas: useCanvas\n};\nuseCanvas(true);\nfunction useCanvas(use) {\n  textMetrics.width = use && context ? measureWidth : estimateWidth;\n}\n\n// make simple estimate if no canvas is available\nfunction estimateWidth(item, text) {\n  return _estimateWidth(textValue(item, text), fontSize(item));\n}\nfunction _estimateWidth(text, currentFontHeight) {\n  return ~~(0.8 * text.length * currentFontHeight);\n}\n\n// measure text width if canvas is available\nfunction measureWidth(item, text) {\n  return fontSize(item) <= 0 || !(text = textValue(item, text)) ? 0 : _measureWidth(text, font(item));\n}\nfunction _measureWidth(text, currentFont) {\n  const key = `(${currentFont}) ${text}`;\n  let width = widthCache.get(key);\n  if (width === undefined) {\n    context.font = currentFont;\n    width = context.measureText(text).width;\n    widthCache.set(key, width);\n  }\n  return width;\n}\nfunction fontSize(item) {\n  return item.fontSize != null ? +item.fontSize || 0 : 11;\n}\nfunction lineHeight(item) {\n  return item.lineHeight != null ? item.lineHeight : fontSize(item) + 2;\n}\nfunction lineArray(_) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_) ? _.length > 1 ? _ : _[0] : _;\n}\nfunction textLines(item) {\n  return lineArray(item.lineBreak && item.text && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(item.text) ? item.text.split(item.lineBreak) : item.text);\n}\nfunction multiLineOffset(item) {\n  const tl = textLines(item);\n  return ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tl) ? tl.length - 1 : 0) * lineHeight(item);\n}\nfunction textValue(item, line) {\n  const text = line == null ? '' : (line + '').trim();\n  return item.limit > 0 && text.length ? truncate(item, text) : text;\n}\nfunction widthGetter(item) {\n  if (textMetrics.width === measureWidth) {\n    // we are using canvas\n    const currentFont = font(item);\n    return text => _measureWidth(text, currentFont);\n  } else {\n    // we are relying on estimates\n    const currentFontHeight = fontSize(item);\n    return text => _estimateWidth(text, currentFontHeight);\n  }\n}\nfunction truncate(item, text) {\n  var limit = +item.limit,\n    width = widthGetter(item);\n  if (width(text) < limit) return text;\n  var ellipsis = item.ellipsis || '\\u2026',\n    rtl = item.dir === 'rtl',\n    lo = 0,\n    hi = text.length,\n    mid;\n  limit -= width(ellipsis);\n  if (rtl) {\n    while (lo < hi) {\n      mid = lo + hi >>> 1;\n      if (width(text.slice(mid)) > limit) lo = mid + 1;else hi = mid;\n    }\n    return ellipsis + text.slice(lo);\n  } else {\n    while (lo < hi) {\n      mid = 1 + (lo + hi >>> 1);\n      if (width(text.slice(0, mid)) < limit) lo = mid;else hi = mid - 1;\n    }\n    return text.slice(0, lo) + ellipsis;\n  }\n}\nfunction fontFamily(item, quote) {\n  var font = item.font;\n  return (quote && font ? String(font).replace(/\"/g, '\\'') : font) || 'sans-serif';\n}\nfunction font(item, quote) {\n  return '' + (item.fontStyle ? item.fontStyle + ' ' : '') + (item.fontVariant ? item.fontVariant + ' ' : '') + (item.fontWeight ? item.fontWeight + ' ' : '') + fontSize(item) + 'px ' + fontFamily(item, quote);\n}\nfunction offset(item) {\n  // perform our own font baseline calculation\n  // why? not all browsers support SVG 1.1 'alignment-baseline' :(\n  // this also ensures consistent layout across renderers\n  var baseline = item.baseline,\n    h = fontSize(item);\n  return Math.round(baseline === 'top' ? 0.79 * h : baseline === 'middle' ? 0.30 * h : baseline === 'bottom' ? -0.21 * h : baseline === 'line-top' ? 0.29 * h + 0.5 * lineHeight(item) : baseline === 'line-bottom' ? 0.29 * h - 0.5 * lineHeight(item) : 0);\n}\n\nconst textAlign = {\n  'left': 'start',\n  'center': 'middle',\n  'right': 'end'\n};\nconst tempBounds = new Bounds();\nfunction anchorPoint(item) {\n  var x = item.x || 0,\n    y = item.y || 0,\n    r = item.radius || 0,\n    t;\n  if (r) {\n    t = (item.theta || 0) - HalfPi;\n    x += r * Math.cos(t);\n    y += r * Math.sin(t);\n  }\n  tempBounds.x1 = x;\n  tempBounds.y1 = y;\n  return tempBounds;\n}\nfunction attr(emit, item) {\n  var dx = item.dx || 0,\n    dy = (item.dy || 0) + offset(item),\n    p = anchorPoint(item),\n    x = p.x1,\n    y = p.y1,\n    a = item.angle || 0,\n    t;\n  emit('text-anchor', textAlign[item.align] || 'start');\n  if (a) {\n    t = translate(x, y) + ' ' + rotate(a);\n    if (dx || dy) t += ' ' + translate(dx, dy);\n  } else {\n    t = translate(x + dx, y + dy);\n  }\n  emit('transform', t);\n}\nfunction bound(bounds, item, mode) {\n  var h = textMetrics.height(item),\n    a = item.align,\n    p = anchorPoint(item),\n    x = p.x1,\n    y = p.y1,\n    dx = item.dx || 0,\n    dy = (item.dy || 0) + offset(item) - Math.round(0.8 * h),\n    // use 4/5 offset\n    tl = textLines(item),\n    w;\n\n  // get dimensions\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tl)) {\n    // multi-line text\n    h += lineHeight(item) * (tl.length - 1);\n    w = tl.reduce((w, t) => Math.max(w, textMetrics.width(item, t)), 0);\n  } else {\n    // single-line text\n    w = textMetrics.width(item, tl);\n  }\n\n  // horizontal alignment\n  if (a === 'center') {\n    dx -= w / 2;\n  } else if (a === 'right') {\n    dx -= w;\n  } else ;\n  bounds.set(dx += x, dy += y, dx + w, dy + h);\n  if (item.angle && !mode) {\n    bounds.rotate(item.angle * DegToRad, x, y);\n  } else if (mode === 2) {\n    return bounds.rotatedPoints(item.angle * DegToRad, x, y);\n  }\n  return bounds;\n}\nfunction draw(context, scene, bounds) {\n  visit(scene, item => {\n    var opacity = item.opacity == null ? 1 : item.opacity,\n      p,\n      x,\n      y,\n      i,\n      lh,\n      tl,\n      str;\n    if (bounds && !bounds.intersects(item.bounds) ||\n    // bounds check\n    opacity === 0 || item.fontSize <= 0 || item.text == null || item.text.length === 0) return;\n    context.font = font(item);\n    context.textAlign = item.align || 'left';\n    p = anchorPoint(item);\n    x = p.x1, y = p.y1;\n    if (item.angle) {\n      context.save();\n      context.translate(x, y);\n      context.rotate(item.angle * DegToRad);\n      x = y = 0; // reset x, y\n    }\n\n    x += item.dx || 0;\n    y += (item.dy || 0) + offset(item);\n    tl = textLines(item);\n    blend(context, item);\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tl)) {\n      lh = lineHeight(item);\n      for (i = 0; i < tl.length; ++i) {\n        str = textValue(item, tl[i]);\n        if (item.fill && fill(context, item, opacity)) {\n          context.fillText(str, x, y);\n        }\n        if (item.stroke && stroke(context, item, opacity)) {\n          context.strokeText(str, x, y);\n        }\n        y += lh;\n      }\n    } else {\n      str = textValue(item, tl);\n      if (item.fill && fill(context, item, opacity)) {\n        context.fillText(str, x, y);\n      }\n      if (item.stroke && stroke(context, item, opacity)) {\n        context.strokeText(str, x, y);\n      }\n    }\n    if (item.angle) context.restore();\n  });\n}\nfunction hit(context, item, x, y, gx, gy) {\n  if (item.fontSize <= 0) return false;\n  if (!item.angle) return true; // bounds sufficient if no rotation\n\n  // project point into space of unrotated bounds\n  var p = anchorPoint(item),\n    ax = p.x1,\n    ay = p.y1,\n    b = bound(tempBounds, item, 1),\n    a = -item.angle * DegToRad,\n    cos = Math.cos(a),\n    sin = Math.sin(a),\n    px = cos * gx - sin * gy + (ax - cos * ax + sin * ay),\n    py = sin * gx + cos * gy + (ay - sin * ax - cos * ay);\n  return b.contains(px, py);\n}\nfunction intersectText(item, box) {\n  const p = bound(tempBounds, item, 2);\n  return intersectBoxLine(box, p[0], p[1], p[2], p[3]) || intersectBoxLine(box, p[0], p[1], p[4], p[5]) || intersectBoxLine(box, p[4], p[5], p[6], p[7]) || intersectBoxLine(box, p[2], p[3], p[6], p[7]);\n}\nvar text = {\n  type: 'text',\n  tag: 'text',\n  nested: false,\n  attr: attr,\n  bound: bound,\n  draw: draw,\n  pick: pick$1(hit),\n  isect: intersectText\n};\n\nvar trail = markMultiItemPath('trail', trail$1, pickTrail);\n\nvar Marks = {\n  arc: arc,\n  area: area,\n  group: group,\n  image: image,\n  line: line,\n  path: path$2,\n  rect: rect,\n  rule: rule,\n  shape: shape,\n  symbol: symbol,\n  text: text,\n  trail: trail\n};\n\nfunction boundItem (item, func, opt) {\n  var type = Marks[item.mark.marktype],\n    bound = func || type.bound;\n  if (type.nested) item = item.mark;\n  return bound(item.bounds || (item.bounds = new Bounds()), item, opt);\n}\n\nvar DUMMY = {\n  mark: null\n};\nfunction boundMark (mark, bounds, opt) {\n  var type = Marks[mark.marktype],\n    bound = type.bound,\n    items = mark.items,\n    hasItems = items && items.length,\n    i,\n    n,\n    item,\n    b;\n  if (type.nested) {\n    if (hasItems) {\n      item = items[0];\n    } else {\n      // no items, fake it\n      DUMMY.mark = mark;\n      item = DUMMY;\n    }\n    b = boundItem(item, bound, opt);\n    bounds = bounds && bounds.union(b) || b;\n    return bounds;\n  }\n  bounds = bounds || mark.bounds && mark.bounds.clear() || new Bounds();\n  if (hasItems) {\n    for (i = 0, n = items.length; i < n; ++i) {\n      bounds.union(boundItem(items[i], bound, opt));\n    }\n  }\n  return mark.bounds = bounds;\n}\n\nconst keys = ['marktype', 'name', 'role', 'interactive', 'clip', 'items', 'zindex', 'x', 'y', 'width', 'height', 'align', 'baseline',\n// layout\n'fill', 'fillOpacity', 'opacity', 'blend',\n// fill\n'stroke', 'strokeOpacity', 'strokeWidth', 'strokeCap',\n// stroke\n'strokeDash', 'strokeDashOffset',\n// stroke dash\n'strokeForeground', 'strokeOffset',\n// group\n'startAngle', 'endAngle', 'innerRadius', 'outerRadius',\n// arc\n'cornerRadius', 'padAngle',\n// arc, rect\n'cornerRadiusTopLeft', 'cornerRadiusTopRight',\n// rect, group\n'cornerRadiusBottomLeft', 'cornerRadiusBottomRight', 'interpolate', 'tension', 'orient', 'defined',\n// area, line\n'url', 'aspect', 'smooth',\n// image\n'path', 'scaleX', 'scaleY',\n// path\n'x2', 'y2',\n// rule\n'size', 'shape',\n// symbol\n'text', 'angle', 'theta', 'radius', 'dir', 'dx', 'dy',\n// text\n'ellipsis', 'limit', 'lineBreak', 'lineHeight', 'font', 'fontSize', 'fontWeight', 'fontStyle', 'fontVariant',\n// font\n'description', 'aria', 'ariaRole', 'ariaRoleDescription' // aria\n];\n\nfunction sceneToJSON(scene, indent) {\n  return JSON.stringify(scene, keys, indent);\n}\nfunction sceneFromJSON(json) {\n  const scene = typeof json === 'string' ? JSON.parse(json) : json;\n  return initialize(scene);\n}\nfunction initialize(scene) {\n  var type = scene.marktype,\n    items = scene.items,\n    parent,\n    i,\n    n;\n  if (items) {\n    for (i = 0, n = items.length; i < n; ++i) {\n      parent = type ? 'mark' : 'group';\n      items[i][parent] = scene;\n      if (items[i].zindex) items[i][parent].zdirty = true;\n      if ('group' === (type || parent)) initialize(items[i]);\n    }\n  }\n  if (type) boundMark(scene);\n  return scene;\n}\n\nfunction Scenegraph(scene) {\n  if (arguments.length) {\n    this.root = sceneFromJSON(scene);\n  } else {\n    this.root = createMark({\n      marktype: 'group',\n      name: 'root',\n      role: 'frame'\n    });\n    this.root.items = [new GroupItem(this.root)];\n  }\n}\nScenegraph.prototype = {\n  toJSON(indent) {\n    return sceneToJSON(this.root, indent || 0);\n  },\n  mark(markdef, group, index) {\n    group = group || this.root.items[0];\n    const mark = createMark(markdef, group);\n    group.items[index] = mark;\n    if (mark.zindex) mark.group.zdirty = true;\n    return mark;\n  }\n};\nfunction createMark(def, group) {\n  const mark = {\n    bounds: new Bounds(),\n    clip: !!def.clip,\n    group: group,\n    interactive: def.interactive === false ? false : true,\n    items: [],\n    marktype: def.marktype,\n    name: def.name || undefined,\n    role: def.role || undefined,\n    zindex: def.zindex || 0\n  };\n\n  // add accessibility properties if defined\n  if (def.aria != null) {\n    mark.aria = def.aria;\n  }\n  if (def.description) {\n    mark.description = def.description;\n  }\n  return mark;\n}\n\n// create a new DOM element\nfunction domCreate(doc, tag, ns) {\n  if (!doc && typeof document !== 'undefined' && document.createElement) {\n    doc = document;\n  }\n  return doc ? ns ? doc.createElementNS(ns, tag) : doc.createElement(tag) : null;\n}\n\n// find first child element with matching tag\nfunction domFind(el, tag) {\n  tag = tag.toLowerCase();\n  var nodes = el.childNodes,\n    i = 0,\n    n = nodes.length;\n  for (; i < n; ++i) if (nodes[i].tagName.toLowerCase() === tag) {\n    return nodes[i];\n  }\n}\n\n// retrieve child element at given index\n// create & insert if doesn't exist or if tags do not match\nfunction domChild(el, index, tag, ns) {\n  var a = el.childNodes[index],\n    b;\n  if (!a || a.tagName.toLowerCase() !== tag.toLowerCase()) {\n    b = a || null;\n    a = domCreate(el.ownerDocument, tag, ns);\n    el.insertBefore(a, b);\n  }\n  return a;\n}\n\n// remove all child elements at or above the given index\nfunction domClear(el, index) {\n  var nodes = el.childNodes,\n    curr = nodes.length;\n  while (curr > index) el.removeChild(nodes[--curr]);\n  return el;\n}\n\n// generate css class name for mark\nfunction cssClass(mark) {\n  return 'mark-' + mark.marktype + (mark.role ? ' role-' + mark.role : '') + (mark.name ? ' ' + mark.name : '');\n}\n\nfunction point (event, el) {\n  const rect = el.getBoundingClientRect();\n  return [event.clientX - rect.left - (el.clientLeft || 0), event.clientY - rect.top - (el.clientTop || 0)];\n}\n\nfunction resolveItem (item, event, el, origin) {\n  var mark = item && item.mark,\n    mdef,\n    p;\n  if (mark && (mdef = Marks[mark.marktype]).tip) {\n    p = point(event, el);\n    p[0] -= origin[0];\n    p[1] -= origin[1];\n    while (item = item.mark.group) {\n      p[0] -= item.x || 0;\n      p[1] -= item.y || 0;\n    }\n    item = mdef.tip(mark.items, p);\n  }\n  return item;\n}\n\n/**\n * Create a new Handler instance.\n * @param {object} [customLoader] - Optional loader instance for\n *   href URL sanitization. If not specified, a standard loader\n *   instance will be generated.\n * @param {function} [customTooltip] - Optional tooltip handler\n *   function for custom tooltip display.\n * @constructor\n */\nfunction Handler(customLoader, customTooltip) {\n  this._active = null;\n  this._handlers = {};\n  this._loader = customLoader || (0,vega_loader__WEBPACK_IMPORTED_MODULE_3__.loader)();\n  this._tooltip = customTooltip || defaultTooltip;\n}\n\n// The default tooltip display handler.\n// Sets the HTML title attribute on the visualization container.\nfunction defaultTooltip(handler, event, item, value) {\n  handler.element().setAttribute('title', value || '');\n}\nHandler.prototype = {\n  /**\n   * Initialize a new Handler instance.\n   * @param {DOMElement} el - The containing DOM element for the display.\n   * @param {Array<number>} origin - The origin of the display, in pixels.\n   *   The coordinate system will be translated to this point.\n   * @param {object} [obj] - Optional context object that should serve as\n   *   the \"this\" context for event callbacks.\n   * @return {Handler} - This handler instance.\n   */\n  initialize(el, origin, obj) {\n    this._el = el;\n    this._obj = obj || null;\n    return this.origin(origin);\n  },\n  /**\n   * Returns the parent container element for a visualization.\n   * @return {DOMElement} - The containing DOM element.\n   */\n  element() {\n    return this._el;\n  },\n  /**\n   * Returns the scene element (e.g., canvas or SVG) of the visualization\n   * Subclasses must override if the first child is not the scene element.\n   * @return {DOMElement} - The scene (e.g., canvas or SVG) element.\n   */\n  canvas() {\n    return this._el && this._el.firstChild;\n  },\n  /**\n   * Get / set the origin coordinates of the visualization.\n   */\n  origin(origin) {\n    if (arguments.length) {\n      this._origin = origin || [0, 0];\n      return this;\n    } else {\n      return this._origin.slice();\n    }\n  },\n  /**\n   * Get / set the scenegraph root.\n   */\n  scene(scene) {\n    if (!arguments.length) return this._scene;\n    this._scene = scene;\n    return this;\n  },\n  /**\n   * Add an event handler. Subclasses should override this method.\n   */\n  on( /*type, handler*/) {},\n  /**\n   * Remove an event handler. Subclasses should override this method.\n   */\n  off( /*type, handler*/) {},\n  /**\n   * Utility method for finding the array index of an event handler.\n   * @param {Array} h - An array of registered event handlers.\n   * @param {string} type - The event type.\n   * @param {function} handler - The event handler instance to find.\n   * @return {number} - The handler's array index or -1 if not registered.\n   */\n  _handlerIndex(h, type, handler) {\n    for (let i = h ? h.length : 0; --i >= 0;) {\n      if (h[i].type === type && (!handler || h[i].handler === handler)) {\n        return i;\n      }\n    }\n    return -1;\n  },\n  /**\n   * Returns an array with registered event handlers.\n   * @param {string} [type] - The event type to query. Any annotations\n   *   are ignored; for example, for the argument \"click.foo\", \".foo\" will\n   *   be ignored and the method returns all \"click\" handlers. If type is\n   *   null or unspecified, this method returns handlers for all types.\n   * @return {Array} - A new array containing all registered event handlers.\n   */\n  handlers(type) {\n    const h = this._handlers,\n      a = [];\n    if (type) {\n      a.push(...h[this.eventName(type)]);\n    } else {\n      for (const k in h) {\n        a.push(...h[k]);\n      }\n    }\n    return a;\n  },\n  /**\n   * Parses an event name string to return the specific event type.\n   * For example, given \"click.foo\" returns \"click\"\n   * @param {string} name - The input event type string.\n   * @return {string} - A string with the event type only.\n   */\n  eventName(name) {\n    const i = name.indexOf('.');\n    return i < 0 ? name : name.slice(0, i);\n  },\n  /**\n   * Handle hyperlink navigation in response to an item.href value.\n   * @param {Event} event - The event triggering hyperlink navigation.\n   * @param {Item} item - The scenegraph item.\n   * @param {string} href - The URL to navigate to.\n   */\n  handleHref(event, item, href) {\n    this._loader.sanitize(href, {\n      context: 'href'\n    }).then(opt => {\n      const e = new MouseEvent(event.type, event),\n        a = domCreate(null, 'a');\n      for (const name in opt) a.setAttribute(name, opt[name]);\n      a.dispatchEvent(e);\n    }).catch(() => {/* do nothing */});\n  },\n  /**\n   * Handle tooltip display in response to an item.tooltip value.\n   * @param {Event} event - The event triggering tooltip display.\n   * @param {Item} item - The scenegraph item.\n   * @param {boolean} show - A boolean flag indicating whether\n   *   to show or hide a tooltip for the given item.\n   */\n  handleTooltip(event, item, show) {\n    if (item && item.tooltip != null) {\n      item = resolveItem(item, event, this.canvas(), this._origin);\n      const value = show && item && item.tooltip || null;\n      this._tooltip.call(this._obj, this, event, item, value);\n    }\n  },\n  /**\n   * Returns the size of a scenegraph item and its position relative\n   * to the viewport.\n   * @param {Item} item - The scenegraph item.\n   * @return {object} - A bounding box object (compatible with the\n   *   DOMRect type) consisting of x, y, width, heigh, top, left,\n   *   right, and bottom properties.\n   */\n  getItemBoundingClientRect(item) {\n    const el = this.canvas();\n    if (!el) return;\n    const rect = el.getBoundingClientRect(),\n      origin = this._origin,\n      bounds = item.bounds,\n      width = bounds.width(),\n      height = bounds.height();\n    let x = bounds.x1 + origin[0] + rect.left,\n      y = bounds.y1 + origin[1] + rect.top;\n\n    // translate coordinate for each parent group\n    while (item.mark && (item = item.mark.group)) {\n      x += item.x || 0;\n      y += item.y || 0;\n    }\n\n    // return DOMRect-compatible bounding box\n    return {\n      x,\n      y,\n      width,\n      height,\n      left: x,\n      top: y,\n      right: x + width,\n      bottom: y + height\n    };\n  }\n};\n\n/**\n * Create a new Renderer instance.\n * @param {object} [loader] - Optional loader instance for\n *   image and href URL sanitization. If not specified, a\n *   standard loader instance will be generated.\n * @constructor\n */\nfunction Renderer(loader) {\n  this._el = null;\n  this._bgcolor = null;\n  this._loader = new ResourceLoader(loader);\n}\nRenderer.prototype = {\n  /**\n   * Initialize a new Renderer instance.\n   * @param {DOMElement} el - The containing DOM element for the display.\n   * @param {number} width - The coordinate width of the display, in pixels.\n   * @param {number} height - The coordinate height of the display, in pixels.\n   * @param {Array<number>} origin - The origin of the display, in pixels.\n   *   The coordinate system will be translated to this point.\n   * @param {number} [scaleFactor=1] - Optional scaleFactor by which to multiply\n   *   the width and height to determine the final pixel size.\n   * @return {Renderer} - This renderer instance.\n   */\n  initialize(el, width, height, origin, scaleFactor) {\n    this._el = el;\n    return this.resize(width, height, origin, scaleFactor);\n  },\n  /**\n   * Returns the parent container element for a visualization.\n   * @return {DOMElement} - The containing DOM element.\n   */\n  element() {\n    return this._el;\n  },\n  /**\n   * Returns the scene element (e.g., canvas or SVG) of the visualization\n   * Subclasses must override if the first child is not the scene element.\n   * @return {DOMElement} - The scene (e.g., canvas or SVG) element.\n   */\n  canvas() {\n    return this._el && this._el.firstChild;\n  },\n  /**\n   * Get / set the background color.\n   */\n  background(bgcolor) {\n    if (arguments.length === 0) return this._bgcolor;\n    this._bgcolor = bgcolor;\n    return this;\n  },\n  /**\n   * Resize the display.\n   * @param {number} width - The new coordinate width of the display, in pixels.\n   * @param {number} height - The new coordinate height of the display, in pixels.\n   * @param {Array<number>} origin - The new origin of the display, in pixels.\n   *   The coordinate system will be translated to this point.\n   * @param {number} [scaleFactor=1] - Optional scaleFactor by which to multiply\n   *   the width and height to determine the final pixel size.\n   * @return {Renderer} - This renderer instance;\n   */\n  resize(width, height, origin, scaleFactor) {\n    this._width = width;\n    this._height = height;\n    this._origin = origin || [0, 0];\n    this._scale = scaleFactor || 1;\n    return this;\n  },\n  /**\n   * Report a dirty item whose bounds should be redrawn.\n   * This base class method does nothing. Subclasses that perform\n   * incremental should implement this method.\n   * @param {Item} item - The dirty item whose bounds should be redrawn.\n   */\n  dirty( /*item*/) {},\n  /**\n   * Render an input scenegraph, potentially with a set of dirty items.\n   * This method will perform an immediate rendering with available resources.\n   * The renderer may also need to perform image loading to perform a complete\n   * render. This process can lead to asynchronous re-rendering of the scene\n   * after this method returns. To receive notification when rendering is\n   * complete, use the renderAsync method instead.\n   * @param {object} scene - The root mark of a scenegraph to render.\n   * @return {Renderer} - This renderer instance.\n   */\n  render(scene) {\n    const r = this;\n\n    // bind arguments into a render call, and cache it\n    // this function may be subsequently called for async redraw\n    r._call = function () {\n      r._render(scene);\n    };\n\n    // invoke the renderer\n    r._call();\n\n    // clear the cached call for garbage collection\n    // async redraws will stash their own copy\n    r._call = null;\n    return r;\n  },\n  /**\n   * Internal rendering method. Renderer subclasses should override this\n   * method to actually perform rendering.\n   * @param {object} scene - The root mark of a scenegraph to render.\n   */\n  _render( /*scene*/\n  ) {\n    // subclasses to override\n  },\n  /**\n   * Asynchronous rendering method. Similar to render, but returns a Promise\n   * that resolves when all rendering is completed. Sometimes a renderer must\n   * perform image loading to get a complete rendering. The returned\n   * Promise will not resolve until this process completes.\n   * @param {object} scene - The root mark of a scenegraph to render.\n   * @return {Promise} - A Promise that resolves when rendering is complete.\n   */\n  renderAsync(scene) {\n    const r = this.render(scene);\n    return this._ready ? this._ready.then(() => r) : Promise.resolve(r);\n  },\n  /**\n   * Internal method for asynchronous resource loading.\n   * Proxies method calls to the ImageLoader, and tracks loading\n   * progress to invoke a re-render once complete.\n   * @param {string} method - The method name to invoke on the ImageLoader.\n   * @param {string} uri - The URI for the requested resource.\n   * @return {Promise} - A Promise that resolves to the requested resource.\n   */\n  _load(method, uri) {\n    var r = this,\n      p = r._loader[method](uri);\n    if (!r._ready) {\n      // re-render the scene when loading completes\n      const call = r._call;\n      r._ready = r._loader.ready().then(redraw => {\n        if (redraw) call();\n        r._ready = null;\n      });\n    }\n    return p;\n  },\n  /**\n   * Sanitize a URL to include as a hyperlink in the rendered scene.\n   * This method proxies a call to ImageLoader.sanitizeURL, but also tracks\n   * image loading progress and invokes a re-render once complete.\n   * @param {string} uri - The URI string to sanitize.\n   * @return {Promise} - A Promise that resolves to the sanitized URL.\n   */\n  sanitizeURL(uri) {\n    return this._load('sanitizeURL', uri);\n  },\n  /**\n   * Requests an image to include in the rendered scene.\n   * This method proxies a call to ImageLoader.loadImage, but also tracks\n   * image loading progress and invokes a re-render once complete.\n   * @param {string} uri - The URI string of the image.\n   * @return {Promise} - A Promise that resolves to the loaded Image.\n   */\n  loadImage(uri) {\n    return this._load('loadImage', uri);\n  }\n};\n\nconst KeyDownEvent = 'keydown';\nconst KeyPressEvent = 'keypress';\nconst KeyUpEvent = 'keyup';\nconst DragEnterEvent = 'dragenter';\nconst DragLeaveEvent = 'dragleave';\nconst DragOverEvent = 'dragover';\nconst MouseDownEvent = 'mousedown';\nconst MouseUpEvent = 'mouseup';\nconst MouseMoveEvent = 'mousemove';\nconst MouseOutEvent = 'mouseout';\nconst MouseOverEvent = 'mouseover';\nconst ClickEvent = 'click';\nconst DoubleClickEvent = 'dblclick';\nconst WheelEvent = 'wheel';\nconst MouseWheelEvent = 'mousewheel';\nconst TouchStartEvent = 'touchstart';\nconst TouchMoveEvent = 'touchmove';\nconst TouchEndEvent = 'touchend';\nconst Events = [KeyDownEvent, KeyPressEvent, KeyUpEvent, DragEnterEvent, DragLeaveEvent, DragOverEvent, MouseDownEvent, MouseUpEvent, MouseMoveEvent, MouseOutEvent, MouseOverEvent, ClickEvent, DoubleClickEvent, WheelEvent, MouseWheelEvent, TouchStartEvent, TouchMoveEvent, TouchEndEvent];\nconst TooltipShowEvent = MouseMoveEvent;\nconst TooltipHideEvent = MouseOutEvent;\nconst HrefEvent = ClickEvent;\n\nfunction CanvasHandler(loader, tooltip) {\n  Handler.call(this, loader, tooltip);\n  this._down = null;\n  this._touch = null;\n  this._first = true;\n  this._events = {};\n}\nconst eventBundle = type => type === TouchStartEvent || type === TouchMoveEvent || type === TouchEndEvent ? [TouchStartEvent, TouchMoveEvent, TouchEndEvent] : [type];\n\n// lazily add listeners to the canvas as needed\nfunction eventListenerCheck(handler, type) {\n  eventBundle(type).forEach(_ => addEventListener(handler, _));\n}\nfunction addEventListener(handler, type) {\n  const canvas = handler.canvas();\n  if (canvas && !handler._events[type]) {\n    handler._events[type] = 1;\n    canvas.addEventListener(type, handler[type] ? evt => handler[type](evt) : evt => handler.fire(type, evt));\n  }\n}\nfunction move(moveEvent, overEvent, outEvent) {\n  return function (evt) {\n    const a = this._active,\n      p = this.pickEvent(evt);\n    if (p === a) {\n      // active item and picked item are the same\n      this.fire(moveEvent, evt); // fire move\n    } else {\n      // active item and picked item are different\n      if (!a || !a.exit) {\n        // fire out for prior active item\n        // suppress if active item was removed from scene\n        this.fire(outEvent, evt);\n      }\n      this._active = p; // set new active item\n      this.fire(overEvent, evt); // fire over for new active item\n      this.fire(moveEvent, evt); // fire move for new active item\n    }\n  };\n}\n\nfunction inactive(type) {\n  return function (evt) {\n    this.fire(type, evt);\n    this._active = null;\n  };\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(CanvasHandler, Handler, {\n  initialize(el, origin, obj) {\n    this._canvas = el && domFind(el, 'canvas');\n\n    // add minimal events required for proper state management\n    [ClickEvent, MouseDownEvent, MouseMoveEvent, MouseOutEvent, DragLeaveEvent].forEach(type => eventListenerCheck(this, type));\n    return Handler.prototype.initialize.call(this, el, origin, obj);\n  },\n  // return the backing canvas instance\n  canvas() {\n    return this._canvas;\n  },\n  // retrieve the current canvas context\n  context() {\n    return this._canvas.getContext('2d');\n  },\n  // supported events\n  events: Events,\n  // to keep old versions of firefox happy\n  DOMMouseScroll(evt) {\n    this.fire(MouseWheelEvent, evt);\n  },\n  mousemove: move(MouseMoveEvent, MouseOverEvent, MouseOutEvent),\n  dragover: move(DragOverEvent, DragEnterEvent, DragLeaveEvent),\n  mouseout: inactive(MouseOutEvent),\n  dragleave: inactive(DragLeaveEvent),\n  mousedown(evt) {\n    this._down = this._active;\n    this.fire(MouseDownEvent, evt);\n  },\n  click(evt) {\n    if (this._down === this._active) {\n      this.fire(ClickEvent, evt);\n      this._down = null;\n    }\n  },\n  touchstart(evt) {\n    this._touch = this.pickEvent(evt.changedTouches[0]);\n    if (this._first) {\n      this._active = this._touch;\n      this._first = false;\n    }\n    this.fire(TouchStartEvent, evt, true);\n  },\n  touchmove(evt) {\n    this.fire(TouchMoveEvent, evt, true);\n  },\n  touchend(evt) {\n    this.fire(TouchEndEvent, evt, true);\n    this._touch = null;\n  },\n  // fire an event\n  fire(type, evt, touch) {\n    const a = touch ? this._touch : this._active,\n      h = this._handlers[type];\n\n    // set event type relative to scenegraph items\n    evt.vegaType = type;\n\n    // handle hyperlinks and tooltips first\n    if (type === HrefEvent && a && a.href) {\n      this.handleHref(evt, a, a.href);\n    } else if (type === TooltipShowEvent || type === TooltipHideEvent) {\n      this.handleTooltip(evt, a, type !== TooltipHideEvent);\n    }\n\n    // invoke all registered handlers\n    if (h) {\n      for (let i = 0, len = h.length; i < len; ++i) {\n        h[i].handler.call(this._obj, evt, a);\n      }\n    }\n  },\n  // add an event handler\n  on(type, handler) {\n    const name = this.eventName(type),\n      h = this._handlers,\n      i = this._handlerIndex(h[name], type, handler);\n    if (i < 0) {\n      eventListenerCheck(this, type);\n      (h[name] || (h[name] = [])).push({\n        type: type,\n        handler: handler\n      });\n    }\n    return this;\n  },\n  // remove an event handler\n  off(type, handler) {\n    const name = this.eventName(type),\n      h = this._handlers[name],\n      i = this._handlerIndex(h, type, handler);\n    if (i >= 0) {\n      h.splice(i, 1);\n    }\n    return this;\n  },\n  pickEvent(evt) {\n    const p = point(evt, this._canvas),\n      o = this._origin;\n    return this.pick(this._scene, p[0], p[1], p[0] - o[0], p[1] - o[1]);\n  },\n  // find the scenegraph item at the current mouse position\n  // x, y -- the absolute x, y mouse coordinates on the canvas element\n  // gx, gy -- the relative coordinates within the current group\n  pick(scene, x, y, gx, gy) {\n    const g = this.context(),\n      mark = Marks[scene.marktype];\n    return mark.pick.call(this, g, scene, x, y, gx, gy);\n  }\n});\n\nfunction devicePixelRatio() {\n  return typeof window !== 'undefined' ? window.devicePixelRatio || 1 : 1;\n}\nvar pixelRatio = devicePixelRatio();\nfunction resize (canvas, width, height, origin, scaleFactor, opt) {\n  const inDOM = typeof HTMLElement !== 'undefined' && canvas instanceof HTMLElement && canvas.parentNode != null,\n    context = canvas.getContext('2d'),\n    ratio = inDOM ? pixelRatio : scaleFactor;\n  canvas.width = width * ratio;\n  canvas.height = height * ratio;\n  for (const key in opt) {\n    context[key] = opt[key];\n  }\n  if (inDOM && ratio !== 1) {\n    canvas.style.width = width + 'px';\n    canvas.style.height = height + 'px';\n  }\n  context.pixelRatio = ratio;\n  context.setTransform(ratio, 0, 0, ratio, ratio * origin[0], ratio * origin[1]);\n  return canvas;\n}\n\nfunction CanvasRenderer(loader) {\n  Renderer.call(this, loader);\n  this._options = {};\n  this._redraw = false;\n  this._dirty = new Bounds();\n  this._tempb = new Bounds();\n}\nconst base$1 = Renderer.prototype;\nconst viewBounds = (origin, width, height) => new Bounds().set(0, 0, width, height).translate(-origin[0], -origin[1]);\nfunction clipToBounds(g, b, origin) {\n  // expand bounds by 1 pixel, then round to pixel boundaries\n  b.expand(1).round();\n\n  // align to base pixel grid in case of non-integer scaling (#2425)\n  if (g.pixelRatio % 1) {\n    b.scale(g.pixelRatio).round().scale(1 / g.pixelRatio);\n  }\n\n  // to avoid artifacts translate if origin has fractional pixels\n  b.translate(-(origin[0] % 1), -(origin[1] % 1));\n\n  // set clip path\n  g.beginPath();\n  g.rect(b.x1, b.y1, b.width(), b.height());\n  g.clip();\n  return b;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(CanvasRenderer, Renderer, {\n  initialize(el, width, height, origin, scaleFactor, options) {\n    this._options = options || {};\n    this._canvas = this._options.externalContext ? null : (0,vega_canvas__WEBPACK_IMPORTED_MODULE_2__.canvas)(1, 1, this._options.type); // instantiate a small canvas\n\n    if (el && this._canvas) {\n      domClear(el, 0).appendChild(this._canvas);\n      this._canvas.setAttribute('class', 'marks');\n    }\n\n    // this method will invoke resize to size the canvas appropriately\n    return base$1.initialize.call(this, el, width, height, origin, scaleFactor);\n  },\n  resize(width, height, origin, scaleFactor) {\n    base$1.resize.call(this, width, height, origin, scaleFactor);\n    if (this._canvas) {\n      // configure canvas size and transform\n      resize(this._canvas, this._width, this._height, this._origin, this._scale, this._options.context);\n    } else {\n      // external context needs to be scaled and positioned to origin\n      const ctx = this._options.externalContext;\n      if (!ctx) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('CanvasRenderer is missing a valid canvas or context');\n      ctx.scale(this._scale, this._scale);\n      ctx.translate(this._origin[0], this._origin[1]);\n    }\n    this._redraw = true;\n    return this;\n  },\n  canvas() {\n    return this._canvas;\n  },\n  context() {\n    return this._options.externalContext || (this._canvas ? this._canvas.getContext('2d') : null);\n  },\n  dirty(item) {\n    const b = this._tempb.clear().union(item.bounds);\n    let g = item.mark.group;\n    while (g) {\n      b.translate(g.x || 0, g.y || 0);\n      g = g.mark.group;\n    }\n    this._dirty.union(b);\n  },\n  _render(scene) {\n    const g = this.context(),\n      o = this._origin,\n      w = this._width,\n      h = this._height,\n      db = this._dirty,\n      vb = viewBounds(o, w, h);\n\n    // setup\n    g.save();\n    const b = this._redraw || db.empty() ? (this._redraw = false, vb.expand(1)) : clipToBounds(g, vb.intersect(db), o);\n    this.clear(-o[0], -o[1], w, h);\n\n    // render\n    this.draw(g, scene, b);\n\n    // takedown\n    g.restore();\n    db.clear();\n    return this;\n  },\n  draw(ctx, scene, bounds) {\n    const mark = Marks[scene.marktype];\n    if (scene.clip) clip(ctx, scene);\n    mark.draw.call(this, ctx, scene, bounds);\n    if (scene.clip) ctx.restore();\n  },\n  clear(x, y, w, h) {\n    const opt = this._options,\n      g = this.context();\n    if (opt.type !== 'pdf' && !opt.externalContext) {\n      // calling clear rect voids vector output in pdf mode\n      // and could remove external context content (#2615)\n      g.clearRect(x, y, w, h);\n    }\n    if (this._bgcolor != null) {\n      g.fillStyle = this._bgcolor;\n      g.fillRect(x, y, w, h);\n    }\n  }\n});\n\nfunction SVGHandler(loader, tooltip) {\n  Handler.call(this, loader, tooltip);\n  const h = this;\n  h._hrefHandler = listener(h, (evt, item) => {\n    if (item && item.href) h.handleHref(evt, item, item.href);\n  });\n  h._tooltipHandler = listener(h, (evt, item) => {\n    h.handleTooltip(evt, item, evt.type !== TooltipHideEvent);\n  });\n}\n\n// wrap an event listener for the SVG DOM\nconst listener = (context, handler) => evt => {\n  let item = evt.target.__data__;\n  item = Array.isArray(item) ? item[0] : item;\n  evt.vegaType = evt.type;\n  handler.call(context._obj, evt, item);\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(SVGHandler, Handler, {\n  initialize(el, origin, obj) {\n    let svg = this._svg;\n    if (svg) {\n      svg.removeEventListener(HrefEvent, this._hrefHandler);\n      svg.removeEventListener(TooltipShowEvent, this._tooltipHandler);\n      svg.removeEventListener(TooltipHideEvent, this._tooltipHandler);\n    }\n    this._svg = svg = el && domFind(el, 'svg');\n    if (svg) {\n      svg.addEventListener(HrefEvent, this._hrefHandler);\n      svg.addEventListener(TooltipShowEvent, this._tooltipHandler);\n      svg.addEventListener(TooltipHideEvent, this._tooltipHandler);\n    }\n    return Handler.prototype.initialize.call(this, el, origin, obj);\n  },\n  canvas() {\n    return this._svg;\n  },\n  // add an event handler\n  on(type, handler) {\n    const name = this.eventName(type),\n      h = this._handlers,\n      i = this._handlerIndex(h[name], type, handler);\n    if (i < 0) {\n      const x = {\n        type,\n        handler,\n        listener: listener(this, handler)\n      };\n      (h[name] || (h[name] = [])).push(x);\n      if (this._svg) {\n        this._svg.addEventListener(name, x.listener);\n      }\n    }\n    return this;\n  },\n  // remove an event handler\n  off(type, handler) {\n    const name = this.eventName(type),\n      h = this._handlers[name],\n      i = this._handlerIndex(h, type, handler);\n    if (i >= 0) {\n      if (this._svg) {\n        this._svg.removeEventListener(name, h[i].listener);\n      }\n      h.splice(i, 1);\n    }\n    return this;\n  }\n});\n\nconst ARIA_HIDDEN = 'aria-hidden';\nconst ARIA_LABEL = 'aria-label';\nconst ARIA_ROLE = 'role';\nconst ARIA_ROLEDESCRIPTION = 'aria-roledescription';\nconst GRAPHICS_OBJECT = 'graphics-object';\nconst GRAPHICS_SYMBOL = 'graphics-symbol';\nconst bundle = (role, roledesc, label) => ({\n  [ARIA_ROLE]: role,\n  [ARIA_ROLEDESCRIPTION]: roledesc,\n  [ARIA_LABEL]: label || undefined\n});\n\n// these roles are covered by related roles\n// we can ignore them, no need to generate attributes\nconst AriaIgnore = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(['axis-domain', 'axis-grid', 'axis-label', 'axis-tick', 'axis-title', 'legend-band', 'legend-entry', 'legend-gradient', 'legend-label', 'legend-title', 'legend-symbol', 'title']);\n\n// aria attribute generators for guide roles\nconst AriaGuides = {\n  'axis': {\n    desc: 'axis',\n    caption: axisCaption\n  },\n  'legend': {\n    desc: 'legend',\n    caption: legendCaption\n  },\n  'title-text': {\n    desc: 'title',\n    caption: item => `Title text '${titleCaption(item)}'`\n  },\n  'title-subtitle': {\n    desc: 'subtitle',\n    caption: item => `Subtitle text '${titleCaption(item)}'`\n  }\n};\n\n// aria properties generated for mark item encoding channels\nconst AriaEncode = {\n  ariaRole: ARIA_ROLE,\n  ariaRoleDescription: ARIA_ROLEDESCRIPTION,\n  description: ARIA_LABEL\n};\nfunction ariaItemAttributes(emit, item) {\n  const hide = item.aria === false;\n  emit(ARIA_HIDDEN, hide || undefined);\n  if (hide || item.description == null) {\n    for (const prop in AriaEncode) {\n      emit(AriaEncode[prop], undefined);\n    }\n  } else {\n    const type = item.mark.marktype;\n    emit(ARIA_LABEL, item.description);\n    emit(ARIA_ROLE, item.ariaRole || (type === 'group' ? GRAPHICS_OBJECT : GRAPHICS_SYMBOL));\n    emit(ARIA_ROLEDESCRIPTION, item.ariaRoleDescription || `${type} mark`);\n  }\n}\nfunction ariaMarkAttributes(mark) {\n  return mark.aria === false ? {\n    [ARIA_HIDDEN]: true\n  } : AriaIgnore[mark.role] ? null : AriaGuides[mark.role] ? ariaGuide(mark, AriaGuides[mark.role]) : ariaMark(mark);\n}\nfunction ariaMark(mark) {\n  const type = mark.marktype;\n  const recurse = type === 'group' || type === 'text' || mark.items.some(_ => _.description != null && _.aria !== false);\n  return bundle(recurse ? GRAPHICS_OBJECT : GRAPHICS_SYMBOL, `${type} mark container`, mark.description);\n}\nfunction ariaGuide(mark, opt) {\n  try {\n    const item = mark.items[0],\n      caption = opt.caption || (() => '');\n    return bundle(opt.role || GRAPHICS_SYMBOL, opt.desc, item.description || caption(item));\n  } catch (err) {\n    return null;\n  }\n}\nfunction titleCaption(item) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(item.text).join(' ');\n}\nfunction axisCaption(item) {\n  const datum = item.datum,\n    orient = item.orient,\n    title = datum.title ? extractTitle(item) : null,\n    ctx = item.context,\n    scale = ctx.scales[datum.scale].value,\n    locale = ctx.dataflow.locale(),\n    type = scale.type,\n    xy = orient === 'left' || orient === 'right' ? 'Y' : 'X';\n  return `${xy}-axis` + (title ? ` titled '${title}'` : '') + ` for a ${(0,vega_scale__WEBPACK_IMPORTED_MODULE_4__.isDiscrete)(type) ? 'discrete' : type} scale` + ` with ${(0,vega_scale__WEBPACK_IMPORTED_MODULE_4__.domainCaption)(locale, scale, item)}`;\n}\nfunction legendCaption(item) {\n  const datum = item.datum,\n    title = datum.title ? extractTitle(item) : null,\n    type = `${datum.type || ''} legend`.trim(),\n    scales = datum.scales,\n    props = Object.keys(scales),\n    ctx = item.context,\n    scale = ctx.scales[scales[props[0]]].value,\n    locale = ctx.dataflow.locale();\n  return capitalize(type) + (title ? ` titled '${title}'` : '') + ` for ${channelCaption(props)}` + ` with ${(0,vega_scale__WEBPACK_IMPORTED_MODULE_4__.domainCaption)(locale, scale, item)}`;\n}\nfunction extractTitle(item) {\n  try {\n    return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(item.items).items[0].text).join(' ');\n  } catch (err) {\n    return null;\n  }\n}\nfunction channelCaption(props) {\n  props = props.map(p => p + (p === 'fill' || p === 'stroke' ? ' color' : ''));\n  return props.length < 2 ? props[0] : props.slice(0, -1).join(', ') + ' and ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(props);\n}\nfunction capitalize(s) {\n  return s.length ? s[0].toUpperCase() + s.slice(1) : s;\n}\n\nconst innerText = val => (val + '').replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;');\nconst attrText = val => innerText(val).replace(/\"/g, '&quot;').replace(/\\t/g, '&#x9;').replace(/\\n/g, '&#xA;').replace(/\\r/g, '&#xD;');\nfunction markup() {\n  let buf = '',\n    outer = '',\n    inner = '';\n  const stack = [],\n    clear = () => outer = inner = '',\n    push = tag => {\n      if (outer) {\n        buf += `${outer}>${inner}`;\n        clear();\n      }\n      stack.push(tag);\n    },\n    attr = (name, value) => {\n      if (value != null) outer += ` ${name}=\"${attrText(value)}\"`;\n      return m;\n    },\n    m = {\n      open(tag) {\n        push(tag);\n        outer = '<' + tag;\n        for (var _len = arguments.length, attrs = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n          attrs[_key - 1] = arguments[_key];\n        }\n        for (const set of attrs) {\n          for (const key in set) attr(key, set[key]);\n        }\n        return m;\n      },\n      close() {\n        const tag = stack.pop();\n        if (outer) {\n          buf += outer + (inner ? `>${inner}</${tag}>` : '/>');\n        } else {\n          buf += `</${tag}>`;\n        }\n        clear();\n        return m;\n      },\n      attr,\n      text: t => (inner += innerText(t), m),\n      toString: () => buf\n    };\n  return m;\n}\nconst serializeXML = node => _serialize(markup(), node) + '';\nfunction _serialize(m, node) {\n  m.open(node.tagName);\n  if (node.hasAttributes()) {\n    const attrs = node.attributes,\n      n = attrs.length;\n    for (let i = 0; i < n; ++i) {\n      m.attr(attrs[i].name, attrs[i].value);\n    }\n  }\n  if (node.hasChildNodes()) {\n    const children = node.childNodes;\n    for (const child of children) {\n      child.nodeType === 3 // text node\n      ? m.text(child.nodeValue) : _serialize(m, child);\n    }\n  }\n  return m.close();\n}\n\nconst stylesAttr = {\n  fill: 'fill',\n  fillOpacity: 'fill-opacity',\n  stroke: 'stroke',\n  strokeOpacity: 'stroke-opacity',\n  strokeWidth: 'stroke-width',\n  strokeCap: 'stroke-linecap',\n  strokeJoin: 'stroke-linejoin',\n  strokeDash: 'stroke-dasharray',\n  strokeDashOffset: 'stroke-dashoffset',\n  strokeMiterLimit: 'stroke-miterlimit',\n  opacity: 'opacity'\n};\nconst stylesCss = {\n  blend: 'mix-blend-mode'\n};\n\n// ensure miter limit default is consistent with canvas (#2498)\nconst rootAttributes = {\n  'fill': 'none',\n  'stroke-miterlimit': 10\n};\n\nconst RootIndex = 0,\n  xmlns = 'http://www.w3.org/2000/xmlns/',\n  svgns = metadata.xmlns;\nfunction SVGRenderer(loader) {\n  Renderer.call(this, loader);\n  this._dirtyID = 0;\n  this._dirty = [];\n  this._svg = null;\n  this._root = null;\n  this._defs = null;\n}\nconst base = Renderer.prototype;\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(SVGRenderer, Renderer, {\n  /**\n   * Initialize a new SVGRenderer instance.\n   * @param {DOMElement} el - The containing DOM element for the display.\n   * @param {number} width - The coordinate width of the display, in pixels.\n   * @param {number} height - The coordinate height of the display, in pixels.\n   * @param {Array<number>} origin - The origin of the display, in pixels.\n   *   The coordinate system will be translated to this point.\n   * @param {number} [scaleFactor=1] - Optional scaleFactor by which to multiply\n   *   the width and height to determine the final pixel size.\n   * @return {SVGRenderer} - This renderer instance.\n   */\n  initialize(el, width, height, origin, scaleFactor) {\n    // create the svg definitions cache\n    this._defs = {};\n    this._clearDefs();\n    if (el) {\n      this._svg = domChild(el, 0, 'svg', svgns);\n      this._svg.setAttributeNS(xmlns, 'xmlns', svgns);\n      this._svg.setAttributeNS(xmlns, 'xmlns:xlink', metadata['xmlns:xlink']);\n      this._svg.setAttribute('version', metadata['version']);\n      this._svg.setAttribute('class', 'marks');\n      domClear(el, 1);\n\n      // set the svg root group\n      this._root = domChild(this._svg, RootIndex, 'g', svgns);\n      setAttributes(this._root, rootAttributes);\n\n      // ensure no additional child elements\n      domClear(this._svg, RootIndex + 1);\n    }\n\n    // set background color if defined\n    this.background(this._bgcolor);\n    return base.initialize.call(this, el, width, height, origin, scaleFactor);\n  },\n  /**\n   * Get / set the background color.\n   */\n  background(bgcolor) {\n    if (arguments.length && this._svg) {\n      this._svg.style.setProperty('background-color', bgcolor);\n    }\n    return base.background.apply(this, arguments);\n  },\n  /**\n   * Resize the display.\n   * @param {number} width - The new coordinate width of the display, in pixels.\n   * @param {number} height - The new coordinate height of the display, in pixels.\n   * @param {Array<number>} origin - The new origin of the display, in pixels.\n   *   The coordinate system will be translated to this point.\n   * @param {number} [scaleFactor=1] - Optional scaleFactor by which to multiply\n   *   the width and height to determine the final pixel size.\n   * @return {SVGRenderer} - This renderer instance;\n   */\n  resize(width, height, origin, scaleFactor) {\n    base.resize.call(this, width, height, origin, scaleFactor);\n    if (this._svg) {\n      setAttributes(this._svg, {\n        width: this._width * this._scale,\n        height: this._height * this._scale,\n        viewBox: `0 0 ${this._width} ${this._height}`\n      });\n      this._root.setAttribute('transform', `translate(${this._origin})`);\n    }\n    this._dirty = [];\n    return this;\n  },\n  /**\n   * Returns the SVG element of the visualization.\n   * @return {DOMElement} - The SVG element.\n   */\n  canvas() {\n    return this._svg;\n  },\n  /**\n   * Returns an SVG text string for the rendered content,\n   * or null if this renderer is currently headless.\n   */\n  svg() {\n    const svg = this._svg,\n      bg = this._bgcolor;\n    if (!svg) return null;\n    let node;\n    if (bg) {\n      svg.removeAttribute('style');\n      node = domChild(svg, RootIndex, 'rect', svgns);\n      setAttributes(node, {\n        width: this._width,\n        height: this._height,\n        fill: bg\n      });\n    }\n    const text = serializeXML(svg);\n    if (bg) {\n      svg.removeChild(node);\n      this._svg.style.setProperty('background-color', bg);\n    }\n    return text;\n  },\n  /**\n   * Internal rendering method.\n   * @param {object} scene - The root mark of a scenegraph to render.\n   */\n  _render(scene) {\n    // perform spot updates and re-render markup\n    if (this._dirtyCheck()) {\n      if (this._dirtyAll) this._clearDefs();\n      this.mark(this._root, scene);\n      domClear(this._root, 1);\n    }\n    this.defs();\n    this._dirty = [];\n    ++this._dirtyID;\n    return this;\n  },\n  // -- Manage rendering of items marked as dirty --\n\n  /**\n   * Flag a mark item as dirty.\n   * @param {Item} item - The mark item.\n   */\n  dirty(item) {\n    if (item.dirty !== this._dirtyID) {\n      item.dirty = this._dirtyID;\n      this._dirty.push(item);\n    }\n  },\n  /**\n   * Check if a mark item is considered dirty.\n   * @param {Item} item - The mark item.\n   */\n  isDirty(item) {\n    return this._dirtyAll || !item._svg || !item._svg.ownerSVGElement || item.dirty === this._dirtyID;\n  },\n  /**\n   * Internal method to check dirty status and, if possible,\n   * make targetted updates without a full rendering pass.\n   */\n  _dirtyCheck() {\n    this._dirtyAll = true;\n    const items = this._dirty;\n    if (!items.length || !this._dirtyID) return true;\n    const id = ++this._dirtyID;\n    let item, mark, type, mdef, i, n, o;\n    for (i = 0, n = items.length; i < n; ++i) {\n      item = items[i];\n      mark = item.mark;\n      if (mark.marktype !== type) {\n        // memoize mark instance lookup\n        type = mark.marktype;\n        mdef = Marks[type];\n      }\n      if (mark.zdirty && mark.dirty !== id) {\n        this._dirtyAll = false;\n        dirtyParents(item, id);\n        mark.items.forEach(i => {\n          i.dirty = id;\n        });\n      }\n      if (mark.zdirty) continue; // handle in standard drawing pass\n\n      if (item.exit) {\n        // EXIT\n        if (mdef.nested && mark.items.length) {\n          // if nested mark with remaining points, update instead\n          o = mark.items[0];\n          if (o._svg) this._update(mdef, o._svg, o);\n        } else if (item._svg) {\n          // otherwise remove from DOM\n          o = item._svg.parentNode;\n          if (o) o.removeChild(item._svg);\n        }\n        item._svg = null;\n        continue;\n      }\n      item = mdef.nested ? mark.items[0] : item;\n      if (item._update === id) continue; // already visited\n\n      if (!item._svg || !item._svg.ownerSVGElement) {\n        // ENTER\n        this._dirtyAll = false;\n        dirtyParents(item, id);\n      } else {\n        // IN-PLACE UPDATE\n        this._update(mdef, item._svg, item);\n      }\n      item._update = id;\n    }\n    return !this._dirtyAll;\n  },\n  // -- Construct & maintain scenegraph to SVG mapping ---\n\n  /**\n   * Render a set of mark items.\n   * @param {SVGElement} el - The parent element in the SVG tree.\n   * @param {object} scene - The mark parent to render.\n   * @param {SVGElement} prev - The previous sibling in the SVG tree.\n   */\n  mark(el, scene, prev) {\n    if (!this.isDirty(scene)) {\n      return scene._svg;\n    }\n    const svg = this._svg,\n      mdef = Marks[scene.marktype],\n      events = scene.interactive === false ? 'none' : null,\n      isGroup = mdef.tag === 'g';\n    const parent = bind(scene, el, prev, 'g', svg);\n    parent.setAttribute('class', cssClass(scene));\n\n    // apply aria attributes to parent container element\n    const aria = ariaMarkAttributes(scene);\n    for (const key in aria) setAttribute(parent, key, aria[key]);\n    if (!isGroup) {\n      setAttribute(parent, 'pointer-events', events);\n    }\n    setAttribute(parent, 'clip-path', scene.clip ? clip$1(this, scene, scene.group) : null);\n    let sibling = null,\n      i = 0;\n    const process = item => {\n      const dirty = this.isDirty(item),\n        node = bind(item, parent, sibling, mdef.tag, svg);\n      if (dirty) {\n        this._update(mdef, node, item);\n        if (isGroup) recurse(this, node, item);\n      }\n      sibling = node;\n      ++i;\n    };\n    if (mdef.nested) {\n      if (scene.items.length) process(scene.items[0]);\n    } else {\n      visit(scene, process);\n    }\n    domClear(parent, i);\n    return parent;\n  },\n  /**\n   * Update the attributes of an SVG element for a mark item.\n   * @param {object} mdef - The mark definition object\n   * @param {SVGElement} el - The SVG element.\n   * @param {Item} item - The mark item.\n   */\n  _update(mdef, el, item) {\n    // set dom element and values cache\n    // provides access to emit method\n    element = el;\n    values = el.__values__;\n\n    // apply aria-specific properties\n    ariaItemAttributes(emit, item);\n\n    // apply svg attributes\n    mdef.attr(emit, item, this);\n\n    // some marks need special treatment\n    const extra = mark_extras[mdef.type];\n    if (extra) extra.call(this, mdef, el, item);\n\n    // apply svg style attributes\n    // note: element state may have been modified by 'extra' method\n    if (element) this.style(element, item);\n  },\n  /**\n   * Update the presentation attributes of an SVG element for a mark item.\n   * @param {SVGElement} el - The SVG element.\n   * @param {Item} item - The mark item.\n   */\n  style(el, item) {\n    if (item == null) return;\n    for (const prop in stylesAttr) {\n      let value = prop === 'font' ? fontFamily(item) : item[prop];\n      if (value === values[prop]) continue;\n      const name = stylesAttr[prop];\n      if (value == null) {\n        el.removeAttribute(name);\n      } else {\n        if (isGradient(value)) {\n          value = gradientRef(value, this._defs.gradient, href());\n        }\n        el.setAttribute(name, value + '');\n      }\n      values[prop] = value;\n    }\n    for (const prop in stylesCss) {\n      setStyle(el, stylesCss[prop], item[prop]);\n    }\n  },\n  /**\n   * Render SVG defs, as needed.\n   * Must be called *after* marks have been processed to ensure the\n   * collected state is current and accurate.\n   */\n  defs() {\n    const svg = this._svg,\n      defs = this._defs;\n    let el = defs.el,\n      index = 0;\n    for (const id in defs.gradient) {\n      if (!el) defs.el = el = domChild(svg, RootIndex + 1, 'defs', svgns);\n      index = updateGradient(el, defs.gradient[id], index);\n    }\n    for (const id in defs.clipping) {\n      if (!el) defs.el = el = domChild(svg, RootIndex + 1, 'defs', svgns);\n      index = updateClipping(el, defs.clipping[id], index);\n    }\n\n    // clean-up\n    if (el) {\n      index === 0 ? (svg.removeChild(el), defs.el = null) : domClear(el, index);\n    }\n  },\n  /**\n   * Clear defs caches.\n   */\n  _clearDefs() {\n    const def = this._defs;\n    def.gradient = {};\n    def.clipping = {};\n  }\n});\n\n// mark ancestor chain with a dirty id\nfunction dirtyParents(item, id) {\n  for (; item && item.dirty !== id; item = item.mark.group) {\n    item.dirty = id;\n    if (item.mark && item.mark.dirty !== id) {\n      item.mark.dirty = id;\n    } else return;\n  }\n}\n\n// update gradient definitions\nfunction updateGradient(el, grad, index) {\n  let i, n, stop;\n  if (grad.gradient === 'radial') {\n    // SVG radial gradients automatically transform to normalized bbox\n    // coordinates, in a way that is cumbersome to replicate in canvas.\n    // We wrap the radial gradient in a pattern element, allowing us to\n    // maintain a circular gradient that matches what canvas provides.\n    let pt = domChild(el, index++, 'pattern', svgns);\n    setAttributes(pt, {\n      id: patternPrefix + grad.id,\n      viewBox: '0,0,1,1',\n      width: '100%',\n      height: '100%',\n      preserveAspectRatio: 'xMidYMid slice'\n    });\n    pt = domChild(pt, 0, 'rect', svgns);\n    setAttributes(pt, {\n      width: 1,\n      height: 1,\n      fill: `url(${href()}#${grad.id})`\n    });\n    el = domChild(el, index++, 'radialGradient', svgns);\n    setAttributes(el, {\n      id: grad.id,\n      fx: grad.x1,\n      fy: grad.y1,\n      fr: grad.r1,\n      cx: grad.x2,\n      cy: grad.y2,\n      r: grad.r2\n    });\n  } else {\n    el = domChild(el, index++, 'linearGradient', svgns);\n    setAttributes(el, {\n      id: grad.id,\n      x1: grad.x1,\n      x2: grad.x2,\n      y1: grad.y1,\n      y2: grad.y2\n    });\n  }\n  for (i = 0, n = grad.stops.length; i < n; ++i) {\n    stop = domChild(el, i, 'stop', svgns);\n    stop.setAttribute('offset', grad.stops[i].offset);\n    stop.setAttribute('stop-color', grad.stops[i].color);\n  }\n  domClear(el, i);\n  return index;\n}\n\n// update clipping path definitions\nfunction updateClipping(el, clip, index) {\n  let mask;\n  el = domChild(el, index, 'clipPath', svgns);\n  el.setAttribute('id', clip.id);\n  if (clip.path) {\n    mask = domChild(el, 0, 'path', svgns);\n    mask.setAttribute('d', clip.path);\n  } else {\n    mask = domChild(el, 0, 'rect', svgns);\n    setAttributes(mask, {\n      x: 0,\n      y: 0,\n      width: clip.width,\n      height: clip.height\n    });\n  }\n  domClear(el, 1);\n  return index + 1;\n}\n\n// Recursively process group contents.\nfunction recurse(renderer, el, group) {\n  // child 'g' element is second to last among children (path, g, path)\n  // other children here are foreground and background path elements\n  el = el.lastChild.previousSibling;\n  let prev,\n    idx = 0;\n  visit(group, item => {\n    prev = renderer.mark(el, item, prev);\n    ++idx;\n  });\n\n  // remove any extraneous DOM elements\n  domClear(el, 1 + idx);\n}\n\n// Bind a scenegraph item to an SVG DOM element.\n// Create new SVG elements as needed.\nfunction bind(item, el, sibling, tag, svg) {\n  let node = item._svg,\n    doc;\n\n  // create a new dom node if needed\n  if (!node) {\n    doc = el.ownerDocument;\n    node = domCreate(doc, tag, svgns);\n    item._svg = node;\n    if (item.mark) {\n      node.__data__ = item;\n      node.__values__ = {\n        fill: 'default'\n      };\n\n      // if group, create background, content, and foreground elements\n      if (tag === 'g') {\n        const bg = domCreate(doc, 'path', svgns);\n        node.appendChild(bg);\n        bg.__data__ = item;\n        const cg = domCreate(doc, 'g', svgns);\n        node.appendChild(cg);\n        cg.__data__ = item;\n        const fg = domCreate(doc, 'path', svgns);\n        node.appendChild(fg);\n        fg.__data__ = item;\n        fg.__values__ = {\n          fill: 'default'\n        };\n      }\n    }\n  }\n\n  // (re-)insert if (a) not contained in SVG or (b) sibling order has changed\n  if (node.ownerSVGElement !== svg || siblingCheck(node, sibling)) {\n    el.insertBefore(node, sibling ? sibling.nextSibling : el.firstChild);\n  }\n  return node;\n}\n\n// check if two nodes are ordered siblings\nfunction siblingCheck(node, sibling) {\n  return node.parentNode && node.parentNode.childNodes.length > 1 && node.previousSibling != sibling; // treat null/undefined the same\n}\n\n// -- Set attributes & styles on SVG elements ---\n\nlet element = null,\n  // temp var for current SVG element\n  values = null; // temp var for current values hash\n\n// Extra configuration for certain mark types\nconst mark_extras = {\n  group(mdef, el, item) {\n    const fg = element = el.childNodes[2];\n    values = fg.__values__;\n    mdef.foreground(emit, item, this);\n    values = el.__values__; // use parent's values hash\n    element = el.childNodes[1];\n    mdef.content(emit, item, this);\n    const bg = element = el.childNodes[0];\n    mdef.background(emit, item, this);\n    const value = item.mark.interactive === false ? 'none' : null;\n    if (value !== values.events) {\n      setAttribute(fg, 'pointer-events', value);\n      setAttribute(bg, 'pointer-events', value);\n      values.events = value;\n    }\n    if (item.strokeForeground && item.stroke) {\n      const fill = item.fill;\n      setAttribute(fg, 'display', null);\n\n      // set style of background\n      this.style(bg, item);\n      setAttribute(bg, 'stroke', null);\n\n      // set style of foreground\n      if (fill) item.fill = null;\n      values = fg.__values__;\n      this.style(fg, item);\n      if (fill) item.fill = fill;\n\n      // leave element null to prevent downstream styling\n      element = null;\n    } else {\n      // ensure foreground is ignored\n      setAttribute(fg, 'display', 'none');\n    }\n  },\n  image(mdef, el, item) {\n    if (item.smooth === false) {\n      setStyle(el, 'image-rendering', 'optimizeSpeed');\n      setStyle(el, 'image-rendering', 'pixelated');\n    } else {\n      setStyle(el, 'image-rendering', null);\n    }\n  },\n  text(mdef, el, item) {\n    const tl = textLines(item);\n    let key, value, doc, lh;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tl)) {\n      // multi-line text\n      value = tl.map(_ => textValue(item, _));\n      key = value.join('\\n'); // content cache key\n\n      if (key !== values.text) {\n        domClear(el, 0);\n        doc = el.ownerDocument;\n        lh = lineHeight(item);\n        value.forEach((t, i) => {\n          const ts = domCreate(doc, 'tspan', svgns);\n          ts.__data__ = item; // data binding\n          ts.textContent = t;\n          if (i) {\n            ts.setAttribute('x', 0);\n            ts.setAttribute('dy', lh);\n          }\n          el.appendChild(ts);\n        });\n        values.text = key;\n      }\n    } else {\n      // single-line text\n      value = textValue(item, tl);\n      if (value !== values.text) {\n        el.textContent = value;\n        values.text = value;\n      }\n    }\n    setAttribute(el, 'font-family', fontFamily(item));\n    setAttribute(el, 'font-size', fontSize(item) + 'px');\n    setAttribute(el, 'font-style', item.fontStyle);\n    setAttribute(el, 'font-variant', item.fontVariant);\n    setAttribute(el, 'font-weight', item.fontWeight);\n  }\n};\nfunction emit(name, value, ns) {\n  // early exit if value is unchanged\n  if (value === values[name]) return;\n\n  // use appropriate method given namespace (ns)\n  if (ns) {\n    setAttributeNS(element, name, value, ns);\n  } else {\n    setAttribute(element, name, value);\n  }\n\n  // note current value for future comparison\n  values[name] = value;\n}\nfunction setStyle(el, name, value) {\n  if (value !== values[name]) {\n    if (value == null) {\n      el.style.removeProperty(name);\n    } else {\n      el.style.setProperty(name, value + '');\n    }\n    values[name] = value;\n  }\n}\nfunction setAttributes(el, attrs) {\n  for (const key in attrs) {\n    setAttribute(el, key, attrs[key]);\n  }\n}\nfunction setAttribute(el, name, value) {\n  if (value != null) {\n    // if value is provided, update DOM attribute\n    el.setAttribute(name, value);\n  } else {\n    // else remove DOM attribute\n    el.removeAttribute(name);\n  }\n}\nfunction setAttributeNS(el, name, value, ns) {\n  if (value != null) {\n    // if value is provided, update DOM attribute\n    el.setAttributeNS(ns, name, value);\n  } else {\n    // else remove DOM attribute\n    el.removeAttributeNS(ns, name);\n  }\n}\nfunction href() {\n  let loc;\n  return typeof window === 'undefined' ? '' : (loc = window.location).hash ? loc.href.slice(0, -loc.hash.length) : loc.href;\n}\n\nfunction SVGStringRenderer(loader) {\n  Renderer.call(this, loader);\n  this._text = null;\n  this._defs = {\n    gradient: {},\n    clipping: {}\n  };\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(SVGStringRenderer, Renderer, {\n  /**\n   * Returns the rendered SVG text string,\n   * or null if rendering has not yet occurred.\n   */\n  svg() {\n    return this._text;\n  },\n  /**\n   * Internal rendering method.\n   * @param {object} scene - The root mark of a scenegraph to render.\n   */\n  _render(scene) {\n    const m = markup();\n\n    // svg tag\n    m.open('svg', (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, metadata, {\n      class: 'marks',\n      width: this._width * this._scale,\n      height: this._height * this._scale,\n      viewBox: `0 0 ${this._width} ${this._height}`\n    }));\n\n    // background, if defined\n    const bg = this._bgcolor;\n    if (bg && bg !== 'transparent' && bg !== 'none') {\n      m.open('rect', {\n        width: this._width,\n        height: this._height,\n        fill: bg\n      }).close();\n    }\n\n    // root content group\n    m.open('g', rootAttributes, {\n      transform: 'translate(' + this._origin + ')'\n    });\n    this.mark(m, scene);\n    m.close(); // </g>\n\n    // defs\n    this.defs(m);\n\n    // get SVG text string\n    this._text = m.close() + '';\n    return this;\n  },\n  /**\n   * Render a set of mark items.\n   * @param {object} m - The markup context.\n   * @param {object} scene - The mark parent to render.\n   */\n  mark(m, scene) {\n    const mdef = Marks[scene.marktype],\n      tag = mdef.tag,\n      attrList = [ariaItemAttributes, mdef.attr];\n\n    // render opening group tag\n    m.open('g', {\n      'class': cssClass(scene),\n      'clip-path': scene.clip ? clip$1(this, scene, scene.group) : null\n    }, ariaMarkAttributes(scene), {\n      'pointer-events': tag !== 'g' && scene.interactive === false ? 'none' : null\n    });\n\n    // render contained elements\n    const process = item => {\n      const href = this.href(item);\n      if (href) m.open('a', href);\n      m.open(tag, this.attr(scene, item, attrList, tag !== 'g' ? tag : null));\n      if (tag === 'text') {\n        const tl = textLines(item);\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(tl)) {\n          // multi-line text\n          const attrs = {\n            x: 0,\n            dy: lineHeight(item)\n          };\n          for (let i = 0; i < tl.length; ++i) {\n            m.open('tspan', i ? attrs : null).text(textValue(item, tl[i])).close();\n          }\n        } else {\n          // single-line text\n          m.text(textValue(item, tl));\n        }\n      } else if (tag === 'g') {\n        const fore = item.strokeForeground,\n          fill = item.fill,\n          stroke = item.stroke;\n        if (fore && stroke) {\n          item.stroke = null;\n        }\n        m.open('path', this.attr(scene, item, mdef.background, 'bgrect')).close();\n\n        // recurse for group content\n        m.open('g', this.attr(scene, item, mdef.content));\n        visit(item, scene => this.mark(m, scene));\n        m.close();\n        if (fore && stroke) {\n          if (fill) item.fill = null;\n          item.stroke = stroke;\n          m.open('path', this.attr(scene, item, mdef.foreground, 'bgrect')).close();\n          if (fill) item.fill = fill;\n        } else {\n          m.open('path', this.attr(scene, item, mdef.foreground, 'bgfore')).close();\n        }\n      }\n      m.close(); // </tag>\n      if (href) m.close(); // </a>\n    };\n\n    if (mdef.nested) {\n      if (scene.items && scene.items.length) process(scene.items[0]);\n    } else {\n      visit(scene, process);\n    }\n\n    // render closing group tag\n    return m.close(); // </g>\n  },\n\n  /**\n   * Get href attributes for a hyperlinked mark item.\n   * @param {Item} item - The mark item.\n   */\n  href(item) {\n    const href = item.href;\n    let attr;\n    if (href) {\n      if (attr = this._hrefs && this._hrefs[href]) {\n        return attr;\n      } else {\n        this.sanitizeURL(href).then(attr => {\n          // rewrite to use xlink namespace\n          attr['xlink:href'] = attr.href;\n          attr.href = null;\n          (this._hrefs || (this._hrefs = {}))[href] = attr;\n        });\n      }\n    }\n    return null;\n  },\n  /**\n   * Get an object of SVG attributes for a mark item.\n   * @param {object} scene - The mark parent.\n   * @param {Item} item - The mark item.\n   * @param {array|function} attrs - One or more attribute emitters.\n   * @param {string} tag - The tag being rendered.\n   */\n  attr(scene, item, attrs, tag) {\n    const object = {},\n      emit = (name, value, ns, prefixed) => {\n        object[prefixed || name] = value;\n      };\n\n    // apply mark specific attributes\n    if (Array.isArray(attrs)) {\n      attrs.forEach(fn => fn(emit, item, this));\n    } else {\n      attrs(emit, item, this);\n    }\n\n    // apply style attributes\n    if (tag) {\n      style(object, item, scene, tag, this._defs);\n    }\n    return object;\n  },\n  /**\n   * Render SVG defs, as needed.\n   * Must be called *after* marks have been processed to ensure the\n   * collected state is current and accurate.\n   * @param {object} m - The markup context.\n   */\n  defs(m) {\n    const gradient = this._defs.gradient,\n      clipping = this._defs.clipping,\n      count = Object.keys(gradient).length + Object.keys(clipping).length;\n    if (count === 0) return; // nothing to do\n\n    m.open('defs');\n    for (const id in gradient) {\n      const def = gradient[id],\n        stops = def.stops;\n      if (def.gradient === 'radial') {\n        // SVG radial gradients automatically transform to normalized bbox\n        // coordinates, in a way that is cumbersome to replicate in canvas.\n        // We wrap the radial gradient in a pattern element, allowing us to\n        // maintain a circular gradient that matches what canvas provides.\n\n        m.open('pattern', {\n          id: patternPrefix + id,\n          viewBox: '0,0,1,1',\n          width: '100%',\n          height: '100%',\n          preserveAspectRatio: 'xMidYMid slice'\n        });\n        m.open('rect', {\n          width: '1',\n          height: '1',\n          fill: 'url(#' + id + ')'\n        }).close();\n        m.close(); // </pattern>\n\n        m.open('radialGradient', {\n          id: id,\n          fx: def.x1,\n          fy: def.y1,\n          fr: def.r1,\n          cx: def.x2,\n          cy: def.y2,\n          r: def.r2\n        });\n      } else {\n        m.open('linearGradient', {\n          id: id,\n          x1: def.x1,\n          x2: def.x2,\n          y1: def.y1,\n          y2: def.y2\n        });\n      }\n      for (let i = 0; i < stops.length; ++i) {\n        m.open('stop', {\n          offset: stops[i].offset,\n          'stop-color': stops[i].color\n        }).close();\n      }\n      m.close();\n    }\n    for (const id in clipping) {\n      const def = clipping[id];\n      m.open('clipPath', {\n        id: id\n      });\n      if (def.path) {\n        m.open('path', {\n          d: def.path\n        }).close();\n      } else {\n        m.open('rect', {\n          x: 0,\n          y: 0,\n          width: def.width,\n          height: def.height\n        }).close();\n      }\n      m.close();\n    }\n    m.close();\n  }\n});\n\n// Helper function for attr for style presentation attributes\nfunction style(s, item, scene, tag, defs) {\n  let styleList;\n  if (item == null) return s;\n  if (tag === 'bgrect' && scene.interactive === false) {\n    s['pointer-events'] = 'none';\n  }\n  if (tag === 'bgfore') {\n    if (scene.interactive === false) {\n      s['pointer-events'] = 'none';\n    }\n    s.display = 'none';\n    if (item.fill !== null) return s;\n  }\n  if (tag === 'image' && item.smooth === false) {\n    styleList = ['image-rendering: optimizeSpeed;', 'image-rendering: pixelated;'];\n  }\n  if (tag === 'text') {\n    s['font-family'] = fontFamily(item);\n    s['font-size'] = fontSize(item) + 'px';\n    s['font-style'] = item.fontStyle;\n    s['font-variant'] = item.fontVariant;\n    s['font-weight'] = item.fontWeight;\n  }\n  for (const prop in stylesAttr) {\n    let value = item[prop];\n    const name = stylesAttr[prop];\n    if (value === 'transparent' && (name === 'fill' || name === 'stroke')) ; else if (value != null) {\n      if (isGradient(value)) {\n        value = gradientRef(value, defs.gradient, '');\n      }\n      s[name] = value;\n    }\n  }\n  for (const prop in stylesCss) {\n    const value = item[prop];\n    if (value != null) {\n      styleList = styleList || [];\n      styleList.push(`${stylesCss[prop]}: ${value};`);\n    }\n  }\n  if (styleList) {\n    s.style = styleList.join(' ');\n  }\n  return s;\n}\n\nconst Canvas = 'canvas';\nconst PNG = 'png';\nconst SVG = 'svg';\nconst None = 'none';\nconst RenderType = {\n  Canvas: Canvas,\n  PNG: PNG,\n  SVG: SVG,\n  None: None\n};\nconst modules = {};\nmodules[Canvas] = modules[PNG] = {\n  renderer: CanvasRenderer,\n  headless: CanvasRenderer,\n  handler: CanvasHandler\n};\nmodules[SVG] = {\n  renderer: SVGRenderer,\n  headless: SVGStringRenderer,\n  handler: SVGHandler\n};\nmodules[None] = {};\nfunction renderModule(name, _) {\n  name = String(name || '').toLowerCase();\n  if (arguments.length > 1) {\n    modules[name] = _;\n    return this;\n  } else {\n    return modules[name];\n  }\n}\n\nfunction intersect(scene, bounds, filter) {\n  const hits = [],\n    // intersection results\n    box = new Bounds().union(bounds),\n    // defensive copy\n    type = scene.marktype;\n  return type ? intersectMark(scene, box, filter, hits) : type === 'group' ? intersectGroup(scene, box, filter, hits) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Intersect scene must be mark node or group item.');\n}\nfunction intersectMark(mark, box, filter, hits) {\n  if (visitMark(mark, box, filter)) {\n    const items = mark.items,\n      type = mark.marktype,\n      n = items.length;\n    let i = 0;\n    if (type === 'group') {\n      for (; i < n; ++i) {\n        intersectGroup(items[i], box, filter, hits);\n      }\n    } else {\n      for (const test = Marks[type].isect; i < n; ++i) {\n        const item = items[i];\n        if (intersectItem(item, box, test)) hits.push(item);\n      }\n    }\n  }\n  return hits;\n}\nfunction visitMark(mark, box, filter) {\n  // process if bounds intersect and if\n  // (1) mark is a group mark (so we must recurse), or\n  // (2) mark is interactive and passes filter\n  return mark.bounds && box.intersects(mark.bounds) && (mark.marktype === 'group' || mark.interactive !== false && (!filter || filter(mark)));\n}\nfunction intersectGroup(group, box, filter, hits) {\n  // test intersect against group\n  // skip groups by default unless filter says otherwise\n  if (filter && filter(group.mark) && intersectItem(group, box, Marks.group.isect)) {\n    hits.push(group);\n  }\n\n  // recursively test children marks\n  // translate box to group coordinate space\n  const marks = group.items,\n    n = marks && marks.length;\n  if (n) {\n    const x = group.x || 0,\n      y = group.y || 0;\n    box.translate(-x, -y);\n    for (let i = 0; i < n; ++i) {\n      intersectMark(marks[i], box, filter, hits);\n    }\n    box.translate(x, y);\n  }\n  return hits;\n}\nfunction intersectItem(item, box, test) {\n  // test bounds enclosure, bounds intersection, then detailed test\n  const bounds = item.bounds;\n  return box.encloses(bounds) || box.intersects(bounds) && test(item, box);\n}\n\nconst clipBounds = new Bounds();\nfunction boundClip (mark) {\n  const clip = mark.clip;\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction)(clip)) {\n    clip(boundContext(clipBounds.clear()));\n  } else if (clip) {\n    clipBounds.set(0, 0, mark.group.width, mark.group.height);\n  } else return;\n  mark.bounds.intersect(clipBounds);\n}\n\nconst TOLERANCE = 1e-9;\nfunction sceneEqual(a, b, key) {\n  return a === b ? true : key === 'path' ? pathEqual(a, b) : a instanceof Date && b instanceof Date ? +a === +b : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(a) && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber)(b) ? Math.abs(a - b) <= TOLERANCE : !a || !b || !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(a) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(b) ? a == b : objectEqual(a, b);\n}\nfunction pathEqual(a, b) {\n  return sceneEqual(parse(a), parse(b));\n}\nfunction objectEqual(a, b) {\n  var ka = Object.keys(a),\n    kb = Object.keys(b),\n    key,\n    i;\n  if (ka.length !== kb.length) return false;\n  ka.sort();\n  kb.sort();\n  for (i = ka.length - 1; i >= 0; i--) {\n    if (ka[i] != kb[i]) return false;\n  }\n  for (i = ka.length - 1; i >= 0; i--) {\n    key = ka[i];\n    if (!sceneEqual(a[key], b[key], key)) return false;\n  }\n  return typeof a === typeof b;\n}\n\nfunction resetSVGDefIds() {\n  resetSVGClipId();\n  resetSVGGradientId();\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js?");

/***/ }),

/***/ "../../node_modules/vega-schema-url-parser/dist/parser.module.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/vega-schema-url-parser/dist/parser.module.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction e(e){const[n,r]=/schema\\/([\\w-]+)\\/([\\w\\.\\-]+)\\.json$/g.exec(e).slice(1,3);return{library:n,version:r}}/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (e);\n//# sourceMappingURL=parser.module.js.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-schema-url-parser/dist/parser.module.js?");

/***/ }),

/***/ "../../node_modules/vega-selections/build/vega-selection.module.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/vega-selections/build/vega-selection.module.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   selectionIdTest: () => (/* binding */ selectionIdTest),\n/* harmony export */   selectionResolve: () => (/* binding */ selectionResolve),\n/* harmony export */   selectionTest: () => (/* binding */ selectionTest),\n/* harmony export */   selectionTuples: () => (/* binding */ selectionTuples),\n/* harmony export */   selectionVisitor: () => (/* binding */ selectionVisitor)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/vega-selections/node_modules/d3-array/src/bisector.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/vega-selections/node_modules/d3-array/src/union.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-array */ \"../../node_modules/vega-selections/node_modules/d3-array/src/intersection.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_expression__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-expression */ \"../../node_modules/vega-expression/build/vega-expression.module.js\");\n\n\n\n\nconst Intersect = 'intersect';\nconst Union = 'union';\nconst VlMulti = 'vlMulti';\nconst VlPoint = 'vlPoint';\nconst Or = 'or';\nconst And = 'and';\nconst SelectionId = '_vgsid_';\nconst $selectionId = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(SelectionId);\n\nconst TYPE_ENUM = 'E',\n  TYPE_RANGE_INC = 'R',\n  TYPE_RANGE_EXC = 'R-E',\n  TYPE_RANGE_LE = 'R-LE',\n  TYPE_RANGE_RE = 'R-RE',\n  UNIT_INDEX = 'index:unit';\n\n// TODO: revisit date coercion?\nfunction testPoint(datum, entry) {\n  var fields = entry.fields,\n    values = entry.values,\n    n = fields.length,\n    i = 0,\n    dval,\n    f;\n  for (; i < n; ++i) {\n    f = fields[i];\n    f.getter = vega_util__WEBPACK_IMPORTED_MODULE_0__.field.getter || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(f.field);\n    dval = f.getter(datum);\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate)(dval)) dval = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(dval);\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate)(values[i])) values[i] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(values[i]);\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate)(values[i][0])) values[i] = values[i].map(vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber);\n    if (f.type === TYPE_ENUM) {\n      // Enumerated fields can either specify individual values (single/multi selections)\n      // or an array of values (interval selections).\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(values[i]) ? values[i].indexOf(dval) < 0 : dval !== values[i]) {\n        return false;\n      }\n    } else {\n      if (f.type === TYPE_RANGE_INC) {\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange)(dval, values[i])) return false;\n      } else if (f.type === TYPE_RANGE_RE) {\n        // Discrete selection of bins test within the range [bin_start, bin_end).\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange)(dval, values[i], true, false)) return false;\n      } else if (f.type === TYPE_RANGE_EXC) {\n        // 'R-E'/'R-LE' included for completeness.\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange)(dval, values[i], false, false)) return false;\n      } else if (f.type === TYPE_RANGE_LE) {\n        if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange)(dval, values[i], false, true)) return false;\n      }\n    }\n  }\n  return true;\n}\n\n/**\n * Tests if a tuple is contained within an interactive selection.\n * @param {string} name - The name of the data set representing the selection.\n *  Tuples in the dataset are of the form\n *  {unit: string, fields: array<fielddef>, values: array<*>}.\n *  Fielddef is of the form\n *  {field: string, channel: string, type: 'E' | 'R'} where\n *  'type' identifies whether tuples in the dataset enumerate\n *  values for the field, or specify a continuous range.\n * @param {object} datum - The tuple to test for inclusion.\n * @param {string} op - The set operation for combining selections.\n *   One of 'intersect' or 'union' (default).\n * @return {boolean} - True if the datum is in the selection, false otherwise.\n */\nfunction selectionTest(name, datum, op) {\n  var data = this.context.data[name],\n    entries = data ? data.values.value : [],\n    unitIdx = data ? data[UNIT_INDEX] && data[UNIT_INDEX].value : undefined,\n    intersect = op === Intersect,\n    n = entries.length,\n    i = 0,\n    entry,\n    miss,\n    count,\n    unit,\n    b;\n  for (; i < n; ++i) {\n    entry = entries[i];\n    if (unitIdx && intersect) {\n      // multi selections union within the same unit and intersect across units.\n      miss = miss || {};\n      count = miss[unit = entry.unit] || 0;\n\n      // if we've already matched this unit, skip.\n      if (count === -1) continue;\n      b = testPoint(datum, entry);\n      miss[unit] = b ? -1 : ++count;\n\n      // if we match and there are no other units return true\n      // if we've missed against all tuples in this unit return false\n      if (b && unitIdx.size === 1) return true;\n      if (!b && count === unitIdx.get(unit).count) return false;\n    } else {\n      b = testPoint(datum, entry);\n\n      // if we find a miss and we do require intersection return false\n      // if we find a match and we don't require intersection return true\n      if (intersect ^ b) return b;\n    }\n  }\n\n  // if intersecting and we made it here, then we saw no misses\n  // if not intersecting, then we saw no matches\n  // if no active selections, return false\n  return n && intersect;\n}\nconst bisect = (0,d3_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])($selectionId),\n  bisectLeft = bisect.left,\n  bisectRight = bisect.right;\nfunction selectionIdTest(name, datum, op) {\n  const data = this.context.data[name],\n    entries = data ? data.values.value : [],\n    unitIdx = data ? data[UNIT_INDEX] && data[UNIT_INDEX].value : undefined,\n    intersect = op === Intersect,\n    value = $selectionId(datum),\n    index = bisectLeft(entries, value);\n  if (index === entries.length) return false;\n  if ($selectionId(entries[index]) !== value) return false;\n  if (unitIdx && intersect) {\n    if (unitIdx.size === 1) return true;\n    if (bisectRight(entries, value) - index < unitIdx.size) return false;\n  }\n  return true;\n}\n\n/**\n * Maps an array of scene graph items to an array of selection tuples.\n * @param {string} name  - The name of the dataset representing the selection.\n * @param {string} base  - The base object that generated tuples extend.\n *\n * @returns {array} An array of selection entries for the given unit.\n */\nfunction selectionTuples(array, base) {\n  return array.map(x => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(base.fields ? {\n    values: base.fields.map(f => (f.getter || (f.getter = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(f.field)))(x.datum))\n  } : {\n    [SelectionId]: $selectionId(x.datum)\n  }, base));\n}\n\n/**\n * Resolves selection for use as a scale domain or reads via the API.\n * @param {string} name - The name of the dataset representing the selection\n * @param {string} [op='union'] - The set operation for combining selections.\n *                 One of 'intersect' or 'union' (default).\n * @param {boolean} isMulti - Identifies a \"multi\" selection to perform more\n *                 expensive resolution computation.\n * @param {boolean} vl5 - With Vega-Lite v5, \"multi\" selections are now called \"point\"\n *                 selections, and thus the resolved tuple should reflect this name.\n *                 This parameter allows us to reflect this change without triggering\n *                 a major version bump for Vega.\n * @returns {object} An object of selected fields and values.\n */\nfunction selectionResolve(name, op, isMulti, vl5) {\n  var data = this.context.data[name],\n    entries = data ? data.values.value : [],\n    resolved = {},\n    multiRes = {},\n    types = {},\n    entry,\n    fields,\n    values,\n    unit,\n    field,\n    value,\n    res,\n    resUnit,\n    type,\n    union,\n    n = entries.length,\n    i = 0,\n    j,\n    m;\n\n  // First union all entries within the same unit.\n  for (; i < n; ++i) {\n    entry = entries[i];\n    unit = entry.unit;\n    fields = entry.fields;\n    values = entry.values;\n    if (fields && values) {\n      // Intentional selection stores\n      for (j = 0, m = fields.length; j < m; ++j) {\n        field = fields[j];\n        res = resolved[field.field] || (resolved[field.field] = {});\n        resUnit = res[unit] || (res[unit] = []);\n        types[field.field] = type = field.type.charAt(0);\n        union = ops[`${type}_union`];\n        res[unit] = union(resUnit, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(values[j]));\n      }\n\n      // If the same multi-selection is repeated over views and projected over\n      // an encoding, it may operate over different fields making it especially\n      // tricky to reliably resolve it. At best, we can de-dupe identical entries\n      // but doing so may be more computationally expensive than it is worth.\n      // Instead, for now, we simply transform our store representation into\n      // a more human-friendly one.\n      if (isMulti) {\n        resUnit = multiRes[unit] || (multiRes[unit] = []);\n        resUnit.push((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(values).reduce((obj, curr, j) => (obj[fields[j].field] = curr, obj), {}));\n      }\n    } else {\n      // Short circuit extensional selectionId stores which hold sorted IDs unique to each unit.\n      field = SelectionId;\n      value = $selectionId(entry);\n      res = resolved[field] || (resolved[field] = {});\n      resUnit = res[unit] || (res[unit] = []);\n      resUnit.push(value);\n      if (isMulti) {\n        resUnit = multiRes[unit] || (multiRes[unit] = []);\n        resUnit.push({\n          [SelectionId]: value\n        });\n      }\n    }\n  }\n\n  // Then resolve fields across units as per the op.\n  op = op || Union;\n  if (resolved[SelectionId]) {\n    resolved[SelectionId] = ops[`${SelectionId}_${op}`](...Object.values(resolved[SelectionId]));\n  } else {\n    Object.keys(resolved).forEach(field => {\n      resolved[field] = Object.keys(resolved[field]).map(unit => resolved[field][unit]).reduce((acc, curr) => acc === undefined ? curr : ops[`${types[field]}_${op}`](acc, curr));\n    });\n  }\n  entries = Object.keys(multiRes);\n  if (isMulti && entries.length) {\n    const key = vl5 ? VlPoint : VlMulti;\n    resolved[key] = op === Union ? {\n      [Or]: entries.reduce((acc, k) => (acc.push(...multiRes[k]), acc), [])\n    } : {\n      [And]: entries.map(k => ({\n        [Or]: multiRes[k]\n      }))\n    };\n  }\n  return resolved;\n}\nvar ops = {\n  [`${SelectionId}_union`]: d3_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  [`${SelectionId}_intersect`]: d3_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  E_union: function (base, value) {\n    if (!base.length) return value;\n    var i = 0,\n      n = value.length;\n    for (; i < n; ++i) if (base.indexOf(value[i]) < 0) base.push(value[i]);\n    return base;\n  },\n  E_intersect: function (base, value) {\n    return !base.length ? value : base.filter(v => value.indexOf(v) >= 0);\n  },\n  R_union: function (base, value) {\n    var lo = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(value[0]),\n      hi = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(value[1]);\n    if (lo > hi) {\n      lo = value[1];\n      hi = value[0];\n    }\n    if (!base.length) return [lo, hi];\n    if (base[0] > lo) base[0] = lo;\n    if (base[1] < hi) base[1] = hi;\n    return base;\n  },\n  R_intersect: function (base, value) {\n    var lo = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(value[0]),\n      hi = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(value[1]);\n    if (lo > hi) {\n      lo = value[1];\n      hi = value[0];\n    }\n    if (!base.length) return [lo, hi];\n    if (hi < base[0] || base[1] < lo) {\n      return [];\n    } else {\n      if (base[0] < lo) base[0] = lo;\n      if (base[1] > hi) base[1] = hi;\n    }\n    return base;\n  }\n};\n\nconst DataPrefix = ':',\n  IndexPrefix = '@';\nfunction selectionVisitor(name, args, scope, params) {\n  if (args[0].type !== vega_expression__WEBPACK_IMPORTED_MODULE_1__.Literal) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('First argument to selection functions must be a string literal.');\n  const data = args[0].value,\n    op = args.length >= 2 && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(args).value,\n    field = 'unit',\n    indexName = IndexPrefix + field,\n    dataName = DataPrefix + data;\n\n  // eslint-disable-next-line no-prototype-builtins\n  if (op === Intersect && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(params, indexName)) {\n    params[indexName] = scope.getData(data).indataRef(scope, field);\n  }\n\n  // eslint-disable-next-line no-prototype-builtins\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(params, dataName)) {\n    params[dataName] = scope.getData(data).tuplesRef();\n  }\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/build/vega-selection.module.js?");

/***/ }),

/***/ "../../node_modules/vega-statistics/build/vega-statistics.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-statistics/build/vega-statistics.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bandwidthNRD: () => (/* binding */ estimateBandwidth),\n/* harmony export */   bin: () => (/* binding */ bin),\n/* harmony export */   bootstrapCI: () => (/* binding */ bootstrapCI),\n/* harmony export */   cumulativeLogNormal: () => (/* binding */ cumulativeLogNormal),\n/* harmony export */   cumulativeNormal: () => (/* binding */ cumulativeNormal),\n/* harmony export */   cumulativeUniform: () => (/* binding */ cumulativeUniform),\n/* harmony export */   densityLogNormal: () => (/* binding */ densityLogNormal),\n/* harmony export */   densityNormal: () => (/* binding */ densityNormal),\n/* harmony export */   densityUniform: () => (/* binding */ densityUniform),\n/* harmony export */   dotbin: () => (/* binding */ dotbin),\n/* harmony export */   quantileLogNormal: () => (/* binding */ quantileLogNormal),\n/* harmony export */   quantileNormal: () => (/* binding */ quantileNormal),\n/* harmony export */   quantileUniform: () => (/* binding */ quantileUniform),\n/* harmony export */   quantiles: () => (/* binding */ quantiles),\n/* harmony export */   quartiles: () => (/* binding */ quartiles),\n/* harmony export */   random: () => (/* binding */ random),\n/* harmony export */   randomInteger: () => (/* binding */ integer),\n/* harmony export */   randomKDE: () => (/* binding */ kde),\n/* harmony export */   randomLCG: () => (/* binding */ lcg),\n/* harmony export */   randomLogNormal: () => (/* binding */ lognormal),\n/* harmony export */   randomMixture: () => (/* binding */ mixture),\n/* harmony export */   randomNormal: () => (/* binding */ gaussian),\n/* harmony export */   randomUniform: () => (/* binding */ uniform),\n/* harmony export */   regressionConstant: () => (/* binding */ constant),\n/* harmony export */   regressionExp: () => (/* binding */ exp),\n/* harmony export */   regressionLinear: () => (/* binding */ linear),\n/* harmony export */   regressionLoess: () => (/* binding */ loess),\n/* harmony export */   regressionLog: () => (/* binding */ log),\n/* harmony export */   regressionPoly: () => (/* binding */ poly),\n/* harmony export */   regressionPow: () => (/* binding */ pow),\n/* harmony export */   regressionQuad: () => (/* binding */ quad),\n/* harmony export */   sampleCurve: () => (/* binding */ sampleCurve),\n/* harmony export */   sampleLogNormal: () => (/* binding */ sampleLogNormal),\n/* harmony export */   sampleNormal: () => (/* binding */ sampleNormal),\n/* harmony export */   sampleUniform: () => (/* binding */ sampleUniform),\n/* harmony export */   setRandom: () => (/* binding */ setRandom)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/quantile.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/deviation.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/median.js\");\n\n\nfunction* numbers (values, valueof) {\n  if (valueof == null) {\n    for (let value of values) {\n      if (value != null && value !== '' && (value = +value) >= value) {\n        yield value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      value = valueof(value, ++index, values);\n      if (value != null && value !== '' && (value = +value) >= value) {\n        yield value;\n      }\n    }\n  }\n}\n\nfunction quantiles (array, p, f) {\n  const values = Float64Array.from(numbers(array, f));\n\n  // don't depend on return value from typed array sort call\n  // protects against undefined sort results in Safari (vega/vega-lite#4964)\n  values.sort(d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n  return p.map(_ => (0,d3_array__WEBPACK_IMPORTED_MODULE_1__.quantileSorted)(values, _));\n}\n\nfunction quartiles (array, f) {\n  return quantiles(array, [0.25, 0.50, 0.75], f);\n}\n\n// Scott, D. W. (1992) Multivariate Density Estimation:\n// Theory, Practice, and Visualization. Wiley.\nfunction estimateBandwidth (array, f) {\n  const n = array.length,\n    d = (0,d3_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(array, f),\n    q = quartiles(array, f),\n    h = (q[2] - q[0]) / 1.34,\n    v = Math.min(d, h) || d || Math.abs(q[0]) || 1;\n  return 1.06 * v * Math.pow(n, -0.2);\n}\n\nfunction bin (_) {\n  // determine range\n  const maxb = _.maxbins || 20,\n    base = _.base || 10,\n    logb = Math.log(base),\n    div = _.divide || [5, 2];\n  let min = _.extent[0],\n    max = _.extent[1],\n    step,\n    level,\n    minstep,\n    v,\n    i,\n    n;\n  const span = _.span || max - min || Math.abs(min) || 1;\n  if (_.step) {\n    // if step size is explicitly given, use that\n    step = _.step;\n  } else if (_.steps) {\n    // if provided, limit choice to acceptable step sizes\n    v = span / maxb;\n    for (i = 0, n = _.steps.length; i < n && _.steps[i] < v; ++i);\n    step = _.steps[Math.max(0, i - 1)];\n  } else {\n    // else use span to determine step size\n    level = Math.ceil(Math.log(maxb) / logb);\n    minstep = _.minstep || 0;\n    step = Math.max(minstep, Math.pow(base, Math.round(Math.log(span) / logb) - level));\n\n    // increase step size if too many bins\n    while (Math.ceil(span / step) > maxb) {\n      step *= base;\n    }\n\n    // decrease step size if allowed\n    for (i = 0, n = div.length; i < n; ++i) {\n      v = step / div[i];\n      if (v >= minstep && span / v <= maxb) step = v;\n    }\n  }\n\n  // update precision, min and max\n  v = Math.log(step);\n  const precision = v >= 0 ? 0 : ~~(-v / logb) + 1,\n    eps = Math.pow(base, -precision - 1);\n  if (_.nice || _.nice === undefined) {\n    v = Math.floor(min / step + eps) * step;\n    min = min < v ? v - step : v;\n    max = Math.ceil(max / step) * step;\n  }\n  return {\n    start: min,\n    stop: max === min ? min + step : max,\n    step: step\n  };\n}\n\nvar random = Math.random;\nfunction setRandom(r) {\n  random = r;\n}\n\nfunction bootstrapCI (array, samples, alpha, f) {\n  if (!array.length) return [undefined, undefined];\n  const values = Float64Array.from(numbers(array, f)),\n    n = values.length,\n    m = samples;\n  let a, i, j, mu;\n  for (j = 0, mu = Array(m); j < m; ++j) {\n    for (a = 0, i = 0; i < n; ++i) {\n      a += values[~~(random() * n)];\n    }\n    mu[j] = a / n;\n  }\n  mu.sort(d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n  return [(0,d3_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(mu, alpha / 2), (0,d3_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(mu, 1 - alpha / 2)];\n}\n\n// Dot density binning for dot plot construction.\n// Based on Leland Wilkinson, Dot Plots, The American Statistician, 1999.\n// https://www.cs.uic.edu/~wilkinson/Publications/dotplots.pdf\nfunction dotbin (array, step, smooth, f) {\n  f = f || (_ => _);\n  const n = array.length,\n    v = new Float64Array(n);\n  let i = 0,\n    j = 1,\n    a = f(array[0]),\n    b = a,\n    w = a + step,\n    x;\n  for (; j < n; ++j) {\n    x = f(array[j]);\n    if (x >= w) {\n      b = (a + b) / 2;\n      for (; i < j; ++i) v[i] = b;\n      w = x + step;\n      a = x;\n    }\n    b = x;\n  }\n  b = (a + b) / 2;\n  for (; i < j; ++i) v[i] = b;\n  return smooth ? smoothing(v, step + step / 4) : v;\n}\n\n// perform smoothing to reduce variance\n// swap points between \"adjacent\" stacks\n// Wilkinson defines adjacent as within step/4 units\nfunction smoothing(v, thresh) {\n  const n = v.length;\n  let a = 0,\n    b = 1,\n    c,\n    d;\n\n  // get left stack\n  while (v[a] === v[b]) ++b;\n  while (b < n) {\n    // get right stack\n    c = b + 1;\n    while (v[b] === v[c]) ++c;\n\n    // are stacks adjacent?\n    // if so, compare sizes and swap as needed\n    if (v[b] - v[b - 1] < thresh) {\n      d = b + (a + c - b - b >> 1);\n      while (d < b) v[d++] = v[b];\n      while (d > b) v[d--] = v[a];\n    }\n\n    // update left stack indices\n    a = b;\n    b = c;\n  }\n  return v;\n}\n\nfunction lcg (seed) {\n  // Random numbers using a Linear Congruential Generator with seed value\n  // Uses glibc values from https://en.wikipedia.org/wiki/Linear_congruential_generator\n  return function () {\n    seed = (1103515245 * seed + 12345) % 2147483647;\n    return seed / 2147483647;\n  };\n}\n\nfunction integer (min, max) {\n  if (max == null) {\n    max = min;\n    min = 0;\n  }\n  let a, b, d;\n  const dist = {\n    min(_) {\n      if (arguments.length) {\n        a = _ || 0;\n        d = b - a;\n        return dist;\n      } else {\n        return a;\n      }\n    },\n    max(_) {\n      if (arguments.length) {\n        b = _ || 0;\n        d = b - a;\n        return dist;\n      } else {\n        return b;\n      }\n    },\n    sample() {\n      return a + Math.floor(d * random());\n    },\n    pdf(x) {\n      return x === Math.floor(x) && x >= a && x < b ? 1 / d : 0;\n    },\n    cdf(x) {\n      const v = Math.floor(x);\n      return v < a ? 0 : v >= b ? 1 : (v - a + 1) / d;\n    },\n    icdf(p) {\n      return p >= 0 && p <= 1 ? a - 1 + Math.floor(p * d) : NaN;\n    }\n  };\n  return dist.min(min).max(max);\n}\n\nconst SQRT2PI = Math.sqrt(2 * Math.PI);\nconst SQRT2 = Math.SQRT2;\n\nlet nextSample = NaN;\nfunction sampleNormal(mean, stdev) {\n  mean = mean || 0;\n  stdev = stdev == null ? 1 : stdev;\n  let x = 0,\n    y = 0,\n    rds,\n    c;\n  if (nextSample === nextSample) {\n    x = nextSample;\n    nextSample = NaN;\n  } else {\n    do {\n      x = random() * 2 - 1;\n      y = random() * 2 - 1;\n      rds = x * x + y * y;\n    } while (rds === 0 || rds > 1);\n    c = Math.sqrt(-2 * Math.log(rds) / rds); // Box-Muller transform\n    x *= c;\n    nextSample = y * c;\n  }\n  return mean + x * stdev;\n}\nfunction densityNormal(value, mean, stdev) {\n  stdev = stdev == null ? 1 : stdev;\n  const z = (value - (mean || 0)) / stdev;\n  return Math.exp(-0.5 * z * z) / (stdev * SQRT2PI);\n}\n\n// Approximation from West (2009)\n// Better Approximations to Cumulative Normal Functions\nfunction cumulativeNormal(value, mean, stdev) {\n  mean = mean || 0;\n  stdev = stdev == null ? 1 : stdev;\n  const z = (value - mean) / stdev,\n    Z = Math.abs(z);\n  let cd;\n  if (Z > 37) {\n    cd = 0;\n  } else {\n    const exp = Math.exp(-Z * Z / 2);\n    let sum;\n    if (Z < 7.07106781186547) {\n      sum = 3.52624965998911e-02 * Z + 0.700383064443688;\n      sum = sum * Z + 6.37396220353165;\n      sum = sum * Z + 33.912866078383;\n      sum = sum * Z + 112.079291497871;\n      sum = sum * Z + 221.213596169931;\n      sum = sum * Z + 220.206867912376;\n      cd = exp * sum;\n      sum = 8.83883476483184e-02 * Z + 1.75566716318264;\n      sum = sum * Z + 16.064177579207;\n      sum = sum * Z + 86.7807322029461;\n      sum = sum * Z + 296.564248779674;\n      sum = sum * Z + 637.333633378831;\n      sum = sum * Z + 793.826512519948;\n      sum = sum * Z + 440.413735824752;\n      cd = cd / sum;\n    } else {\n      sum = Z + 0.65;\n      sum = Z + 4 / sum;\n      sum = Z + 3 / sum;\n      sum = Z + 2 / sum;\n      sum = Z + 1 / sum;\n      cd = exp / sum / 2.506628274631;\n    }\n  }\n  return z > 0 ? 1 - cd : cd;\n}\n\n// Approximation of Probit function using inverse error function.\nfunction quantileNormal(p, mean, stdev) {\n  if (p < 0 || p > 1) return NaN;\n  return (mean || 0) + (stdev == null ? 1 : stdev) * SQRT2 * erfinv(2 * p - 1);\n}\n\n// Approximate inverse error function. Implementation from \"Approximating\n// the erfinv function\" by Mike Giles, GPU Computing Gems, volume 2, 2010.\n// Ported from Apache Commons Math, http://www.apache.org/licenses/LICENSE-2.0\nfunction erfinv(x) {\n  // beware that the logarithm argument must be\n  // commputed as (1.0 - x) * (1.0 + x),\n  // it must NOT be simplified as 1.0 - x * x as this\n  // would induce rounding errors near the boundaries +/-1\n  let w = -Math.log((1 - x) * (1 + x)),\n    p;\n  if (w < 6.25) {\n    w -= 3.125;\n    p = -3.6444120640178196996e-21;\n    p = -1.685059138182016589e-19 + p * w;\n    p = 1.2858480715256400167e-18 + p * w;\n    p = 1.115787767802518096e-17 + p * w;\n    p = -1.333171662854620906e-16 + p * w;\n    p = 2.0972767875968561637e-17 + p * w;\n    p = 6.6376381343583238325e-15 + p * w;\n    p = -4.0545662729752068639e-14 + p * w;\n    p = -8.1519341976054721522e-14 + p * w;\n    p = 2.6335093153082322977e-12 + p * w;\n    p = -1.2975133253453532498e-11 + p * w;\n    p = -5.4154120542946279317e-11 + p * w;\n    p = 1.051212273321532285e-09 + p * w;\n    p = -4.1126339803469836976e-09 + p * w;\n    p = -2.9070369957882005086e-08 + p * w;\n    p = 4.2347877827932403518e-07 + p * w;\n    p = -1.3654692000834678645e-06 + p * w;\n    p = -1.3882523362786468719e-05 + p * w;\n    p = 0.0001867342080340571352 + p * w;\n    p = -0.00074070253416626697512 + p * w;\n    p = -0.0060336708714301490533 + p * w;\n    p = 0.24015818242558961693 + p * w;\n    p = 1.6536545626831027356 + p * w;\n  } else if (w < 16.0) {\n    w = Math.sqrt(w) - 3.25;\n    p = 2.2137376921775787049e-09;\n    p = 9.0756561938885390979e-08 + p * w;\n    p = -2.7517406297064545428e-07 + p * w;\n    p = 1.8239629214389227755e-08 + p * w;\n    p = 1.5027403968909827627e-06 + p * w;\n    p = -4.013867526981545969e-06 + p * w;\n    p = 2.9234449089955446044e-06 + p * w;\n    p = 1.2475304481671778723e-05 + p * w;\n    p = -4.7318229009055733981e-05 + p * w;\n    p = 6.8284851459573175448e-05 + p * w;\n    p = 2.4031110387097893999e-05 + p * w;\n    p = -0.0003550375203628474796 + p * w;\n    p = 0.00095328937973738049703 + p * w;\n    p = -0.0016882755560235047313 + p * w;\n    p = 0.0024914420961078508066 + p * w;\n    p = -0.0037512085075692412107 + p * w;\n    p = 0.005370914553590063617 + p * w;\n    p = 1.0052589676941592334 + p * w;\n    p = 3.0838856104922207635 + p * w;\n  } else if (Number.isFinite(w)) {\n    w = Math.sqrt(w) - 5.0;\n    p = -2.7109920616438573243e-11;\n    p = -2.5556418169965252055e-10 + p * w;\n    p = 1.5076572693500548083e-09 + p * w;\n    p = -3.7894654401267369937e-09 + p * w;\n    p = 7.6157012080783393804e-09 + p * w;\n    p = -1.4960026627149240478e-08 + p * w;\n    p = 2.9147953450901080826e-08 + p * w;\n    p = -6.7711997758452339498e-08 + p * w;\n    p = 2.2900482228026654717e-07 + p * w;\n    p = -9.9298272942317002539e-07 + p * w;\n    p = 4.5260625972231537039e-06 + p * w;\n    p = -1.9681778105531670567e-05 + p * w;\n    p = 7.5995277030017761139e-05 + p * w;\n    p = -0.00021503011930044477347 + p * w;\n    p = -0.00013871931833623122026 + p * w;\n    p = 1.0103004648645343977 + p * w;\n    p = 4.8499064014085844221 + p * w;\n  } else {\n    p = Infinity;\n  }\n  return p * x;\n}\nfunction gaussian (mean, stdev) {\n  let mu, sigma;\n  const dist = {\n    mean(_) {\n      if (arguments.length) {\n        mu = _ || 0;\n        return dist;\n      } else {\n        return mu;\n      }\n    },\n    stdev(_) {\n      if (arguments.length) {\n        sigma = _ == null ? 1 : _;\n        return dist;\n      } else {\n        return sigma;\n      }\n    },\n    sample: () => sampleNormal(mu, sigma),\n    pdf: value => densityNormal(value, mu, sigma),\n    cdf: value => cumulativeNormal(value, mu, sigma),\n    icdf: p => quantileNormal(p, mu, sigma)\n  };\n  return dist.mean(mean).stdev(stdev);\n}\n\nfunction kde (support, bandwidth) {\n  const kernel = gaussian();\n  let n = 0;\n  const dist = {\n    data(_) {\n      if (arguments.length) {\n        support = _;\n        n = _ ? _.length : 0;\n        return dist.bandwidth(bandwidth);\n      } else {\n        return support;\n      }\n    },\n    bandwidth(_) {\n      if (!arguments.length) return bandwidth;\n      bandwidth = _;\n      if (!bandwidth && support) bandwidth = estimateBandwidth(support);\n      return dist;\n    },\n    sample() {\n      return support[~~(random() * n)] + bandwidth * kernel.sample();\n    },\n    pdf(x) {\n      let y = 0,\n        i = 0;\n      for (; i < n; ++i) {\n        y += kernel.pdf((x - support[i]) / bandwidth);\n      }\n      return y / bandwidth / n;\n    },\n    cdf(x) {\n      let y = 0,\n        i = 0;\n      for (; i < n; ++i) {\n        y += kernel.cdf((x - support[i]) / bandwidth);\n      }\n      return y / n;\n    },\n    icdf() {\n      throw Error('KDE icdf not supported.');\n    }\n  };\n  return dist.data(support);\n}\n\nfunction sampleLogNormal(mean, stdev) {\n  mean = mean || 0;\n  stdev = stdev == null ? 1 : stdev;\n  return Math.exp(mean + sampleNormal() * stdev);\n}\nfunction densityLogNormal(value, mean, stdev) {\n  if (value <= 0) return 0;\n  mean = mean || 0;\n  stdev = stdev == null ? 1 : stdev;\n  const z = (Math.log(value) - mean) / stdev;\n  return Math.exp(-0.5 * z * z) / (stdev * SQRT2PI * value);\n}\nfunction cumulativeLogNormal(value, mean, stdev) {\n  return cumulativeNormal(Math.log(value), mean, stdev);\n}\nfunction quantileLogNormal(p, mean, stdev) {\n  return Math.exp(quantileNormal(p, mean, stdev));\n}\nfunction lognormal (mean, stdev) {\n  let mu, sigma;\n  const dist = {\n    mean(_) {\n      if (arguments.length) {\n        mu = _ || 0;\n        return dist;\n      } else {\n        return mu;\n      }\n    },\n    stdev(_) {\n      if (arguments.length) {\n        sigma = _ == null ? 1 : _;\n        return dist;\n      } else {\n        return sigma;\n      }\n    },\n    sample: () => sampleLogNormal(mu, sigma),\n    pdf: value => densityLogNormal(value, mu, sigma),\n    cdf: value => cumulativeLogNormal(value, mu, sigma),\n    icdf: p => quantileLogNormal(p, mu, sigma)\n  };\n  return dist.mean(mean).stdev(stdev);\n}\n\nfunction mixture (dists, weights) {\n  let m = 0,\n    w;\n  function normalize(x) {\n    const w = [];\n    let sum = 0,\n      i;\n    for (i = 0; i < m; ++i) {\n      sum += w[i] = x[i] == null ? 1 : +x[i];\n    }\n    for (i = 0; i < m; ++i) {\n      w[i] /= sum;\n    }\n    return w;\n  }\n  const dist = {\n    weights(_) {\n      if (arguments.length) {\n        w = normalize(weights = _ || []);\n        return dist;\n      }\n      return weights;\n    },\n    distributions(_) {\n      if (arguments.length) {\n        if (_) {\n          m = _.length;\n          dists = _;\n        } else {\n          m = 0;\n          dists = [];\n        }\n        return dist.weights(weights);\n      }\n      return dists;\n    },\n    sample() {\n      const r = random();\n      let d = dists[m - 1],\n        v = w[0],\n        i = 0;\n\n      // first select distribution\n      for (; i < m - 1; v += w[++i]) {\n        if (r < v) {\n          d = dists[i];\n          break;\n        }\n      }\n      // then sample from it\n      return d.sample();\n    },\n    pdf(x) {\n      let p = 0,\n        i = 0;\n      for (; i < m; ++i) {\n        p += w[i] * dists[i].pdf(x);\n      }\n      return p;\n    },\n    cdf(x) {\n      let p = 0,\n        i = 0;\n      for (; i < m; ++i) {\n        p += w[i] * dists[i].cdf(x);\n      }\n      return p;\n    },\n    icdf() {\n      throw Error('Mixture icdf not supported.');\n    }\n  };\n  return dist.distributions(dists).weights(weights);\n}\n\nfunction sampleUniform(min, max) {\n  if (max == null) {\n    max = min == null ? 1 : min;\n    min = 0;\n  }\n  return min + (max - min) * random();\n}\nfunction densityUniform(value, min, max) {\n  if (max == null) {\n    max = min == null ? 1 : min;\n    min = 0;\n  }\n  return value >= min && value <= max ? 1 / (max - min) : 0;\n}\nfunction cumulativeUniform(value, min, max) {\n  if (max == null) {\n    max = min == null ? 1 : min;\n    min = 0;\n  }\n  return value < min ? 0 : value > max ? 1 : (value - min) / (max - min);\n}\nfunction quantileUniform(p, min, max) {\n  if (max == null) {\n    max = min == null ? 1 : min;\n    min = 0;\n  }\n  return p >= 0 && p <= 1 ? min + p * (max - min) : NaN;\n}\nfunction uniform (min, max) {\n  let a, b;\n  const dist = {\n    min(_) {\n      if (arguments.length) {\n        a = _ || 0;\n        return dist;\n      } else {\n        return a;\n      }\n    },\n    max(_) {\n      if (arguments.length) {\n        b = _ == null ? 1 : _;\n        return dist;\n      } else {\n        return b;\n      }\n    },\n    sample: () => sampleUniform(a, b),\n    pdf: value => densityUniform(value, a, b),\n    cdf: value => cumulativeUniform(value, a, b),\n    icdf: p => quantileUniform(p, a, b)\n  };\n  if (max == null) {\n    max = min == null ? 1 : min;\n    min = 0;\n  }\n  return dist.min(min).max(max);\n}\n\nfunction constant (data, x, y) {\n  let mean = 0,\n    n = 0;\n  for (const d of data) {\n    const val = y(d);\n    if (x(d) == null || val == null || isNaN(val)) continue;\n    mean += (val - mean) / ++n;\n  }\n  return {\n    coef: [mean],\n    predict: () => mean,\n    rSquared: 0\n  };\n}\n\n// Ordinary Least Squares\nfunction ols (uX, uY, uXY, uX2) {\n  const delta = uX2 - uX * uX,\n    slope = Math.abs(delta) < 1e-24 ? 0 : (uXY - uX * uY) / delta,\n    intercept = uY - slope * uX;\n  return [intercept, slope];\n}\n\nfunction points(data, x, y, sort) {\n  data = data.filter(d => {\n    let u = x(d),\n      v = y(d);\n    return u != null && (u = +u) >= u && v != null && (v = +v) >= v;\n  });\n  if (sort) {\n    data.sort((a, b) => x(a) - x(b));\n  }\n  const n = data.length,\n    X = new Float64Array(n),\n    Y = new Float64Array(n);\n\n  // extract values, calculate means\n  let i = 0,\n    ux = 0,\n    uy = 0,\n    xv,\n    yv,\n    d;\n  for (d of data) {\n    X[i] = xv = +x(d);\n    Y[i] = yv = +y(d);\n    ++i;\n    ux += (xv - ux) / i;\n    uy += (yv - uy) / i;\n  }\n\n  // mean center the data\n  for (i = 0; i < n; ++i) {\n    X[i] -= ux;\n    Y[i] -= uy;\n  }\n  return [X, Y, ux, uy];\n}\nfunction visitPoints(data, x, y, callback) {\n  let i = -1,\n    u,\n    v;\n  for (const d of data) {\n    u = x(d);\n    v = y(d);\n    if (u != null && (u = +u) >= u && v != null && (v = +v) >= v) {\n      callback(u, v, ++i);\n    }\n  }\n}\n\n// Adapted from d3-regression by Harry Stevens\n// License: https://github.com/HarryStevens/d3-regression/blob/master/LICENSE\nfunction rSquared (data, x, y, uY, predict) {\n  let SSE = 0,\n    SST = 0;\n  visitPoints(data, x, y, (dx, dy) => {\n    const sse = dy - predict(dx),\n      sst = dy - uY;\n    SSE += sse * sse;\n    SST += sst * sst;\n  });\n  return 1 - SSE / SST;\n}\n\n// Adapted from d3-regression by Harry Stevens\n// License: https://github.com/HarryStevens/d3-regression/blob/master/LICENSE\nfunction linear (data, x, y) {\n  let X = 0,\n    Y = 0,\n    XY = 0,\n    X2 = 0,\n    n = 0;\n  visitPoints(data, x, y, (dx, dy) => {\n    ++n;\n    X += (dx - X) / n;\n    Y += (dy - Y) / n;\n    XY += (dx * dy - XY) / n;\n    X2 += (dx * dx - X2) / n;\n  });\n  const coef = ols(X, Y, XY, X2),\n    predict = x => coef[0] + coef[1] * x;\n  return {\n    coef: coef,\n    predict: predict,\n    rSquared: rSquared(data, x, y, Y, predict)\n  };\n}\n\n// Adapted from d3-regression by Harry Stevens\n// License: https://github.com/HarryStevens/d3-regression/blob/master/LICENSE\nfunction log (data, x, y) {\n  let X = 0,\n    Y = 0,\n    XY = 0,\n    X2 = 0,\n    n = 0;\n  visitPoints(data, x, y, (dx, dy) => {\n    ++n;\n    dx = Math.log(dx);\n    X += (dx - X) / n;\n    Y += (dy - Y) / n;\n    XY += (dx * dy - XY) / n;\n    X2 += (dx * dx - X2) / n;\n  });\n  const coef = ols(X, Y, XY, X2),\n    predict = x => coef[0] + coef[1] * Math.log(x);\n  return {\n    coef: coef,\n    predict: predict,\n    rSquared: rSquared(data, x, y, Y, predict)\n  };\n}\n\nfunction exp (data, x, y) {\n  // eslint-disable-next-line no-unused-vars\n  const [xv, yv, ux, uy] = points(data, x, y);\n  let YL = 0,\n    XY = 0,\n    XYL = 0,\n    X2Y = 0,\n    n = 0,\n    dx,\n    ly,\n    xy;\n  visitPoints(data, x, y, (_, dy) => {\n    dx = xv[n++];\n    ly = Math.log(dy);\n    xy = dx * dy;\n    YL += (dy * ly - YL) / n;\n    XY += (xy - XY) / n;\n    XYL += (xy * ly - XYL) / n;\n    X2Y += (dx * xy - X2Y) / n;\n  });\n  const [c0, c1] = ols(XY / uy, YL / uy, XYL / uy, X2Y / uy),\n    predict = x => Math.exp(c0 + c1 * (x - ux));\n  return {\n    coef: [Math.exp(c0 - c1 * ux), c1],\n    predict: predict,\n    rSquared: rSquared(data, x, y, uy, predict)\n  };\n}\n\n// Adapted from d3-regression by Harry Stevens\n// License: https://github.com/HarryStevens/d3-regression/blob/master/LICENSE\nfunction pow (data, x, y) {\n  let X = 0,\n    Y = 0,\n    XY = 0,\n    X2 = 0,\n    YS = 0,\n    n = 0;\n  visitPoints(data, x, y, (dx, dy) => {\n    const lx = Math.log(dx),\n      ly = Math.log(dy);\n    ++n;\n    X += (lx - X) / n;\n    Y += (ly - Y) / n;\n    XY += (lx * ly - XY) / n;\n    X2 += (lx * lx - X2) / n;\n    YS += (dy - YS) / n;\n  });\n  const coef = ols(X, Y, XY, X2),\n    predict = x => coef[0] * Math.pow(x, coef[1]);\n  coef[0] = Math.exp(coef[0]);\n  return {\n    coef: coef,\n    predict: predict,\n    rSquared: rSquared(data, x, y, YS, predict)\n  };\n}\n\nfunction quad (data, x, y) {\n  const [xv, yv, ux, uy] = points(data, x, y),\n    n = xv.length;\n  let X2 = 0,\n    X3 = 0,\n    X4 = 0,\n    XY = 0,\n    X2Y = 0,\n    i,\n    dx,\n    dy,\n    x2;\n  for (i = 0; i < n;) {\n    dx = xv[i];\n    dy = yv[i++];\n    x2 = dx * dx;\n    X2 += (x2 - X2) / i;\n    X3 += (x2 * dx - X3) / i;\n    X4 += (x2 * x2 - X4) / i;\n    XY += (dx * dy - XY) / i;\n    X2Y += (x2 * dy - X2Y) / i;\n  }\n  const X2X2 = X4 - X2 * X2,\n    d = X2 * X2X2 - X3 * X3,\n    a = (X2Y * X2 - XY * X3) / d,\n    b = (XY * X2X2 - X2Y * X3) / d,\n    c = -a * X2,\n    predict = x => {\n      x = x - ux;\n      return a * x * x + b * x + c + uy;\n    };\n\n  // transform coefficients back from mean-centered space\n  return {\n    coef: [c - b * ux + a * ux * ux + uy, b - 2 * a * ux, a],\n    predict: predict,\n    rSquared: rSquared(data, x, y, uy, predict)\n  };\n}\n\n// Adapted from d3-regression by Harry Stevens\n// License: https://github.com/HarryStevens/d3-regression/blob/master/LICENSE\n// ... which was adapted from regression-js by Tom Alexander\n// Source: https://github.com/Tom-Alexander/regression-js/blob/master/src/regression.js#L246\n// License: https://github.com/Tom-Alexander/regression-js/blob/master/LICENSE\nfunction poly (data, x, y, order) {\n  // use more efficient methods for lower orders\n  if (order === 0) return constant(data, x, y);\n  if (order === 1) return linear(data, x, y);\n  if (order === 2) return quad(data, x, y);\n  const [xv, yv, ux, uy] = points(data, x, y),\n    n = xv.length,\n    lhs = [],\n    rhs = [],\n    k = order + 1;\n  let i, j, l, v, c;\n  for (i = 0; i < k; ++i) {\n    for (l = 0, v = 0; l < n; ++l) {\n      v += Math.pow(xv[l], i) * yv[l];\n    }\n    lhs.push(v);\n    c = new Float64Array(k);\n    for (j = 0; j < k; ++j) {\n      for (l = 0, v = 0; l < n; ++l) {\n        v += Math.pow(xv[l], i + j);\n      }\n      c[j] = v;\n    }\n    rhs.push(c);\n  }\n  rhs.push(lhs);\n  const coef = gaussianElimination(rhs),\n    predict = x => {\n      x -= ux;\n      let y = uy + coef[0] + coef[1] * x + coef[2] * x * x;\n      for (i = 3; i < k; ++i) y += coef[i] * Math.pow(x, i);\n      return y;\n    };\n  return {\n    coef: uncenter(k, coef, -ux, uy),\n    predict: predict,\n    rSquared: rSquared(data, x, y, uy, predict)\n  };\n}\nfunction uncenter(k, a, x, y) {\n  const z = Array(k);\n  let i, j, v, c;\n\n  // initialize to zero\n  for (i = 0; i < k; ++i) z[i] = 0;\n\n  // polynomial expansion\n  for (i = k - 1; i >= 0; --i) {\n    v = a[i];\n    c = 1;\n    z[i] += v;\n    for (j = 1; j <= i; ++j) {\n      c *= (i + 1 - j) / j; // binomial coefficent\n      z[i - j] += v * Math.pow(x, j) * c;\n    }\n  }\n\n  // bias term\n  z[0] += y;\n  return z;\n}\n\n// Given an array for a two-dimensional matrix and the polynomial order,\n// solve A * x = b using Gaussian elimination.\nfunction gaussianElimination(matrix) {\n  const n = matrix.length - 1,\n    coef = [];\n  let i, j, k, r, t;\n  for (i = 0; i < n; ++i) {\n    r = i; // max row\n    for (j = i + 1; j < n; ++j) {\n      if (Math.abs(matrix[i][j]) > Math.abs(matrix[i][r])) {\n        r = j;\n      }\n    }\n    for (k = i; k < n + 1; ++k) {\n      t = matrix[k][i];\n      matrix[k][i] = matrix[k][r];\n      matrix[k][r] = t;\n    }\n    for (j = i + 1; j < n; ++j) {\n      for (k = n; k >= i; k--) {\n        matrix[k][j] -= matrix[k][i] * matrix[i][j] / matrix[i][i];\n      }\n    }\n  }\n  for (j = n - 1; j >= 0; --j) {\n    t = 0;\n    for (k = j + 1; k < n; ++k) {\n      t += matrix[k][j] * coef[k];\n    }\n    coef[j] = (matrix[n][j] - t) / matrix[j][j];\n  }\n  return coef;\n}\n\nconst maxiters = 2,\n  epsilon = 1e-12;\n\n// Adapted from science.js by Jason Davies\n// Source: https://github.com/jasondavies/science.js/blob/master/src/stats/loess.js\n// License: https://github.com/jasondavies/science.js/blob/master/LICENSE\nfunction loess (data, x, y, bandwidth) {\n  const [xv, yv, ux, uy] = points(data, x, y, true),\n    n = xv.length,\n    bw = Math.max(2, ~~(bandwidth * n)),\n    // # nearest neighbors\n    yhat = new Float64Array(n),\n    residuals = new Float64Array(n),\n    robustWeights = new Float64Array(n).fill(1);\n  for (let iter = -1; ++iter <= maxiters;) {\n    const interval = [0, bw - 1];\n    for (let i = 0; i < n; ++i) {\n      const dx = xv[i],\n        i0 = interval[0],\n        i1 = interval[1],\n        edge = dx - xv[i0] > xv[i1] - dx ? i0 : i1;\n      let W = 0,\n        X = 0,\n        Y = 0,\n        XY = 0,\n        X2 = 0;\n      const denom = 1 / Math.abs(xv[edge] - dx || 1); // avoid singularity!\n\n      for (let k = i0; k <= i1; ++k) {\n        const xk = xv[k],\n          yk = yv[k],\n          w = tricube(Math.abs(dx - xk) * denom) * robustWeights[k],\n          xkw = xk * w;\n        W += w;\n        X += xkw;\n        Y += yk * w;\n        XY += yk * xkw;\n        X2 += xk * xkw;\n      }\n\n      // linear regression fit\n      const [a, b] = ols(X / W, Y / W, XY / W, X2 / W);\n      yhat[i] = a + b * dx;\n      residuals[i] = Math.abs(yv[i] - yhat[i]);\n      updateInterval(xv, i + 1, interval);\n    }\n    if (iter === maxiters) {\n      break;\n    }\n    const medianResidual = (0,d3_array__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(residuals);\n    if (Math.abs(medianResidual) < epsilon) break;\n    for (let i = 0, arg, w; i < n; ++i) {\n      arg = residuals[i] / (6 * medianResidual);\n      // default to epsilon (rather than zero) for large deviations\n      // keeping weights tiny but non-zero prevents singularites\n      robustWeights[i] = arg >= 1 ? epsilon : (w = 1 - arg * arg) * w;\n    }\n  }\n  return output(xv, yhat, ux, uy);\n}\n\n// weighting kernel for local regression\nfunction tricube(x) {\n  return (x = 1 - x * x * x) * x * x;\n}\n\n// advance sliding window interval of nearest neighbors\nfunction updateInterval(xv, i, interval) {\n  const val = xv[i];\n  let left = interval[0],\n    right = interval[1] + 1;\n  if (right >= xv.length) return;\n\n  // step right if distance to new right edge is <= distance to old left edge\n  // step when distance is equal to ensure movement over duplicate x values\n  while (i > left && xv[right] - val <= val - xv[left]) {\n    interval[0] = ++left;\n    interval[1] = right;\n    ++right;\n  }\n}\n\n// generate smoothed output points\n// average points with repeated x values\nfunction output(xv, yhat, ux, uy) {\n  const n = xv.length,\n    out = [];\n  let i = 0,\n    cnt = 0,\n    prev = [],\n    v;\n  for (; i < n; ++i) {\n    v = xv[i] + ux;\n    if (prev[0] === v) {\n      // average output values via online update\n      prev[1] += (yhat[i] - prev[1]) / ++cnt;\n    } else {\n      // add new output point\n      cnt = 0;\n      prev[1] += uy;\n      prev = [v, yhat[i]];\n      out.push(prev);\n    }\n  }\n  prev[1] += uy;\n  return out;\n}\n\n// subdivide up to accuracy of 0.5 degrees\nconst MIN_RADIANS = 0.5 * Math.PI / 180;\n\n// Adaptively sample an interpolated function over a domain extent\nfunction sampleCurve (f, extent, minSteps, maxSteps) {\n  minSteps = minSteps || 25;\n  maxSteps = Math.max(minSteps, maxSteps || 200);\n  const point = x => [x, f(x)],\n    minX = extent[0],\n    maxX = extent[1],\n    span = maxX - minX,\n    stop = span / maxSteps,\n    prev = [point(minX)],\n    next = [];\n  if (minSteps === maxSteps) {\n    // no adaptation, sample uniform grid directly and return\n    for (let i = 1; i < maxSteps; ++i) {\n      prev.push(point(minX + i / minSteps * span));\n    }\n    prev.push(point(maxX));\n    return prev;\n  } else {\n    // sample minimum points on uniform grid\n    // then move on to perform adaptive refinement\n    next.push(point(maxX));\n    for (let i = minSteps; --i > 0;) {\n      next.push(point(minX + i / minSteps * span));\n    }\n  }\n  let p0 = prev[0];\n  let p1 = next[next.length - 1];\n  const sx = 1 / span;\n  const sy = scaleY(p0[1], next);\n  while (p1) {\n    // midpoint for potential curve subdivision\n    const pm = point((p0[0] + p1[0]) / 2);\n    const dx = pm[0] - p0[0] >= stop;\n    if (dx && angleDelta(p0, pm, p1, sx, sy) > MIN_RADIANS) {\n      // maximum resolution has not yet been met, and\n      // subdivision midpoint is sufficiently different from endpoint\n      // save subdivision, push midpoint onto the visitation stack\n      next.push(pm);\n    } else {\n      // subdivision midpoint sufficiently similar to endpoint\n      // skip subdivision, store endpoint, move to next point on the stack\n      p0 = p1;\n      prev.push(p1);\n      next.pop();\n    }\n    p1 = next[next.length - 1];\n  }\n  return prev;\n}\nfunction scaleY(init, points) {\n  let ymin = init;\n  let ymax = init;\n  const n = points.length;\n  for (let i = 0; i < n; ++i) {\n    const y = points[i][1];\n    if (y < ymin) ymin = y;\n    if (y > ymax) ymax = y;\n  }\n  return 1 / (ymax - ymin);\n}\nfunction angleDelta(p, q, r, sx, sy) {\n  const a0 = Math.atan2(sy * (r[1] - p[1]), sx * (r[0] - p[0])),\n    a1 = Math.atan2(sy * (q[1] - p[1]), sx * (q[0] - p[0]));\n  return Math.abs(a0 - a1);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-statistics/build/vega-statistics.module.js?");

/***/ }),

/***/ "../../node_modules/vega-themes/build/vega-themes.module.js":
/*!******************************************************************!*\
  !*** ../../node_modules/vega-themes/build/vega-themes.module.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   carbong10: () => (/* binding */ carbong10),\n/* harmony export */   carbong100: () => (/* binding */ carbong100),\n/* harmony export */   carbong90: () => (/* binding */ carbong90),\n/* harmony export */   carbonwhite: () => (/* binding */ carbonwhite),\n/* harmony export */   dark: () => (/* binding */ darkTheme),\n/* harmony export */   excel: () => (/* binding */ excelTheme),\n/* harmony export */   fivethirtyeight: () => (/* binding */ fiveThirtyEightTheme),\n/* harmony export */   ggplot2: () => (/* binding */ ggplot2Theme),\n/* harmony export */   googlecharts: () => (/* binding */ googlechartsTheme),\n/* harmony export */   latimes: () => (/* binding */ latimesTheme),\n/* harmony export */   powerbi: () => (/* binding */ powerbiTheme),\n/* harmony export */   quartz: () => (/* binding */ quartzTheme),\n/* harmony export */   urbaninstitute: () => (/* binding */ urbanInstituteTheme),\n/* harmony export */   version: () => (/* binding */ version),\n/* harmony export */   vox: () => (/* binding */ voxTheme)\n/* harmony export */ });\nvar name = \"vega-themes\";\nvar version$1 = \"2.14.0\";\nvar description = \"Themes for stylized Vega and Vega-Lite visualizations.\";\nvar keywords = [\"vega\", \"vega-lite\", \"themes\", \"style\"];\nvar license = \"BSD-3-Clause\";\nvar author = {\n  name: \"UW Interactive Data Lab\",\n  url: \"https://idl.cs.washington.edu\"\n};\nvar contributors = [{\n  name: \"Emily Gu\",\n  url: \"https://github.com/emilygu\"\n}, {\n  name: \"Arvind Satyanarayan\",\n  url: \"http://arvindsatya.com\"\n}, {\n  name: \"Jeffrey Heer\",\n  url: \"https://idl.cs.washington.edu\"\n}, {\n  name: \"Dominik Moritz\",\n  url: \"https://www.domoritz.de\"\n}];\nvar main = \"build/vega-themes.js\";\nvar module = \"build/vega-themes.module.js\";\nvar unpkg = \"build/vega-themes.min.js\";\nvar jsdelivr = \"build/vega-themes.min.js\";\nvar types = \"build/vega-themes.module.d.ts\";\nvar repository = {\n  type: \"git\",\n  url: \"https://github.com/vega/vega-themes.git\"\n};\nvar files = [\"src\", \"build\"];\nvar scripts = {\n  prebuild: \"yarn clean\",\n  build: \"rollup -c\",\n  clean: \"rimraf build && rimraf examples/build\",\n  \"copy:data\": \"rsync -r node_modules/vega-datasets/data/* examples/data\",\n  \"copy:build\": \"rsync -r build/* examples/build\",\n  \"deploy:gh\": \"yarn build && mkdir -p examples/build && rsync -r build/* examples/build && gh-pages -d examples\",\n  preversion: \"yarn lint\",\n  serve: \"browser-sync start -s -f build examples --serveStatic examples\",\n  start: \"yarn build && concurrently --kill-others -n Server,Rollup 'yarn serve' 'rollup -c -w'\",\n  format: \"eslint . --fix\",\n  lint: \"eslint .\",\n  release: \"release-it\"\n};\nvar devDependencies = {\n  \"@babel/core\": \"^7.22.9\",\n  \"@babel/plugin-proposal-async-generator-functions\": \"^7.20.7\",\n  \"@babel/plugin-proposal-json-strings\": \"^7.18.6\",\n  \"@babel/plugin-proposal-object-rest-spread\": \"^7.20.7\",\n  \"@babel/plugin-proposal-optional-catch-binding\": \"^7.18.6\",\n  \"@babel/plugin-transform-runtime\": \"^7.22.9\",\n  \"@babel/preset-env\": \"^7.22.9\",\n  \"@babel/preset-typescript\": \"^7.22.5\",\n  \"@release-it/conventional-changelog\": \"^7.0.0\",\n  \"@rollup/plugin-json\": \"^6.0.0\",\n  \"@rollup/plugin-node-resolve\": \"^15.1.0\",\n  \"@rollup/plugin-terser\": \"^0.4.3\",\n  \"@typescript-eslint/eslint-plugin\": \"^6.0.0\",\n  \"@typescript-eslint/parser\": \"^6.0.0\",\n  \"browser-sync\": \"^2.29.3\",\n  concurrently: \"^8.2.0\",\n  eslint: \"^8.45.0\",\n  \"eslint-config-prettier\": \"^8.8.0\",\n  \"eslint-plugin-prettier\": \"^5.0.0\",\n  \"gh-pages\": \"^5.0.0\",\n  prettier: \"^3.0.0\",\n  \"release-it\": \"^16.1.0\",\n  rollup: \"^3.26.2\",\n  \"rollup-plugin-bundle-size\": \"^1.0.3\",\n  \"rollup-plugin-ts\": \"^3.2.0\",\n  typescript: \"^5.1.6\",\n  vega: \"^5.25.0\",\n  \"vega-lite\": \"^5.9.3\"\n};\nvar peerDependencies = {\n  vega: \"*\",\n  \"vega-lite\": \"*\"\n};\nvar dependencies = {};\nvar pkg = {\n  name: name,\n  version: version$1,\n  description: description,\n  keywords: keywords,\n  license: license,\n  author: author,\n  contributors: contributors,\n  main: main,\n  module: module,\n  unpkg: unpkg,\n  jsdelivr: jsdelivr,\n  types: types,\n  repository: repository,\n  files: files,\n  scripts: scripts,\n  devDependencies: devDependencies,\n  peerDependencies: peerDependencies,\n  dependencies: dependencies\n};\n\nconst lightColor = '#fff';\nconst medColor = '#888';\nconst darkTheme = {\n  background: '#333',\n  view: {\n    stroke: medColor\n  },\n  title: {\n    color: lightColor,\n    subtitleColor: lightColor\n  },\n  style: {\n    'guide-label': {\n      fill: lightColor\n    },\n    'guide-title': {\n      fill: lightColor\n    }\n  },\n  axis: {\n    domainColor: lightColor,\n    gridColor: medColor,\n    tickColor: lightColor\n  }\n};\n\nconst markColor$7 = '#4572a7';\nconst excelTheme = {\n  background: '#fff',\n  arc: {\n    fill: markColor$7\n  },\n  area: {\n    fill: markColor$7\n  },\n  line: {\n    stroke: markColor$7,\n    strokeWidth: 2\n  },\n  path: {\n    stroke: markColor$7\n  },\n  rect: {\n    fill: markColor$7\n  },\n  shape: {\n    stroke: markColor$7\n  },\n  symbol: {\n    fill: markColor$7,\n    strokeWidth: 1.5,\n    size: 50\n  },\n  axis: {\n    bandPosition: 0.5,\n    grid: true,\n    gridColor: '#000000',\n    gridOpacity: 1,\n    gridWidth: 0.5,\n    labelPadding: 10,\n    tickSize: 5,\n    tickWidth: 0.5\n  },\n  axisBand: {\n    grid: false,\n    tickExtra: true\n  },\n  legend: {\n    labelBaseline: 'middle',\n    labelFontSize: 11,\n    symbolSize: 50,\n    symbolType: 'square'\n  },\n  range: {\n    category: ['#4572a7', '#aa4643', '#8aa453', '#71598e', '#4598ae', '#d98445', '#94aace', '#d09393', '#b9cc98', '#a99cbc']\n  }\n};\n\nconst markColor$6 = '#30a2da';\nconst axisColor$2 = '#cbcbcb';\nconst guideLabelColor = '#999';\nconst guideTitleColor = '#333';\nconst backgroundColor$2 = '#f0f0f0';\nconst blackTitle = '#333';\nconst fiveThirtyEightTheme = {\n  arc: {\n    fill: markColor$6\n  },\n  area: {\n    fill: markColor$6\n  },\n  axis: {\n    domainColor: axisColor$2,\n    grid: true,\n    gridColor: axisColor$2,\n    gridWidth: 1,\n    labelColor: guideLabelColor,\n    labelFontSize: 10,\n    titleColor: guideTitleColor,\n    tickColor: axisColor$2,\n    tickSize: 10,\n    titleFontSize: 14,\n    titlePadding: 10,\n    labelPadding: 4\n  },\n  axisBand: {\n    grid: false\n  },\n  background: backgroundColor$2,\n  group: {\n    fill: backgroundColor$2\n  },\n  legend: {\n    labelColor: blackTitle,\n    labelFontSize: 11,\n    padding: 1,\n    symbolSize: 30,\n    symbolType: 'square',\n    titleColor: blackTitle,\n    titleFontSize: 14,\n    titlePadding: 10\n  },\n  line: {\n    stroke: markColor$6,\n    strokeWidth: 2\n  },\n  path: {\n    stroke: markColor$6,\n    strokeWidth: 0.5\n  },\n  rect: {\n    fill: markColor$6\n  },\n  range: {\n    category: ['#30a2da', '#fc4f30', '#e5ae38', '#6d904f', '#8b8b8b', '#b96db8', '#ff9e27', '#56cc60', '#52d2ca', '#52689e', '#545454', '#9fe4f8'],\n    diverging: ['#cc0020', '#e77866', '#f6e7e1', '#d6e8ed', '#91bfd9', '#1d78b5'],\n    heatmap: ['#d6e8ed', '#cee0e5', '#91bfd9', '#549cc6', '#1d78b5']\n  },\n  point: {\n    filled: true,\n    shape: 'circle'\n  },\n  shape: {\n    stroke: markColor$6\n  },\n  bar: {\n    binSpacing: 2,\n    fill: markColor$6,\n    stroke: null\n  },\n  title: {\n    anchor: 'start',\n    fontSize: 24,\n    fontWeight: 600,\n    offset: 20\n  }\n};\n\nconst markColor$5 = '#000';\nconst ggplot2Theme = {\n  group: {\n    fill: '#e5e5e5'\n  },\n  arc: {\n    fill: markColor$5\n  },\n  area: {\n    fill: markColor$5\n  },\n  line: {\n    stroke: markColor$5\n  },\n  path: {\n    stroke: markColor$5\n  },\n  rect: {\n    fill: markColor$5\n  },\n  shape: {\n    stroke: markColor$5\n  },\n  symbol: {\n    fill: markColor$5,\n    size: 40\n  },\n  axis: {\n    domain: false,\n    grid: true,\n    gridColor: '#FFFFFF',\n    gridOpacity: 1,\n    labelColor: '#7F7F7F',\n    labelPadding: 4,\n    tickColor: '#7F7F7F',\n    tickSize: 5.67,\n    titleFontSize: 16,\n    titleFontWeight: 'normal'\n  },\n  legend: {\n    labelBaseline: 'middle',\n    labelFontSize: 11,\n    symbolSize: 40\n  },\n  range: {\n    category: ['#000000', '#7F7F7F', '#1A1A1A', '#999999', '#333333', '#B0B0B0', '#4D4D4D', '#C9C9C9', '#666666', '#DCDCDC']\n  }\n};\n\nconst headlineFontSize = 22;\nconst headlineFontWeight = 'normal';\nconst labelFont$1 = 'Benton Gothic, sans-serif';\nconst labelFontSize = 11.5;\nconst labelFontWeight = 'normal';\nconst markColor$4 = '#82c6df';\n// const markHighlight = '#006d8f';\n// const markDemocrat = '#5789b8';\n// const markRepublican = '#d94f54';\nconst titleFont = 'Benton Gothic Bold, sans-serif';\nconst titleFontWeight = 'normal';\nconst titleFontSize$1 = 13;\nconst colorSchemes$1 = {\n  'category-6': ['#ec8431', '#829eb1', '#c89d29', '#3580b1', '#adc839', '#ab7fb4'],\n  'fire-7': ['#fbf2c7', '#f9e39c', '#f8d36e', '#f4bb6a', '#e68a4f', '#d15a40', '#ab4232'],\n  'fireandice-6': ['#e68a4f', '#f4bb6a', '#f9e39c', '#dadfe2', '#a6b7c6', '#849eae'],\n  'ice-7': ['#edefee', '#dadfe2', '#c4ccd2', '#a6b7c6', '#849eae', '#607785', '#47525d']\n};\nconst latimesTheme = {\n  background: '#ffffff',\n  title: {\n    anchor: 'start',\n    color: '#000000',\n    font: titleFont,\n    fontSize: headlineFontSize,\n    fontWeight: headlineFontWeight\n  },\n  arc: {\n    fill: markColor$4\n  },\n  area: {\n    fill: markColor$4\n  },\n  line: {\n    stroke: markColor$4,\n    strokeWidth: 2\n  },\n  path: {\n    stroke: markColor$4\n  },\n  rect: {\n    fill: markColor$4\n  },\n  shape: {\n    stroke: markColor$4\n  },\n  symbol: {\n    fill: markColor$4,\n    size: 30\n  },\n  axis: {\n    labelFont: labelFont$1,\n    labelFontSize,\n    labelFontWeight,\n    titleFont,\n    titleFontSize: titleFontSize$1,\n    titleFontWeight\n  },\n  axisX: {\n    labelAngle: 0,\n    labelPadding: 4,\n    tickSize: 3\n  },\n  axisY: {\n    labelBaseline: 'middle',\n    maxExtent: 45,\n    minExtent: 45,\n    tickSize: 2,\n    titleAlign: 'left',\n    titleAngle: 0,\n    titleX: -45,\n    titleY: -11\n  },\n  legend: {\n    labelFont: labelFont$1,\n    labelFontSize,\n    symbolType: 'square',\n    titleFont,\n    titleFontSize: titleFontSize$1,\n    titleFontWeight\n  },\n  range: {\n    category: colorSchemes$1['category-6'],\n    diverging: colorSchemes$1['fireandice-6'],\n    heatmap: colorSchemes$1['fire-7'],\n    ordinal: colorSchemes$1['fire-7'],\n    ramp: colorSchemes$1['fire-7']\n  }\n};\n\nconst markColor$3 = '#ab5787';\nconst axisColor$1 = '#979797';\nconst quartzTheme = {\n  background: '#f9f9f9',\n  arc: {\n    fill: markColor$3\n  },\n  area: {\n    fill: markColor$3\n  },\n  line: {\n    stroke: markColor$3\n  },\n  path: {\n    stroke: markColor$3\n  },\n  rect: {\n    fill: markColor$3\n  },\n  shape: {\n    stroke: markColor$3\n  },\n  symbol: {\n    fill: markColor$3,\n    size: 30\n  },\n  axis: {\n    domainColor: axisColor$1,\n    domainWidth: 0.5,\n    gridWidth: 0.2,\n    labelColor: axisColor$1,\n    tickColor: axisColor$1,\n    tickWidth: 0.2,\n    titleColor: axisColor$1\n  },\n  axisBand: {\n    grid: false\n  },\n  axisX: {\n    grid: true,\n    tickSize: 10\n  },\n  axisY: {\n    domain: false,\n    grid: true,\n    tickSize: 0\n  },\n  legend: {\n    labelFontSize: 11,\n    padding: 1,\n    symbolSize: 30,\n    symbolType: 'square'\n  },\n  range: {\n    category: ['#ab5787', '#51b2e5', '#703c5c', '#168dd9', '#d190b6', '#00609f', '#d365ba', '#154866', '#666666', '#c4c4c4']\n  }\n};\n\nconst markColor$2 = '#3e5c69';\nconst voxTheme = {\n  background: '#fff',\n  arc: {\n    fill: markColor$2\n  },\n  area: {\n    fill: markColor$2\n  },\n  line: {\n    stroke: markColor$2\n  },\n  path: {\n    stroke: markColor$2\n  },\n  rect: {\n    fill: markColor$2\n  },\n  shape: {\n    stroke: markColor$2\n  },\n  symbol: {\n    fill: markColor$2\n  },\n  axis: {\n    domainWidth: 0.5,\n    grid: true,\n    labelPadding: 2,\n    tickSize: 5,\n    tickWidth: 0.5,\n    titleFontWeight: 'normal'\n  },\n  axisBand: {\n    grid: false\n  },\n  axisX: {\n    gridWidth: 0.2\n  },\n  axisY: {\n    gridDash: [3],\n    gridWidth: 0.4\n  },\n  legend: {\n    labelFontSize: 11,\n    padding: 1,\n    symbolType: 'square'\n  },\n  range: {\n    category: ['#3e5c69', '#6793a6', '#182429', '#0570b0', '#3690c0', '#74a9cf', '#a6bddb', '#e2ddf2']\n  }\n};\n\nconst markColor$1 = '#1696d2';\nconst axisColor = '#000000';\nconst backgroundColor$1 = '#FFFFFF';\nconst font = 'Lato';\nconst labelFont = 'Lato';\nconst sourceFont = 'Lato';\nconst gridColor$1 = '#DEDDDD';\nconst titleFontSize = 18;\nconst colorSchemes = {\n  'main-colors': ['#1696d2', '#d2d2d2', '#000000', '#fdbf11', '#ec008b', '#55b748', '#5c5859', '#db2b27'],\n  'shades-blue': ['#CFE8F3', '#A2D4EC', '#73BFE2', '#46ABDB', '#1696D2', '#12719E', '#0A4C6A', '#062635'],\n  'shades-gray': ['#F5F5F5', '#ECECEC', '#E3E3E3', '#DCDBDB', '#D2D2D2', '#9D9D9D', '#696969', '#353535'],\n  'shades-yellow': ['#FFF2CF', '#FCE39E', '#FDD870', '#FCCB41', '#FDBF11', '#E88E2D', '#CA5800', '#843215'],\n  'shades-magenta': ['#F5CBDF', '#EB99C2', '#E46AA7', '#E54096', '#EC008B', '#AF1F6B', '#761548', '#351123'],\n  'shades-green': ['#DCEDD9', '#BCDEB4', '#98CF90', '#78C26D', '#55B748', '#408941', '#2C5C2D', '#1A2E19'],\n  'shades-black': ['#D5D5D4', '#ADABAC', '#848081', '#5C5859', '#332D2F', '#262223', '#1A1717', '#0E0C0D'],\n  'shades-red': ['#F8D5D4', '#F1AAA9', '#E9807D', '#E25552', '#DB2B27', '#A4201D', '#6E1614', '#370B0A'],\n  'one-group': ['#1696d2', '#000000'],\n  'two-groups-cat-1': ['#1696d2', '#000000'],\n  'two-groups-cat-2': ['#1696d2', '#fdbf11'],\n  'two-groups-cat-3': ['#1696d2', '#db2b27'],\n  'two-groups-seq': ['#a2d4ec', '#1696d2'],\n  'three-groups-cat': ['#1696d2', '#fdbf11', '#000000'],\n  'three-groups-seq': ['#a2d4ec', '#1696d2', '#0a4c6a'],\n  'four-groups-cat-1': ['#000000', '#d2d2d2', '#fdbf11', '#1696d2'],\n  'four-groups-cat-2': ['#1696d2', '#ec0008b', '#fdbf11', '#5c5859'],\n  'four-groups-seq': ['#cfe8f3', '#73bf42', '#1696d2', '#0a4c6a'],\n  'five-groups-cat-1': ['#1696d2', '#fdbf11', '#d2d2d2', '#ec008b', '#000000'],\n  'five-groups-cat-2': ['#1696d2', '#0a4c6a', '#d2d2d2', '#fdbf11', '#332d2f'],\n  'five-groups-seq': ['#cfe8f3', '#73bf42', '#1696d2', '#0a4c6a', '#000000'],\n  'six-groups-cat-1': ['#1696d2', '#ec008b', '#fdbf11', '#000000', '#d2d2d2', '#55b748'],\n  'six-groups-cat-2': ['#1696d2', '#d2d2d2', '#ec008b', '#fdbf11', '#332d2f', '#0a4c6a'],\n  'six-groups-seq': ['#cfe8f3', '#a2d4ec', '#73bfe2', '#46abdb', '#1696d2', '#12719e'],\n  'diverging-colors': ['#ca5800', '#fdbf11', '#fdd870', '#fff2cf', '#cfe8f3', '#73bfe2', '#1696d2', '#0a4c6a']\n};\nconst urbanInstituteTheme = {\n  background: backgroundColor$1,\n  title: {\n    anchor: 'start',\n    fontSize: titleFontSize,\n    font: font\n  },\n  axisX: {\n    domain: true,\n    domainColor: axisColor,\n    domainWidth: 1,\n    grid: false,\n    labelFontSize: 12,\n    labelFont: labelFont,\n    labelAngle: 0,\n    tickColor: axisColor,\n    tickSize: 5,\n    titleFontSize: 12,\n    titlePadding: 10,\n    titleFont: font\n  },\n  axisY: {\n    domain: false,\n    domainWidth: 1,\n    grid: true,\n    gridColor: gridColor$1,\n    gridWidth: 1,\n    labelFontSize: 12,\n    labelFont: labelFont,\n    labelPadding: 8,\n    ticks: false,\n    titleFontSize: 12,\n    titlePadding: 10,\n    titleFont: font,\n    titleAngle: 0,\n    titleY: -10,\n    titleX: 18\n  },\n  legend: {\n    labelFontSize: 12,\n    labelFont: labelFont,\n    symbolSize: 100,\n    titleFontSize: 12,\n    titlePadding: 10,\n    titleFont: font,\n    orient: 'right',\n    offset: 10\n  },\n  view: {\n    stroke: 'transparent'\n  },\n  range: {\n    category: colorSchemes['six-groups-cat-1'],\n    diverging: colorSchemes['diverging-colors'],\n    heatmap: colorSchemes['diverging-colors'],\n    ordinal: colorSchemes['six-groups-seq'],\n    ramp: colorSchemes['shades-blue']\n  },\n  area: {\n    fill: markColor$1\n  },\n  rect: {\n    fill: markColor$1\n  },\n  line: {\n    color: markColor$1,\n    stroke: markColor$1,\n    strokeWidth: 5\n  },\n  trail: {\n    color: markColor$1,\n    stroke: markColor$1,\n    strokeWidth: 0,\n    size: 1\n  },\n  path: {\n    stroke: markColor$1,\n    strokeWidth: 0.5\n  },\n  point: {\n    filled: true\n  },\n  text: {\n    font: sourceFont,\n    color: markColor$1,\n    fontSize: 11,\n    align: 'center',\n    fontWeight: 400,\n    size: 11\n  },\n  style: {\n    bar: {\n      fill: markColor$1,\n      stroke: null\n    }\n  },\n  arc: {\n    fill: markColor$1\n  },\n  shape: {\n    stroke: markColor$1\n  },\n  symbol: {\n    fill: markColor$1,\n    size: 30\n  }\n};\n\n/**\n * Copyright 2020 Google LLC.\n *\n * Use of this source code is governed by a BSD-style\n * license that can be found in the LICENSE file or at\n * https://developers.google.com/open-source/licenses/bsd\n */\n\nconst markColor = '#3366CC';\nconst gridColor = '#ccc';\nconst defaultFont$1 = 'Arial, sans-serif';\nconst googlechartsTheme = {\n  arc: {\n    fill: markColor\n  },\n  area: {\n    fill: markColor\n  },\n  path: {\n    stroke: markColor\n  },\n  rect: {\n    fill: markColor\n  },\n  shape: {\n    stroke: markColor\n  },\n  symbol: {\n    stroke: markColor\n  },\n  circle: {\n    fill: markColor\n  },\n  background: '#fff',\n  padding: {\n    top: 10,\n    right: 10,\n    bottom: 10,\n    left: 10\n  },\n  style: {\n    'guide-label': {\n      font: defaultFont$1,\n      fontSize: 12\n    },\n    'guide-title': {\n      font: defaultFont$1,\n      fontSize: 12\n    },\n    'group-title': {\n      font: defaultFont$1,\n      fontSize: 12\n    }\n  },\n  title: {\n    font: defaultFont$1,\n    fontSize: 14,\n    fontWeight: 'bold',\n    dy: -3,\n    anchor: 'start'\n  },\n  axis: {\n    gridColor: gridColor,\n    tickColor: gridColor,\n    domain: false,\n    grid: true\n  },\n  range: {\n    category: ['#4285F4', '#DB4437', '#F4B400', '#0F9D58', '#AB47BC', '#00ACC1', '#FF7043', '#9E9D24', '#5C6BC0', '#F06292', '#00796B', '#C2185B'],\n    heatmap: ['#c6dafc', '#5e97f6', '#2a56c6']\n  }\n};\n\nconst ptToPx = value => value * (1 / 3 + 1);\nconst fontSmallPx = ptToPx(9);\nconst legendFontPx = ptToPx(10);\nconst fontLargePx = ptToPx(12);\nconst fontStandard = 'Segoe UI';\nconst fontTitle = 'wf_standard-font, helvetica, arial, sans-serif';\nconst firstLevelElementColor = '#252423';\nconst secondLevelElementColor = '#605E5C';\nconst backgroundColor = 'transparent';\nconst backgroundSecondaryColor = '#C8C6C4';\nconst paletteColor1 = '#118DFF';\nconst paletteColor2 = '#12239E';\nconst paletteColor3 = '#E66C37';\nconst paletteColor4 = '#6B007B';\nconst paletteColor5 = '#E044A7';\nconst paletteColor6 = '#744EC2';\nconst paletteColor7 = '#D9B300';\nconst paletteColor8 = '#D64550';\nconst divergentColorMax = paletteColor1;\nconst divergentColorMin = '#DEEFFF';\nconst divergentPalette = [divergentColorMin, divergentColorMax];\nconst ordinalPalette = [divergentColorMin, '#c7e4ff', '#b0d9ff', '#9aceff', '#83c3ff', '#6cb9ff', '#55aeff', '#3fa3ff', '#2898ff', divergentColorMax];\nconst powerbiTheme = {\n  view: {\n    stroke: backgroundColor\n  },\n  background: backgroundColor,\n  font: fontStandard,\n  header: {\n    titleFont: fontTitle,\n    titleFontSize: fontLargePx,\n    titleColor: firstLevelElementColor,\n    labelFont: fontStandard,\n    labelFontSize: legendFontPx,\n    labelColor: secondLevelElementColor\n  },\n  axis: {\n    ticks: false,\n    grid: false,\n    domain: false,\n    labelColor: secondLevelElementColor,\n    labelFontSize: fontSmallPx,\n    titleFont: fontTitle,\n    titleColor: firstLevelElementColor,\n    titleFontSize: fontLargePx,\n    titleFontWeight: 'normal'\n  },\n  axisQuantitative: {\n    tickCount: 3,\n    grid: true,\n    gridColor: backgroundSecondaryColor,\n    gridDash: [1, 5],\n    labelFlush: false\n  },\n  axisBand: {\n    tickExtra: true\n  },\n  axisX: {\n    labelPadding: 5\n  },\n  axisY: {\n    labelPadding: 10\n  },\n  bar: {\n    fill: paletteColor1\n  },\n  line: {\n    stroke: paletteColor1,\n    strokeWidth: 3,\n    strokeCap: 'round',\n    strokeJoin: 'round'\n  },\n  text: {\n    font: fontStandard,\n    fontSize: fontSmallPx,\n    fill: secondLevelElementColor\n  },\n  arc: {\n    fill: paletteColor1\n  },\n  area: {\n    fill: paletteColor1,\n    line: true,\n    opacity: 0.6\n  },\n  path: {\n    stroke: paletteColor1\n  },\n  rect: {\n    fill: paletteColor1\n  },\n  point: {\n    fill: paletteColor1,\n    filled: true,\n    size: 75\n  },\n  shape: {\n    stroke: paletteColor1\n  },\n  symbol: {\n    fill: paletteColor1,\n    strokeWidth: 1.5,\n    size: 50\n  },\n  legend: {\n    titleFont: fontStandard,\n    titleFontWeight: 'bold',\n    titleColor: secondLevelElementColor,\n    labelFont: fontStandard,\n    labelFontSize: legendFontPx,\n    labelColor: secondLevelElementColor,\n    symbolType: 'circle',\n    symbolSize: 75\n  },\n  range: {\n    category: [paletteColor1, paletteColor2, paletteColor3, paletteColor4, paletteColor5, paletteColor6, paletteColor7, paletteColor8],\n    diverging: divergentPalette,\n    heatmap: divergentPalette,\n    ordinal: ordinalPalette\n  }\n};\n\nconst defaultFont = 'IBM Plex Sans,system-ui,-apple-system,BlinkMacSystemFont,\".sfnstext-regular\",sans-serif';\nconst fontWeight = 400;\nconst darkCategories = ['#8a3ffc', '#33b1ff', '#007d79', '#ff7eb6', '#fa4d56', '#fff1f1', '#6fdc8c', '#4589ff', '#d12771', '#d2a106', '#08bdba', '#bae6ff', '#ba4e00', '#d4bbff'];\nconst lightCategories = ['#6929c4', '#1192e8', '#005d5d', '#9f1853', '#fa4d56', '#570408', '#198038', '#002d9c', '#ee538b', '#b28600', '#009d9a', '#012749', '#8a3800', '#a56eff'];\nfunction genCarbonConfig({\n  type,\n  background\n}) {\n  const viewbg = type === 'dark' ? '#161616' : '#ffffff';\n  const textColor = type === 'dark' ? '#f4f4f4' : '#161616';\n  const category = type === 'dark' ? darkCategories : lightCategories;\n  const markColor = type === 'dark' ? '#d4bbff' : '#6929c4';\n  return {\n    background,\n    arc: {\n      fill: markColor\n    },\n    area: {\n      fill: markColor\n    },\n    path: {\n      stroke: markColor\n    },\n    rect: {\n      fill: markColor\n    },\n    shape: {\n      stroke: markColor\n    },\n    symbol: {\n      stroke: markColor\n    },\n    circle: {\n      fill: markColor\n    },\n    view: {\n      fill: viewbg,\n      stroke: viewbg\n    },\n    group: {\n      fill: viewbg\n    },\n    title: {\n      color: textColor,\n      anchor: 'start',\n      dy: -15,\n      fontSize: 16,\n      font: defaultFont,\n      fontWeight: 600\n    },\n    axis: {\n      labelColor: textColor,\n      labelFontSize: 12,\n      grid: true,\n      gridColor: '#525252',\n      titleColor: textColor,\n      labelAngle: 0\n    },\n    style: {\n      'guide-label': {\n        font: defaultFont,\n        fill: textColor,\n        fontWeight: fontWeight\n      },\n      'guide-title': {\n        font: defaultFont,\n        fill: textColor,\n        fontWeight: fontWeight\n      }\n    },\n    range: {\n      category,\n      diverging: ['#750e13', '#a2191f', '#da1e28', '#fa4d56', '#ff8389', '#ffb3b8', '#ffd7d9', '#fff1f1', '#e5f6ff', '#bae6ff', '#82cfff', '#33b1ff', '#1192e8', '#0072c3', '#00539a', '#003a6d'],\n      heatmap: ['#f6f2ff', '#e8daff', '#d4bbff', '#be95ff', '#a56eff', '#8a3ffc', '#6929c4', '#491d8b', '#31135e', '#1c0f30']\n    }\n  };\n}\n\nconst carbonwhite = genCarbonConfig({\n  type: 'light',\n  background: '#ffffff'\n});\n\nconst carbong10 = genCarbonConfig({\n  type: 'light',\n  background: '#f4f4f4'\n});\n\nconst carbong90 = genCarbonConfig({\n  type: 'dark',\n  background: '#262626'\n});\n\nconst carbong100 = genCarbonConfig({\n  type: 'dark',\n  background: '#161616'\n});\n\nconst version = pkg.version;\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-themes/build/vega-themes.module.js?");

/***/ }),

/***/ "../../node_modules/vega-time/build/vega-time.module.js":
/*!**************************************************************!*\
  !*** ../../node_modules/vega-time/build/vega-time.module.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DATE: () => (/* binding */ DATE),\n/* harmony export */   DAY: () => (/* binding */ DAY),\n/* harmony export */   DAYOFYEAR: () => (/* binding */ DAYOFYEAR),\n/* harmony export */   HOURS: () => (/* binding */ HOURS),\n/* harmony export */   MILLISECONDS: () => (/* binding */ MILLISECONDS),\n/* harmony export */   MINUTES: () => (/* binding */ MINUTES),\n/* harmony export */   MONTH: () => (/* binding */ MONTH),\n/* harmony export */   QUARTER: () => (/* binding */ QUARTER),\n/* harmony export */   SECONDS: () => (/* binding */ SECONDS),\n/* harmony export */   TIME_UNITS: () => (/* binding */ TIME_UNITS),\n/* harmony export */   WEEK: () => (/* binding */ WEEK),\n/* harmony export */   YEAR: () => (/* binding */ YEAR),\n/* harmony export */   dayofyear: () => (/* binding */ dayofyear),\n/* harmony export */   timeBin: () => (/* binding */ bin),\n/* harmony export */   timeFloor: () => (/* binding */ timeFloor),\n/* harmony export */   timeInterval: () => (/* binding */ timeInterval),\n/* harmony export */   timeOffset: () => (/* binding */ timeOffset),\n/* harmony export */   timeSequence: () => (/* binding */ timeSequence),\n/* harmony export */   timeUnitSpecifier: () => (/* binding */ timeUnitSpecifier),\n/* harmony export */   timeUnits: () => (/* binding */ timeUnits),\n/* harmony export */   utcFloor: () => (/* binding */ utcFloor),\n/* harmony export */   utcInterval: () => (/* binding */ utcInterval),\n/* harmony export */   utcOffset: () => (/* binding */ utcOffset),\n/* harmony export */   utcSequence: () => (/* binding */ utcSequence),\n/* harmony export */   utcdayofyear: () => (/* binding */ utcdayofyear),\n/* harmony export */   utcweek: () => (/* binding */ utcweek),\n/* harmony export */   week: () => (/* binding */ week)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/day.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/week.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/year.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/month.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/hour.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/minute.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/second.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/millisecond.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisector.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n\n\n\n\nconst YEAR = 'year';\nconst QUARTER = 'quarter';\nconst MONTH = 'month';\nconst WEEK = 'week';\nconst DATE = 'date';\nconst DAY = 'day';\nconst DAYOFYEAR = 'dayofyear';\nconst HOURS = 'hours';\nconst MINUTES = 'minutes';\nconst SECONDS = 'seconds';\nconst MILLISECONDS = 'milliseconds';\nconst TIME_UNITS = [YEAR, QUARTER, MONTH, WEEK, DATE, DAY, DAYOFYEAR, HOURS, MINUTES, SECONDS, MILLISECONDS];\nconst UNITS = TIME_UNITS.reduce((o, u, i) => (o[u] = 1 + i, o), {});\nfunction timeUnits(units) {\n  const u = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(units).slice(),\n    m = {};\n\n  // check validity\n  if (!u.length) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing time unit.');\n  u.forEach(unit => {\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(UNITS, unit)) {\n      m[unit] = 1;\n    } else {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)(`Invalid time unit: ${unit}.`);\n    }\n  });\n  const numTypes = (m[WEEK] || m[DAY] ? 1 : 0) + (m[QUARTER] || m[MONTH] || m[DATE] ? 1 : 0) + (m[DAYOFYEAR] ? 1 : 0);\n  if (numTypes > 1) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)(`Incompatible time units: ${units}`);\n  }\n\n  // ensure proper sort order\n  u.sort((a, b) => UNITS[a] - UNITS[b]);\n  return u;\n}\nconst defaultSpecifiers = {\n  [YEAR]: '%Y ',\n  [QUARTER]: 'Q%q ',\n  [MONTH]: '%b ',\n  [DATE]: '%d ',\n  [WEEK]: 'W%U ',\n  [DAY]: '%a ',\n  [DAYOFYEAR]: '%j ',\n  [HOURS]: '%H:00',\n  [MINUTES]: '00:%M',\n  [SECONDS]: ':%S',\n  [MILLISECONDS]: '.%L',\n  [`${YEAR}-${MONTH}`]: '%Y-%m ',\n  [`${YEAR}-${MONTH}-${DATE}`]: '%Y-%m-%d ',\n  [`${HOURS}-${MINUTES}`]: '%H:%M'\n};\nfunction timeUnitSpecifier(units, specifiers) {\n  const s = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, defaultSpecifiers, specifiers),\n    u = timeUnits(units),\n    n = u.length;\n  let fmt = '',\n    start = 0,\n    end,\n    key;\n  for (start = 0; start < n;) {\n    for (end = u.length; end > start; --end) {\n      key = u.slice(start, end).join('-');\n      if (s[key] != null) {\n        fmt += s[key];\n        start = end;\n        break;\n      }\n    }\n  }\n  return fmt.trim();\n}\n\nconst t0 = new Date();\nfunction localYear(y) {\n  t0.setFullYear(y);\n  t0.setMonth(0);\n  t0.setDate(1);\n  t0.setHours(0, 0, 0, 0);\n  return t0;\n}\nfunction dayofyear(d) {\n  return localDayOfYear(new Date(d));\n}\nfunction week(d) {\n  return localWeekNum(new Date(d));\n}\nfunction localDayOfYear(d) {\n  return d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay.count(localYear(d.getFullYear()) - 1, d);\n}\nfunction localWeekNum(d) {\n  return d3_time__WEBPACK_IMPORTED_MODULE_2__.timeSunday.count(localYear(d.getFullYear()) - 1, d);\n}\nfunction localFirst(y) {\n  return localYear(y).getDay();\n}\nfunction localDate(y, m, d, H, M, S, L) {\n  if (0 <= y && y < 100) {\n    const date = new Date(-1, m, d, H, M, S, L);\n    date.setFullYear(y);\n    return date;\n  }\n  return new Date(y, m, d, H, M, S, L);\n}\nfunction utcdayofyear(d) {\n  return utcDayOfYear(new Date(d));\n}\nfunction utcweek(d) {\n  return utcWeekNum(new Date(d));\n}\nfunction utcDayOfYear(d) {\n  const y = Date.UTC(d.getUTCFullYear(), 0, 1);\n  return d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay.count(y - 1, d);\n}\nfunction utcWeekNum(d) {\n  const y = Date.UTC(d.getUTCFullYear(), 0, 1);\n  return d3_time__WEBPACK_IMPORTED_MODULE_2__.utcSunday.count(y - 1, d);\n}\nfunction utcFirst(y) {\n  t0.setTime(Date.UTC(y, 0, 1));\n  return t0.getUTCDay();\n}\nfunction utcDate(y, m, d, H, M, S, L) {\n  if (0 <= y && y < 100) {\n    const date = new Date(Date.UTC(-1, m, d, H, M, S, L));\n    date.setUTCFullYear(d.y);\n    return date;\n  }\n  return new Date(Date.UTC(y, m, d, H, M, S, L));\n}\n\nfunction floor(units, step, get, inv, newDate) {\n  const s = step || 1,\n    b = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(units),\n    _ = (unit, p, key) => {\n      key = key || unit;\n      return getUnit(get[key], inv[key], unit === b && s, p);\n    };\n  const t = new Date(),\n    u = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(units),\n    y = u[YEAR] ? _(YEAR) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(2012),\n    m = u[MONTH] ? _(MONTH) : u[QUARTER] ? _(QUARTER) : vega_util__WEBPACK_IMPORTED_MODULE_0__.zero,\n    d = u[WEEK] && u[DAY] ? _(DAY, 1, WEEK + DAY) : u[WEEK] ? _(WEEK, 1) : u[DAY] ? _(DAY, 1) : u[DATE] ? _(DATE, 1) : u[DAYOFYEAR] ? _(DAYOFYEAR, 1) : vega_util__WEBPACK_IMPORTED_MODULE_0__.one,\n    H = u[HOURS] ? _(HOURS) : vega_util__WEBPACK_IMPORTED_MODULE_0__.zero,\n    M = u[MINUTES] ? _(MINUTES) : vega_util__WEBPACK_IMPORTED_MODULE_0__.zero,\n    S = u[SECONDS] ? _(SECONDS) : vega_util__WEBPACK_IMPORTED_MODULE_0__.zero,\n    L = u[MILLISECONDS] ? _(MILLISECONDS) : vega_util__WEBPACK_IMPORTED_MODULE_0__.zero;\n  return function (v) {\n    t.setTime(+v);\n    const year = y(t);\n    return newDate(year, m(t), d(t, year), H(t), M(t), S(t), L(t));\n  };\n}\nfunction getUnit(f, inv, step, phase) {\n  const u = step <= 1 ? f : phase ? (d, y) => phase + step * Math.floor((f(d, y) - phase) / step) : (d, y) => step * Math.floor(f(d, y) / step);\n  return inv ? (d, y) => inv(u(d, y), y) : u;\n}\n\n// returns the day of the year based on week number, day of week,\n// and the day of the week for the first day of the year\nfunction weekday(week, day, firstDay) {\n  return day + week * 7 - (firstDay + 6) % 7;\n}\n\n// -- LOCAL TIME --\n\nconst localGet = {\n  [YEAR]: d => d.getFullYear(),\n  [QUARTER]: d => Math.floor(d.getMonth() / 3),\n  [MONTH]: d => d.getMonth(),\n  [DATE]: d => d.getDate(),\n  [HOURS]: d => d.getHours(),\n  [MINUTES]: d => d.getMinutes(),\n  [SECONDS]: d => d.getSeconds(),\n  [MILLISECONDS]: d => d.getMilliseconds(),\n  [DAYOFYEAR]: d => localDayOfYear(d),\n  [WEEK]: d => localWeekNum(d),\n  [WEEK + DAY]: (d, y) => weekday(localWeekNum(d), d.getDay(), localFirst(y)),\n  [DAY]: (d, y) => weekday(1, d.getDay(), localFirst(y))\n};\nconst localInv = {\n  [QUARTER]: q => 3 * q,\n  [WEEK]: (w, y) => weekday(w, 0, localFirst(y))\n};\nfunction timeFloor(units, step) {\n  return floor(units, step || 1, localGet, localInv, localDate);\n}\n\n// -- UTC TIME --\n\nconst utcGet = {\n  [YEAR]: d => d.getUTCFullYear(),\n  [QUARTER]: d => Math.floor(d.getUTCMonth() / 3),\n  [MONTH]: d => d.getUTCMonth(),\n  [DATE]: d => d.getUTCDate(),\n  [HOURS]: d => d.getUTCHours(),\n  [MINUTES]: d => d.getUTCMinutes(),\n  [SECONDS]: d => d.getUTCSeconds(),\n  [MILLISECONDS]: d => d.getUTCMilliseconds(),\n  [DAYOFYEAR]: d => utcDayOfYear(d),\n  [WEEK]: d => utcWeekNum(d),\n  [DAY]: (d, y) => weekday(1, d.getUTCDay(), utcFirst(y)),\n  [WEEK + DAY]: (d, y) => weekday(utcWeekNum(d), d.getUTCDay(), utcFirst(y))\n};\nconst utcInv = {\n  [QUARTER]: q => 3 * q,\n  [WEEK]: (w, y) => weekday(w, 0, utcFirst(y))\n};\nfunction utcFloor(units, step) {\n  return floor(units, step || 1, utcGet, utcInv, utcDate);\n}\n\nconst timeIntervals = {\n  [YEAR]: d3_time__WEBPACK_IMPORTED_MODULE_3__.timeYear,\n  [QUARTER]: d3_time__WEBPACK_IMPORTED_MODULE_4__.timeMonth.every(3),\n  [MONTH]: d3_time__WEBPACK_IMPORTED_MODULE_4__.timeMonth,\n  [WEEK]: d3_time__WEBPACK_IMPORTED_MODULE_2__.timeSunday,\n  [DATE]: d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay,\n  [DAY]: d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay,\n  [DAYOFYEAR]: d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay,\n  [HOURS]: d3_time__WEBPACK_IMPORTED_MODULE_5__.timeHour,\n  [MINUTES]: d3_time__WEBPACK_IMPORTED_MODULE_6__.timeMinute,\n  [SECONDS]: d3_time__WEBPACK_IMPORTED_MODULE_7__.second,\n  [MILLISECONDS]: d3_time__WEBPACK_IMPORTED_MODULE_8__.millisecond\n};\nconst utcIntervals = {\n  [YEAR]: d3_time__WEBPACK_IMPORTED_MODULE_3__.utcYear,\n  [QUARTER]: d3_time__WEBPACK_IMPORTED_MODULE_4__.utcMonth.every(3),\n  [MONTH]: d3_time__WEBPACK_IMPORTED_MODULE_4__.utcMonth,\n  [WEEK]: d3_time__WEBPACK_IMPORTED_MODULE_2__.utcSunday,\n  [DATE]: d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay,\n  [DAY]: d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay,\n  [DAYOFYEAR]: d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay,\n  [HOURS]: d3_time__WEBPACK_IMPORTED_MODULE_5__.utcHour,\n  [MINUTES]: d3_time__WEBPACK_IMPORTED_MODULE_6__.utcMinute,\n  [SECONDS]: d3_time__WEBPACK_IMPORTED_MODULE_7__.second,\n  [MILLISECONDS]: d3_time__WEBPACK_IMPORTED_MODULE_8__.millisecond\n};\nfunction timeInterval(unit) {\n  return timeIntervals[unit];\n}\nfunction utcInterval(unit) {\n  return utcIntervals[unit];\n}\nfunction offset(ival, date, step) {\n  return ival ? ival.offset(date, step) : undefined;\n}\nfunction timeOffset(unit, date, step) {\n  return offset(timeInterval(unit), date, step);\n}\nfunction utcOffset(unit, date, step) {\n  return offset(utcInterval(unit), date, step);\n}\nfunction sequence(ival, start, stop, step) {\n  return ival ? ival.range(start, stop, step) : undefined;\n}\nfunction timeSequence(unit, start, stop, step) {\n  return sequence(timeInterval(unit), start, stop, step);\n}\nfunction utcSequence(unit, start, stop, step) {\n  return sequence(utcInterval(unit), start, stop, step);\n}\n\nconst durationSecond = 1000,\n  durationMinute = durationSecond * 60,\n  durationHour = durationMinute * 60,\n  durationDay = durationHour * 24,\n  durationWeek = durationDay * 7,\n  durationMonth = durationDay * 30,\n  durationYear = durationDay * 365;\nconst Milli = [YEAR, MONTH, DATE, HOURS, MINUTES, SECONDS, MILLISECONDS],\n  Seconds = Milli.slice(0, -1),\n  Minutes = Seconds.slice(0, -1),\n  Hours = Minutes.slice(0, -1),\n  Day = Hours.slice(0, -1),\n  Week = [YEAR, WEEK],\n  Month = [YEAR, MONTH],\n  Year = [YEAR];\nconst intervals = [[Seconds, 1, durationSecond], [Seconds, 5, 5 * durationSecond], [Seconds, 15, 15 * durationSecond], [Seconds, 30, 30 * durationSecond], [Minutes, 1, durationMinute], [Minutes, 5, 5 * durationMinute], [Minutes, 15, 15 * durationMinute], [Minutes, 30, 30 * durationMinute], [Hours, 1, durationHour], [Hours, 3, 3 * durationHour], [Hours, 6, 6 * durationHour], [Hours, 12, 12 * durationHour], [Day, 1, durationDay], [Week, 1, durationWeek], [Month, 1, durationMonth], [Month, 3, 3 * durationMonth], [Year, 1, durationYear]];\nfunction bin (opt) {\n  const ext = opt.extent,\n    max = opt.maxbins || 40,\n    target = Math.abs((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.span)(ext)) / max;\n  let i = (0,d3_array__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(i => i[2]).right(intervals, target),\n    units,\n    step;\n  if (i === intervals.length) {\n    units = Year, step = (0,d3_array__WEBPACK_IMPORTED_MODULE_10__.tickStep)(ext[0] / durationYear, ext[1] / durationYear, max);\n  } else if (i) {\n    i = intervals[target / intervals[i - 1][2] < intervals[i][2] / target ? i - 1 : i];\n    units = i[0];\n    step = i[1];\n  } else {\n    units = Milli;\n    step = Math.max((0,d3_array__WEBPACK_IMPORTED_MODULE_10__.tickStep)(ext[0], ext[1], max), 1);\n  }\n  return {\n    units,\n    step\n  };\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-time/build/vega-time.module.js?");

/***/ }),

/***/ "../../node_modules/vega-tooltip/build/vega-tooltip.module.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-tooltip/build/vega-tooltip.module.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DEFAULT_OPTIONS: () => (/* binding */ DEFAULT_OPTIONS),\n/* harmony export */   Handler: () => (/* binding */ Handler),\n/* harmony export */   calculatePosition: () => (/* binding */ calculatePosition),\n/* harmony export */   createDefaultStyle: () => (/* binding */ createDefaultStyle),\n/* harmony export */   \"default\": () => (/* binding */ index),\n/* harmony export */   escapeHTML: () => (/* binding */ escapeHTML),\n/* harmony export */   formatValue: () => (/* binding */ formatValue),\n/* harmony export */   replacer: () => (/* binding */ replacer),\n/* harmony export */   stringify: () => (/* binding */ stringify),\n/* harmony export */   version: () => (/* binding */ version)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\nvar name = \"vega-tooltip\";\nvar version$1 = \"0.32.0\";\nvar description = \"A tooltip plugin for Vega-Lite and Vega visualizations.\";\nvar keywords = [\"vega-lite\", \"vega\", \"tooltip\"];\nvar repository = {\n  type: \"git\",\n  url: \"https://github.com/vega/vega-tooltip.git\"\n};\nvar author = {\n  name: \"UW Interactive Data Lab\",\n  url: \"https://idl.cs.washington.edu\"\n};\nvar collaborators = [\"Dominik Moritz\", \"Sira Horradarn\", \"Zening Qu\", \"Kanit Wongsuphasawat\", \"Yuri Astrakhan\", \"Jeffrey Heer\"];\nvar license = \"BSD-3-Clause\";\nvar bugs = {\n  url: \"https://github.com/vega/vega-tooltip/issues\"\n};\nvar homepage = \"https://github.com/vega/vega-tooltip#readme\";\nvar main = \"build/vega-tooltip.js\";\nvar module = \"build/vega-tooltip.module.js\";\nvar unpkg = \"build/vega-tooltip.min.js\";\nvar jsdelivr = \"build/vega-tooltip.min.js\";\nvar types = \"build/vega-tooltip.module.d.ts\";\nvar files = [\"src\", \"build\", \"types\"];\nvar scripts = {\n  prebuild: \"yarn clean && yarn build:style\",\n  build: \"rollup -c\",\n  \"build:style\": \"./build-style.sh\",\n  clean: \"rimraf build && rimraf src/style.ts\",\n  \"copy:data\": \"rsync -r node_modules/vega-datasets/data/* examples/data\",\n  \"copy:build\": \"rsync -r build/* examples/build\",\n  \"deploy:gh\": \"yarn build && yarn copy:build && gh-pages -d examples && yarn clean\",\n  prepublishOnly: \"yarn clean && yarn build\",\n  preversion: \"yarn lint && yarn test\",\n  serve: \"browser-sync start -s -f build examples --serveStatic examples\",\n  start: \"yarn build && concurrently --kill-others -n Server,Rollup 'yarn serve' 'rollup -c -w'\",\n  pretest: \"yarn build:style\",\n  test: \"jest\",\n  \"test:inspect\": \"node --inspect-brk ./node_modules/.bin/jest --runInBand\",\n  prepare: \"yarn copy:data\",\n  prettierbase: \"prettier '*.{css,scss,html}'\",\n  format: \"eslint . --fix && yarn prettierbase --write\",\n  lint: \"eslint . && yarn prettierbase --check\",\n  release: \"release-it\"\n};\nvar devDependencies = {\n  \"@babel/core\": \"^7.21.4\",\n  \"@babel/plugin-transform-runtime\": \"^7.21.4\",\n  \"@babel/preset-env\": \"^7.21.4\",\n  \"@babel/preset-typescript\": \"^7.21.4\",\n  \"@release-it/conventional-changelog\": \"^5.1.1\",\n  \"@rollup/plugin-json\": \"^6.0.0\",\n  \"@rollup/plugin-node-resolve\": \"^15.0.2\",\n  \"@rollup/plugin-terser\": \"^0.4.1\",\n  \"@types/jest\": \"^29.5.1\",\n  \"@typescript-eslint/eslint-plugin\": \"^5.59.0\",\n  \"@typescript-eslint/parser\": \"^5.59.0\",\n  \"browser-sync\": \"^2.29.1\",\n  concurrently: \"^8.0.1\",\n  eslint: \"^8.38.0\",\n  \"eslint-config-prettier\": \"^8.8.0\",\n  \"eslint-plugin-jest\": \"^27.2.1\",\n  \"eslint-plugin-prettier\": \"^4.2.1\",\n  \"gh-pages\": \"^5.0.0\",\n  jest: \"^29.5.0\",\n  \"jest-environment-jsdom\": \"^29.5.0\",\n  path: \"^0.12.7\",\n  prettier: \"^2.8.7\",\n  \"release-it\": \"^15.10.1\",\n  rollup: \"^3.20.6\",\n  \"rollup-plugin-bundle-size\": \"^1.0.3\",\n  \"rollup-plugin-ts\": \"^3.2.0\",\n  sass: \"^1.62.0\",\n  typescript: \"~5.0.4\",\n  \"vega-datasets\": \"^2.7.0\",\n  \"vega-typings\": \"^0.24.0\"\n};\nvar dependencies = {\n  \"vega-util\": \"^1.17.1\"\n};\nvar pkg = {\n  name: name,\n  version: version$1,\n  description: description,\n  keywords: keywords,\n  repository: repository,\n  author: author,\n  collaborators: collaborators,\n  license: license,\n  bugs: bugs,\n  homepage: homepage,\n  main: main,\n  module: module,\n  unpkg: unpkg,\n  jsdelivr: jsdelivr,\n  types: types,\n  files: files,\n  scripts: scripts,\n  devDependencies: devDependencies,\n  dependencies: dependencies\n};\n\nfunction _typeof(obj) {\n  \"@babel/helpers - typeof\";\n\n  return _typeof = \"function\" == typeof Symbol && \"symbol\" == typeof Symbol.iterator ? function (obj) {\n    return typeof obj;\n  } : function (obj) {\n    return obj && \"function\" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj;\n  }, _typeof(obj);\n}\n\nfunction _toPrimitive(input, hint) {\n  if (_typeof(input) !== \"object\" || input === null) return input;\n  var prim = input[Symbol.toPrimitive];\n  if (prim !== undefined) {\n    var res = prim.call(input, hint || \"default\");\n    if (_typeof(res) !== \"object\") return res;\n    throw new TypeError(\"@@toPrimitive must return a primitive value.\");\n  }\n  return (hint === \"string\" ? String : Number)(input);\n}\n\nfunction _toPropertyKey(arg) {\n  var key = _toPrimitive(arg, \"string\");\n  return _typeof(key) === \"symbol\" ? key : String(key);\n}\n\nfunction _defineProperty(obj, key, value) {\n  key = _toPropertyKey(key);\n  if (key in obj) {\n    Object.defineProperty(obj, key, {\n      value: value,\n      enumerable: true,\n      configurable: true,\n      writable: true\n    });\n  } else {\n    obj[key] = value;\n  }\n  return obj;\n}\n\nfunction _objectWithoutPropertiesLoose(source, excluded) {\n  if (source == null) return {};\n  var target = {};\n  var sourceKeys = Object.keys(source);\n  var key, i;\n  for (i = 0; i < sourceKeys.length; i++) {\n    key = sourceKeys[i];\n    if (excluded.indexOf(key) >= 0) continue;\n    target[key] = source[key];\n  }\n  return target;\n}\n\nfunction _objectWithoutProperties(source, excluded) {\n  if (source == null) return {};\n  var target = _objectWithoutPropertiesLoose(source, excluded);\n  var key, i;\n  if (Object.getOwnPropertySymbols) {\n    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);\n    for (i = 0; i < sourceSymbolKeys.length; i++) {\n      key = sourceSymbolKeys[i];\n      if (excluded.indexOf(key) >= 0) continue;\n      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;\n      target[key] = source[key];\n    }\n  }\n  return target;\n}\n\nconst _excluded = [\"title\", \"image\"];\n\n/**\n * Format the value to be shown in the tooltip.\n *\n * @param value The value to show in the tooltip.\n * @param valueToHtml Function to convert a single cell value to an HTML string\n */\nfunction formatValue(value, valueToHtml, maxDepth) {\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value)) {\n    return `[${value.map(v => valueToHtml((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(v) ? v : stringify(v, maxDepth))).join(', ')}]`;\n  }\n  if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value)) {\n    let content = '';\n    const _ref = value,\n      {\n        title,\n        image\n      } = _ref,\n      rest = _objectWithoutProperties(_ref, _excluded);\n    if (title) {\n      content += `<h2>${valueToHtml(title)}</h2>`;\n    }\n    if (image) {\n      content += `<img src=\"${valueToHtml(image)}\">`;\n    }\n    const keys = Object.keys(rest);\n    if (keys.length > 0) {\n      content += '<table>';\n      for (const key of keys) {\n        let val = rest[key];\n\n        // ignore undefined properties\n        if (val === undefined) {\n          continue;\n        }\n        if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(val)) {\n          val = stringify(val, maxDepth);\n        }\n        content += `<tr><td class=\"key\">${valueToHtml(key)}:</td><td class=\"value\">${valueToHtml(val)}</td></tr>`;\n      }\n      content += `</table>`;\n    }\n    return content || '{}'; // show empty object if there are no properties\n  }\n\n  return valueToHtml(value);\n}\nfunction replacer(maxDepth) {\n  const stack = [];\n  return function (key, value) {\n    if (typeof value !== 'object' || value === null) {\n      return value;\n    }\n    const pos = stack.indexOf(this) + 1;\n    stack.length = pos;\n    if (stack.length > maxDepth) {\n      return '[Object]';\n    }\n    if (stack.indexOf(value) >= 0) {\n      return '[Circular]';\n    }\n    stack.push(value);\n    return value;\n  };\n}\n\n/**\n * Stringify any JS object to valid JSON\n */\nfunction stringify(obj, maxDepth) {\n  return JSON.stringify(obj, replacer(maxDepth));\n}\n\n// generated with build-style.sh\nvar defaultStyle = `#vg-tooltip-element {\n  visibility: hidden;\n  padding: 8px;\n  position: fixed;\n  z-index: 1000;\n  font-family: sans-serif;\n  font-size: 11px;\n  border-radius: 3px;\n  box-shadow: 2px 2px 4px rgba(0, 0, 0, 0.1);\n  /* The default theme is the light theme. */\n  background-color: rgba(255, 255, 255, 0.95);\n  border: 1px solid #d9d9d9;\n  color: black;\n}\n#vg-tooltip-element.visible {\n  visibility: visible;\n}\n#vg-tooltip-element h2 {\n  margin-top: 0;\n  margin-bottom: 10px;\n  font-size: 13px;\n}\n#vg-tooltip-element table {\n  border-spacing: 0;\n}\n#vg-tooltip-element table tr {\n  border: none;\n}\n#vg-tooltip-element table tr td {\n  overflow: hidden;\n  text-overflow: ellipsis;\n  padding-top: 2px;\n  padding-bottom: 2px;\n}\n#vg-tooltip-element table tr td.key {\n  color: #808080;\n  max-width: 150px;\n  text-align: right;\n  padding-right: 4px;\n}\n#vg-tooltip-element table tr td.value {\n  display: block;\n  max-width: 300px;\n  max-height: 7em;\n  text-align: left;\n}\n#vg-tooltip-element.dark-theme {\n  background-color: rgba(32, 32, 32, 0.9);\n  border: 1px solid #f5f5f5;\n  color: white;\n}\n#vg-tooltip-element.dark-theme td.key {\n  color: #bfbfbf;\n}\n`;\n\nconst EL_ID = 'vg-tooltip-element';\nconst DEFAULT_OPTIONS = {\n  /**\n   * X offset.\n   */\n  offsetX: 10,\n  /**\n   * Y offset.\n   */\n  offsetY: 10,\n  /**\n   * ID of the tooltip element.\n   */\n  id: EL_ID,\n  /**\n   * ID of the tooltip CSS style.\n   */\n  styleId: 'vega-tooltip-style',\n  /**\n   * The name of the theme. You can use the CSS class called [THEME]-theme to style the tooltips.\n   *\n   * There are two predefined themes: \"light\" (default) and \"dark\".\n   */\n  theme: 'light',\n  /**\n   * Do not use the default styles provided by Vega Tooltip. If you enable this option, you need to use your own styles. It is not necessary to disable the default style when using a custom theme.\n   */\n  disableDefaultStyle: false,\n  /**\n   * HTML sanitizer function that removes dangerous HTML to prevent XSS.\n   *\n   * This should be a function from string to string. You may replace it with a formatter such as a markdown formatter.\n   */\n  sanitize: escapeHTML,\n  /**\n   * The maximum recursion depth when printing objects in the tooltip.\n   */\n  maxDepth: 2,\n  /**\n   * A function to customize the rendered HTML of the tooltip.\n   * @param value A value string, or object of value strings keyed by field\n   * @param sanitize The `sanitize` function from `options.sanitize`\n   * @returns {string} The returned string will become the `innerHTML` of the tooltip element\n   */\n  formatTooltip: formatValue\n};\n/**\n * Escape special HTML characters.\n *\n * @param value A value to convert to string and HTML-escape.\n */\nfunction escapeHTML(value) {\n  return String(value).replace(/&/g, '&amp;').replace(/</g, '&lt;');\n}\nfunction createDefaultStyle(id) {\n  // Just in case this id comes from a user, ensure these is no security issues\n  if (!/^[A-Za-z]+[-:.\\w]*$/.test(id)) {\n    throw new Error('Invalid HTML ID');\n  }\n  return defaultStyle.toString().replace(EL_ID, id);\n}\n\n/**\n * Position the tooltip\n *\n * @param event The mouse event.\n * @param tooltipBox\n * @param offsetX Horizontal offset.\n * @param offsetY Vertical offset.\n */\nfunction calculatePosition(event, tooltipBox, offsetX, offsetY) {\n  let x = event.clientX + offsetX;\n  if (x + tooltipBox.width > window.innerWidth) {\n    x = +event.clientX - offsetX - tooltipBox.width;\n  }\n  let y = event.clientY + offsetY;\n  if (y + tooltipBox.height > window.innerHeight) {\n    y = +event.clientY - offsetY - tooltipBox.height;\n  }\n  return {\n    x,\n    y\n  };\n}\n\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }\n\n/**\n * The tooltip handler class.\n */\nclass Handler {\n  /**\n   * The handler function. We bind this to this function in the constructor.\n   */\n\n  /**\n   * Complete tooltip options.\n   */\n\n  /**\n   * The tooltip html element.\n   */\n\n  /**\n   * Create the tooltip handler and initialize the element and style.\n   *\n   * @param options Tooltip Options\n   */\n  constructor(options) {\n    this.options = _objectSpread(_objectSpread({}, DEFAULT_OPTIONS), options);\n    const elementId = this.options.id;\n    this.el = null;\n\n    // bind this to call\n    this.call = this.tooltipHandler.bind(this);\n\n    // prepend a default stylesheet for tooltips to the head\n    if (!this.options.disableDefaultStyle && !document.getElementById(this.options.styleId)) {\n      const style = document.createElement('style');\n      style.setAttribute('id', this.options.styleId);\n      style.innerHTML = createDefaultStyle(elementId);\n      const head = document.head;\n      if (head.childNodes.length > 0) {\n        head.insertBefore(style, head.childNodes[0]);\n      } else {\n        head.appendChild(style);\n      }\n    }\n  }\n\n  /**\n   * The tooltip handler function.\n   */\n  tooltipHandler(handler, event, item, value) {\n    // console.log(handler, event, item, value);\n\n    // append a div element that we use as a tooltip unless it already exists\n    this.el = document.getElementById(this.options.id);\n    if (!this.el) {\n      this.el = document.createElement('div');\n      this.el.setAttribute('id', this.options.id);\n      this.el.classList.add('vg-tooltip');\n      const tooltipContainer = document.fullscreenElement ?? document.body;\n      tooltipContainer.appendChild(this.el);\n    }\n\n    // hide tooltip for null, undefined, or empty string values\n    if (value == null || value === '') {\n      this.el.classList.remove('visible', `${this.options.theme}-theme`);\n      return;\n    }\n\n    // set the tooltip content\n    this.el.innerHTML = this.options.formatTooltip(value, this.options.sanitize, this.options.maxDepth);\n\n    // make the tooltip visible\n    this.el.classList.add('visible', `${this.options.theme}-theme`);\n    const {\n      x,\n      y\n    } = calculatePosition(event, this.el.getBoundingClientRect(), this.options.offsetX, this.options.offsetY);\n    this.el.style.top = `${y}px`;\n    this.el.style.left = `${x}px`;\n  }\n}\n\nconst version = pkg.version;\n\n/**\n * Create a tooltip handler and register it with the provided view.\n *\n * @param view The Vega view.\n * @param opt Tooltip options.\n */\nfunction index (view, opt) {\n  const handler = new Handler(opt);\n  view.tooltip(handler.call).run();\n  return handler;\n}\n\n\n//# sourceMappingURL=vega-tooltip.module.js.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-tooltip/build/vega-tooltip.module.js?");

/***/ }),

/***/ "../../node_modules/vega-transforms/build/vega-transforms.module.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/vega-transforms/build/vega-transforms.module.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   aggregate: () => (/* binding */ Aggregate),\n/* harmony export */   bin: () => (/* binding */ Bin),\n/* harmony export */   collect: () => (/* binding */ Collect),\n/* harmony export */   compare: () => (/* binding */ Compare),\n/* harmony export */   countpattern: () => (/* binding */ CountPattern),\n/* harmony export */   cross: () => (/* binding */ Cross),\n/* harmony export */   density: () => (/* binding */ Density),\n/* harmony export */   dotbin: () => (/* binding */ DotBin),\n/* harmony export */   expression: () => (/* binding */ Expression),\n/* harmony export */   extent: () => (/* binding */ Extent),\n/* harmony export */   facet: () => (/* binding */ Facet),\n/* harmony export */   field: () => (/* binding */ Field),\n/* harmony export */   filter: () => (/* binding */ Filter),\n/* harmony export */   flatten: () => (/* binding */ Flatten),\n/* harmony export */   fold: () => (/* binding */ Fold),\n/* harmony export */   formula: () => (/* binding */ Formula),\n/* harmony export */   generate: () => (/* binding */ Generate),\n/* harmony export */   impute: () => (/* binding */ Impute),\n/* harmony export */   joinaggregate: () => (/* binding */ JoinAggregate),\n/* harmony export */   kde: () => (/* binding */ KDE),\n/* harmony export */   key: () => (/* binding */ Key),\n/* harmony export */   load: () => (/* binding */ Load),\n/* harmony export */   lookup: () => (/* binding */ Lookup),\n/* harmony export */   multiextent: () => (/* binding */ MultiExtent),\n/* harmony export */   multivalues: () => (/* binding */ MultiValues),\n/* harmony export */   params: () => (/* binding */ Params),\n/* harmony export */   pivot: () => (/* binding */ Pivot),\n/* harmony export */   prefacet: () => (/* binding */ PreFacet),\n/* harmony export */   project: () => (/* binding */ Project),\n/* harmony export */   proxy: () => (/* binding */ Proxy),\n/* harmony export */   quantile: () => (/* binding */ Quantile),\n/* harmony export */   relay: () => (/* binding */ Relay),\n/* harmony export */   sample: () => (/* binding */ Sample),\n/* harmony export */   sequence: () => (/* binding */ Sequence),\n/* harmony export */   sieve: () => (/* binding */ Sieve),\n/* harmony export */   subflow: () => (/* binding */ Subflow),\n/* harmony export */   timeunit: () => (/* binding */ TimeUnit),\n/* harmony export */   tupleindex: () => (/* binding */ TupleIndex),\n/* harmony export */   values: () => (/* binding */ Values),\n/* harmony export */   window: () => (/* binding */ Window)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/median.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/mean.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/min.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/max.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisector.js\");\n/* harmony import */ var vega_time__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-time */ \"../../node_modules/vega-time/build/vega-time.module.js\");\n\n\n\n\n\n\nfunction multikey(f) {\n  return x => {\n    const n = f.length;\n    let i = 1,\n      k = String(f[0](x));\n    for (; i < n; ++i) {\n      k += '|' + f[i](x);\n    }\n    return k;\n  };\n}\nfunction groupkey(fields) {\n  return !fields || !fields.length ? function () {\n    return '';\n  } : fields.length === 1 ? fields[0] : multikey(fields);\n}\n\nfunction measureName(op, field, as) {\n  return as || op + (!field ? '' : '_' + field);\n}\nconst noop = () => {};\nconst base_op = {\n  init: noop,\n  add: noop,\n  rem: noop,\n  idx: 0\n};\nconst AggregateOps = {\n  values: {\n    init: m => m.cell.store = true,\n    value: m => m.cell.data.values(),\n    idx: -1\n  },\n  count: {\n    value: m => m.cell.num\n  },\n  __count__: {\n    value: m => m.missing + m.valid\n  },\n  missing: {\n    value: m => m.missing\n  },\n  valid: {\n    value: m => m.valid\n  },\n  sum: {\n    init: m => m.sum = 0,\n    value: m => m.sum,\n    add: (m, v) => m.sum += +v,\n    rem: (m, v) => m.sum -= v\n  },\n  product: {\n    init: m => m.product = 1,\n    value: m => m.valid ? m.product : undefined,\n    add: (m, v) => m.product *= v,\n    rem: (m, v) => m.product /= v\n  },\n  mean: {\n    init: m => m.mean = 0,\n    value: m => m.valid ? m.mean : undefined,\n    add: (m, v) => (m.mean_d = v - m.mean, m.mean += m.mean_d / m.valid),\n    rem: (m, v) => (m.mean_d = v - m.mean, m.mean -= m.valid ? m.mean_d / m.valid : m.mean)\n  },\n  average: {\n    value: m => m.valid ? m.mean : undefined,\n    req: ['mean'],\n    idx: 1\n  },\n  variance: {\n    init: m => m.dev = 0,\n    value: m => m.valid > 1 ? m.dev / (m.valid - 1) : undefined,\n    add: (m, v) => m.dev += m.mean_d * (v - m.mean),\n    rem: (m, v) => m.dev -= m.mean_d * (v - m.mean),\n    req: ['mean'],\n    idx: 1\n  },\n  variancep: {\n    value: m => m.valid > 1 ? m.dev / m.valid : undefined,\n    req: ['variance'],\n    idx: 2\n  },\n  stdev: {\n    value: m => m.valid > 1 ? Math.sqrt(m.dev / (m.valid - 1)) : undefined,\n    req: ['variance'],\n    idx: 2\n  },\n  stdevp: {\n    value: m => m.valid > 1 ? Math.sqrt(m.dev / m.valid) : undefined,\n    req: ['variance'],\n    idx: 2\n  },\n  stderr: {\n    value: m => m.valid > 1 ? Math.sqrt(m.dev / (m.valid * (m.valid - 1))) : undefined,\n    req: ['variance'],\n    idx: 2\n  },\n  distinct: {\n    value: m => m.cell.data.distinct(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  ci0: {\n    value: m => m.cell.data.ci0(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  ci1: {\n    value: m => m.cell.data.ci1(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  median: {\n    value: m => m.cell.data.q2(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  q1: {\n    value: m => m.cell.data.q1(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  q3: {\n    value: m => m.cell.data.q3(m.get),\n    req: ['values'],\n    idx: 3\n  },\n  min: {\n    init: m => m.min = undefined,\n    value: m => m.min = Number.isNaN(m.min) ? m.cell.data.min(m.get) : m.min,\n    add: (m, v) => {\n      if (v < m.min || m.min === undefined) m.min = v;\n    },\n    rem: (m, v) => {\n      if (v <= m.min) m.min = NaN;\n    },\n    req: ['values'],\n    idx: 4\n  },\n  max: {\n    init: m => m.max = undefined,\n    value: m => m.max = Number.isNaN(m.max) ? m.cell.data.max(m.get) : m.max,\n    add: (m, v) => {\n      if (v > m.max || m.max === undefined) m.max = v;\n    },\n    rem: (m, v) => {\n      if (v >= m.max) m.max = NaN;\n    },\n    req: ['values'],\n    idx: 4\n  },\n  argmin: {\n    init: m => m.argmin = undefined,\n    value: m => m.argmin || m.cell.data.argmin(m.get),\n    add: (m, v, t) => {\n      if (v < m.min) m.argmin = t;\n    },\n    rem: (m, v) => {\n      if (v <= m.min) m.argmin = undefined;\n    },\n    req: ['min', 'values'],\n    idx: 3\n  },\n  argmax: {\n    init: m => m.argmax = undefined,\n    value: m => m.argmax || m.cell.data.argmax(m.get),\n    add: (m, v, t) => {\n      if (v > m.max) m.argmax = t;\n    },\n    rem: (m, v) => {\n      if (v >= m.max) m.argmax = undefined;\n    },\n    req: ['max', 'values'],\n    idx: 3\n  }\n};\nconst ValidAggregateOps = Object.keys(AggregateOps).filter(d => d !== '__count__');\nfunction measure(key, value) {\n  return out => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n    name: key,\n    out: out || key\n  }, base_op, value);\n}\n[...ValidAggregateOps, '__count__'].forEach(key => {\n  AggregateOps[key] = measure(key, AggregateOps[key]);\n});\nfunction createMeasure(op, name) {\n  return AggregateOps[op](name);\n}\nfunction compareIndex(a, b) {\n  return a.idx - b.idx;\n}\nfunction resolve(agg) {\n  const map = {};\n  agg.forEach(a => map[a.name] = a);\n  const getreqs = a => {\n    if (!a.req) return;\n    a.req.forEach(key => {\n      if (!map[key]) getreqs(map[key] = AggregateOps[key]());\n    });\n  };\n  agg.forEach(getreqs);\n  return Object.values(map).sort(compareIndex);\n}\nfunction init() {\n  this.valid = 0;\n  this.missing = 0;\n  this._ops.forEach(op => op.init(this));\n}\nfunction add(v, t) {\n  if (v == null || v === '') {\n    ++this.missing;\n    return;\n  }\n  if (v !== v) return;\n  ++this.valid;\n  this._ops.forEach(op => op.add(this, v, t));\n}\nfunction rem(v, t) {\n  if (v == null || v === '') {\n    --this.missing;\n    return;\n  }\n  if (v !== v) return;\n  --this.valid;\n  this._ops.forEach(op => op.rem(this, v, t));\n}\nfunction set(t) {\n  this._out.forEach(op => t[op.out] = op.value(this));\n  return t;\n}\nfunction compileMeasures(agg, field) {\n  const get = field || vega_util__WEBPACK_IMPORTED_MODULE_0__.identity,\n    ops = resolve(agg),\n    out = agg.slice().sort(compareIndex);\n  function ctr(cell) {\n    this._ops = ops;\n    this._out = out;\n    this.cell = cell;\n    this.init();\n  }\n  ctr.prototype.init = init;\n  ctr.prototype.add = add;\n  ctr.prototype.rem = rem;\n  ctr.prototype.set = set;\n  ctr.prototype.get = get;\n  ctr.fields = agg.map(op => op.out);\n  return ctr;\n}\n\nfunction TupleStore(key) {\n  this._key = key ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(key) : vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid;\n  this.reset();\n}\nconst prototype$1 = TupleStore.prototype;\nprototype$1.reset = function () {\n  this._add = [];\n  this._rem = [];\n  this._ext = null;\n  this._get = null;\n  this._q = null;\n};\nprototype$1.add = function (v) {\n  this._add.push(v);\n};\nprototype$1.rem = function (v) {\n  this._rem.push(v);\n};\nprototype$1.values = function () {\n  this._get = null;\n  if (this._rem.length === 0) return this._add;\n  const a = this._add,\n    r = this._rem,\n    k = this._key,\n    n = a.length,\n    m = r.length,\n    x = Array(n - m),\n    map = {};\n  let i, j, v;\n\n  // use unique key field to clear removed values\n  for (i = 0; i < m; ++i) {\n    map[k(r[i])] = 1;\n  }\n  for (i = 0, j = 0; i < n; ++i) {\n    if (map[k(v = a[i])]) {\n      map[k(v)] = 0;\n    } else {\n      x[j++] = v;\n    }\n  }\n  this._rem = [];\n  return this._add = x;\n};\n\n// memoizing statistics methods\n\nprototype$1.distinct = function (get) {\n  const v = this.values(),\n    map = {};\n  let n = v.length,\n    count = 0,\n    s;\n  while (--n >= 0) {\n    s = get(v[n]) + '';\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(map, s)) {\n      map[s] = 1;\n      ++count;\n    }\n  }\n  return count;\n};\nprototype$1.extent = function (get) {\n  if (this._get !== get || !this._ext) {\n    const v = this.values(),\n      i = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extentIndex)(v, get);\n    this._ext = [v[i[0]], v[i[1]]];\n    this._get = get;\n  }\n  return this._ext;\n};\nprototype$1.argmin = function (get) {\n  return this.extent(get)[0] || {};\n};\nprototype$1.argmax = function (get) {\n  return this.extent(get)[1] || {};\n};\nprototype$1.min = function (get) {\n  const m = this.extent(get)[0];\n  return m != null ? get(m) : undefined;\n};\nprototype$1.max = function (get) {\n  const m = this.extent(get)[1];\n  return m != null ? get(m) : undefined;\n};\nprototype$1.quartile = function (get) {\n  if (this._get !== get || !this._q) {\n    this._q = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.quartiles)(this.values(), get);\n    this._get = get;\n  }\n  return this._q;\n};\nprototype$1.q1 = function (get) {\n  return this.quartile(get)[0];\n};\nprototype$1.q2 = function (get) {\n  return this.quartile(get)[1];\n};\nprototype$1.q3 = function (get) {\n  return this.quartile(get)[2];\n};\nprototype$1.ci = function (get) {\n  if (this._get !== get || !this._ci) {\n    this._ci = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.bootstrapCI)(this.values(), 1000, 0.05, get);\n    this._get = get;\n  }\n  return this._ci;\n};\nprototype$1.ci0 = function (get) {\n  return this.ci(get)[0];\n};\nprototype$1.ci1 = function (get) {\n  return this.ci(get)[1];\n};\n\n/**\n * Group-by aggregation operator.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors to groupby.\n * @param {Array<function(object): *>} [params.fields] - An array of accessors to aggregate.\n * @param {Array<string>} [params.ops] - An array of strings indicating aggregation operations.\n * @param {Array<string>} [params.as] - An array of output field names for aggregated values.\n * @param {boolean} [params.cross=false] - A flag indicating that the full\n *   cross-product of groupby values should be generated, including empty cells.\n *   If true, the drop parameter is ignored and empty cells are retained.\n * @param {boolean} [params.drop=true] - A flag indicating if empty cells should be removed.\n */\nfunction Aggregate(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n  this._adds = []; // array of added output tuples\n  this._mods = []; // array of modified output tuples\n  this._alen = 0; // number of active added tuples\n  this._mlen = 0; // number of active modified tuples\n  this._drop = true; // should empty aggregation cells be removed\n  this._cross = false; // produce full cross-product of group-by values\n\n  this._dims = []; // group-by dimension accessors\n  this._dnames = []; // group-by dimension names\n\n  this._measures = []; // collection of aggregation monoids\n  this._countOnly = false; // flag indicating only count aggregation\n  this._counts = null; // collection of count fields\n  this._prev = null; // previous aggregation cells\n\n  this._inputs = null; // array of dependent input tuple field names\n  this._outputs = null; // array of output tuple field names\n}\n\nAggregate.Definition = {\n  'type': 'Aggregate',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'ops',\n    'type': 'enum',\n    'array': true,\n    'values': ValidAggregateOps\n  }, {\n    'name': 'fields',\n    'type': 'field',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'drop',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'cross',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'key',\n    'type': 'field'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Aggregate, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const aggr = this,\n      out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      mod = _.modified();\n    aggr.stamp = out.stamp;\n    if (aggr.value && (mod || pulse.modified(aggr._inputs, true))) {\n      aggr._prev = aggr.value;\n      aggr.value = mod ? aggr.init(_) : Object.create(null);\n      pulse.visit(pulse.SOURCE, t => aggr.add(t));\n    } else {\n      aggr.value = aggr.value || aggr.init(_);\n      pulse.visit(pulse.REM, t => aggr.rem(t));\n      pulse.visit(pulse.ADD, t => aggr.add(t));\n    }\n\n    // Indicate output fields and return aggregate tuples.\n    out.modifies(aggr._outputs);\n\n    // Should empty cells be dropped?\n    aggr._drop = _.drop !== false;\n\n    // If domain cross-product requested, generate empty cells as needed\n    // and ensure that empty cells are not dropped\n    if (_.cross && aggr._dims.length > 1) {\n      aggr._drop = false;\n      aggr.cross();\n    }\n    if (pulse.clean() && aggr._drop) {\n      out.clean(true).runAfter(() => this.clean());\n    }\n    return aggr.changes(out);\n  },\n  cross() {\n    const aggr = this,\n      curr = aggr.value,\n      dims = aggr._dnames,\n      vals = dims.map(() => ({})),\n      n = dims.length;\n\n    // collect all group-by domain values\n    function collect(cells) {\n      let key, i, t, v;\n      for (key in cells) {\n        t = cells[key].tuple;\n        for (i = 0; i < n; ++i) {\n          vals[i][v = t[dims[i]]] = v;\n        }\n      }\n    }\n    collect(aggr._prev);\n    collect(curr);\n\n    // iterate over key cross-product, create cells as needed\n    function generate(base, tuple, index) {\n      const name = dims[index],\n        v = vals[index++];\n      for (const k in v) {\n        const key = base ? base + '|' + k : k;\n        tuple[name] = v[k];\n        if (index < n) generate(key, tuple, index);else if (!curr[key]) aggr.cell(key, tuple);\n      }\n    }\n    generate('', {}, 0);\n  },\n  init(_) {\n    // initialize input and output fields\n    const inputs = this._inputs = [],\n      outputs = this._outputs = [],\n      inputMap = {};\n    function inputVisit(get) {\n      const fields = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(get)),\n        n = fields.length;\n      let i = 0,\n        f;\n      for (; i < n; ++i) {\n        if (!inputMap[f = fields[i]]) {\n          inputMap[f] = 1;\n          inputs.push(f);\n        }\n      }\n    }\n\n    // initialize group-by dimensions\n    this._dims = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.groupby);\n    this._dnames = this._dims.map(d => {\n      const dname = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(d);\n      inputVisit(d);\n      outputs.push(dname);\n      return dname;\n    });\n    this.cellkey = _.key ? _.key : groupkey(this._dims);\n\n    // initialize aggregate measures\n    this._countOnly = true;\n    this._counts = [];\n    this._measures = [];\n    const fields = _.fields || [null],\n      ops = _.ops || ['count'],\n      as = _.as || [],\n      n = fields.length,\n      map = {};\n    let field, op, m, mname, outname, i;\n    if (n !== ops.length) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unmatched number of fields and aggregate ops.');\n    }\n    for (i = 0; i < n; ++i) {\n      field = fields[i];\n      op = ops[i];\n      if (field == null && op !== 'count') {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Null aggregate field specified.');\n      }\n      mname = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(field);\n      outname = measureName(op, mname, as[i]);\n      outputs.push(outname);\n      if (op === 'count') {\n        this._counts.push(outname);\n        continue;\n      }\n      m = map[mname];\n      if (!m) {\n        inputVisit(field);\n        m = map[mname] = [];\n        m.field = field;\n        this._measures.push(m);\n      }\n      if (op !== 'count') this._countOnly = false;\n      m.push(createMeasure(op, outname));\n    }\n    this._measures = this._measures.map(m => compileMeasures(m, m.field));\n    return Object.create(null); // aggregation cells (this.value)\n  },\n\n  // -- Cell Management -----\n\n  cellkey: groupkey(),\n  cell(key, t) {\n    let cell = this.value[key];\n    if (!cell) {\n      cell = this.value[key] = this.newcell(key, t);\n      this._adds[this._alen++] = cell;\n    } else if (cell.num === 0 && this._drop && cell.stamp < this.stamp) {\n      cell.stamp = this.stamp;\n      this._adds[this._alen++] = cell;\n    } else if (cell.stamp < this.stamp) {\n      cell.stamp = this.stamp;\n      this._mods[this._mlen++] = cell;\n    }\n    return cell;\n  },\n  newcell(key, t) {\n    const cell = {\n      key: key,\n      num: 0,\n      agg: null,\n      tuple: this.newtuple(t, this._prev && this._prev[key]),\n      stamp: this.stamp,\n      store: false\n    };\n    if (!this._countOnly) {\n      const measures = this._measures,\n        n = measures.length;\n      cell.agg = Array(n);\n      for (let i = 0; i < n; ++i) {\n        cell.agg[i] = new measures[i](cell);\n      }\n    }\n    if (cell.store) {\n      cell.data = new TupleStore();\n    }\n    return cell;\n  },\n  newtuple(t, p) {\n    const names = this._dnames,\n      dims = this._dims,\n      n = dims.length,\n      x = {};\n    for (let i = 0; i < n; ++i) {\n      x[names[i]] = dims[i](t);\n    }\n    return p ? (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.replace)(p.tuple, x) : (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(x);\n  },\n  clean() {\n    const cells = this.value;\n    for (const key in cells) {\n      if (cells[key].num === 0) {\n        delete cells[key];\n      }\n    }\n  },\n  // -- Process Tuples -----\n\n  add(t) {\n    const key = this.cellkey(t),\n      cell = this.cell(key, t);\n    cell.num += 1;\n    if (this._countOnly) return;\n    if (cell.store) cell.data.add(t);\n    const agg = cell.agg;\n    for (let i = 0, n = agg.length; i < n; ++i) {\n      agg[i].add(agg[i].get(t), t);\n    }\n  },\n  rem(t) {\n    const key = this.cellkey(t),\n      cell = this.cell(key, t);\n    cell.num -= 1;\n    if (this._countOnly) return;\n    if (cell.store) cell.data.rem(t);\n    const agg = cell.agg;\n    for (let i = 0, n = agg.length; i < n; ++i) {\n      agg[i].rem(agg[i].get(t), t);\n    }\n  },\n  celltuple(cell) {\n    const tuple = cell.tuple,\n      counts = this._counts;\n\n    // consolidate stored values\n    if (cell.store) {\n      cell.data.values();\n    }\n\n    // update tuple properties\n    for (let i = 0, n = counts.length; i < n; ++i) {\n      tuple[counts[i]] = cell.num;\n    }\n    if (!this._countOnly) {\n      const agg = cell.agg;\n      for (let i = 0, n = agg.length; i < n; ++i) {\n        agg[i].set(tuple);\n      }\n    }\n    return tuple;\n  },\n  changes(out) {\n    const adds = this._adds,\n      mods = this._mods,\n      prev = this._prev,\n      drop = this._drop,\n      add = out.add,\n      rem = out.rem,\n      mod = out.mod;\n    let cell, key, i, n;\n    if (prev) for (key in prev) {\n      cell = prev[key];\n      if (!drop || cell.num) rem.push(cell.tuple);\n    }\n    for (i = 0, n = this._alen; i < n; ++i) {\n      add.push(this.celltuple(adds[i]));\n      adds[i] = null; // for garbage collection\n    }\n\n    for (i = 0, n = this._mlen; i < n; ++i) {\n      cell = mods[i];\n      (cell.num === 0 && drop ? rem : mod).push(this.celltuple(cell));\n      mods[i] = null; // for garbage collection\n    }\n\n    this._alen = this._mlen = 0; // reset list of active cells\n    this._prev = null;\n    return out;\n  }\n});\n\n// epsilon bias to offset floating point error (#1737)\nconst EPSILON$1 = 1e-14;\n\n/**\n * Generates a binning function for discretizing data.\n * @constructor\n * @param {object} params - The parameters for this operator. The\n *   provided values should be valid options for the {@link bin} function.\n * @param {function(object): *} params.field - The data field to bin.\n */\nfunction Bin(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nBin.Definition = {\n  'type': 'Bin',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'interval',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'anchor',\n    'type': 'number'\n  }, {\n    'name': 'maxbins',\n    'type': 'number',\n    'default': 20\n  }, {\n    'name': 'base',\n    'type': 'number',\n    'default': 10\n  }, {\n    'name': 'divide',\n    'type': 'number',\n    'array': true,\n    'default': [5, 2]\n  }, {\n    'name': 'extent',\n    'type': 'number',\n    'array': true,\n    'length': 2,\n    'required': true\n  }, {\n    'name': 'span',\n    'type': 'number'\n  }, {\n    'name': 'step',\n    'type': 'number'\n  }, {\n    'name': 'steps',\n    'type': 'number',\n    'array': true\n  }, {\n    'name': 'minstep',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'nice',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'name',\n    'type': 'string'\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['bin0', 'bin1']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Bin, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const band = _.interval !== false,\n      bins = this._bins(_),\n      start = bins.start,\n      step = bins.step,\n      as = _.as || ['bin0', 'bin1'],\n      b0 = as[0],\n      b1 = as[1];\n    let flag;\n    if (_.modified()) {\n      pulse = pulse.reflow(true);\n      flag = pulse.SOURCE;\n    } else {\n      flag = pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(_.field)) ? pulse.ADD_MOD : pulse.ADD;\n    }\n    pulse.visit(flag, band ? t => {\n      const v = bins(t);\n      // minimum bin value (inclusive)\n      t[b0] = v;\n      // maximum bin value (exclusive)\n      // use convoluted math for better floating point agreement\n      // see https://github.com/vega/vega/issues/830\n      // infinite values propagate through this formula! #2227\n      t[b1] = v == null ? null : start + step * (1 + (v - start) / step);\n    } : t => t[b0] = bins(t));\n    return pulse.modifies(band ? as : b0);\n  },\n  _bins(_) {\n    if (this.value && !_.modified()) {\n      return this.value;\n    }\n    const field = _.field,\n      bins = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.bin)(_),\n      step = bins.step;\n    let start = bins.start,\n      stop = start + Math.ceil((bins.stop - start) / step) * step,\n      a,\n      d;\n    if ((a = _.anchor) != null) {\n      d = a - (start + step * Math.floor((a - start) / step));\n      start += d;\n      stop += d;\n    }\n    const f = function (t) {\n      let v = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(field(t));\n      return v == null ? null : v < start ? -Infinity : v > stop ? +Infinity : (v = Math.max(start, Math.min(v, stop - step)), start + step * Math.floor(EPSILON$1 + (v - start) / step));\n    };\n    f.start = start;\n    f.stop = bins.stop;\n    f.step = step;\n    return this.value = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor)(f, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(field), _.name || 'bin_' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(field));\n  }\n});\n\nfunction SortedList (idFunc, source, input) {\n  const $ = idFunc;\n  let data = source || [],\n    add = input || [],\n    rem = {},\n    cnt = 0;\n  return {\n    add: t => add.push(t),\n    remove: t => rem[$(t)] = ++cnt,\n    size: () => data.length,\n    data: (compare, resort) => {\n      if (cnt) {\n        data = data.filter(t => !rem[$(t)]);\n        rem = {};\n        cnt = 0;\n      }\n      if (resort && compare) {\n        data.sort(compare);\n      }\n      if (add.length) {\n        data = compare ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.merge)(compare, data, add.sort(compare)) : data.concat(add);\n        add = [];\n      }\n      return data;\n    }\n  };\n}\n\n/**\n * Collects all data tuples that pass through this operator.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(*,*): number} [params.sort] - An optional\n *   comparator function for additionally sorting the collected tuples.\n */\nfunction Collect(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n}\nCollect.Definition = {\n  'type': 'Collect',\n  'metadata': {\n    'source': true\n  },\n  'params': [{\n    'name': 'sort',\n    'type': 'compare'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Collect, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.ALL),\n      list = SortedList(vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid, this.value, out.materialize(out.ADD).add),\n      sort = _.sort,\n      mod = pulse.changed() || sort && (_.modified('sort') || pulse.modified(sort.fields));\n    out.visit(out.REM, list.remove);\n    this.modified(mod);\n    this.value = out.source = list.data((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.stableCompare)(sort), mod);\n\n    // propagate tree root if defined\n    if (pulse.source && pulse.source.root) {\n      this.value.root = pulse.source.root;\n    }\n    return out;\n  }\n});\n\n/**\n * Generates a comparator function.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<string|function>} params.fields - The fields to compare.\n * @param {Array<string>} [params.orders] - The sort orders.\n *   Each entry should be one of \"ascending\" (default) or \"descending\".\n */\nfunction Compare(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update$5, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Compare, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update$5(_) {\n  return this.value && !_.modified() ? this.value : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.compare)(_.fields, _.orders);\n}\n\n/**\n * Count regexp-defined pattern occurrences in a text field.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - An accessor for the text field.\n * @param {string} [params.pattern] - RegExp string defining the text pattern.\n * @param {string} [params.case] - One of 'lower', 'upper' or null (mixed) case.\n * @param {string} [params.stopwords] - RegExp string of words to ignore.\n */\nfunction CountPattern(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nCountPattern.Definition = {\n  'type': 'CountPattern',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'case',\n    'type': 'enum',\n    'values': ['upper', 'lower', 'mixed'],\n    'default': 'mixed'\n  }, {\n    'name': 'pattern',\n    'type': 'string',\n    'default': '[\\\\w\"]+'\n  }, {\n    'name': 'stopwords',\n    'type': 'string',\n    'default': ''\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['text', 'count']\n  }]\n};\nfunction tokenize(text, tcase, match) {\n  switch (tcase) {\n    case 'upper':\n      text = text.toUpperCase();\n      break;\n    case 'lower':\n      text = text.toLowerCase();\n      break;\n  }\n  return text.match(match);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(CountPattern, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const process = update => tuple => {\n      var tokens = tokenize(get(tuple), _.case, match) || [],\n        t;\n      for (var i = 0, n = tokens.length; i < n; ++i) {\n        if (!stop.test(t = tokens[i])) update(t);\n      }\n    };\n    const init = this._parameterCheck(_, pulse),\n      counts = this._counts,\n      match = this._match,\n      stop = this._stop,\n      get = _.field,\n      as = _.as || ['text', 'count'],\n      add = process(t => counts[t] = 1 + (counts[t] || 0)),\n      rem = process(t => counts[t] -= 1);\n    if (init) {\n      pulse.visit(pulse.SOURCE, add);\n    } else {\n      pulse.visit(pulse.ADD, add);\n      pulse.visit(pulse.REM, rem);\n    }\n    return this._finish(pulse, as); // generate output tuples\n  },\n\n  _parameterCheck(_, pulse) {\n    let init = false;\n    if (_.modified('stopwords') || !this._stop) {\n      this._stop = new RegExp('^' + (_.stopwords || '') + '$', 'i');\n      init = true;\n    }\n    if (_.modified('pattern') || !this._match) {\n      this._match = new RegExp(_.pattern || '[\\\\w\\']+', 'g');\n      init = true;\n    }\n    if (_.modified('field') || pulse.modified(_.field.fields)) {\n      init = true;\n    }\n    if (init) this._counts = {};\n    return init;\n  },\n  _finish(pulse, as) {\n    const counts = this._counts,\n      tuples = this._tuples || (this._tuples = {}),\n      text = as[0],\n      count = as[1],\n      out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n    let w, t, c;\n    for (w in counts) {\n      t = tuples[w];\n      c = counts[w] || 0;\n      if (!t && c) {\n        tuples[w] = t = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)({});\n        t[text] = w;\n        t[count] = c;\n        out.add.push(t);\n      } else if (c === 0) {\n        if (t) out.rem.push(t);\n        counts[w] = null;\n        tuples[w] = null;\n      } else if (t[count] !== c) {\n        t[count] = c;\n        out.mod.push(t);\n      }\n    }\n    return out.modifies(as);\n  }\n});\n\n/**\n * Perform a cross-product of a tuple stream with itself.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object):boolean} [params.filter] - An optional filter\n *   function for selectively including tuples in the cross product.\n * @param {Array<string>} [params.as] - The names of the output fields.\n */\nfunction Cross(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nCross.Definition = {\n  'type': 'Cross',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'filter',\n    'type': 'expr'\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['a', 'b']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Cross, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE),\n      as = _.as || ['a', 'b'],\n      a = as[0],\n      b = as[1],\n      reset = !this.value || pulse.changed(pulse.ADD_REM) || _.modified('as') || _.modified('filter');\n    let data = this.value;\n    if (reset) {\n      if (data) out.rem = data;\n      data = pulse.materialize(pulse.SOURCE).source;\n      out.add = this.value = cross(data, a, b, _.filter || vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy);\n    } else {\n      out.mod = data;\n    }\n    out.source = this.value;\n    return out.modifies(as);\n  }\n});\nfunction cross(input, a, b, filter) {\n  var data = [],\n    t = {},\n    n = input.length,\n    i = 0,\n    j,\n    left;\n  for (; i < n; ++i) {\n    t[a] = left = input[i];\n    for (j = 0; j < n; ++j) {\n      t[b] = input[j];\n      if (filter(t)) {\n        data.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n        t = {};\n        t[a] = left;\n      }\n    }\n  }\n  return data;\n}\n\nconst Distributions = {\n  kde: vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomKDE,\n  mixture: vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomMixture,\n  normal: vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomNormal,\n  lognormal: vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomLogNormal,\n  uniform: vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomUniform\n};\nconst DISTRIBUTIONS = 'distributions',\n  FUNCTION = 'function',\n  FIELD = 'field';\n\n/**\n * Parse a parameter object for a probability distribution.\n * @param {object} def - The distribution parameter object.\n * @param {function():Array<object>} - A method for requesting\n *   source data. Used for distributions (such as KDE) that\n *   require sample data points. This method will only be\n *   invoked if the 'from' parameter for a target data source\n *   is not provided. Typically this method returns backing\n *   source data for a Pulse object.\n * @return {object} - The output distribution object.\n */\nfunction parse(def, data) {\n  const func = def[FUNCTION];\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(Distributions, func)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unknown distribution function: ' + func);\n  }\n  const d = Distributions[func]();\n  for (const name in def) {\n    // if data field, extract values\n    if (name === FIELD) {\n      d.data((def.from || data()).map(def[name]));\n    }\n\n    // if distribution mixture, recurse to parse each definition\n    else if (name === DISTRIBUTIONS) {\n      d[name](def[name].map(_ => parse(_, data)));\n    }\n\n    // otherwise, simply set the parameter\n    else if (typeof d[name] === FUNCTION) {\n      d[name](def[name]);\n    }\n  }\n  return d;\n}\n\n/**\n * Grid sample points for a probability density. Given a distribution and\n * a sampling extent, will generate points suitable for plotting either\n * PDF (probability density function) or CDF (cumulative distribution\n * function) curves.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {object} params.distribution - The probability distribution. This\n *   is an object parameter dependent on the distribution type.\n * @param {string} [params.method='pdf'] - The distribution method to sample.\n *   One of 'pdf' or 'cdf'.\n * @param {Array<number>} [params.extent] - The [min, max] extent over which\n *   to sample the distribution. This argument is required in most cases, but\n *   can be omitted if the distribution (e.g., 'kde') supports a 'data' method\n *   that returns numerical sample points from which the extent can be deduced.\n * @param {number} [params.minsteps=25] - The minimum number of curve samples\n *   for plotting the density.\n * @param {number} [params.maxsteps=200] - The maximum number of curve samples\n *   for plotting the density.\n * @param {number} [params.steps] - The exact number of curve samples for\n *   plotting the density. If specified, overrides both minsteps and maxsteps\n *   to set an exact number of uniform samples. Useful in conjunction with\n *   a fixed extent to ensure consistent sample points for stacked densities.\n */\nfunction Density(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nconst distributions = [{\n  'key': {\n    'function': 'normal'\n  },\n  'params': [{\n    'name': 'mean',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'stdev',\n    'type': 'number',\n    'default': 1\n  }]\n}, {\n  'key': {\n    'function': 'lognormal'\n  },\n  'params': [{\n    'name': 'mean',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'stdev',\n    'type': 'number',\n    'default': 1\n  }]\n}, {\n  'key': {\n    'function': 'uniform'\n  },\n  'params': [{\n    'name': 'min',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'max',\n    'type': 'number',\n    'default': 1\n  }]\n}, {\n  'key': {\n    'function': 'kde'\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'from',\n    'type': 'data'\n  }, {\n    'name': 'bandwidth',\n    'type': 'number',\n    'default': 0\n  }]\n}];\nconst mixture = {\n  'key': {\n    'function': 'mixture'\n  },\n  'params': [{\n    'name': 'distributions',\n    'type': 'param',\n    'array': true,\n    'params': distributions\n  }, {\n    'name': 'weights',\n    'type': 'number',\n    'array': true\n  }]\n};\nDensity.Definition = {\n  'type': 'Density',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'extent',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'steps',\n    'type': 'number'\n  }, {\n    'name': 'minsteps',\n    'type': 'number',\n    'default': 25\n  }, {\n    'name': 'maxsteps',\n    'type': 'number',\n    'default': 200\n  }, {\n    'name': 'method',\n    'type': 'string',\n    'default': 'pdf',\n    'values': ['pdf', 'cdf']\n  }, {\n    'name': 'distribution',\n    'type': 'param',\n    'params': distributions.concat(mixture)\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'default': ['value', 'density']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Density, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n    if (!this.value || pulse.changed() || _.modified()) {\n      const dist = parse(_.distribution, source(pulse)),\n        minsteps = _.steps || _.minsteps || 25,\n        maxsteps = _.steps || _.maxsteps || 200;\n      let method = _.method || 'pdf';\n      if (method !== 'pdf' && method !== 'cdf') {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid density method: ' + method);\n      }\n      if (!_.extent && !dist.data) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing density extent parameter.');\n      }\n      method = dist[method];\n      const as = _.as || ['value', 'density'],\n        domain = _.extent || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(dist.data()),\n        values = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.sampleCurve)(method, domain, minsteps, maxsteps).map(v => {\n          const tuple = {};\n          tuple[as[0]] = v[0];\n          tuple[as[1]] = v[1];\n          return (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(tuple);\n        });\n      if (this.value) out.rem = this.value;\n      this.value = out.add = out.source = values;\n    }\n    return out;\n  }\n});\nfunction source(pulse) {\n  return () => pulse.materialize(pulse.SOURCE).source;\n}\n\n// use either provided alias or accessor field name\nfunction fieldNames(fields, as) {\n  if (!fields) return null;\n  return fields.map((f, i) => as[i] || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(f));\n}\nfunction partition$1(data, groupby, field) {\n  const groups = [],\n    get = f => f(t);\n  let map, i, n, t, k, g;\n\n  // partition data points into groups\n  if (groupby == null) {\n    groups.push(data.map(field));\n  } else {\n    for (map = {}, i = 0, n = data.length; i < n; ++i) {\n      t = data[i];\n      k = groupby.map(get);\n      g = map[k];\n      if (!g) {\n        map[k] = g = [];\n        g.dims = k;\n        groups.push(g);\n      }\n      g.push(field(t));\n    }\n  }\n  return groups;\n}\n\nconst Output = 'bin';\n\n/**\n * Dot density binning for dot plot construction.\n * Based on Leland Wilkinson, Dot Plots, The American Statistician, 1999.\n * https://www.cs.uic.edu/~wilkinson/Publications/dotplots.pdf\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to bin.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors to groupby.\n * @param {number} [params.step] - The step size (bin width) within which dots should be\n *   stacked. Defaults to 1/30 of the extent of the data *field*.\n * @param {boolean} [params.smooth=false] - A boolean flag indicating if dot density\n *   stacks should be smoothed to reduce variance.\n */\nfunction DotBin(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nDotBin.Definition = {\n  'type': 'DotBin',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'step',\n    'type': 'number'\n  }, {\n    'name': 'smooth',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': Output\n  }]\n};\nconst autostep = (data, field) => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.span)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(data, field)) / 30;\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(DotBin, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !(_.modified() || pulse.changed())) {\n      return pulse; // early exit\n    }\n\n    const source = pulse.materialize(pulse.SOURCE).source,\n      groups = partition$1(pulse.source, _.groupby, vega_util__WEBPACK_IMPORTED_MODULE_0__.identity),\n      smooth = _.smooth || false,\n      field = _.field,\n      step = _.step || autostep(source, field),\n      sort = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.stableCompare)((a, b) => field(a) - field(b)),\n      as = _.as || Output,\n      n = groups.length;\n\n    // compute dotplot bins per group\n    let min = Infinity,\n      max = -Infinity,\n      i = 0,\n      j;\n    for (; i < n; ++i) {\n      const g = groups[i].sort(sort);\n      j = -1;\n      for (const v of (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.dotbin)(g, step, smooth, field)) {\n        if (v < min) min = v;\n        if (v > max) max = v;\n        g[++j][as] = v;\n      }\n    }\n    this.value = {\n      start: min,\n      stop: max,\n      step: step\n    };\n    return pulse.reflow(true).modifies(as);\n  }\n});\n\n/**\n * Wraps an expression function with access to external parameters.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function} params.expr - The expression function. The\n *  function should accept both a datum and a parameter object.\n *  This operator's value will be a new function that wraps the\n *  expression function with access to this operator's parameters.\n */\nfunction Expression(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update$4, params);\n  this.modified(true);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Expression, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update$4(_) {\n  const expr = _.expr;\n  return this.value && !_.modified('expr') ? this.value : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor)(datum => expr(datum, _), (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(expr), (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(expr));\n}\n\n/**\n * Computes extents (min/max) for a data field.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The field over which to compute extends.\n */\nfunction Extent(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [undefined, undefined], params);\n}\nExtent.Definition = {\n  'type': 'Extent',\n  'metadata': {},\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Extent, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const extent = this.value,\n      field = _.field,\n      mod = pulse.changed() || pulse.modified(field.fields) || _.modified('field');\n    let min = extent[0],\n      max = extent[1];\n    if (mod || min == null) {\n      min = +Infinity;\n      max = -Infinity;\n    }\n    pulse.visit(mod ? pulse.SOURCE : pulse.ADD, t => {\n      const v = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber)(field(t));\n      if (v != null) {\n        // NaNs will fail all comparisons!\n        if (v < min) min = v;\n        if (v > max) max = v;\n      }\n    });\n    if (!Number.isFinite(min) || !Number.isFinite(max)) {\n      let name = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(field);\n      if (name) name = ` for field \"${name}\"`;\n      pulse.dataflow.warn(`Infinite extent${name}: [${min}, ${max}]`);\n      min = max = undefined;\n    }\n    this.value = [min, max];\n  }\n});\n\n/**\n * Provides a bridge between a parent transform and a target subflow that\n * consumes only a subset of the tuples that pass through the parent.\n * @constructor\n * @param {Pulse} pulse - A pulse to use as the value of this operator.\n * @param {Transform} parent - The parent transform (typically a Facet instance).\n */\nfunction Subflow(pulse, parent) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, pulse);\n  this.parent = parent;\n  this.count = 0;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Subflow, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator, {\n  /**\n   * Routes pulses from this subflow to a target transform.\n   * @param {Transform} target - A transform that receives the subflow of tuples.\n   */\n  connect(target) {\n    this.detachSubflow = target.detachSubflow;\n    this.targets().add(target);\n    return target.source = this;\n  },\n  /**\n   * Add an 'add' tuple to the subflow pulse.\n   * @param {Tuple} t - The tuple being added.\n   */\n  add(t) {\n    this.count += 1;\n    this.value.add.push(t);\n  },\n  /**\n   * Add a 'rem' tuple to the subflow pulse.\n   * @param {Tuple} t - The tuple being removed.\n   */\n  rem(t) {\n    this.count -= 1;\n    this.value.rem.push(t);\n  },\n  /**\n   * Add a 'mod' tuple to the subflow pulse.\n   * @param {Tuple} t - The tuple being modified.\n   */\n  mod(t) {\n    this.value.mod.push(t);\n  },\n  /**\n   * Re-initialize this operator's pulse value.\n   * @param {Pulse} pulse - The pulse to copy from.\n   * @see Pulse.init\n   */\n  init(pulse) {\n    this.value.init(pulse, pulse.NO_SOURCE);\n  },\n  /**\n   * Evaluate this operator. This method overrides the\n   * default behavior to simply return the contained pulse value.\n   * @return {Pulse}\n   */\n  evaluate() {\n    // assert: this.value.stamp === pulse.stamp\n    return this.value;\n  }\n});\n\n/**\n * Facets a dataflow into a set of subflows based on a key.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(Dataflow, string): Operator} params.subflow - A function\n *   that generates a subflow of operators and returns its root operator.\n * @param {function(object): *} params.key - The key field to facet by.\n */\nfunction Facet(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, {}, params);\n  this._keys = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.fastmap)(); // cache previously calculated key values\n\n  // keep track of active subflows, use as targets array for listeners\n  // this allows us to limit propagation to only updated subflows\n  const a = this._targets = [];\n  a.active = 0;\n  a.forEach = f => {\n    for (let i = 0, n = a.active; i < n; ++i) {\n      f(a[i], i, a);\n    }\n  };\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Facet, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  activate(flow) {\n    this._targets[this._targets.active++] = flow;\n  },\n  // parent argument provided by PreFacet subclass\n  subflow(key, flow, pulse, parent) {\n    const flows = this.value;\n    let sf = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(flows, key) && flows[key],\n      df,\n      p;\n    if (!sf) {\n      p = parent || (p = this._group[key]) && p.tuple;\n      df = pulse.dataflow;\n      sf = new Subflow(pulse.fork(pulse.NO_SOURCE), this);\n      df.add(sf).connect(flow(df, key, p));\n      flows[key] = sf;\n      this.activate(sf);\n    } else if (sf.value.stamp < pulse.stamp) {\n      sf.init(pulse);\n      this.activate(sf);\n    }\n    return sf;\n  },\n  clean() {\n    const flows = this.value;\n    let detached = 0;\n    for (const key in flows) {\n      if (flows[key].count === 0) {\n        const detach = flows[key].detachSubflow;\n        if (detach) detach();\n        delete flows[key];\n        ++detached;\n      }\n    }\n\n    // remove inactive targets from the active targets array\n    if (detached) {\n      const active = this._targets.filter(sf => sf && sf.count > 0);\n      this.initTargets(active);\n    }\n  },\n  initTargets(act) {\n    const a = this._targets,\n      n = a.length,\n      m = act ? act.length : 0;\n    let i = 0;\n    for (; i < m; ++i) {\n      a[i] = act[i];\n    }\n    for (; i < n && a[i] != null; ++i) {\n      a[i] = null; // ensure old flows can be garbage collected\n    }\n\n    a.active = m;\n  },\n  transform(_, pulse) {\n    const df = pulse.dataflow,\n      key = _.key,\n      flow = _.subflow,\n      cache = this._keys,\n      rekey = _.modified('key'),\n      subflow = key => this.subflow(key, flow, pulse);\n    this._group = _.group || {};\n    this.initTargets(); // reset list of active subflows\n\n    pulse.visit(pulse.REM, t => {\n      const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t),\n        k = cache.get(id);\n      if (k !== undefined) {\n        cache.delete(id);\n        subflow(k).rem(t);\n      }\n    });\n    pulse.visit(pulse.ADD, t => {\n      const k = key(t);\n      cache.set((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t), k);\n      subflow(k).add(t);\n    });\n    if (rekey || pulse.modified(key.fields)) {\n      pulse.visit(pulse.MOD, t => {\n        const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t),\n          k0 = cache.get(id),\n          k1 = key(t);\n        if (k0 === k1) {\n          subflow(k1).mod(t);\n        } else {\n          cache.set(id, k1);\n          subflow(k0).rem(t);\n          subflow(k1).add(t);\n        }\n      });\n    } else if (pulse.changed(pulse.MOD)) {\n      pulse.visit(pulse.MOD, t => {\n        subflow(cache.get((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t))).mod(t);\n      });\n    }\n    if (rekey) {\n      pulse.visit(pulse.REFLOW, t => {\n        const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t),\n          k0 = cache.get(id),\n          k1 = key(t);\n        if (k0 !== k1) {\n          cache.set(id, k1);\n          subflow(k0).rem(t);\n          subflow(k1).add(t);\n        }\n      });\n    }\n    if (pulse.clean()) {\n      df.runAfter(() => {\n        this.clean();\n        cache.clean();\n      });\n    } else if (cache.empty > df.cleanThreshold) {\n      df.runAfter(cache.clean);\n    }\n    return pulse;\n  }\n});\n\n/**\n * Generates one or more field accessor functions.\n * If the 'name' parameter is an array, an array of field accessors\n * will be created and the 'as' parameter will be ignored.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {string} params.name - The field name(s) to access.\n * @param {string} params.as - The accessor function name.\n */\nfunction Field(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update$3, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Field, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update$3(_) {\n  return this.value && !_.modified() ? this.value : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(_.name) ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.name).map(f => (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(f)) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.field)(_.name, _.as);\n}\n\n/**\n * Filters data tuples according to a predicate function.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.expr - The predicate expression function\n *   that determines a tuple's filter status. Truthy values pass the filter.\n */\nfunction Filter(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.fastmap)(), params);\n}\nFilter.Definition = {\n  'type': 'Filter',\n  'metadata': {\n    'changes': true\n  },\n  'params': [{\n    'name': 'expr',\n    'type': 'expr',\n    'required': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Filter, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const df = pulse.dataflow,\n      cache = this.value,\n      // cache ids of filtered tuples\n      output = pulse.fork(),\n      add = output.add,\n      rem = output.rem,\n      mod = output.mod,\n      test = _.expr;\n    let isMod = true;\n    pulse.visit(pulse.REM, t => {\n      const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t);\n      if (!cache.has(id)) rem.push(t);else cache.delete(id);\n    });\n    pulse.visit(pulse.ADD, t => {\n      if (test(t, _)) add.push(t);else cache.set((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t), 1);\n    });\n    function revisit(t) {\n      const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t),\n        b = test(t, _),\n        s = cache.get(id);\n      if (b && s) {\n        cache.delete(id);\n        add.push(t);\n      } else if (!b && !s) {\n        cache.set(id, 1);\n        rem.push(t);\n      } else if (isMod && b && !s) {\n        mod.push(t);\n      }\n    }\n    pulse.visit(pulse.MOD, revisit);\n    if (_.modified()) {\n      isMod = false;\n      pulse.visit(pulse.REFLOW, revisit);\n    }\n    if (cache.empty > df.cleanThreshold) df.runAfter(cache.clean);\n    return output;\n  }\n});\n\n/**\n * Flattens array-typed field values into new data objects.\n * If multiple fields are specified, they are treated as parallel arrays,\n * with output values included for each matching index (or null if missing).\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} params.fields - An array of field\n *   accessors for the tuple fields that should be flattened.\n * @param {string} [params.index] - Optional output field name for index\n *   value. If unspecified, no index field is included in the output.\n * @param {Array<string>} [params.as] - Output field names for flattened\n *   array fields. Any unspecified fields will use the field name provided\n *   by the fields accessors.\n */\nfunction Flatten(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n}\nFlatten.Definition = {\n  'type': 'Flatten',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'required': true\n  }, {\n    'name': 'index',\n    'type': 'string'\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Flatten, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE),\n      fields = _.fields,\n      as = fieldNames(fields, _.as || []),\n      index = _.index || null,\n      m = as.length;\n\n    // remove any previous results\n    out.rem = this.value;\n\n    // generate flattened tuples\n    pulse.visit(pulse.SOURCE, t => {\n      const arrays = fields.map(f => f(t)),\n        maxlen = arrays.reduce((l, a) => Math.max(l, a.length), 0);\n      let i = 0,\n        j,\n        d,\n        v;\n      for (; i < maxlen; ++i) {\n        d = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.derive)(t);\n        for (j = 0; j < m; ++j) {\n          d[as[j]] = (v = arrays[j][i]) == null ? null : v;\n        }\n        if (index) {\n          d[index] = i;\n        }\n        out.add.push(d);\n      }\n    });\n    this.value = out.source = out.add;\n    if (index) out.modifies(index);\n    return out.modifies(as);\n  }\n});\n\n/**\n * Folds one more tuple fields into multiple tuples in which the field\n * name and values are available under new 'key' and 'value' fields.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.fields - An array of field accessors\n *   for the tuple fields that should be folded.\n * @param {Array<string>} [params.as] - Output field names for folded key\n *   and value fields, defaults to ['key', 'value'].\n */\nfunction Fold(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n}\nFold.Definition = {\n  'type': 'Fold',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'required': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': ['key', 'value']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Fold, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE),\n      fields = _.fields,\n      fnames = fields.map(vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName),\n      as = _.as || ['key', 'value'],\n      k = as[0],\n      v = as[1],\n      n = fields.length;\n    out.rem = this.value;\n    pulse.visit(pulse.SOURCE, t => {\n      for (let i = 0, d; i < n; ++i) {\n        d = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.derive)(t);\n        d[k] = fnames[i];\n        d[v] = fields[i](t);\n        out.add.push(d);\n      }\n    });\n    this.value = out.source = out.add;\n    return out.modifies(as);\n  }\n});\n\n/**\n * Invokes a function for each data tuple and saves the results as a new field.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.expr - The formula function to invoke for each tuple.\n * @param {string} params.as - The field name under which to save the result.\n * @param {boolean} [params.initonly=false] - If true, the formula is applied to\n *   added tuples only, and does not update in response to modifications.\n */\nfunction Formula(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nFormula.Definition = {\n  'type': 'Formula',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'expr',\n    'type': 'expr',\n    'required': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'required': true\n  }, {\n    'name': 'initonly',\n    'type': 'boolean'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Formula, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const func = _.expr,\n      as = _.as,\n      mod = _.modified(),\n      flag = _.initonly ? pulse.ADD : mod ? pulse.SOURCE : pulse.modified(func.fields) || pulse.modified(as) ? pulse.ADD_MOD : pulse.ADD;\n    if (mod) {\n      // parameters updated, need to reflow\n      pulse = pulse.materialize().reflow(true);\n    }\n    if (!_.initonly) {\n      pulse.modifies(as);\n    }\n    return pulse.visit(flag, t => t[as] = func(t, _));\n  }\n});\n\n/**\n * Generates data tuples using a provided generator function.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(Parameters): object} params.generator - A tuple generator\n *   function. This function is given the operator parameters as input.\n *   Changes to any additional parameters will not trigger re-calculation\n *   of previously generated tuples. Only future tuples are affected.\n * @param {number} params.size - The number of tuples to produce.\n */\nfunction Generate(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Generate, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.ALL),\n      gen = _.generator;\n    let data = this.value,\n      num = _.size - data.length,\n      add,\n      rem,\n      t;\n    if (num > 0) {\n      // need more tuples, generate and add\n      for (add = []; --num >= 0;) {\n        add.push(t = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(gen(_)));\n        data.push(t);\n      }\n      out.add = out.add.length ? out.materialize(out.ADD).add.concat(add) : add;\n    } else {\n      // need fewer tuples, remove\n      rem = data.slice(0, -num);\n      out.rem = out.rem.length ? out.materialize(out.REM).rem.concat(rem) : rem;\n      data = data.slice(-num);\n    }\n    out.source = this.value = data;\n    return out;\n  }\n});\n\nconst Methods = {\n  value: 'value',\n  median: d3_array__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  mean: d3_array__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  min: d3_array__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  max: d3_array__WEBPACK_IMPORTED_MODULE_7__[\"default\"]\n};\nconst Empty = [];\n\n/**\n * Impute missing values.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The value field to impute.\n * @param {Array<function(object): *>} [params.groupby] - An array of\n *   accessors to determine series within which to perform imputation.\n * @param {function(object): *} params.key - An accessor for a key value.\n *   Each key value should be unique within a group. New tuples will be\n *   imputed for any key values that are not found within a group.\n * @param {Array<*>} [params.keyvals] - Optional array of required key\n *   values. New tuples will be imputed for any key values that are not\n *   found within a group. In addition, these values will be automatically\n *   augmented with the key values observed in the input data.\n * @param {string} [method='value'] - The imputation method to use. One of\n *   'value', 'mean', 'median', 'max', 'min'.\n * @param {*} [value=0] - The constant value to use for imputation\n *   when using method 'value'.\n */\nfunction Impute(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n}\nImpute.Definition = {\n  'type': 'Impute',\n  'metadata': {\n    'changes': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'key',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'keyvals',\n    'array': true\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'method',\n    'type': 'enum',\n    'default': 'value',\n    'values': ['value', 'mean', 'median', 'max', 'min']\n  }, {\n    'name': 'value',\n    'default': 0\n  }]\n};\nfunction getValue(_) {\n  var m = _.method || Methods.value,\n    v;\n  if (Methods[m] == null) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized imputation method: ' + m);\n  } else if (m === Methods.value) {\n    v = _.value !== undefined ? _.value : 0;\n    return () => v;\n  } else {\n    return Methods[m];\n  }\n}\nfunction getField(_) {\n  const f = _.field;\n  return t => t ? f(t) : NaN;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Impute, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    var out = pulse.fork(pulse.ALL),\n      impute = getValue(_),\n      field = getField(_),\n      fName = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(_.field),\n      kName = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(_.key),\n      gNames = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName),\n      groups = partition(pulse.source, _.groupby, _.key, _.keyvals),\n      curr = [],\n      prev = this.value,\n      m = groups.domain.length,\n      group,\n      value,\n      gVals,\n      kVal,\n      g,\n      i,\n      j,\n      l,\n      n,\n      t;\n    for (g = 0, l = groups.length; g < l; ++g) {\n      group = groups[g];\n      gVals = group.values;\n      value = NaN;\n\n      // add tuples for missing values\n      for (j = 0; j < m; ++j) {\n        if (group[j] != null) continue;\n        kVal = groups.domain[j];\n        t = {\n          _impute: true\n        };\n        for (i = 0, n = gVals.length; i < n; ++i) t[gNames[i]] = gVals[i];\n        t[kName] = kVal;\n        t[fName] = Number.isNaN(value) ? value = impute(group, field) : value;\n        curr.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n      }\n    }\n\n    // update pulse with imputed tuples\n    if (curr.length) out.add = out.materialize(out.ADD).add.concat(curr);\n    if (prev.length) out.rem = out.materialize(out.REM).rem.concat(prev);\n    this.value = curr;\n    return out;\n  }\n});\nfunction partition(data, groupby, key, keyvals) {\n  var get = f => f(t),\n    groups = [],\n    domain = keyvals ? keyvals.slice() : [],\n    kMap = {},\n    gMap = {},\n    gVals,\n    gKey,\n    group,\n    i,\n    j,\n    k,\n    n,\n    t;\n  domain.forEach((k, i) => kMap[k] = i + 1);\n  for (i = 0, n = data.length; i < n; ++i) {\n    t = data[i];\n    k = key(t);\n    j = kMap[k] || (kMap[k] = domain.push(k));\n    gKey = (gVals = groupby ? groupby.map(get) : Empty) + '';\n    if (!(group = gMap[gKey])) {\n      group = gMap[gKey] = [];\n      groups.push(group);\n      group.values = gVals;\n    }\n    group[j - 1] = t;\n  }\n  groups.domain = domain;\n  return groups;\n}\n\n/**\n * Extend input tuples with aggregate values.\n * Calcuates aggregate values and joins them with the input stream.\n * @constructor\n */\nfunction JoinAggregate(params) {\n  Aggregate.call(this, params);\n}\nJoinAggregate.Definition = {\n  'type': 'JoinAggregate',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'fields',\n    'type': 'field',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'ops',\n    'type': 'enum',\n    'array': true,\n    'values': ValidAggregateOps\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'key',\n    'type': 'field'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(JoinAggregate, Aggregate, {\n  transform(_, pulse) {\n    const aggr = this,\n      mod = _.modified();\n    let cells;\n\n    // process all input tuples to calculate aggregates\n    if (aggr.value && (mod || pulse.modified(aggr._inputs, true))) {\n      cells = aggr.value = mod ? aggr.init(_) : {};\n      pulse.visit(pulse.SOURCE, t => aggr.add(t));\n    } else {\n      cells = aggr.value = aggr.value || this.init(_);\n      pulse.visit(pulse.REM, t => aggr.rem(t));\n      pulse.visit(pulse.ADD, t => aggr.add(t));\n    }\n\n    // update aggregation cells\n    aggr.changes();\n\n    // write aggregate values to input tuples\n    pulse.visit(pulse.SOURCE, t => {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(t, cells[aggr.cellkey(t)].tuple);\n    });\n    return pulse.reflow(mod).modifies(this._outputs);\n  },\n  changes() {\n    const adds = this._adds,\n      mods = this._mods;\n    let i, n;\n    for (i = 0, n = this._alen; i < n; ++i) {\n      this.celltuple(adds[i]);\n      adds[i] = null; // for garbage collection\n    }\n\n    for (i = 0, n = this._mlen; i < n; ++i) {\n      this.celltuple(mods[i]);\n      mods[i] = null; // for garbage collection\n    }\n\n    this._alen = this._mlen = 0; // reset list of active cells\n  }\n});\n\n/**\n * Compute kernel density estimates (KDE) for one or more data groups.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors\n *   to groupby.\n * @param {function(object): *} params.field - An accessor for the data field\n *   to estimate.\n * @param {number} [params.bandwidth=0] - The KDE kernel bandwidth.\n *   If zero or unspecified, the bandwidth is automatically determined.\n * @param {boolean} [params.counts=false] - A boolean flag indicating if the\n *   output values should be probability estimates (false, default) or\n *   smoothed counts (true).\n * @param {string} [params.cumulative=false] - A boolean flag indicating if a\n *   density (false) or cumulative distribution (true) should be generated.\n * @param {Array<number>} [params.extent] - The domain extent over which to\n *   plot the density. If unspecified, the [min, max] data extent is used.\n * @param {string} [params.resolve='independent'] - Indicates how parameters for\n *   multiple densities should be resolved. If \"independent\" (the default), each\n *   density may have its own domain extent and dynamic number of curve sample\n *   steps. If \"shared\", the KDE transform will ensure that all densities are\n *   defined over a shared domain and curve steps, enabling stacking.\n * @param {number} [params.minsteps=25] - The minimum number of curve samples\n *   for plotting the density.\n * @param {number} [params.maxsteps=200] - The maximum number of curve samples\n *   for plotting the density.\n * @param {number} [params.steps] - The exact number of curve samples for\n *   plotting the density. If specified, overrides both minsteps and maxsteps\n *   to set an exact number of uniform samples. Useful in conjunction with\n *   a fixed extent to ensure consistent sample points for stacked densities.\n */\nfunction KDE(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nKDE.Definition = {\n  'type': 'KDE',\n  'metadata': {\n    'generates': true\n  },\n  'params': [{\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'cumulative',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'counts',\n    'type': 'boolean',\n    'default': false\n  }, {\n    'name': 'bandwidth',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'extent',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'resolve',\n    'type': 'enum',\n    'values': ['shared', 'independent'],\n    'default': 'independent'\n  }, {\n    'name': 'steps',\n    'type': 'number'\n  }, {\n    'name': 'minsteps',\n    'type': 'number',\n    'default': 25\n  }, {\n    'name': 'maxsteps',\n    'type': 'number',\n    'default': 200\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'default': ['value', 'density']\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(KDE, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS);\n    if (!this.value || pulse.changed() || _.modified()) {\n      const source = pulse.materialize(pulse.SOURCE).source,\n        groups = partition$1(source, _.groupby, _.field),\n        names = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName),\n        bandwidth = _.bandwidth,\n        method = _.cumulative ? 'cdf' : 'pdf',\n        as = _.as || ['value', 'density'],\n        values = [];\n      let domain = _.extent,\n        minsteps = _.steps || _.minsteps || 25,\n        maxsteps = _.steps || _.maxsteps || 200;\n      if (method !== 'pdf' && method !== 'cdf') {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Invalid density method: ' + method);\n      }\n      if (_.resolve === 'shared') {\n        if (!domain) domain = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(source, _.field);\n        minsteps = maxsteps = _.steps || maxsteps;\n      }\n      groups.forEach(g => {\n        const density = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.randomKDE)(g, bandwidth)[method],\n          scale = _.counts ? g.length : 1,\n          local = domain || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(g);\n        (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.sampleCurve)(density, local, minsteps, maxsteps).forEach(v => {\n          const t = {};\n          for (let i = 0; i < names.length; ++i) {\n            t[names[i]] = g.dims[i];\n          }\n          t[as[0]] = v[0];\n          t[as[1]] = v[1] * scale;\n          values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n        });\n      });\n      if (this.value) out.rem = this.value;\n      this.value = out.add = out.source = values;\n    }\n    return out;\n  }\n});\n\n/**\n * Generates a key function.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<string>} params.fields - The field name(s) for the key function.\n * @param {boolean} params.flat - A boolean flag indicating if the field names\n *  should be treated as flat property names, side-stepping nested field\n *  lookups normally indicated by dot or bracket notation.\n */\nfunction Key(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update$2, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Key, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update$2(_) {\n  return this.value && !_.modified() ? this.value : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.key)(_.fields, _.flat);\n}\n\n/**\n * Load and parse data from an external source. Marshalls parameter\n * values and then invokes the Dataflow request method.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {string} params.url - The URL to load from.\n * @param {object} params.format - The data format options.\n */\nfunction Load(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n  this._pending = null;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Load, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const df = pulse.dataflow;\n    if (this._pending) {\n      // update state and return pulse\n      return output(this, pulse, this._pending);\n    }\n    if (stop(_)) return pulse.StopPropagation;\n    if (_.values) {\n      // parse and ingest values, return output pulse\n      return output(this, pulse, df.parse(_.values, _.format));\n    } else if (_.async) {\n      // return promise for non-blocking async loading\n      const p = df.request(_.url, _.format).then(res => {\n        this._pending = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(res.data);\n        return df => df.touch(this);\n      });\n      return {\n        async: p\n      };\n    } else {\n      // return promise for synchronous loading\n      return df.request(_.url, _.format).then(res => output(this, pulse, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(res.data)));\n    }\n  }\n});\nfunction stop(_) {\n  return _.modified('async') && !(_.modified('values') || _.modified('url') || _.modified('format'));\n}\nfunction output(op, pulse, data) {\n  data.forEach(vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest);\n  const out = pulse.fork(pulse.NO_FIELDS & pulse.NO_SOURCE);\n  out.rem = op.value;\n  op.value = out.source = out.add = data;\n  op._pending = null;\n  if (out.rem.length) out.clean(true);\n  return out;\n}\n\n/**\n * Extend tuples by joining them with values from a lookup table.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Map} params.index - The lookup table map.\n * @param {Array<function(object): *} params.fields - The fields to lookup.\n * @param {Array<string>} params.as - Output field names for each lookup value.\n * @param {*} [params.default] - A default value to use if lookup fails.\n */\nfunction Lookup(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, {}, params);\n}\nLookup.Definition = {\n  'type': 'Lookup',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'index',\n    'type': 'index',\n    'params': [{\n      'name': 'from',\n      'type': 'data',\n      'required': true\n    }, {\n      'name': 'key',\n      'type': 'field',\n      'required': true\n    }]\n  }, {\n    'name': 'values',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'fields',\n    'type': 'field',\n    'array': true,\n    'required': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true\n  }, {\n    'name': 'default',\n    'default': null\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Lookup, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const keys = _.fields,\n      index = _.index,\n      values = _.values,\n      defaultValue = _.default == null ? null : _.default,\n      reset = _.modified(),\n      n = keys.length;\n    let flag = reset ? pulse.SOURCE : pulse.ADD,\n      out = pulse,\n      as = _.as,\n      set,\n      m,\n      mods;\n    if (values) {\n      m = values.length;\n      if (n > 1 && !as) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Multi-field lookup requires explicit \"as\" parameter.');\n      }\n      if (as && as.length !== n * m) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('The \"as\" parameter has too few output field names.');\n      }\n      as = as || values.map(vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName);\n      set = function (t) {\n        for (var i = 0, k = 0, j, v; i < n; ++i) {\n          v = index.get(keys[i](t));\n          if (v == null) for (j = 0; j < m; ++j, ++k) t[as[k]] = defaultValue;else for (j = 0; j < m; ++j, ++k) t[as[k]] = values[j](v);\n        }\n      };\n    } else {\n      if (!as) {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Missing output field names.');\n      }\n      set = function (t) {\n        for (var i = 0, v; i < n; ++i) {\n          v = index.get(keys[i](t));\n          t[as[i]] = v == null ? defaultValue : v;\n        }\n      };\n    }\n    if (reset) {\n      out = pulse.reflow(true);\n    } else {\n      mods = keys.some(k => pulse.modified(k.fields));\n      flag |= mods ? pulse.MOD : 0;\n    }\n    pulse.visit(flag, set);\n    return out.modifies(as);\n  }\n});\n\n/**\n * Computes global min/max extents over a collection of extents.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<Array<number>>} params.extents - The input extents.\n */\nfunction MultiExtent(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update$1, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(MultiExtent, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update$1(_) {\n  if (this.value && !_.modified()) {\n    return this.value;\n  }\n  const ext = _.extents,\n    n = ext.length;\n  let min = +Infinity,\n    max = -Infinity,\n    i,\n    e;\n  for (i = 0; i < n; ++i) {\n    e = ext[i];\n    if (e[0] < min) min = e[0];\n    if (e[1] > max) max = e[1];\n  }\n  return [min, max];\n}\n\n/**\n * Merge a collection of value arrays.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<Array<*>>} params.values - The input value arrrays.\n */\nfunction MultiValues(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator.call(this, null, update, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(MultiValues, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator);\nfunction update(_) {\n  return this.value && !_.modified() ? this.value : _.values.reduce((data, _) => data.concat(_), []);\n}\n\n/**\n * Operator whose value is simply its parameter hash. This operator is\n * useful for enabling reactive updates to values of nested objects.\n * @constructor\n * @param {object} params - The parameters for this operator.\n */\nfunction Params(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Params, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    this.modified(_.modified());\n    this.value = _;\n    return pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS); // do not pass tuples\n  }\n});\n\n/**\n * Aggregate and pivot selected field values to become new fields.\n * This operator is useful to construction cross-tabulations.\n * @constructor\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors\n *  to groupby. These fields act just like groupby fields of an Aggregate transform.\n * @param {function(object): *} params.field - The field to pivot on. The unique\n *  values of this field become new field names in the output stream.\n * @param {function(object): *} params.value - The field to populate pivoted fields.\n *  The aggregate values of this field become the values of the new pivoted fields.\n * @param {string} [params.op] - The aggregation operation for the value field,\n *  applied per cell in the output stream. The default is \"sum\".\n * @param {number} [params.limit] - An optional parameter indicating the maximum\n *  number of pivoted fields to generate. The pivoted field names are sorted in\n *  ascending order prior to enforcing the limit.\n */\nfunction Pivot(params) {\n  Aggregate.call(this, params);\n}\nPivot.Definition = {\n  'type': 'Pivot',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'value',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'op',\n    'type': 'enum',\n    'values': ValidAggregateOps,\n    'default': 'sum'\n  }, {\n    'name': 'limit',\n    'type': 'number',\n    'default': 0\n  }, {\n    'name': 'key',\n    'type': 'field'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Pivot, Aggregate, {\n  _transform: Aggregate.prototype.transform,\n  transform(_, pulse) {\n    return this._transform(aggregateParams(_, pulse), pulse);\n  }\n});\n\n// Shoehorn a pivot transform into an aggregate transform!\n// First collect all unique pivot field values.\n// Then generate aggregate fields for each output pivot field.\nfunction aggregateParams(_, pulse) {\n  const key = _.field,\n    value = _.value,\n    op = (_.op === 'count' ? '__count__' : _.op) || 'sum',\n    fields = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(key).concat((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(value)),\n    keys = pivotKeys(key, _.limit || 0, pulse);\n\n  // if data stream content changes, pivot fields may change\n  // flag parameter modification to ensure re-initialization\n  if (pulse.changed()) _.set('__pivot__', null, null, true);\n  return {\n    key: _.key,\n    groupby: _.groupby,\n    ops: keys.map(() => op),\n    fields: keys.map(k => get(k, key, value, fields)),\n    as: keys.map(k => k + ''),\n    modified: _.modified.bind(_)\n  };\n}\n\n// Generate aggregate field accessor.\n// Output NaN for non-existent values; aggregator will ignore!\nfunction get(k, key, value, fields) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor)(d => key(d) === k ? value(d) : NaN, fields, k + '');\n}\n\n// Collect (and optionally limit) all unique pivot values.\nfunction pivotKeys(key, limit, pulse) {\n  const map = {},\n    list = [];\n  pulse.visit(pulse.SOURCE, t => {\n    const k = key(t);\n    if (!map[k]) {\n      map[k] = 1;\n      list.push(k);\n    }\n  });\n  list.sort(vega_util__WEBPACK_IMPORTED_MODULE_0__.ascending);\n  return limit ? list.slice(0, limit) : list;\n}\n\n/**\n * Partitions pre-faceted data into tuple subflows.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(Dataflow, string): Operator} params.subflow - A function\n *   that generates a subflow of operators and returns its root operator.\n * @param {function(object): Array<object>} params.field - The field\n *   accessor for an array of subflow tuple objects.\n */\nfunction PreFacet(params) {\n  Facet.call(this, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(PreFacet, Facet, {\n  transform(_, pulse) {\n    const flow = _.subflow,\n      field = _.field,\n      subflow = t => this.subflow((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t), flow, pulse, t);\n    if (_.modified('field') || field && pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(field))) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('PreFacet does not support field modification.');\n    }\n    this.initTargets(); // reset list of active subflows\n\n    if (field) {\n      pulse.visit(pulse.MOD, t => {\n        const sf = subflow(t);\n        field(t).forEach(_ => sf.mod(_));\n      });\n      pulse.visit(pulse.ADD, t => {\n        const sf = subflow(t);\n        field(t).forEach(_ => sf.add((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(_)));\n      });\n      pulse.visit(pulse.REM, t => {\n        const sf = subflow(t);\n        field(t).forEach(_ => sf.rem(_));\n      });\n    } else {\n      pulse.visit(pulse.MOD, t => subflow(t).mod(t));\n      pulse.visit(pulse.ADD, t => subflow(t).add(t));\n      pulse.visit(pulse.REM, t => subflow(t).rem(t));\n    }\n    if (pulse.clean()) {\n      pulse.runAfter(() => this.clean());\n    }\n    return pulse;\n  }\n});\n\n/**\n * Performs a relational projection, copying selected fields from source\n * tuples to a new set of derived tuples.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {Array<function(object): *} params.fields - The fields to project,\n *   as an array of field accessors. If unspecified, all fields will be\n *   copied with names unchanged.\n * @param {Array<string>} [params.as] - Output field names for each projected\n *   field. Any unspecified fields will use the field name provided by\n *   the field accessor.\n */\nfunction Project(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nProject.Definition = {\n  'type': 'Project',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'fields',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'null': true,\n    'array': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Project, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE),\n      fields = _.fields,\n      as = fieldNames(_.fields, _.as || []),\n      derive = fields ? (s, t) => project(s, t, fields, as) : vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.rederive;\n    let lut;\n    if (this.value) {\n      lut = this.value;\n    } else {\n      pulse = pulse.addAll();\n      lut = this.value = {};\n    }\n    pulse.visit(pulse.REM, t => {\n      const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t);\n      out.rem.push(lut[id]);\n      lut[id] = null;\n    });\n    pulse.visit(pulse.ADD, t => {\n      const dt = derive(t, (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)({}));\n      lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)] = dt;\n      out.add.push(dt);\n    });\n    pulse.visit(pulse.MOD, t => {\n      out.mod.push(derive(t, lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)]));\n    });\n    return out;\n  }\n});\nfunction project(s, t, fields, as) {\n  for (let i = 0, n = fields.length; i < n; ++i) {\n    t[as[i]] = fields[i](s);\n  }\n  return t;\n}\n\n/**\n * Proxy the value of another operator as a pure signal value.\n * Ensures no tuples are propagated.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {*} params.value - The value to proxy, becomes the value of this operator.\n */\nfunction Proxy(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Proxy, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    this.value = _.value;\n    return _.modified('value') ? pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS) : pulse.StopPropagation;\n  }\n});\n\n/**\n * Generates sample quantile values from an input data stream.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - An accessor for the data field\n *   over which to calculate quantile values.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors\n *   to groupby.\n * @param {Array<number>} [params.probs] - An array of probabilities in\n *   the range (0, 1) for which to compute quantile values. If not specified,\n *   the *step* parameter will be used.\n * @param {Array<number>} [params.step=0.01] - A probability step size for\n *   sampling quantile values. All values from one-half the step size up to\n *   1 (exclusive) will be sampled. This parameter is only used if the\n *   *quantiles* parameter is not provided.\n */\nfunction Quantile(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nQuantile.Definition = {\n  'type': 'Quantile',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'probs',\n    'type': 'number',\n    'array': true\n  }, {\n    'name': 'step',\n    'type': 'number',\n    'default': 0.01\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'default': ['prob', 'value']\n  }]\n};\nconst EPSILON = 1e-14;\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Quantile, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS),\n      as = _.as || ['prob', 'value'];\n    if (this.value && !_.modified() && !pulse.changed()) {\n      out.source = this.value;\n      return out;\n    }\n    const source = pulse.materialize(pulse.SOURCE).source,\n      groups = partition$1(source, _.groupby, _.field),\n      names = (_.groupby || []).map(vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName),\n      values = [],\n      step = _.step || 0.01,\n      p = _.probs || (0,d3_array__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(step / 2, 1 - EPSILON, step),\n      n = p.length;\n    groups.forEach(g => {\n      const q = (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.quantiles)(g, p);\n      for (let i = 0; i < n; ++i) {\n        const t = {};\n        for (let i = 0; i < names.length; ++i) {\n          t[names[i]] = g.dims[i];\n        }\n        t[as[0]] = p[i];\n        t[as[1]] = q[i];\n        values.push((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t));\n      }\n    });\n    if (this.value) out.rem = this.value;\n    this.value = out.add = out.source = values;\n    return out;\n  }\n});\n\n/**\n * Relays a data stream between data processing pipelines.\n * If the derive parameter is set, this transform will create derived\n * copies of observed tuples. This provides derived data streams in which\n * modifications to the tuples do not pollute an upstream data source.\n * @param {object} params - The parameters for this operator.\n * @param {number} [params.derive=false] - Boolean flag indicating if\n *   the transform should make derived copies of incoming tuples.\n * @constructor\n */\nfunction Relay(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Relay, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    let out, lut;\n    if (this.value) {\n      lut = this.value;\n    } else {\n      out = pulse = pulse.addAll();\n      lut = this.value = {};\n    }\n    if (_.derive) {\n      out = pulse.fork(pulse.NO_SOURCE);\n      pulse.visit(pulse.REM, t => {\n        const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t);\n        out.rem.push(lut[id]);\n        lut[id] = null;\n      });\n      pulse.visit(pulse.ADD, t => {\n        const dt = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.derive)(t);\n        lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)] = dt;\n        out.add.push(dt);\n      });\n      pulse.visit(pulse.MOD, t => {\n        const dt = lut[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)];\n        for (const k in t) {\n          dt[k] = t[k];\n          // down stream writes may overwrite re-derived tuples\n          // conservatively mark all source fields as modified\n          out.modifies(k);\n        }\n        out.mod.push(dt);\n      });\n    }\n    return out;\n  }\n});\n\n/**\n * Samples tuples passing through this operator.\n * Uses reservoir sampling to maintain a representative sample.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {number} [params.size=1000] - The maximum number of samples.\n */\nfunction Sample(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, [], params);\n  this.count = 0;\n}\nSample.Definition = {\n  'type': 'Sample',\n  'metadata': {},\n  'params': [{\n    'name': 'size',\n    'type': 'number',\n    'default': 1000\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Sample, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const out = pulse.fork(pulse.NO_SOURCE),\n      mod = _.modified('size'),\n      num = _.size,\n      map = this.value.reduce((m, t) => (m[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)] = 1, m), {});\n    let res = this.value,\n      cnt = this.count,\n      cap = 0;\n\n    // sample reservoir update function\n    function update(t) {\n      let p, idx;\n      if (res.length < num) {\n        res.push(t);\n      } else {\n        idx = ~~((cnt + 1) * (0,vega_statistics__WEBPACK_IMPORTED_MODULE_2__.random)());\n        if (idx < res.length && idx >= cap) {\n          p = res[idx];\n          if (map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(p)]) out.rem.push(p); // eviction\n          res[idx] = t;\n        }\n      }\n      ++cnt;\n    }\n    if (pulse.rem.length) {\n      // find all tuples that should be removed, add to output\n      pulse.visit(pulse.REM, t => {\n        const id = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t);\n        if (map[id]) {\n          map[id] = -1;\n          out.rem.push(t);\n        }\n        --cnt;\n      });\n\n      // filter removed tuples out of the sample reservoir\n      res = res.filter(t => map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)] !== -1);\n    }\n    if ((pulse.rem.length || mod) && res.length < num && pulse.source) {\n      // replenish sample if backing data source is available\n      cap = cnt = res.length;\n      pulse.visit(pulse.SOURCE, t => {\n        // update, but skip previously sampled tuples\n        if (!map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)]) update(t);\n      });\n      cap = -1;\n    }\n    if (mod && res.length > num) {\n      const n = res.length - num;\n      for (let i = 0; i < n; ++i) {\n        map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(res[i])] = -1;\n        out.rem.push(res[i]);\n      }\n      res = res.slice(n);\n    }\n    if (pulse.mod.length) {\n      // propagate modified tuples in the sample reservoir\n      pulse.visit(pulse.MOD, t => {\n        if (map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)]) out.mod.push(t);\n      });\n    }\n    if (pulse.add.length) {\n      // update sample reservoir\n      pulse.visit(pulse.ADD, update);\n    }\n    if (pulse.add.length || cap < 0) {\n      // output newly added tuples\n      out.add = res.filter(t => !map[(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid)(t)]);\n    }\n    this.count = cnt;\n    this.value = out.source = res;\n    return out;\n  }\n});\n\n/**\n * Generates data tuples for a specified sequence range of numbers.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {number} params.start - The first number in the sequence.\n * @param {number} params.stop - The last number (exclusive) in the sequence.\n * @param {number} [params.step=1] - The step size between numbers in the sequence.\n */\nfunction Sequence(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nSequence.Definition = {\n  'type': 'Sequence',\n  'metadata': {\n    'generates': true,\n    'changes': true\n  },\n  'params': [{\n    'name': 'start',\n    'type': 'number',\n    'required': true\n  }, {\n    'name': 'stop',\n    'type': 'number',\n    'required': true\n  }, {\n    'name': 'step',\n    'type': 'number',\n    'default': 1\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'data'\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Sequence, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    if (this.value && !_.modified()) return;\n    const out = pulse.materialize().fork(pulse.MOD),\n      as = _.as || 'data';\n    out.rem = this.value ? pulse.rem.concat(this.value) : pulse.rem;\n    this.value = (0,d3_array__WEBPACK_IMPORTED_MODULE_8__[\"default\"])(_.start, _.stop, _.step || 1).map(v => {\n      const t = {};\n      t[as] = v;\n      return (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest)(t);\n    });\n    out.add = pulse.add.concat(this.value);\n    return out;\n  }\n});\n\n/**\n * Propagates a new pulse without any tuples so long as the input\n * pulse contains some added, removed or modified tuples.\n * @param {object} params - The parameters for this operator.\n * @constructor\n */\nfunction Sieve(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n  this.modified(true); // always treat as modified\n}\n\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Sieve, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    this.value = pulse.source;\n    return pulse.changed() ? pulse.fork(pulse.NO_SOURCE | pulse.NO_FIELDS) : pulse.StopPropagation;\n  }\n});\n\n/**\n * Discretize dates to specific time units.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The data field containing date/time values.\n */\nfunction TimeUnit(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\nconst OUTPUT = ['unit0', 'unit1'];\nTimeUnit.Definition = {\n  'type': 'TimeUnit',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'field',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'interval',\n    'type': 'boolean',\n    'default': true\n  }, {\n    'name': 'units',\n    'type': 'enum',\n    'values': vega_time__WEBPACK_IMPORTED_MODULE_3__.TIME_UNITS,\n    'array': true\n  }, {\n    'name': 'step',\n    'type': 'number',\n    'default': 1\n  }, {\n    'name': 'maxbins',\n    'type': 'number',\n    'default': 40\n  }, {\n    'name': 'extent',\n    'type': 'date',\n    'array': true\n  }, {\n    'name': 'timezone',\n    'type': 'enum',\n    'default': 'local',\n    'values': ['local', 'utc']\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 2,\n    'default': OUTPUT\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(TimeUnit, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const field = _.field,\n      band = _.interval !== false,\n      utc = _.timezone === 'utc',\n      floor = this._floor(_, pulse),\n      offset = (utc ? vega_time__WEBPACK_IMPORTED_MODULE_3__.utcInterval : vega_time__WEBPACK_IMPORTED_MODULE_3__.timeInterval)(floor.unit).offset,\n      as = _.as || OUTPUT,\n      u0 = as[0],\n      u1 = as[1],\n      step = floor.step;\n    let min = floor.start || Infinity,\n      max = floor.stop || -Infinity,\n      flag = pulse.ADD;\n    if (_.modified() || pulse.changed(pulse.REM) || pulse.modified((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(field))) {\n      pulse = pulse.reflow(true);\n      flag = pulse.SOURCE;\n      min = Infinity;\n      max = -Infinity;\n    }\n    pulse.visit(flag, t => {\n      const v = field(t);\n      let a, b;\n      if (v == null) {\n        t[u0] = null;\n        if (band) t[u1] = null;\n      } else {\n        t[u0] = a = b = floor(v);\n        if (band) t[u1] = b = offset(a, step);\n        if (a < min) min = a;\n        if (b > max) max = b;\n      }\n    });\n    floor.start = min;\n    floor.stop = max;\n    return pulse.modifies(band ? as : u0);\n  },\n  _floor(_, pulse) {\n    const utc = _.timezone === 'utc';\n\n    // get parameters\n    const {\n      units,\n      step\n    } = _.units ? {\n      units: _.units,\n      step: _.step || 1\n    } : (0,vega_time__WEBPACK_IMPORTED_MODULE_3__.timeBin)({\n      extent: _.extent || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extent)(pulse.materialize(pulse.SOURCE).source, _.field),\n      maxbins: _.maxbins\n    });\n\n    // check / standardize time units\n    const tunits = (0,vega_time__WEBPACK_IMPORTED_MODULE_3__.timeUnits)(units),\n      prev = this.value || {},\n      floor = (utc ? vega_time__WEBPACK_IMPORTED_MODULE_3__.utcFloor : vega_time__WEBPACK_IMPORTED_MODULE_3__.timeFloor)(tunits, step);\n    floor.unit = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.peek)(tunits);\n    floor.units = tunits;\n    floor.step = step;\n    floor.start = prev.start;\n    floor.stop = prev.stop;\n    return this.value = floor;\n  }\n});\n\n/**\n * An index that maps from unique, string-coerced, field values to tuples.\n * Assumes that the field serves as a unique key with no duplicate values.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The field accessor to index.\n */\nfunction TupleIndex(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.fastmap)(), params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(TupleIndex, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const df = pulse.dataflow,\n      field = _.field,\n      index = this.value,\n      set = t => index.set(field(t), t);\n    let mod = true;\n    if (_.modified('field') || pulse.modified(field.fields)) {\n      index.clear();\n      pulse.visit(pulse.SOURCE, set);\n    } else if (pulse.changed()) {\n      pulse.visit(pulse.REM, t => index.delete(field(t)));\n      pulse.visit(pulse.ADD, set);\n    } else {\n      mod = false;\n    }\n    this.modified(mod);\n    if (index.empty > df.cleanThreshold) df.runAfter(index.clean);\n    return pulse.fork();\n  }\n});\n\n/**\n * Extracts an array of values. Assumes the source data has already been\n * reduced as needed (e.g., by an upstream Aggregate transform).\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(object): *} params.field - The domain field to extract.\n * @param {function(*,*): number} [params.sort] - An optional\n *   comparator function for sorting the values. The comparator will be\n *   applied to backing tuples prior to value extraction.\n */\nfunction Values(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Values, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    const run = !this.value || _.modified('field') || _.modified('sort') || pulse.changed() || _.sort && pulse.modified(_.sort.fields);\n    if (run) {\n      this.value = (_.sort ? pulse.source.slice().sort((0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.stableCompare)(_.sort)) : pulse.source).map(_.field);\n    }\n  }\n});\n\nfunction WindowOp(op, field, param, as) {\n  const fn = WindowOps[op](field, param);\n  return {\n    init: fn.init || vega_util__WEBPACK_IMPORTED_MODULE_0__.zero,\n    update: function (w, t) {\n      t[as] = fn.next(w);\n    }\n  };\n}\nconst WindowOps = {\n  row_number: function () {\n    return {\n      next: w => w.index + 1\n    };\n  },\n  rank: function () {\n    let rank;\n    return {\n      init: () => rank = 1,\n      next: w => {\n        const i = w.index,\n          data = w.data;\n        return i && w.compare(data[i - 1], data[i]) ? rank = i + 1 : rank;\n      }\n    };\n  },\n  dense_rank: function () {\n    let drank;\n    return {\n      init: () => drank = 1,\n      next: w => {\n        const i = w.index,\n          d = w.data;\n        return i && w.compare(d[i - 1], d[i]) ? ++drank : drank;\n      }\n    };\n  },\n  percent_rank: function () {\n    const rank = WindowOps.rank(),\n      next = rank.next;\n    return {\n      init: rank.init,\n      next: w => (next(w) - 1) / (w.data.length - 1)\n    };\n  },\n  cume_dist: function () {\n    let cume;\n    return {\n      init: () => cume = 0,\n      next: w => {\n        const d = w.data,\n          c = w.compare;\n        let i = w.index;\n        if (cume < i) {\n          while (i + 1 < d.length && !c(d[i], d[i + 1])) ++i;\n          cume = i;\n        }\n        return (1 + cume) / d.length;\n      }\n    };\n  },\n  ntile: function (field, num) {\n    num = +num;\n    if (!(num > 0)) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('ntile num must be greater than zero.');\n    const cume = WindowOps.cume_dist(),\n      next = cume.next;\n    return {\n      init: cume.init,\n      next: w => Math.ceil(num * next(w))\n    };\n  },\n  lag: function (field, offset) {\n    offset = +offset || 1;\n    return {\n      next: w => {\n        const i = w.index - offset;\n        return i >= 0 ? field(w.data[i]) : null;\n      }\n    };\n  },\n  lead: function (field, offset) {\n    offset = +offset || 1;\n    return {\n      next: w => {\n        const i = w.index + offset,\n          d = w.data;\n        return i < d.length ? field(d[i]) : null;\n      }\n    };\n  },\n  first_value: function (field) {\n    return {\n      next: w => field(w.data[w.i0])\n    };\n  },\n  last_value: function (field) {\n    return {\n      next: w => field(w.data[w.i1 - 1])\n    };\n  },\n  nth_value: function (field, nth) {\n    nth = +nth;\n    if (!(nth > 0)) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('nth_value nth must be greater than zero.');\n    return {\n      next: w => {\n        const i = w.i0 + (nth - 1);\n        return i < w.i1 ? field(w.data[i]) : null;\n      }\n    };\n  },\n  prev_value: function (field) {\n    let prev;\n    return {\n      init: () => prev = null,\n      next: w => {\n        const v = field(w.data[w.index]);\n        return v != null ? prev = v : prev;\n      }\n    };\n  },\n  next_value: function (field) {\n    let v, i;\n    return {\n      init: () => (v = null, i = -1),\n      next: w => {\n        const d = w.data;\n        return w.index <= i ? v : (i = find(field, d, w.index)) < 0 ? (i = d.length, v = null) : v = field(d[i]);\n      }\n    };\n  }\n};\nfunction find(field, data, index) {\n  for (let n = data.length; index < n; ++index) {\n    const v = field(data[index]);\n    if (v != null) return index;\n  }\n  return -1;\n}\nconst ValidWindowOps = Object.keys(WindowOps);\n\nfunction WindowState(_) {\n  const ops = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.ops),\n    fields = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.fields),\n    params = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.params),\n    as = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(_.as),\n    outputs = this.outputs = [],\n    windows = this.windows = [],\n    inputs = {},\n    map = {},\n    counts = [],\n    measures = [];\n  let countOnly = true;\n  function visitInputs(f) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields)(f)).forEach(_ => inputs[_] = 1);\n  }\n  visitInputs(_.sort);\n  ops.forEach((op, i) => {\n    const field = fields[i],\n      mname = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName)(field),\n      name = measureName(op, mname, as[i]);\n    visitInputs(field);\n    outputs.push(name);\n\n    // Window operation\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(WindowOps, op)) {\n      windows.push(WindowOp(op, fields[i], params[i], name));\n    }\n\n    // Aggregate operation\n    else {\n      if (field == null && op !== 'count') {\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Null aggregate field specified.');\n      }\n      if (op === 'count') {\n        counts.push(name);\n        return;\n      }\n      countOnly = false;\n      let m = map[mname];\n      if (!m) {\n        m = map[mname] = [];\n        m.field = field;\n        measures.push(m);\n      }\n      m.push(createMeasure(op, name));\n    }\n  });\n  if (counts.length || measures.length) {\n    this.cell = cell(measures, counts, countOnly);\n  }\n  this.inputs = Object.keys(inputs);\n}\nconst prototype = WindowState.prototype;\nprototype.init = function () {\n  this.windows.forEach(_ => _.init());\n  if (this.cell) this.cell.init();\n};\nprototype.update = function (w, t) {\n  const cell = this.cell,\n    wind = this.windows,\n    data = w.data,\n    m = wind && wind.length;\n  let j;\n  if (cell) {\n    for (j = w.p0; j < w.i0; ++j) cell.rem(data[j]);\n    for (j = w.p1; j < w.i1; ++j) cell.add(data[j]);\n    cell.set(t);\n  }\n  for (j = 0; j < m; ++j) wind[j].update(w, t);\n};\nfunction cell(measures, counts, countOnly) {\n  measures = measures.map(m => compileMeasures(m, m.field));\n  const cell = {\n    num: 0,\n    agg: null,\n    store: false,\n    count: counts\n  };\n  if (!countOnly) {\n    var n = measures.length,\n      a = cell.agg = Array(n),\n      i = 0;\n    for (; i < n; ++i) a[i] = new measures[i](cell);\n  }\n  if (cell.store) {\n    var store = cell.data = new TupleStore();\n  }\n  cell.add = function (t) {\n    cell.num += 1;\n    if (countOnly) return;\n    if (store) store.add(t);\n    for (let i = 0; i < n; ++i) {\n      a[i].add(a[i].get(t), t);\n    }\n  };\n  cell.rem = function (t) {\n    cell.num -= 1;\n    if (countOnly) return;\n    if (store) store.rem(t);\n    for (let i = 0; i < n; ++i) {\n      a[i].rem(a[i].get(t), t);\n    }\n  };\n  cell.set = function (t) {\n    let i, n;\n\n    // consolidate stored values\n    if (store) store.values();\n\n    // update tuple properties\n    for (i = 0, n = counts.length; i < n; ++i) t[counts[i]] = cell.num;\n    if (!countOnly) for (i = 0, n = a.length; i < n; ++i) a[i].set(t);\n  };\n  cell.init = function () {\n    cell.num = 0;\n    if (store) store.reset();\n    for (let i = 0; i < n; ++i) a[i].init();\n  };\n  return cell;\n}\n\n/**\n * Perform window calculations and write results to the input stream.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {function(*,*): number} [params.sort] - A comparator function for sorting tuples within a window.\n * @param {Array<function(object): *>} [params.groupby] - An array of accessors by which to partition tuples into separate windows.\n * @param {Array<string>} params.ops - An array of strings indicating window operations to perform.\n * @param {Array<function(object): *>} [params.fields] - An array of accessors\n *   for data fields to use as inputs to window operations.\n * @param {Array<*>} [params.params] - An array of parameter values for window operations.\n * @param {Array<string>} [params.as] - An array of output field names for window operations.\n * @param {Array<number>} [params.frame] - Window frame definition as two-element array.\n * @param {boolean} [params.ignorePeers=false] - If true, base window frame boundaries on row\n *   number alone, ignoring peers with identical sort values. If false (default),\n *   the window boundaries will be adjusted to include peer values.\n */\nfunction Window(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, {}, params);\n  this._mlen = 0;\n  this._mods = [];\n}\nWindow.Definition = {\n  'type': 'Window',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'sort',\n    'type': 'compare'\n  }, {\n    'name': 'groupby',\n    'type': 'field',\n    'array': true\n  }, {\n    'name': 'ops',\n    'type': 'enum',\n    'array': true,\n    'values': ValidWindowOps.concat(ValidAggregateOps)\n  }, {\n    'name': 'params',\n    'type': 'number',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'fields',\n    'type': 'field',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'null': true,\n    'array': true\n  }, {\n    'name': 'frame',\n    'type': 'number',\n    'null': true,\n    'array': true,\n    'length': 2,\n    'default': [null, 0]\n  }, {\n    'name': 'ignorePeers',\n    'type': 'boolean',\n    'default': false\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(Window, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    this.stamp = pulse.stamp;\n    const mod = _.modified(),\n      cmp = (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.stableCompare)(_.sort),\n      key = groupkey(_.groupby),\n      group = t => this.group(key(t));\n\n    // initialize window state\n    let state = this.state;\n    if (!state || mod) {\n      state = this.state = new WindowState(_);\n    }\n\n    // partition input tuples\n    if (mod || pulse.modified(state.inputs)) {\n      this.value = {};\n      pulse.visit(pulse.SOURCE, t => group(t).add(t));\n    } else {\n      pulse.visit(pulse.REM, t => group(t).remove(t));\n      pulse.visit(pulse.ADD, t => group(t).add(t));\n    }\n\n    // perform window calculations for each modified partition\n    for (let i = 0, n = this._mlen; i < n; ++i) {\n      processPartition(this._mods[i], state, cmp, _);\n    }\n    this._mlen = 0;\n    this._mods = [];\n\n    // TODO don't reflow everything?\n    return pulse.reflow(mod).modifies(state.outputs);\n  },\n  group(key) {\n    let group = this.value[key];\n    if (!group) {\n      group = this.value[key] = SortedList(vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid);\n      group.stamp = -1;\n    }\n    if (group.stamp < this.stamp) {\n      group.stamp = this.stamp;\n      this._mods[this._mlen++] = group;\n    }\n    return group;\n  }\n});\nfunction processPartition(list, state, cmp, _) {\n  const sort = _.sort,\n    range = sort && !_.ignorePeers,\n    frame = _.frame || [null, 0],\n    data = list.data(cmp),\n    // use cmp for stable sort\n    n = data.length,\n    b = range ? (0,d3_array__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(sort) : null,\n    w = {\n      i0: 0,\n      i1: 0,\n      p0: 0,\n      p1: 0,\n      index: 0,\n      data: data,\n      compare: sort || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(-1)\n    };\n  state.init();\n  for (let i = 0; i < n; ++i) {\n    setWindow(w, frame, i, n);\n    if (range) adjustRange(w, b);\n    state.update(w, data[i]);\n  }\n}\nfunction setWindow(w, f, i, n) {\n  w.p0 = w.i0;\n  w.p1 = w.i1;\n  w.i0 = f[0] == null ? 0 : Math.max(0, i - Math.abs(f[0]));\n  w.i1 = f[1] == null ? n : Math.min(n, i + Math.abs(f[1]) + 1);\n  w.index = i;\n}\n\n// if frame type is 'range', adjust window for peer values\nfunction adjustRange(w, bisect) {\n  const r0 = w.i0,\n    r1 = w.i1 - 1,\n    c = w.compare,\n    d = w.data,\n    n = d.length - 1;\n  if (r0 > 0 && !c(d[r0], d[r0 - 1])) w.i0 = bisect.left(d, d[r0]);\n  if (r1 < n && !c(d[r1], d[r1 + 1])) w.i1 = bisect.right(d, d[r1]);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-transforms/build/vega-transforms.module.js?");

/***/ }),

/***/ "../../node_modules/vega-util/build/vega-util.module.js":
/*!**************************************************************!*\
  !*** ../../node_modules/vega-util/build/vega-util.module.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Debug: () => (/* binding */ Debug),\n/* harmony export */   Error: () => (/* binding */ Error$1),\n/* harmony export */   Info: () => (/* binding */ Info),\n/* harmony export */   None: () => (/* binding */ None),\n/* harmony export */   Warn: () => (/* binding */ Warn),\n/* harmony export */   accessor: () => (/* binding */ accessor),\n/* harmony export */   accessorFields: () => (/* binding */ accessorFields),\n/* harmony export */   accessorName: () => (/* binding */ accessorName),\n/* harmony export */   array: () => (/* binding */ array),\n/* harmony export */   ascending: () => (/* binding */ ascending),\n/* harmony export */   clampRange: () => (/* binding */ clampRange),\n/* harmony export */   compare: () => (/* binding */ compare),\n/* harmony export */   constant: () => (/* binding */ constant),\n/* harmony export */   debounce: () => (/* binding */ debounce),\n/* harmony export */   error: () => (/* binding */ error),\n/* harmony export */   extend: () => (/* binding */ extend),\n/* harmony export */   extent: () => (/* binding */ extent),\n/* harmony export */   extentIndex: () => (/* binding */ extentIndex),\n/* harmony export */   falsy: () => (/* binding */ falsy),\n/* harmony export */   fastmap: () => (/* binding */ fastmap),\n/* harmony export */   field: () => (/* binding */ field),\n/* harmony export */   flush: () => (/* binding */ flush),\n/* harmony export */   hasOwnProperty: () => (/* binding */ has),\n/* harmony export */   id: () => (/* binding */ id),\n/* harmony export */   identity: () => (/* binding */ identity),\n/* harmony export */   inherits: () => (/* binding */ inherits),\n/* harmony export */   inrange: () => (/* binding */ inrange),\n/* harmony export */   isArray: () => (/* binding */ isArray),\n/* harmony export */   isBoolean: () => (/* binding */ isBoolean),\n/* harmony export */   isDate: () => (/* binding */ isDate),\n/* harmony export */   isFunction: () => (/* binding */ isFunction),\n/* harmony export */   isIterable: () => (/* binding */ isIterable),\n/* harmony export */   isNumber: () => (/* binding */ isNumber),\n/* harmony export */   isObject: () => (/* binding */ isObject),\n/* harmony export */   isRegExp: () => (/* binding */ isRegExp),\n/* harmony export */   isString: () => (/* binding */ isString),\n/* harmony export */   key: () => (/* binding */ key),\n/* harmony export */   lerp: () => (/* binding */ lerp),\n/* harmony export */   logger: () => (/* binding */ logger),\n/* harmony export */   lruCache: () => (/* binding */ lruCache),\n/* harmony export */   merge: () => (/* binding */ merge),\n/* harmony export */   mergeConfig: () => (/* binding */ mergeConfig),\n/* harmony export */   one: () => (/* binding */ one),\n/* harmony export */   pad: () => (/* binding */ pad),\n/* harmony export */   panLinear: () => (/* binding */ panLinear),\n/* harmony export */   panLog: () => (/* binding */ panLog),\n/* harmony export */   panPow: () => (/* binding */ panPow),\n/* harmony export */   panSymlog: () => (/* binding */ panSymlog),\n/* harmony export */   peek: () => (/* binding */ peek),\n/* harmony export */   quarter: () => (/* binding */ quarter),\n/* harmony export */   repeat: () => (/* binding */ repeat),\n/* harmony export */   span: () => (/* binding */ span),\n/* harmony export */   splitAccessPath: () => (/* binding */ splitAccessPath),\n/* harmony export */   stringValue: () => (/* binding */ $),\n/* harmony export */   toBoolean: () => (/* binding */ toBoolean),\n/* harmony export */   toDate: () => (/* binding */ toDate),\n/* harmony export */   toNumber: () => (/* binding */ toNumber),\n/* harmony export */   toSet: () => (/* binding */ toSet),\n/* harmony export */   toString: () => (/* binding */ toString),\n/* harmony export */   truncate: () => (/* binding */ truncate),\n/* harmony export */   truthy: () => (/* binding */ truthy),\n/* harmony export */   utcquarter: () => (/* binding */ utcquarter),\n/* harmony export */   visitArray: () => (/* binding */ visitArray),\n/* harmony export */   writeConfig: () => (/* binding */ writeConfig),\n/* harmony export */   zero: () => (/* binding */ zero),\n/* harmony export */   zoomLinear: () => (/* binding */ zoomLinear),\n/* harmony export */   zoomLog: () => (/* binding */ zoomLog),\n/* harmony export */   zoomPow: () => (/* binding */ zoomPow),\n/* harmony export */   zoomSymlog: () => (/* binding */ zoomSymlog)\n/* harmony export */ });\nfunction accessor (fn, fields, name) {\n  fn.fields = fields || [];\n  fn.fname = name;\n  return fn;\n}\nfunction accessorName(fn) {\n  return fn == null ? null : fn.fname;\n}\nfunction accessorFields(fn) {\n  return fn == null ? null : fn.fields;\n}\n\nfunction getter (path) {\n  return path.length === 1 ? get1(path[0]) : getN(path);\n}\nconst get1 = field => function (obj) {\n  return obj[field];\n};\nconst getN = path => {\n  const len = path.length;\n  return function (obj) {\n    for (let i = 0; i < len; ++i) {\n      obj = obj[path[i]];\n    }\n    return obj;\n  };\n};\n\nfunction error (message) {\n  throw Error(message);\n}\n\nfunction splitAccessPath (p) {\n  const path = [],\n    n = p.length;\n  let q = null,\n    b = 0,\n    s = '',\n    i,\n    j,\n    c;\n  p = p + '';\n  function push() {\n    path.push(s + p.substring(i, j));\n    s = '';\n    i = j + 1;\n  }\n  for (i = j = 0; j < n; ++j) {\n    c = p[j];\n    if (c === '\\\\') {\n      s += p.substring(i, j++);\n      i = j;\n    } else if (c === q) {\n      push();\n      q = null;\n      b = -1;\n    } else if (q) {\n      continue;\n    } else if (i === b && c === '\"') {\n      i = j + 1;\n      q = c;\n    } else if (i === b && c === \"'\") {\n      i = j + 1;\n      q = c;\n    } else if (c === '.' && !b) {\n      if (j > i) {\n        push();\n      } else {\n        i = j + 1;\n      }\n    } else if (c === '[') {\n      if (j > i) push();\n      b = i = j + 1;\n    } else if (c === ']') {\n      if (!b) error('Access path missing open bracket: ' + p);\n      if (b > 0) push();\n      b = 0;\n      i = j + 1;\n    }\n  }\n  if (b) error('Access path missing closing bracket: ' + p);\n  if (q) error('Access path missing closing quote: ' + p);\n  if (j > i) {\n    j++;\n    push();\n  }\n  return path;\n}\n\nfunction field (field, name, opt) {\n  const path = splitAccessPath(field);\n  field = path.length === 1 ? path[0] : field;\n  return accessor((opt && opt.get || getter)(path), [field], name || field);\n}\n\nconst id = field('id');\nconst identity = accessor(_ => _, [], 'identity');\nconst zero = accessor(() => 0, [], 'zero');\nconst one = accessor(() => 1, [], 'one');\nconst truthy = accessor(() => true, [], 'true');\nconst falsy = accessor(() => false, [], 'false');\n\nfunction log$1(method, level, input) {\n  const args = [level].concat([].slice.call(input));\n  console[method].apply(console, args); // eslint-disable-line no-console\n}\n\nconst None = 0;\nconst Error$1 = 1;\nconst Warn = 2;\nconst Info = 3;\nconst Debug = 4;\nfunction logger (_, method) {\n  let handler = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : log$1;\n  let level = _ || None;\n  return {\n    level(_) {\n      if (arguments.length) {\n        level = +_;\n        return this;\n      } else {\n        return level;\n      }\n    },\n    error() {\n      if (level >= Error$1) handler(method || 'error', 'ERROR', arguments);\n      return this;\n    },\n    warn() {\n      if (level >= Warn) handler(method || 'warn', 'WARN', arguments);\n      return this;\n    },\n    info() {\n      if (level >= Info) handler(method || 'log', 'INFO', arguments);\n      return this;\n    },\n    debug() {\n      if (level >= Debug) handler(method || 'log', 'DEBUG', arguments);\n      return this;\n    }\n  };\n}\n\nvar isArray = Array.isArray;\n\nfunction isObject (_) {\n  return _ === Object(_);\n}\n\nconst isLegalKey = key => key !== '__proto__';\nfunction mergeConfig() {\n  for (var _len = arguments.length, configs = new Array(_len), _key = 0; _key < _len; _key++) {\n    configs[_key] = arguments[_key];\n  }\n  return configs.reduce((out, source) => {\n    for (const key in source) {\n      if (key === 'signals') {\n        // for signals, we merge the signals arrays\n        // source signals take precedence over\n        // existing signals with the same name\n        out.signals = mergeNamed(out.signals, source.signals);\n      } else {\n        // otherwise, merge objects subject to recursion constraints\n        // for legend block, recurse for the layout entry only\n        // for style block, recurse for all properties\n        // otherwise, no recursion: objects overwrite, no merging\n        const r = key === 'legend' ? {\n          layout: 1\n        } : key === 'style' ? true : null;\n        writeConfig(out, key, source[key], r);\n      }\n    }\n    return out;\n  }, {});\n}\nfunction writeConfig(output, key, value, recurse) {\n  if (!isLegalKey(key)) return;\n  let k, o;\n  if (isObject(value) && !isArray(value)) {\n    o = isObject(output[key]) ? output[key] : output[key] = {};\n    for (k in value) {\n      if (recurse && (recurse === true || recurse[k])) {\n        writeConfig(o, k, value[k]);\n      } else if (isLegalKey(k)) {\n        o[k] = value[k];\n      }\n    }\n  } else {\n    output[key] = value;\n  }\n}\nfunction mergeNamed(a, b) {\n  if (a == null) return b;\n  const map = {},\n    out = [];\n  function add(_) {\n    if (!map[_.name]) {\n      map[_.name] = 1;\n      out.push(_);\n    }\n  }\n  b.forEach(add);\n  a.forEach(add);\n  return out;\n}\n\nfunction peek (array) {\n  return array[array.length - 1];\n}\n\nfunction toNumber (_) {\n  return _ == null || _ === '' ? null : +_;\n}\n\nconst exp = sign => x => sign * Math.exp(x);\nconst log = sign => x => Math.log(sign * x);\nconst symlog = c => x => Math.sign(x) * Math.log1p(Math.abs(x / c));\nconst symexp = c => x => Math.sign(x) * Math.expm1(Math.abs(x)) * c;\nconst pow = exponent => x => x < 0 ? -Math.pow(-x, exponent) : Math.pow(x, exponent);\nfunction pan(domain, delta, lift, ground) {\n  const d0 = lift(domain[0]),\n    d1 = lift(peek(domain)),\n    dd = (d1 - d0) * delta;\n  return [ground(d0 - dd), ground(d1 - dd)];\n}\nfunction panLinear(domain, delta) {\n  return pan(domain, delta, toNumber, identity);\n}\nfunction panLog(domain, delta) {\n  var sign = Math.sign(domain[0]);\n  return pan(domain, delta, log(sign), exp(sign));\n}\nfunction panPow(domain, delta, exponent) {\n  return pan(domain, delta, pow(exponent), pow(1 / exponent));\n}\nfunction panSymlog(domain, delta, constant) {\n  return pan(domain, delta, symlog(constant), symexp(constant));\n}\nfunction zoom(domain, anchor, scale, lift, ground) {\n  const d0 = lift(domain[0]),\n    d1 = lift(peek(domain)),\n    da = anchor != null ? lift(anchor) : (d0 + d1) / 2;\n  return [ground(da + (d0 - da) * scale), ground(da + (d1 - da) * scale)];\n}\nfunction zoomLinear(domain, anchor, scale) {\n  return zoom(domain, anchor, scale, toNumber, identity);\n}\nfunction zoomLog(domain, anchor, scale) {\n  const sign = Math.sign(domain[0]);\n  return zoom(domain, anchor, scale, log(sign), exp(sign));\n}\nfunction zoomPow(domain, anchor, scale, exponent) {\n  return zoom(domain, anchor, scale, pow(exponent), pow(1 / exponent));\n}\nfunction zoomSymlog(domain, anchor, scale, constant) {\n  return zoom(domain, anchor, scale, symlog(constant), symexp(constant));\n}\n\nfunction quarter(date) {\n  return 1 + ~~(new Date(date).getMonth() / 3);\n}\nfunction utcquarter(date) {\n  return 1 + ~~(new Date(date).getUTCMonth() / 3);\n}\n\nfunction array (_) {\n  return _ != null ? isArray(_) ? _ : [_] : [];\n}\n\n/**\n * Span-preserving range clamp. If the span of the input range is less\n * than (max - min) and an endpoint exceeds either the min or max value,\n * the range is translated such that the span is preserved and one\n * endpoint touches the boundary of the min/max range.\n * If the span exceeds (max - min), the range [min, max] is returned.\n */\nfunction clampRange (range, min, max) {\n  let lo = range[0],\n    hi = range[1],\n    span;\n  if (hi < lo) {\n    span = hi;\n    hi = lo;\n    lo = span;\n  }\n  span = hi - lo;\n  return span >= max - min ? [min, max] : [lo = Math.min(Math.max(lo, min), max - span), lo + span];\n}\n\nfunction isFunction (_) {\n  return typeof _ === 'function';\n}\n\nconst DESCENDING = 'descending';\nfunction compare (fields, orders, opt) {\n  opt = opt || {};\n  orders = array(orders) || [];\n  const ord = [],\n    get = [],\n    fmap = {},\n    gen = opt.comparator || comparator;\n  array(fields).forEach((f, i) => {\n    if (f == null) return;\n    ord.push(orders[i] === DESCENDING ? -1 : 1);\n    get.push(f = isFunction(f) ? f : field(f, null, opt));\n    (accessorFields(f) || []).forEach(_ => fmap[_] = 1);\n  });\n  return get.length === 0 ? null : accessor(gen(get, ord), Object.keys(fmap));\n}\nconst ascending = (u, v) => (u < v || u == null) && v != null ? -1 : (u > v || v == null) && u != null ? 1 : (v = v instanceof Date ? +v : v, u = u instanceof Date ? +u : u) !== u && v === v ? -1 : v !== v && u === u ? 1 : 0;\nconst comparator = (fields, orders) => fields.length === 1 ? compare1(fields[0], orders[0]) : compareN(fields, orders, fields.length);\nconst compare1 = (field, order) => function (a, b) {\n  return ascending(field(a), field(b)) * order;\n};\nconst compareN = (fields, orders, n) => {\n  orders.push(0); // pad zero for convenient lookup\n  return function (a, b) {\n    let f,\n      c = 0,\n      i = -1;\n    while (c === 0 && ++i < n) {\n      f = fields[i];\n      c = ascending(f(a), f(b));\n    }\n    return c * orders[i];\n  };\n};\n\nfunction constant (_) {\n  return isFunction(_) ? _ : () => _;\n}\n\nfunction debounce (delay, handler) {\n  let tid;\n  return e => {\n    if (tid) clearTimeout(tid);\n    tid = setTimeout(() => (handler(e), tid = null), delay);\n  };\n}\n\nfunction extend (_) {\n  for (let x, k, i = 1, len = arguments.length; i < len; ++i) {\n    x = arguments[i];\n    for (k in x) {\n      _[k] = x[k];\n    }\n  }\n  return _;\n}\n\n/**\n * Return an array with minimum and maximum values, in the\n * form [min, max]. Ignores null, undefined, and NaN values.\n */\nfunction extent (array, f) {\n  let i = 0,\n    n,\n    v,\n    min,\n    max;\n  if (array && (n = array.length)) {\n    if (f == null) {\n      // find first valid value\n      for (v = array[i]; i < n && (v == null || v !== v); v = array[++i]);\n      min = max = v;\n\n      // visit all other values\n      for (; i < n; ++i) {\n        v = array[i];\n        // skip null/undefined; NaN will fail all comparisons\n        if (v != null) {\n          if (v < min) min = v;\n          if (v > max) max = v;\n        }\n      }\n    } else {\n      // find first valid value\n      for (v = f(array[i]); i < n && (v == null || v !== v); v = f(array[++i]));\n      min = max = v;\n\n      // visit all other values\n      for (; i < n; ++i) {\n        v = f(array[i]);\n        // skip null/undefined; NaN will fail all comparisons\n        if (v != null) {\n          if (v < min) min = v;\n          if (v > max) max = v;\n        }\n      }\n    }\n  }\n  return [min, max];\n}\n\nfunction extentIndex (array, f) {\n  const n = array.length;\n  let i = -1,\n    a,\n    b,\n    c,\n    u,\n    v;\n  if (f == null) {\n    while (++i < n) {\n      b = array[i];\n      if (b != null && b >= b) {\n        a = c = b;\n        break;\n      }\n    }\n    if (i === n) return [-1, -1];\n    u = v = i;\n    while (++i < n) {\n      b = array[i];\n      if (b != null) {\n        if (a > b) {\n          a = b;\n          u = i;\n        }\n        if (c < b) {\n          c = b;\n          v = i;\n        }\n      }\n    }\n  } else {\n    while (++i < n) {\n      b = f(array[i], i, array);\n      if (b != null && b >= b) {\n        a = c = b;\n        break;\n      }\n    }\n    if (i === n) return [-1, -1];\n    u = v = i;\n    while (++i < n) {\n      b = f(array[i], i, array);\n      if (b != null) {\n        if (a > b) {\n          a = b;\n          u = i;\n        }\n        if (c < b) {\n          c = b;\n          v = i;\n        }\n      }\n    }\n  }\n  return [u, v];\n}\n\nconst hop = Object.prototype.hasOwnProperty;\nfunction has (object, property) {\n  return hop.call(object, property);\n}\n\nconst NULL = {};\nfunction fastmap (input) {\n  let obj = {},\n    test;\n  function has$1(key) {\n    return has(obj, key) && obj[key] !== NULL;\n  }\n  const map = {\n    size: 0,\n    empty: 0,\n    object: obj,\n    has: has$1,\n    get(key) {\n      return has$1(key) ? obj[key] : undefined;\n    },\n    set(key, value) {\n      if (!has$1(key)) {\n        ++map.size;\n        if (obj[key] === NULL) --map.empty;\n      }\n      obj[key] = value;\n      return this;\n    },\n    delete(key) {\n      if (has$1(key)) {\n        --map.size;\n        ++map.empty;\n        obj[key] = NULL;\n      }\n      return this;\n    },\n    clear() {\n      map.size = map.empty = 0;\n      map.object = obj = {};\n    },\n    test(_) {\n      if (arguments.length) {\n        test = _;\n        return map;\n      } else {\n        return test;\n      }\n    },\n    clean() {\n      const next = {};\n      let size = 0;\n      for (const key in obj) {\n        const value = obj[key];\n        if (value !== NULL && (!test || !test(value))) {\n          next[key] = value;\n          ++size;\n        }\n      }\n      map.size = size;\n      map.empty = 0;\n      map.object = obj = next;\n    }\n  };\n  if (input) Object.keys(input).forEach(key => {\n    map.set(key, input[key]);\n  });\n  return map;\n}\n\nfunction flush (range, value, threshold, left, right, center) {\n  if (!threshold && threshold !== 0) return center;\n  const t = +threshold;\n  let a = range[0],\n    b = peek(range),\n    l;\n\n  // swap endpoints if range is reversed\n  if (b < a) {\n    l = a;\n    a = b;\n    b = l;\n  }\n\n  // compare value to endpoints\n  l = Math.abs(value - a);\n  const r = Math.abs(b - value);\n\n  // adjust if value is within threshold distance of endpoint\n  return l < r && l <= t ? left : r <= t ? right : center;\n}\n\nfunction inherits (child, parent, members) {\n  const proto = child.prototype = Object.create(parent.prototype);\n  Object.defineProperty(proto, 'constructor', {\n    value: child,\n    writable: true,\n    enumerable: true,\n    configurable: true\n  });\n  return extend(proto, members);\n}\n\n/**\n * Predicate that returns true if the value lies within the span\n * of the given range. The left and right flags control the use\n * of inclusive (true) or exclusive (false) comparisons.\n */\nfunction inrange (value, range, left, right) {\n  let r0 = range[0],\n    r1 = range[range.length - 1],\n    t;\n  if (r0 > r1) {\n    t = r0;\n    r0 = r1;\n    r1 = t;\n  }\n  left = left === undefined || left;\n  right = right === undefined || right;\n  return (left ? r0 <= value : r0 < value) && (right ? value <= r1 : value < r1);\n}\n\nfunction isBoolean (_) {\n  return typeof _ === 'boolean';\n}\n\nfunction isDate (_) {\n  return Object.prototype.toString.call(_) === '[object Date]';\n}\n\nfunction isIterable (_) {\n  return _ && isFunction(_[Symbol.iterator]);\n}\n\nfunction isNumber (_) {\n  return typeof _ === 'number';\n}\n\nfunction isRegExp (_) {\n  return Object.prototype.toString.call(_) === '[object RegExp]';\n}\n\nfunction isString (_) {\n  return typeof _ === 'string';\n}\n\nfunction key (fields, flat, opt) {\n  if (fields) {\n    fields = flat ? array(fields).map(f => f.replace(/\\\\(.)/g, '$1')) : array(fields);\n  }\n  const len = fields && fields.length,\n    gen = opt && opt.get || getter,\n    map = f => gen(flat ? [f] : splitAccessPath(f));\n  let fn;\n  if (!len) {\n    fn = function () {\n      return '';\n    };\n  } else if (len === 1) {\n    const get = map(fields[0]);\n    fn = function (_) {\n      return '' + get(_);\n    };\n  } else {\n    const get = fields.map(map);\n    fn = function (_) {\n      let s = '' + get[0](_),\n        i = 0;\n      while (++i < len) s += '|' + get[i](_);\n      return s;\n    };\n  }\n  return accessor(fn, fields, 'key');\n}\n\nfunction lerp (array, frac) {\n  const lo = array[0],\n    hi = peek(array),\n    f = +frac;\n  return !f ? lo : f === 1 ? hi : lo + f * (hi - lo);\n}\n\nconst DEFAULT_MAX_SIZE = 10000;\n\n// adapted from https://github.com/dominictarr/hashlru/ (MIT License)\nfunction lruCache (maxsize) {\n  maxsize = +maxsize || DEFAULT_MAX_SIZE;\n  let curr, prev, size;\n  const clear = () => {\n    curr = {};\n    prev = {};\n    size = 0;\n  };\n  const update = (key, value) => {\n    if (++size > maxsize) {\n      prev = curr;\n      curr = {};\n      size = 1;\n    }\n    return curr[key] = value;\n  };\n  clear();\n  return {\n    clear,\n    has: key => has(curr, key) || has(prev, key),\n    get: key => has(curr, key) ? curr[key] : has(prev, key) ? update(key, prev[key]) : undefined,\n    set: (key, value) => has(curr, key) ? curr[key] = value : update(key, value)\n  };\n}\n\nfunction merge (compare, array0, array1, output) {\n  const n0 = array0.length,\n    n1 = array1.length;\n  if (!n1) return array0;\n  if (!n0) return array1;\n  const merged = output || new array0.constructor(n0 + n1);\n  let i0 = 0,\n    i1 = 0,\n    i = 0;\n  for (; i0 < n0 && i1 < n1; ++i) {\n    merged[i] = compare(array0[i0], array1[i1]) > 0 ? array1[i1++] : array0[i0++];\n  }\n  for (; i0 < n0; ++i0, ++i) {\n    merged[i] = array0[i0];\n  }\n  for (; i1 < n1; ++i1, ++i) {\n    merged[i] = array1[i1];\n  }\n  return merged;\n}\n\nfunction repeat (str, reps) {\n  let s = '';\n  while (--reps >= 0) s += str;\n  return s;\n}\n\nfunction pad (str, length, padchar, align) {\n  const c = padchar || ' ',\n    s = str + '',\n    n = length - s.length;\n  return n <= 0 ? s : align === 'left' ? repeat(c, n) + s : align === 'center' ? repeat(c, ~~(n / 2)) + s + repeat(c, Math.ceil(n / 2)) : s + repeat(c, n);\n}\n\n/**\n * Return the numerical span of an array: the difference between\n * the last and first values.\n */\nfunction span (array) {\n  return array && peek(array) - array[0] || 0;\n}\n\nfunction $(x) {\n  return isArray(x) ? '[' + x.map($) + ']' : isObject(x) || isString(x) ?\n  // Output valid JSON and JS source strings.\n  // See http://timelessrepo.com/json-isnt-a-javascript-subset\n  JSON.stringify(x).replace('\\u2028', '\\\\u2028').replace('\\u2029', '\\\\u2029') : x;\n}\n\nfunction toBoolean (_) {\n  return _ == null || _ === '' ? null : !_ || _ === 'false' || _ === '0' ? false : !!_;\n}\n\nconst defaultParser = _ => isNumber(_) ? _ : isDate(_) ? _ : Date.parse(_);\nfunction toDate (_, parser) {\n  parser = parser || defaultParser;\n  return _ == null || _ === '' ? null : parser(_);\n}\n\nfunction toString (_) {\n  return _ == null || _ === '' ? null : _ + '';\n}\n\nfunction toSet (_) {\n  const s = {},\n    n = _.length;\n  for (let i = 0; i < n; ++i) s[_[i]] = true;\n  return s;\n}\n\nfunction truncate (str, length, align, ellipsis) {\n  const e = ellipsis != null ? ellipsis : '\\u2026',\n    s = str + '',\n    n = s.length,\n    l = Math.max(0, length - e.length);\n  return n <= length ? s : align === 'left' ? e + s.slice(n - l) : align === 'center' ? s.slice(0, Math.ceil(l / 2)) + e + s.slice(n - ~~(l / 2)) : s.slice(0, l) + e;\n}\n\nfunction visitArray (array, filter, visitor) {\n  if (array) {\n    if (filter) {\n      const n = array.length;\n      for (let i = 0; i < n; ++i) {\n        const t = filter(array[i]);\n        if (t) visitor(t, i, array);\n      }\n    } else {\n      array.forEach(visitor);\n    }\n  }\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-util/build/vega-util.module.js?");

/***/ }),

/***/ "../../node_modules/vega-view-transforms/build/vega-view-transforms.module.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/vega-view-transforms/build/vega-view-transforms.module.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bound: () => (/* binding */ Bound),\n/* harmony export */   identifier: () => (/* binding */ Identifier),\n/* harmony export */   mark: () => (/* binding */ Mark),\n/* harmony export */   overlap: () => (/* binding */ Overlap),\n/* harmony export */   render: () => (/* binding */ Render),\n/* harmony export */   viewlayout: () => (/* binding */ ViewLayout)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-scenegraph */ \"../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n\n\n\n\nconst Top = 'top';\nconst Left = 'left';\nconst Right = 'right';\nconst Bottom = 'bottom';\nconst TopLeft = 'top-left';\nconst TopRight = 'top-right';\nconst BottomLeft = 'bottom-left';\nconst BottomRight = 'bottom-right';\nconst Start = 'start';\nconst Middle = 'middle';\nconst End = 'end';\nconst X = 'x';\nconst Y = 'y';\nconst Group = 'group';\nconst AxisRole = 'axis';\nconst TitleRole = 'title';\nconst FrameRole = 'frame';\nconst ScopeRole = 'scope';\nconst LegendRole = 'legend';\nconst RowHeader = 'row-header';\nconst RowFooter = 'row-footer';\nconst RowTitle = 'row-title';\nconst ColHeader = 'column-header';\nconst ColFooter = 'column-footer';\nconst ColTitle = 'column-title';\nconst Padding = 'padding';\nconst Symbols = 'symbol';\nconst Fit = 'fit';\nconst FitX = 'fit-x';\nconst FitY = 'fit-y';\nconst Pad = 'pad';\nconst None = 'none';\nconst All = 'all';\nconst Each = 'each';\nconst Flush = 'flush';\nconst Column = 'column';\nconst Row = 'row';\n\n/**\n * Calculate bounding boxes for scenegraph items.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {object} params.mark - The scenegraph mark instance to bound.\n */\nfunction Bound(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Bound, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const view = pulse.dataflow,\n      mark = _.mark,\n      type = mark.marktype,\n      entry = vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Marks[type],\n      bound = entry.bound;\n    let markBounds = mark.bounds,\n      rebound;\n    if (entry.nested) {\n      // multi-item marks have a single bounds instance\n      if (mark.items.length) view.dirty(mark.items[0]);\n      markBounds = boundItem(mark, bound);\n      mark.items.forEach(item => {\n        item.bounds.clear().union(markBounds);\n      });\n    } else if (type === Group || _.modified()) {\n      // operator parameters modified -> re-bound all items\n      // updates group bounds in response to modified group content\n      pulse.visit(pulse.MOD, item => view.dirty(item));\n      markBounds.clear();\n      mark.items.forEach(item => markBounds.union(boundItem(item, bound)));\n\n      // force reflow for axes/legends/titles to propagate any layout changes\n      switch (mark.role) {\n        case AxisRole:\n        case LegendRole:\n        case TitleRole:\n          pulse.reflow();\n      }\n    } else {\n      // incrementally update bounds, re-bound mark as needed\n      rebound = pulse.changed(pulse.REM);\n      pulse.visit(pulse.ADD, item => {\n        markBounds.union(boundItem(item, bound));\n      });\n      pulse.visit(pulse.MOD, item => {\n        rebound = rebound || markBounds.alignsWith(item.bounds);\n        view.dirty(item);\n        markBounds.union(boundItem(item, bound));\n      });\n      if (rebound) {\n        markBounds.clear();\n        mark.items.forEach(item => markBounds.union(item.bounds));\n      }\n    }\n\n    // ensure mark bounds do not exceed any clipping region\n    (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.boundClip)(mark);\n    return pulse.modifies('bounds');\n  }\n});\nfunction boundItem(item, bound, opt) {\n  return bound(item.bounds.clear(), item, opt);\n}\n\nconst COUNTER_NAME = ':vega_identifier:';\n\n/**\n * Adds a unique identifier to all added tuples.\n * This transform creates a new signal that serves as an id counter.\n * As a result, the id counter is shared across all instances of this\n * transform, generating unique ids across multiple data streams. In\n * addition, this signal value can be included in a snapshot of the\n * dataflow state, enabling correct resumption of id allocation.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {string} params.as - The field name for the generated identifier.\n */\nfunction Identifier(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, 0, params);\n}\nIdentifier.Definition = {\n  'type': 'Identifier',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'as',\n    'type': 'string',\n    'required': true\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Identifier, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const counter = getCounter(pulse.dataflow),\n      as = _.as;\n    let id = counter.value;\n    pulse.visit(pulse.ADD, t => t[as] = t[as] || ++id);\n    counter.set(this.value = id);\n    return pulse;\n  }\n});\nfunction getCounter(view) {\n  return view._signals[COUNTER_NAME] || (view._signals[COUNTER_NAME] = view.add(0));\n}\n\n/**\n * Bind scenegraph items to a scenegraph mark instance.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {object} params.markdef - The mark definition for creating the mark.\n *   This is an object of legal scenegraph mark properties which *must* include\n *   the 'marktype' property.\n */\nfunction Mark(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Mark, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    let mark = this.value;\n\n    // acquire mark on first invocation, bind context and group\n    if (!mark) {\n      mark = pulse.dataflow.scenegraph().mark(_.markdef, lookup$1(_), _.index);\n      mark.group.context = _.context;\n      if (!_.context.group) _.context.group = mark.group;\n      mark.source = this.source; // point to upstream collector\n      mark.clip = _.clip;\n      mark.interactive = _.interactive;\n      this.value = mark;\n    }\n\n    // initialize entering items\n    const Init = mark.marktype === Group ? vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.GroupItem : vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Item;\n    pulse.visit(pulse.ADD, item => Init.call(item, mark));\n\n    // update clipping and/or interactive status\n    if (_.modified('clip') || _.modified('interactive')) {\n      mark.clip = _.clip;\n      mark.interactive = !!_.interactive;\n      mark.zdirty = true; // force scenegraph re-eval\n      pulse.reflow();\n    }\n\n    // bind items array to scenegraph mark\n    mark.items = pulse.source;\n    return pulse;\n  }\n});\nfunction lookup$1(_) {\n  const g = _.groups,\n    p = _.parent;\n  return g && g.size === 1 ? g.get(Object.keys(g.object)[0]) : g && p ? g.lookup(p) : null;\n}\n\n/**\n * Analyze items for overlap, changing opacity to hide items with\n * overlapping bounding boxes. This transform will preserve at least\n * two items (e.g., first and last) even if overlap persists.\n * @param {object} params - The parameters for this operator.\n * @param {function(*,*): number} [params.sort] - A comparator\n *   function for sorting items.\n * @param {object} [params.method] - The overlap removal method to apply.\n *   One of 'parity' (default, hide every other item until there is no\n *   more overlap) or 'greedy' (sequentially scan and hide and items that\n *   overlap with the last visible item).\n * @param {object} [params.boundScale] - A scale whose range should be used\n *   to bound the items. Items exceeding the bounds of the scale range\n *   will be treated as overlapping. If null or undefined, no bounds check\n *   will be applied.\n * @param {object} [params.boundOrient] - The orientation of the scale\n *   (top, bottom, left, or right) used to bound items. This parameter is\n *   ignored if boundScale is null or undefined.\n * @param {object} [params.boundTolerance] - The tolerance in pixels for\n *   bound inclusion testing (default 1). This specifies by how many pixels\n *   an item's bounds may exceed the scale range bounds and not be culled.\n * @constructor\n */\nfunction Overlap(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nconst methods = {\n  parity: items => items.filter((item, i) => i % 2 ? item.opacity = 0 : 1),\n  greedy: (items, sep) => {\n    let a;\n    return items.filter((b, i) => !i || !intersect(a.bounds, b.bounds, sep) ? (a = b, 1) : b.opacity = 0);\n  }\n};\n\n// compute bounding box intersection\n// including padding pixels of separation\nconst intersect = (a, b, sep) => sep > Math.max(b.x1 - a.x2, a.x1 - b.x2, b.y1 - a.y2, a.y1 - b.y2);\nconst hasOverlap = (items, pad) => {\n  for (var i = 1, n = items.length, a = items[0].bounds, b; i < n; a = b, ++i) {\n    if (intersect(a, b = items[i].bounds, pad)) return true;\n  }\n};\nconst hasBounds = item => {\n  const b = item.bounds;\n  return b.width() > 1 && b.height() > 1;\n};\nconst boundTest = (scale, orient, tolerance) => {\n  var range = scale.range(),\n    b = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Bounds();\n  if (orient === Top || orient === Bottom) {\n    b.set(range[0], -Infinity, range[1], +Infinity);\n  } else {\n    b.set(-Infinity, range[0], +Infinity, range[1]);\n  }\n  b.expand(tolerance || 1);\n  return item => b.encloses(item.bounds);\n};\n\n// reset all items to be fully opaque\nconst reset = source => {\n  source.forEach(item => item.opacity = 1);\n  return source;\n};\n\n// add all tuples to mod, fork pulse if parameters were modified\n// fork prevents cross-stream tuple pollution (e.g., pulse from scale)\nconst reflow = (pulse, _) => pulse.reflow(_.modified()).modifies('opacity');\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Overlap, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const reduce = methods[_.method] || methods.parity,\n      sep = _.separation || 0;\n    let source = pulse.materialize(pulse.SOURCE).source,\n      items,\n      test;\n    if (!source || !source.length) return;\n    if (!_.method) {\n      // early exit if method is falsy\n      if (_.modified('method')) {\n        reset(source);\n        pulse = reflow(pulse, _);\n      }\n      return pulse;\n    }\n\n    // skip labels with no content\n    source = source.filter(hasBounds);\n\n    // early exit, nothing to do\n    if (!source.length) return;\n    if (_.sort) {\n      source = source.slice().sort(_.sort);\n    }\n    items = reset(source);\n    pulse = reflow(pulse, _);\n    if (items.length >= 3 && hasOverlap(items, sep)) {\n      do {\n        items = reduce(items, sep);\n      } while (items.length >= 3 && hasOverlap(items, sep));\n      if (items.length < 3 && !(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(source).opacity) {\n        if (items.length > 1) (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(items).opacity = 0;\n        (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.peek)(source).opacity = 1;\n      }\n    }\n    if (_.boundScale && _.boundTolerance >= 0) {\n      test = boundTest(_.boundScale, _.boundOrient, +_.boundTolerance);\n      source.forEach(item => {\n        if (!test(item)) item.opacity = 0;\n      });\n    }\n\n    // re-calculate mark bounds\n    const bounds = items[0].mark.bounds.clear();\n    source.forEach(item => {\n      if (item.opacity) bounds.union(item.bounds);\n    });\n    return pulse;\n  }\n});\n\n/**\n * Queue modified scenegraph items for rendering.\n * @constructor\n */\nfunction Render(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Render, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const view = pulse.dataflow;\n    pulse.visit(pulse.ALL, item => view.dirty(item));\n\n    // set z-index dirty flag as needed\n    if (pulse.fields && pulse.fields['zindex']) {\n      const item = pulse.source && pulse.source[0];\n      if (item) item.mark.zdirty = true;\n    }\n  }\n});\n\nconst tempBounds = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Bounds();\nfunction set(item, property, value) {\n  return item[property] === value ? 0 : (item[property] = value, 1);\n}\n\nfunction isYAxis(mark) {\n  var orient = mark.items[0].orient;\n  return orient === Left || orient === Right;\n}\nfunction axisIndices(datum) {\n  let index = +datum.grid;\n  return [datum.ticks ? index++ : -1,\n  // ticks index\n  datum.labels ? index++ : -1,\n  // labels index\n  index + +datum.domain // title index\n  ];\n}\n\nfunction axisLayout(view, axis, width, height) {\n  var item = axis.items[0],\n    datum = item.datum,\n    delta = item.translate != null ? item.translate : 0.5,\n    orient = item.orient,\n    indices = axisIndices(datum),\n    range = item.range,\n    offset = item.offset,\n    position = item.position,\n    minExtent = item.minExtent,\n    maxExtent = item.maxExtent,\n    title = datum.title && item.items[indices[2]].items[0],\n    titlePadding = item.titlePadding,\n    bounds = item.bounds,\n    dl = title && (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.multiLineOffset)(title),\n    x = 0,\n    y = 0,\n    i,\n    s;\n  tempBounds.clear().union(bounds);\n  bounds.clear();\n  if ((i = indices[0]) > -1) bounds.union(item.items[i].bounds);\n  if ((i = indices[1]) > -1) bounds.union(item.items[i].bounds);\n\n  // position axis group and title\n  switch (orient) {\n    case Top:\n      x = position || 0;\n      y = -offset;\n      s = Math.max(minExtent, Math.min(maxExtent, -bounds.y1));\n      bounds.add(0, -s).add(range, 0);\n      if (title) axisTitleLayout(view, title, s, titlePadding, dl, 0, -1, bounds);\n      break;\n    case Left:\n      x = -offset;\n      y = position || 0;\n      s = Math.max(minExtent, Math.min(maxExtent, -bounds.x1));\n      bounds.add(-s, 0).add(0, range);\n      if (title) axisTitleLayout(view, title, s, titlePadding, dl, 1, -1, bounds);\n      break;\n    case Right:\n      x = width + offset;\n      y = position || 0;\n      s = Math.max(minExtent, Math.min(maxExtent, bounds.x2));\n      bounds.add(0, 0).add(s, range);\n      if (title) axisTitleLayout(view, title, s, titlePadding, dl, 1, 1, bounds);\n      break;\n    case Bottom:\n      x = position || 0;\n      y = height + offset;\n      s = Math.max(minExtent, Math.min(maxExtent, bounds.y2));\n      bounds.add(0, 0).add(range, s);\n      if (title) axisTitleLayout(view, title, s, titlePadding, 0, 0, 1, bounds);\n      break;\n    default:\n      x = item.x;\n      y = item.y;\n  }\n\n  // update bounds\n  (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.boundStroke)(bounds.translate(x, y), item);\n  if (set(item, 'x', x + delta) | set(item, 'y', y + delta)) {\n    item.bounds = tempBounds;\n    view.dirty(item);\n    item.bounds = bounds;\n    view.dirty(item);\n  }\n  return item.mark.bounds.clear().union(bounds);\n}\nfunction axisTitleLayout(view, title, offset, pad, dl, isYAxis, sign, bounds) {\n  const b = title.bounds;\n  if (title.auto) {\n    const v = sign * (offset + dl + pad);\n    let dx = 0,\n      dy = 0;\n    view.dirty(title);\n    isYAxis ? dx = (title.x || 0) - (title.x = v) : dy = (title.y || 0) - (title.y = v);\n    title.mark.bounds.clear().union(b.translate(-dx, -dy));\n    view.dirty(title);\n  }\n  bounds.union(b);\n}\n\n// aggregation functions for grid margin determination\nconst min = (a, b) => Math.floor(Math.min(a, b));\nconst max = (a, b) => Math.ceil(Math.max(a, b));\nfunction gridLayoutGroups(group) {\n  var groups = group.items,\n    n = groups.length,\n    i = 0,\n    mark,\n    items;\n  const views = {\n    marks: [],\n    rowheaders: [],\n    rowfooters: [],\n    colheaders: [],\n    colfooters: [],\n    rowtitle: null,\n    coltitle: null\n  };\n\n  // layout axes, gather legends, collect bounds\n  for (; i < n; ++i) {\n    mark = groups[i];\n    items = mark.items;\n    if (mark.marktype === Group) {\n      switch (mark.role) {\n        case AxisRole:\n        case LegendRole:\n        case TitleRole:\n          break;\n        case RowHeader:\n          views.rowheaders.push(...items);\n          break;\n        case RowFooter:\n          views.rowfooters.push(...items);\n          break;\n        case ColHeader:\n          views.colheaders.push(...items);\n          break;\n        case ColFooter:\n          views.colfooters.push(...items);\n          break;\n        case RowTitle:\n          views.rowtitle = items[0];\n          break;\n        case ColTitle:\n          views.coltitle = items[0];\n          break;\n        default:\n          views.marks.push(...items);\n      }\n    }\n  }\n  return views;\n}\nfunction bboxFlush(item) {\n  return new vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Bounds().set(0, 0, item.width || 0, item.height || 0);\n}\nfunction bboxFull(item) {\n  const b = item.bounds.clone();\n  return b.empty() ? b.set(0, 0, 0, 0) : b.translate(-(item.x || 0), -(item.y || 0));\n}\nfunction get(opt, key, d) {\n  const v = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isObject)(opt) ? opt[key] : opt;\n  return v != null ? v : d !== undefined ? d : 0;\n}\nfunction offsetValue(v) {\n  return v < 0 ? Math.ceil(-v) : 0;\n}\nfunction gridLayout(view, groups, opt) {\n  var dirty = !opt.nodirty,\n    bbox = opt.bounds === Flush ? bboxFlush : bboxFull,\n    bounds = tempBounds.set(0, 0, 0, 0),\n    alignCol = get(opt.align, Column),\n    alignRow = get(opt.align, Row),\n    padCol = get(opt.padding, Column),\n    padRow = get(opt.padding, Row),\n    ncols = opt.columns || groups.length,\n    nrows = ncols <= 0 ? 1 : Math.ceil(groups.length / ncols),\n    n = groups.length,\n    xOffset = Array(n),\n    xExtent = Array(ncols),\n    xMax = 0,\n    yOffset = Array(n),\n    yExtent = Array(nrows),\n    yMax = 0,\n    dx = Array(n),\n    dy = Array(n),\n    boxes = Array(n),\n    m,\n    i,\n    c,\n    r,\n    b,\n    g,\n    px,\n    py,\n    x,\n    y,\n    offset;\n  for (i = 0; i < ncols; ++i) xExtent[i] = 0;\n  for (i = 0; i < nrows; ++i) yExtent[i] = 0;\n\n  // determine offsets for each group\n  for (i = 0; i < n; ++i) {\n    g = groups[i];\n    b = boxes[i] = bbox(g);\n    g.x = g.x || 0;\n    dx[i] = 0;\n    g.y = g.y || 0;\n    dy[i] = 0;\n    c = i % ncols;\n    r = ~~(i / ncols);\n    xMax = Math.max(xMax, px = Math.ceil(b.x2));\n    yMax = Math.max(yMax, py = Math.ceil(b.y2));\n    xExtent[c] = Math.max(xExtent[c], px);\n    yExtent[r] = Math.max(yExtent[r], py);\n    xOffset[i] = padCol + offsetValue(b.x1);\n    yOffset[i] = padRow + offsetValue(b.y1);\n    if (dirty) view.dirty(groups[i]);\n  }\n\n  // set initial alignment offsets\n  for (i = 0; i < n; ++i) {\n    if (i % ncols === 0) xOffset[i] = 0;\n    if (i < ncols) yOffset[i] = 0;\n  }\n\n  // enforce column alignment constraints\n  if (alignCol === Each) {\n    for (c = 1; c < ncols; ++c) {\n      for (offset = 0, i = c; i < n; i += ncols) {\n        if (offset < xOffset[i]) offset = xOffset[i];\n      }\n      for (i = c; i < n; i += ncols) {\n        xOffset[i] = offset + xExtent[c - 1];\n      }\n    }\n  } else if (alignCol === All) {\n    for (offset = 0, i = 0; i < n; ++i) {\n      if (i % ncols && offset < xOffset[i]) offset = xOffset[i];\n    }\n    for (i = 0; i < n; ++i) {\n      if (i % ncols) xOffset[i] = offset + xMax;\n    }\n  } else {\n    for (alignCol = false, c = 1; c < ncols; ++c) {\n      for (i = c; i < n; i += ncols) {\n        xOffset[i] += xExtent[c - 1];\n      }\n    }\n  }\n\n  // enforce row alignment constraints\n  if (alignRow === Each) {\n    for (r = 1; r < nrows; ++r) {\n      for (offset = 0, i = r * ncols, m = i + ncols; i < m; ++i) {\n        if (offset < yOffset[i]) offset = yOffset[i];\n      }\n      for (i = r * ncols; i < m; ++i) {\n        yOffset[i] = offset + yExtent[r - 1];\n      }\n    }\n  } else if (alignRow === All) {\n    for (offset = 0, i = ncols; i < n; ++i) {\n      if (offset < yOffset[i]) offset = yOffset[i];\n    }\n    for (i = ncols; i < n; ++i) {\n      yOffset[i] = offset + yMax;\n    }\n  } else {\n    for (alignRow = false, r = 1; r < nrows; ++r) {\n      for (i = r * ncols, m = i + ncols; i < m; ++i) {\n        yOffset[i] += yExtent[r - 1];\n      }\n    }\n  }\n\n  // perform horizontal grid layout\n  for (x = 0, i = 0; i < n; ++i) {\n    x = xOffset[i] + (i % ncols ? x : 0);\n    dx[i] += x - groups[i].x;\n  }\n\n  // perform vertical grid layout\n  for (c = 0; c < ncols; ++c) {\n    for (y = 0, i = c; i < n; i += ncols) {\n      y += yOffset[i];\n      dy[i] += y - groups[i].y;\n    }\n  }\n\n  // perform horizontal centering\n  if (alignCol && get(opt.center, Column) && nrows > 1) {\n    for (i = 0; i < n; ++i) {\n      b = alignCol === All ? xMax : xExtent[i % ncols];\n      x = b - boxes[i].x2 - groups[i].x - dx[i];\n      if (x > 0) dx[i] += x / 2;\n    }\n  }\n\n  // perform vertical centering\n  if (alignRow && get(opt.center, Row) && ncols !== 1) {\n    for (i = 0; i < n; ++i) {\n      b = alignRow === All ? yMax : yExtent[~~(i / ncols)];\n      y = b - boxes[i].y2 - groups[i].y - dy[i];\n      if (y > 0) dy[i] += y / 2;\n    }\n  }\n\n  // position grid relative to anchor\n  for (i = 0; i < n; ++i) {\n    bounds.union(boxes[i].translate(dx[i], dy[i]));\n  }\n  x = get(opt.anchor, X);\n  y = get(opt.anchor, Y);\n  switch (get(opt.anchor, Column)) {\n    case End:\n      x -= bounds.width();\n      break;\n    case Middle:\n      x -= bounds.width() / 2;\n  }\n  switch (get(opt.anchor, Row)) {\n    case End:\n      y -= bounds.height();\n      break;\n    case Middle:\n      y -= bounds.height() / 2;\n  }\n  x = Math.round(x);\n  y = Math.round(y);\n\n  // update mark positions, bounds, dirty\n  bounds.clear();\n  for (i = 0; i < n; ++i) {\n    groups[i].mark.bounds.clear();\n  }\n  for (i = 0; i < n; ++i) {\n    g = groups[i];\n    g.x += dx[i] += x;\n    g.y += dy[i] += y;\n    bounds.union(g.mark.bounds.union(g.bounds.translate(dx[i], dy[i])));\n    if (dirty) view.dirty(g);\n  }\n  return bounds;\n}\nfunction trellisLayout(view, group, opt) {\n  var views = gridLayoutGroups(group),\n    groups = views.marks,\n    bbox = opt.bounds === Flush ? boundFlush : boundFull,\n    off = opt.offset,\n    ncols = opt.columns || groups.length,\n    nrows = ncols <= 0 ? 1 : Math.ceil(groups.length / ncols),\n    cells = nrows * ncols,\n    x,\n    y,\n    x2,\n    y2,\n    anchor,\n    band,\n    offset;\n\n  // -- initial grid layout\n  const bounds = gridLayout(view, groups, opt);\n  if (bounds.empty()) bounds.set(0, 0, 0, 0); // empty grid\n\n  // -- layout grid headers and footers --\n\n  // perform row header layout\n  if (views.rowheaders) {\n    band = get(opt.headerBand, Row, null);\n    x = layoutHeaders(view, views.rowheaders, groups, ncols, nrows, -get(off, 'rowHeader'), min, 0, bbox, 'x1', 0, ncols, 1, band);\n  }\n\n  // perform column header layout\n  if (views.colheaders) {\n    band = get(opt.headerBand, Column, null);\n    y = layoutHeaders(view, views.colheaders, groups, ncols, ncols, -get(off, 'columnHeader'), min, 1, bbox, 'y1', 0, 1, ncols, band);\n  }\n\n  // perform row footer layout\n  if (views.rowfooters) {\n    band = get(opt.footerBand, Row, null);\n    x2 = layoutHeaders(view, views.rowfooters, groups, ncols, nrows, get(off, 'rowFooter'), max, 0, bbox, 'x2', ncols - 1, ncols, 1, band);\n  }\n\n  // perform column footer layout\n  if (views.colfooters) {\n    band = get(opt.footerBand, Column, null);\n    y2 = layoutHeaders(view, views.colfooters, groups, ncols, ncols, get(off, 'columnFooter'), max, 1, bbox, 'y2', cells - ncols, 1, ncols, band);\n  }\n\n  // perform row title layout\n  if (views.rowtitle) {\n    anchor = get(opt.titleAnchor, Row);\n    offset = get(off, 'rowTitle');\n    offset = anchor === End ? x2 + offset : x - offset;\n    band = get(opt.titleBand, Row, 0.5);\n    layoutTitle(view, views.rowtitle, offset, 0, bounds, band);\n  }\n\n  // perform column title layout\n  if (views.coltitle) {\n    anchor = get(opt.titleAnchor, Column);\n    offset = get(off, 'columnTitle');\n    offset = anchor === End ? y2 + offset : y - offset;\n    band = get(opt.titleBand, Column, 0.5);\n    layoutTitle(view, views.coltitle, offset, 1, bounds, band);\n  }\n}\nfunction boundFlush(item, field) {\n  return field === 'x1' ? item.x || 0 : field === 'y1' ? item.y || 0 : field === 'x2' ? (item.x || 0) + (item.width || 0) : field === 'y2' ? (item.y || 0) + (item.height || 0) : undefined;\n}\nfunction boundFull(item, field) {\n  return item.bounds[field];\n}\nfunction layoutHeaders(view, headers, groups, ncols, limit, offset, agg, isX, bound, bf, start, stride, back, band) {\n  var n = groups.length,\n    init = 0,\n    edge = 0,\n    i,\n    j,\n    k,\n    m,\n    b,\n    h,\n    g,\n    x,\n    y;\n\n  // if no groups, early exit and return 0\n  if (!n) return init;\n\n  // compute margin\n  for (i = start; i < n; i += stride) {\n    if (groups[i]) init = agg(init, bound(groups[i], bf));\n  }\n\n  // if no headers, return margin calculation\n  if (!headers.length) return init;\n\n  // check if number of headers exceeds number of rows or columns\n  if (headers.length > limit) {\n    view.warn('Grid headers exceed limit: ' + limit);\n    headers = headers.slice(0, limit);\n  }\n\n  // apply offset\n  init += offset;\n\n  // clear mark bounds for all headers\n  for (j = 0, m = headers.length; j < m; ++j) {\n    view.dirty(headers[j]);\n    headers[j].mark.bounds.clear();\n  }\n\n  // layout each header\n  for (i = start, j = 0, m = headers.length; j < m; ++j, i += stride) {\n    h = headers[j];\n    b = h.mark.bounds;\n\n    // search for nearest group to align to\n    // necessary if table has empty cells\n    for (k = i; k >= 0 && (g = groups[k]) == null; k -= back);\n\n    // assign coordinates and update bounds\n    if (isX) {\n      x = band == null ? g.x : Math.round(g.bounds.x1 + band * g.bounds.width());\n      y = init;\n    } else {\n      x = init;\n      y = band == null ? g.y : Math.round(g.bounds.y1 + band * g.bounds.height());\n    }\n    b.union(h.bounds.translate(x - (h.x || 0), y - (h.y || 0)));\n    h.x = x;\n    h.y = y;\n    view.dirty(h);\n\n    // update current edge of layout bounds\n    edge = agg(edge, b[bf]);\n  }\n  return edge;\n}\nfunction layoutTitle(view, g, offset, isX, bounds, band) {\n  if (!g) return;\n  view.dirty(g);\n\n  // compute title coordinates\n  var x = offset,\n    y = offset;\n  isX ? x = Math.round(bounds.x1 + band * bounds.width()) : y = Math.round(bounds.y1 + band * bounds.height());\n\n  // assign coordinates and update bounds\n  g.bounds.translate(x - (g.x || 0), y - (g.y || 0));\n  g.mark.bounds.clear().union(g.bounds);\n  g.x = x;\n  g.y = y;\n\n  // queue title for redraw\n  view.dirty(g);\n}\n\n// utility for looking up legend layout configuration\nfunction lookup(config, orient) {\n  const opt = config[orient] || {};\n  return (key, d) => opt[key] != null ? opt[key] : config[key] != null ? config[key] : d;\n}\n\n// if legends specify offset directly, use the maximum specified value\nfunction offsets(legends, value) {\n  let max = -Infinity;\n  legends.forEach(item => {\n    if (item.offset != null) max = Math.max(max, item.offset);\n  });\n  return max > -Infinity ? max : value;\n}\nfunction legendParams(g, orient, config, xb, yb, w, h) {\n  const _ = lookup(config, orient),\n    offset = offsets(g, _('offset', 0)),\n    anchor = _('anchor', Start),\n    mult = anchor === End ? 1 : anchor === Middle ? 0.5 : 0;\n  const p = {\n    align: Each,\n    bounds: _('bounds', Flush),\n    columns: _('direction') === 'vertical' ? 1 : g.length,\n    padding: _('margin', 8),\n    center: _('center'),\n    nodirty: true\n  };\n  switch (orient) {\n    case Left:\n      p.anchor = {\n        x: Math.floor(xb.x1) - offset,\n        column: End,\n        y: mult * (h || xb.height() + 2 * xb.y1),\n        row: anchor\n      };\n      break;\n    case Right:\n      p.anchor = {\n        x: Math.ceil(xb.x2) + offset,\n        y: mult * (h || xb.height() + 2 * xb.y1),\n        row: anchor\n      };\n      break;\n    case Top:\n      p.anchor = {\n        y: Math.floor(yb.y1) - offset,\n        row: End,\n        x: mult * (w || yb.width() + 2 * yb.x1),\n        column: anchor\n      };\n      break;\n    case Bottom:\n      p.anchor = {\n        y: Math.ceil(yb.y2) + offset,\n        x: mult * (w || yb.width() + 2 * yb.x1),\n        column: anchor\n      };\n      break;\n    case TopLeft:\n      p.anchor = {\n        x: offset,\n        y: offset\n      };\n      break;\n    case TopRight:\n      p.anchor = {\n        x: w - offset,\n        y: offset,\n        column: End\n      };\n      break;\n    case BottomLeft:\n      p.anchor = {\n        x: offset,\n        y: h - offset,\n        row: End\n      };\n      break;\n    case BottomRight:\n      p.anchor = {\n        x: w - offset,\n        y: h - offset,\n        column: End,\n        row: End\n      };\n      break;\n  }\n  return p;\n}\nfunction legendLayout(view, legend) {\n  var item = legend.items[0],\n    datum = item.datum,\n    orient = item.orient,\n    bounds = item.bounds,\n    x = item.x,\n    y = item.y,\n    w,\n    h;\n\n  // cache current bounds for later comparison\n  item._bounds ? item._bounds.clear().union(bounds) : item._bounds = bounds.clone();\n  bounds.clear();\n\n  // adjust legend to accommodate padding and title\n  legendGroupLayout(view, item, item.items[0].items[0]);\n\n  // aggregate bounds to determine size, and include origin\n  bounds = legendBounds(item, bounds);\n  w = 2 * item.padding;\n  h = 2 * item.padding;\n  if (!bounds.empty()) {\n    w = Math.ceil(bounds.width() + w);\n    h = Math.ceil(bounds.height() + h);\n  }\n  if (datum.type === Symbols) {\n    legendEntryLayout(item.items[0].items[0].items[0].items);\n  }\n  if (orient !== None) {\n    item.x = x = 0;\n    item.y = y = 0;\n  }\n  item.width = w;\n  item.height = h;\n  (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.boundStroke)(bounds.set(x, y, x + w, y + h), item);\n  item.mark.bounds.clear().union(bounds);\n  return item;\n}\nfunction legendBounds(item, b) {\n  // aggregate item bounds\n  item.items.forEach(_ => b.union(_.bounds));\n\n  // anchor to legend origin\n  b.x1 = item.padding;\n  b.y1 = item.padding;\n  return b;\n}\nfunction legendGroupLayout(view, item, entry) {\n  var pad = item.padding,\n    ex = pad - entry.x,\n    ey = pad - entry.y;\n  if (!item.datum.title) {\n    if (ex || ey) translate(view, entry, ex, ey);\n  } else {\n    var title = item.items[1].items[0],\n      anchor = title.anchor,\n      tpad = item.titlePadding || 0,\n      tx = pad - title.x,\n      ty = pad - title.y;\n    switch (title.orient) {\n      case Left:\n        ex += Math.ceil(title.bounds.width()) + tpad;\n        break;\n      case Right:\n      case Bottom:\n        break;\n      default:\n        ey += title.bounds.height() + tpad;\n    }\n    if (ex || ey) translate(view, entry, ex, ey);\n    switch (title.orient) {\n      case Left:\n        ty += legendTitleOffset(item, entry, title, anchor, 1, 1);\n        break;\n      case Right:\n        tx += legendTitleOffset(item, entry, title, End, 0, 0) + tpad;\n        ty += legendTitleOffset(item, entry, title, anchor, 1, 1);\n        break;\n      case Bottom:\n        tx += legendTitleOffset(item, entry, title, anchor, 0, 0);\n        ty += legendTitleOffset(item, entry, title, End, -1, 0, 1) + tpad;\n        break;\n      default:\n        tx += legendTitleOffset(item, entry, title, anchor, 0, 0);\n    }\n    if (tx || ty) translate(view, title, tx, ty);\n\n    // translate legend if title pushes into negative coordinates\n    if ((tx = Math.round(title.bounds.x1 - pad)) < 0) {\n      translate(view, entry, -tx, 0);\n      translate(view, title, -tx, 0);\n    }\n  }\n}\nfunction legendTitleOffset(item, entry, title, anchor, y, lr, noBar) {\n  const grad = item.datum.type !== 'symbol',\n    vgrad = title.datum.vgrad,\n    e = grad && (lr || !vgrad) && !noBar ? entry.items[0] : entry,\n    s = e.bounds[y ? 'y2' : 'x2'] - item.padding,\n    u = vgrad && lr ? s : 0,\n    v = vgrad && lr ? 0 : s,\n    o = y <= 0 ? 0 : (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.multiLineOffset)(title);\n  return Math.round(anchor === Start ? u : anchor === End ? v - o : 0.5 * (s - o));\n}\nfunction translate(view, item, dx, dy) {\n  item.x += dx;\n  item.y += dy;\n  item.bounds.translate(dx, dy);\n  item.mark.bounds.translate(dx, dy);\n  view.dirty(item);\n}\nfunction legendEntryLayout(entries) {\n  // get max widths for each column\n  const widths = entries.reduce((w, g) => {\n    w[g.column] = Math.max(g.bounds.x2 - g.x, w[g.column] || 0);\n    return w;\n  }, {});\n\n  // set dimensions of legend entry groups\n  entries.forEach(g => {\n    g.width = widths[g.column];\n    g.height = g.bounds.y2 - g.y;\n  });\n}\n\nfunction titleLayout(view, mark, width, height, viewBounds) {\n  var group = mark.items[0],\n    frame = group.frame,\n    orient = group.orient,\n    anchor = group.anchor,\n    offset = group.offset,\n    padding = group.padding,\n    title = group.items[0].items[0],\n    subtitle = group.items[1] && group.items[1].items[0],\n    end = orient === Left || orient === Right ? height : width,\n    start = 0,\n    x = 0,\n    y = 0,\n    sx = 0,\n    sy = 0,\n    pos;\n  if (frame !== Group) {\n    orient === Left ? (start = viewBounds.y2, end = viewBounds.y1) : orient === Right ? (start = viewBounds.y1, end = viewBounds.y2) : (start = viewBounds.x1, end = viewBounds.x2);\n  } else if (orient === Left) {\n    start = height, end = 0;\n  }\n  pos = anchor === Start ? start : anchor === End ? end : (start + end) / 2;\n  if (subtitle && subtitle.text) {\n    // position subtitle\n    switch (orient) {\n      case Top:\n      case Bottom:\n        sy = title.bounds.height() + padding;\n        break;\n      case Left:\n        sx = title.bounds.width() + padding;\n        break;\n      case Right:\n        sx = -title.bounds.width() - padding;\n        break;\n    }\n    tempBounds.clear().union(subtitle.bounds);\n    tempBounds.translate(sx - (subtitle.x || 0), sy - (subtitle.y || 0));\n    if (set(subtitle, 'x', sx) | set(subtitle, 'y', sy)) {\n      view.dirty(subtitle);\n      subtitle.bounds.clear().union(tempBounds);\n      subtitle.mark.bounds.clear().union(tempBounds);\n      view.dirty(subtitle);\n    }\n    tempBounds.clear().union(subtitle.bounds);\n  } else {\n    tempBounds.clear();\n  }\n  tempBounds.union(title.bounds);\n\n  // position title group\n  switch (orient) {\n    case Top:\n      x = pos;\n      y = viewBounds.y1 - tempBounds.height() - offset;\n      break;\n    case Left:\n      x = viewBounds.x1 - tempBounds.width() - offset;\n      y = pos;\n      break;\n    case Right:\n      x = viewBounds.x2 + tempBounds.width() + offset;\n      y = pos;\n      break;\n    case Bottom:\n      x = pos;\n      y = viewBounds.y2 + offset;\n      break;\n    default:\n      x = group.x;\n      y = group.y;\n  }\n  if (set(group, 'x', x) | set(group, 'y', y)) {\n    tempBounds.translate(x, y);\n    view.dirty(group);\n    group.bounds.clear().union(tempBounds);\n    mark.bounds.clear().union(tempBounds);\n    view.dirty(group);\n  }\n  return group.bounds;\n}\n\n/**\n * Layout view elements such as axes and legends.\n * Also performs size adjustments.\n * @constructor\n * @param {object} params - The parameters for this operator.\n * @param {object} params.mark - Scenegraph mark of groups to layout.\n */\nfunction ViewLayout(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(ViewLayout, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const view = pulse.dataflow;\n    _.mark.items.forEach(group => {\n      if (_.layout) trellisLayout(view, group, _.layout);\n      layoutGroup(view, group, _);\n    });\n    return shouldReflow(_.mark.group) ? pulse.reflow() : pulse;\n  }\n});\nfunction shouldReflow(group) {\n  // We typically should reflow if layout is invoked (#2568), as child items\n  // may have resized and reflow ensures group bounds are re-calculated.\n  // However, legend entries have a special exception to avoid instability.\n  // For example, if a selected legend symbol gains a stroke on hover,\n  // we don't want to re-position subsequent elements in the legend.\n  return group && group.mark.role !== 'legend-entry';\n}\nfunction layoutGroup(view, group, _) {\n  var items = group.items,\n    width = Math.max(0, group.width || 0),\n    height = Math.max(0, group.height || 0),\n    viewBounds = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_1__.Bounds().set(0, 0, width, height),\n    xBounds = viewBounds.clone(),\n    yBounds = viewBounds.clone(),\n    legends = [],\n    title,\n    mark,\n    orient,\n    b,\n    i,\n    n;\n\n  // layout axes, gather legends, collect bounds\n  for (i = 0, n = items.length; i < n; ++i) {\n    mark = items[i];\n    switch (mark.role) {\n      case AxisRole:\n        b = isYAxis(mark) ? xBounds : yBounds;\n        b.union(axisLayout(view, mark, width, height));\n        break;\n      case TitleRole:\n        title = mark;\n        break;\n      case LegendRole:\n        legends.push(legendLayout(view, mark));\n        break;\n      case FrameRole:\n      case ScopeRole:\n      case RowHeader:\n      case RowFooter:\n      case RowTitle:\n      case ColHeader:\n      case ColFooter:\n      case ColTitle:\n        xBounds.union(mark.bounds);\n        yBounds.union(mark.bounds);\n        break;\n      default:\n        viewBounds.union(mark.bounds);\n    }\n  }\n\n  // layout legends, adjust viewBounds\n  if (legends.length) {\n    // group legends by orient\n    const l = {};\n    legends.forEach(item => {\n      orient = item.orient || Right;\n      if (orient !== None) (l[orient] || (l[orient] = [])).push(item);\n    });\n\n    // perform grid layout for each orient group\n    for (const orient in l) {\n      const g = l[orient];\n      gridLayout(view, g, legendParams(g, orient, _.legends, xBounds, yBounds, width, height));\n    }\n\n    // update view bounds\n    legends.forEach(item => {\n      const b = item.bounds;\n      if (!b.equals(item._bounds)) {\n        item.bounds = item._bounds;\n        view.dirty(item); // dirty previous location\n        item.bounds = b;\n        view.dirty(item);\n      }\n      if (_.autosize && (_.autosize.type === Fit || _.autosize.type === FitX || _.autosize.type === FitY)) {\n        // For autosize fit, incorporate the orthogonal dimension only.\n        // Legends that overrun the chart area will then be clipped;\n        // otherwise the chart area gets reduced to nothing!\n        switch (item.orient) {\n          case Left:\n          case Right:\n            viewBounds.add(b.x1, 0).add(b.x2, 0);\n            break;\n          case Top:\n          case Bottom:\n            viewBounds.add(0, b.y1).add(0, b.y2);\n        }\n      } else {\n        viewBounds.union(b);\n      }\n    });\n  }\n\n  // combine bounding boxes\n  viewBounds.union(xBounds).union(yBounds);\n\n  // layout title, adjust bounds\n  if (title) {\n    viewBounds.union(titleLayout(view, title, width, height, viewBounds));\n  }\n\n  // override aggregated view bounds if content is clipped\n  if (group.clip) {\n    viewBounds.set(0, 0, group.width || 0, group.height || 0);\n  }\n\n  // perform size adjustment\n  viewSizeLayout(view, group, viewBounds, _);\n}\nfunction viewSizeLayout(view, group, viewBounds, _) {\n  const auto = _.autosize || {},\n    type = auto.type;\n  if (view._autosize < 1 || !type) return;\n  let viewWidth = view._width,\n    viewHeight = view._height,\n    width = Math.max(0, group.width || 0),\n    left = Math.max(0, Math.ceil(-viewBounds.x1)),\n    height = Math.max(0, group.height || 0),\n    top = Math.max(0, Math.ceil(-viewBounds.y1));\n  const right = Math.max(0, Math.ceil(viewBounds.x2 - width)),\n    bottom = Math.max(0, Math.ceil(viewBounds.y2 - height));\n  if (auto.contains === Padding) {\n    const padding = view.padding();\n    viewWidth -= padding.left + padding.right;\n    viewHeight -= padding.top + padding.bottom;\n  }\n  if (type === None) {\n    left = 0;\n    top = 0;\n    width = viewWidth;\n    height = viewHeight;\n  } else if (type === Fit) {\n    width = Math.max(0, viewWidth - left - right);\n    height = Math.max(0, viewHeight - top - bottom);\n  } else if (type === FitX) {\n    width = Math.max(0, viewWidth - left - right);\n    viewHeight = height + top + bottom;\n  } else if (type === FitY) {\n    viewWidth = width + left + right;\n    height = Math.max(0, viewHeight - top - bottom);\n  } else if (type === Pad) {\n    viewWidth = width + left + right;\n    viewHeight = height + top + bottom;\n  }\n  view._resizeView(viewWidth, viewHeight, width, height, [left, top], auto.resize);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-view-transforms/build/vega-view-transforms.module.js?");

/***/ }),

/***/ "../../node_modules/vega-view/build/vega-view.module.js":
/*!**************************************************************!*\
  !*** ../../node_modules/vega-view/build/vega-view.module.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   View: () => (/* binding */ View)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-scenegraph */ \"../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var vega_functions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-functions */ \"../../node_modules/vega-functions/build/vega-functions.module.js\");\n/* harmony import */ var vega_runtime__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-runtime */ \"../../node_modules/vega-runtime/build/vega-runtime.module.js\");\n/* harmony import */ var d3_timer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-timer */ \"../../node_modules/d3-timer/src/interval.js\");\n/* harmony import */ var vega_format__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! vega-format */ \"../../node_modules/vega-format/build/vega-format.module.js\");\n\n\n\n\n\n\n\n\n\n// initialize aria role and label attributes\nfunction initializeAria(view) {\n  const el = view.container();\n  if (el) {\n    el.setAttribute('role', 'graphics-document');\n    el.setAttribute('aria-roleDescription', 'visualization');\n    ariaLabel(el, view.description());\n  }\n}\n\n// update aria-label if we have a DOM container element\nfunction ariaLabel(el, desc) {\n  if (el) desc == null ? el.removeAttribute('aria-label') : el.setAttribute('aria-label', desc);\n}\n\nfunction background (view) {\n  // respond to background signal\n  view.add(null, _ => {\n    view._background = _.bg;\n    view._resize = 1;\n    return _.bg;\n  }, {\n    bg: view._signals.background\n  });\n}\n\nconst Default = 'default';\nfunction cursor (view) {\n  // get cursor signal, add to dataflow if needed\n  const cursor = view._signals.cursor || (view._signals.cursor = view.add({\n    user: Default,\n    item: null\n  }));\n\n  // evaluate cursor on each mousemove event\n  view.on(view.events('view', 'mousemove'), cursor, (_, event) => {\n    const value = cursor.value,\n      user = value ? (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(value) ? value : value.user : Default,\n      item = event.item && event.item.cursor || null;\n    return value && user === value.user && item == value.item ? value : {\n      user: user,\n      item: item\n    };\n  });\n\n  // when cursor signal updates, set visible cursor\n  view.add(null, function (_) {\n    let user = _.cursor,\n      item = this.value;\n    if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(user)) {\n      item = user.item;\n      user = user.user;\n    }\n    setCursor(view, user && user !== Default ? user : item || user);\n    return item;\n  }, {\n    cursor: cursor\n  });\n}\nfunction setCursor(view, cursor) {\n  const el = view.globalCursor() ? typeof document !== 'undefined' && document.body : view.container();\n  if (el) {\n    return cursor == null ? el.style.removeProperty('cursor') : el.style.cursor = cursor;\n  }\n}\n\nfunction dataref(view, name) {\n  var data = view._runtime.data;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(data, name)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized data set: ' + name);\n  }\n  return data[name];\n}\nfunction data(name, values) {\n  return arguments.length < 2 ? dataref(this, name).values.value : change.call(this, name, (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.changeset)().remove(vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy).insert(values));\n}\nfunction change(name, changes) {\n  if (!(0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.isChangeSet)(changes)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Second argument to changes must be a changeset.');\n  }\n  const dataset = dataref(this, name);\n  dataset.modified = true;\n  return this.pulse(dataset.input, changes);\n}\nfunction insert(name, _) {\n  return change.call(this, name, (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.changeset)().insert(_));\n}\nfunction remove(name, _) {\n  return change.call(this, name, (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.changeset)().remove(_));\n}\n\nfunction width(view) {\n  var padding = view.padding();\n  return Math.max(0, view._viewWidth + padding.left + padding.right);\n}\nfunction height(view) {\n  var padding = view.padding();\n  return Math.max(0, view._viewHeight + padding.top + padding.bottom);\n}\nfunction offset(view) {\n  var padding = view.padding(),\n    origin = view._origin;\n  return [padding.left + origin[0], padding.top + origin[1]];\n}\nfunction resizeRenderer(view) {\n  var origin = offset(view),\n    w = width(view),\n    h = height(view);\n  view._renderer.background(view.background());\n  view._renderer.resize(w, h, origin);\n  view._handler.origin(origin);\n  view._resizeListeners.forEach(handler => {\n    try {\n      handler(w, h);\n    } catch (error) {\n      view.error(error);\n    }\n  });\n}\n\n/**\n * Extend an event with additional view-specific methods.\n * Adds a new property ('vega') to an event that provides a number\n * of methods for querying information about the current interaction.\n * The vega object provides the following methods:\n *   view - Returns the backing View instance.\n *   item - Returns the currently active scenegraph item (if any).\n *   group - Returns the currently active scenegraph group (if any).\n *     This method accepts a single string-typed argument indicating the name\n *     of the desired parent group. The scenegraph will be traversed from\n *     the item up towards the root to search for a matching group. If no\n *     argument is provided the enclosing group for the active item is\n *     returned, unless the item it itself a group, in which case it is\n *     returned directly.\n *   xy - Returns a two-element array containing the x and y coordinates for\n *     mouse or touch events. For touch events, this is based on the first\n *     elements in the changedTouches array. This method accepts a single\n *     argument: either an item instance or mark name that should serve as\n *     the reference coordinate system. If no argument is provided the\n *     top-level view coordinate system is assumed.\n *   x - Returns the current x-coordinate, accepts the same arguments as xy.\n *   y - Returns the current y-coordinate, accepts the same arguments as xy.\n * @param {Event} event - The input event to extend.\n * @param {Item} item - The currently active scenegraph item (if any).\n * @return {Event} - The extended input event.\n */\nfunction eventExtend (view, event, item) {\n  var r = view._renderer,\n    el = r && r.canvas(),\n    p,\n    e,\n    translate;\n  if (el) {\n    translate = offset(view);\n    e = event.changedTouches ? event.changedTouches[0] : event;\n    p = (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.point)(e, el);\n    p[0] -= translate[0];\n    p[1] -= translate[1];\n  }\n  event.dataflow = view;\n  event.item = item;\n  event.vega = extension(view, item, p);\n  return event;\n}\nfunction extension(view, item, point) {\n  const itemGroup = item ? item.mark.marktype === 'group' ? item : item.mark.group : null;\n  function group(name) {\n    var g = itemGroup,\n      i;\n    if (name) for (i = item; i; i = i.mark.group) {\n      if (i.mark.name === name) {\n        g = i;\n        break;\n      }\n    }\n    return g && g.mark && g.mark.interactive ? g : {};\n  }\n  function xy(item) {\n    if (!item) return point;\n    if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isString)(item)) item = group(item);\n    const p = point.slice();\n    while (item) {\n      p[0] -= item.x || 0;\n      p[1] -= item.y || 0;\n      item = item.mark && item.mark.group;\n    }\n    return p;\n  }\n  return {\n    view: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(view),\n    item: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.constant)(item || {}),\n    group: group,\n    xy: xy,\n    x: item => xy(item)[0],\n    y: item => xy(item)[1]\n  };\n}\n\nconst VIEW = 'view',\n  TIMER = 'timer',\n  WINDOW = 'window',\n  NO_TRAP = {\n    trap: false\n  };\n\n/**\n * Initialize event handling configuration.\n * @param {object} config - The configuration settings.\n * @return {object}\n */\nfunction initializeEventConfig(config) {\n  const events = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({\n    defaults: {}\n  }, config);\n  const unpack = (obj, keys) => {\n    keys.forEach(k => {\n      if ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(obj[k])) obj[k] = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet)(obj[k]);\n    });\n  };\n  unpack(events.defaults, ['prevent', 'allow']);\n  unpack(events, ['view', 'window', 'selector']);\n  return events;\n}\nfunction trackEventListener(view, sources, type, handler) {\n  view._eventListeners.push({\n    type: type,\n    sources: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.array)(sources),\n    handler: handler\n  });\n}\nfunction prevent(view, type) {\n  var def = view._eventConfig.defaults,\n    prevent = def.prevent,\n    allow = def.allow;\n  return prevent === false || allow === true ? false : prevent === true || allow === false ? true : prevent ? prevent[type] : allow ? !allow[type] : view.preventDefault();\n}\nfunction permit(view, key, type) {\n  const rule = view._eventConfig && view._eventConfig[key];\n  if (rule === false || (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(rule) && !rule[type]) {\n    view.warn(`Blocked ${key} ${type} event listener.`);\n    return false;\n  }\n  return true;\n}\n\n/**\n * Create a new event stream from an event source.\n * @param {object} source - The event source to monitor.\n * @param {string} type - The event type.\n * @param {function(object): boolean} [filter] - Event filter function.\n * @return {EventStream}\n */\nfunction events(source, type, filter) {\n  var view = this,\n    s = new vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.EventStream(filter),\n    send = function (e, item) {\n      view.runAsync(null, () => {\n        if (source === VIEW && prevent(view, type)) {\n          e.preventDefault();\n        }\n        s.receive(eventExtend(view, e, item));\n      });\n    },\n    sources;\n  if (source === TIMER) {\n    if (permit(view, 'timer', type)) {\n      view.timer(send, type);\n    }\n  } else if (source === VIEW) {\n    if (permit(view, 'view', type)) {\n      // send traps errors, so use {trap: false} option\n      view.addEventListener(type, send, NO_TRAP);\n    }\n  } else {\n    if (source === WINDOW) {\n      if (permit(view, 'window', type) && typeof window !== 'undefined') {\n        sources = [window];\n      }\n    } else if (typeof document !== 'undefined') {\n      if (permit(view, 'selector', type)) {\n        sources = Array.from(document.querySelectorAll(source));\n      }\n    }\n    if (!sources) {\n      view.warn('Can not resolve event source: ' + source);\n    } else {\n      for (var i = 0, n = sources.length; i < n; ++i) {\n        sources[i].addEventListener(type, send);\n      }\n      trackEventListener(view, sources, type, send);\n    }\n  }\n  return s;\n}\n\nfunction itemFilter(event) {\n  return event.item;\n}\nfunction markTarget(event) {\n  // grab upstream collector feeding the mark operator\n  return event.item.mark.source;\n}\nfunction invoke(name) {\n  return function (_, event) {\n    return event.vega.view().changeset().encode(event.item, name);\n  };\n}\nfunction hover (hoverSet, leaveSet) {\n  hoverSet = [hoverSet || 'hover'];\n  leaveSet = [leaveSet || 'update', hoverSet[0]];\n\n  // invoke hover set upon mouseover\n  this.on(this.events('view', 'mouseover', itemFilter), markTarget, invoke(hoverSet));\n\n  // invoke leave set upon mouseout\n  this.on(this.events('view', 'mouseout', itemFilter), markTarget, invoke(leaveSet));\n  return this;\n}\n\n/**\n * Finalize a View instance that is being removed.\n * Cancel any running timers.\n * Remove all external event listeners.\n * Remove any currently displayed tooltip.\n */\nfunction finalize () {\n  var tooltip = this._tooltip,\n    timers = this._timers,\n    listeners = this._eventListeners,\n    n,\n    m,\n    e;\n  n = timers.length;\n  while (--n >= 0) {\n    timers[n].stop();\n  }\n  n = listeners.length;\n  while (--n >= 0) {\n    e = listeners[n];\n    m = e.sources.length;\n    while (--m >= 0) {\n      e.sources[m].removeEventListener(e.type, e.handler);\n    }\n  }\n  if (tooltip) {\n    tooltip.call(this, this._handler, null, null, null);\n  }\n  return this;\n}\n\nfunction element (tag, attr, text) {\n  const el = document.createElement(tag);\n  for (const key in attr) el.setAttribute(key, attr[key]);\n  if (text != null) el.textContent = text;\n  return el;\n}\n\nconst BindClass = 'vega-bind',\n  NameClass = 'vega-bind-name',\n  RadioClass = 'vega-bind-radio';\n\n/**\n * Bind a signal to an external HTML input element. The resulting two-way\n * binding will propagate input changes to signals, and propagate signal\n * changes to the input element state. If this view instance has no parent\n * element, we assume the view is headless and no bindings are created.\n * @param {Element|string} el - The parent DOM element to which the input\n *   element should be appended as a child. If string-valued, this argument\n *   will be treated as a CSS selector. If null or undefined, the parent\n *   element of this view will be used as the element.\n * @param {object} param - The binding parameters which specify the signal\n *   to bind to, the input element type, and type-specific configuration.\n * @return {View} - This view instance.\n */\nfunction bind (view, el, binding) {\n  if (!el) return;\n  const param = binding.param;\n  let bind = binding.state;\n  if (!bind) {\n    bind = binding.state = {\n      elements: null,\n      active: false,\n      set: null,\n      update: value => {\n        if (value != view.signal(param.signal)) {\n          view.runAsync(null, () => {\n            bind.source = true;\n            view.signal(param.signal, value);\n          });\n        }\n      }\n    };\n    if (param.debounce) {\n      bind.update = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.debounce)(param.debounce, bind.update);\n    }\n  }\n  const create = param.input == null && param.element ? target : generate;\n  create(bind, el, param, view);\n  if (!bind.active) {\n    view.on(view._signals[param.signal], null, () => {\n      bind.source ? bind.source = false : bind.set(view.signal(param.signal));\n    });\n    bind.active = true;\n  }\n  return bind;\n}\n\n/**\n * Bind the signal to an external EventTarget.\n */\nfunction target(bind, node, param, view) {\n  const type = param.event || 'input';\n  const handler = () => bind.update(node.value);\n\n  // initialize signal value to external input value\n  view.signal(param.signal, node.value);\n\n  // listen for changes on the element\n  node.addEventListener(type, handler);\n\n  // register with view, so we can remove it upon finalization\n  trackEventListener(view, node, type, handler);\n\n  // propagate change to element\n  bind.set = value => {\n    node.value = value;\n    node.dispatchEvent(event(type));\n  };\n}\nfunction event(type) {\n  return typeof Event !== 'undefined' ? new Event(type) : {\n    type\n  };\n}\n\n/**\n * Generate an HTML input form element and bind it to a signal.\n */\nfunction generate(bind, el, param, view) {\n  const value = view.signal(param.signal);\n  const div = element('div', {\n    'class': BindClass\n  });\n  const wrapper = param.input === 'radio' ? div : div.appendChild(element('label'));\n  wrapper.appendChild(element('span', {\n    'class': NameClass\n  }, param.name || param.signal));\n  el.appendChild(div);\n  let input = form;\n  switch (param.input) {\n    case 'checkbox':\n      input = checkbox;\n      break;\n    case 'select':\n      input = select;\n      break;\n    case 'radio':\n      input = radio;\n      break;\n    case 'range':\n      input = range;\n      break;\n  }\n  input(bind, wrapper, param, value);\n}\n\n/**\n * Generates an arbitrary input form element.\n * The input type is controlled via user-provided parameters.\n */\nfunction form(bind, el, param, value) {\n  const node = element('input');\n  for (const key in param) {\n    if (key !== 'signal' && key !== 'element') {\n      node.setAttribute(key === 'input' ? 'type' : key, param[key]);\n    }\n  }\n  node.setAttribute('name', param.signal);\n  node.value = value;\n  el.appendChild(node);\n  node.addEventListener('input', () => bind.update(node.value));\n  bind.elements = [node];\n  bind.set = value => node.value = value;\n}\n\n/**\n * Generates a checkbox input element.\n */\nfunction checkbox(bind, el, param, value) {\n  const attr = {\n    type: 'checkbox',\n    name: param.signal\n  };\n  if (value) attr.checked = true;\n  const node = element('input', attr);\n  el.appendChild(node);\n  node.addEventListener('change', () => bind.update(node.checked));\n  bind.elements = [node];\n  bind.set = value => node.checked = !!value || null;\n}\n\n/**\n * Generates a selection list input element.\n */\nfunction select(bind, el, param, value) {\n  const node = element('select', {\n      name: param.signal\n    }),\n    labels = param.labels || [];\n  param.options.forEach((option, i) => {\n    const attr = {\n      value: option\n    };\n    if (valuesEqual(option, value)) attr.selected = true;\n    node.appendChild(element('option', attr, (labels[i] || option) + ''));\n  });\n  el.appendChild(node);\n  node.addEventListener('change', () => {\n    bind.update(param.options[node.selectedIndex]);\n  });\n  bind.elements = [node];\n  bind.set = value => {\n    for (let i = 0, n = param.options.length; i < n; ++i) {\n      if (valuesEqual(param.options[i], value)) {\n        node.selectedIndex = i;\n        return;\n      }\n    }\n  };\n}\n\n/**\n * Generates a radio button group.\n */\nfunction radio(bind, el, param, value) {\n  const group = element('span', {\n      'class': RadioClass\n    }),\n    labels = param.labels || [];\n  el.appendChild(group);\n  bind.elements = param.options.map((option, i) => {\n    const attr = {\n      type: 'radio',\n      name: param.signal,\n      value: option\n    };\n    if (valuesEqual(option, value)) attr.checked = true;\n    const input = element('input', attr);\n    input.addEventListener('change', () => bind.update(option));\n    const label = element('label', {}, (labels[i] || option) + '');\n    label.prepend(input);\n    group.appendChild(label);\n    return input;\n  });\n  bind.set = value => {\n    const nodes = bind.elements,\n      n = nodes.length;\n    for (let i = 0; i < n; ++i) {\n      if (valuesEqual(nodes[i].value, value)) nodes[i].checked = true;\n    }\n  };\n}\n\n/**\n * Generates a slider input element.\n */\nfunction range(bind, el, param, value) {\n  value = value !== undefined ? value : (+param.max + +param.min) / 2;\n  const max = param.max != null ? param.max : Math.max(100, +value) || 100,\n    min = param.min || Math.min(0, max, +value) || 0,\n    step = param.step || (0,d3_array__WEBPACK_IMPORTED_MODULE_6__.tickStep)(min, max, 100);\n  const node = element('input', {\n    type: 'range',\n    name: param.signal,\n    min: min,\n    max: max,\n    step: step\n  });\n  node.value = value;\n  const span = element('span', {}, +value);\n  el.appendChild(node);\n  el.appendChild(span);\n  const update = () => {\n    span.textContent = node.value;\n    bind.update(+node.value);\n  };\n\n  // subscribe to both input and change\n  node.addEventListener('input', update);\n  node.addEventListener('change', update);\n  bind.elements = [node];\n  bind.set = value => {\n    node.value = value;\n    span.textContent = value;\n  };\n}\nfunction valuesEqual(a, b) {\n  return a === b || a + '' === b + '';\n}\n\nfunction initializeRenderer (view, r, el, constructor, scaleFactor, opt) {\n  r = r || new constructor(view.loader());\n  return r.initialize(el, width(view), height(view), offset(view), scaleFactor, opt).background(view.background());\n}\n\nfunction trap (view, fn) {\n  return !fn ? null : function () {\n    try {\n      fn.apply(this, arguments);\n    } catch (error) {\n      view.error(error);\n    }\n  };\n}\n\nfunction initializeHandler (view, prevHandler, el, constructor) {\n  // instantiate scenegraph handler\n  const handler = new constructor(view.loader(), trap(view, view.tooltip())).scene(view.scenegraph().root).initialize(el, offset(view), view);\n\n  // transfer event handlers\n  if (prevHandler) {\n    prevHandler.handlers().forEach(h => {\n      handler.on(h.type, h.handler);\n    });\n  }\n  return handler;\n}\n\nfunction initialize (el, elBind) {\n  const view = this,\n    type = view._renderType,\n    config = view._eventConfig.bind,\n    module = (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.renderModule)(type);\n\n  // containing dom element\n  el = view._el = el ? lookup(view, el, true) : null;\n\n  // initialize aria attributes\n  initializeAria(view);\n\n  // select appropriate renderer & handler\n  if (!module) view.error('Unrecognized renderer type: ' + type);\n  const Handler = module.handler || vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.CanvasHandler,\n    Renderer = el ? module.renderer : module.headless;\n\n  // initialize renderer and input handler\n  view._renderer = !Renderer ? null : initializeRenderer(view, view._renderer, el, Renderer);\n  view._handler = initializeHandler(view, view._handler, el, Handler);\n  view._redraw = true;\n\n  // initialize signal bindings\n  if (el && config !== 'none') {\n    elBind = elBind ? view._elBind = lookup(view, elBind, true) : el.appendChild(element('form', {\n      'class': 'vega-bindings'\n    }));\n    view._bind.forEach(_ => {\n      if (_.param.element && config !== 'container') {\n        _.element = lookup(view, _.param.element, !!_.param.input);\n      }\n    });\n    view._bind.forEach(_ => {\n      bind(view, _.element || elBind, _);\n    });\n  }\n  return view;\n}\nfunction lookup(view, el, clear) {\n  if (typeof el === 'string') {\n    if (typeof document !== 'undefined') {\n      el = document.querySelector(el);\n      if (!el) {\n        view.error('Signal bind element not found: ' + el);\n        return null;\n      }\n    } else {\n      view.error('DOM document instance not found.');\n      return null;\n    }\n  }\n  if (el && clear) {\n    try {\n      el.textContent = '';\n    } catch (e) {\n      el = null;\n      view.error(e);\n    }\n  }\n  return el;\n}\n\nconst number = _ => +_ || 0;\nconst paddingObject = _ => ({\n  top: _,\n  bottom: _,\n  left: _,\n  right: _\n});\nfunction padding (_) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(_) ? {\n    top: number(_.top),\n    bottom: number(_.bottom),\n    left: number(_.left),\n    right: number(_.right)\n  } : paddingObject(number(_));\n}\n\n/**\n * Render the current scene in a headless fashion.\n * This method is asynchronous, returning a Promise instance.\n * @return {Promise} - A Promise that resolves to a renderer.\n */\nasync function renderHeadless (view, type, scaleFactor, opt) {\n  const module = (0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.renderModule)(type),\n    ctr = module && module.headless;\n  if (!ctr) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized renderer type: ' + type);\n  await view.runAsync();\n  return initializeRenderer(view, null, null, ctr, scaleFactor, opt).renderAsync(view._scenegraph.root);\n}\n\n/**\n * Produce an image URL for the visualization. Depending on the type\n * parameter, the generated URL contains data for either a PNG or SVG image.\n * The URL can be used (for example) to download images of the visualization.\n * This method is asynchronous, returning a Promise instance.\n * @param {string} type - The image type. One of 'svg', 'png' or 'canvas'.\n *   The 'canvas' and 'png' types are synonyms for a PNG image.\n * @return {Promise} - A promise that resolves to an image URL.\n */\nasync function renderToImageURL (type, scaleFactor) {\n  if (type !== vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.Canvas && type !== vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.SVG && type !== vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.PNG) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized image type: ' + type);\n  }\n  const r = await renderHeadless(this, type, scaleFactor);\n  return type === vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.SVG ? toBlobURL(r.svg(), 'image/svg+xml') : r.canvas().toDataURL('image/png');\n}\nfunction toBlobURL(data, mime) {\n  const blob = new Blob([data], {\n    type: mime\n  });\n  return window.URL.createObjectURL(blob);\n}\n\n/**\n * Produce a Canvas instance containing a rendered visualization.\n * This method is asynchronous, returning a Promise instance.\n * @return {Promise} - A promise that resolves to a Canvas instance.\n */\nasync function renderToCanvas (scaleFactor, opt) {\n  const r = await renderHeadless(this, vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.Canvas, scaleFactor, opt);\n  return r.canvas();\n}\n\n/**\n * Produce a rendered SVG string of the visualization.\n * This method is asynchronous, returning a Promise instance.\n * @return {Promise} - A promise that resolves to an SVG string.\n */\nasync function renderToSVG (scaleFactor) {\n  const r = await renderHeadless(this, vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.SVG, scaleFactor);\n  return r.svg();\n}\n\nfunction runtime (view, spec, expr) {\n  return (0,vega_runtime__WEBPACK_IMPORTED_MODULE_4__.context)(view, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.transforms, vega_functions__WEBPACK_IMPORTED_MODULE_3__.functionContext, expr).parse(spec);\n}\n\nfunction scale(name) {\n  var scales = this._runtime.scales;\n  if (!(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(scales, name)) {\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized scale or projection: ' + name);\n  }\n  return scales[name].value;\n}\n\nvar Width = 'width',\n  Height = 'height',\n  Padding = 'padding',\n  Skip = {\n    skip: true\n  };\nfunction viewWidth(view, width) {\n  var a = view.autosize(),\n    p = view.padding();\n  return width - (a && a.contains === Padding ? p.left + p.right : 0);\n}\nfunction viewHeight(view, height) {\n  var a = view.autosize(),\n    p = view.padding();\n  return height - (a && a.contains === Padding ? p.top + p.bottom : 0);\n}\nfunction initializeResize(view) {\n  var s = view._signals,\n    w = s[Width],\n    h = s[Height],\n    p = s[Padding];\n  function resetSize() {\n    view._autosize = view._resize = 1;\n  }\n\n  // respond to width signal\n  view._resizeWidth = view.add(null, _ => {\n    view._width = _.size;\n    view._viewWidth = viewWidth(view, _.size);\n    resetSize();\n  }, {\n    size: w\n  });\n\n  // respond to height signal\n  view._resizeHeight = view.add(null, _ => {\n    view._height = _.size;\n    view._viewHeight = viewHeight(view, _.size);\n    resetSize();\n  }, {\n    size: h\n  });\n\n  // respond to padding signal\n  const resizePadding = view.add(null, resetSize, {\n    pad: p\n  });\n\n  // set rank to run immediately after source signal\n  view._resizeWidth.rank = w.rank + 1;\n  view._resizeHeight.rank = h.rank + 1;\n  resizePadding.rank = p.rank + 1;\n}\nfunction resizeView(viewWidth, viewHeight, width, height, origin, auto) {\n  this.runAfter(view => {\n    let rerun = 0;\n\n    // reset autosize flag\n    view._autosize = 0;\n\n    // width value changed: update signal, skip resize op\n    if (view.width() !== width) {\n      rerun = 1;\n      view.signal(Width, width, Skip); // set width, skip update calc\n      view._resizeWidth.skip(true); // skip width resize handler\n    }\n\n    // height value changed: update signal, skip resize op\n    if (view.height() !== height) {\n      rerun = 1;\n      view.signal(Height, height, Skip); // set height, skip update calc\n      view._resizeHeight.skip(true); // skip height resize handler\n    }\n\n    // view width changed: update view property, set resize flag\n    if (view._viewWidth !== viewWidth) {\n      view._resize = 1;\n      view._viewWidth = viewWidth;\n    }\n\n    // view height changed: update view property, set resize flag\n    if (view._viewHeight !== viewHeight) {\n      view._resize = 1;\n      view._viewHeight = viewHeight;\n    }\n\n    // origin changed: update view property, set resize flag\n    if (view._origin[0] !== origin[0] || view._origin[1] !== origin[1]) {\n      view._resize = 1;\n      view._origin = origin;\n    }\n\n    // run dataflow on width/height signal change\n    if (rerun) view.run('enter');\n    if (auto) view.runAfter(v => v.resize());\n  }, false, 1);\n}\n\n/**\n * Get the current view state, consisting of signal values and/or data sets.\n * @param {object} [options] - Options flags indicating which state to export.\n *   If unspecified, all signals and data sets will be exported.\n * @param {function(string, Operator):boolean} [options.signals] - Optional\n *   predicate function for testing if a signal should be included in the\n *   exported state. If unspecified, all signals will be included, except for\n *   those named 'parent' or those which refer to a Transform value.\n * @param {function(string, object):boolean} [options.data] - Optional\n *   predicate function for testing if a data set's input should be included\n *   in the exported state. If unspecified, all data sets that have been\n *   explicitly modified will be included.\n * @param {boolean} [options.recurse=true] - Flag indicating if the exported\n *   state should recursively include state from group mark sub-contexts.\n * @return {object} - An object containing the exported state values.\n */\nfunction getState(options) {\n  return this._runtime.getState(options || {\n    data: dataTest,\n    signals: signalTest,\n    recurse: true\n  });\n}\nfunction dataTest(name, data) {\n  return data.modified && (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(data.input.value) && name.indexOf('_:vega:_');\n}\nfunction signalTest(name, op) {\n  return !(name === 'parent' || op instanceof vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.transforms.proxy);\n}\n\n/**\n * Sets the current view state and updates the view by invoking run.\n * @param {object} state - A state object containing signal and/or\n *   data set values, following the format used by the getState method.\n * @return {View} - This view instance.\n */\nfunction setState(state) {\n  this.runAsync(null, v => {\n    v._trigger = false;\n    v._runtime.setState(state);\n  }, v => {\n    v._trigger = true;\n  });\n  return this;\n}\n\nfunction timer (callback, delay) {\n  function tick(elapsed) {\n    callback({\n      timestamp: Date.now(),\n      elapsed: elapsed\n    });\n  }\n  this._timers.push((0,d3_timer__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(tick, delay));\n}\n\nfunction defaultTooltip (handler, event, item, value) {\n  const el = handler.element();\n  if (el) el.setAttribute('title', formatTooltip(value));\n}\nfunction formatTooltip(value) {\n  return value == null ? '' : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) ? formatArray(value) : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate)(value) ? formatObject(value) : value + '';\n}\nfunction formatObject(obj) {\n  return Object.keys(obj).map(key => {\n    const v = obj[key];\n    return key + ': ' + ((0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(v) ? formatArray(v) : formatValue(v));\n  }).join('\\n');\n}\nfunction formatArray(value) {\n  return '[' + value.map(formatValue).join(', ') + ']';\n}\nfunction formatValue(value) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray)(value) ? '[\\u2026]' : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject)(value) && !(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate)(value) ? '{\\u2026}' : value;\n}\n\n/**\n * Create a new View instance from a Vega dataflow runtime specification.\n * The generated View will not immediately be ready for display. Callers\n * should also invoke the initialize method (e.g., to set the parent\n * DOM element in browser-based deployment) and then invoke the run\n * method to evaluate the dataflow graph. Rendering will automatically\n * be performed upon dataflow runs.\n * @constructor\n * @param {object} spec - The Vega dataflow runtime specification.\n */\nfunction View(spec, options) {\n  const view = this;\n  options = options || {};\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Dataflow.call(view);\n  if (options.loader) view.loader(options.loader);\n  if (options.logger) view.logger(options.logger);\n  if (options.logLevel != null) view.logLevel(options.logLevel);\n  if (options.locale || spec.locale) {\n    const loc = (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, spec.locale, options.locale);\n    view.locale((0,vega_format__WEBPACK_IMPORTED_MODULE_5__.locale)(loc.number, loc.time));\n  }\n  view._el = null;\n  view._elBind = null;\n  view._renderType = options.renderer || vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.RenderType.Canvas;\n  view._scenegraph = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.Scenegraph();\n  const root = view._scenegraph.root;\n\n  // initialize renderer, handler and event management\n  view._renderer = null;\n  view._tooltip = options.tooltip || defaultTooltip, view._redraw = true;\n  view._handler = new vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.CanvasHandler().scene(root);\n  view._globalCursor = false;\n  view._preventDefault = false;\n  view._timers = [];\n  view._eventListeners = [];\n  view._resizeListeners = [];\n\n  // initialize event configuration\n  view._eventConfig = initializeEventConfig(spec.eventConfig);\n  view.globalCursor(view._eventConfig.globalCursor);\n\n  // initialize dataflow graph\n  const ctx = runtime(view, spec, options.expr);\n  view._runtime = ctx;\n  view._signals = ctx.signals;\n  view._bind = (spec.bindings || []).map(_ => ({\n    state: null,\n    param: (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)({}, _)\n  }));\n\n  // initialize scenegraph\n  if (ctx.root) ctx.root.set(root);\n  root.source = ctx.data.root.input;\n  view.pulse(ctx.data.root.input, view.changeset().insert(root.items));\n\n  // initialize view size\n  view._width = view.width();\n  view._height = view.height();\n  view._viewWidth = viewWidth(view, view._width);\n  view._viewHeight = viewHeight(view, view._height);\n  view._origin = [0, 0];\n  view._resize = 0;\n  view._autosize = 1;\n  initializeResize(view);\n\n  // initialize background color\n  background(view);\n\n  // initialize cursor\n  cursor(view);\n\n  // initialize view description\n  view.description(spec.description);\n\n  // initialize hover proessing, if requested\n  if (options.hover) view.hover();\n\n  // initialize DOM container(s) and renderer\n  if (options.container) view.initialize(options.container, options.bind);\n}\nfunction lookupSignal(view, name) {\n  return (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(view._signals, name) ? view._signals[name] : (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized signal name: ' + (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue)(name));\n}\nfunction findOperatorHandler(op, handler) {\n  const h = (op._targets || []).filter(op => op._update && op._update.handler === handler);\n  return h.length ? h[0] : null;\n}\nfunction addOperatorListener(view, name, op, handler) {\n  let h = findOperatorHandler(op, handler);\n  if (!h) {\n    h = trap(view, () => handler(name, op.value));\n    h.handler = handler;\n    view.on(op, null, h);\n  }\n  return view;\n}\nfunction removeOperatorListener(view, op, handler) {\n  const h = findOperatorHandler(op, handler);\n  if (h) op._targets.remove(h);\n  return view;\n}\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits)(View, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Dataflow, {\n  // -- DATAFLOW / RENDERING ----\n\n  async evaluate(encode, prerun, postrun) {\n    // evaluate dataflow and prerun\n    await vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Dataflow.prototype.evaluate.call(this, encode, prerun);\n\n    // render as needed\n    if (this._redraw || this._resize) {\n      try {\n        if (this._renderer) {\n          if (this._resize) {\n            this._resize = 0;\n            resizeRenderer(this);\n          }\n          await this._renderer.renderAsync(this._scenegraph.root);\n        }\n        this._redraw = false;\n      } catch (e) {\n        this.error(e);\n      }\n    }\n\n    // evaluate postrun\n    if (postrun) (0,vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.asyncCallback)(this, postrun);\n    return this;\n  },\n  dirty(item) {\n    this._redraw = true;\n    this._renderer && this._renderer.dirty(item);\n  },\n  // -- GET / SET ----\n\n  description(text) {\n    if (arguments.length) {\n      const desc = text != null ? text + '' : null;\n      if (desc !== this._desc) ariaLabel(this._el, this._desc = desc);\n      return this;\n    }\n    return this._desc;\n  },\n  container() {\n    return this._el;\n  },\n  scenegraph() {\n    return this._scenegraph;\n  },\n  origin() {\n    return this._origin.slice();\n  },\n  signal(name, value, options) {\n    const op = lookupSignal(this, name);\n    return arguments.length === 1 ? op.value : this.update(op, value, options);\n  },\n  width(_) {\n    return arguments.length ? this.signal('width', _) : this.signal('width');\n  },\n  height(_) {\n    return arguments.length ? this.signal('height', _) : this.signal('height');\n  },\n  padding(_) {\n    return arguments.length ? this.signal('padding', padding(_)) : padding(this.signal('padding'));\n  },\n  autosize(_) {\n    return arguments.length ? this.signal('autosize', _) : this.signal('autosize');\n  },\n  background(_) {\n    return arguments.length ? this.signal('background', _) : this.signal('background');\n  },\n  renderer(type) {\n    if (!arguments.length) return this._renderType;\n    if (!(0,vega_scenegraph__WEBPACK_IMPORTED_MODULE_2__.renderModule)(type)) (0,vega_util__WEBPACK_IMPORTED_MODULE_0__.error)('Unrecognized renderer type: ' + type);\n    if (type !== this._renderType) {\n      this._renderType = type;\n      this._resetRenderer();\n    }\n    return this;\n  },\n  tooltip(handler) {\n    if (!arguments.length) return this._tooltip;\n    if (handler !== this._tooltip) {\n      this._tooltip = handler;\n      this._resetRenderer();\n    }\n    return this;\n  },\n  loader(loader) {\n    if (!arguments.length) return this._loader;\n    if (loader !== this._loader) {\n      vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Dataflow.prototype.loader.call(this, loader);\n      this._resetRenderer();\n    }\n    return this;\n  },\n  resize() {\n    // set flag to perform autosize\n    this._autosize = 1;\n    // touch autosize signal to ensure top-level ViewLayout runs\n    return this.touch(lookupSignal(this, 'autosize'));\n  },\n  _resetRenderer() {\n    if (this._renderer) {\n      this._renderer = null;\n      this.initialize(this._el, this._elBind);\n    }\n  },\n  // -- SIZING ----\n  _resizeView: resizeView,\n  // -- EVENT HANDLING ----\n\n  addEventListener(type, handler, options) {\n    let callback = handler;\n    if (!(options && options.trap === false)) {\n      // wrap callback in error handler\n      callback = trap(this, handler);\n      callback.raw = handler;\n    }\n    this._handler.on(type, callback);\n    return this;\n  },\n  removeEventListener(type, handler) {\n    var handlers = this._handler.handlers(type),\n      i = handlers.length,\n      h,\n      t;\n\n    // search registered handlers, remove if match found\n    while (--i >= 0) {\n      t = handlers[i].type;\n      h = handlers[i].handler;\n      if (type === t && (handler === h || handler === h.raw)) {\n        this._handler.off(t, h);\n        break;\n      }\n    }\n    return this;\n  },\n  addResizeListener(handler) {\n    const l = this._resizeListeners;\n    if (l.indexOf(handler) < 0) {\n      // add handler if it isn't already registered\n      // note: error trapping handled elsewhere, so\n      // no need to wrap handlers here\n      l.push(handler);\n    }\n    return this;\n  },\n  removeResizeListener(handler) {\n    var l = this._resizeListeners,\n      i = l.indexOf(handler);\n    if (i >= 0) {\n      l.splice(i, 1);\n    }\n    return this;\n  },\n  addSignalListener(name, handler) {\n    return addOperatorListener(this, name, lookupSignal(this, name), handler);\n  },\n  removeSignalListener(name, handler) {\n    return removeOperatorListener(this, lookupSignal(this, name), handler);\n  },\n  addDataListener(name, handler) {\n    return addOperatorListener(this, name, dataref(this, name).values, handler);\n  },\n  removeDataListener(name, handler) {\n    return removeOperatorListener(this, dataref(this, name).values, handler);\n  },\n  globalCursor(_) {\n    if (arguments.length) {\n      if (this._globalCursor !== !!_) {\n        const prev = setCursor(this, null); // clear previous cursor\n        this._globalCursor = !!_;\n        if (prev) setCursor(this, prev); // swap cursor\n      }\n\n      return this;\n    } else {\n      return this._globalCursor;\n    }\n  },\n  preventDefault(_) {\n    if (arguments.length) {\n      this._preventDefault = _;\n      return this;\n    } else {\n      return this._preventDefault;\n    }\n  },\n  timer,\n  events,\n  finalize,\n  hover,\n  // -- DATA ----\n  data,\n  change,\n  insert,\n  remove,\n  // -- SCALES --\n  scale,\n  // -- INITIALIZATION ----\n  initialize,\n  // -- HEADLESS RENDERING ----\n  toImageURL: renderToImageURL,\n  toCanvas: renderToCanvas,\n  toSVG: renderToSVG,\n  // -- SAVE / RESTORE STATE ----\n  getState,\n  setState\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-view/build/vega-view.module.js?");

/***/ }),

/***/ "../../node_modules/vega-voronoi/build/vega-voronoi.module.js":
/*!********************************************************************!*\
  !*** ../../node_modules/vega-voronoi/build/vega-voronoi.module.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   voronoi: () => (/* binding */ Voronoi)\n/* harmony export */ });\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var d3_delaunay__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-delaunay */ \"../../node_modules/d3-delaunay/src/delaunay.js\");\n\n\n\n\nfunction Voronoi(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform.call(this, null, params);\n}\nVoronoi.Definition = {\n  'type': 'Voronoi',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'x',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'y',\n    'type': 'field',\n    'required': true\n  }, {\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'extent',\n    'type': 'array',\n    'array': true,\n    'length': 2,\n    'default': [[-1e5, -1e5], [1e5, 1e5]],\n    'content': {\n      'type': 'number',\n      'array': true,\n      'length': 2\n    }\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'default': 'path'\n  }]\n};\nconst defaultExtent = [-1e5, -1e5, 1e5, 1e5];\n(0,vega_util__WEBPACK_IMPORTED_MODULE_1__.inherits)(Voronoi, vega_dataflow__WEBPACK_IMPORTED_MODULE_0__.Transform, {\n  transform(_, pulse) {\n    const as = _.as || 'path',\n      data = pulse.source;\n\n    // nothing to do if no data\n    if (!data || !data.length) return pulse;\n\n    // configure and construct voronoi diagram\n    let s = _.size;\n    s = s ? [0, 0, s[0], s[1]] : (s = _.extent) ? [s[0][0], s[0][1], s[1][0], s[1][1]] : defaultExtent;\n    const voronoi = this.value = d3_delaunay__WEBPACK_IMPORTED_MODULE_2__[\"default\"].from(data, _.x, _.y).voronoi(s);\n\n    // map polygons to paths\n    for (let i = 0, n = data.length; i < n; ++i) {\n      const polygon = voronoi.cellPolygon(i);\n      data[i][as] = polygon ? toPathString(polygon) : null;\n    }\n    return pulse.reflow(_.modified()).modifies(as);\n  }\n});\n\n// suppress duplicated end point vertices\nfunction toPathString(p) {\n  const x = p[0][0],\n    y = p[0][1];\n  let n = p.length - 1;\n  for (; p[n][0] === x && p[n][1] === y; --n);\n  return 'M' + p.slice(0, n + 1).join('L') + 'Z';\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-voronoi/build/vega-voronoi.module.js?");

/***/ }),

/***/ "../../node_modules/vega-wordcloud/build/vega-wordcloud.module.js":
/*!************************************************************************!*\
  !*** ../../node_modules/vega-wordcloud/build/vega-wordcloud.module.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   wordcloud: () => (/* binding */ Wordcloud)\n/* harmony export */ });\n/* harmony import */ var vega_canvas__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-canvas */ \"../../node_modules/vega-canvas/build/vega-canvas.browser.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n\n\n\n\n\n\n/*\nCopyright (c) 2013, Jason Davies.\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n  * Redistributions of source code must retain the above copyright notice, this\n    list of conditions and the following disclaimer.\n\n  * Redistributions in binary form must reproduce the above copyright notice,\n    this list of conditions and the following disclaimer in the documentation\n    and/or other materials provided with the distribution.\n\n  * The name Jason Davies may not be used to endorse or promote products\n    derived from this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\" AND\nANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED\nWARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL JASON DAVIES BE LIABLE FOR ANY DIRECT, INDIRECT,\nINCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT\nLIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\nPROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\nLIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE\nOR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF\nADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n*/\n\n// Word cloud layout by Jason Davies, https://www.jasondavies.com/wordcloud/\n// Algorithm due to Jonathan Feinberg, http://static.mrfeinberg.com/bv_ch03.pdf\n\nvar cloudRadians = Math.PI / 180,\n  cw = 1 << 11 >> 5,\n  ch = 1 << 11;\nfunction cloud () {\n  var size = [256, 256],\n    text,\n    font,\n    fontSize,\n    fontStyle,\n    fontWeight,\n    rotate,\n    padding,\n    spiral = archimedeanSpiral,\n    words = [],\n    random = Math.random,\n    cloud = {};\n  cloud.layout = function () {\n    var contextAndRatio = getContext((0,vega_canvas__WEBPACK_IMPORTED_MODULE_0__.canvas)()),\n      board = zeroArray((size[0] >> 5) * size[1]),\n      bounds = null,\n      n = words.length,\n      i = -1,\n      tags = [],\n      data = words.map(d => ({\n        text: text(d),\n        font: font(d),\n        style: fontStyle(d),\n        weight: fontWeight(d),\n        rotate: rotate(d),\n        size: ~~(fontSize(d) + 1e-14),\n        padding: padding(d),\n        xoff: 0,\n        yoff: 0,\n        x1: 0,\n        y1: 0,\n        x0: 0,\n        y0: 0,\n        hasText: false,\n        sprite: null,\n        datum: d\n      })).sort((a, b) => b.size - a.size);\n    while (++i < n) {\n      var d = data[i];\n      d.x = size[0] * (random() + .5) >> 1;\n      d.y = size[1] * (random() + .5) >> 1;\n      cloudSprite(contextAndRatio, d, data, i);\n      if (d.hasText && place(board, d, bounds)) {\n        tags.push(d);\n        if (bounds) cloudBounds(bounds, d);else bounds = [{\n          x: d.x + d.x0,\n          y: d.y + d.y0\n        }, {\n          x: d.x + d.x1,\n          y: d.y + d.y1\n        }];\n        // Temporary hack\n        d.x -= size[0] >> 1;\n        d.y -= size[1] >> 1;\n      }\n    }\n    return tags;\n  };\n  function getContext(canvas) {\n    canvas.width = canvas.height = 1;\n    var ratio = Math.sqrt(canvas.getContext('2d').getImageData(0, 0, 1, 1).data.length >> 2);\n    canvas.width = (cw << 5) / ratio;\n    canvas.height = ch / ratio;\n    var context = canvas.getContext('2d');\n    context.fillStyle = context.strokeStyle = 'red';\n    context.textAlign = 'center';\n    return {\n      context: context,\n      ratio: ratio\n    };\n  }\n  function place(board, tag, bounds) {\n    var startX = tag.x,\n      startY = tag.y,\n      maxDelta = Math.sqrt(size[0] * size[0] + size[1] * size[1]),\n      s = spiral(size),\n      dt = random() < .5 ? 1 : -1,\n      t = -dt,\n      dxdy,\n      dx,\n      dy;\n    while (dxdy = s(t += dt)) {\n      dx = ~~dxdy[0];\n      dy = ~~dxdy[1];\n      if (Math.min(Math.abs(dx), Math.abs(dy)) >= maxDelta) break;\n      tag.x = startX + dx;\n      tag.y = startY + dy;\n      if (tag.x + tag.x0 < 0 || tag.y + tag.y0 < 0 || tag.x + tag.x1 > size[0] || tag.y + tag.y1 > size[1]) continue;\n      // TODO only check for collisions within current bounds.\n      if (!bounds || !cloudCollide(tag, board, size[0])) {\n        if (!bounds || collideRects(tag, bounds)) {\n          var sprite = tag.sprite,\n            w = tag.width >> 5,\n            sw = size[0] >> 5,\n            lx = tag.x - (w << 4),\n            sx = lx & 0x7f,\n            msx = 32 - sx,\n            h = tag.y1 - tag.y0,\n            x = (tag.y + tag.y0) * sw + (lx >> 5),\n            last;\n          for (var j = 0; j < h; j++) {\n            last = 0;\n            for (var i = 0; i <= w; i++) {\n              board[x + i] |= last << msx | (i < w ? (last = sprite[j * w + i]) >>> sx : 0);\n            }\n            x += sw;\n          }\n          tag.sprite = null;\n          return true;\n        }\n      }\n    }\n    return false;\n  }\n  cloud.words = function (_) {\n    if (arguments.length) {\n      words = _;\n      return cloud;\n    } else {\n      return words;\n    }\n  };\n  cloud.size = function (_) {\n    if (arguments.length) {\n      size = [+_[0], +_[1]];\n      return cloud;\n    } else {\n      return size;\n    }\n  };\n  cloud.font = function (_) {\n    if (arguments.length) {\n      font = functor(_);\n      return cloud;\n    } else {\n      return font;\n    }\n  };\n  cloud.fontStyle = function (_) {\n    if (arguments.length) {\n      fontStyle = functor(_);\n      return cloud;\n    } else {\n      return fontStyle;\n    }\n  };\n  cloud.fontWeight = function (_) {\n    if (arguments.length) {\n      fontWeight = functor(_);\n      return cloud;\n    } else {\n      return fontWeight;\n    }\n  };\n  cloud.rotate = function (_) {\n    if (arguments.length) {\n      rotate = functor(_);\n      return cloud;\n    } else {\n      return rotate;\n    }\n  };\n  cloud.text = function (_) {\n    if (arguments.length) {\n      text = functor(_);\n      return cloud;\n    } else {\n      return text;\n    }\n  };\n  cloud.spiral = function (_) {\n    if (arguments.length) {\n      spiral = spirals[_] || _;\n      return cloud;\n    } else {\n      return spiral;\n    }\n  };\n  cloud.fontSize = function (_) {\n    if (arguments.length) {\n      fontSize = functor(_);\n      return cloud;\n    } else {\n      return fontSize;\n    }\n  };\n  cloud.padding = function (_) {\n    if (arguments.length) {\n      padding = functor(_);\n      return cloud;\n    } else {\n      return padding;\n    }\n  };\n  cloud.random = function (_) {\n    if (arguments.length) {\n      random = _;\n      return cloud;\n    } else {\n      return random;\n    }\n  };\n  return cloud;\n}\n\n// Fetches a monochrome sprite bitmap for the specified text.\n// Load in batches for speed.\nfunction cloudSprite(contextAndRatio, d, data, di) {\n  if (d.sprite) return;\n  var c = contextAndRatio.context,\n    ratio = contextAndRatio.ratio;\n  c.clearRect(0, 0, (cw << 5) / ratio, ch / ratio);\n  var x = 0,\n    y = 0,\n    maxh = 0,\n    n = data.length,\n    w,\n    w32,\n    h,\n    i,\n    j;\n  --di;\n  while (++di < n) {\n    d = data[di];\n    c.save();\n    c.font = d.style + ' ' + d.weight + ' ' + ~~((d.size + 1) / ratio) + 'px ' + d.font;\n    w = c.measureText(d.text + 'm').width * ratio;\n    h = d.size << 1;\n    if (d.rotate) {\n      var sr = Math.sin(d.rotate * cloudRadians),\n        cr = Math.cos(d.rotate * cloudRadians),\n        wcr = w * cr,\n        wsr = w * sr,\n        hcr = h * cr,\n        hsr = h * sr;\n      w = Math.max(Math.abs(wcr + hsr), Math.abs(wcr - hsr)) + 0x1f >> 5 << 5;\n      h = ~~Math.max(Math.abs(wsr + hcr), Math.abs(wsr - hcr));\n    } else {\n      w = w + 0x1f >> 5 << 5;\n    }\n    if (h > maxh) maxh = h;\n    if (x + w >= cw << 5) {\n      x = 0;\n      y += maxh;\n      maxh = 0;\n    }\n    if (y + h >= ch) break;\n    c.translate((x + (w >> 1)) / ratio, (y + (h >> 1)) / ratio);\n    if (d.rotate) c.rotate(d.rotate * cloudRadians);\n    c.fillText(d.text, 0, 0);\n    if (d.padding) {\n      c.lineWidth = 2 * d.padding;\n      c.strokeText(d.text, 0, 0);\n    }\n    c.restore();\n    d.width = w;\n    d.height = h;\n    d.xoff = x;\n    d.yoff = y;\n    d.x1 = w >> 1;\n    d.y1 = h >> 1;\n    d.x0 = -d.x1;\n    d.y0 = -d.y1;\n    d.hasText = true;\n    x += w;\n  }\n  var pixels = c.getImageData(0, 0, (cw << 5) / ratio, ch / ratio).data,\n    sprite = [];\n  while (--di >= 0) {\n    d = data[di];\n    if (!d.hasText) continue;\n    w = d.width;\n    w32 = w >> 5;\n    h = d.y1 - d.y0;\n    // Zero the buffer\n    for (i = 0; i < h * w32; i++) sprite[i] = 0;\n    x = d.xoff;\n    if (x == null) return;\n    y = d.yoff;\n    var seen = 0,\n      seenRow = -1;\n    for (j = 0; j < h; j++) {\n      for (i = 0; i < w; i++) {\n        var k = w32 * j + (i >> 5),\n          m = pixels[(y + j) * (cw << 5) + (x + i) << 2] ? 1 << 31 - i % 32 : 0;\n        sprite[k] |= m;\n        seen |= m;\n      }\n      if (seen) seenRow = j;else {\n        d.y0++;\n        h--;\n        j--;\n        y++;\n      }\n    }\n    d.y1 = d.y0 + seenRow;\n    d.sprite = sprite.slice(0, (d.y1 - d.y0) * w32);\n  }\n}\n\n// Use mask-based collision detection.\nfunction cloudCollide(tag, board, sw) {\n  sw >>= 5;\n  var sprite = tag.sprite,\n    w = tag.width >> 5,\n    lx = tag.x - (w << 4),\n    sx = lx & 0x7f,\n    msx = 32 - sx,\n    h = tag.y1 - tag.y0,\n    x = (tag.y + tag.y0) * sw + (lx >> 5),\n    last;\n  for (var j = 0; j < h; j++) {\n    last = 0;\n    for (var i = 0; i <= w; i++) {\n      if ((last << msx | (i < w ? (last = sprite[j * w + i]) >>> sx : 0)) & board[x + i]) return true;\n    }\n    x += sw;\n  }\n  return false;\n}\nfunction cloudBounds(bounds, d) {\n  var b0 = bounds[0],\n    b1 = bounds[1];\n  if (d.x + d.x0 < b0.x) b0.x = d.x + d.x0;\n  if (d.y + d.y0 < b0.y) b0.y = d.y + d.y0;\n  if (d.x + d.x1 > b1.x) b1.x = d.x + d.x1;\n  if (d.y + d.y1 > b1.y) b1.y = d.y + d.y1;\n}\nfunction collideRects(a, b) {\n  return a.x + a.x1 > b[0].x && a.x + a.x0 < b[1].x && a.y + a.y1 > b[0].y && a.y + a.y0 < b[1].y;\n}\nfunction archimedeanSpiral(size) {\n  var e = size[0] / size[1];\n  return function (t) {\n    return [e * (t *= .1) * Math.cos(t), t * Math.sin(t)];\n  };\n}\nfunction rectangularSpiral(size) {\n  var dy = 4,\n    dx = dy * size[0] / size[1],\n    x = 0,\n    y = 0;\n  return function (t) {\n    var sign = t < 0 ? -1 : 1;\n    // See triangular numbers: T_n = n * (n + 1) / 2.\n    switch (Math.sqrt(1 + 4 * sign * t) - sign & 3) {\n      case 0:\n        x += dx;\n        break;\n      case 1:\n        y += dy;\n        break;\n      case 2:\n        x -= dx;\n        break;\n      default:\n        y -= dy;\n        break;\n    }\n    return [x, y];\n  };\n}\n\n// TODO reuse arrays?\nfunction zeroArray(n) {\n  var a = [],\n    i = -1;\n  while (++i < n) a[i] = 0;\n  return a;\n}\nfunction functor(d) {\n  return typeof d === 'function' ? d : function () {\n    return d;\n  };\n}\nvar spirals = {\n  archimedean: archimedeanSpiral,\n  rectangular: rectangularSpiral\n};\n\nconst Output = ['x', 'y', 'font', 'fontSize', 'fontStyle', 'fontWeight', 'angle'];\nconst Params = ['text', 'font', 'rotate', 'fontSize', 'fontStyle', 'fontWeight'];\nfunction Wordcloud(params) {\n  vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform.call(this, cloud(), params);\n}\nWordcloud.Definition = {\n  'type': 'Wordcloud',\n  'metadata': {\n    'modifies': true\n  },\n  'params': [{\n    'name': 'size',\n    'type': 'number',\n    'array': true,\n    'length': 2\n  }, {\n    'name': 'font',\n    'type': 'string',\n    'expr': true,\n    'default': 'sans-serif'\n  }, {\n    'name': 'fontStyle',\n    'type': 'string',\n    'expr': true,\n    'default': 'normal'\n  }, {\n    'name': 'fontWeight',\n    'type': 'string',\n    'expr': true,\n    'default': 'normal'\n  }, {\n    'name': 'fontSize',\n    'type': 'number',\n    'expr': true,\n    'default': 14\n  }, {\n    'name': 'fontSizeRange',\n    'type': 'number',\n    'array': 'nullable',\n    'default': [10, 50]\n  }, {\n    'name': 'rotate',\n    'type': 'number',\n    'expr': true,\n    'default': 0\n  }, {\n    'name': 'text',\n    'type': 'field'\n  }, {\n    'name': 'spiral',\n    'type': 'string',\n    'values': ['archimedean', 'rectangular']\n  }, {\n    'name': 'padding',\n    'type': 'number',\n    'expr': true\n  }, {\n    'name': 'as',\n    'type': 'string',\n    'array': true,\n    'length': 7,\n    'default': Output\n  }]\n};\n(0,vega_util__WEBPACK_IMPORTED_MODULE_2__.inherits)(Wordcloud, vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform, {\n  transform(_, pulse) {\n    if (_.size && !(_.size[0] && _.size[1])) {\n      (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.error)('Wordcloud size dimensions must be non-zero.');\n    }\n    function modp(param) {\n      const p = _[param];\n      return (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(p) && pulse.modified(p.fields);\n    }\n    const mod = _.modified();\n    if (!(mod || pulse.changed(pulse.ADD_REM) || Params.some(modp))) return;\n    const data = pulse.materialize(pulse.SOURCE).source,\n      layout = this.value,\n      as = _.as || Output;\n    let fontSize = _.fontSize || 14,\n      range;\n    (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.isFunction)(fontSize) ? range = _.fontSizeRange : fontSize = (0,vega_util__WEBPACK_IMPORTED_MODULE_2__.constant)(fontSize);\n\n    // create font size scaling function as needed\n    if (range) {\n      const fsize = fontSize,\n        sizeScale = (0,vega_scale__WEBPACK_IMPORTED_MODULE_3__.scale)('sqrt')().domain((0,vega_util__WEBPACK_IMPORTED_MODULE_2__.extent)(data, fsize)).range(range);\n      fontSize = x => sizeScale(fsize(x));\n    }\n    data.forEach(t => {\n      t[as[0]] = NaN;\n      t[as[1]] = NaN;\n      t[as[3]] = 0;\n    });\n\n    // configure layout\n    const words = layout.words(data).text(_.text).size(_.size || [500, 500]).padding(_.padding || 1).spiral(_.spiral || 'archimedean').rotate(_.rotate || 0).font(_.font || 'sans-serif').fontStyle(_.fontStyle || 'normal').fontWeight(_.fontWeight || 'normal').fontSize(fontSize).random(vega_statistics__WEBPACK_IMPORTED_MODULE_4__.random).layout();\n    const size = layout.size(),\n      dx = size[0] >> 1,\n      dy = size[1] >> 1,\n      n = words.length;\n    for (let i = 0, w, t; i < n; ++i) {\n      w = words[i];\n      t = w.datum;\n      t[as[0]] = w.x + dx;\n      t[as[1]] = w.y + dy;\n      t[as[2]] = w.font;\n      t[as[3]] = w.size;\n      t[as[4]] = w.style;\n      t[as[5]] = w.weight;\n      t[as[6]] = w.rotate;\n    }\n    return pulse.reflow(mod).modifies(as);\n  }\n});\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-wordcloud/build/vega-wordcloud.module.js?");

/***/ }),

/***/ "../../node_modules/vega/build/vega.module.js":
/*!****************************************************!*\
  !*** ../../node_modules/vega/build/vega.module.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Bounds: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Bounds),\n/* harmony export */   CanvasHandler: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.CanvasHandler),\n/* harmony export */   CanvasRenderer: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.CanvasRenderer),\n/* harmony export */   DATE: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.DATE),\n/* harmony export */   DAY: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.DAY),\n/* harmony export */   DAYOFYEAR: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.DAYOFYEAR),\n/* harmony export */   Dataflow: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Dataflow),\n/* harmony export */   Debug: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.Debug),\n/* harmony export */   Error: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.Error),\n/* harmony export */   EventStream: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.EventStream),\n/* harmony export */   Gradient: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Gradient),\n/* harmony export */   GroupItem: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.GroupItem),\n/* harmony export */   HOURS: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.HOURS),\n/* harmony export */   Handler: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Handler),\n/* harmony export */   Info: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.Info),\n/* harmony export */   Item: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Item),\n/* harmony export */   MILLISECONDS: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.MILLISECONDS),\n/* harmony export */   MINUTES: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.MINUTES),\n/* harmony export */   MONTH: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.MONTH),\n/* harmony export */   Marks: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Marks),\n/* harmony export */   MultiPulse: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.MultiPulse),\n/* harmony export */   None: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.None),\n/* harmony export */   Operator: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Operator),\n/* harmony export */   Parameters: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Parameters),\n/* harmony export */   Pulse: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Pulse),\n/* harmony export */   QUARTER: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.QUARTER),\n/* harmony export */   RenderType: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.RenderType),\n/* harmony export */   Renderer: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Renderer),\n/* harmony export */   ResourceLoader: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.ResourceLoader),\n/* harmony export */   SECONDS: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.SECONDS),\n/* harmony export */   SVGHandler: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.SVGHandler),\n/* harmony export */   SVGRenderer: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.SVGRenderer),\n/* harmony export */   SVGStringRenderer: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.SVGStringRenderer),\n/* harmony export */   Scenegraph: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.Scenegraph),\n/* harmony export */   TIME_UNITS: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.TIME_UNITS),\n/* harmony export */   Transform: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.Transform),\n/* harmony export */   View: () => (/* reexport safe */ vega_view__WEBPACK_IMPORTED_MODULE_19__.View),\n/* harmony export */   WEEK: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.WEEK),\n/* harmony export */   Warn: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.Warn),\n/* harmony export */   YEAR: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.YEAR),\n/* harmony export */   accessor: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.accessor),\n/* harmony export */   accessorFields: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorFields),\n/* harmony export */   accessorName: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.accessorName),\n/* harmony export */   array: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.array),\n/* harmony export */   ascending: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.ascending),\n/* harmony export */   bandwidthNRD: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.bandwidthNRD),\n/* harmony export */   bin: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.bin),\n/* harmony export */   bootstrapCI: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.bootstrapCI),\n/* harmony export */   boundClip: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.boundClip),\n/* harmony export */   boundContext: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.boundContext),\n/* harmony export */   boundItem: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.boundItem),\n/* harmony export */   boundMark: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.boundMark),\n/* harmony export */   boundStroke: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.boundStroke),\n/* harmony export */   changeset: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.changeset),\n/* harmony export */   clampRange: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.clampRange),\n/* harmony export */   codegenExpression: () => (/* reexport safe */ vega_expression__WEBPACK_IMPORTED_MODULE_24__.codegenExpression),\n/* harmony export */   compare: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.compare),\n/* harmony export */   constant: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.constant),\n/* harmony export */   cumulativeLogNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.cumulativeLogNormal),\n/* harmony export */   cumulativeNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.cumulativeNormal),\n/* harmony export */   cumulativeUniform: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.cumulativeUniform),\n/* harmony export */   dayofyear: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.dayofyear),\n/* harmony export */   debounce: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.debounce),\n/* harmony export */   defaultLocale: () => (/* reexport safe */ vega_format__WEBPACK_IMPORTED_MODULE_20__.defaultLocale),\n/* harmony export */   definition: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.definition),\n/* harmony export */   densityLogNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.densityLogNormal),\n/* harmony export */   densityNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.densityNormal),\n/* harmony export */   densityUniform: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.densityUniform),\n/* harmony export */   domChild: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.domChild),\n/* harmony export */   domClear: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.domClear),\n/* harmony export */   domCreate: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.domCreate),\n/* harmony export */   domFind: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.domFind),\n/* harmony export */   dotbin: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.dotbin),\n/* harmony export */   error: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.error),\n/* harmony export */   expressionFunction: () => (/* reexport safe */ vega_functions__WEBPACK_IMPORTED_MODULE_21__.expressionFunction),\n/* harmony export */   extend: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.extend),\n/* harmony export */   extent: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.extent),\n/* harmony export */   extentIndex: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.extentIndex),\n/* harmony export */   falsy: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.falsy),\n/* harmony export */   fastmap: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.fastmap),\n/* harmony export */   field: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.field),\n/* harmony export */   flush: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.flush),\n/* harmony export */   font: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.font),\n/* harmony export */   fontFamily: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.fontFamily),\n/* harmony export */   fontSize: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.fontSize),\n/* harmony export */   format: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.format),\n/* harmony export */   formatLocale: () => (/* reexport safe */ vega_format__WEBPACK_IMPORTED_MODULE_20__.numberFormatDefaultLocale),\n/* harmony export */   formats: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.formats),\n/* harmony export */   hasOwnProperty: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty),\n/* harmony export */   id: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.id),\n/* harmony export */   identity: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.identity),\n/* harmony export */   inferType: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.inferType),\n/* harmony export */   inferTypes: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.inferTypes),\n/* harmony export */   ingest: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.ingest),\n/* harmony export */   inherits: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.inherits),\n/* harmony export */   inrange: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.inrange),\n/* harmony export */   interpolate: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.interpolate),\n/* harmony export */   interpolateColors: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.interpolateColors),\n/* harmony export */   interpolateRange: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.interpolateRange),\n/* harmony export */   intersect: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.intersect),\n/* harmony export */   intersectBoxLine: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.intersectBoxLine),\n/* harmony export */   intersectPath: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.intersectPath),\n/* harmony export */   intersectPoint: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.intersectPoint),\n/* harmony export */   intersectRule: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.intersectRule),\n/* harmony export */   isArray: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isArray),\n/* harmony export */   isBoolean: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isBoolean),\n/* harmony export */   isDate: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isDate),\n/* harmony export */   isFunction: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isFunction),\n/* harmony export */   isIterable: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isIterable),\n/* harmony export */   isNumber: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isNumber),\n/* harmony export */   isObject: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isObject),\n/* harmony export */   isRegExp: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isRegExp),\n/* harmony export */   isString: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.isString),\n/* harmony export */   isTuple: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.isTuple),\n/* harmony export */   key: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.key),\n/* harmony export */   lerp: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.lerp),\n/* harmony export */   lineHeight: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.lineHeight),\n/* harmony export */   loader: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.loader),\n/* harmony export */   locale: () => (/* reexport safe */ vega_format__WEBPACK_IMPORTED_MODULE_20__.locale),\n/* harmony export */   logger: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.logger),\n/* harmony export */   lruCache: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.lruCache),\n/* harmony export */   markup: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.markup),\n/* harmony export */   merge: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.merge),\n/* harmony export */   mergeConfig: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.mergeConfig),\n/* harmony export */   multiLineOffset: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.multiLineOffset),\n/* harmony export */   one: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.one),\n/* harmony export */   pad: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.pad),\n/* harmony export */   panLinear: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.panLinear),\n/* harmony export */   panLog: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.panLog),\n/* harmony export */   panPow: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.panPow),\n/* harmony export */   panSymlog: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.panSymlog),\n/* harmony export */   parse: () => (/* reexport safe */ vega_parser__WEBPACK_IMPORTED_MODULE_22__.parse),\n/* harmony export */   parseExpression: () => (/* reexport safe */ vega_expression__WEBPACK_IMPORTED_MODULE_24__.parseExpression),\n/* harmony export */   parseSelector: () => (/* reexport safe */ vega_event_selector__WEBPACK_IMPORTED_MODULE_25__.parseSelector),\n/* harmony export */   path: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.path),\n/* harmony export */   pathCurves: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathCurves),\n/* harmony export */   pathEqual: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathEqual),\n/* harmony export */   pathParse: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathParse),\n/* harmony export */   pathRectangle: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathRectangle),\n/* harmony export */   pathRender: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathRender),\n/* harmony export */   pathSymbols: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathSymbols),\n/* harmony export */   pathTrail: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.pathTrail),\n/* harmony export */   peek: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.peek),\n/* harmony export */   point: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.point),\n/* harmony export */   projection: () => (/* reexport safe */ vega_projection__WEBPACK_IMPORTED_MODULE_18__.projection),\n/* harmony export */   quantileLogNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.quantileLogNormal),\n/* harmony export */   quantileNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.quantileNormal),\n/* harmony export */   quantileUniform: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.quantileUniform),\n/* harmony export */   quantiles: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.quantiles),\n/* harmony export */   quantizeInterpolator: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.quantizeInterpolator),\n/* harmony export */   quarter: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.quarter),\n/* harmony export */   quartiles: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.quartiles),\n/* harmony export */   random: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.random),\n/* harmony export */   randomInteger: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomInteger),\n/* harmony export */   randomKDE: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomKDE),\n/* harmony export */   randomLCG: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomLCG),\n/* harmony export */   randomLogNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomLogNormal),\n/* harmony export */   randomMixture: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomMixture),\n/* harmony export */   randomNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomNormal),\n/* harmony export */   randomUniform: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.randomUniform),\n/* harmony export */   read: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.read),\n/* harmony export */   regressionConstant: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionConstant),\n/* harmony export */   regressionExp: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionExp),\n/* harmony export */   regressionLinear: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionLinear),\n/* harmony export */   regressionLoess: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionLoess),\n/* harmony export */   regressionLog: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionLog),\n/* harmony export */   regressionPoly: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionPoly),\n/* harmony export */   regressionPow: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionPow),\n/* harmony export */   regressionQuad: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.regressionQuad),\n/* harmony export */   renderModule: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.renderModule),\n/* harmony export */   repeat: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.repeat),\n/* harmony export */   resetDefaultLocale: () => (/* reexport safe */ vega_format__WEBPACK_IMPORTED_MODULE_20__.resetDefaultLocale),\n/* harmony export */   resetSVGClipId: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.resetSVGClipId),\n/* harmony export */   resetSVGDefIds: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.resetSVGDefIds),\n/* harmony export */   responseType: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.responseType),\n/* harmony export */   runtimeContext: () => (/* reexport safe */ vega_runtime__WEBPACK_IMPORTED_MODULE_23__.context),\n/* harmony export */   sampleCurve: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.sampleCurve),\n/* harmony export */   sampleLogNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.sampleLogNormal),\n/* harmony export */   sampleNormal: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.sampleNormal),\n/* harmony export */   sampleUniform: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.sampleUniform),\n/* harmony export */   scale: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.scale),\n/* harmony export */   sceneEqual: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.sceneEqual),\n/* harmony export */   sceneFromJSON: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.sceneFromJSON),\n/* harmony export */   scenePickVisit: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.scenePickVisit),\n/* harmony export */   sceneToJSON: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.sceneToJSON),\n/* harmony export */   sceneVisit: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.sceneVisit),\n/* harmony export */   sceneZOrder: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.sceneZOrder),\n/* harmony export */   scheme: () => (/* reexport safe */ vega_scale__WEBPACK_IMPORTED_MODULE_17__.scheme),\n/* harmony export */   serializeXML: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.serializeXML),\n/* harmony export */   setRandom: () => (/* reexport safe */ vega_statistics__WEBPACK_IMPORTED_MODULE_13__.setRandom),\n/* harmony export */   span: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.span),\n/* harmony export */   splitAccessPath: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.splitAccessPath),\n/* harmony export */   stringValue: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.stringValue),\n/* harmony export */   textMetrics: () => (/* reexport safe */ vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__.textMetrics),\n/* harmony export */   timeBin: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeBin),\n/* harmony export */   timeFloor: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeFloor),\n/* harmony export */   timeFormatLocale: () => (/* reexport safe */ vega_format__WEBPACK_IMPORTED_MODULE_20__.timeFormatDefaultLocale),\n/* harmony export */   timeInterval: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeInterval),\n/* harmony export */   timeOffset: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeOffset),\n/* harmony export */   timeSequence: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeSequence),\n/* harmony export */   timeUnitSpecifier: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeUnitSpecifier),\n/* harmony export */   timeUnits: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.timeUnits),\n/* harmony export */   toBoolean: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.toBoolean),\n/* harmony export */   toDate: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.toDate),\n/* harmony export */   toNumber: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.toNumber),\n/* harmony export */   toSet: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.toSet),\n/* harmony export */   toString: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.toString),\n/* harmony export */   transform: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.transform),\n/* harmony export */   transforms: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.transforms),\n/* harmony export */   truncate: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.truncate),\n/* harmony export */   truthy: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.truthy),\n/* harmony export */   tupleid: () => (/* reexport safe */ vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.tupleid),\n/* harmony export */   typeParsers: () => (/* reexport safe */ vega_loader__WEBPACK_IMPORTED_MODULE_15__.typeParsers),\n/* harmony export */   utcFloor: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcFloor),\n/* harmony export */   utcInterval: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcInterval),\n/* harmony export */   utcOffset: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcOffset),\n/* harmony export */   utcSequence: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcSequence),\n/* harmony export */   utcdayofyear: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcdayofyear),\n/* harmony export */   utcquarter: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.utcquarter),\n/* harmony export */   utcweek: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.utcweek),\n/* harmony export */   version: () => (/* binding */ version),\n/* harmony export */   visitArray: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.visitArray),\n/* harmony export */   week: () => (/* reexport safe */ vega_time__WEBPACK_IMPORTED_MODULE_14__.week),\n/* harmony export */   writeConfig: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.writeConfig),\n/* harmony export */   zero: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.zero),\n/* harmony export */   zoomLinear: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomLinear),\n/* harmony export */   zoomLog: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomLog),\n/* harmony export */   zoomPow: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomPow),\n/* harmony export */   zoomSymlog: () => (/* reexport safe */ vega_util__WEBPACK_IMPORTED_MODULE_0__.zoomSymlog)\n/* harmony export */ });\n/* harmony import */ var vega_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-util */ \"../../node_modules/vega-util/build/vega-util.module.js\");\n/* harmony import */ var vega_dataflow__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vega-dataflow */ \"../../node_modules/vega-dataflow/build/vega-dataflow.module.js\");\n/* harmony import */ var vega_transforms__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vega-transforms */ \"../../node_modules/vega-transforms/build/vega-transforms.module.js\");\n/* harmony import */ var vega_view_transforms__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vega-view-transforms */ \"../../node_modules/vega-view-transforms/build/vega-view-transforms.module.js\");\n/* harmony import */ var vega_encode__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vega-encode */ \"../../node_modules/vega-encode/build/vega-encode.module.js\");\n/* harmony import */ var vega_geo__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! vega-geo */ \"../../node_modules/vega-geo/build/vega-geo.module.js\");\n/* harmony import */ var vega_force__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! vega-force */ \"../../node_modules/vega-force/build/vega-force.module.js\");\n/* harmony import */ var vega_hierarchy__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! vega-hierarchy */ \"../../node_modules/vega-hierarchy/build/vega-hierarchy.module.js\");\n/* harmony import */ var vega_label__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! vega-label */ \"../../node_modules/vega-label/build/vega-label.module.js\");\n/* harmony import */ var vega_regression__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! vega-regression */ \"../../node_modules/vega-regression/build/vega-regression.module.js\");\n/* harmony import */ var vega_voronoi__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! vega-voronoi */ \"../../node_modules/vega-voronoi/build/vega-voronoi.module.js\");\n/* harmony import */ var vega_wordcloud__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! vega-wordcloud */ \"../../node_modules/vega-wordcloud/build/vega-wordcloud.module.js\");\n/* harmony import */ var vega_crossfilter__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! vega-crossfilter */ \"../../node_modules/vega-crossfilter/build/vega-crossfilter.module.js\");\n/* harmony import */ var vega_statistics__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! vega-statistics */ \"../../node_modules/vega-statistics/build/vega-statistics.module.js\");\n/* harmony import */ var vega_time__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! vega-time */ \"../../node_modules/vega-time/build/vega-time.module.js\");\n/* harmony import */ var vega_loader__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! vega-loader */ \"../../node_modules/vega-loader/build/vega-loader.browser.module.js\");\n/* harmony import */ var vega_scenegraph__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! vega-scenegraph */ \"../../node_modules/vega-scenegraph/build/vega-scenegraph.module.js\");\n/* harmony import */ var vega_scale__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! vega-scale */ \"../../node_modules/vega-scale/build/vega-scale.module.js\");\n/* harmony import */ var vega_projection__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! vega-projection */ \"../../node_modules/vega-projection/build/vega-projection.module.js\");\n/* harmony import */ var vega_view__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! vega-view */ \"../../node_modules/vega-view/build/vega-view.module.js\");\n/* harmony import */ var vega_format__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! vega-format */ \"../../node_modules/vega-format/build/vega-format.module.js\");\n/* harmony import */ var vega_functions__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! vega-functions */ \"../../node_modules/vega-functions/build/vega-functions.module.js\");\n/* harmony import */ var vega_parser__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! vega-parser */ \"../../node_modules/vega-parser/build/vega-parser.module.js\");\n/* harmony import */ var vega_runtime__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! vega-runtime */ \"../../node_modules/vega-runtime/build/vega-runtime.module.js\");\n/* harmony import */ var vega_expression__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! vega-expression */ \"../../node_modules/vega-expression/build/vega-expression.module.js\");\n/* harmony import */ var vega_event_selector__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! vega-event-selector */ \"../../node_modules/vega-event-selector/build/vega-event-selector.module.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nvar version = \"5.25.0\";\n\n// -- Transforms -----\n(0,vega_util__WEBPACK_IMPORTED_MODULE_0__.extend)(vega_dataflow__WEBPACK_IMPORTED_MODULE_1__.transforms, vega_transforms__WEBPACK_IMPORTED_MODULE_2__, vega_view_transforms__WEBPACK_IMPORTED_MODULE_3__, vega_encode__WEBPACK_IMPORTED_MODULE_4__, vega_geo__WEBPACK_IMPORTED_MODULE_5__, vega_force__WEBPACK_IMPORTED_MODULE_6__, vega_label__WEBPACK_IMPORTED_MODULE_8__, vega_hierarchy__WEBPACK_IMPORTED_MODULE_7__, vega_regression__WEBPACK_IMPORTED_MODULE_9__, vega_voronoi__WEBPACK_IMPORTED_MODULE_10__, vega_wordcloud__WEBPACK_IMPORTED_MODULE_11__, vega_crossfilter__WEBPACK_IMPORTED_MODULE_12__);\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega/build/vega.module.js?");

/***/ }),

/***/ "../../node_modules/wavesurfer.js/dist/wavesurfer.js":
/*!***********************************************************!*\
  !*** ../../node_modules/wavesurfer.js/dist/wavesurfer.js ***!
  \***********************************************************/
/***/ ((module) => {

eval("/*!\n * wavesurfer.js 5.2.0 (2021-08-16)\n * https://wavesurfer-js.org\n * @license BSD-3-Clause\n */\n(function webpackUniversalModuleDefinition(root, factory) {\n\tif(true)\n\t\tmodule.exports = factory();\n\telse {}\n})(self, function() {\nreturn /******/ (() => { // webpackBootstrap\n/******/ \tvar __webpack_modules__ = ({\n\n/***/ \"./src/drawer.canvasentry.js\":\n/*!***********************************!*\\\n  !*** ./src/drawer.canvasentry.js ***!\n  \\***********************************/\n/***/ ((module, exports, __nested_webpack_require_747__) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar _style = _interopRequireDefault(__nested_webpack_require_747__(/*! ./util/style */ \"./src/util/style.js\"));\n\nvar _getId = _interopRequireDefault(__nested_webpack_require_747__(/*! ./util/get-id */ \"./src/util/get-id.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\n/**\n * The `CanvasEntry` class represents an element consisting of a wave `canvas`\n * and an (optional) progress wave `canvas`.\n *\n * The `MultiCanvas` renderer uses one or more `CanvasEntry` instances to\n * render a waveform, depending on the zoom level.\n */\nvar CanvasEntry = /*#__PURE__*/function () {\n  function CanvasEntry() {\n    _classCallCheck(this, CanvasEntry);\n\n    /**\n     * The wave node\n     *\n     * @type {HTMLCanvasElement}\n     */\n    this.wave = null;\n    /**\n     * The wave canvas rendering context\n     *\n     * @type {CanvasRenderingContext2D}\n     */\n\n    this.waveCtx = null;\n    /**\n     * The (optional) progress wave node\n     *\n     * @type {HTMLCanvasElement}\n     */\n\n    this.progress = null;\n    /**\n     * The (optional) progress wave canvas rendering context\n     *\n     * @type {CanvasRenderingContext2D}\n     */\n\n    this.progressCtx = null;\n    /**\n     * Start of the area the canvas should render, between 0 and 1\n     *\n     * @type {number}\n     */\n\n    this.start = 0;\n    /**\n     * End of the area the canvas should render, between 0 and 1\n     *\n     * @type {number}\n     */\n\n    this.end = 1;\n    /**\n     * Unique identifier for this entry\n     *\n     * @type {string}\n     */\n\n    this.id = (0, _getId.default)(typeof this.constructor.name !== 'undefined' ? this.constructor.name.toLowerCase() + '_' : 'canvasentry_');\n    /**\n     * Canvas 2d context attributes\n     *\n     * @type {object}\n     */\n\n    this.canvasContextAttributes = {};\n  }\n  /**\n   * Store the wave canvas element and create the 2D rendering context\n   *\n   * @param {HTMLCanvasElement} element The wave `canvas` element.\n   */\n\n\n  _createClass(CanvasEntry, [{\n    key: \"initWave\",\n    value: function initWave(element) {\n      this.wave = element;\n      this.waveCtx = this.wave.getContext('2d', this.canvasContextAttributes);\n    }\n    /**\n     * Store the progress wave canvas element and create the 2D rendering\n     * context\n     *\n     * @param {HTMLCanvasElement} element The progress wave `canvas` element.\n     */\n\n  }, {\n    key: \"initProgress\",\n    value: function initProgress(element) {\n      this.progress = element;\n      this.progressCtx = this.progress.getContext('2d', this.canvasContextAttributes);\n    }\n    /**\n     * Update the dimensions\n     *\n     * @param {number} elementWidth Width of the entry\n     * @param {number} totalWidth Total width of the multi canvas renderer\n     * @param {number} width The new width of the element\n     * @param {number} height The new height of the element\n     */\n\n  }, {\n    key: \"updateDimensions\",\n    value: function updateDimensions(elementWidth, totalWidth, width, height) {\n      // where the canvas starts and ends in the waveform, represented as a\n      // decimal between 0 and 1\n      this.start = this.wave.offsetLeft / totalWidth || 0;\n      this.end = this.start + elementWidth / totalWidth; // set wave canvas dimensions\n\n      this.wave.width = width;\n      this.wave.height = height;\n      var elementSize = {\n        width: elementWidth + 'px'\n      };\n      (0, _style.default)(this.wave, elementSize);\n\n      if (this.hasProgressCanvas) {\n        // set progress canvas dimensions\n        this.progress.width = width;\n        this.progress.height = height;\n        (0, _style.default)(this.progress, elementSize);\n      }\n    }\n    /**\n     * Clear the wave and progress rendering contexts\n     */\n\n  }, {\n    key: \"clearWave\",\n    value: function clearWave() {\n      // wave\n      this.waveCtx.clearRect(0, 0, this.waveCtx.canvas.width, this.waveCtx.canvas.height); // progress\n\n      if (this.hasProgressCanvas) {\n        this.progressCtx.clearRect(0, 0, this.progressCtx.canvas.width, this.progressCtx.canvas.height);\n      }\n    }\n    /**\n     * Set the fill styles for wave and progress\n     *\n     * @param {string} waveColor Fill color for the wave canvas\n     * @param {?string} progressColor Fill color for the progress canvas\n     */\n\n  }, {\n    key: \"setFillStyles\",\n    value: function setFillStyles(waveColor, progressColor) {\n      this.waveCtx.fillStyle = waveColor;\n\n      if (this.hasProgressCanvas) {\n        this.progressCtx.fillStyle = progressColor;\n      }\n    }\n    /**\n     * Set the canvas transforms for wave and progress\n     *\n     * @param {boolean} vertical Whether to render vertically\n     */\n\n  }, {\n    key: \"applyCanvasTransforms\",\n    value: function applyCanvasTransforms(vertical) {\n      if (vertical) {\n        // Reflect the waveform across the line y = -x\n        this.waveCtx.setTransform(0, 1, 1, 0, 0, 0);\n\n        if (this.hasProgressCanvas) {\n          this.progressCtx.setTransform(0, 1, 1, 0, 0, 0);\n        }\n      }\n    }\n    /**\n     * Draw a rectangle for wave and progress\n     *\n     * @param {number} x X start position\n     * @param {number} y Y start position\n     * @param {number} width Width of the rectangle\n     * @param {number} height Height of the rectangle\n     * @param {number} radius Radius of the rectangle\n     */\n\n  }, {\n    key: \"fillRects\",\n    value: function fillRects(x, y, width, height, radius) {\n      this.fillRectToContext(this.waveCtx, x, y, width, height, radius);\n\n      if (this.hasProgressCanvas) {\n        this.fillRectToContext(this.progressCtx, x, y, width, height, radius);\n      }\n    }\n    /**\n     * Draw the actual rectangle on a `canvas` element\n     *\n     * @param {CanvasRenderingContext2D} ctx Rendering context of target canvas\n     * @param {number} x X start position\n     * @param {number} y Y start position\n     * @param {number} width Width of the rectangle\n     * @param {number} height Height of the rectangle\n     * @param {number} radius Radius of the rectangle\n     */\n\n  }, {\n    key: \"fillRectToContext\",\n    value: function fillRectToContext(ctx, x, y, width, height, radius) {\n      if (!ctx) {\n        return;\n      }\n\n      if (radius) {\n        this.drawRoundedRect(ctx, x, y, width, height, radius);\n      } else {\n        ctx.fillRect(x, y, width, height);\n      }\n    }\n    /**\n     * Draw a rounded rectangle on Canvas\n     *\n     * @param {CanvasRenderingContext2D} ctx Canvas context\n     * @param {number} x X-position of the rectangle\n     * @param {number} y Y-position of the rectangle\n     * @param {number} width Width of the rectangle\n     * @param {number} height Height of the rectangle\n     * @param {number} radius Radius of the rectangle\n     *\n     * @return {void}\n     * @example drawRoundedRect(ctx, 50, 50, 5, 10, 3)\n     */\n\n  }, {\n    key: \"drawRoundedRect\",\n    value: function drawRoundedRect(ctx, x, y, width, height, radius) {\n      if (height === 0) {\n        return;\n      } // peaks are float values from -1 to 1. Use absolute height values in\n      // order to correctly calculate rounded rectangle coordinates\n\n\n      if (height < 0) {\n        height *= -1;\n        y -= height;\n      }\n\n      ctx.beginPath();\n      ctx.moveTo(x + radius, y);\n      ctx.lineTo(x + width - radius, y);\n      ctx.quadraticCurveTo(x + width, y, x + width, y + radius);\n      ctx.lineTo(x + width, y + height - radius);\n      ctx.quadraticCurveTo(x + width, y + height, x + width - radius, y + height);\n      ctx.lineTo(x + radius, y + height);\n      ctx.quadraticCurveTo(x, y + height, x, y + height - radius);\n      ctx.lineTo(x, y + radius);\n      ctx.quadraticCurveTo(x, y, x + radius, y);\n      ctx.closePath();\n      ctx.fill();\n    }\n    /**\n     * Render the actual wave and progress lines\n     *\n     * @param {number[]} peaks Array with peaks data\n     * @param {number} absmax Maximum peak value (absolute)\n     * @param {number} halfH Half the height of the waveform\n     * @param {number} offsetY Offset to the top\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that\n     * should be rendered\n     */\n\n  }, {\n    key: \"drawLines\",\n    value: function drawLines(peaks, absmax, halfH, offsetY, start, end) {\n      this.drawLineToContext(this.waveCtx, peaks, absmax, halfH, offsetY, start, end);\n\n      if (this.hasProgressCanvas) {\n        this.drawLineToContext(this.progressCtx, peaks, absmax, halfH, offsetY, start, end);\n      }\n    }\n    /**\n     * Render the actual waveform line on a `canvas` element\n     *\n     * @param {CanvasRenderingContext2D} ctx Rendering context of target canvas\n     * @param {number[]} peaks Array with peaks data\n     * @param {number} absmax Maximum peak value (absolute)\n     * @param {number} halfH Half the height of the waveform\n     * @param {number} offsetY Offset to the top\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that\n     * should be rendered\n     */\n\n  }, {\n    key: \"drawLineToContext\",\n    value: function drawLineToContext(ctx, peaks, absmax, halfH, offsetY, start, end) {\n      if (!ctx) {\n        return;\n      }\n\n      var length = peaks.length / 2;\n      var first = Math.round(length * this.start); // use one more peak value to make sure we join peaks at ends -- unless,\n      // of course, this is the last canvas\n\n      var last = Math.round(length * this.end) + 1;\n      var canvasStart = first;\n      var canvasEnd = last;\n      var scale = this.wave.width / (canvasEnd - canvasStart - 1); // optimization\n\n      var halfOffset = halfH + offsetY;\n      var absmaxHalf = absmax / halfH;\n      ctx.beginPath();\n      ctx.moveTo((canvasStart - first) * scale, halfOffset);\n      ctx.lineTo((canvasStart - first) * scale, halfOffset - Math.round((peaks[2 * canvasStart] || 0) / absmaxHalf));\n      var i, peak, h;\n\n      for (i = canvasStart; i < canvasEnd; i++) {\n        peak = peaks[2 * i] || 0;\n        h = Math.round(peak / absmaxHalf);\n        ctx.lineTo((i - first) * scale + this.halfPixel, halfOffset - h);\n      } // draw the bottom edge going backwards, to make a single\n      // closed hull to fill\n\n\n      var j = canvasEnd - 1;\n\n      for (j; j >= canvasStart; j--) {\n        peak = peaks[2 * j + 1] || 0;\n        h = Math.round(peak / absmaxHalf);\n        ctx.lineTo((j - first) * scale + this.halfPixel, halfOffset - h);\n      }\n\n      ctx.lineTo((canvasStart - first) * scale, halfOffset - Math.round((peaks[2 * canvasStart + 1] || 0) / absmaxHalf));\n      ctx.closePath();\n      ctx.fill();\n    }\n    /**\n     * Destroys this entry\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      this.waveCtx = null;\n      this.wave = null;\n      this.progressCtx = null;\n      this.progress = null;\n    }\n    /**\n     * Return image data of the wave `canvas` element\n     *\n     * When using a `type` of `'blob'`, this will return a `Promise` that\n     * resolves with a `Blob` instance.\n     *\n     * @param {string} format='image/png' An optional value of a format type.\n     * @param {number} quality=0.92 An optional value between 0 and 1.\n     * @param {string} type='dataURL' Either 'dataURL' or 'blob'.\n     * @return {string|Promise} When using the default `'dataURL'` `type` this\n     * returns a data URL. When using the `'blob'` `type` this returns a\n     * `Promise` that resolves with a `Blob` instance.\n     */\n\n  }, {\n    key: \"getImage\",\n    value: function getImage(format, quality, type) {\n      var _this = this;\n\n      if (type === 'blob') {\n        return new Promise(function (resolve) {\n          _this.wave.toBlob(resolve, format, quality);\n        });\n      } else if (type === 'dataURL') {\n        return this.wave.toDataURL(format, quality);\n      }\n    }\n  }]);\n\n  return CanvasEntry;\n}();\n\nexports.default = CanvasEntry;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/drawer.js\":\n/*!***********************!*\\\n  !*** ./src/drawer.js ***!\n  \\***********************/\n/***/ ((module, exports, __nested_webpack_require_13686__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar util = _interopRequireWildcard(__nested_webpack_require_13686__(/*! ./util */ \"./src/util/index.js\"));\n\nfunction _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== \"function\") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }\n\nfunction _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== \"default\" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n/**\n * Parent class for renderers\n *\n * @extends {Observer}\n */\nvar Drawer = /*#__PURE__*/function (_util$Observer) {\n  _inherits(Drawer, _util$Observer);\n\n  var _super = _createSuper(Drawer);\n\n  /**\n   * @param {HTMLElement} container The container node of the wavesurfer instance\n   * @param {WavesurferParams} params The wavesurfer initialisation options\n   */\n  function Drawer(container, params) {\n    var _this;\n\n    _classCallCheck(this, Drawer);\n\n    _this = _super.call(this);\n    _this.container = util.withOrientation(container, params.vertical);\n    /**\n     * @type {WavesurferParams}\n     */\n\n    _this.params = params;\n    /**\n     * The width of the renderer\n     * @type {number}\n     */\n\n    _this.width = 0;\n    /**\n     * The height of the renderer\n     * @type {number}\n     */\n\n    _this.height = params.height * _this.params.pixelRatio;\n    _this.lastPos = 0;\n    /**\n     * The `<wave>` element which is added to the container\n     * @type {HTMLElement}\n     */\n\n    _this.wrapper = null;\n    return _this;\n  }\n  /**\n   * Alias of `util.style`\n   *\n   * @param {HTMLElement} el The element that the styles will be applied to\n   * @param {Object} styles The map of propName: attribute, both are used as-is\n   * @return {HTMLElement} el\n   */\n\n\n  _createClass(Drawer, [{\n    key: \"style\",\n    value: function style(el, styles) {\n      return util.style(el, styles);\n    }\n    /**\n     * Create the wrapper `<wave>` element, style it and set up the events for\n     * interaction\n     */\n\n  }, {\n    key: \"createWrapper\",\n    value: function createWrapper() {\n      this.wrapper = util.withOrientation(this.container.appendChild(document.createElement('wave')), this.params.vertical);\n      this.style(this.wrapper, {\n        display: 'block',\n        position: 'relative',\n        userSelect: 'none',\n        webkitUserSelect: 'none',\n        height: this.params.height + 'px'\n      });\n\n      if (this.params.fillParent || this.params.scrollParent) {\n        this.style(this.wrapper, {\n          width: '100%',\n          overflowX: this.params.hideScrollbar ? 'hidden' : 'auto',\n          overflowY: 'hidden'\n        });\n      }\n\n      this.setupWrapperEvents();\n    }\n    /**\n     * Handle click event\n     *\n     * @param {Event} e Click event\n     * @param {?boolean} noPrevent Set to true to not call `e.preventDefault()`\n     * @return {number} Playback position from 0 to 1\n     */\n\n  }, {\n    key: \"handleEvent\",\n    value: function handleEvent(e, noPrevent) {\n      !noPrevent && e.preventDefault();\n      var clientX = util.withOrientation(e.targetTouches ? e.targetTouches[0] : e, this.params.vertical).clientX;\n      var bbox = this.wrapper.getBoundingClientRect();\n      var nominalWidth = this.width;\n      var parentWidth = this.getWidth();\n      var progressPixels = this.getProgressPixels(bbox, clientX);\n      var progress;\n\n      if (!this.params.fillParent && nominalWidth < parentWidth) {\n        progress = progressPixels * (this.params.pixelRatio / nominalWidth) || 0;\n      } else {\n        progress = (progressPixels + this.wrapper.scrollLeft) / this.wrapper.scrollWidth || 0;\n      }\n\n      return util.clamp(progress, 0, 1);\n    }\n  }, {\n    key: \"getProgressPixels\",\n    value: function getProgressPixels(wrapperBbox, clientX) {\n      if (this.params.rtl) {\n        return wrapperBbox.right - clientX;\n      } else {\n        return clientX - wrapperBbox.left;\n      }\n    }\n  }, {\n    key: \"setupWrapperEvents\",\n    value: function setupWrapperEvents() {\n      var _this2 = this;\n\n      this.wrapper.addEventListener('click', function (e) {\n        var orientedEvent = util.withOrientation(e, _this2.params.vertical);\n        var scrollbarHeight = _this2.wrapper.offsetHeight - _this2.wrapper.clientHeight;\n\n        if (scrollbarHeight !== 0) {\n          // scrollbar is visible.  Check if click was on it\n          var bbox = _this2.wrapper.getBoundingClientRect();\n\n          if (orientedEvent.clientY >= bbox.bottom - scrollbarHeight) {\n            // ignore mousedown as it was on the scrollbar\n            return;\n          }\n        }\n\n        if (_this2.params.interact) {\n          _this2.fireEvent('click', e, _this2.handleEvent(e));\n        }\n      });\n      this.wrapper.addEventListener('dblclick', function (e) {\n        if (_this2.params.interact) {\n          _this2.fireEvent('dblclick', e, _this2.handleEvent(e));\n        }\n      });\n      this.wrapper.addEventListener('scroll', function (e) {\n        return _this2.fireEvent('scroll', e);\n      });\n    }\n    /**\n     * Draw peaks on the canvas\n     *\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays\n     * for split channel rendering\n     * @param {number} length The width of the area that should be drawn\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that should be\n     * rendered\n     */\n\n  }, {\n    key: \"drawPeaks\",\n    value: function drawPeaks(peaks, length, start, end) {\n      if (!this.setWidth(length)) {\n        this.clearWave();\n      }\n\n      this.params.barWidth ? this.drawBars(peaks, 0, start, end) : this.drawWave(peaks, 0, start, end);\n    }\n    /**\n     * Scroll to the beginning\n     */\n\n  }, {\n    key: \"resetScroll\",\n    value: function resetScroll() {\n      if (this.wrapper !== null) {\n        this.wrapper.scrollLeft = 0;\n      }\n    }\n    /**\n     * Recenter the view-port at a certain percent of the waveform\n     *\n     * @param {number} percent Value from 0 to 1 on the waveform\n     */\n\n  }, {\n    key: \"recenter\",\n    value: function recenter(percent) {\n      var position = this.wrapper.scrollWidth * percent;\n      this.recenterOnPosition(position, true);\n    }\n    /**\n     * Recenter the view-port on a position, either scroll there immediately or\n     * in steps of 5 pixels\n     *\n     * @param {number} position X-offset in pixels\n     * @param {boolean} immediate Set to true to immediately scroll somewhere\n     */\n\n  }, {\n    key: \"recenterOnPosition\",\n    value: function recenterOnPosition(position, immediate) {\n      var scrollLeft = this.wrapper.scrollLeft;\n      var half = ~~(this.wrapper.clientWidth / 2);\n      var maxScroll = this.wrapper.scrollWidth - this.wrapper.clientWidth;\n      var target = position - half;\n      var offset = target - scrollLeft;\n\n      if (maxScroll == 0) {\n        // no need to continue if scrollbar is not there\n        return;\n      } // if the cursor is currently visible...\n\n\n      if (!immediate && -half <= offset && offset < half) {\n        // set rate at which waveform is centered\n        var rate = this.params.autoCenterRate; // make rate depend on width of view and length of waveform\n\n        rate /= half;\n        rate *= maxScroll;\n        offset = Math.max(-rate, Math.min(rate, offset));\n        target = scrollLeft + offset;\n      } // limit target to valid range (0 to maxScroll)\n\n\n      target = Math.max(0, Math.min(maxScroll, target)); // no use attempting to scroll if we're not moving\n\n      if (target != scrollLeft) {\n        this.wrapper.scrollLeft = target;\n      }\n    }\n    /**\n     * Get the current scroll position in pixels\n     *\n     * @return {number} Horizontal scroll position in pixels\n     */\n\n  }, {\n    key: \"getScrollX\",\n    value: function getScrollX() {\n      var x = 0;\n\n      if (this.wrapper) {\n        var pixelRatio = this.params.pixelRatio;\n        x = Math.round(this.wrapper.scrollLeft * pixelRatio); // In cases of elastic scroll (safari with mouse wheel) you can\n        // scroll beyond the limits of the container\n        // Calculate and floor the scrollable extent to make sure an out\n        // of bounds value is not returned\n        // Ticket #1312\n\n        if (this.params.scrollParent) {\n          var maxScroll = ~~(this.wrapper.scrollWidth * pixelRatio - this.getWidth());\n          x = Math.min(maxScroll, Math.max(0, x));\n        }\n      }\n\n      return x;\n    }\n    /**\n     * Get the width of the container\n     *\n     * @return {number} The width of the container\n     */\n\n  }, {\n    key: \"getWidth\",\n    value: function getWidth() {\n      return Math.round(this.container.clientWidth * this.params.pixelRatio);\n    }\n    /**\n     * Set the width of the container\n     *\n     * @param {number} width The new width of the container\n     * @return {boolean} Whether the width of the container was updated or not\n     */\n\n  }, {\n    key: \"setWidth\",\n    value: function setWidth(width) {\n      if (this.width == width) {\n        return false;\n      }\n\n      this.width = width;\n\n      if (this.params.fillParent || this.params.scrollParent) {\n        this.style(this.wrapper, {\n          width: ''\n        });\n      } else {\n        var newWidth = ~~(this.width / this.params.pixelRatio) + 'px';\n        this.style(this.wrapper, {\n          width: newWidth\n        });\n      }\n\n      this.updateSize();\n      return true;\n    }\n    /**\n     * Set the height of the container\n     *\n     * @param {number} height The new height of the container.\n     * @return {boolean} Whether the height of the container was updated or not\n     */\n\n  }, {\n    key: \"setHeight\",\n    value: function setHeight(height) {\n      if (height == this.height) {\n        return false;\n      }\n\n      this.height = height;\n      this.style(this.wrapper, {\n        height: ~~(this.height / this.params.pixelRatio) + 'px'\n      });\n      this.updateSize();\n      return true;\n    }\n    /**\n     * Called by wavesurfer when progress should be rendered\n     *\n     * @param {number} progress From 0 to 1\n     */\n\n  }, {\n    key: \"progress\",\n    value: function progress(_progress) {\n      var minPxDelta = 1 / this.params.pixelRatio;\n      var pos = Math.round(_progress * this.width) * minPxDelta;\n\n      if (pos < this.lastPos || pos - this.lastPos >= minPxDelta) {\n        this.lastPos = pos;\n\n        if (this.params.scrollParent && this.params.autoCenter) {\n          var newPos = ~~(this.wrapper.scrollWidth * _progress);\n          this.recenterOnPosition(newPos, this.params.autoCenterImmediately);\n        }\n\n        this.updateProgress(pos);\n      }\n    }\n    /**\n     * This is called when wavesurfer is destroyed\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      this.unAll();\n\n      if (this.wrapper) {\n        if (this.wrapper.parentNode == this.container.domElement) {\n          this.container.removeChild(this.wrapper.domElement);\n        }\n\n        this.wrapper = null;\n      }\n    }\n    /* Renderer-specific methods */\n\n    /**\n     * Called after cursor related params have changed.\n     *\n     * @abstract\n     */\n\n  }, {\n    key: \"updateCursor\",\n    value: function updateCursor() {}\n    /**\n     * Called when the size of the container changes so the renderer can adjust\n     *\n     * @abstract\n     */\n\n  }, {\n    key: \"updateSize\",\n    value: function updateSize() {}\n    /**\n     * Draw a waveform with bars\n     *\n     * @abstract\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays for split channel\n     * rendering\n     * @param {number} channelIndex The index of the current channel. Normally\n     * should be 0\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that should be\n     * rendered\n     */\n\n  }, {\n    key: \"drawBars\",\n    value: function drawBars(peaks, channelIndex, start, end) {}\n    /**\n     * Draw a waveform\n     *\n     * @abstract\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays for split channel\n     * rendering\n     * @param {number} channelIndex The index of the current channel. Normally\n     * should be 0\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that should be\n     * rendered\n     */\n\n  }, {\n    key: \"drawWave\",\n    value: function drawWave(peaks, channelIndex, start, end) {}\n    /**\n     * Clear the waveform\n     *\n     * @abstract\n     */\n\n  }, {\n    key: \"clearWave\",\n    value: function clearWave() {}\n    /**\n     * Render the new progress\n     *\n     * @abstract\n     * @param {number} position X-Offset of progress position in pixels\n     */\n\n  }, {\n    key: \"updateProgress\",\n    value: function updateProgress(position) {}\n  }]);\n\n  return Drawer;\n}(util.Observer);\n\nexports.default = Drawer;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/drawer.multicanvas.js\":\n/*!***********************************!*\\\n  !*** ./src/drawer.multicanvas.js ***!\n  \\***********************************/\n/***/ ((module, exports, __nested_webpack_require_30815__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar _drawer = _interopRequireDefault(__nested_webpack_require_30815__(/*! ./drawer */ \"./src/drawer.js\"));\n\nvar util = _interopRequireWildcard(__nested_webpack_require_30815__(/*! ./util */ \"./src/util/index.js\"));\n\nvar _drawer2 = _interopRequireDefault(__nested_webpack_require_30815__(/*! ./drawer.canvasentry */ \"./src/drawer.canvasentry.js\"));\n\nfunction _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== \"function\") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }\n\nfunction _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== \"default\" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n/**\n * MultiCanvas renderer for wavesurfer. Is currently the default and sole\n * builtin renderer.\n *\n * A `MultiCanvas` consists of one or more `CanvasEntry` instances, depending\n * on the zoom level.\n */\nvar MultiCanvas = /*#__PURE__*/function (_Drawer) {\n  _inherits(MultiCanvas, _Drawer);\n\n  var _super = _createSuper(MultiCanvas);\n\n  /**\n   * @param {HTMLElement} container The container node of the wavesurfer instance\n   * @param {WavesurferParams} params The wavesurfer initialisation options\n   */\n  function MultiCanvas(container, params) {\n    var _this;\n\n    _classCallCheck(this, MultiCanvas);\n\n    _this = _super.call(this, container, params);\n    /**\n     * @type {number}\n     */\n\n    _this.maxCanvasWidth = params.maxCanvasWidth;\n    /**\n     * @type {number}\n     */\n\n    _this.maxCanvasElementWidth = Math.round(params.maxCanvasWidth / params.pixelRatio);\n    /**\n     * Whether or not the progress wave is rendered. If the `waveColor`\n     * and `progressColor` are the same color it is not.\n     *\n     * @type {boolean}\n     */\n\n    _this.hasProgressCanvas = params.waveColor != params.progressColor;\n    /**\n     * @type {number}\n     */\n\n    _this.halfPixel = 0.5 / params.pixelRatio;\n    /**\n     * List of `CanvasEntry` instances.\n     *\n     * @type {Array}\n     */\n\n    _this.canvases = [];\n    /**\n     * @type {HTMLElement}\n     */\n\n    _this.progressWave = null;\n    /**\n     * Class used to generate entries.\n     *\n     * @type {function}\n     */\n\n    _this.EntryClass = _drawer2.default;\n    /**\n     * Canvas 2d context attributes.\n     *\n     * @type {object}\n     */\n\n    _this.canvasContextAttributes = params.drawingContextAttributes;\n    /**\n     * Overlap added between entries to prevent vertical white stripes\n     * between `canvas` elements.\n     *\n     * @type {number}\n     */\n\n    _this.overlap = 2 * Math.ceil(params.pixelRatio / 2);\n    /**\n     * The radius of the wave bars. Makes bars rounded\n     *\n     * @type {number}\n     */\n\n    _this.barRadius = params.barRadius || 0;\n    /**\n     * Whether to render the waveform vertically. Defaults to false.\n     *\n     * @type {boolean}\n     */\n\n    _this.vertical = params.vertical;\n    return _this;\n  }\n  /**\n   * Initialize the drawer\n   */\n\n\n  _createClass(MultiCanvas, [{\n    key: \"init\",\n    value: function init() {\n      this.createWrapper();\n      this.createElements();\n    }\n    /**\n     * Create the canvas elements and style them\n     *\n     */\n\n  }, {\n    key: \"createElements\",\n    value: function createElements() {\n      this.progressWave = util.withOrientation(this.wrapper.appendChild(document.createElement('wave')), this.params.vertical);\n      this.style(this.progressWave, {\n        position: 'absolute',\n        zIndex: 3,\n        left: 0,\n        top: 0,\n        bottom: 0,\n        overflow: 'hidden',\n        width: '0',\n        display: 'none',\n        boxSizing: 'border-box',\n        borderRightStyle: 'solid',\n        pointerEvents: 'none'\n      });\n      this.addCanvas();\n      this.updateCursor();\n    }\n    /**\n     * Update cursor style\n     */\n\n  }, {\n    key: \"updateCursor\",\n    value: function updateCursor() {\n      this.style(this.progressWave, {\n        borderRightWidth: this.params.cursorWidth + 'px',\n        borderRightColor: this.params.cursorColor\n      });\n    }\n    /**\n     * Adjust to the updated size by adding or removing canvases\n     */\n\n  }, {\n    key: \"updateSize\",\n    value: function updateSize() {\n      var _this2 = this;\n\n      var totalWidth = Math.round(this.width / this.params.pixelRatio);\n      var requiredCanvases = Math.ceil(totalWidth / (this.maxCanvasElementWidth + this.overlap)); // add required canvases\n\n      while (this.canvases.length < requiredCanvases) {\n        this.addCanvas();\n      } // remove older existing canvases, if any\n\n\n      while (this.canvases.length > requiredCanvases) {\n        this.removeCanvas();\n      }\n\n      var canvasWidth = this.maxCanvasWidth + this.overlap;\n      var lastCanvas = this.canvases.length - 1;\n      this.canvases.forEach(function (entry, i) {\n        if (i == lastCanvas) {\n          canvasWidth = _this2.width - _this2.maxCanvasWidth * lastCanvas;\n        }\n\n        _this2.updateDimensions(entry, canvasWidth, _this2.height);\n\n        entry.clearWave();\n      });\n    }\n    /**\n     * Add a canvas to the canvas list\n     *\n     */\n\n  }, {\n    key: \"addCanvas\",\n    value: function addCanvas() {\n      var entry = new this.EntryClass();\n      entry.canvasContextAttributes = this.canvasContextAttributes;\n      entry.hasProgressCanvas = this.hasProgressCanvas;\n      entry.halfPixel = this.halfPixel;\n      var leftOffset = this.maxCanvasElementWidth * this.canvases.length; // wave\n\n      var wave = util.withOrientation(this.wrapper.appendChild(document.createElement('canvas')), this.params.vertical);\n      this.style(wave, {\n        position: 'absolute',\n        zIndex: 2,\n        left: leftOffset + 'px',\n        top: 0,\n        bottom: 0,\n        height: '100%',\n        pointerEvents: 'none'\n      });\n      entry.initWave(wave); // progress\n\n      if (this.hasProgressCanvas) {\n        var progress = util.withOrientation(this.progressWave.appendChild(document.createElement('canvas')), this.params.vertical);\n        this.style(progress, {\n          position: 'absolute',\n          left: leftOffset + 'px',\n          top: 0,\n          bottom: 0,\n          height: '100%'\n        });\n        entry.initProgress(progress);\n      }\n\n      this.canvases.push(entry);\n    }\n    /**\n     * Pop single canvas from the list\n     *\n     */\n\n  }, {\n    key: \"removeCanvas\",\n    value: function removeCanvas() {\n      var lastEntry = this.canvases[this.canvases.length - 1]; // wave\n\n      lastEntry.wave.parentElement.removeChild(lastEntry.wave.domElement); // progress\n\n      if (this.hasProgressCanvas) {\n        lastEntry.progress.parentElement.removeChild(lastEntry.progress.domElement);\n      } // cleanup\n\n\n      if (lastEntry) {\n        lastEntry.destroy();\n        lastEntry = null;\n      }\n\n      this.canvases.pop();\n    }\n    /**\n     * Update the dimensions of a canvas element\n     *\n     * @param {CanvasEntry} entry Target entry\n     * @param {number} width The new width of the element\n     * @param {number} height The new height of the element\n     */\n\n  }, {\n    key: \"updateDimensions\",\n    value: function updateDimensions(entry, width, height) {\n      var elementWidth = Math.round(width / this.params.pixelRatio);\n      var totalWidth = Math.round(this.width / this.params.pixelRatio); // update canvas dimensions\n\n      entry.updateDimensions(elementWidth, totalWidth, width, height); // style element\n\n      this.style(this.progressWave, {\n        display: 'block'\n      });\n    }\n    /**\n     * Clear the whole multi-canvas\n     */\n\n  }, {\n    key: \"clearWave\",\n    value: function clearWave() {\n      var _this3 = this;\n\n      util.frame(function () {\n        _this3.canvases.forEach(function (entry) {\n          return entry.clearWave();\n        });\n      })();\n    }\n    /**\n     * Draw a waveform with bars\n     *\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays\n     * for split channel rendering\n     * @param {number} channelIndex The index of the current channel. Normally\n     * should be 0. Must be an integer.\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that should be\n     * rendered\n     * @returns {void}\n     */\n\n  }, {\n    key: \"drawBars\",\n    value: function drawBars(peaks, channelIndex, start, end) {\n      var _this4 = this;\n\n      return this.prepareDraw(peaks, channelIndex, start, end, function (_ref) {\n        var absmax = _ref.absmax,\n            hasMinVals = _ref.hasMinVals,\n            height = _ref.height,\n            offsetY = _ref.offsetY,\n            halfH = _ref.halfH,\n            peaks = _ref.peaks,\n            ch = _ref.channelIndex;\n\n        // if drawBars was called within ws.empty we don't pass a start and\n        // don't want anything to happen\n        if (start === undefined) {\n          return;\n        } // Skip every other value if there are negatives.\n\n\n        var peakIndexScale = hasMinVals ? 2 : 1;\n        var length = peaks.length / peakIndexScale;\n        var bar = _this4.params.barWidth * _this4.params.pixelRatio;\n        var gap = _this4.params.barGap === null ? Math.max(_this4.params.pixelRatio, ~~(bar / 2)) : Math.max(_this4.params.pixelRatio, _this4.params.barGap * _this4.params.pixelRatio);\n        var step = bar + gap;\n        var scale = length / _this4.width;\n        var first = start;\n        var last = end;\n        var i = first;\n\n        for (i; i < last; i += step) {\n          var peak = peaks[Math.floor(i * scale * peakIndexScale)] || 0;\n          var h = Math.round(peak / absmax * halfH);\n          /* in case of silences, allow the user to specify that we\n           * always draw *something* (normally a 1px high bar) */\n\n          if (h == 0 && _this4.params.barMinHeight) {\n            h = _this4.params.barMinHeight;\n          }\n\n          _this4.fillRect(i + _this4.halfPixel, halfH - h + offsetY, bar + _this4.halfPixel, h * 2, _this4.barRadius, ch);\n        }\n      });\n    }\n    /**\n     * Draw a waveform\n     *\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays\n     * for split channel rendering\n     * @param {number} channelIndex The index of the current channel. Normally\n     * should be 0\n     * @param {number?} start The x-offset of the beginning of the area that\n     * should be rendered (If this isn't set only a flat line is rendered)\n     * @param {number?} end The x-offset of the end of the area that should be\n     * rendered\n     * @returns {void}\n     */\n\n  }, {\n    key: \"drawWave\",\n    value: function drawWave(peaks, channelIndex, start, end) {\n      var _this5 = this;\n\n      return this.prepareDraw(peaks, channelIndex, start, end, function (_ref2) {\n        var absmax = _ref2.absmax,\n            hasMinVals = _ref2.hasMinVals,\n            height = _ref2.height,\n            offsetY = _ref2.offsetY,\n            halfH = _ref2.halfH,\n            peaks = _ref2.peaks,\n            channelIndex = _ref2.channelIndex;\n\n        if (!hasMinVals) {\n          var reflectedPeaks = [];\n          var len = peaks.length;\n          var i = 0;\n\n          for (i; i < len; i++) {\n            reflectedPeaks[2 * i] = peaks[i];\n            reflectedPeaks[2 * i + 1] = -peaks[i];\n          }\n\n          peaks = reflectedPeaks;\n        } // if drawWave was called within ws.empty we don't pass a start and\n        // end and simply want a flat line\n\n\n        if (start !== undefined) {\n          _this5.drawLine(peaks, absmax, halfH, offsetY, start, end, channelIndex);\n        } // always draw a median line\n\n\n        _this5.fillRect(0, halfH + offsetY - _this5.halfPixel, _this5.width, _this5.halfPixel, _this5.barRadius, channelIndex);\n      });\n    }\n    /**\n     * Tell the canvas entries to render their portion of the waveform\n     *\n     * @param {number[]} peaks Peaks data\n     * @param {number} absmax Maximum peak value (absolute)\n     * @param {number} halfH Half the height of the waveform\n     * @param {number} offsetY Offset to the top\n     * @param {number} start The x-offset of the beginning of the area that\n     * should be rendered\n     * @param {number} end The x-offset of the end of the area that\n     * should be rendered\n     * @param {channelIndex} channelIndex The channel index of the line drawn\n     */\n\n  }, {\n    key: \"drawLine\",\n    value: function drawLine(peaks, absmax, halfH, offsetY, start, end, channelIndex) {\n      var _this6 = this;\n\n      var _ref3 = this.params.splitChannelsOptions.channelColors[channelIndex] || {},\n          waveColor = _ref3.waveColor,\n          progressColor = _ref3.progressColor;\n\n      this.canvases.forEach(function (entry, i) {\n        _this6.setFillStyles(entry, waveColor, progressColor);\n\n        _this6.applyCanvasTransforms(entry, _this6.params.vertical);\n\n        entry.drawLines(peaks, absmax, halfH, offsetY, start, end);\n      });\n    }\n    /**\n     * Draw a rectangle on the multi-canvas\n     *\n     * @param {number} x X-position of the rectangle\n     * @param {number} y Y-position of the rectangle\n     * @param {number} width Width of the rectangle\n     * @param {number} height Height of the rectangle\n     * @param {number} radius Radius of the rectangle\n     * @param {channelIndex} channelIndex The channel index of the bar drawn\n     */\n\n  }, {\n    key: \"fillRect\",\n    value: function fillRect(x, y, width, height, radius, channelIndex) {\n      var startCanvas = Math.floor(x / this.maxCanvasWidth);\n      var endCanvas = Math.min(Math.ceil((x + width) / this.maxCanvasWidth) + 1, this.canvases.length);\n      var i = startCanvas;\n\n      for (i; i < endCanvas; i++) {\n        var entry = this.canvases[i];\n        var leftOffset = i * this.maxCanvasWidth;\n        var intersection = {\n          x1: Math.max(x, i * this.maxCanvasWidth),\n          y1: y,\n          x2: Math.min(x + width, i * this.maxCanvasWidth + entry.wave.width),\n          y2: y + height\n        };\n\n        if (intersection.x1 < intersection.x2) {\n          var _ref4 = this.params.splitChannelsOptions.channelColors[channelIndex] || {},\n              waveColor = _ref4.waveColor,\n              progressColor = _ref4.progressColor;\n\n          this.setFillStyles(entry, waveColor, progressColor);\n          this.applyCanvasTransforms(entry, this.params.vertical);\n          entry.fillRects(intersection.x1 - leftOffset, intersection.y1, intersection.x2 - intersection.x1, intersection.y2 - intersection.y1, radius);\n        }\n      }\n    }\n    /**\n     * Returns whether to hide the channel from being drawn based on params.\n     *\n     * @param {number} channelIndex The index of the current channel.\n     * @returns {bool} True to hide the channel, false to draw.\n     */\n\n  }, {\n    key: \"hideChannel\",\n    value: function hideChannel(channelIndex) {\n      return this.params.splitChannels && this.params.splitChannelsOptions.filterChannels.includes(channelIndex);\n    }\n    /**\n     * Performs preparation tasks and calculations which are shared by `drawBars`\n     * and `drawWave`\n     *\n     * @param {number[]|Number.<Array[]>} peaks Can also be an array of arrays for\n     * split channel rendering\n     * @param {number} channelIndex The index of the current channel. Normally\n     * should be 0\n     * @param {number?} start The x-offset of the beginning of the area that\n     * should be rendered. If this isn't set only a flat line is rendered\n     * @param {number?} end The x-offset of the end of the area that should be\n     * rendered\n     * @param {function} fn The render function to call, e.g. `drawWave`\n     * @param {number} drawIndex The index of the current channel after filtering.\n     * @param {number?} normalizedMax Maximum modulation value across channels for use with relativeNormalization. Ignored when undefined\n     * @returns {void}\n     */\n\n  }, {\n    key: \"prepareDraw\",\n    value: function prepareDraw(peaks, channelIndex, start, end, fn, drawIndex, normalizedMax) {\n      var _this7 = this;\n\n      return util.frame(function () {\n        // Split channels and call this function with the channelIndex set\n        if (peaks[0] instanceof Array) {\n          var channels = peaks;\n\n          if (_this7.params.splitChannels) {\n            var filteredChannels = channels.filter(function (c, i) {\n              return !_this7.hideChannel(i);\n            });\n\n            if (!_this7.params.splitChannelsOptions.overlay) {\n              _this7.setHeight(Math.max(filteredChannels.length, 1) * _this7.params.height * _this7.params.pixelRatio);\n            }\n\n            var overallAbsMax;\n\n            if (_this7.params.splitChannelsOptions && _this7.params.splitChannelsOptions.relativeNormalization) {\n              // calculate maximum peak across channels to use for normalization\n              overallAbsMax = util.max(channels.map(function (channelPeaks) {\n                return util.absMax(channelPeaks);\n              }));\n            }\n\n            return channels.forEach(function (channelPeaks, i) {\n              return _this7.prepareDraw(channelPeaks, i, start, end, fn, filteredChannels.indexOf(channelPeaks), overallAbsMax);\n            });\n          }\n\n          peaks = channels[0];\n        } // Return and do not draw channel peaks if hidden.\n\n\n        if (_this7.hideChannel(channelIndex)) {\n          return;\n        } // calculate maximum modulation value, either from the barHeight\n        // parameter or if normalize=true from the largest value in the peak\n        // set\n\n\n        var absmax = 1 / _this7.params.barHeight;\n\n        if (_this7.params.normalize) {\n          absmax = normalizedMax === undefined ? util.absMax(peaks) : normalizedMax;\n        } // Bar wave draws the bottom only as a reflection of the top,\n        // so we don't need negative values\n\n\n        var hasMinVals = [].some.call(peaks, function (val) {\n          return val < 0;\n        });\n        var height = _this7.params.height * _this7.params.pixelRatio;\n        var halfH = height / 2;\n        var offsetY = height * drawIndex || 0; // Override offsetY if overlay is true\n\n        if (_this7.params.splitChannelsOptions && _this7.params.splitChannelsOptions.overlay) {\n          offsetY = 0;\n        }\n\n        return fn({\n          absmax: absmax,\n          hasMinVals: hasMinVals,\n          height: height,\n          offsetY: offsetY,\n          halfH: halfH,\n          peaks: peaks,\n          channelIndex: channelIndex\n        });\n      })();\n    }\n    /**\n     * Set the fill styles for a certain entry (wave and progress)\n     *\n     * @param {CanvasEntry} entry Target entry\n     * @param {string} waveColor Wave color to draw this entry\n     * @param {string} progressColor Progress color to draw this entry\n     */\n\n  }, {\n    key: \"setFillStyles\",\n    value: function setFillStyles(entry) {\n      var waveColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.params.waveColor;\n      var progressColor = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : this.params.progressColor;\n      entry.setFillStyles(waveColor, progressColor);\n    }\n    /**\n     * Set the canvas transforms for a certain entry (wave and progress)\n     *\n     * @param {CanvasEntry} entry Target entry\n     * @param {boolean} vertical Whether to render the waveform vertically\n     */\n\n  }, {\n    key: \"applyCanvasTransforms\",\n    value: function applyCanvasTransforms(entry) {\n      var vertical = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;\n      entry.applyCanvasTransforms(vertical);\n    }\n    /**\n     * Return image data of the multi-canvas\n     *\n     * When using a `type` of `'blob'`, this will return a `Promise`.\n     *\n     * @param {string} format='image/png' An optional value of a format type.\n     * @param {number} quality=0.92 An optional value between 0 and 1.\n     * @param {string} type='dataURL' Either 'dataURL' or 'blob'.\n     * @return {string|string[]|Promise} When using the default `'dataURL'`\n     * `type` this returns a single data URL or an array of data URLs,\n     * one for each canvas. When using the `'blob'` `type` this returns a\n     * `Promise` that resolves with an array of `Blob` instances, one for each\n     * canvas.\n     */\n\n  }, {\n    key: \"getImage\",\n    value: function getImage(format, quality, type) {\n      if (type === 'blob') {\n        return Promise.all(this.canvases.map(function (entry) {\n          return entry.getImage(format, quality, type);\n        }));\n      } else if (type === 'dataURL') {\n        var images = this.canvases.map(function (entry) {\n          return entry.getImage(format, quality, type);\n        });\n        return images.length > 1 ? images : images[0];\n      }\n    }\n    /**\n     * Render the new progress\n     *\n     * @param {number} position X-offset of progress position in pixels\n     */\n\n  }, {\n    key: \"updateProgress\",\n    value: function updateProgress(position) {\n      this.style(this.progressWave, {\n        width: position + 'px'\n      });\n    }\n  }]);\n\n  return MultiCanvas;\n}(_drawer.default);\n\nexports.default = MultiCanvas;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/mediaelement-webaudio.js\":\n/*!**************************************!*\\\n  !*** ./src/mediaelement-webaudio.js ***!\n  \\**************************************/\n/***/ ((module, exports, __nested_webpack_require_56119__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar _mediaelement = _interopRequireDefault(__nested_webpack_require_56119__(/*! ./mediaelement */ \"./src/mediaelement.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n/**\n * MediaElementWebAudio backend: load audio via an HTML5 audio tag, but playback with the WebAudio API.\n * The advantage here is that the html5 <audio> tag can perform range requests on the server and not\n * buffer the entire file in one request, and you still get the filtering and scripting functionality\n * of the webaudio API.\n * Note that in order to use range requests and prevent buffering, you must provide peak data.\n *\n * @since 3.2.0\n */\nvar MediaElementWebAudio = /*#__PURE__*/function (_MediaElement) {\n  _inherits(MediaElementWebAudio, _MediaElement);\n\n  var _super = _createSuper(MediaElementWebAudio);\n\n  /**\n   * Construct the backend\n   *\n   * @param {WavesurferParams} params Wavesurfer parameters\n   */\n  function MediaElementWebAudio(params) {\n    var _this;\n\n    _classCallCheck(this, MediaElementWebAudio);\n\n    _this = _super.call(this, params);\n    /** @private */\n\n    _this.params = params;\n    /** @private */\n\n    _this.sourceMediaElement = null;\n    return _this;\n  }\n  /**\n   * Initialise the backend, called in `wavesurfer.createBackend()`\n   */\n\n\n  _createClass(MediaElementWebAudio, [{\n    key: \"init\",\n    value: function init() {\n      this.setPlaybackRate(this.params.audioRate);\n      this.createTimer();\n      this.createVolumeNode();\n      this.createScriptNode();\n      this.createAnalyserNode();\n    }\n    /**\n     * Private method called by both `load` (from url)\n     * and `loadElt` (existing media element) methods.\n     *\n     * @param {HTMLMediaElement} media HTML5 Audio or Video element\n     * @param {number[]|Number.<Array[]>} peaks Array of peak data\n     * @param {string} preload HTML 5 preload attribute value\n     * @private\n     */\n\n  }, {\n    key: \"_load\",\n    value: function _load(media, peaks, preload) {\n      _get(_getPrototypeOf(MediaElementWebAudio.prototype), \"_load\", this).call(this, media, peaks, preload);\n\n      this.createMediaElementSource(media);\n    }\n    /**\n     * Create MediaElementSource node\n     *\n     * @since 3.2.0\n     * @param {HTMLMediaElement} mediaElement HTML5 Audio to load\n     */\n\n  }, {\n    key: \"createMediaElementSource\",\n    value: function createMediaElementSource(mediaElement) {\n      this.sourceMediaElement = this.ac.createMediaElementSource(mediaElement);\n      this.sourceMediaElement.connect(this.analyser);\n    }\n  }, {\n    key: \"play\",\n    value: function play(start, end) {\n      this.resumeAudioContext();\n      return _get(_getPrototypeOf(MediaElementWebAudio.prototype), \"play\", this).call(this, start, end);\n    }\n    /**\n     * This is called when wavesurfer is destroyed\n     *\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      _get(_getPrototypeOf(MediaElementWebAudio.prototype), \"destroy\", this).call(this);\n\n      this.destroyWebAudio();\n    }\n  }]);\n\n  return MediaElementWebAudio;\n}(_mediaelement.default);\n\nexports.default = MediaElementWebAudio;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/mediaelement.js\":\n/*!*****************************!*\\\n  !*** ./src/mediaelement.js ***!\n  \\*****************************/\n/***/ ((module, exports, __nested_webpack_require_63244__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar _webaudio = _interopRequireDefault(__nested_webpack_require_63244__(/*! ./webaudio */ \"./src/webaudio.js\"));\n\nvar util = _interopRequireWildcard(__nested_webpack_require_63244__(/*! ./util */ \"./src/util/index.js\"));\n\nfunction _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== \"function\") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }\n\nfunction _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== \"default\" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n/**\n * MediaElement backend\n */\nvar MediaElement = /*#__PURE__*/function (_WebAudio) {\n  _inherits(MediaElement, _WebAudio);\n\n  var _super = _createSuper(MediaElement);\n\n  /**\n   * Construct the backend\n   *\n   * @param {WavesurferParams} params Wavesurfer parameters\n   */\n  function MediaElement(params) {\n    var _this;\n\n    _classCallCheck(this, MediaElement);\n\n    _this = _super.call(this, params);\n    /** @private */\n\n    _this.params = params;\n    /**\n     * Initially a dummy media element to catch errors. Once `_load` is\n     * called, this will contain the actual `HTMLMediaElement`.\n     * @private\n     */\n\n    _this.media = {\n      currentTime: 0,\n      duration: 0,\n      paused: true,\n      playbackRate: 1,\n      play: function play() {},\n      pause: function pause() {},\n      volume: 0\n    };\n    /** @private */\n\n    _this.mediaType = params.mediaType.toLowerCase();\n    /** @private */\n\n    _this.elementPosition = params.elementPosition;\n    /** @private */\n\n    _this.peaks = null;\n    /** @private */\n\n    _this.playbackRate = 1;\n    /** @private */\n\n    _this.volume = 1;\n    /** @private */\n\n    _this.isMuted = false;\n    /** @private */\n\n    _this.buffer = null;\n    /** @private */\n\n    _this.onPlayEnd = null;\n    /** @private */\n\n    _this.mediaListeners = {};\n    return _this;\n  }\n  /**\n   * Initialise the backend, called in `wavesurfer.createBackend()`\n   */\n\n\n  _createClass(MediaElement, [{\n    key: \"init\",\n    value: function init() {\n      this.setPlaybackRate(this.params.audioRate);\n      this.createTimer();\n    }\n    /**\n     * Attach event listeners to media element.\n     */\n\n  }, {\n    key: \"_setupMediaListeners\",\n    value: function _setupMediaListeners() {\n      var _this2 = this;\n\n      this.mediaListeners.error = function () {\n        _this2.fireEvent('error', 'Error loading media element');\n      };\n\n      this.mediaListeners.canplay = function () {\n        _this2.fireEvent('canplay');\n      };\n\n      this.mediaListeners.ended = function () {\n        _this2.fireEvent('finish');\n      }; // listen to and relay play, pause and seeked events to enable\n      // playback control from the external media element\n\n\n      this.mediaListeners.play = function () {\n        _this2.fireEvent('play');\n      };\n\n      this.mediaListeners.pause = function () {\n        _this2.fireEvent('pause');\n      };\n\n      this.mediaListeners.seeked = function (event) {\n        _this2.fireEvent('seek');\n      };\n\n      this.mediaListeners.volumechange = function (event) {\n        _this2.isMuted = _this2.media.muted;\n\n        if (_this2.isMuted) {\n          _this2.volume = 0;\n        } else {\n          _this2.volume = _this2.media.volume;\n        }\n\n        _this2.fireEvent('volume');\n      }; // reset event listeners\n\n\n      Object.keys(this.mediaListeners).forEach(function (id) {\n        _this2.media.removeEventListener(id, _this2.mediaListeners[id]);\n\n        _this2.media.addEventListener(id, _this2.mediaListeners[id]);\n      });\n    }\n    /**\n     * Create a timer to provide a more precise `audioprocess` event.\n     */\n\n  }, {\n    key: \"createTimer\",\n    value: function createTimer() {\n      var _this3 = this;\n\n      var onAudioProcess = function onAudioProcess() {\n        if (_this3.isPaused()) {\n          return;\n        }\n\n        _this3.fireEvent('audioprocess', _this3.getCurrentTime()); // Call again in the next frame\n\n\n        util.frame(onAudioProcess)();\n      };\n\n      this.on('play', onAudioProcess); // Update the progress one more time to prevent it from being stuck in\n      // case of lower framerates\n\n      this.on('pause', function () {\n        _this3.fireEvent('audioprocess', _this3.getCurrentTime());\n      });\n    }\n    /**\n     * Create media element with url as its source,\n     * and append to container element.\n     *\n     * @param {string} url Path to media file\n     * @param {HTMLElement} container HTML element\n     * @param {number[]|Number.<Array[]>} peaks Array of peak data\n     * @param {string} preload HTML 5 preload attribute value\n     * @throws Will throw an error if the `url` argument is not a valid media\n     * element.\n     */\n\n  }, {\n    key: \"load\",\n    value: function load(url, container, peaks, preload) {\n      var media = document.createElement(this.mediaType);\n      media.controls = this.params.mediaControls;\n      media.autoplay = this.params.autoplay || false;\n      media.preload = preload == null ? 'auto' : preload;\n      media.src = url;\n      media.style.width = '100%';\n      var prevMedia = container.querySelector(this.mediaType);\n\n      if (prevMedia) {\n        container.removeChild(prevMedia);\n      }\n\n      container.appendChild(media);\n\n      this._load(media, peaks, preload);\n    }\n    /**\n     * Load existing media element.\n     *\n     * @param {HTMLMediaElement} elt HTML5 Audio or Video element\n     * @param {number[]|Number.<Array[]>} peaks Array of peak data\n     */\n\n  }, {\n    key: \"loadElt\",\n    value: function loadElt(elt, peaks) {\n      elt.controls = this.params.mediaControls;\n      elt.autoplay = this.params.autoplay || false;\n\n      this._load(elt, peaks, elt.preload);\n    }\n    /**\n     * Method called by both `load` (from url)\n     * and `loadElt` (existing media element) methods.\n     *\n     * @param {HTMLMediaElement} media HTML5 Audio or Video element\n     * @param {number[]|Number.<Array[]>} peaks Array of peak data\n     * @param {string} preload HTML 5 preload attribute value\n     * @throws Will throw an error if the `media` argument is not a valid media\n     * element.\n     * @private\n     */\n\n  }, {\n    key: \"_load\",\n    value: function _load(media, peaks, preload) {\n      // verify media element is valid\n      if (!(media instanceof HTMLMediaElement) || typeof media.addEventListener === 'undefined') {\n        throw new Error('media parameter is not a valid media element');\n      } // load must be called manually on iOS, otherwise peaks won't draw\n      // until a user interaction triggers load --> 'ready' event\n      //\n      // note that we avoid calling media.load here when given peaks and preload == 'none'\n      // as this almost always triggers some browser fetch of the media.\n\n\n      if (typeof media.load == 'function' && !(peaks && preload == 'none')) {\n        // Resets the media element and restarts the media resource. Any\n        // pending events are discarded. How much media data is fetched is\n        // still affected by the preload attribute.\n        media.load();\n      }\n\n      this.media = media;\n\n      this._setupMediaListeners();\n\n      this.peaks = peaks;\n      this.onPlayEnd = null;\n      this.buffer = null;\n      this.isMuted = media.muted;\n      this.setPlaybackRate(this.playbackRate);\n      this.setVolume(this.volume);\n    }\n    /**\n     * Used by `wavesurfer.isPlaying()` and `wavesurfer.playPause()`\n     *\n     * @return {boolean} Media paused or not\n     */\n\n  }, {\n    key: \"isPaused\",\n    value: function isPaused() {\n      return !this.media || this.media.paused;\n    }\n    /**\n     * Used by `wavesurfer.getDuration()`\n     *\n     * @return {number} Duration\n     */\n\n  }, {\n    key: \"getDuration\",\n    value: function getDuration() {\n      if (this.explicitDuration) {\n        return this.explicitDuration;\n      }\n\n      var duration = (this.buffer || this.media).duration;\n\n      if (duration >= Infinity) {\n        // streaming audio\n        duration = this.media.seekable.end(0);\n      }\n\n      return duration;\n    }\n    /**\n     * Returns the current time in seconds relative to the audio-clip's\n     * duration.\n     *\n     * @return {number} Current time\n     */\n\n  }, {\n    key: \"getCurrentTime\",\n    value: function getCurrentTime() {\n      return this.media && this.media.currentTime;\n    }\n    /**\n     * Get the position from 0 to 1\n     *\n     * @return {number} Current position\n     */\n\n  }, {\n    key: \"getPlayedPercents\",\n    value: function getPlayedPercents() {\n      return this.getCurrentTime() / this.getDuration() || 0;\n    }\n    /**\n     * Get the audio source playback rate.\n     *\n     * @return {number} Playback rate\n     */\n\n  }, {\n    key: \"getPlaybackRate\",\n    value: function getPlaybackRate() {\n      return this.playbackRate || this.media.playbackRate;\n    }\n    /**\n     * Set the audio source playback rate.\n     *\n     * @param {number} value Playback rate\n     */\n\n  }, {\n    key: \"setPlaybackRate\",\n    value: function setPlaybackRate(value) {\n      this.playbackRate = value || 1;\n      this.media.playbackRate = this.playbackRate;\n    }\n    /**\n     * Used by `wavesurfer.seekTo()`\n     *\n     * @param {number} start Position to start at in seconds\n     */\n\n  }, {\n    key: \"seekTo\",\n    value: function seekTo(start) {\n      if (start != null) {\n        this.media.currentTime = start;\n      }\n\n      this.clearPlayEnd();\n    }\n    /**\n     * Plays the loaded audio region.\n     *\n     * @param {number} start Start offset in seconds, relative to the beginning\n     * of a clip.\n     * @param {number} end When to stop, relative to the beginning of a clip.\n     * @emits MediaElement#play\n     * @return {Promise} Result\n     */\n\n  }, {\n    key: \"play\",\n    value: function play(start, end) {\n      this.seekTo(start);\n      var promise = this.media.play();\n      end && this.setPlayEnd(end);\n      return promise;\n    }\n    /**\n     * Pauses the loaded audio.\n     *\n     * @emits MediaElement#pause\n     * @return {Promise} Result\n     */\n\n  }, {\n    key: \"pause\",\n    value: function pause() {\n      var promise;\n\n      if (this.media) {\n        promise = this.media.pause();\n      }\n\n      this.clearPlayEnd();\n      return promise;\n    }\n    /**\n     * Set the play end\n     *\n     * @param {number} end Where to end\n     */\n\n  }, {\n    key: \"setPlayEnd\",\n    value: function setPlayEnd(end) {\n      var _this4 = this;\n\n      this.clearPlayEnd();\n\n      this._onPlayEnd = function (time) {\n        if (time >= end) {\n          _this4.pause();\n\n          _this4.seekTo(end);\n        }\n      };\n\n      this.on('audioprocess', this._onPlayEnd);\n    }\n    /** @private */\n\n  }, {\n    key: \"clearPlayEnd\",\n    value: function clearPlayEnd() {\n      if (this._onPlayEnd) {\n        this.un('audioprocess', this._onPlayEnd);\n        this._onPlayEnd = null;\n      }\n    }\n    /**\n     * Compute the max and min value of the waveform when broken into\n     * <length> subranges.\n     *\n     * @param {number} length How many subranges to break the waveform into.\n     * @param {number} first First sample in the required range.\n     * @param {number} last Last sample in the required range.\n     * @return {number[]|Number.<Array[]>} Array of 2*<length> peaks or array of\n     * arrays of peaks consisting of (max, min) values for each subrange.\n     */\n\n  }, {\n    key: \"getPeaks\",\n    value: function getPeaks(length, first, last) {\n      if (this.buffer) {\n        return _get(_getPrototypeOf(MediaElement.prototype), \"getPeaks\", this).call(this, length, first, last);\n      }\n\n      return this.peaks || [];\n    }\n    /**\n     * Set the sink id for the media player\n     *\n     * @param {string} deviceId String value representing audio device id.\n     * @returns {Promise} A Promise that resolves to `undefined` when there\n     * are no errors.\n     */\n\n  }, {\n    key: \"setSinkId\",\n    value: function setSinkId(deviceId) {\n      if (deviceId) {\n        if (!this.media.setSinkId) {\n          return Promise.reject(new Error('setSinkId is not supported in your browser'));\n        }\n\n        return this.media.setSinkId(deviceId);\n      }\n\n      return Promise.reject(new Error('Invalid deviceId: ' + deviceId));\n    }\n    /**\n     * Get the current volume\n     *\n     * @return {number} value A floating point value between 0 and 1.\n     */\n\n  }, {\n    key: \"getVolume\",\n    value: function getVolume() {\n      return this.volume;\n    }\n    /**\n     * Set the audio volume\n     *\n     * @param {number} value A floating point value between 0 and 1.\n     */\n\n  }, {\n    key: \"setVolume\",\n    value: function setVolume(value) {\n      this.volume = value; // no need to change when it's already at that volume\n\n      if (this.media.volume !== this.volume) {\n        this.media.volume = this.volume;\n      }\n    }\n    /**\n     * Enable or disable muted audio\n     *\n     * @since 4.0.0\n     * @param {boolean} muted Specify `true` to mute audio.\n     */\n\n  }, {\n    key: \"setMute\",\n    value: function setMute(muted) {\n      // This causes a volume change to be emitted too through the\n      // volumechange event listener.\n      this.isMuted = this.media.muted = muted;\n    }\n    /**\n     * This is called when wavesurfer is destroyed\n     *\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      var _this5 = this;\n\n      this.pause();\n      this.unAll();\n      this.destroyed = true; // cleanup media event listeners\n\n      Object.keys(this.mediaListeners).forEach(function (id) {\n        if (_this5.media) {\n          _this5.media.removeEventListener(id, _this5.mediaListeners[id]);\n        }\n      });\n\n      if (this.params.removeMediaElementOnDestroy && this.media && this.media.parentNode) {\n        this.media.parentNode.removeChild(this.media);\n      }\n\n      this.media = null;\n    }\n  }]);\n\n  return MediaElement;\n}(_webaudio.default);\n\nexports.default = MediaElement;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/peakcache.js\":\n/*!**************************!*\\\n  !*** ./src/peakcache.js ***!\n  \\**************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\n/**\n * Caches the decoded peaks data to improve rendering speed for large audio\n *\n * Is used if the option parameter `partialRender` is set to `true`\n */\nvar PeakCache = /*#__PURE__*/function () {\n  /**\n   * Instantiate cache\n   */\n  function PeakCache() {\n    _classCallCheck(this, PeakCache);\n\n    this.clearPeakCache();\n  }\n  /**\n   * Empty the cache\n   */\n\n\n  _createClass(PeakCache, [{\n    key: \"clearPeakCache\",\n    value: function clearPeakCache() {\n      /**\n       * Flat array with entries that are always in pairs to mark the\n       * beginning and end of each subrange.  This is a convenience so we can\n       * iterate over the pairs for easy set difference operations.\n       * @private\n       */\n      this.peakCacheRanges = [];\n      /**\n       * Length of the entire cachable region, used for resetting the cache\n       * when this changes (zoom events, for instance).\n       * @private\n       */\n\n      this.peakCacheLength = -1;\n    }\n    /**\n     * Add a range of peaks to the cache\n     *\n     * @param {number} length The length of the range\n     * @param {number} start The x offset of the start of the range\n     * @param {number} end The x offset of the end of the range\n     * @return {Number.<Array[]>} Array with arrays of numbers\n     */\n\n  }, {\n    key: \"addRangeToPeakCache\",\n    value: function addRangeToPeakCache(length, start, end) {\n      if (length != this.peakCacheLength) {\n        this.clearPeakCache();\n        this.peakCacheLength = length;\n      } // Return ranges that weren't in the cache before the call.\n\n\n      var uncachedRanges = [];\n      var i = 0; // Skip ranges before the current start.\n\n      while (i < this.peakCacheRanges.length && this.peakCacheRanges[i] < start) {\n        i++;\n      } // If |i| is even, |start| falls after an existing range.  Otherwise,\n      // |start| falls between an existing range, and the uncached region\n      // starts when we encounter the next node in |peakCacheRanges| or\n      // |end|, whichever comes first.\n\n\n      if (i % 2 == 0) {\n        uncachedRanges.push(start);\n      }\n\n      while (i < this.peakCacheRanges.length && this.peakCacheRanges[i] <= end) {\n        uncachedRanges.push(this.peakCacheRanges[i]);\n        i++;\n      } // If |i| is even, |end| is after all existing ranges.\n\n\n      if (i % 2 == 0) {\n        uncachedRanges.push(end);\n      } // Filter out the 0-length ranges.\n\n\n      uncachedRanges = uncachedRanges.filter(function (item, pos, arr) {\n        if (pos == 0) {\n          return item != arr[pos + 1];\n        } else if (pos == arr.length - 1) {\n          return item != arr[pos - 1];\n        }\n\n        return item != arr[pos - 1] && item != arr[pos + 1];\n      }); // Merge the two ranges together, uncachedRanges will either contain\n      // wholly new points, or duplicates of points in peakCacheRanges.  If\n      // duplicates are detected, remove both and extend the range.\n\n      this.peakCacheRanges = this.peakCacheRanges.concat(uncachedRanges);\n      this.peakCacheRanges = this.peakCacheRanges.sort(function (a, b) {\n        return a - b;\n      }).filter(function (item, pos, arr) {\n        if (pos == 0) {\n          return item != arr[pos + 1];\n        } else if (pos == arr.length - 1) {\n          return item != arr[pos - 1];\n        }\n\n        return item != arr[pos - 1] && item != arr[pos + 1];\n      }); // Push the uncached ranges into an array of arrays for ease of\n      // iteration in the functions that call this.\n\n      var uncachedRangePairs = [];\n\n      for (i = 0; i < uncachedRanges.length; i += 2) {\n        uncachedRangePairs.push([uncachedRanges[i], uncachedRanges[i + 1]]);\n      }\n\n      return uncachedRangePairs;\n    }\n    /**\n     * For testing\n     *\n     * @return {Number.<Array[]>} Array with arrays of numbers\n     */\n\n  }, {\n    key: \"getCacheRanges\",\n    value: function getCacheRanges() {\n      var peakCacheRangePairs = [];\n      var i;\n\n      for (i = 0; i < this.peakCacheRanges.length; i += 2) {\n        peakCacheRangePairs.push([this.peakCacheRanges[i], this.peakCacheRanges[i + 1]]);\n      }\n\n      return peakCacheRangePairs;\n    }\n  }]);\n\n  return PeakCache;\n}();\n\nexports.default = PeakCache;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/absMax.js\":\n/*!****************************!*\\\n  !*** ./src/util/absMax.js ***!\n  \\****************************/\n/***/ ((module, exports, __nested_webpack_require_87138__) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = absMax;\n\nvar _max = _interopRequireDefault(__nested_webpack_require_87138__(/*! ./max */ \"./src/util/max.js\"));\n\nvar _min = _interopRequireDefault(__nested_webpack_require_87138__(/*! ./min */ \"./src/util/min.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\n/**\r\n * Get the largest absolute value in an array\r\n *\r\n * @param   {Array} values Array of numbers\r\n * @returns {Number} Largest number found\r\n * @example console.log(max([-3, 2, 1]), max([-3, 2, 4])); // logs 3 4\r\n * @since 4.3.0\r\n */\nfunction absMax(values) {\n  var max = (0, _max.default)(values);\n  var min = (0, _min.default)(values);\n  return -min > max ? -min : max;\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/clamp.js\":\n/*!***************************!*\\\n  !*** ./src/util/clamp.js ***!\n  \\***************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = clamp;\n\n/**\n * Returns a number limited to the given range.\n *\n * @param {number} val The number to be limited to a range\n * @param {number} min The lower boundary of the limit range\n * @param {number} max The upper boundary of the limit range\n * @returns {number} A number in the range [min, max]\n */\nfunction clamp(val, min, max) {\n  return Math.min(Math.max(min, val), max);\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/fetch.js\":\n/*!***************************!*\\\n  !*** ./src/util/fetch.js ***!\n  \\***************************/\n/***/ ((module, exports, __nested_webpack_require_88816__) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = fetchFile;\n\nvar _observer = _interopRequireDefault(__nested_webpack_require_88816__(/*! ./observer */ \"./src/util/observer.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nvar ProgressHandler = /*#__PURE__*/function () {\n  /**\n   * Instantiate ProgressHandler\n   *\n   * @param {Observer} instance The `fetchFile` observer instance.\n   * @param {Number} contentLength Content length.\n   * @param {Response} response Response object.\n   */\n  function ProgressHandler(instance, contentLength, response) {\n    _classCallCheck(this, ProgressHandler);\n\n    this.instance = instance;\n    this.instance._reader = response.body.getReader();\n    this.total = parseInt(contentLength, 10);\n    this.loaded = 0;\n  }\n  /**\n   * A method that is called once, immediately after the `ReadableStream``\n   * is constructed.\n   *\n   * @param {ReadableStreamDefaultController} controller Controller instance\n   *     used to control the stream.\n   */\n\n\n  _createClass(ProgressHandler, [{\n    key: \"start\",\n    value: function start(controller) {\n      var _this = this;\n\n      var read = function read() {\n        // instance._reader.read() returns a promise that resolves\n        // when a value has been received\n        _this.instance._reader.read().then(function (_ref) {\n          var done = _ref.done,\n              value = _ref.value;\n\n          // result objects contain two properties:\n          // done  - true if the stream has already given you all its data.\n          // value - some data. Always undefined when done is true.\n          if (done) {\n            // ensure onProgress called when content-length=0\n            if (_this.total === 0) {\n              _this.instance.onProgress.call(_this.instance, {\n                loaded: _this.loaded,\n                total: _this.total,\n                lengthComputable: false\n              });\n            } // no more data needs to be consumed, close the stream\n\n\n            controller.close();\n            return;\n          }\n\n          _this.loaded += value.byteLength;\n\n          _this.instance.onProgress.call(_this.instance, {\n            loaded: _this.loaded,\n            total: _this.total,\n            lengthComputable: !(_this.total === 0)\n          }); // enqueue the next data chunk into our target stream\n\n\n          controller.enqueue(value);\n          read();\n        }).catch(function (error) {\n          controller.error(error);\n        });\n      };\n\n      read();\n    }\n  }]);\n\n  return ProgressHandler;\n}();\n/**\n * Load a file using `fetch`.\n *\n * @param {object} options Request options to use. See example below.\n * @returns {Observer} Observer instance\n * @example\n * // default options\n * let options = {\n *     url: undefined,\n *     method: 'GET',\n *     mode: 'cors',\n *     credentials: 'same-origin',\n *     cache: 'default',\n *     responseType: 'json',\n *     requestHeaders: [],\n *     redirect: 'follow',\n *     referrer: 'client'\n * };\n *\n * // override some options\n * options.url = '../media/demo.wav';\n\n * // available types: 'arraybuffer', 'blob', 'json' or 'text'\n * options.responseType = 'arraybuffer';\n *\n * // make fetch call\n * let request = util.fetchFile(options);\n *\n * // listen for events\n * request.on('progress', e => {\n *     console.log('progress', e);\n * });\n *\n * request.on('success', data => {\n *     console.log('success!', data);\n * });\n *\n * request.on('error', e => {\n *     console.warn('fetchFile error: ', e);\n * });\n */\n\n\nfunction fetchFile(options) {\n  if (!options) {\n    throw new Error('fetch options missing');\n  } else if (!options.url) {\n    throw new Error('fetch url missing');\n  }\n\n  var instance = new _observer.default();\n  var fetchHeaders = new Headers();\n  var fetchRequest = new Request(options.url); // add ability to abort\n\n  instance.controller = new AbortController(); // check if headers have to be added\n\n  if (options && options.requestHeaders) {\n    // add custom request headers\n    options.requestHeaders.forEach(function (header) {\n      fetchHeaders.append(header.key, header.value);\n    });\n  } // parse fetch options\n\n\n  var responseType = options.responseType || 'json';\n  var fetchOptions = {\n    method: options.method || 'GET',\n    headers: fetchHeaders,\n    mode: options.mode || 'cors',\n    credentials: options.credentials || 'same-origin',\n    cache: options.cache || 'default',\n    redirect: options.redirect || 'follow',\n    referrer: options.referrer || 'client',\n    signal: instance.controller.signal\n  };\n  fetch(fetchRequest, fetchOptions).then(function (response) {\n    // store response reference\n    instance.response = response;\n    var progressAvailable = true;\n\n    if (!response.body) {\n      // ReadableStream is not yet supported in this browser\n      // see https://developer.mozilla.org/en-US/docs/Web/API/ReadableStream\n      progressAvailable = false;\n    } // Server must send CORS header \"Access-Control-Expose-Headers: content-length\"\n\n\n    var contentLength = response.headers.get('content-length');\n\n    if (contentLength === null) {\n      // Content-Length server response header missing.\n      // Don't evaluate download progress if we can't compare against a total size\n      // see https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS#Access-Control-Expose-Headers\n      progressAvailable = false;\n    }\n\n    if (!progressAvailable) {\n      // not able to check download progress so skip it\n      return response;\n    } // fire progress event when during load\n\n\n    instance.onProgress = function (e) {\n      instance.fireEvent('progress', e);\n    };\n\n    return new Response(new ReadableStream(new ProgressHandler(instance, contentLength, response)), fetchOptions);\n  }).then(function (response) {\n    var errMsg;\n\n    if (response.ok) {\n      switch (responseType) {\n        case 'arraybuffer':\n          return response.arrayBuffer();\n\n        case 'json':\n          return response.json();\n\n        case 'blob':\n          return response.blob();\n\n        case 'text':\n          return response.text();\n\n        default:\n          errMsg = 'Unknown responseType: ' + responseType;\n          break;\n      }\n    }\n\n    if (!errMsg) {\n      errMsg = 'HTTP error status: ' + response.status;\n    }\n\n    throw new Error(errMsg);\n  }).then(function (response) {\n    instance.fireEvent('success', response);\n  }).catch(function (error) {\n    instance.fireEvent('error', error);\n  }); // return the fetch request\n\n  instance.fetchRequest = fetchRequest;\n  return instance;\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/frame.js\":\n/*!***************************!*\\\n  !*** ./src/util/frame.js ***!\n  \\***************************/\n/***/ ((module, exports, __nested_webpack_require_96321__) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = frame;\n\nvar _requestAnimationFrame = _interopRequireDefault(__nested_webpack_require_96321__(/*! ./request-animation-frame */ \"./src/util/request-animation-frame.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\n/**\n * Create a function which will be called at the next requestAnimationFrame\n * cycle\n *\n * @param {function} func The function to call\n *\n * @return {func} The function wrapped within a requestAnimationFrame\n */\nfunction frame(func) {\n  return function () {\n    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {\n      args[_key] = arguments[_key];\n    }\n\n    return (0, _requestAnimationFrame.default)(function () {\n      return func.apply(void 0, args);\n    });\n  };\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/get-id.js\":\n/*!****************************!*\\\n  !*** ./src/util/get-id.js ***!\n  \\****************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = getId;\n\n/**\n * Get a random prefixed ID\n *\n * @param {String} prefix Prefix to use. Default is `'wavesurfer_'`.\n * @returns {String} Random prefixed ID\n * @example\n * console.log(getId()); // logs 'wavesurfer_b5pors4ru6g'\n *\n * let prefix = 'foo-';\n * console.log(getId(prefix)); // logs 'foo-b5pors4ru6g'\n */\nfunction getId(prefix) {\n  if (prefix === undefined) {\n    prefix = 'wavesurfer_';\n  }\n\n  return prefix + Math.random().toString(32).substring(2);\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/index.js\":\n/*!***************************!*\\\n  !*** ./src/util/index.js ***!\n  \\***************************/\n/***/ ((__unused_webpack_module, exports, __nested_webpack_require_98203__) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nObject.defineProperty(exports, \"getId\", ({\n  enumerable: true,\n  get: function get() {\n    return _getId.default;\n  }\n}));\nObject.defineProperty(exports, \"max\", ({\n  enumerable: true,\n  get: function get() {\n    return _max.default;\n  }\n}));\nObject.defineProperty(exports, \"min\", ({\n  enumerable: true,\n  get: function get() {\n    return _min.default;\n  }\n}));\nObject.defineProperty(exports, \"absMax\", ({\n  enumerable: true,\n  get: function get() {\n    return _absMax.default;\n  }\n}));\nObject.defineProperty(exports, \"Observer\", ({\n  enumerable: true,\n  get: function get() {\n    return _observer.default;\n  }\n}));\nObject.defineProperty(exports, \"style\", ({\n  enumerable: true,\n  get: function get() {\n    return _style.default;\n  }\n}));\nObject.defineProperty(exports, \"requestAnimationFrame\", ({\n  enumerable: true,\n  get: function get() {\n    return _requestAnimationFrame.default;\n  }\n}));\nObject.defineProperty(exports, \"frame\", ({\n  enumerable: true,\n  get: function get() {\n    return _frame.default;\n  }\n}));\nObject.defineProperty(exports, \"debounce\", ({\n  enumerable: true,\n  get: function get() {\n    return _debounce.default;\n  }\n}));\nObject.defineProperty(exports, \"preventClick\", ({\n  enumerable: true,\n  get: function get() {\n    return _preventClick.default;\n  }\n}));\nObject.defineProperty(exports, \"fetchFile\", ({\n  enumerable: true,\n  get: function get() {\n    return _fetch.default;\n  }\n}));\nObject.defineProperty(exports, \"clamp\", ({\n  enumerable: true,\n  get: function get() {\n    return _clamp.default;\n  }\n}));\nObject.defineProperty(exports, \"withOrientation\", ({\n  enumerable: true,\n  get: function get() {\n    return _orientation.default;\n  }\n}));\nObject.defineProperty(exports, \"ignoreSilenceMode\", ({\n  enumerable: true,\n  get: function get() {\n    return _silenceMode.default;\n  }\n}));\n\nvar _getId = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./get-id */ \"./src/util/get-id.js\"));\n\nvar _max = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./max */ \"./src/util/max.js\"));\n\nvar _min = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./min */ \"./src/util/min.js\"));\n\nvar _absMax = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./absMax */ \"./src/util/absMax.js\"));\n\nvar _observer = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./observer */ \"./src/util/observer.js\"));\n\nvar _style = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./style */ \"./src/util/style.js\"));\n\nvar _requestAnimationFrame = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./request-animation-frame */ \"./src/util/request-animation-frame.js\"));\n\nvar _frame = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./frame */ \"./src/util/frame.js\"));\n\nvar _debounce = _interopRequireDefault(__nested_webpack_require_98203__(/*! debounce */ \"./node_modules/debounce/index.js\"));\n\nvar _preventClick = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./prevent-click */ \"./src/util/prevent-click.js\"));\n\nvar _fetch = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./fetch */ \"./src/util/fetch.js\"));\n\nvar _clamp = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./clamp */ \"./src/util/clamp.js\"));\n\nvar _orientation = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./orientation */ \"./src/util/orientation.js\"));\n\nvar _silenceMode = _interopRequireDefault(__nested_webpack_require_98203__(/*! ./silence-mode */ \"./src/util/silence-mode.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\n/***/ }),\n\n/***/ \"./src/util/max.js\":\n/*!*************************!*\\\n  !*** ./src/util/max.js ***!\n  \\*************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = max;\n\n/**\n * Get the largest value\n *\n * @param   {Array} values Array of numbers\n * @returns {Number} Largest number found\n * @example console.log(max([1, 2, 3])); // logs 3\n */\nfunction max(values) {\n  var largest = -Infinity;\n  Object.keys(values).forEach(function (i) {\n    if (values[i] > largest) {\n      largest = values[i];\n    }\n  });\n  return largest;\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/min.js\":\n/*!*************************!*\\\n  !*** ./src/util/min.js ***!\n  \\*************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = min;\n\n/**\n * Get the smallest value\n *\n * @param   {Array} values Array of numbers\n * @returns {Number} Smallest number found\n * @example console.log(min([1, 2, 3])); // logs 1\n */\nfunction min(values) {\n  var smallest = Number(Infinity);\n  Object.keys(values).forEach(function (i) {\n    if (values[i] < smallest) {\n      smallest = values[i];\n    }\n  });\n  return smallest;\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/observer.js\":\n/*!******************************!*\\\n  !*** ./src/util/observer.js ***!\n  \\******************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\n/**\n * @typedef {Object} ListenerDescriptor\n * @property {string} name The name of the event\n * @property {function} callback The callback\n * @property {function} un The function to call to remove the listener\n */\n\n/**\n * Observer class\n */\nvar Observer = /*#__PURE__*/function () {\n  /**\n   * Instantiate Observer\n   */\n  function Observer() {\n    _classCallCheck(this, Observer);\n\n    /**\n     * @private\n     * @todo Initialise the handlers here already and remove the conditional\n     * assignment in `on()`\n     */\n    this._disabledEventEmissions = [];\n    this.handlers = null;\n  }\n  /**\n   * Attach a handler function for an event.\n   *\n   * @param {string} event Name of the event to listen to\n   * @param {function} fn The callback to trigger when the event is fired\n   * @return {ListenerDescriptor} The event descriptor\n   */\n\n\n  _createClass(Observer, [{\n    key: \"on\",\n    value: function on(event, fn) {\n      var _this = this;\n\n      if (!this.handlers) {\n        this.handlers = {};\n      }\n\n      var handlers = this.handlers[event];\n\n      if (!handlers) {\n        handlers = this.handlers[event] = [];\n      }\n\n      handlers.push(fn); // Return an event descriptor\n\n      return {\n        name: event,\n        callback: fn,\n        un: function un(e, fn) {\n          return _this.un(e, fn);\n        }\n      };\n    }\n    /**\n     * Remove an event handler.\n     *\n     * @param {string} event Name of the event the listener that should be\n     * removed listens to\n     * @param {function} fn The callback that should be removed\n     */\n\n  }, {\n    key: \"un\",\n    value: function un(event, fn) {\n      if (!this.handlers) {\n        return;\n      }\n\n      var handlers = this.handlers[event];\n      var i;\n\n      if (handlers) {\n        if (fn) {\n          for (i = handlers.length - 1; i >= 0; i--) {\n            if (handlers[i] == fn) {\n              handlers.splice(i, 1);\n            }\n          }\n        } else {\n          handlers.length = 0;\n        }\n      }\n    }\n    /**\n     * Remove all event handlers.\n     */\n\n  }, {\n    key: \"unAll\",\n    value: function unAll() {\n      this.handlers = null;\n    }\n    /**\n     * Attach a handler to an event. The handler is executed at most once per\n     * event type.\n     *\n     * @param {string} event The event to listen to\n     * @param {function} handler The callback that is only to be called once\n     * @return {ListenerDescriptor} The event descriptor\n     */\n\n  }, {\n    key: \"once\",\n    value: function once(event, handler) {\n      var _this2 = this;\n\n      var fn = function fn() {\n        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {\n          args[_key] = arguments[_key];\n        }\n\n        /*  eslint-disable no-invalid-this */\n        handler.apply(_this2, args);\n        /*  eslint-enable no-invalid-this */\n\n        setTimeout(function () {\n          _this2.un(event, fn);\n        }, 0);\n      };\n\n      return this.on(event, fn);\n    }\n    /**\n     * Disable firing a list of events by name. When specified, event handlers for any event type\n     * passed in here will not be called.\n     *\n     * @since 4.0.0\n     * @param {string[]} eventNames an array of event names to disable emissions for\n     * @example\n     * // disable seek and interaction events\n     * wavesurfer.setDisabledEventEmissions(['seek', 'interaction']);\n     */\n\n  }, {\n    key: \"setDisabledEventEmissions\",\n    value: function setDisabledEventEmissions(eventNames) {\n      this._disabledEventEmissions = eventNames;\n    }\n    /**\n     * plugins borrow part of this class without calling the constructor,\n     * so we have to be careful about _disabledEventEmissions\n     */\n\n  }, {\n    key: \"_isDisabledEventEmission\",\n    value: function _isDisabledEventEmission(event) {\n      return this._disabledEventEmissions && this._disabledEventEmissions.includes(event);\n    }\n    /**\n     * Manually fire an event\n     *\n     * @param {string} event The event to fire manually\n     * @param {...any} args The arguments with which to call the listeners\n     */\n\n  }, {\n    key: \"fireEvent\",\n    value: function fireEvent(event) {\n      for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {\n        args[_key2 - 1] = arguments[_key2];\n      }\n\n      if (!this.handlers || this._isDisabledEventEmission(event)) {\n        return;\n      }\n\n      var handlers = this.handlers[event];\n      handlers && handlers.forEach(function (fn) {\n        fn.apply(void 0, args);\n      });\n    }\n  }]);\n\n  return Observer;\n}();\n\nexports.default = Observer;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/orientation.js\":\n/*!*********************************!*\\\n  !*** ./src/util/orientation.js ***!\n  \\*********************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = withOrientation;\nvar verticalPropMap = {\n  width: 'height',\n  height: 'width',\n  overflowX: 'overflowY',\n  overflowY: 'overflowX',\n  clientWidth: 'clientHeight',\n  clientHeight: 'clientWidth',\n  clientX: 'clientY',\n  clientY: 'clientX',\n  scrollWidth: 'scrollHeight',\n  scrollLeft: 'scrollTop',\n  offsetLeft: 'offsetTop',\n  offsetTop: 'offsetLeft',\n  offsetHeight: 'offsetWidth',\n  offsetWidth: 'offsetHeight',\n  left: 'top',\n  right: 'bottom',\n  top: 'left',\n  bottom: 'right',\n  borderRightStyle: 'borderBottomStyle',\n  borderRightWidth: 'borderBottomWidth',\n  borderRightColor: 'borderBottomColor'\n};\n/**\n * Convert a horizontally-oriented property name to a vertical one.\n *\n * @param {string} prop A property name\n * @param {bool} vertical Whether the element is oriented vertically\n * @returns {string} prop, converted appropriately\n */\n\nfunction mapProp(prop, vertical) {\n  if (Object.prototype.hasOwnProperty.call(verticalPropMap, prop)) {\n    return vertical ? verticalPropMap[prop] : prop;\n  } else {\n    return prop;\n  }\n}\n\nvar isProxy = Symbol(\"isProxy\");\n/**\n * Returns an appropriately oriented object based on vertical.\n * If vertical is true, attribute getting and setting will be mapped through\n * verticalPropMap, so that e.g. getting the object's .width will give its\n * .height instead.\n * Certain methods of an oriented object will return oriented objects as well.\n * Oriented objects can't be added to the DOM directly since they are Proxy objects\n * and thus fail typechecks. Use domElement to get the actual element for this.\n *\n * @param {object} target The object to be wrapped and oriented\n * @param {bool} vertical Whether the element is oriented vertically\n * @returns {Proxy} An oriented object with attr translation via verticalAttrMap\n * @since 5.0.0\n */\n\nfunction withOrientation(target, vertical) {\n  if (target[isProxy]) {\n    return target;\n  } else {\n    return new Proxy(target, {\n      get: function get(obj, prop, receiver) {\n        if (prop === isProxy) {\n          return true;\n        } else if (prop === 'domElement') {\n          return obj;\n        } else if (prop === 'style') {\n          return withOrientation(obj.style, vertical);\n        } else if (prop === 'canvas') {\n          return withOrientation(obj.canvas, vertical);\n        } else if (prop === 'getBoundingClientRect') {\n          return function () {\n            return withOrientation(obj.getBoundingClientRect.apply(obj, arguments), vertical);\n          };\n        } else if (prop === 'getContext') {\n          return function () {\n            return withOrientation(obj.getContext.apply(obj, arguments), vertical);\n          };\n        } else {\n          var value = obj[mapProp(prop, vertical)];\n          return typeof value == 'function' ? value.bind(obj) : value;\n        }\n      },\n      set: function set(obj, prop, value) {\n        obj[mapProp(prop, vertical)] = value;\n        return true;\n      }\n    });\n  }\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/prevent-click.js\":\n/*!***********************************!*\\\n  !*** ./src/util/prevent-click.js ***!\n  \\***********************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = preventClick;\n\n/**\n * Stops propagation of click event and removes event listener\n *\n * @private\n * @param {object} event The click event\n */\nfunction preventClickHandler(event) {\n  event.stopPropagation();\n  document.body.removeEventListener('click', preventClickHandler, true);\n}\n/**\n * Starts listening for click event and prevent propagation\n *\n * @param {object} values Values\n */\n\n\nfunction preventClick(values) {\n  document.body.addEventListener('click', preventClickHandler, true);\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/request-animation-frame.js\":\n/*!*********************************************!*\\\n  !*** ./src/util/request-animation-frame.js ***!\n  \\*********************************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\n/* eslint-disable valid-jsdoc */\n\n/**\n * Returns the `requestAnimationFrame` function for the browser, or a shim with\n * `setTimeout` if the function is not found\n *\n * @return {function} Available `requestAnimationFrame` function for the browser\n */\nvar _default = (window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame || window.oRequestAnimationFrame || window.msRequestAnimationFrame || function (callback, element) {\n  return setTimeout(callback, 1000 / 60);\n}).bind(window);\n\nexports.default = _default;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/silence-mode.js\":\n/*!**********************************!*\\\n  !*** ./src/util/silence-mode.js ***!\n  \\**********************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = ignoreSilenceMode;\n\n/**\n * Ignores device silence mode when using the `WebAudio` backend.\n *\n * Many mobile devices contain a hardware button to mute the ringtone for incoming\n * calls and messages. Unfortunately, on some platforms like iOS, this also mutes\n * wavesurfer's audio when using the `WebAudio` backend. This function creates a\n * temporary `<audio>` element that makes sure the WebAudio backend keeps playing\n * when muting the device ringer.\n *\n * @since 5.2.0\n */\nfunction ignoreSilenceMode() {\n  // Set the src to a short bit of url encoded as a silent mp3\n  // NOTE The silence MP3 must be high quality, when web audio sounds are played\n  // in parallel the web audio sound is mixed to match the bitrate of the html sound\n  // 0.01 seconds of silence VBR220-260 Joint Stereo 859B\n  var audioData = \"data:audio/mpeg;base64,//uQxAAAAAAAAAAAAAAAAAAAAAAAWGluZwAAAA8AAAACAAACcQCAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICA//////////////////////////////////////////////////////////////////8AAABhTEFNRTMuMTAwA8MAAAAAAAAAABQgJAUHQQAB9AAAAnGMHkkIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA//sQxAADgnABGiAAQBCqgCRMAAgEAH///////////////7+n/9FTuQsQH//////2NG0jWUGlio5gLQTOtIoeR2WX////X4s9Atb/JRVCbBUpeRUq//////////////////9RUi0f2jn/+xDECgPCjAEQAABN4AAANIAAAAQVTEFNRTMuMTAwVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVQ==\"; // disable iOS Airplay (setting the attribute in js doesn't work)\n\n  var tmp = document.createElement(\"div\");\n  tmp.innerHTML = '<audio x-webkit-airplay=\"deny\"></audio>';\n  var audioSilentMode = tmp.children.item(0);\n  audioSilentMode.src = audioData;\n  audioSilentMode.preload = \"auto\";\n  audioSilentMode.type = \"audio/mpeg\";\n  audioSilentMode.disableRemotePlayback = true; // play\n\n  audioSilentMode.play(); // cleanup\n\n  audioSilentMode.remove();\n  tmp.remove();\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/util/style.js\":\n/*!***************************!*\\\n  !*** ./src/util/style.js ***!\n  \\***************************/\n/***/ ((module, exports) => {\n\n\"use strict\";\n\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = style;\n\n/**\n * Apply a map of styles to an element\n *\n * @param {HTMLElement} el The element that the styles will be applied to\n * @param {Object} styles The map of propName: attribute, both are used as-is\n *\n * @return {HTMLElement} el\n */\nfunction style(el, styles) {\n  Object.keys(styles).forEach(function (prop) {\n    if (el.style[prop] !== styles[prop]) {\n      el.style[prop] = styles[prop];\n    }\n  });\n  return el;\n}\n\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/wavesurfer.js\":\n/*!***************************!*\\\n  !*** ./src/wavesurfer.js ***!\n  \\***************************/\n/***/ ((module, exports, __nested_webpack_require_117085__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar util = _interopRequireWildcard(__nested_webpack_require_117085__(/*! ./util */ \"./src/util/index.js\"));\n\nvar _drawer = _interopRequireDefault(__nested_webpack_require_117085__(/*! ./drawer.multicanvas */ \"./src/drawer.multicanvas.js\"));\n\nvar _webaudio = _interopRequireDefault(__nested_webpack_require_117085__(/*! ./webaudio */ \"./src/webaudio.js\"));\n\nvar _mediaelement = _interopRequireDefault(__nested_webpack_require_117085__(/*! ./mediaelement */ \"./src/mediaelement.js\"));\n\nvar _peakcache = _interopRequireDefault(__nested_webpack_require_117085__(/*! ./peakcache */ \"./src/peakcache.js\"));\n\nvar _mediaelementWebaudio = _interopRequireDefault(__nested_webpack_require_117085__(/*! ./mediaelement-webaudio */ \"./src/mediaelement-webaudio.js\"));\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== \"function\") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }\n\nfunction _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== \"default\" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\n/*\n * This work is licensed under a BSD-3-Clause License.\n */\n\n/** @external {HTMLElement} https://developer.mozilla.org/en/docs/Web/API/HTMLElement */\n\n/** @external {OfflineAudioContext} https://developer.mozilla.org/en-US/docs/Web/API/OfflineAudioContext */\n\n/** @external {File} https://developer.mozilla.org/en-US/docs/Web/API/File */\n\n/** @external {Blob} https://developer.mozilla.org/en-US/docs/Web/API/Blob */\n\n/** @external {CanvasRenderingContext2D} https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D */\n\n/** @external {MediaStreamConstraints} https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamConstraints */\n\n/** @external {AudioNode} https://developer.mozilla.org/de/docs/Web/API/AudioNode */\n\n/**\n * @typedef {Object} WavesurferParams\n * @property {AudioContext} audioContext=null Use your own previously\n * initialized AudioContext or leave blank.\n * @property {number} audioRate=1 Speed at which to play audio. Lower number is\n * slower.\n * @property {ScriptProcessorNode} audioScriptProcessor=null Use your own previously\n * initialized ScriptProcessorNode or leave blank.\n * @property {boolean} autoCenter=true If a scrollbar is present, center the\n * waveform on current progress\n * @property {number} autoCenterRate=5 If autoCenter is active, rate at which the\n * waveform is centered\n * @property {boolean} autoCenterImmediately=false If autoCenter is active, immediately\n * center waveform on current progress\n * @property {string} backend='WebAudio' `'WebAudio'|'MediaElement'|'MediaElementWebAudio'` In most cases\n * you don't have to set this manually. MediaElement is a fallback for unsupported browsers.\n * MediaElementWebAudio allows to use WebAudio API also with big audio files, loading audio like with\n * MediaElement backend (HTML5 audio tag). You have to use the same methods of MediaElement backend for loading and\n * playback, giving also peaks, so the audio data are not decoded. In this way you can use WebAudio features, like filters,\n * also with audio with big duration. For example:\n * ` wavesurfer.load(url | HTMLMediaElement, peaks, preload, duration);\n *   wavesurfer.play();\n *   wavesurfer.setFilter(customFilter);\n * `\n * @property {string} backgroundColor=null Change background color of the\n * waveform container.\n * @property {number} barHeight=1 The height of the wave bars.\n * @property {number} barRadius=0 The radius of the wave bars. Makes bars rounded\n * @property {number} barGap=null The optional spacing between bars of the wave,\n * if not provided will be calculated in legacy format.\n * @property {number} barWidth=null Draw the waveform using bars.\n * @property {number} barMinHeight=null If specified, draw at least a bar of this height,\n * eliminating waveform gaps\n * @property {boolean} closeAudioContext=false Close and nullify all audio\n * contexts when the destroy method is called.\n * @property {!string|HTMLElement} container CSS selector or HTML element where\n * the waveform should be drawn. This is the only required parameter.\n * @property {string} cursorColor='#333' The fill color of the cursor indicating\n * the playhead position.\n * @property {number} cursorWidth=1 Measured in pixels.\n * @property {object} drawingContextAttributes={desynchronized: false} Drawing context\n * attributes.\n * @property {number} duration=null Optional audio length so pre-rendered peaks\n * can be display immediately for example.\n * @property {boolean} fillParent=true Whether to fill the entire container or\n * draw only according to `minPxPerSec`.\n * @property {boolean} forceDecode=false Force decoding of audio using web audio\n * when zooming to get a more detailed waveform.\n * @property {number} height=128 The height of the waveform. Measured in\n * pixels.\n * @property {boolean} hideScrollbar=false Whether to hide the horizontal\n * scrollbar when one would normally be shown.\n * @property {boolean} ignoreSilenceMode=false If true, ignores device silence mode\n * when using the `WebAudio` backend.\n * @property {boolean} interact=true Whether the mouse interaction will be\n * enabled at initialization. You can switch this parameter at any time later\n * on.\n * @property {boolean} loopSelection=true (Use with regions plugin) Enable\n * looping of selected regions\n * @property {number} maxCanvasWidth=4000 Maximum width of a single canvas in\n * pixels, excluding a small overlap (2 * `pixelRatio`, rounded up to the next\n * even integer). If the waveform is longer than this value, additional canvases\n * will be used to render the waveform, which is useful for very large waveforms\n * that may be too wide for browsers to draw on a single canvas.\n * @property {boolean} mediaControls=false (Use with backend `MediaElement` or `MediaElementWebAudio`)\n * this enables the native controls for the media element\n * @property {string} mediaType='audio' (Use with backend `MediaElement` or `MediaElementWebAudio`)\n * `'audio'|'video'` ('video' only for `MediaElement`)\n * @property {number} minPxPerSec=20 Minimum number of pixels per second of\n * audio.\n * @property {boolean} normalize=false If true, normalize by the maximum peak\n * instead of 1.0.\n * @property {boolean} partialRender=false Use the PeakCache to improve\n * rendering speed of large waveforms\n * @property {number} pixelRatio=window.devicePixelRatio The pixel ratio used to\n * calculate display\n * @property {PluginDefinition[]} plugins=[] An array of plugin definitions to\n * register during instantiation, they will be directly initialised unless they\n * are added with the `deferInit` property set to true.\n * @property {string} progressColor='#555' The fill color of the part of the\n * waveform behind the cursor. When `progressColor` and `waveColor` are the same\n * the progress wave is not rendered at all.\n * @property {boolean} removeMediaElementOnDestroy=true Set to false to keep the\n * media element in the DOM when the player is destroyed. This is useful when\n * reusing an existing media element via the `loadMediaElement` method.\n * @property {Object} renderer=MultiCanvas Can be used to inject a custom\n * renderer.\n * @property {boolean|number} responsive=false If set to `true` resize the\n * waveform, when the window is resized. This is debounced with a `100ms`\n * timeout by default. If this parameter is a number it represents that timeout.\n * @property {boolean} rtl=false If set to `true`, renders waveform from\n * right-to-left.\n * @property {boolean} scrollParent=false Whether to scroll the container with a\n * lengthy waveform. Otherwise the waveform is shrunk to the container width\n * (see fillParent).\n * @property {number} skipLength=2 Number of seconds to skip with the\n * skipForward() and skipBackward() methods.\n * @property {boolean} splitChannels=false Render with separate waveforms for\n * the channels of the audio\n * @property {SplitChannelOptions} splitChannelsOptions={} Options for splitChannel rendering\n * @property {boolean} vertical=false Render the waveform vertically instead of horizontally.\n * @property {string} waveColor='#999' The fill color of the waveform after the\n * cursor.\n * @property {object} xhr={} XHR options. For example:\n * `let xhr = {\n *     cache: 'default',\n *     mode: 'cors',\n *     method: 'GET',\n *     credentials: 'same-origin',\n *     redirect: 'follow',\n *     referrer: 'client',\n *     requestHeaders: [\n *         {\n *             key: 'Authorization',\n *             value: 'my-token'\n *         }\n *     ]\n * };`\n */\n\n/**\n * @typedef {Object} PluginDefinition\n * @desc The Object used to describe a plugin\n * @example wavesurfer.addPlugin(pluginDefinition);\n * @property {string} name The name of the plugin, the plugin instance will be\n * added as a property to the wavesurfer instance under this name\n * @property {?Object} staticProps The properties that should be added to the\n * wavesurfer instance as static properties\n * @property {?boolean} deferInit Don't initialise plugin\n * automatically\n * @property {Object} params={} The plugin parameters, they are the first parameter\n * passed to the plugin class constructor function\n * @property {PluginClass} instance The plugin instance factory, is called with\n * the dependency specified in extends. Returns the plugin class.\n */\n\n/**\n * @typedef {Object} SplitChannelOptions\n * @desc parameters applied when splitChannels option is true\n * @property {boolean} overlay=false determines whether channels are rendered on top of each other or on separate tracks\n * @property {object} channelColors={} object describing color for each channel. Example:\n * {\n *     0: {\n *         progressColor: 'green',\n *         waveColor: 'pink'\n *     },\n *     1: {\n *         progressColor: 'orange',\n *         waveColor: 'purple'\n *     }\n * }\n * @property {number[]} filterChannels=[] indexes of channels to be hidden from rendering\n * @property {boolean} relativeNormalization=false determines whether\n * normalization is done per channel or maintains proportionality between\n * channels. Only applied when normalize and splitChannels are both true.\n * @since 4.3.0\n */\n\n/**\n * @interface PluginClass\n *\n * @desc This is the interface which is implemented by all plugin classes. Note\n * that this only turns into an observer after being passed through\n * `wavesurfer.addPlugin`.\n *\n * @extends {Observer}\n */\nvar PluginClass = /*#__PURE__*/function () {\n  /**\n   * Construct the plugin\n   *\n   * @param {Object} params={} The plugin params (specific to the plugin)\n   * @param {Object} ws The wavesurfer instance\n   */\n  function PluginClass(params, ws) {\n    _classCallCheck(this, PluginClass);\n  }\n  /**\n   * Initialise the plugin\n   *\n   * Start doing something. This is called by\n   * `wavesurfer.initPlugin(pluginName)`\n   */\n\n\n  _createClass(PluginClass, [{\n    key: \"create\",\n    value:\n    /**\n     * Plugin definition factory\n     *\n     * This function must be used to create a plugin definition which can be\n     * used by wavesurfer to correctly instantiate the plugin.\n     *\n     * It returns a `PluginDefinition` object representing the plugin.\n     *\n     * @param {Object} params={} The plugin params (specific to the plugin)\n     */\n    function create(params) {}\n  }, {\n    key: \"init\",\n    value: function init() {}\n    /**\n     * Destroy the plugin instance\n     *\n     * Stop doing something. This is called by\n     * `wavesurfer.destroyPlugin(pluginName)`\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {}\n  }]);\n\n  return PluginClass;\n}();\n/**\n * WaveSurfer core library class\n *\n * @extends {Observer}\n * @example\n * const params = {\n *   container: '#waveform',\n *   waveColor: 'violet',\n *   progressColor: 'purple'\n * };\n *\n * // initialise like this\n * const wavesurfer = WaveSurfer.create(params);\n *\n * // or like this ...\n * const wavesurfer = new WaveSurfer(params);\n * wavesurfer.init();\n *\n * // load audio file\n * wavesurfer.load('example/media/demo.wav');\n */\n\n\nvar WaveSurfer = /*#__PURE__*/function (_util$Observer) {\n  _inherits(WaveSurfer, _util$Observer);\n\n  var _super = _createSuper(WaveSurfer);\n\n  /**\n   * Initialise wavesurfer instance\n   *\n   * @param {WavesurferParams} params Instantiation options for wavesurfer\n   * @example\n   * const wavesurfer = new WaveSurfer(params);\n   * @returns {this} Wavesurfer instance\n   */\n  function WaveSurfer(params) {\n    var _this;\n\n    _classCallCheck(this, WaveSurfer);\n\n    _this = _super.call(this);\n    /**\n     * Extract relevant parameters (or defaults)\n     * @private\n     */\n\n    _this.defaultParams = {\n      audioContext: null,\n      audioScriptProcessor: null,\n      audioRate: 1,\n      autoCenter: true,\n      autoCenterRate: 5,\n      autoCenterImmediately: false,\n      backend: 'WebAudio',\n      backgroundColor: null,\n      barHeight: 1,\n      barRadius: 0,\n      barGap: null,\n      barMinHeight: null,\n      container: null,\n      cursorColor: '#333',\n      cursorWidth: 1,\n      dragSelection: true,\n      drawingContextAttributes: {\n        // Boolean that hints the user agent to reduce the latency\n        // by desynchronizing the canvas paint cycle from the event\n        // loop\n        desynchronized: false\n      },\n      duration: null,\n      fillParent: true,\n      forceDecode: false,\n      height: 128,\n      hideScrollbar: false,\n      ignoreSilenceMode: false,\n      interact: true,\n      loopSelection: true,\n      maxCanvasWidth: 4000,\n      mediaContainer: null,\n      mediaControls: false,\n      mediaType: 'audio',\n      minPxPerSec: 20,\n      normalize: false,\n      partialRender: false,\n      pixelRatio: window.devicePixelRatio || screen.deviceXDPI / screen.logicalXDPI,\n      plugins: [],\n      progressColor: '#555',\n      removeMediaElementOnDestroy: true,\n      renderer: _drawer.default,\n      responsive: false,\n      rtl: false,\n      scrollParent: false,\n      skipLength: 2,\n      splitChannels: false,\n      splitChannelsOptions: {\n        overlay: false,\n        channelColors: {},\n        filterChannels: [],\n        relativeNormalization: false\n      },\n      vertical: false,\n      waveColor: '#999',\n      xhr: {}\n    };\n    _this.backends = {\n      MediaElement: _mediaelement.default,\n      WebAudio: _webaudio.default,\n      MediaElementWebAudio: _mediaelementWebaudio.default\n    };\n    _this.util = util;\n    _this.params = Object.assign({}, _this.defaultParams, params);\n    _this.params.splitChannelsOptions = Object.assign({}, _this.defaultParams.splitChannelsOptions, params.splitChannelsOptions);\n    /** @private */\n\n    _this.container = 'string' == typeof params.container ? document.querySelector(_this.params.container) : _this.params.container;\n\n    if (!_this.container) {\n      throw new Error('Container element not found');\n    }\n\n    if (_this.params.mediaContainer == null) {\n      /** @private */\n      _this.mediaContainer = _this.container;\n    } else if (typeof _this.params.mediaContainer == 'string') {\n      /** @private */\n      _this.mediaContainer = document.querySelector(_this.params.mediaContainer);\n    } else {\n      /** @private */\n      _this.mediaContainer = _this.params.mediaContainer;\n    }\n\n    if (!_this.mediaContainer) {\n      throw new Error('Media Container element not found');\n    }\n\n    if (_this.params.maxCanvasWidth <= 1) {\n      throw new Error('maxCanvasWidth must be greater than 1');\n    } else if (_this.params.maxCanvasWidth % 2 == 1) {\n      throw new Error('maxCanvasWidth must be an even number');\n    }\n\n    if (_this.params.rtl === true) {\n      if (_this.params.vertical === true) {\n        util.style(_this.container, {\n          transform: 'rotateX(180deg)'\n        });\n      } else {\n        util.style(_this.container, {\n          transform: 'rotateY(180deg)'\n        });\n      }\n    }\n\n    if (_this.params.backgroundColor) {\n      _this.setBackgroundColor(_this.params.backgroundColor);\n    }\n    /**\n     * @private Used to save the current volume when muting so we can\n     * restore once unmuted\n     * @type {number}\n     */\n\n\n    _this.savedVolume = 0;\n    /**\n     * @private The current muted state\n     * @type {boolean}\n     */\n\n    _this.isMuted = false;\n    /**\n     * @private Will hold a list of event descriptors that need to be\n     * canceled on subsequent loads of audio\n     * @type {Object[]}\n     */\n\n    _this.tmpEvents = [];\n    /**\n     * @private Holds any running audio downloads\n     * @type {Observer}\n     */\n\n    _this.currentRequest = null;\n    /** @private */\n\n    _this.arraybuffer = null;\n    /** @private */\n\n    _this.drawer = null;\n    /** @private */\n\n    _this.backend = null;\n    /** @private */\n\n    _this.peakCache = null; // cache constructor objects\n\n    if (typeof _this.params.renderer !== 'function') {\n      throw new Error('Renderer parameter is invalid');\n    }\n    /**\n     * @private The uninitialised Drawer class\n     */\n\n\n    _this.Drawer = _this.params.renderer;\n    /**\n     * @private The uninitialised Backend class\n     */\n    // Back compat\n\n    if (_this.params.backend == 'AudioElement') {\n      _this.params.backend = 'MediaElement';\n    }\n\n    if ((_this.params.backend == 'WebAudio' || _this.params.backend === 'MediaElementWebAudio') && !_webaudio.default.prototype.supportsWebAudio.call(null)) {\n      _this.params.backend = 'MediaElement';\n    }\n\n    _this.Backend = _this.backends[_this.params.backend];\n    /**\n     * @private map of plugin names that are currently initialised\n     */\n\n    _this.initialisedPluginList = {};\n    /** @private */\n\n    _this.isDestroyed = false;\n    /**\n     * Get the current ready status.\n     *\n     * @example const isReady = wavesurfer.isReady;\n     * @return {boolean}\n     */\n\n    _this.isReady = false; // responsive debounced event listener. If this.params.responsive is not\n    // set, this is never called. Use 100ms or this.params.responsive as\n    // timeout for the debounce function.\n\n    var prevWidth = 0;\n    _this._onResize = util.debounce(function () {\n      if (prevWidth != _this.drawer.wrapper.clientWidth && !_this.params.scrollParent) {\n        prevWidth = _this.drawer.wrapper.clientWidth;\n\n        _this.drawer.fireEvent('redraw');\n      }\n    }, typeof _this.params.responsive === 'number' ? _this.params.responsive : 100);\n    return _possibleConstructorReturn(_this, _assertThisInitialized(_this));\n  }\n  /**\n   * Initialise the wave\n   *\n   * @example\n   * var wavesurfer = new WaveSurfer(params);\n   * wavesurfer.init();\n   * @return {this} The wavesurfer instance\n   */\n\n\n  _createClass(WaveSurfer, [{\n    key: \"init\",\n    value: function init() {\n      this.registerPlugins(this.params.plugins);\n      this.createDrawer();\n      this.createBackend();\n      this.createPeakCache();\n      return this;\n    }\n    /**\n     * Add and initialise array of plugins (if `plugin.deferInit` is falsey),\n     * this function is called in the init function of wavesurfer\n     *\n     * @param {PluginDefinition[]} plugins An array of plugin definitions\n     * @emits {WaveSurfer#plugins-registered} Called with the array of plugin definitions\n     * @return {this} The wavesurfer instance\n     */\n\n  }, {\n    key: \"registerPlugins\",\n    value: function registerPlugins(plugins) {\n      var _this2 = this;\n\n      // first instantiate all the plugins\n      plugins.forEach(function (plugin) {\n        return _this2.addPlugin(plugin);\n      }); // now run the init functions\n\n      plugins.forEach(function (plugin) {\n        // call init function of the plugin if deferInit is falsey\n        // in that case you would manually use initPlugins()\n        if (!plugin.deferInit) {\n          _this2.initPlugin(plugin.name);\n        }\n      });\n      this.fireEvent('plugins-registered', plugins);\n      return this;\n    }\n    /**\n     * Get a map of plugin names that are currently initialised\n     *\n     * @example wavesurfer.getPlugins();\n     * @return {Object} Object with plugin names\n     */\n\n  }, {\n    key: \"getActivePlugins\",\n    value: function getActivePlugins() {\n      return this.initialisedPluginList;\n    }\n    /**\n     * Add a plugin object to wavesurfer\n     *\n     * @param {PluginDefinition} plugin A plugin definition\n     * @emits {WaveSurfer#plugin-added} Called with the name of the plugin that was added\n     * @example wavesurfer.addPlugin(WaveSurfer.minimap());\n     * @return {this} The wavesurfer instance\n     */\n\n  }, {\n    key: \"addPlugin\",\n    value: function addPlugin(plugin) {\n      var _this3 = this;\n\n      if (!plugin.name) {\n        throw new Error('Plugin does not have a name!');\n      }\n\n      if (!plugin.instance) {\n        throw new Error(\"Plugin \".concat(plugin.name, \" does not have an instance property!\"));\n      } // staticProps properties are applied to wavesurfer instance\n\n\n      if (plugin.staticProps) {\n        Object.keys(plugin.staticProps).forEach(function (pluginStaticProp) {\n          /**\n           * Properties defined in a plugin definition's `staticProps` property are added as\n           * staticProps properties of the WaveSurfer instance\n           */\n          _this3[pluginStaticProp] = plugin.staticProps[pluginStaticProp];\n        });\n      }\n\n      var Instance = plugin.instance; // turn the plugin instance into an observer\n\n      var observerPrototypeKeys = Object.getOwnPropertyNames(util.Observer.prototype);\n      observerPrototypeKeys.forEach(function (key) {\n        Instance.prototype[key] = util.Observer.prototype[key];\n      });\n      /**\n       * Instantiated plugin classes are added as a property of the wavesurfer\n       * instance\n       * @type {Object}\n       */\n\n      this[plugin.name] = new Instance(plugin.params || {}, this);\n      this.fireEvent('plugin-added', plugin.name);\n      return this;\n    }\n    /**\n     * Initialise a plugin\n     *\n     * @param {string} name A plugin name\n     * @emits WaveSurfer#plugin-initialised\n     * @example wavesurfer.initPlugin('minimap');\n     * @return {this} The wavesurfer instance\n     */\n\n  }, {\n    key: \"initPlugin\",\n    value: function initPlugin(name) {\n      if (!this[name]) {\n        throw new Error(\"Plugin \".concat(name, \" has not been added yet!\"));\n      }\n\n      if (this.initialisedPluginList[name]) {\n        // destroy any already initialised plugins\n        this.destroyPlugin(name);\n      }\n\n      this[name].init();\n      this.initialisedPluginList[name] = true;\n      this.fireEvent('plugin-initialised', name);\n      return this;\n    }\n    /**\n     * Destroy a plugin\n     *\n     * @param {string} name A plugin name\n     * @emits WaveSurfer#plugin-destroyed\n     * @example wavesurfer.destroyPlugin('minimap');\n     * @returns {this} The wavesurfer instance\n     */\n\n  }, {\n    key: \"destroyPlugin\",\n    value: function destroyPlugin(name) {\n      if (!this[name]) {\n        throw new Error(\"Plugin \".concat(name, \" has not been added yet and cannot be destroyed!\"));\n      }\n\n      if (!this.initialisedPluginList[name]) {\n        throw new Error(\"Plugin \".concat(name, \" is not active and cannot be destroyed!\"));\n      }\n\n      if (typeof this[name].destroy !== 'function') {\n        throw new Error(\"Plugin \".concat(name, \" does not have a destroy function!\"));\n      }\n\n      this[name].destroy();\n      delete this.initialisedPluginList[name];\n      this.fireEvent('plugin-destroyed', name);\n      return this;\n    }\n    /**\n     * Destroy all initialised plugins. Convenience function to use when\n     * wavesurfer is removed\n     *\n     * @private\n     */\n\n  }, {\n    key: \"destroyAllPlugins\",\n    value: function destroyAllPlugins() {\n      var _this4 = this;\n\n      Object.keys(this.initialisedPluginList).forEach(function (name) {\n        return _this4.destroyPlugin(name);\n      });\n    }\n    /**\n     * Create the drawer and draw the waveform\n     *\n     * @private\n     * @emits WaveSurfer#drawer-created\n     */\n\n  }, {\n    key: \"createDrawer\",\n    value: function createDrawer() {\n      var _this5 = this;\n\n      this.drawer = new this.Drawer(this.container, this.params);\n      this.drawer.init();\n      this.fireEvent('drawer-created', this.drawer);\n\n      if (this.params.responsive !== false) {\n        window.addEventListener('resize', this._onResize, true);\n        window.addEventListener('orientationchange', this._onResize, true);\n      }\n\n      this.drawer.on('redraw', function () {\n        _this5.drawBuffer();\n\n        _this5.drawer.progress(_this5.backend.getPlayedPercents());\n      }); // Click-to-seek\n\n      this.drawer.on('click', function (e, progress) {\n        setTimeout(function () {\n          return _this5.seekTo(progress);\n        }, 0);\n      }); // Relay the scroll event from the drawer\n\n      this.drawer.on('scroll', function (e) {\n        if (_this5.params.partialRender) {\n          _this5.drawBuffer();\n        }\n\n        _this5.fireEvent('scroll', e);\n      });\n    }\n    /**\n     * Create the backend\n     *\n     * @private\n     * @emits WaveSurfer#backend-created\n     */\n\n  }, {\n    key: \"createBackend\",\n    value: function createBackend() {\n      var _this6 = this;\n\n      if (this.backend) {\n        this.backend.destroy();\n      }\n\n      this.backend = new this.Backend(this.params);\n      this.backend.init();\n      this.fireEvent('backend-created', this.backend);\n      this.backend.on('finish', function () {\n        _this6.drawer.progress(_this6.backend.getPlayedPercents());\n\n        _this6.fireEvent('finish');\n      });\n      this.backend.on('play', function () {\n        return _this6.fireEvent('play');\n      });\n      this.backend.on('pause', function () {\n        return _this6.fireEvent('pause');\n      });\n      this.backend.on('audioprocess', function (time) {\n        _this6.drawer.progress(_this6.backend.getPlayedPercents());\n\n        _this6.fireEvent('audioprocess', time);\n      }); // only needed for MediaElement and MediaElementWebAudio backend\n\n      if (this.params.backend === 'MediaElement' || this.params.backend === 'MediaElementWebAudio') {\n        this.backend.on('seek', function () {\n          _this6.drawer.progress(_this6.backend.getPlayedPercents());\n        });\n        this.backend.on('volume', function () {\n          var newVolume = _this6.getVolume();\n\n          _this6.fireEvent('volume', newVolume);\n\n          if (_this6.backend.isMuted !== _this6.isMuted) {\n            _this6.isMuted = _this6.backend.isMuted;\n\n            _this6.fireEvent('mute', _this6.isMuted);\n          }\n        });\n      }\n    }\n    /**\n     * Create the peak cache\n     *\n     * @private\n     */\n\n  }, {\n    key: \"createPeakCache\",\n    value: function createPeakCache() {\n      if (this.params.partialRender) {\n        this.peakCache = new _peakcache.default();\n      }\n    }\n    /**\n     * Get the duration of the audio clip\n     *\n     * @example const duration = wavesurfer.getDuration();\n     * @return {number} Duration in seconds\n     */\n\n  }, {\n    key: \"getDuration\",\n    value: function getDuration() {\n      return this.backend.getDuration();\n    }\n    /**\n     * Get the current playback position\n     *\n     * @example const currentTime = wavesurfer.getCurrentTime();\n     * @return {number} Playback position in seconds\n     */\n\n  }, {\n    key: \"getCurrentTime\",\n    value: function getCurrentTime() {\n      return this.backend.getCurrentTime();\n    }\n    /**\n     * Set the current play time in seconds.\n     *\n     * @param {number} seconds A positive number in seconds. E.g. 10 means 10\n     * seconds, 60 means 1 minute\n     */\n\n  }, {\n    key: \"setCurrentTime\",\n    value: function setCurrentTime(seconds) {\n      if (seconds >= this.getDuration()) {\n        this.seekTo(1);\n      } else {\n        this.seekTo(seconds / this.getDuration());\n      }\n    }\n    /**\n     * Starts playback from the current position. Optional start and end\n     * measured in seconds can be used to set the range of audio to play.\n     *\n     * @param {?number} start Position to start at\n     * @param {?number} end Position to end at\n     * @emits WaveSurfer#interaction\n     * @return {Promise} Result of the backend play method\n     * @example\n     * // play from second 1 to 5\n     * wavesurfer.play(1, 5);\n     */\n\n  }, {\n    key: \"play\",\n    value: function play(start, end) {\n      var _this7 = this;\n\n      if (this.params.ignoreSilenceMode) {\n        // ignores device hardware silence mode\n        util.ignoreSilenceMode();\n      }\n\n      this.fireEvent('interaction', function () {\n        return _this7.play(start, end);\n      });\n      return this.backend.play(start, end);\n    }\n    /**\n     * Set a point in seconds for playback to stop at.\n     *\n     * @param {number} position Position (in seconds) to stop at\n     * @version 3.3.0\n     */\n\n  }, {\n    key: \"setPlayEnd\",\n    value: function setPlayEnd(position) {\n      this.backend.setPlayEnd(position);\n    }\n    /**\n     * Stops and pauses playback\n     *\n     * @example wavesurfer.pause();\n     * @return {Promise} Result of the backend pause method\n     */\n\n  }, {\n    key: \"pause\",\n    value: function pause() {\n      if (!this.backend.isPaused()) {\n        return this.backend.pause();\n      }\n    }\n    /**\n     * Toggle playback\n     *\n     * @example wavesurfer.playPause();\n     * @return {Promise} Result of the backend play or pause method\n     */\n\n  }, {\n    key: \"playPause\",\n    value: function playPause() {\n      return this.backend.isPaused() ? this.play() : this.pause();\n    }\n    /**\n     * Get the current playback state\n     *\n     * @example const isPlaying = wavesurfer.isPlaying();\n     * @return {boolean} False if paused, true if playing\n     */\n\n  }, {\n    key: \"isPlaying\",\n    value: function isPlaying() {\n      return !this.backend.isPaused();\n    }\n    /**\n     * Skip backward\n     *\n     * @param {?number} seconds Amount to skip back, if not specified `skipLength`\n     * is used\n     * @example wavesurfer.skipBackward();\n     */\n\n  }, {\n    key: \"skipBackward\",\n    value: function skipBackward(seconds) {\n      this.skip(-seconds || -this.params.skipLength);\n    }\n    /**\n     * Skip forward\n     *\n     * @param {?number} seconds Amount to skip back, if not specified `skipLength`\n     * is used\n     * @example wavesurfer.skipForward();\n     */\n\n  }, {\n    key: \"skipForward\",\n    value: function skipForward(seconds) {\n      this.skip(seconds || this.params.skipLength);\n    }\n    /**\n     * Skip a number of seconds from the current position (use a negative value\n     * to go backwards).\n     *\n     * @param {number} offset Amount to skip back or forwards\n     * @example\n     * // go back 2 seconds\n     * wavesurfer.skip(-2);\n     */\n\n  }, {\n    key: \"skip\",\n    value: function skip(offset) {\n      var duration = this.getDuration() || 1;\n      var position = this.getCurrentTime() || 0;\n      position = Math.max(0, Math.min(duration, position + (offset || 0)));\n      this.seekAndCenter(position / duration);\n    }\n    /**\n     * Seeks to a position and centers the view\n     *\n     * @param {number} progress Between 0 (=beginning) and 1 (=end)\n     * @example\n     * // seek and go to the middle of the audio\n     * wavesurfer.seekTo(0.5);\n     */\n\n  }, {\n    key: \"seekAndCenter\",\n    value: function seekAndCenter(progress) {\n      this.seekTo(progress);\n      this.drawer.recenter(progress);\n    }\n    /**\n     * Seeks to a position\n     *\n     * @param {number} progress Between 0 (=beginning) and 1 (=end)\n     * @emits WaveSurfer#interaction\n     * @emits WaveSurfer#seek\n     * @example\n     * // seek to the middle of the audio\n     * wavesurfer.seekTo(0.5);\n     */\n\n  }, {\n    key: \"seekTo\",\n    value: function seekTo(progress) {\n      var _this8 = this;\n\n      // return an error if progress is not a number between 0 and 1\n      if (typeof progress !== 'number' || !isFinite(progress) || progress < 0 || progress > 1) {\n        throw new Error('Error calling wavesurfer.seekTo, parameter must be a number between 0 and 1!');\n      }\n\n      this.fireEvent('interaction', function () {\n        return _this8.seekTo(progress);\n      });\n      var isWebAudioBackend = this.params.backend === 'WebAudio';\n      var paused = this.backend.isPaused();\n\n      if (isWebAudioBackend && !paused) {\n        this.backend.pause();\n      } // avoid small scrolls while paused seeking\n\n\n      var oldScrollParent = this.params.scrollParent;\n      this.params.scrollParent = false;\n      this.backend.seekTo(progress * this.getDuration());\n      this.drawer.progress(progress);\n\n      if (isWebAudioBackend && !paused) {\n        this.backend.play();\n      }\n\n      this.params.scrollParent = oldScrollParent;\n      this.fireEvent('seek', progress);\n    }\n    /**\n     * Stops and goes to the beginning.\n     *\n     * @example wavesurfer.stop();\n     */\n\n  }, {\n    key: \"stop\",\n    value: function stop() {\n      this.pause();\n      this.seekTo(0);\n      this.drawer.progress(0);\n    }\n    /**\n     * Sets the ID of the audio device to use for output and returns a Promise.\n     *\n     * @param {string} deviceId String value representing underlying output\n     * device\n     * @returns {Promise} `Promise` that resolves to `undefined` when there are\n     * no errors detected.\n     */\n\n  }, {\n    key: \"setSinkId\",\n    value: function setSinkId(deviceId) {\n      return this.backend.setSinkId(deviceId);\n    }\n    /**\n     * Set the playback volume.\n     *\n     * @param {number} newVolume A value between 0 and 1, 0 being no\n     * volume and 1 being full volume.\n     * @emits WaveSurfer#volume\n     */\n\n  }, {\n    key: \"setVolume\",\n    value: function setVolume(newVolume) {\n      this.backend.setVolume(newVolume);\n      this.fireEvent('volume', newVolume);\n    }\n    /**\n     * Get the playback volume.\n     *\n     * @return {number} A value between 0 and 1, 0 being no\n     * volume and 1 being full volume.\n     */\n\n  }, {\n    key: \"getVolume\",\n    value: function getVolume() {\n      return this.backend.getVolume();\n    }\n    /**\n     * Set the playback rate.\n     *\n     * @param {number} rate A positive number. E.g. 0.5 means half the normal\n     * speed, 2 means double speed and so on.\n     * @example wavesurfer.setPlaybackRate(2);\n     */\n\n  }, {\n    key: \"setPlaybackRate\",\n    value: function setPlaybackRate(rate) {\n      this.backend.setPlaybackRate(rate);\n    }\n    /**\n     * Get the playback rate.\n     *\n     * @return {number} The current playback rate.\n     */\n\n  }, {\n    key: \"getPlaybackRate\",\n    value: function getPlaybackRate() {\n      return this.backend.getPlaybackRate();\n    }\n    /**\n     * Toggle the volume on and off. If not currently muted it will save the\n     * current volume value and turn the volume off. If currently muted then it\n     * will restore the volume to the saved value, and then rest the saved\n     * value.\n     *\n     * @example wavesurfer.toggleMute();\n     */\n\n  }, {\n    key: \"toggleMute\",\n    value: function toggleMute() {\n      this.setMute(!this.isMuted);\n    }\n    /**\n     * Enable or disable muted audio\n     *\n     * @param {boolean} mute Specify `true` to mute audio.\n     * @emits WaveSurfer#volume\n     * @emits WaveSurfer#mute\n     * @example\n     * // unmute\n     * wavesurfer.setMute(false);\n     * console.log(wavesurfer.getMute()) // logs false\n     */\n\n  }, {\n    key: \"setMute\",\n    value: function setMute(mute) {\n      // ignore all muting requests if the audio is already in that state\n      if (mute === this.isMuted) {\n        this.fireEvent('mute', this.isMuted);\n        return;\n      }\n\n      if (this.backend.setMute) {\n        // Backends such as the MediaElement backend have their own handling\n        // of mute, let them handle it.\n        this.backend.setMute(mute);\n        this.isMuted = mute;\n      } else {\n        if (mute) {\n          // If currently not muted then save current volume,\n          // turn off the volume and update the mute properties\n          this.savedVolume = this.backend.getVolume();\n          this.backend.setVolume(0);\n          this.isMuted = true;\n          this.fireEvent('volume', 0);\n        } else {\n          // If currently muted then restore to the saved volume\n          // and update the mute properties\n          this.backend.setVolume(this.savedVolume);\n          this.isMuted = false;\n          this.fireEvent('volume', this.savedVolume);\n        }\n      }\n\n      this.fireEvent('mute', this.isMuted);\n    }\n    /**\n     * Get the current mute status.\n     *\n     * @example const isMuted = wavesurfer.getMute();\n     * @return {boolean} Current mute status\n     */\n\n  }, {\n    key: \"getMute\",\n    value: function getMute() {\n      return this.isMuted;\n    }\n    /**\n     * Get the list of current set filters as an array.\n     *\n     * Filters must be set with setFilters method first\n     *\n     * @return {array} List of enabled filters\n     */\n\n  }, {\n    key: \"getFilters\",\n    value: function getFilters() {\n      return this.backend.filters || [];\n    }\n    /**\n     * Toggles `scrollParent` and redraws\n     *\n     * @example wavesurfer.toggleScroll();\n     */\n\n  }, {\n    key: \"toggleScroll\",\n    value: function toggleScroll() {\n      this.params.scrollParent = !this.params.scrollParent;\n      this.drawBuffer();\n    }\n    /**\n     * Toggle mouse interaction\n     *\n     * @example wavesurfer.toggleInteraction();\n     */\n\n  }, {\n    key: \"toggleInteraction\",\n    value: function toggleInteraction() {\n      this.params.interact = !this.params.interact;\n    }\n    /**\n     * Get the fill color of the waveform after the cursor.\n     *\n     * @return {string} A CSS color string.\n     */\n\n  }, {\n    key: \"getWaveColor\",\n    value: function getWaveColor() {\n      return this.params.waveColor;\n    }\n    /**\n     * Set the fill color of the waveform after the cursor.\n     *\n     * @param {string} color A CSS color string.\n     * @example wavesurfer.setWaveColor('#ddd');\n     */\n\n  }, {\n    key: \"setWaveColor\",\n    value: function setWaveColor(color) {\n      this.params.waveColor = color;\n      this.drawBuffer();\n    }\n    /**\n     * Get the fill color of the waveform behind the cursor.\n     *\n     * @return {string} A CSS color string.\n     */\n\n  }, {\n    key: \"getProgressColor\",\n    value: function getProgressColor() {\n      return this.params.progressColor;\n    }\n    /**\n     * Set the fill color of the waveform behind the cursor.\n     *\n     * @param {string} color A CSS color string.\n     * @example wavesurfer.setProgressColor('#400');\n     */\n\n  }, {\n    key: \"setProgressColor\",\n    value: function setProgressColor(color) {\n      this.params.progressColor = color;\n      this.drawBuffer();\n    }\n    /**\n     * Get the background color of the waveform container.\n     *\n     * @return {string} A CSS color string.\n     */\n\n  }, {\n    key: \"getBackgroundColor\",\n    value: function getBackgroundColor() {\n      return this.params.backgroundColor;\n    }\n    /**\n     * Set the background color of the waveform container.\n     *\n     * @param {string} color A CSS color string.\n     * @example wavesurfer.setBackgroundColor('#FF00FF');\n     */\n\n  }, {\n    key: \"setBackgroundColor\",\n    value: function setBackgroundColor(color) {\n      this.params.backgroundColor = color;\n      util.style(this.container, {\n        background: this.params.backgroundColor\n      });\n    }\n    /**\n     * Get the fill color of the cursor indicating the playhead\n     * position.\n     *\n     * @return {string} A CSS color string.\n     */\n\n  }, {\n    key: \"getCursorColor\",\n    value: function getCursorColor() {\n      return this.params.cursorColor;\n    }\n    /**\n     * Set the fill color of the cursor indicating the playhead\n     * position.\n     *\n     * @param {string} color A CSS color string.\n     * @example wavesurfer.setCursorColor('#222');\n     */\n\n  }, {\n    key: \"setCursorColor\",\n    value: function setCursorColor(color) {\n      this.params.cursorColor = color;\n      this.drawer.updateCursor();\n    }\n    /**\n     * Get the height of the waveform.\n     *\n     * @return {number} Height measured in pixels.\n     */\n\n  }, {\n    key: \"getHeight\",\n    value: function getHeight() {\n      return this.params.height;\n    }\n    /**\n     * Set the height of the waveform.\n     *\n     * @param {number} height Height measured in pixels.\n     * @example wavesurfer.setHeight(200);\n     */\n\n  }, {\n    key: \"setHeight\",\n    value: function setHeight(height) {\n      this.params.height = height;\n      this.drawer.setHeight(height * this.params.pixelRatio);\n      this.drawBuffer();\n    }\n    /**\n     * Hide channels from being drawn on the waveform if splitting channels.\n     *\n     * For example, if we want to draw only the peaks for the right stereo channel:\n     *\n     * const wavesurfer = new WaveSurfer.create({...splitChannels: true});\n     * wavesurfer.load('stereo_audio.mp3');\n     *\n     * wavesurfer.setFilteredChannel([0]); <-- hide left channel peaks.\n     *\n     * @param {array} channelIndices Channels to be filtered out from drawing.\n     * @version 4.0.0\n     */\n\n  }, {\n    key: \"setFilteredChannels\",\n    value: function setFilteredChannels(channelIndices) {\n      this.params.splitChannelsOptions.filterChannels = channelIndices;\n      this.drawBuffer();\n    }\n    /**\n     * Get the correct peaks for current wave view-port and render wave\n     *\n     * @private\n     * @emits WaveSurfer#redraw\n     */\n\n  }, {\n    key: \"drawBuffer\",\n    value: function drawBuffer() {\n      var nominalWidth = Math.round(this.getDuration() * this.params.minPxPerSec * this.params.pixelRatio);\n      var parentWidth = this.drawer.getWidth();\n      var width = nominalWidth; // always start at 0 after zooming for scrolling : issue redraw left part\n\n      var start = 0;\n      var end = Math.max(start + parentWidth, width); // Fill container\n\n      if (this.params.fillParent && (!this.params.scrollParent || nominalWidth < parentWidth)) {\n        width = parentWidth;\n        start = 0;\n        end = width;\n      }\n\n      var peaks;\n\n      if (this.params.partialRender) {\n        var newRanges = this.peakCache.addRangeToPeakCache(width, start, end);\n        var i;\n\n        for (i = 0; i < newRanges.length; i++) {\n          peaks = this.backend.getPeaks(width, newRanges[i][0], newRanges[i][1]);\n          this.drawer.drawPeaks(peaks, width, newRanges[i][0], newRanges[i][1]);\n        }\n      } else {\n        peaks = this.backend.getPeaks(width, start, end);\n        this.drawer.drawPeaks(peaks, width, start, end);\n      }\n\n      this.fireEvent('redraw', peaks, width);\n    }\n    /**\n     * Horizontally zooms the waveform in and out. It also changes the parameter\n     * `minPxPerSec` and enables the `scrollParent` option. Calling the function\n     * with a falsey parameter will reset the zoom state.\n     *\n     * @param {?number} pxPerSec Number of horizontal pixels per second of\n     * audio, if none is set the waveform returns to unzoomed state\n     * @emits WaveSurfer#zoom\n     * @example wavesurfer.zoom(20);\n     */\n\n  }, {\n    key: \"zoom\",\n    value: function zoom(pxPerSec) {\n      if (!pxPerSec) {\n        this.params.minPxPerSec = this.defaultParams.minPxPerSec;\n        this.params.scrollParent = false;\n      } else {\n        this.params.minPxPerSec = pxPerSec;\n        this.params.scrollParent = true;\n      }\n\n      this.drawBuffer();\n      this.drawer.progress(this.backend.getPlayedPercents());\n      this.drawer.recenter(this.getCurrentTime() / this.getDuration());\n      this.fireEvent('zoom', pxPerSec);\n    }\n    /**\n     * Decode buffer and load\n     *\n     * @private\n     * @param {ArrayBuffer} arraybuffer Buffer to process\n     */\n\n  }, {\n    key: \"loadArrayBuffer\",\n    value: function loadArrayBuffer(arraybuffer) {\n      var _this9 = this;\n\n      this.decodeArrayBuffer(arraybuffer, function (data) {\n        if (!_this9.isDestroyed) {\n          _this9.loadDecodedBuffer(data);\n        }\n      });\n    }\n    /**\n     * Directly load an externally decoded AudioBuffer\n     *\n     * @private\n     * @param {AudioBuffer} buffer Buffer to process\n     * @emits WaveSurfer#ready\n     */\n\n  }, {\n    key: \"loadDecodedBuffer\",\n    value: function loadDecodedBuffer(buffer) {\n      this.backend.load(buffer);\n      this.drawBuffer();\n      this.isReady = true;\n      this.fireEvent('ready');\n    }\n    /**\n     * Loads audio data from a Blob or File object\n     *\n     * @param {Blob|File} blob Audio data\n     * @example\n     */\n\n  }, {\n    key: \"loadBlob\",\n    value: function loadBlob(blob) {\n      var _this10 = this;\n\n      // Create file reader\n      var reader = new FileReader();\n      reader.addEventListener('progress', function (e) {\n        return _this10.onProgress(e);\n      });\n      reader.addEventListener('load', function (e) {\n        return _this10.loadArrayBuffer(e.target.result);\n      });\n      reader.addEventListener('error', function () {\n        return _this10.fireEvent('error', 'Error reading file');\n      });\n      reader.readAsArrayBuffer(blob);\n      this.empty();\n    }\n    /**\n     * Loads audio and re-renders the waveform.\n     *\n     * @param {string|HTMLMediaElement} url The url of the audio file or the\n     * audio element with the audio\n     * @param {number[]|Number.<Array[]>} peaks Wavesurfer does not have to decode\n     * the audio to render the waveform if this is specified\n     * @param {?string} preload (Use with backend `MediaElement` and `MediaElementWebAudio`)\n     * `'none'|'metadata'|'auto'` Preload attribute for the media element\n     * @param {?number} duration The duration of the audio. This is used to\n     * render the peaks data in the correct size for the audio duration (as\n     * befits the current `minPxPerSec` and zoom value) without having to decode\n     * the audio.\n     * @returns {void}\n     * @throws Will throw an error if the `url` argument is empty.\n     * @example\n     * // uses fetch or media element to load file (depending on backend)\n     * wavesurfer.load('http://example.com/demo.wav');\n     *\n     * // setting preload attribute with media element backend and supplying\n     * // peaks\n     * wavesurfer.load(\n     *   'http://example.com/demo.wav',\n     *   [0.0218, 0.0183, 0.0165, 0.0198, 0.2137, 0.2888],\n     *   true\n     * );\n     */\n\n  }, {\n    key: \"load\",\n    value: function load(url, peaks, preload, duration) {\n      if (!url) {\n        throw new Error('url parameter cannot be empty');\n      }\n\n      this.empty();\n\n      if (preload) {\n        // check whether the preload attribute will be usable and if not log\n        // a warning listing the reasons why not and nullify the variable\n        var preloadIgnoreReasons = {\n          \"Preload is not 'auto', 'none' or 'metadata'\": ['auto', 'metadata', 'none'].indexOf(preload) === -1,\n          'Peaks are not provided': !peaks,\n          \"Backend is not of type 'MediaElement' or 'MediaElementWebAudio'\": ['MediaElement', 'MediaElementWebAudio'].indexOf(this.params.backend) === -1,\n          'Url is not of type string': typeof url !== 'string'\n        };\n        var activeReasons = Object.keys(preloadIgnoreReasons).filter(function (reason) {\n          return preloadIgnoreReasons[reason];\n        });\n\n        if (activeReasons.length) {\n          // eslint-disable-next-line no-console\n          console.warn('Preload parameter of wavesurfer.load will be ignored because:\\n\\t- ' + activeReasons.join('\\n\\t- ')); // stop invalid values from being used\n\n          preload = null;\n        }\n      } // loadBuffer(url, peaks, duration) requires that url is a string\n      // but users can pass in a HTMLMediaElement to WaveSurfer\n\n\n      if (this.params.backend === 'WebAudio' && url instanceof HTMLMediaElement) {\n        url = url.src;\n      }\n\n      switch (this.params.backend) {\n        case 'WebAudio':\n          return this.loadBuffer(url, peaks, duration);\n\n        case 'MediaElement':\n        case 'MediaElementWebAudio':\n          return this.loadMediaElement(url, peaks, preload, duration);\n      }\n    }\n    /**\n     * Loads audio using Web Audio buffer backend.\n     *\n     * @private\n     * @emits WaveSurfer#waveform-ready\n     * @param {string} url URL of audio file\n     * @param {number[]|Number.<Array[]>} peaks Peaks data\n     * @param {?number} duration Optional duration of audio file\n     * @returns {void}\n     */\n\n  }, {\n    key: \"loadBuffer\",\n    value: function loadBuffer(url, peaks, duration) {\n      var _this11 = this;\n\n      var load = function load(action) {\n        if (action) {\n          _this11.tmpEvents.push(_this11.once('ready', action));\n        }\n\n        return _this11.getArrayBuffer(url, function (data) {\n          return _this11.loadArrayBuffer(data);\n        });\n      };\n\n      if (peaks) {\n        this.backend.setPeaks(peaks, duration);\n        this.drawBuffer();\n        this.fireEvent('waveform-ready');\n        this.tmpEvents.push(this.once('interaction', load));\n      } else {\n        return load();\n      }\n    }\n    /**\n     * Either create a media element, or load an existing media element.\n     *\n     * @private\n     * @emits WaveSurfer#waveform-ready\n     * @param {string|HTMLMediaElement} urlOrElt Either a path to a media file, or an\n     * existing HTML5 Audio/Video Element\n     * @param {number[]|Number.<Array[]>} peaks Array of peaks. Required to bypass web audio\n     * dependency\n     * @param {?boolean} preload Set to true if the preload attribute of the\n     * audio element should be enabled\n     * @param {?number} duration Optional duration of audio file\n     */\n\n  }, {\n    key: \"loadMediaElement\",\n    value: function loadMediaElement(urlOrElt, peaks, preload, duration) {\n      var _this12 = this;\n\n      var url = urlOrElt;\n\n      if (typeof urlOrElt === 'string') {\n        this.backend.load(url, this.mediaContainer, peaks, preload);\n      } else {\n        var elt = urlOrElt;\n        this.backend.loadElt(elt, peaks); // If peaks are not provided,\n        // url = element.src so we can get peaks with web audio\n\n        url = elt.src;\n      }\n\n      this.tmpEvents.push(this.backend.once('canplay', function () {\n        // ignore when backend was already destroyed\n        if (!_this12.backend.destroyed) {\n          _this12.drawBuffer();\n\n          _this12.isReady = true;\n\n          _this12.fireEvent('ready');\n        }\n      }), this.backend.once('error', function (err) {\n        return _this12.fireEvent('error', err);\n      })); // If peaks are provided, render them and fire the `waveform-ready` event.\n\n      if (peaks) {\n        this.backend.setPeaks(peaks, duration);\n        this.drawBuffer();\n        this.fireEvent('waveform-ready');\n      } // If no pre-decoded peaks are provided, or are provided with\n      // forceDecode flag, attempt to download the audio file and decode it\n      // with Web Audio.\n\n\n      if ((!peaks || this.params.forceDecode) && this.backend.supportsWebAudio()) {\n        this.getArrayBuffer(url, function (arraybuffer) {\n          _this12.decodeArrayBuffer(arraybuffer, function (buffer) {\n            _this12.backend.buffer = buffer;\n\n            _this12.backend.setPeaks(null);\n\n            _this12.drawBuffer();\n\n            _this12.fireEvent('waveform-ready');\n          });\n        });\n      }\n    }\n    /**\n     * Decode an array buffer and pass data to a callback\n     *\n     * @private\n     * @param {Object} arraybuffer The array buffer to decode\n     * @param {function} callback The function to call on complete\n     */\n\n  }, {\n    key: \"decodeArrayBuffer\",\n    value: function decodeArrayBuffer(arraybuffer, callback) {\n      var _this13 = this;\n\n      if (!this.isDestroyed) {\n        this.arraybuffer = arraybuffer;\n        this.backend.decodeArrayBuffer(arraybuffer, function (data) {\n          // Only use the decoded data if we haven't been destroyed or\n          // another decode started in the meantime\n          if (!_this13.isDestroyed && _this13.arraybuffer == arraybuffer) {\n            callback(data);\n            _this13.arraybuffer = null;\n          }\n        }, function () {\n          return _this13.fireEvent('error', 'Error decoding audiobuffer');\n        });\n      }\n    }\n    /**\n     * Load an array buffer using fetch and pass the result to a callback\n     *\n     * @param {string} url The URL of the file object\n     * @param {function} callback The function to call on complete\n     * @returns {util.fetchFile} fetch call\n     * @private\n     */\n\n  }, {\n    key: \"getArrayBuffer\",\n    value: function getArrayBuffer(url, callback) {\n      var _this14 = this;\n\n      var options = Object.assign({\n        url: url,\n        responseType: 'arraybuffer'\n      }, this.params.xhr);\n      var request = util.fetchFile(options);\n      this.currentRequest = request;\n      this.tmpEvents.push(request.on('progress', function (e) {\n        _this14.onProgress(e);\n      }), request.on('success', function (data) {\n        callback(data);\n        _this14.currentRequest = null;\n      }), request.on('error', function (e) {\n        _this14.fireEvent('error', e);\n\n        _this14.currentRequest = null;\n      }));\n      return request;\n    }\n    /**\n     * Called while the audio file is loading\n     *\n     * @private\n     * @param {Event} e Progress event\n     * @emits WaveSurfer#loading\n     */\n\n  }, {\n    key: \"onProgress\",\n    value: function onProgress(e) {\n      var percentComplete;\n\n      if (e.lengthComputable) {\n        percentComplete = e.loaded / e.total;\n      } else {\n        // Approximate progress with an asymptotic\n        // function, and assume downloads in the 1-3 MB range.\n        percentComplete = e.loaded / (e.loaded + 1000000);\n      }\n\n      this.fireEvent('loading', Math.round(percentComplete * 100), e.target);\n    }\n    /**\n     * Exports PCM data into a JSON array and optionally opens in a new window\n     * as valid JSON Blob instance.\n     *\n     * @param {number} length=1024 The scale in which to export the peaks\n     * @param {number} accuracy=10000\n     * @param {?boolean} noWindow Set to true to disable opening a new\n     * window with the JSON\n     * @param {number} start Start index\n     * @param {number} end End index\n     * @return {Promise} Promise that resolves with array of peaks\n     */\n\n  }, {\n    key: \"exportPCM\",\n    value: function exportPCM(length, accuracy, noWindow, start, end) {\n      length = length || 1024;\n      start = start || 0;\n      accuracy = accuracy || 10000;\n      noWindow = noWindow || false;\n      var peaks = this.backend.getPeaks(length, start, end);\n      var arr = [].map.call(peaks, function (val) {\n        return Math.round(val * accuracy) / accuracy;\n      });\n      return new Promise(function (resolve, reject) {\n        if (!noWindow) {\n          var blobJSON = new Blob([JSON.stringify(arr)], {\n            type: 'application/json;charset=utf-8'\n          });\n          var objURL = URL.createObjectURL(blobJSON);\n          window.open(objURL);\n          URL.revokeObjectURL(objURL);\n        }\n\n        resolve(arr);\n      });\n    }\n    /**\n     * Save waveform image as data URI.\n     *\n     * The default format is `'image/png'`. Other supported types are\n     * `'image/jpeg'` and `'image/webp'`.\n     *\n     * @param {string} format='image/png' A string indicating the image format.\n     * The default format type is `'image/png'`.\n     * @param {number} quality=1 A number between 0 and 1 indicating the image\n     * quality to use for image formats that use lossy compression such as\n     * `'image/jpeg'`` and `'image/webp'`.\n     * @param {string} type Image data type to return. Either 'dataURL' (default)\n     * or 'blob'.\n     * @return {string|string[]|Promise} When using `'dataURL'` type this returns\n     * a single data URL or an array of data URLs, one for each canvas. When using\n     * `'blob'` type this returns a `Promise` resolving with an array of `Blob`\n     * instances, one for each canvas.\n     */\n\n  }, {\n    key: \"exportImage\",\n    value: function exportImage(format, quality, type) {\n      if (!format) {\n        format = 'image/png';\n      }\n\n      if (!quality) {\n        quality = 1;\n      }\n\n      if (!type) {\n        type = 'dataURL';\n      }\n\n      return this.drawer.getImage(format, quality, type);\n    }\n    /**\n     * Cancel any fetch request currently in progress\n     */\n\n  }, {\n    key: \"cancelAjax\",\n    value: function cancelAjax() {\n      if (this.currentRequest && this.currentRequest.controller) {\n        // If the current request has a ProgressHandler, then its ReadableStream might need to be cancelled too\n        // See: Wavesurfer issue #2042\n        // See Firefox bug: https://bugzilla.mozilla.org/show_bug.cgi?id=1583815\n        if (this.currentRequest._reader) {\n          // Ignoring exceptions thrown by call to cancel()\n          this.currentRequest._reader.cancel().catch(function (err) {});\n        }\n\n        this.currentRequest.controller.abort();\n        this.currentRequest = null;\n      }\n    }\n    /**\n     * @private\n     */\n\n  }, {\n    key: \"clearTmpEvents\",\n    value: function clearTmpEvents() {\n      this.tmpEvents.forEach(function (e) {\n        return e.un();\n      });\n    }\n    /**\n     * Display empty waveform.\n     */\n\n  }, {\n    key: \"empty\",\n    value: function empty() {\n      if (!this.backend.isPaused()) {\n        this.stop();\n        this.backend.disconnectSource();\n      }\n\n      this.isReady = false;\n      this.cancelAjax();\n      this.clearTmpEvents(); // empty drawer\n\n      this.drawer.progress(0);\n      this.drawer.setWidth(0);\n      this.drawer.drawPeaks({\n        length: this.drawer.getWidth()\n      }, 0);\n    }\n    /**\n     * Remove events, elements and disconnect WebAudio nodes.\n     *\n     * @emits WaveSurfer#destroy\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      this.destroyAllPlugins();\n      this.fireEvent('destroy');\n      this.cancelAjax();\n      this.clearTmpEvents();\n      this.unAll();\n\n      if (this.params.responsive !== false) {\n        window.removeEventListener('resize', this._onResize, true);\n        window.removeEventListener('orientationchange', this._onResize, true);\n      }\n\n      if (this.backend) {\n        this.backend.destroy(); // clears memory usage\n\n        this.backend = null;\n      }\n\n      if (this.drawer) {\n        this.drawer.destroy();\n      }\n\n      this.isDestroyed = true;\n      this.isReady = false;\n      this.arraybuffer = null;\n    }\n  }], [{\n    key: \"create\",\n    value:\n    /** @private */\n\n    /** @private */\n\n    /**\n     * Instantiate this class, call its `init` function and returns it\n     *\n     * @param {WavesurferParams} params The wavesurfer parameters\n     * @return {Object} WaveSurfer instance\n     * @example const wavesurfer = WaveSurfer.create(params);\n     */\n    function create(params) {\n      var wavesurfer = new WaveSurfer(params);\n      return wavesurfer.init();\n    }\n    /**\n     * The library version number is available as a static property of the\n     * WaveSurfer class\n     *\n     * @type {String}\n     * @example\n     * console.log('Using wavesurfer.js ' + WaveSurfer.VERSION);\n     */\n\n  }]);\n\n  return WaveSurfer;\n}(util.Observer);\n\nexports.default = WaveSurfer;\nWaveSurfer.VERSION = \"5.2.0\";\nWaveSurfer.util = util;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./src/webaudio.js\":\n/*!*************************!*\\\n  !*** ./src/webaudio.js ***!\n  \\*************************/\n/***/ ((module, exports, __nested_webpack_require_180241__) => {\n\n\"use strict\";\n\n\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.default = void 0;\n\nvar util = _interopRequireWildcard(__nested_webpack_require_180241__(/*! ./util */ \"./src/util/index.js\"));\n\nfunction _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== \"function\") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }\n\nfunction _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== \"default\" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } else if (call !== void 0) { throw new TypeError(\"Derived constructors may only return object or undefined\"); } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n// using constants to prevent someone writing the string wrong\nvar PLAYING = 'playing';\nvar PAUSED = 'paused';\nvar FINISHED = 'finished';\n/**\n * WebAudio backend\n *\n * @extends {Observer}\n */\n\nvar WebAudio = /*#__PURE__*/function (_util$Observer) {\n  _inherits(WebAudio, _util$Observer);\n\n  var _super = _createSuper(WebAudio);\n\n  /**\n   * Construct the backend\n   *\n   * @param {WavesurferParams} params Wavesurfer parameters\n   */\n  function WebAudio(params) {\n    var _this$stateBehaviors, _this$states;\n\n    var _this;\n\n    _classCallCheck(this, WebAudio);\n\n    _this = _super.call(this);\n    /** @private */\n\n    _this.audioContext = null;\n    _this.offlineAudioContext = null;\n    _this.stateBehaviors = (_this$stateBehaviors = {}, _defineProperty(_this$stateBehaviors, PLAYING, {\n      init: function init() {\n        this.addOnAudioProcess();\n      },\n      getPlayedPercents: function getPlayedPercents() {\n        var duration = this.getDuration();\n        return this.getCurrentTime() / duration || 0;\n      },\n      getCurrentTime: function getCurrentTime() {\n        return this.startPosition + this.getPlayedTime();\n      }\n    }), _defineProperty(_this$stateBehaviors, PAUSED, {\n      init: function init() {\n        this.removeOnAudioProcess();\n      },\n      getPlayedPercents: function getPlayedPercents() {\n        var duration = this.getDuration();\n        return this.getCurrentTime() / duration || 0;\n      },\n      getCurrentTime: function getCurrentTime() {\n        return this.startPosition;\n      }\n    }), _defineProperty(_this$stateBehaviors, FINISHED, {\n      init: function init() {\n        this.removeOnAudioProcess();\n        this.fireEvent('finish');\n      },\n      getPlayedPercents: function getPlayedPercents() {\n        return 1;\n      },\n      getCurrentTime: function getCurrentTime() {\n        return this.getDuration();\n      }\n    }), _this$stateBehaviors);\n    _this.params = params;\n    /** ac: Audio Context instance */\n\n    _this.ac = params.audioContext || (_this.supportsWebAudio() ? _this.getAudioContext() : {});\n    /**@private */\n\n    _this.lastPlay = _this.ac.currentTime;\n    /** @private */\n\n    _this.startPosition = 0;\n    /** @private */\n\n    _this.scheduledPause = null;\n    /** @private */\n\n    _this.states = (_this$states = {}, _defineProperty(_this$states, PLAYING, Object.create(_this.stateBehaviors[PLAYING])), _defineProperty(_this$states, PAUSED, Object.create(_this.stateBehaviors[PAUSED])), _defineProperty(_this$states, FINISHED, Object.create(_this.stateBehaviors[FINISHED])), _this$states);\n    /** @private */\n\n    _this.buffer = null;\n    /** @private */\n\n    _this.filters = [];\n    /** gainNode: allows to control audio volume */\n\n    _this.gainNode = null;\n    /** @private */\n\n    _this.mergedPeaks = null;\n    /** @private */\n\n    _this.offlineAc = null;\n    /** @private */\n\n    _this.peaks = null;\n    /** @private */\n\n    _this.playbackRate = 1;\n    /** analyser: provides audio analysis information */\n\n    _this.analyser = null;\n    /** scriptNode: allows processing audio */\n\n    _this.scriptNode = null;\n    /** @private */\n\n    _this.source = null;\n    /** @private */\n\n    _this.splitPeaks = [];\n    /** @private */\n\n    _this.state = null;\n    /** @private */\n\n    _this.explicitDuration = params.duration;\n    /**\n     * Boolean indicating if the backend was destroyed.\n     */\n\n    _this.destroyed = false;\n    return _this;\n  }\n  /**\n   * Initialise the backend, called in `wavesurfer.createBackend()`\n   */\n\n\n  _createClass(WebAudio, [{\n    key: \"supportsWebAudio\",\n    value:\n    /** scriptBufferSize: size of the processing buffer */\n\n    /** audioContext: allows to process audio with WebAudio API */\n\n    /** @private */\n\n    /** @private */\n\n    /**\n     * Does the browser support this backend\n     *\n     * @return {boolean} Whether or not this browser supports this backend\n     */\n    function supportsWebAudio() {\n      return !!(window.AudioContext || window.webkitAudioContext);\n    }\n    /**\n     * Get the audio context used by this backend or create one\n     *\n     * @return {AudioContext} Existing audio context, or creates a new one\n     */\n\n  }, {\n    key: \"getAudioContext\",\n    value: function getAudioContext() {\n      if (!window.WaveSurferAudioContext) {\n        window.WaveSurferAudioContext = new (window.AudioContext || window.webkitAudioContext)();\n      }\n\n      return window.WaveSurferAudioContext;\n    }\n    /**\n     * Get the offline audio context used by this backend or create one\n     *\n     * @param {number} sampleRate The sample rate to use\n     * @return {OfflineAudioContext} Existing offline audio context, or creates\n     * a new one\n     */\n\n  }, {\n    key: \"getOfflineAudioContext\",\n    value: function getOfflineAudioContext(sampleRate) {\n      if (!window.WaveSurferOfflineAudioContext) {\n        window.WaveSurferOfflineAudioContext = new (window.OfflineAudioContext || window.webkitOfflineAudioContext)(1, 2, sampleRate);\n      }\n\n      return window.WaveSurferOfflineAudioContext;\n    }\n  }, {\n    key: \"init\",\n    value: function init() {\n      this.createVolumeNode();\n      this.createScriptNode();\n      this.createAnalyserNode();\n      this.setState(PAUSED);\n      this.setPlaybackRate(this.params.audioRate);\n      this.setLength(0);\n    }\n    /** @private */\n\n  }, {\n    key: \"disconnectFilters\",\n    value: function disconnectFilters() {\n      if (this.filters) {\n        this.filters.forEach(function (filter) {\n          filter && filter.disconnect();\n        });\n        this.filters = null; // Reconnect direct path\n\n        this.analyser.connect(this.gainNode);\n      }\n    }\n    /**\n     * @private\n     *\n     * @param {string} state The new state\n     */\n\n  }, {\n    key: \"setState\",\n    value: function setState(state) {\n      if (this.state !== this.states[state]) {\n        this.state = this.states[state];\n        this.state.init.call(this);\n      }\n    }\n    /**\n     * Unpacked `setFilters()`\n     *\n     * @param {...AudioNode} filters One or more filters to set\n     */\n\n  }, {\n    key: \"setFilter\",\n    value: function setFilter() {\n      for (var _len = arguments.length, filters = new Array(_len), _key = 0; _key < _len; _key++) {\n        filters[_key] = arguments[_key];\n      }\n\n      this.setFilters(filters);\n    }\n    /**\n     * Insert custom Web Audio nodes into the graph\n     *\n     * @param {AudioNode[]} filters Packed filters array\n     * @example\n     * const lowpass = wavesurfer.backend.ac.createBiquadFilter();\n     * wavesurfer.backend.setFilter(lowpass);\n     */\n\n  }, {\n    key: \"setFilters\",\n    value: function setFilters(filters) {\n      // Remove existing filters\n      this.disconnectFilters(); // Insert filters if filter array not empty\n\n      if (filters && filters.length) {\n        this.filters = filters; // Disconnect direct path before inserting filters\n\n        this.analyser.disconnect(); // Connect each filter in turn\n\n        filters.reduce(function (prev, curr) {\n          prev.connect(curr);\n          return curr;\n        }, this.analyser).connect(this.gainNode);\n      }\n    }\n    /** Create ScriptProcessorNode to process audio */\n\n  }, {\n    key: \"createScriptNode\",\n    value: function createScriptNode() {\n      if (this.params.audioScriptProcessor) {\n        this.scriptNode = this.params.audioScriptProcessor;\n      } else {\n        if (this.ac.createScriptProcessor) {\n          this.scriptNode = this.ac.createScriptProcessor(WebAudio.scriptBufferSize);\n        } else {\n          this.scriptNode = this.ac.createJavaScriptNode(WebAudio.scriptBufferSize);\n        }\n      }\n\n      this.scriptNode.connect(this.ac.destination);\n    }\n    /** @private */\n\n  }, {\n    key: \"addOnAudioProcess\",\n    value: function addOnAudioProcess() {\n      var _this2 = this;\n\n      this.scriptNode.onaudioprocess = function () {\n        var time = _this2.getCurrentTime();\n\n        if (time >= _this2.getDuration()) {\n          _this2.setState(FINISHED);\n\n          _this2.fireEvent('pause');\n        } else if (time >= _this2.scheduledPause) {\n          _this2.pause();\n        } else if (_this2.state === _this2.states[PLAYING]) {\n          _this2.fireEvent('audioprocess', time);\n        }\n      };\n    }\n    /** @private */\n\n  }, {\n    key: \"removeOnAudioProcess\",\n    value: function removeOnAudioProcess() {\n      this.scriptNode.onaudioprocess = null;\n    }\n    /** Create analyser node to perform audio analysis */\n\n  }, {\n    key: \"createAnalyserNode\",\n    value: function createAnalyserNode() {\n      this.analyser = this.ac.createAnalyser();\n      this.analyser.connect(this.gainNode);\n    }\n    /**\n     * Create the gain node needed to control the playback volume.\n     *\n     */\n\n  }, {\n    key: \"createVolumeNode\",\n    value: function createVolumeNode() {\n      // Create gain node using the AudioContext\n      if (this.ac.createGain) {\n        this.gainNode = this.ac.createGain();\n      } else {\n        this.gainNode = this.ac.createGainNode();\n      } // Add the gain node to the graph\n\n\n      this.gainNode.connect(this.ac.destination);\n    }\n    /**\n     * Set the sink id for the media player\n     *\n     * @param {string} deviceId String value representing audio device id.\n     * @returns {Promise} A Promise that resolves to `undefined` when there\n     * are no errors.\n     */\n\n  }, {\n    key: \"setSinkId\",\n    value: function setSinkId(deviceId) {\n      if (deviceId) {\n        /**\n         * The webaudio API doesn't currently support setting the device\n         * output. Here we create an HTMLAudioElement, connect the\n         * webaudio stream to that element and setSinkId there.\n         */\n        var audio = new window.Audio();\n\n        if (!audio.setSinkId) {\n          return Promise.reject(new Error('setSinkId is not supported in your browser'));\n        }\n\n        audio.autoplay = true;\n        var dest = this.ac.createMediaStreamDestination();\n        this.gainNode.disconnect();\n        this.gainNode.connect(dest);\n        audio.srcObject = dest.stream;\n        return audio.setSinkId(deviceId);\n      } else {\n        return Promise.reject(new Error('Invalid deviceId: ' + deviceId));\n      }\n    }\n    /**\n     * Set the audio volume\n     *\n     * @param {number} value A floating point value between 0 and 1.\n     */\n\n  }, {\n    key: \"setVolume\",\n    value: function setVolume(value) {\n      this.gainNode.gain.setValueAtTime(value, this.ac.currentTime);\n    }\n    /**\n     * Get the current volume\n     *\n     * @return {number} value A floating point value between 0 and 1.\n     */\n\n  }, {\n    key: \"getVolume\",\n    value: function getVolume() {\n      return this.gainNode.gain.value;\n    }\n    /**\n     * Decode an array buffer and pass data to a callback\n     *\n     * @private\n     * @param {ArrayBuffer} arraybuffer The array buffer to decode\n     * @param {function} callback The function to call on complete.\n     * @param {function} errback The function to call on error.\n     */\n\n  }, {\n    key: \"decodeArrayBuffer\",\n    value: function decodeArrayBuffer(arraybuffer, callback, errback) {\n      if (!this.offlineAc) {\n        this.offlineAc = this.getOfflineAudioContext(this.ac && this.ac.sampleRate ? this.ac.sampleRate : 44100);\n      }\n\n      if ('webkitAudioContext' in window) {\n        // Safari: no support for Promise-based decodeAudioData enabled\n        // Enable it in Safari using the Experimental Features > Modern WebAudio API option\n        this.offlineAc.decodeAudioData(arraybuffer, function (data) {\n          return callback(data);\n        }, errback);\n      } else {\n        this.offlineAc.decodeAudioData(arraybuffer).then(function (data) {\n          return callback(data);\n        }).catch(function (err) {\n          return errback(err);\n        });\n      }\n    }\n    /**\n     * Set pre-decoded peaks\n     *\n     * @param {number[]|Number.<Array[]>} peaks Peaks data\n     * @param {?number} duration Explicit duration\n     */\n\n  }, {\n    key: \"setPeaks\",\n    value: function setPeaks(peaks, duration) {\n      if (duration != null) {\n        this.explicitDuration = duration;\n      }\n\n      this.peaks = peaks;\n    }\n    /**\n     * Set the rendered length (different from the length of the audio)\n     *\n     * @param {number} length The rendered length\n     */\n\n  }, {\n    key: \"setLength\",\n    value: function setLength(length) {\n      // No resize, we can preserve the cached peaks.\n      if (this.mergedPeaks && length == 2 * this.mergedPeaks.length - 1 + 2) {\n        return;\n      }\n\n      this.splitPeaks = [];\n      this.mergedPeaks = []; // Set the last element of the sparse array so the peak arrays are\n      // appropriately sized for other calculations.\n\n      var channels = this.buffer ? this.buffer.numberOfChannels : 1;\n      var c;\n\n      for (c = 0; c < channels; c++) {\n        this.splitPeaks[c] = [];\n        this.splitPeaks[c][2 * (length - 1)] = 0;\n        this.splitPeaks[c][2 * (length - 1) + 1] = 0;\n      }\n\n      this.mergedPeaks[2 * (length - 1)] = 0;\n      this.mergedPeaks[2 * (length - 1) + 1] = 0;\n    }\n    /**\n     * Compute the max and min value of the waveform when broken into <length> subranges.\n     *\n     * @param {number} length How many subranges to break the waveform into.\n     * @param {number} first First sample in the required range.\n     * @param {number} last Last sample in the required range.\n     * @return {number[]|Number.<Array[]>} Array of 2*<length> peaks or array of arrays of\n     * peaks consisting of (max, min) values for each subrange.\n     */\n\n  }, {\n    key: \"getPeaks\",\n    value: function getPeaks(length, first, last) {\n      if (this.peaks) {\n        return this.peaks;\n      }\n\n      if (!this.buffer) {\n        return [];\n      }\n\n      first = first || 0;\n      last = last || length - 1;\n      this.setLength(length);\n\n      if (!this.buffer) {\n        return this.params.splitChannels ? this.splitPeaks : this.mergedPeaks;\n      }\n      /**\n       * The following snippet fixes a buffering data issue on the Safari\n       * browser which returned undefined It creates the missing buffer based\n       * on 1 channel, 4096 samples and the sampleRate from the current\n       * webaudio context 4096 samples seemed to be the best fit for rendering\n       * will review this code once a stable version of Safari TP is out\n       */\n\n\n      if (!this.buffer.length) {\n        var newBuffer = this.createBuffer(1, 4096, this.sampleRate);\n        this.buffer = newBuffer.buffer;\n      }\n\n      var sampleSize = this.buffer.length / length;\n      var sampleStep = ~~(sampleSize / 10) || 1;\n      var channels = this.buffer.numberOfChannels;\n      var c;\n\n      for (c = 0; c < channels; c++) {\n        var peaks = this.splitPeaks[c];\n        var chan = this.buffer.getChannelData(c);\n        var i = void 0;\n\n        for (i = first; i <= last; i++) {\n          var start = ~~(i * sampleSize);\n          var end = ~~(start + sampleSize);\n          /**\n           * Initialize the max and min to the first sample of this\n           * subrange, so that even if the samples are entirely\n           * on one side of zero, we still return the true max and\n           * min values in the subrange.\n           */\n\n          var min = chan[start];\n          var max = min;\n          var j = void 0;\n\n          for (j = start; j < end; j += sampleStep) {\n            var value = chan[j];\n\n            if (value > max) {\n              max = value;\n            }\n\n            if (value < min) {\n              min = value;\n            }\n          }\n\n          peaks[2 * i] = max;\n          peaks[2 * i + 1] = min;\n\n          if (c == 0 || max > this.mergedPeaks[2 * i]) {\n            this.mergedPeaks[2 * i] = max;\n          }\n\n          if (c == 0 || min < this.mergedPeaks[2 * i + 1]) {\n            this.mergedPeaks[2 * i + 1] = min;\n          }\n        }\n      }\n\n      return this.params.splitChannels ? this.splitPeaks : this.mergedPeaks;\n    }\n    /**\n     * Get the position from 0 to 1\n     *\n     * @return {number} Position\n     */\n\n  }, {\n    key: \"getPlayedPercents\",\n    value: function getPlayedPercents() {\n      return this.state.getPlayedPercents.call(this);\n    }\n    /** @private */\n\n  }, {\n    key: \"disconnectSource\",\n    value: function disconnectSource() {\n      if (this.source) {\n        this.source.disconnect();\n      }\n    }\n    /**\n     * Destroy all references with WebAudio, disconnecting audio nodes and closing Audio Context\n     */\n\n  }, {\n    key: \"destroyWebAudio\",\n    value: function destroyWebAudio() {\n      this.disconnectFilters();\n      this.disconnectSource();\n      this.gainNode.disconnect();\n      this.scriptNode.disconnect();\n      this.analyser.disconnect(); // close the audioContext if closeAudioContext option is set to true\n\n      if (this.params.closeAudioContext) {\n        // check if browser supports AudioContext.close()\n        if (typeof this.ac.close === 'function' && this.ac.state != 'closed') {\n          this.ac.close();\n        } // clear the reference to the audiocontext\n\n\n        this.ac = null; // clear the actual audiocontext, either passed as param or the\n        // global singleton\n\n        if (!this.params.audioContext) {\n          window.WaveSurferAudioContext = null;\n        } else {\n          this.params.audioContext = null;\n        } // clear the offlineAudioContext\n\n\n        window.WaveSurferOfflineAudioContext = null;\n      }\n    }\n    /**\n     * This is called when wavesurfer is destroyed\n     */\n\n  }, {\n    key: \"destroy\",\n    value: function destroy() {\n      if (!this.isPaused()) {\n        this.pause();\n      }\n\n      this.unAll();\n      this.buffer = null;\n      this.destroyed = true;\n      this.destroyWebAudio();\n    }\n    /**\n     * Loaded a decoded audio buffer\n     *\n     * @param {Object} buffer Decoded audio buffer to load\n     */\n\n  }, {\n    key: \"load\",\n    value: function load(buffer) {\n      this.startPosition = 0;\n      this.lastPlay = this.ac.currentTime;\n      this.buffer = buffer;\n      this.createSource();\n    }\n    /** @private */\n\n  }, {\n    key: \"createSource\",\n    value: function createSource() {\n      this.disconnectSource();\n      this.source = this.ac.createBufferSource(); // adjust for old browsers\n\n      this.source.start = this.source.start || this.source.noteGrainOn;\n      this.source.stop = this.source.stop || this.source.noteOff;\n      this.setPlaybackRate(this.playbackRate);\n      this.source.buffer = this.buffer;\n      this.source.connect(this.analyser);\n    }\n    /**\n     * @private\n     *\n     * some browsers require an explicit call to #resume before they will play back audio\n     */\n\n  }, {\n    key: \"resumeAudioContext\",\n    value: function resumeAudioContext() {\n      if (this.ac.state == 'suspended') {\n        this.ac.resume && this.ac.resume();\n      }\n    }\n    /**\n     * Used by `wavesurfer.isPlaying()` and `wavesurfer.playPause()`\n     *\n     * @return {boolean} Whether or not this backend is currently paused\n     */\n\n  }, {\n    key: \"isPaused\",\n    value: function isPaused() {\n      return this.state !== this.states[PLAYING];\n    }\n    /**\n     * Used by `wavesurfer.getDuration()`\n     *\n     * @return {number} Duration of loaded buffer\n     */\n\n  }, {\n    key: \"getDuration\",\n    value: function getDuration() {\n      if (this.explicitDuration) {\n        return this.explicitDuration;\n      }\n\n      if (!this.buffer) {\n        return 0;\n      }\n\n      return this.buffer.duration;\n    }\n    /**\n     * Used by `wavesurfer.seekTo()`\n     *\n     * @param {number} start Position to start at in seconds\n     * @param {number} end Position to end at in seconds\n     * @return {{start: number, end: number}} Object containing start and end\n     * positions\n     */\n\n  }, {\n    key: \"seekTo\",\n    value: function seekTo(start, end) {\n      if (!this.buffer) {\n        return;\n      }\n\n      this.scheduledPause = null;\n\n      if (start == null) {\n        start = this.getCurrentTime();\n\n        if (start >= this.getDuration()) {\n          start = 0;\n        }\n      }\n\n      if (end == null) {\n        end = this.getDuration();\n      }\n\n      this.startPosition = start;\n      this.lastPlay = this.ac.currentTime;\n\n      if (this.state === this.states[FINISHED]) {\n        this.setState(PAUSED);\n      }\n\n      return {\n        start: start,\n        end: end\n      };\n    }\n    /**\n     * Get the playback position in seconds\n     *\n     * @return {number} The playback position in seconds\n     */\n\n  }, {\n    key: \"getPlayedTime\",\n    value: function getPlayedTime() {\n      return (this.ac.currentTime - this.lastPlay) * this.playbackRate;\n    }\n    /**\n     * Plays the loaded audio region.\n     *\n     * @param {number} start Start offset in seconds, relative to the beginning\n     * of a clip.\n     * @param {number} end When to stop relative to the beginning of a clip.\n     */\n\n  }, {\n    key: \"play\",\n    value: function play(start, end) {\n      if (!this.buffer) {\n        return;\n      } // need to re-create source on each playback\n\n\n      this.createSource();\n      var adjustedTime = this.seekTo(start, end);\n      start = adjustedTime.start;\n      end = adjustedTime.end;\n      this.scheduledPause = end;\n      this.source.start(0, start);\n      this.resumeAudioContext();\n      this.setState(PLAYING);\n      this.fireEvent('play');\n    }\n    /**\n     * Pauses the loaded audio.\n     */\n\n  }, {\n    key: \"pause\",\n    value: function pause() {\n      this.scheduledPause = null;\n      this.startPosition += this.getPlayedTime();\n\n      try {\n        this.source && this.source.stop(0);\n      } catch (err) {// Calling stop can throw the following 2 errors:\n        // - RangeError (The value specified for when is negative.)\n        // - InvalidStateNode (The node has not been started by calling start().)\n        // We can safely ignore both errors, because:\n        // - The range is surely correct\n        // - The node might not have been started yet, in which case we just want to carry on without causing any trouble.\n      }\n\n      this.setState(PAUSED);\n      this.fireEvent('pause');\n    }\n    /**\n     * Returns the current time in seconds relative to the audio-clip's\n     * duration.\n     *\n     * @return {number} The current time in seconds\n     */\n\n  }, {\n    key: \"getCurrentTime\",\n    value: function getCurrentTime() {\n      return this.state.getCurrentTime.call(this);\n    }\n    /**\n     * Returns the current playback rate. (0=no playback, 1=normal playback)\n     *\n     * @return {number} The current playback rate\n     */\n\n  }, {\n    key: \"getPlaybackRate\",\n    value: function getPlaybackRate() {\n      return this.playbackRate;\n    }\n    /**\n     * Set the audio source playback rate.\n     *\n     * @param {number} value The playback rate to use\n     */\n\n  }, {\n    key: \"setPlaybackRate\",\n    value: function setPlaybackRate(value) {\n      this.playbackRate = value || 1;\n      this.source && this.source.playbackRate.setValueAtTime(this.playbackRate, this.ac.currentTime);\n    }\n    /**\n     * Set a point in seconds for playback to stop at.\n     *\n     * @param {number} end Position to end at\n     * @version 3.3.0\n     */\n\n  }, {\n    key: \"setPlayEnd\",\n    value: function setPlayEnd(end) {\n      this.scheduledPause = end;\n    }\n  }]);\n\n  return WebAudio;\n}(util.Observer);\n\nexports.default = WebAudio;\nWebAudio.scriptBufferSize = 256;\nmodule.exports = exports.default;\n\n/***/ }),\n\n/***/ \"./node_modules/debounce/index.js\":\n/*!****************************************!*\\\n  !*** ./node_modules/debounce/index.js ***!\n  \\****************************************/\n/***/ ((module) => {\n\n/**\n * Returns a function, that, as long as it continues to be invoked, will not\n * be triggered. The function will be called after it stops being called for\n * N milliseconds. If `immediate` is passed, trigger the function on the\n * leading edge, instead of the trailing. The function also has a property 'clear' \n * that is a function which will clear the timer to prevent previously scheduled executions. \n *\n * @source underscore.js\n * @see http://unscriptable.com/2009/03/20/debouncing-javascript-methods/\n * @param {Function} function to wrap\n * @param {Number} timeout in ms (`100`)\n * @param {Boolean} whether to execute at the beginning (`false`)\n * @api public\n */\nfunction debounce(func, wait, immediate){\n  var timeout, args, context, timestamp, result;\n  if (null == wait) wait = 100;\n\n  function later() {\n    var last = Date.now() - timestamp;\n\n    if (last < wait && last >= 0) {\n      timeout = setTimeout(later, wait - last);\n    } else {\n      timeout = null;\n      if (!immediate) {\n        result = func.apply(context, args);\n        context = args = null;\n      }\n    }\n  };\n\n  var debounced = function(){\n    context = this;\n    args = arguments;\n    timestamp = Date.now();\n    var callNow = immediate && !timeout;\n    if (!timeout) timeout = setTimeout(later, wait);\n    if (callNow) {\n      result = func.apply(context, args);\n      context = args = null;\n    }\n\n    return result;\n  };\n\n  debounced.clear = function() {\n    if (timeout) {\n      clearTimeout(timeout);\n      timeout = null;\n    }\n  };\n  \n  debounced.flush = function() {\n    if (timeout) {\n      result = func.apply(context, args);\n      context = args = null;\n      \n      clearTimeout(timeout);\n      timeout = null;\n    }\n  };\n\n  return debounced;\n};\n\n// Adds compatibility for ES modules\ndebounce.debounce = debounce;\n\nmodule.exports = debounce;\n\n\n/***/ })\n\n/******/ \t});\n/************************************************************************/\n/******/ \t// The module cache\n/******/ \tvar __webpack_module_cache__ = {};\n/******/ \t\n/******/ \t// The require function\n/******/ \tfunction __nested_webpack_require_210487__(moduleId) {\n/******/ \t\t// Check if module is in cache\n/******/ \t\tvar cachedModule = __webpack_module_cache__[moduleId];\n/******/ \t\tif (cachedModule !== undefined) {\n/******/ \t\t\treturn cachedModule.exports;\n/******/ \t\t}\n/******/ \t\t// Create a new module (and put it into the cache)\n/******/ \t\tvar module = __webpack_module_cache__[moduleId] = {\n/******/ \t\t\t// no module.id needed\n/******/ \t\t\t// no module.loaded needed\n/******/ \t\t\texports: {}\n/******/ \t\t};\n/******/ \t\n/******/ \t\t// Execute the module function\n/******/ \t\t__webpack_modules__[moduleId](module, module.exports, __nested_webpack_require_210487__);\n/******/ \t\n/******/ \t\t// Return the exports of the module\n/******/ \t\treturn module.exports;\n/******/ \t}\n/******/ \t\n/************************************************************************/\n/******/ \t\n/******/ \t// startup\n/******/ \t// Load entry module and return exports\n/******/ \t// This entry module is referenced by other modules so it can't be inlined\n/******/ \tvar __nested_webpack_exports__ = __nested_webpack_require_210487__(\"./src/wavesurfer.js\");\n/******/ \t\n/******/ \treturn __nested_webpack_exports__;\n/******/ })()\n;\n});\n//# sourceMappingURL=wavesurfer.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/wavesurfer.js/dist/wavesurfer.js?");

/***/ }),

/***/ "@jupyter-widgets/base":
/*!****************************************!*\
  !*** external "@jupyter-widgets/base" ***!
  \****************************************/
/***/ ((module) => {

"use strict";
module.exports = __WEBPACK_EXTERNAL_MODULE__jupyter_widgets_base__;

/***/ }),

/***/ "../../node_modules/json-stringify-pretty-compact/index.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/json-stringify-pretty-compact/index.js ***!
  \*****************************************************************/
/***/ ((module) => {

"use strict";
eval("\n\n// Note: This regex matches even invalid JSON strings, but since we’re\n// working on the output of `JSON.stringify` we know that only valid strings\n// are present (unless the user supplied a weird `options.indent` but in\n// that case we don’t care since the output would be invalid anyway).\nvar stringOrChar = /(\"(?:[^\\\\\"]|\\\\.)*\")|[:,]/g;\n\nmodule.exports = function stringify(passedObj, options) {\n  var indent, maxLength, replacer;\n\n  options = options || {};\n  indent = JSON.stringify(\n    [1],\n    undefined,\n    options.indent === undefined ? 2 : options.indent\n  ).slice(2, -3);\n  maxLength =\n    indent === \"\"\n      ? Infinity\n      : options.maxLength === undefined\n      ? 80\n      : options.maxLength;\n  replacer = options.replacer;\n\n  return (function _stringify(obj, currentIndent, reserved) {\n    // prettier-ignore\n    var end, index, items, key, keyPart, keys, length, nextIndent, prettified, start, string, value;\n\n    if (obj && typeof obj.toJSON === \"function\") {\n      obj = obj.toJSON();\n    }\n\n    string = JSON.stringify(obj, replacer);\n\n    if (string === undefined) {\n      return string;\n    }\n\n    length = maxLength - currentIndent.length - reserved;\n\n    if (string.length <= length) {\n      prettified = string.replace(\n        stringOrChar,\n        function (match, stringLiteral) {\n          return stringLiteral || match + \" \";\n        }\n      );\n      if (prettified.length <= length) {\n        return prettified;\n      }\n    }\n\n    if (replacer != null) {\n      obj = JSON.parse(string);\n      replacer = undefined;\n    }\n\n    if (typeof obj === \"object\" && obj !== null) {\n      nextIndent = currentIndent + indent;\n      items = [];\n      index = 0;\n\n      if (Array.isArray(obj)) {\n        start = \"[\";\n        end = \"]\";\n        length = obj.length;\n        for (; index < length; index++) {\n          items.push(\n            _stringify(obj[index], nextIndent, index === length - 1 ? 0 : 1) ||\n              \"null\"\n          );\n        }\n      } else {\n        start = \"{\";\n        end = \"}\";\n        keys = Object.keys(obj);\n        length = keys.length;\n        for (; index < length; index++) {\n          key = keys[index];\n          keyPart = JSON.stringify(key) + \": \";\n          value = _stringify(\n            obj[key],\n            nextIndent,\n            keyPart.length + (index === length - 1 ? 0 : 1)\n          );\n          if (value !== undefined) {\n            items.push(keyPart + value);\n          }\n        }\n      }\n\n      if (items.length > 0) {\n        return [start, indent + items.join(\",\\n\" + nextIndent), end].join(\n          \"\\n\" + currentIndent\n        );\n      }\n    }\n\n    return string;\n  })(passedObj, \"\", 0);\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/json-stringify-pretty-compact/index.js?");

/***/ }),

/***/ "../../node_modules/acorn/dist/acorn.mjs":
/*!***********************************************!*\
  !*** ../../node_modules/acorn/dist/acorn.mjs ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Node: () => (/* binding */ Node),\n/* harmony export */   Parser: () => (/* binding */ Parser),\n/* harmony export */   Position: () => (/* binding */ Position),\n/* harmony export */   SourceLocation: () => (/* binding */ SourceLocation),\n/* harmony export */   TokContext: () => (/* binding */ TokContext),\n/* harmony export */   Token: () => (/* binding */ Token),\n/* harmony export */   TokenType: () => (/* binding */ TokenType),\n/* harmony export */   defaultOptions: () => (/* binding */ defaultOptions),\n/* harmony export */   getLineInfo: () => (/* binding */ getLineInfo),\n/* harmony export */   isIdentifierChar: () => (/* binding */ isIdentifierChar),\n/* harmony export */   isIdentifierStart: () => (/* binding */ isIdentifierStart),\n/* harmony export */   isNewLine: () => (/* binding */ isNewLine),\n/* harmony export */   keywordTypes: () => (/* binding */ keywords),\n/* harmony export */   lineBreak: () => (/* binding */ lineBreak),\n/* harmony export */   lineBreakG: () => (/* binding */ lineBreakG),\n/* harmony export */   nonASCIIwhitespace: () => (/* binding */ nonASCIIwhitespace),\n/* harmony export */   parse: () => (/* binding */ parse),\n/* harmony export */   parseExpressionAt: () => (/* binding */ parseExpressionAt),\n/* harmony export */   tokContexts: () => (/* binding */ types),\n/* harmony export */   tokTypes: () => (/* binding */ types$1),\n/* harmony export */   tokenizer: () => (/* binding */ tokenizer),\n/* harmony export */   version: () => (/* binding */ version)\n/* harmony export */ });\n// This file was generated. Do not modify manually!\nvar astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];\n\n// This file was generated. Do not modify manually!\nvar astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];\n\n// This file was generated. Do not modify manually!\nvar nonASCIIidentifierChars = \"\\u200c\\u200d\\xb7\\u0300-\\u036f\\u0387\\u0483-\\u0487\\u0591-\\u05bd\\u05bf\\u05c1\\u05c2\\u05c4\\u05c5\\u05c7\\u0610-\\u061a\\u064b-\\u0669\\u0670\\u06d6-\\u06dc\\u06df-\\u06e4\\u06e7\\u06e8\\u06ea-\\u06ed\\u06f0-\\u06f9\\u0711\\u0730-\\u074a\\u07a6-\\u07b0\\u07c0-\\u07c9\\u07eb-\\u07f3\\u07fd\\u0816-\\u0819\\u081b-\\u0823\\u0825-\\u0827\\u0829-\\u082d\\u0859-\\u085b\\u0898-\\u089f\\u08ca-\\u08e1\\u08e3-\\u0903\\u093a-\\u093c\\u093e-\\u094f\\u0951-\\u0957\\u0962\\u0963\\u0966-\\u096f\\u0981-\\u0983\\u09bc\\u09be-\\u09c4\\u09c7\\u09c8\\u09cb-\\u09cd\\u09d7\\u09e2\\u09e3\\u09e6-\\u09ef\\u09fe\\u0a01-\\u0a03\\u0a3c\\u0a3e-\\u0a42\\u0a47\\u0a48\\u0a4b-\\u0a4d\\u0a51\\u0a66-\\u0a71\\u0a75\\u0a81-\\u0a83\\u0abc\\u0abe-\\u0ac5\\u0ac7-\\u0ac9\\u0acb-\\u0acd\\u0ae2\\u0ae3\\u0ae6-\\u0aef\\u0afa-\\u0aff\\u0b01-\\u0b03\\u0b3c\\u0b3e-\\u0b44\\u0b47\\u0b48\\u0b4b-\\u0b4d\\u0b55-\\u0b57\\u0b62\\u0b63\\u0b66-\\u0b6f\\u0b82\\u0bbe-\\u0bc2\\u0bc6-\\u0bc8\\u0bca-\\u0bcd\\u0bd7\\u0be6-\\u0bef\\u0c00-\\u0c04\\u0c3c\\u0c3e-\\u0c44\\u0c46-\\u0c48\\u0c4a-\\u0c4d\\u0c55\\u0c56\\u0c62\\u0c63\\u0c66-\\u0c6f\\u0c81-\\u0c83\\u0cbc\\u0cbe-\\u0cc4\\u0cc6-\\u0cc8\\u0cca-\\u0ccd\\u0cd5\\u0cd6\\u0ce2\\u0ce3\\u0ce6-\\u0cef\\u0cf3\\u0d00-\\u0d03\\u0d3b\\u0d3c\\u0d3e-\\u0d44\\u0d46-\\u0d48\\u0d4a-\\u0d4d\\u0d57\\u0d62\\u0d63\\u0d66-\\u0d6f\\u0d81-\\u0d83\\u0dca\\u0dcf-\\u0dd4\\u0dd6\\u0dd8-\\u0ddf\\u0de6-\\u0def\\u0df2\\u0df3\\u0e31\\u0e34-\\u0e3a\\u0e47-\\u0e4e\\u0e50-\\u0e59\\u0eb1\\u0eb4-\\u0ebc\\u0ec8-\\u0ece\\u0ed0-\\u0ed9\\u0f18\\u0f19\\u0f20-\\u0f29\\u0f35\\u0f37\\u0f39\\u0f3e\\u0f3f\\u0f71-\\u0f84\\u0f86\\u0f87\\u0f8d-\\u0f97\\u0f99-\\u0fbc\\u0fc6\\u102b-\\u103e\\u1040-\\u1049\\u1056-\\u1059\\u105e-\\u1060\\u1062-\\u1064\\u1067-\\u106d\\u1071-\\u1074\\u1082-\\u108d\\u108f-\\u109d\\u135d-\\u135f\\u1369-\\u1371\\u1712-\\u1715\\u1732-\\u1734\\u1752\\u1753\\u1772\\u1773\\u17b4-\\u17d3\\u17dd\\u17e0-\\u17e9\\u180b-\\u180d\\u180f-\\u1819\\u18a9\\u1920-\\u192b\\u1930-\\u193b\\u1946-\\u194f\\u19d0-\\u19da\\u1a17-\\u1a1b\\u1a55-\\u1a5e\\u1a60-\\u1a7c\\u1a7f-\\u1a89\\u1a90-\\u1a99\\u1ab0-\\u1abd\\u1abf-\\u1ace\\u1b00-\\u1b04\\u1b34-\\u1b44\\u1b50-\\u1b59\\u1b6b-\\u1b73\\u1b80-\\u1b82\\u1ba1-\\u1bad\\u1bb0-\\u1bb9\\u1be6-\\u1bf3\\u1c24-\\u1c37\\u1c40-\\u1c49\\u1c50-\\u1c59\\u1cd0-\\u1cd2\\u1cd4-\\u1ce8\\u1ced\\u1cf4\\u1cf7-\\u1cf9\\u1dc0-\\u1dff\\u203f\\u2040\\u2054\\u20d0-\\u20dc\\u20e1\\u20e5-\\u20f0\\u2cef-\\u2cf1\\u2d7f\\u2de0-\\u2dff\\u302a-\\u302f\\u3099\\u309a\\ua620-\\ua629\\ua66f\\ua674-\\ua67d\\ua69e\\ua69f\\ua6f0\\ua6f1\\ua802\\ua806\\ua80b\\ua823-\\ua827\\ua82c\\ua880\\ua881\\ua8b4-\\ua8c5\\ua8d0-\\ua8d9\\ua8e0-\\ua8f1\\ua8ff-\\ua909\\ua926-\\ua92d\\ua947-\\ua953\\ua980-\\ua983\\ua9b3-\\ua9c0\\ua9d0-\\ua9d9\\ua9e5\\ua9f0-\\ua9f9\\uaa29-\\uaa36\\uaa43\\uaa4c\\uaa4d\\uaa50-\\uaa59\\uaa7b-\\uaa7d\\uaab0\\uaab2-\\uaab4\\uaab7\\uaab8\\uaabe\\uaabf\\uaac1\\uaaeb-\\uaaef\\uaaf5\\uaaf6\\uabe3-\\uabea\\uabec\\uabed\\uabf0-\\uabf9\\ufb1e\\ufe00-\\ufe0f\\ufe20-\\ufe2f\\ufe33\\ufe34\\ufe4d-\\ufe4f\\uff10-\\uff19\\uff3f\";\n\n// This file was generated. Do not modify manually!\nvar nonASCIIidentifierStartChars = \"\\xaa\\xb5\\xba\\xc0-\\xd6\\xd8-\\xf6\\xf8-\\u02c1\\u02c6-\\u02d1\\u02e0-\\u02e4\\u02ec\\u02ee\\u0370-\\u0374\\u0376\\u0377\\u037a-\\u037d\\u037f\\u0386\\u0388-\\u038a\\u038c\\u038e-\\u03a1\\u03a3-\\u03f5\\u03f7-\\u0481\\u048a-\\u052f\\u0531-\\u0556\\u0559\\u0560-\\u0588\\u05d0-\\u05ea\\u05ef-\\u05f2\\u0620-\\u064a\\u066e\\u066f\\u0671-\\u06d3\\u06d5\\u06e5\\u06e6\\u06ee\\u06ef\\u06fa-\\u06fc\\u06ff\\u0710\\u0712-\\u072f\\u074d-\\u07a5\\u07b1\\u07ca-\\u07ea\\u07f4\\u07f5\\u07fa\\u0800-\\u0815\\u081a\\u0824\\u0828\\u0840-\\u0858\\u0860-\\u086a\\u0870-\\u0887\\u0889-\\u088e\\u08a0-\\u08c9\\u0904-\\u0939\\u093d\\u0950\\u0958-\\u0961\\u0971-\\u0980\\u0985-\\u098c\\u098f\\u0990\\u0993-\\u09a8\\u09aa-\\u09b0\\u09b2\\u09b6-\\u09b9\\u09bd\\u09ce\\u09dc\\u09dd\\u09df-\\u09e1\\u09f0\\u09f1\\u09fc\\u0a05-\\u0a0a\\u0a0f\\u0a10\\u0a13-\\u0a28\\u0a2a-\\u0a30\\u0a32\\u0a33\\u0a35\\u0a36\\u0a38\\u0a39\\u0a59-\\u0a5c\\u0a5e\\u0a72-\\u0a74\\u0a85-\\u0a8d\\u0a8f-\\u0a91\\u0a93-\\u0aa8\\u0aaa-\\u0ab0\\u0ab2\\u0ab3\\u0ab5-\\u0ab9\\u0abd\\u0ad0\\u0ae0\\u0ae1\\u0af9\\u0b05-\\u0b0c\\u0b0f\\u0b10\\u0b13-\\u0b28\\u0b2a-\\u0b30\\u0b32\\u0b33\\u0b35-\\u0b39\\u0b3d\\u0b5c\\u0b5d\\u0b5f-\\u0b61\\u0b71\\u0b83\\u0b85-\\u0b8a\\u0b8e-\\u0b90\\u0b92-\\u0b95\\u0b99\\u0b9a\\u0b9c\\u0b9e\\u0b9f\\u0ba3\\u0ba4\\u0ba8-\\u0baa\\u0bae-\\u0bb9\\u0bd0\\u0c05-\\u0c0c\\u0c0e-\\u0c10\\u0c12-\\u0c28\\u0c2a-\\u0c39\\u0c3d\\u0c58-\\u0c5a\\u0c5d\\u0c60\\u0c61\\u0c80\\u0c85-\\u0c8c\\u0c8e-\\u0c90\\u0c92-\\u0ca8\\u0caa-\\u0cb3\\u0cb5-\\u0cb9\\u0cbd\\u0cdd\\u0cde\\u0ce0\\u0ce1\\u0cf1\\u0cf2\\u0d04-\\u0d0c\\u0d0e-\\u0d10\\u0d12-\\u0d3a\\u0d3d\\u0d4e\\u0d54-\\u0d56\\u0d5f-\\u0d61\\u0d7a-\\u0d7f\\u0d85-\\u0d96\\u0d9a-\\u0db1\\u0db3-\\u0dbb\\u0dbd\\u0dc0-\\u0dc6\\u0e01-\\u0e30\\u0e32\\u0e33\\u0e40-\\u0e46\\u0e81\\u0e82\\u0e84\\u0e86-\\u0e8a\\u0e8c-\\u0ea3\\u0ea5\\u0ea7-\\u0eb0\\u0eb2\\u0eb3\\u0ebd\\u0ec0-\\u0ec4\\u0ec6\\u0edc-\\u0edf\\u0f00\\u0f40-\\u0f47\\u0f49-\\u0f6c\\u0f88-\\u0f8c\\u1000-\\u102a\\u103f\\u1050-\\u1055\\u105a-\\u105d\\u1061\\u1065\\u1066\\u106e-\\u1070\\u1075-\\u1081\\u108e\\u10a0-\\u10c5\\u10c7\\u10cd\\u10d0-\\u10fa\\u10fc-\\u1248\\u124a-\\u124d\\u1250-\\u1256\\u1258\\u125a-\\u125d\\u1260-\\u1288\\u128a-\\u128d\\u1290-\\u12b0\\u12b2-\\u12b5\\u12b8-\\u12be\\u12c0\\u12c2-\\u12c5\\u12c8-\\u12d6\\u12d8-\\u1310\\u1312-\\u1315\\u1318-\\u135a\\u1380-\\u138f\\u13a0-\\u13f5\\u13f8-\\u13fd\\u1401-\\u166c\\u166f-\\u167f\\u1681-\\u169a\\u16a0-\\u16ea\\u16ee-\\u16f8\\u1700-\\u1711\\u171f-\\u1731\\u1740-\\u1751\\u1760-\\u176c\\u176e-\\u1770\\u1780-\\u17b3\\u17d7\\u17dc\\u1820-\\u1878\\u1880-\\u18a8\\u18aa\\u18b0-\\u18f5\\u1900-\\u191e\\u1950-\\u196d\\u1970-\\u1974\\u1980-\\u19ab\\u19b0-\\u19c9\\u1a00-\\u1a16\\u1a20-\\u1a54\\u1aa7\\u1b05-\\u1b33\\u1b45-\\u1b4c\\u1b83-\\u1ba0\\u1bae\\u1baf\\u1bba-\\u1be5\\u1c00-\\u1c23\\u1c4d-\\u1c4f\\u1c5a-\\u1c7d\\u1c80-\\u1c88\\u1c90-\\u1cba\\u1cbd-\\u1cbf\\u1ce9-\\u1cec\\u1cee-\\u1cf3\\u1cf5\\u1cf6\\u1cfa\\u1d00-\\u1dbf\\u1e00-\\u1f15\\u1f18-\\u1f1d\\u1f20-\\u1f45\\u1f48-\\u1f4d\\u1f50-\\u1f57\\u1f59\\u1f5b\\u1f5d\\u1f5f-\\u1f7d\\u1f80-\\u1fb4\\u1fb6-\\u1fbc\\u1fbe\\u1fc2-\\u1fc4\\u1fc6-\\u1fcc\\u1fd0-\\u1fd3\\u1fd6-\\u1fdb\\u1fe0-\\u1fec\\u1ff2-\\u1ff4\\u1ff6-\\u1ffc\\u2071\\u207f\\u2090-\\u209c\\u2102\\u2107\\u210a-\\u2113\\u2115\\u2118-\\u211d\\u2124\\u2126\\u2128\\u212a-\\u2139\\u213c-\\u213f\\u2145-\\u2149\\u214e\\u2160-\\u2188\\u2c00-\\u2ce4\\u2ceb-\\u2cee\\u2cf2\\u2cf3\\u2d00-\\u2d25\\u2d27\\u2d2d\\u2d30-\\u2d67\\u2d6f\\u2d80-\\u2d96\\u2da0-\\u2da6\\u2da8-\\u2dae\\u2db0-\\u2db6\\u2db8-\\u2dbe\\u2dc0-\\u2dc6\\u2dc8-\\u2dce\\u2dd0-\\u2dd6\\u2dd8-\\u2dde\\u3005-\\u3007\\u3021-\\u3029\\u3031-\\u3035\\u3038-\\u303c\\u3041-\\u3096\\u309b-\\u309f\\u30a1-\\u30fa\\u30fc-\\u30ff\\u3105-\\u312f\\u3131-\\u318e\\u31a0-\\u31bf\\u31f0-\\u31ff\\u3400-\\u4dbf\\u4e00-\\ua48c\\ua4d0-\\ua4fd\\ua500-\\ua60c\\ua610-\\ua61f\\ua62a\\ua62b\\ua640-\\ua66e\\ua67f-\\ua69d\\ua6a0-\\ua6ef\\ua717-\\ua71f\\ua722-\\ua788\\ua78b-\\ua7ca\\ua7d0\\ua7d1\\ua7d3\\ua7d5-\\ua7d9\\ua7f2-\\ua801\\ua803-\\ua805\\ua807-\\ua80a\\ua80c-\\ua822\\ua840-\\ua873\\ua882-\\ua8b3\\ua8f2-\\ua8f7\\ua8fb\\ua8fd\\ua8fe\\ua90a-\\ua925\\ua930-\\ua946\\ua960-\\ua97c\\ua984-\\ua9b2\\ua9cf\\ua9e0-\\ua9e4\\ua9e6-\\ua9ef\\ua9fa-\\ua9fe\\uaa00-\\uaa28\\uaa40-\\uaa42\\uaa44-\\uaa4b\\uaa60-\\uaa76\\uaa7a\\uaa7e-\\uaaaf\\uaab1\\uaab5\\uaab6\\uaab9-\\uaabd\\uaac0\\uaac2\\uaadb-\\uaadd\\uaae0-\\uaaea\\uaaf2-\\uaaf4\\uab01-\\uab06\\uab09-\\uab0e\\uab11-\\uab16\\uab20-\\uab26\\uab28-\\uab2e\\uab30-\\uab5a\\uab5c-\\uab69\\uab70-\\uabe2\\uac00-\\ud7a3\\ud7b0-\\ud7c6\\ud7cb-\\ud7fb\\uf900-\\ufa6d\\ufa70-\\ufad9\\ufb00-\\ufb06\\ufb13-\\ufb17\\ufb1d\\ufb1f-\\ufb28\\ufb2a-\\ufb36\\ufb38-\\ufb3c\\ufb3e\\ufb40\\ufb41\\ufb43\\ufb44\\ufb46-\\ufbb1\\ufbd3-\\ufd3d\\ufd50-\\ufd8f\\ufd92-\\ufdc7\\ufdf0-\\ufdfb\\ufe70-\\ufe74\\ufe76-\\ufefc\\uff21-\\uff3a\\uff41-\\uff5a\\uff66-\\uffbe\\uffc2-\\uffc7\\uffca-\\uffcf\\uffd2-\\uffd7\\uffda-\\uffdc\";\n\n// These are a run-length and offset encoded representation of the\n// >0xffff code points that are a valid part of identifiers. The\n// offset starts at 0x10000, and each pair of numbers represents an\n// offset to the next range, and then a size of the range.\n\n// Reserved word lists for various dialects of the language\n\nvar reservedWords = {\n  3: \"abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile\",\n  5: \"class enum extends super const export import\",\n  6: \"enum\",\n  strict: \"implements interface let package private protected public static yield\",\n  strictBind: \"eval arguments\"\n};\n\n// And the keywords\n\nvar ecma5AndLessKeywords = \"break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this\";\n\nvar keywords$1 = {\n  5: ecma5AndLessKeywords,\n  \"5module\": ecma5AndLessKeywords + \" export import\",\n  6: ecma5AndLessKeywords + \" const class extends export import super\"\n};\n\nvar keywordRelationalOperator = /^in(stanceof)?$/;\n\n// ## Character categories\n\nvar nonASCIIidentifierStart = new RegExp(\"[\" + nonASCIIidentifierStartChars + \"]\");\nvar nonASCIIidentifier = new RegExp(\"[\" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + \"]\");\n\n// This has a complexity linear to the value of the code. The\n// assumption is that looking up astral identifier characters is\n// rare.\nfunction isInAstralSet(code, set) {\n  var pos = 0x10000;\n  for (var i = 0; i < set.length; i += 2) {\n    pos += set[i];\n    if (pos > code) { return false }\n    pos += set[i + 1];\n    if (pos >= code) { return true }\n  }\n  return false\n}\n\n// Test whether a given character code starts an identifier.\n\nfunction isIdentifierStart(code, astral) {\n  if (code < 65) { return code === 36 }\n  if (code < 91) { return true }\n  if (code < 97) { return code === 95 }\n  if (code < 123) { return true }\n  if (code <= 0xffff) { return code >= 0xaa && nonASCIIidentifierStart.test(String.fromCharCode(code)) }\n  if (astral === false) { return false }\n  return isInAstralSet(code, astralIdentifierStartCodes)\n}\n\n// Test whether a given character is part of an identifier.\n\nfunction isIdentifierChar(code, astral) {\n  if (code < 48) { return code === 36 }\n  if (code < 58) { return true }\n  if (code < 65) { return false }\n  if (code < 91) { return true }\n  if (code < 97) { return code === 95 }\n  if (code < 123) { return true }\n  if (code <= 0xffff) { return code >= 0xaa && nonASCIIidentifier.test(String.fromCharCode(code)) }\n  if (astral === false) { return false }\n  return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes)\n}\n\n// ## Token types\n\n// The assignment of fine-grained, information-carrying type objects\n// allows the tokenizer to store the information it has about a\n// token in a way that is very cheap for the parser to look up.\n\n// All token type variables start with an underscore, to make them\n// easy to recognize.\n\n// The `beforeExpr` property is used to disambiguate between regular\n// expressions and divisions. It is set on all token types that can\n// be followed by an expression (thus, a slash after them would be a\n// regular expression).\n//\n// The `startsExpr` property is used to check if the token ends a\n// `yield` expression. It is set on all token types that either can\n// directly start an expression (like a quotation mark) or can\n// continue an expression (like the body of a string).\n//\n// `isLoop` marks a keyword as starting a loop, which is important\n// to know when parsing a label, in order to allow or disallow\n// continue jumps to that label.\n\nvar TokenType = function TokenType(label, conf) {\n  if ( conf === void 0 ) conf = {};\n\n  this.label = label;\n  this.keyword = conf.keyword;\n  this.beforeExpr = !!conf.beforeExpr;\n  this.startsExpr = !!conf.startsExpr;\n  this.isLoop = !!conf.isLoop;\n  this.isAssign = !!conf.isAssign;\n  this.prefix = !!conf.prefix;\n  this.postfix = !!conf.postfix;\n  this.binop = conf.binop || null;\n  this.updateContext = null;\n};\n\nfunction binop(name, prec) {\n  return new TokenType(name, {beforeExpr: true, binop: prec})\n}\nvar beforeExpr = {beforeExpr: true}, startsExpr = {startsExpr: true};\n\n// Map keyword names to token types.\n\nvar keywords = {};\n\n// Succinct definitions of keyword token types\nfunction kw(name, options) {\n  if ( options === void 0 ) options = {};\n\n  options.keyword = name;\n  return keywords[name] = new TokenType(name, options)\n}\n\nvar types$1 = {\n  num: new TokenType(\"num\", startsExpr),\n  regexp: new TokenType(\"regexp\", startsExpr),\n  string: new TokenType(\"string\", startsExpr),\n  name: new TokenType(\"name\", startsExpr),\n  privateId: new TokenType(\"privateId\", startsExpr),\n  eof: new TokenType(\"eof\"),\n\n  // Punctuation token types.\n  bracketL: new TokenType(\"[\", {beforeExpr: true, startsExpr: true}),\n  bracketR: new TokenType(\"]\"),\n  braceL: new TokenType(\"{\", {beforeExpr: true, startsExpr: true}),\n  braceR: new TokenType(\"}\"),\n  parenL: new TokenType(\"(\", {beforeExpr: true, startsExpr: true}),\n  parenR: new TokenType(\")\"),\n  comma: new TokenType(\",\", beforeExpr),\n  semi: new TokenType(\";\", beforeExpr),\n  colon: new TokenType(\":\", beforeExpr),\n  dot: new TokenType(\".\"),\n  question: new TokenType(\"?\", beforeExpr),\n  questionDot: new TokenType(\"?.\"),\n  arrow: new TokenType(\"=>\", beforeExpr),\n  template: new TokenType(\"template\"),\n  invalidTemplate: new TokenType(\"invalidTemplate\"),\n  ellipsis: new TokenType(\"...\", beforeExpr),\n  backQuote: new TokenType(\"`\", startsExpr),\n  dollarBraceL: new TokenType(\"${\", {beforeExpr: true, startsExpr: true}),\n\n  // Operators. These carry several kinds of properties to help the\n  // parser use them properly (the presence of these properties is\n  // what categorizes them as operators).\n  //\n  // `binop`, when present, specifies that this operator is a binary\n  // operator, and will refer to its precedence.\n  //\n  // `prefix` and `postfix` mark the operator as a prefix or postfix\n  // unary operator.\n  //\n  // `isAssign` marks all of `=`, `+=`, `-=` etcetera, which act as\n  // binary operators with a very low precedence, that should result\n  // in AssignmentExpression nodes.\n\n  eq: new TokenType(\"=\", {beforeExpr: true, isAssign: true}),\n  assign: new TokenType(\"_=\", {beforeExpr: true, isAssign: true}),\n  incDec: new TokenType(\"++/--\", {prefix: true, postfix: true, startsExpr: true}),\n  prefix: new TokenType(\"!/~\", {beforeExpr: true, prefix: true, startsExpr: true}),\n  logicalOR: binop(\"||\", 1),\n  logicalAND: binop(\"&&\", 2),\n  bitwiseOR: binop(\"|\", 3),\n  bitwiseXOR: binop(\"^\", 4),\n  bitwiseAND: binop(\"&\", 5),\n  equality: binop(\"==/!=/===/!==\", 6),\n  relational: binop(\"</>/<=/>=\", 7),\n  bitShift: binop(\"<</>>/>>>\", 8),\n  plusMin: new TokenType(\"+/-\", {beforeExpr: true, binop: 9, prefix: true, startsExpr: true}),\n  modulo: binop(\"%\", 10),\n  star: binop(\"*\", 10),\n  slash: binop(\"/\", 10),\n  starstar: new TokenType(\"**\", {beforeExpr: true}),\n  coalesce: binop(\"??\", 1),\n\n  // Keyword token types.\n  _break: kw(\"break\"),\n  _case: kw(\"case\", beforeExpr),\n  _catch: kw(\"catch\"),\n  _continue: kw(\"continue\"),\n  _debugger: kw(\"debugger\"),\n  _default: kw(\"default\", beforeExpr),\n  _do: kw(\"do\", {isLoop: true, beforeExpr: true}),\n  _else: kw(\"else\", beforeExpr),\n  _finally: kw(\"finally\"),\n  _for: kw(\"for\", {isLoop: true}),\n  _function: kw(\"function\", startsExpr),\n  _if: kw(\"if\"),\n  _return: kw(\"return\", beforeExpr),\n  _switch: kw(\"switch\"),\n  _throw: kw(\"throw\", beforeExpr),\n  _try: kw(\"try\"),\n  _var: kw(\"var\"),\n  _const: kw(\"const\"),\n  _while: kw(\"while\", {isLoop: true}),\n  _with: kw(\"with\"),\n  _new: kw(\"new\", {beforeExpr: true, startsExpr: true}),\n  _this: kw(\"this\", startsExpr),\n  _super: kw(\"super\", startsExpr),\n  _class: kw(\"class\", startsExpr),\n  _extends: kw(\"extends\", beforeExpr),\n  _export: kw(\"export\"),\n  _import: kw(\"import\", startsExpr),\n  _null: kw(\"null\", startsExpr),\n  _true: kw(\"true\", startsExpr),\n  _false: kw(\"false\", startsExpr),\n  _in: kw(\"in\", {beforeExpr: true, binop: 7}),\n  _instanceof: kw(\"instanceof\", {beforeExpr: true, binop: 7}),\n  _typeof: kw(\"typeof\", {beforeExpr: true, prefix: true, startsExpr: true}),\n  _void: kw(\"void\", {beforeExpr: true, prefix: true, startsExpr: true}),\n  _delete: kw(\"delete\", {beforeExpr: true, prefix: true, startsExpr: true})\n};\n\n// Matches a whole line break (where CRLF is considered a single\n// line break). Used to count lines.\n\nvar lineBreak = /\\r\\n?|\\n|\\u2028|\\u2029/;\nvar lineBreakG = new RegExp(lineBreak.source, \"g\");\n\nfunction isNewLine(code) {\n  return code === 10 || code === 13 || code === 0x2028 || code === 0x2029\n}\n\nfunction nextLineBreak(code, from, end) {\n  if ( end === void 0 ) end = code.length;\n\n  for (var i = from; i < end; i++) {\n    var next = code.charCodeAt(i);\n    if (isNewLine(next))\n      { return i < end - 1 && next === 13 && code.charCodeAt(i + 1) === 10 ? i + 2 : i + 1 }\n  }\n  return -1\n}\n\nvar nonASCIIwhitespace = /[\\u1680\\u2000-\\u200a\\u202f\\u205f\\u3000\\ufeff]/;\n\nvar skipWhiteSpace = /(?:\\s|\\/\\/.*|\\/\\*[^]*?\\*\\/)*/g;\n\nvar ref = Object.prototype;\nvar hasOwnProperty = ref.hasOwnProperty;\nvar toString = ref.toString;\n\nvar hasOwn = Object.hasOwn || (function (obj, propName) { return (\n  hasOwnProperty.call(obj, propName)\n); });\n\nvar isArray = Array.isArray || (function (obj) { return (\n  toString.call(obj) === \"[object Array]\"\n); });\n\nfunction wordsRegexp(words) {\n  return new RegExp(\"^(?:\" + words.replace(/ /g, \"|\") + \")$\")\n}\n\nfunction codePointToString(code) {\n  // UTF-16 Decoding\n  if (code <= 0xFFFF) { return String.fromCharCode(code) }\n  code -= 0x10000;\n  return String.fromCharCode((code >> 10) + 0xD800, (code & 1023) + 0xDC00)\n}\n\nvar loneSurrogate = /(?:[\\uD800-\\uDBFF](?![\\uDC00-\\uDFFF])|(?:[^\\uD800-\\uDBFF]|^)[\\uDC00-\\uDFFF])/;\n\n// These are used when `options.locations` is on, for the\n// `startLoc` and `endLoc` properties.\n\nvar Position = function Position(line, col) {\n  this.line = line;\n  this.column = col;\n};\n\nPosition.prototype.offset = function offset (n) {\n  return new Position(this.line, this.column + n)\n};\n\nvar SourceLocation = function SourceLocation(p, start, end) {\n  this.start = start;\n  this.end = end;\n  if (p.sourceFile !== null) { this.source = p.sourceFile; }\n};\n\n// The `getLineInfo` function is mostly useful when the\n// `locations` option is off (for performance reasons) and you\n// want to find the line/column position for a given character\n// offset. `input` should be the code string that the offset refers\n// into.\n\nfunction getLineInfo(input, offset) {\n  for (var line = 1, cur = 0;;) {\n    var nextBreak = nextLineBreak(input, cur, offset);\n    if (nextBreak < 0) { return new Position(line, offset - cur) }\n    ++line;\n    cur = nextBreak;\n  }\n}\n\n// A second argument must be given to configure the parser process.\n// These options are recognized (only `ecmaVersion` is required):\n\nvar defaultOptions = {\n  // `ecmaVersion` indicates the ECMAScript version to parse. Must be\n  // either 3, 5, 6 (or 2015), 7 (2016), 8 (2017), 9 (2018), 10\n  // (2019), 11 (2020), 12 (2021), 13 (2022), 14 (2023), or `\"latest\"`\n  // (the latest version the library supports). This influences\n  // support for strict mode, the set of reserved words, and support\n  // for new syntax features.\n  ecmaVersion: null,\n  // `sourceType` indicates the mode the code should be parsed in.\n  // Can be either `\"script\"` or `\"module\"`. This influences global\n  // strict mode and parsing of `import` and `export` declarations.\n  sourceType: \"script\",\n  // `onInsertedSemicolon` can be a callback that will be called\n  // when a semicolon is automatically inserted. It will be passed\n  // the position of the comma as an offset, and if `locations` is\n  // enabled, it is given the location as a `{line, column}` object\n  // as second argument.\n  onInsertedSemicolon: null,\n  // `onTrailingComma` is similar to `onInsertedSemicolon`, but for\n  // trailing commas.\n  onTrailingComma: null,\n  // By default, reserved words are only enforced if ecmaVersion >= 5.\n  // Set `allowReserved` to a boolean value to explicitly turn this on\n  // an off. When this option has the value \"never\", reserved words\n  // and keywords can also not be used as property names.\n  allowReserved: null,\n  // When enabled, a return at the top level is not considered an\n  // error.\n  allowReturnOutsideFunction: false,\n  // When enabled, import/export statements are not constrained to\n  // appearing at the top of the program, and an import.meta expression\n  // in a script isn't considered an error.\n  allowImportExportEverywhere: false,\n  // By default, await identifiers are allowed to appear at the top-level scope only if ecmaVersion >= 2022.\n  // When enabled, await identifiers are allowed to appear at the top-level scope,\n  // but they are still not allowed in non-async functions.\n  allowAwaitOutsideFunction: null,\n  // When enabled, super identifiers are not constrained to\n  // appearing in methods and do not raise an error when they appear elsewhere.\n  allowSuperOutsideMethod: null,\n  // When enabled, hashbang directive in the beginning of file is\n  // allowed and treated as a line comment. Enabled by default when\n  // `ecmaVersion` >= 2023.\n  allowHashBang: false,\n  // By default, the parser will verify that private properties are\n  // only used in places where they are valid and have been declared.\n  // Set this to false to turn such checks off.\n  checkPrivateFields: true,\n  // When `locations` is on, `loc` properties holding objects with\n  // `start` and `end` properties in `{line, column}` form (with\n  // line being 1-based and column 0-based) will be attached to the\n  // nodes.\n  locations: false,\n  // A function can be passed as `onToken` option, which will\n  // cause Acorn to call that function with object in the same\n  // format as tokens returned from `tokenizer().getToken()`. Note\n  // that you are not allowed to call the parser from the\n  // callback—that will corrupt its internal state.\n  onToken: null,\n  // A function can be passed as `onComment` option, which will\n  // cause Acorn to call that function with `(block, text, start,\n  // end)` parameters whenever a comment is skipped. `block` is a\n  // boolean indicating whether this is a block (`/* */`) comment,\n  // `text` is the content of the comment, and `start` and `end` are\n  // character offsets that denote the start and end of the comment.\n  // When the `locations` option is on, two more parameters are\n  // passed, the full `{line, column}` locations of the start and\n  // end of the comments. Note that you are not allowed to call the\n  // parser from the callback—that will corrupt its internal state.\n  onComment: null,\n  // Nodes have their start and end characters offsets recorded in\n  // `start` and `end` properties (directly on the node, rather than\n  // the `loc` object, which holds line/column data. To also add a\n  // [semi-standardized][range] `range` property holding a `[start,\n  // end]` array with the same numbers, set the `ranges` option to\n  // `true`.\n  //\n  // [range]: https://bugzilla.mozilla.org/show_bug.cgi?id=745678\n  ranges: false,\n  // It is possible to parse multiple files into a single AST by\n  // passing the tree produced by parsing the first file as\n  // `program` option in subsequent parses. This will add the\n  // toplevel forms of the parsed file to the `Program` (top) node\n  // of an existing parse tree.\n  program: null,\n  // When `locations` is on, you can pass this to record the source\n  // file in every node's `loc` object.\n  sourceFile: null,\n  // This value, if given, is stored in every node, whether\n  // `locations` is on or off.\n  directSourceFile: null,\n  // When enabled, parenthesized expressions are represented by\n  // (non-standard) ParenthesizedExpression nodes\n  preserveParens: false\n};\n\n// Interpret and default an options object\n\nvar warnedAboutEcmaVersion = false;\n\nfunction getOptions(opts) {\n  var options = {};\n\n  for (var opt in defaultOptions)\n    { options[opt] = opts && hasOwn(opts, opt) ? opts[opt] : defaultOptions[opt]; }\n\n  if (options.ecmaVersion === \"latest\") {\n    options.ecmaVersion = 1e8;\n  } else if (options.ecmaVersion == null) {\n    if (!warnedAboutEcmaVersion && typeof console === \"object\" && console.warn) {\n      warnedAboutEcmaVersion = true;\n      console.warn(\"Since Acorn 8.0.0, options.ecmaVersion is required.\\nDefaulting to 2020, but this will stop working in the future.\");\n    }\n    options.ecmaVersion = 11;\n  } else if (options.ecmaVersion >= 2015) {\n    options.ecmaVersion -= 2009;\n  }\n\n  if (options.allowReserved == null)\n    { options.allowReserved = options.ecmaVersion < 5; }\n\n  if (!opts || opts.allowHashBang == null)\n    { options.allowHashBang = options.ecmaVersion >= 14; }\n\n  if (isArray(options.onToken)) {\n    var tokens = options.onToken;\n    options.onToken = function (token) { return tokens.push(token); };\n  }\n  if (isArray(options.onComment))\n    { options.onComment = pushComment(options, options.onComment); }\n\n  return options\n}\n\nfunction pushComment(options, array) {\n  return function(block, text, start, end, startLoc, endLoc) {\n    var comment = {\n      type: block ? \"Block\" : \"Line\",\n      value: text,\n      start: start,\n      end: end\n    };\n    if (options.locations)\n      { comment.loc = new SourceLocation(this, startLoc, endLoc); }\n    if (options.ranges)\n      { comment.range = [start, end]; }\n    array.push(comment);\n  }\n}\n\n// Each scope gets a bitset that may contain these flags\nvar\n    SCOPE_TOP = 1,\n    SCOPE_FUNCTION = 2,\n    SCOPE_ASYNC = 4,\n    SCOPE_GENERATOR = 8,\n    SCOPE_ARROW = 16,\n    SCOPE_SIMPLE_CATCH = 32,\n    SCOPE_SUPER = 64,\n    SCOPE_DIRECT_SUPER = 128,\n    SCOPE_CLASS_STATIC_BLOCK = 256,\n    SCOPE_VAR = SCOPE_TOP | SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK;\n\nfunction functionFlags(async, generator) {\n  return SCOPE_FUNCTION | (async ? SCOPE_ASYNC : 0) | (generator ? SCOPE_GENERATOR : 0)\n}\n\n// Used in checkLVal* and declareName to determine the type of a binding\nvar\n    BIND_NONE = 0, // Not a binding\n    BIND_VAR = 1, // Var-style binding\n    BIND_LEXICAL = 2, // Let- or const-style binding\n    BIND_FUNCTION = 3, // Function declaration\n    BIND_SIMPLE_CATCH = 4, // Simple (identifier pattern) catch binding\n    BIND_OUTSIDE = 5; // Special case for function names as bound inside the function\n\nvar Parser = function Parser(options, input, startPos) {\n  this.options = options = getOptions(options);\n  this.sourceFile = options.sourceFile;\n  this.keywords = wordsRegexp(keywords$1[options.ecmaVersion >= 6 ? 6 : options.sourceType === \"module\" ? \"5module\" : 5]);\n  var reserved = \"\";\n  if (options.allowReserved !== true) {\n    reserved = reservedWords[options.ecmaVersion >= 6 ? 6 : options.ecmaVersion === 5 ? 5 : 3];\n    if (options.sourceType === \"module\") { reserved += \" await\"; }\n  }\n  this.reservedWords = wordsRegexp(reserved);\n  var reservedStrict = (reserved ? reserved + \" \" : \"\") + reservedWords.strict;\n  this.reservedWordsStrict = wordsRegexp(reservedStrict);\n  this.reservedWordsStrictBind = wordsRegexp(reservedStrict + \" \" + reservedWords.strictBind);\n  this.input = String(input);\n\n  // Used to signal to callers of `readWord1` whether the word\n  // contained any escape sequences. This is needed because words with\n  // escape sequences must not be interpreted as keywords.\n  this.containsEsc = false;\n\n  // Set up token state\n\n  // The current position of the tokenizer in the input.\n  if (startPos) {\n    this.pos = startPos;\n    this.lineStart = this.input.lastIndexOf(\"\\n\", startPos - 1) + 1;\n    this.curLine = this.input.slice(0, this.lineStart).split(lineBreak).length;\n  } else {\n    this.pos = this.lineStart = 0;\n    this.curLine = 1;\n  }\n\n  // Properties of the current token:\n  // Its type\n  this.type = types$1.eof;\n  // For tokens that include more information than their type, the value\n  this.value = null;\n  // Its start and end offset\n  this.start = this.end = this.pos;\n  // And, if locations are used, the {line, column} object\n  // corresponding to those offsets\n  this.startLoc = this.endLoc = this.curPosition();\n\n  // Position information for the previous token\n  this.lastTokEndLoc = this.lastTokStartLoc = null;\n  this.lastTokStart = this.lastTokEnd = this.pos;\n\n  // The context stack is used to superficially track syntactic\n  // context to predict whether a regular expression is allowed in a\n  // given position.\n  this.context = this.initialContext();\n  this.exprAllowed = true;\n\n  // Figure out if it's a module code.\n  this.inModule = options.sourceType === \"module\";\n  this.strict = this.inModule || this.strictDirective(this.pos);\n\n  // Used to signify the start of a potential arrow function\n  this.potentialArrowAt = -1;\n  this.potentialArrowInForAwait = false;\n\n  // Positions to delayed-check that yield/await does not exist in default parameters.\n  this.yieldPos = this.awaitPos = this.awaitIdentPos = 0;\n  // Labels in scope.\n  this.labels = [];\n  // Thus-far undefined exports.\n  this.undefinedExports = Object.create(null);\n\n  // If enabled, skip leading hashbang line.\n  if (this.pos === 0 && options.allowHashBang && this.input.slice(0, 2) === \"#!\")\n    { this.skipLineComment(2); }\n\n  // Scope tracking for duplicate variable names (see scope.js)\n  this.scopeStack = [];\n  this.enterScope(SCOPE_TOP);\n\n  // For RegExp validation\n  this.regexpState = null;\n\n  // The stack of private names.\n  // Each element has two properties: 'declared' and 'used'.\n  // When it exited from the outermost class definition, all used private names must be declared.\n  this.privateNameStack = [];\n};\n\nvar prototypeAccessors = { inFunction: { configurable: true },inGenerator: { configurable: true },inAsync: { configurable: true },canAwait: { configurable: true },allowSuper: { configurable: true },allowDirectSuper: { configurable: true },treatFunctionsAsVar: { configurable: true },allowNewDotTarget: { configurable: true },inClassStaticBlock: { configurable: true } };\n\nParser.prototype.parse = function parse () {\n  var node = this.options.program || this.startNode();\n  this.nextToken();\n  return this.parseTopLevel(node)\n};\n\nprototypeAccessors.inFunction.get = function () { return (this.currentVarScope().flags & SCOPE_FUNCTION) > 0 };\n\nprototypeAccessors.inGenerator.get = function () { return (this.currentVarScope().flags & SCOPE_GENERATOR) > 0 && !this.currentVarScope().inClassFieldInit };\n\nprototypeAccessors.inAsync.get = function () { return (this.currentVarScope().flags & SCOPE_ASYNC) > 0 && !this.currentVarScope().inClassFieldInit };\n\nprototypeAccessors.canAwait.get = function () {\n  for (var i = this.scopeStack.length - 1; i >= 0; i--) {\n    var scope = this.scopeStack[i];\n    if (scope.inClassFieldInit || scope.flags & SCOPE_CLASS_STATIC_BLOCK) { return false }\n    if (scope.flags & SCOPE_FUNCTION) { return (scope.flags & SCOPE_ASYNC) > 0 }\n  }\n  return (this.inModule && this.options.ecmaVersion >= 13) || this.options.allowAwaitOutsideFunction\n};\n\nprototypeAccessors.allowSuper.get = function () {\n  var ref = this.currentThisScope();\n    var flags = ref.flags;\n    var inClassFieldInit = ref.inClassFieldInit;\n  return (flags & SCOPE_SUPER) > 0 || inClassFieldInit || this.options.allowSuperOutsideMethod\n};\n\nprototypeAccessors.allowDirectSuper.get = function () { return (this.currentThisScope().flags & SCOPE_DIRECT_SUPER) > 0 };\n\nprototypeAccessors.treatFunctionsAsVar.get = function () { return this.treatFunctionsAsVarInScope(this.currentScope()) };\n\nprototypeAccessors.allowNewDotTarget.get = function () {\n  var ref = this.currentThisScope();\n    var flags = ref.flags;\n    var inClassFieldInit = ref.inClassFieldInit;\n  return (flags & (SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK)) > 0 || inClassFieldInit\n};\n\nprototypeAccessors.inClassStaticBlock.get = function () {\n  return (this.currentVarScope().flags & SCOPE_CLASS_STATIC_BLOCK) > 0\n};\n\nParser.extend = function extend () {\n    var plugins = [], len = arguments.length;\n    while ( len-- ) plugins[ len ] = arguments[ len ];\n\n  var cls = this;\n  for (var i = 0; i < plugins.length; i++) { cls = plugins[i](cls); }\n  return cls\n};\n\nParser.parse = function parse (input, options) {\n  return new this(options, input).parse()\n};\n\nParser.parseExpressionAt = function parseExpressionAt (input, pos, options) {\n  var parser = new this(options, input, pos);\n  parser.nextToken();\n  return parser.parseExpression()\n};\n\nParser.tokenizer = function tokenizer (input, options) {\n  return new this(options, input)\n};\n\nObject.defineProperties( Parser.prototype, prototypeAccessors );\n\nvar pp$9 = Parser.prototype;\n\n// ## Parser utilities\n\nvar literal = /^(?:'((?:\\\\.|[^'\\\\])*?)'|\"((?:\\\\.|[^\"\\\\])*?)\")/;\npp$9.strictDirective = function(start) {\n  if (this.options.ecmaVersion < 5) { return false }\n  for (;;) {\n    // Try to find string literal.\n    skipWhiteSpace.lastIndex = start;\n    start += skipWhiteSpace.exec(this.input)[0].length;\n    var match = literal.exec(this.input.slice(start));\n    if (!match) { return false }\n    if ((match[1] || match[2]) === \"use strict\") {\n      skipWhiteSpace.lastIndex = start + match[0].length;\n      var spaceAfter = skipWhiteSpace.exec(this.input), end = spaceAfter.index + spaceAfter[0].length;\n      var next = this.input.charAt(end);\n      return next === \";\" || next === \"}\" ||\n        (lineBreak.test(spaceAfter[0]) &&\n         !(/[(`.[+\\-/*%<>=,?^&]/.test(next) || next === \"!\" && this.input.charAt(end + 1) === \"=\"))\n    }\n    start += match[0].length;\n\n    // Skip semicolon, if any.\n    skipWhiteSpace.lastIndex = start;\n    start += skipWhiteSpace.exec(this.input)[0].length;\n    if (this.input[start] === \";\")\n      { start++; }\n  }\n};\n\n// Predicate that tests whether the next token is of the given\n// type, and if yes, consumes it as a side effect.\n\npp$9.eat = function(type) {\n  if (this.type === type) {\n    this.next();\n    return true\n  } else {\n    return false\n  }\n};\n\n// Tests whether parsed token is a contextual keyword.\n\npp$9.isContextual = function(name) {\n  return this.type === types$1.name && this.value === name && !this.containsEsc\n};\n\n// Consumes contextual keyword if possible.\n\npp$9.eatContextual = function(name) {\n  if (!this.isContextual(name)) { return false }\n  this.next();\n  return true\n};\n\n// Asserts that following token is given contextual keyword.\n\npp$9.expectContextual = function(name) {\n  if (!this.eatContextual(name)) { this.unexpected(); }\n};\n\n// Test whether a semicolon can be inserted at the current position.\n\npp$9.canInsertSemicolon = function() {\n  return this.type === types$1.eof ||\n    this.type === types$1.braceR ||\n    lineBreak.test(this.input.slice(this.lastTokEnd, this.start))\n};\n\npp$9.insertSemicolon = function() {\n  if (this.canInsertSemicolon()) {\n    if (this.options.onInsertedSemicolon)\n      { this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc); }\n    return true\n  }\n};\n\n// Consume a semicolon, or, failing that, see if we are allowed to\n// pretend that there is a semicolon at this position.\n\npp$9.semicolon = function() {\n  if (!this.eat(types$1.semi) && !this.insertSemicolon()) { this.unexpected(); }\n};\n\npp$9.afterTrailingComma = function(tokType, notNext) {\n  if (this.type === tokType) {\n    if (this.options.onTrailingComma)\n      { this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc); }\n    if (!notNext)\n      { this.next(); }\n    return true\n  }\n};\n\n// Expect a token of a given type. If found, consume it, otherwise,\n// raise an unexpected token error.\n\npp$9.expect = function(type) {\n  this.eat(type) || this.unexpected();\n};\n\n// Raise an unexpected token error.\n\npp$9.unexpected = function(pos) {\n  this.raise(pos != null ? pos : this.start, \"Unexpected token\");\n};\n\nvar DestructuringErrors = function DestructuringErrors() {\n  this.shorthandAssign =\n  this.trailingComma =\n  this.parenthesizedAssign =\n  this.parenthesizedBind =\n  this.doubleProto =\n    -1;\n};\n\npp$9.checkPatternErrors = function(refDestructuringErrors, isAssign) {\n  if (!refDestructuringErrors) { return }\n  if (refDestructuringErrors.trailingComma > -1)\n    { this.raiseRecoverable(refDestructuringErrors.trailingComma, \"Comma is not permitted after the rest element\"); }\n  var parens = isAssign ? refDestructuringErrors.parenthesizedAssign : refDestructuringErrors.parenthesizedBind;\n  if (parens > -1) { this.raiseRecoverable(parens, isAssign ? \"Assigning to rvalue\" : \"Parenthesized pattern\"); }\n};\n\npp$9.checkExpressionErrors = function(refDestructuringErrors, andThrow) {\n  if (!refDestructuringErrors) { return false }\n  var shorthandAssign = refDestructuringErrors.shorthandAssign;\n  var doubleProto = refDestructuringErrors.doubleProto;\n  if (!andThrow) { return shorthandAssign >= 0 || doubleProto >= 0 }\n  if (shorthandAssign >= 0)\n    { this.raise(shorthandAssign, \"Shorthand property assignments are valid only in destructuring patterns\"); }\n  if (doubleProto >= 0)\n    { this.raiseRecoverable(doubleProto, \"Redefinition of __proto__ property\"); }\n};\n\npp$9.checkYieldAwaitInDefaultParams = function() {\n  if (this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos))\n    { this.raise(this.yieldPos, \"Yield expression cannot be a default value\"); }\n  if (this.awaitPos)\n    { this.raise(this.awaitPos, \"Await expression cannot be a default value\"); }\n};\n\npp$9.isSimpleAssignTarget = function(expr) {\n  if (expr.type === \"ParenthesizedExpression\")\n    { return this.isSimpleAssignTarget(expr.expression) }\n  return expr.type === \"Identifier\" || expr.type === \"MemberExpression\"\n};\n\nvar pp$8 = Parser.prototype;\n\n// ### Statement parsing\n\n// Parse a program. Initializes the parser, reads any number of\n// statements, and wraps them in a Program node.  Optionally takes a\n// `program` argument.  If present, the statements will be appended\n// to its body instead of creating a new node.\n\npp$8.parseTopLevel = function(node) {\n  var exports = Object.create(null);\n  if (!node.body) { node.body = []; }\n  while (this.type !== types$1.eof) {\n    var stmt = this.parseStatement(null, true, exports);\n    node.body.push(stmt);\n  }\n  if (this.inModule)\n    { for (var i = 0, list = Object.keys(this.undefinedExports); i < list.length; i += 1)\n      {\n        var name = list[i];\n\n        this.raiseRecoverable(this.undefinedExports[name].start, (\"Export '\" + name + \"' is not defined\"));\n      } }\n  this.adaptDirectivePrologue(node.body);\n  this.next();\n  node.sourceType = this.options.sourceType;\n  return this.finishNode(node, \"Program\")\n};\n\nvar loopLabel = {kind: \"loop\"}, switchLabel = {kind: \"switch\"};\n\npp$8.isLet = function(context) {\n  if (this.options.ecmaVersion < 6 || !this.isContextual(\"let\")) { return false }\n  skipWhiteSpace.lastIndex = this.pos;\n  var skip = skipWhiteSpace.exec(this.input);\n  var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);\n  // For ambiguous cases, determine if a LexicalDeclaration (or only a\n  // Statement) is allowed here. If context is not empty then only a Statement\n  // is allowed. However, `let [` is an explicit negative lookahead for\n  // ExpressionStatement, so special-case it first.\n  if (nextCh === 91 || nextCh === 92) { return true } // '[', '/'\n  if (context) { return false }\n\n  if (nextCh === 123 || nextCh > 0xd7ff && nextCh < 0xdc00) { return true } // '{', astral\n  if (isIdentifierStart(nextCh, true)) {\n    var pos = next + 1;\n    while (isIdentifierChar(nextCh = this.input.charCodeAt(pos), true)) { ++pos; }\n    if (nextCh === 92 || nextCh > 0xd7ff && nextCh < 0xdc00) { return true }\n    var ident = this.input.slice(next, pos);\n    if (!keywordRelationalOperator.test(ident)) { return true }\n  }\n  return false\n};\n\n// check 'async [no LineTerminator here] function'\n// - 'async /*foo*/ function' is OK.\n// - 'async /*\\n*/ function' is invalid.\npp$8.isAsyncFunction = function() {\n  if (this.options.ecmaVersion < 8 || !this.isContextual(\"async\"))\n    { return false }\n\n  skipWhiteSpace.lastIndex = this.pos;\n  var skip = skipWhiteSpace.exec(this.input);\n  var next = this.pos + skip[0].length, after;\n  return !lineBreak.test(this.input.slice(this.pos, next)) &&\n    this.input.slice(next, next + 8) === \"function\" &&\n    (next + 8 === this.input.length ||\n     !(isIdentifierChar(after = this.input.charCodeAt(next + 8)) || after > 0xd7ff && after < 0xdc00))\n};\n\n// Parse a single statement.\n//\n// If expecting a statement and finding a slash operator, parse a\n// regular expression literal. This is to handle cases like\n// `if (foo) /blah/.exec(foo)`, where looking at the previous token\n// does not help.\n\npp$8.parseStatement = function(context, topLevel, exports) {\n  var starttype = this.type, node = this.startNode(), kind;\n\n  if (this.isLet(context)) {\n    starttype = types$1._var;\n    kind = \"let\";\n  }\n\n  // Most types of statements are recognized by the keyword they\n  // start with. Many are trivial to parse, some require a bit of\n  // complexity.\n\n  switch (starttype) {\n  case types$1._break: case types$1._continue: return this.parseBreakContinueStatement(node, starttype.keyword)\n  case types$1._debugger: return this.parseDebuggerStatement(node)\n  case types$1._do: return this.parseDoStatement(node)\n  case types$1._for: return this.parseForStatement(node)\n  case types$1._function:\n    // Function as sole body of either an if statement or a labeled statement\n    // works, but not when it is part of a labeled statement that is the sole\n    // body of an if statement.\n    if ((context && (this.strict || context !== \"if\" && context !== \"label\")) && this.options.ecmaVersion >= 6) { this.unexpected(); }\n    return this.parseFunctionStatement(node, false, !context)\n  case types$1._class:\n    if (context) { this.unexpected(); }\n    return this.parseClass(node, true)\n  case types$1._if: return this.parseIfStatement(node)\n  case types$1._return: return this.parseReturnStatement(node)\n  case types$1._switch: return this.parseSwitchStatement(node)\n  case types$1._throw: return this.parseThrowStatement(node)\n  case types$1._try: return this.parseTryStatement(node)\n  case types$1._const: case types$1._var:\n    kind = kind || this.value;\n    if (context && kind !== \"var\") { this.unexpected(); }\n    return this.parseVarStatement(node, kind)\n  case types$1._while: return this.parseWhileStatement(node)\n  case types$1._with: return this.parseWithStatement(node)\n  case types$1.braceL: return this.parseBlock(true, node)\n  case types$1.semi: return this.parseEmptyStatement(node)\n  case types$1._export:\n  case types$1._import:\n    if (this.options.ecmaVersion > 10 && starttype === types$1._import) {\n      skipWhiteSpace.lastIndex = this.pos;\n      var skip = skipWhiteSpace.exec(this.input);\n      var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);\n      if (nextCh === 40 || nextCh === 46) // '(' or '.'\n        { return this.parseExpressionStatement(node, this.parseExpression()) }\n    }\n\n    if (!this.options.allowImportExportEverywhere) {\n      if (!topLevel)\n        { this.raise(this.start, \"'import' and 'export' may only appear at the top level\"); }\n      if (!this.inModule)\n        { this.raise(this.start, \"'import' and 'export' may appear only with 'sourceType: module'\"); }\n    }\n    return starttype === types$1._import ? this.parseImport(node) : this.parseExport(node, exports)\n\n    // If the statement does not start with a statement keyword or a\n    // brace, it's an ExpressionStatement or LabeledStatement. We\n    // simply start parsing an expression, and afterwards, if the\n    // next token is a colon and the expression was a simple\n    // Identifier node, we switch to interpreting it as a label.\n  default:\n    if (this.isAsyncFunction()) {\n      if (context) { this.unexpected(); }\n      this.next();\n      return this.parseFunctionStatement(node, true, !context)\n    }\n\n    var maybeName = this.value, expr = this.parseExpression();\n    if (starttype === types$1.name && expr.type === \"Identifier\" && this.eat(types$1.colon))\n      { return this.parseLabeledStatement(node, maybeName, expr, context) }\n    else { return this.parseExpressionStatement(node, expr) }\n  }\n};\n\npp$8.parseBreakContinueStatement = function(node, keyword) {\n  var isBreak = keyword === \"break\";\n  this.next();\n  if (this.eat(types$1.semi) || this.insertSemicolon()) { node.label = null; }\n  else if (this.type !== types$1.name) { this.unexpected(); }\n  else {\n    node.label = this.parseIdent();\n    this.semicolon();\n  }\n\n  // Verify that there is an actual destination to break or\n  // continue to.\n  var i = 0;\n  for (; i < this.labels.length; ++i) {\n    var lab = this.labels[i];\n    if (node.label == null || lab.name === node.label.name) {\n      if (lab.kind != null && (isBreak || lab.kind === \"loop\")) { break }\n      if (node.label && isBreak) { break }\n    }\n  }\n  if (i === this.labels.length) { this.raise(node.start, \"Unsyntactic \" + keyword); }\n  return this.finishNode(node, isBreak ? \"BreakStatement\" : \"ContinueStatement\")\n};\n\npp$8.parseDebuggerStatement = function(node) {\n  this.next();\n  this.semicolon();\n  return this.finishNode(node, \"DebuggerStatement\")\n};\n\npp$8.parseDoStatement = function(node) {\n  this.next();\n  this.labels.push(loopLabel);\n  node.body = this.parseStatement(\"do\");\n  this.labels.pop();\n  this.expect(types$1._while);\n  node.test = this.parseParenExpression();\n  if (this.options.ecmaVersion >= 6)\n    { this.eat(types$1.semi); }\n  else\n    { this.semicolon(); }\n  return this.finishNode(node, \"DoWhileStatement\")\n};\n\n// Disambiguating between a `for` and a `for`/`in` or `for`/`of`\n// loop is non-trivial. Basically, we have to parse the init `var`\n// statement or expression, disallowing the `in` operator (see\n// the second parameter to `parseExpression`), and then check\n// whether the next token is `in` or `of`. When there is no init\n// part (semicolon immediately after the opening parenthesis), it\n// is a regular `for` loop.\n\npp$8.parseForStatement = function(node) {\n  this.next();\n  var awaitAt = (this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual(\"await\")) ? this.lastTokStart : -1;\n  this.labels.push(loopLabel);\n  this.enterScope(0);\n  this.expect(types$1.parenL);\n  if (this.type === types$1.semi) {\n    if (awaitAt > -1) { this.unexpected(awaitAt); }\n    return this.parseFor(node, null)\n  }\n  var isLet = this.isLet();\n  if (this.type === types$1._var || this.type === types$1._const || isLet) {\n    var init$1 = this.startNode(), kind = isLet ? \"let\" : this.value;\n    this.next();\n    this.parseVar(init$1, true, kind);\n    this.finishNode(init$1, \"VariableDeclaration\");\n    if ((this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual(\"of\"))) && init$1.declarations.length === 1) {\n      if (this.options.ecmaVersion >= 9) {\n        if (this.type === types$1._in) {\n          if (awaitAt > -1) { this.unexpected(awaitAt); }\n        } else { node.await = awaitAt > -1; }\n      }\n      return this.parseForIn(node, init$1)\n    }\n    if (awaitAt > -1) { this.unexpected(awaitAt); }\n    return this.parseFor(node, init$1)\n  }\n  var startsWithLet = this.isContextual(\"let\"), isForOf = false;\n  var refDestructuringErrors = new DestructuringErrors;\n  var init = this.parseExpression(awaitAt > -1 ? \"await\" : true, refDestructuringErrors);\n  if (this.type === types$1._in || (isForOf = this.options.ecmaVersion >= 6 && this.isContextual(\"of\"))) {\n    if (this.options.ecmaVersion >= 9) {\n      if (this.type === types$1._in) {\n        if (awaitAt > -1) { this.unexpected(awaitAt); }\n      } else { node.await = awaitAt > -1; }\n    }\n    if (startsWithLet && isForOf) { this.raise(init.start, \"The left-hand side of a for-of loop may not start with 'let'.\"); }\n    this.toAssignable(init, false, refDestructuringErrors);\n    this.checkLValPattern(init);\n    return this.parseForIn(node, init)\n  } else {\n    this.checkExpressionErrors(refDestructuringErrors, true);\n  }\n  if (awaitAt > -1) { this.unexpected(awaitAt); }\n  return this.parseFor(node, init)\n};\n\npp$8.parseFunctionStatement = function(node, isAsync, declarationPosition) {\n  this.next();\n  return this.parseFunction(node, FUNC_STATEMENT | (declarationPosition ? 0 : FUNC_HANGING_STATEMENT), false, isAsync)\n};\n\npp$8.parseIfStatement = function(node) {\n  this.next();\n  node.test = this.parseParenExpression();\n  // allow function declarations in branches, but only in non-strict mode\n  node.consequent = this.parseStatement(\"if\");\n  node.alternate = this.eat(types$1._else) ? this.parseStatement(\"if\") : null;\n  return this.finishNode(node, \"IfStatement\")\n};\n\npp$8.parseReturnStatement = function(node) {\n  if (!this.inFunction && !this.options.allowReturnOutsideFunction)\n    { this.raise(this.start, \"'return' outside of function\"); }\n  this.next();\n\n  // In `return` (and `break`/`continue`), the keywords with\n  // optional arguments, we eagerly look for a semicolon or the\n  // possibility to insert one.\n\n  if (this.eat(types$1.semi) || this.insertSemicolon()) { node.argument = null; }\n  else { node.argument = this.parseExpression(); this.semicolon(); }\n  return this.finishNode(node, \"ReturnStatement\")\n};\n\npp$8.parseSwitchStatement = function(node) {\n  this.next();\n  node.discriminant = this.parseParenExpression();\n  node.cases = [];\n  this.expect(types$1.braceL);\n  this.labels.push(switchLabel);\n  this.enterScope(0);\n\n  // Statements under must be grouped (by label) in SwitchCase\n  // nodes. `cur` is used to keep the node that we are currently\n  // adding statements to.\n\n  var cur;\n  for (var sawDefault = false; this.type !== types$1.braceR;) {\n    if (this.type === types$1._case || this.type === types$1._default) {\n      var isCase = this.type === types$1._case;\n      if (cur) { this.finishNode(cur, \"SwitchCase\"); }\n      node.cases.push(cur = this.startNode());\n      cur.consequent = [];\n      this.next();\n      if (isCase) {\n        cur.test = this.parseExpression();\n      } else {\n        if (sawDefault) { this.raiseRecoverable(this.lastTokStart, \"Multiple default clauses\"); }\n        sawDefault = true;\n        cur.test = null;\n      }\n      this.expect(types$1.colon);\n    } else {\n      if (!cur) { this.unexpected(); }\n      cur.consequent.push(this.parseStatement(null));\n    }\n  }\n  this.exitScope();\n  if (cur) { this.finishNode(cur, \"SwitchCase\"); }\n  this.next(); // Closing brace\n  this.labels.pop();\n  return this.finishNode(node, \"SwitchStatement\")\n};\n\npp$8.parseThrowStatement = function(node) {\n  this.next();\n  if (lineBreak.test(this.input.slice(this.lastTokEnd, this.start)))\n    { this.raise(this.lastTokEnd, \"Illegal newline after throw\"); }\n  node.argument = this.parseExpression();\n  this.semicolon();\n  return this.finishNode(node, \"ThrowStatement\")\n};\n\n// Reused empty array added for node fields that are always empty.\n\nvar empty$1 = [];\n\npp$8.parseCatchClauseParam = function() {\n  var param = this.parseBindingAtom();\n  var simple = param.type === \"Identifier\";\n  this.enterScope(simple ? SCOPE_SIMPLE_CATCH : 0);\n  this.checkLValPattern(param, simple ? BIND_SIMPLE_CATCH : BIND_LEXICAL);\n  this.expect(types$1.parenR);\n\n  return param\n};\n\npp$8.parseTryStatement = function(node) {\n  this.next();\n  node.block = this.parseBlock();\n  node.handler = null;\n  if (this.type === types$1._catch) {\n    var clause = this.startNode();\n    this.next();\n    if (this.eat(types$1.parenL)) {\n      clause.param = this.parseCatchClauseParam();\n    } else {\n      if (this.options.ecmaVersion < 10) { this.unexpected(); }\n      clause.param = null;\n      this.enterScope(0);\n    }\n    clause.body = this.parseBlock(false);\n    this.exitScope();\n    node.handler = this.finishNode(clause, \"CatchClause\");\n  }\n  node.finalizer = this.eat(types$1._finally) ? this.parseBlock() : null;\n  if (!node.handler && !node.finalizer)\n    { this.raise(node.start, \"Missing catch or finally clause\"); }\n  return this.finishNode(node, \"TryStatement\")\n};\n\npp$8.parseVarStatement = function(node, kind, allowMissingInitializer) {\n  this.next();\n  this.parseVar(node, false, kind, allowMissingInitializer);\n  this.semicolon();\n  return this.finishNode(node, \"VariableDeclaration\")\n};\n\npp$8.parseWhileStatement = function(node) {\n  this.next();\n  node.test = this.parseParenExpression();\n  this.labels.push(loopLabel);\n  node.body = this.parseStatement(\"while\");\n  this.labels.pop();\n  return this.finishNode(node, \"WhileStatement\")\n};\n\npp$8.parseWithStatement = function(node) {\n  if (this.strict) { this.raise(this.start, \"'with' in strict mode\"); }\n  this.next();\n  node.object = this.parseParenExpression();\n  node.body = this.parseStatement(\"with\");\n  return this.finishNode(node, \"WithStatement\")\n};\n\npp$8.parseEmptyStatement = function(node) {\n  this.next();\n  return this.finishNode(node, \"EmptyStatement\")\n};\n\npp$8.parseLabeledStatement = function(node, maybeName, expr, context) {\n  for (var i$1 = 0, list = this.labels; i$1 < list.length; i$1 += 1)\n    {\n    var label = list[i$1];\n\n    if (label.name === maybeName)\n      { this.raise(expr.start, \"Label '\" + maybeName + \"' is already declared\");\n  } }\n  var kind = this.type.isLoop ? \"loop\" : this.type === types$1._switch ? \"switch\" : null;\n  for (var i = this.labels.length - 1; i >= 0; i--) {\n    var label$1 = this.labels[i];\n    if (label$1.statementStart === node.start) {\n      // Update information about previous labels on this node\n      label$1.statementStart = this.start;\n      label$1.kind = kind;\n    } else { break }\n  }\n  this.labels.push({name: maybeName, kind: kind, statementStart: this.start});\n  node.body = this.parseStatement(context ? context.indexOf(\"label\") === -1 ? context + \"label\" : context : \"label\");\n  this.labels.pop();\n  node.label = expr;\n  return this.finishNode(node, \"LabeledStatement\")\n};\n\npp$8.parseExpressionStatement = function(node, expr) {\n  node.expression = expr;\n  this.semicolon();\n  return this.finishNode(node, \"ExpressionStatement\")\n};\n\n// Parse a semicolon-enclosed block of statements, handling `\"use\n// strict\"` declarations when `allowStrict` is true (used for\n// function bodies).\n\npp$8.parseBlock = function(createNewLexicalScope, node, exitStrict) {\n  if ( createNewLexicalScope === void 0 ) createNewLexicalScope = true;\n  if ( node === void 0 ) node = this.startNode();\n\n  node.body = [];\n  this.expect(types$1.braceL);\n  if (createNewLexicalScope) { this.enterScope(0); }\n  while (this.type !== types$1.braceR) {\n    var stmt = this.parseStatement(null);\n    node.body.push(stmt);\n  }\n  if (exitStrict) { this.strict = false; }\n  this.next();\n  if (createNewLexicalScope) { this.exitScope(); }\n  return this.finishNode(node, \"BlockStatement\")\n};\n\n// Parse a regular `for` loop. The disambiguation code in\n// `parseStatement` will already have parsed the init statement or\n// expression.\n\npp$8.parseFor = function(node, init) {\n  node.init = init;\n  this.expect(types$1.semi);\n  node.test = this.type === types$1.semi ? null : this.parseExpression();\n  this.expect(types$1.semi);\n  node.update = this.type === types$1.parenR ? null : this.parseExpression();\n  this.expect(types$1.parenR);\n  node.body = this.parseStatement(\"for\");\n  this.exitScope();\n  this.labels.pop();\n  return this.finishNode(node, \"ForStatement\")\n};\n\n// Parse a `for`/`in` and `for`/`of` loop, which are almost\n// same from parser's perspective.\n\npp$8.parseForIn = function(node, init) {\n  var isForIn = this.type === types$1._in;\n  this.next();\n\n  if (\n    init.type === \"VariableDeclaration\" &&\n    init.declarations[0].init != null &&\n    (\n      !isForIn ||\n      this.options.ecmaVersion < 8 ||\n      this.strict ||\n      init.kind !== \"var\" ||\n      init.declarations[0].id.type !== \"Identifier\"\n    )\n  ) {\n    this.raise(\n      init.start,\n      ((isForIn ? \"for-in\" : \"for-of\") + \" loop variable declaration may not have an initializer\")\n    );\n  }\n  node.left = init;\n  node.right = isForIn ? this.parseExpression() : this.parseMaybeAssign();\n  this.expect(types$1.parenR);\n  node.body = this.parseStatement(\"for\");\n  this.exitScope();\n  this.labels.pop();\n  return this.finishNode(node, isForIn ? \"ForInStatement\" : \"ForOfStatement\")\n};\n\n// Parse a list of variable declarations.\n\npp$8.parseVar = function(node, isFor, kind, allowMissingInitializer) {\n  node.declarations = [];\n  node.kind = kind;\n  for (;;) {\n    var decl = this.startNode();\n    this.parseVarId(decl, kind);\n    if (this.eat(types$1.eq)) {\n      decl.init = this.parseMaybeAssign(isFor);\n    } else if (!allowMissingInitializer && kind === \"const\" && !(this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual(\"of\")))) {\n      this.unexpected();\n    } else if (!allowMissingInitializer && decl.id.type !== \"Identifier\" && !(isFor && (this.type === types$1._in || this.isContextual(\"of\")))) {\n      this.raise(this.lastTokEnd, \"Complex binding patterns require an initialization value\");\n    } else {\n      decl.init = null;\n    }\n    node.declarations.push(this.finishNode(decl, \"VariableDeclarator\"));\n    if (!this.eat(types$1.comma)) { break }\n  }\n  return node\n};\n\npp$8.parseVarId = function(decl, kind) {\n  decl.id = this.parseBindingAtom();\n  this.checkLValPattern(decl.id, kind === \"var\" ? BIND_VAR : BIND_LEXICAL, false);\n};\n\nvar FUNC_STATEMENT = 1, FUNC_HANGING_STATEMENT = 2, FUNC_NULLABLE_ID = 4;\n\n// Parse a function declaration or literal (depending on the\n// `statement & FUNC_STATEMENT`).\n\n// Remove `allowExpressionBody` for 7.0.0, as it is only called with false\npp$8.parseFunction = function(node, statement, allowExpressionBody, isAsync, forInit) {\n  this.initFunction(node);\n  if (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !isAsync) {\n    if (this.type === types$1.star && (statement & FUNC_HANGING_STATEMENT))\n      { this.unexpected(); }\n    node.generator = this.eat(types$1.star);\n  }\n  if (this.options.ecmaVersion >= 8)\n    { node.async = !!isAsync; }\n\n  if (statement & FUNC_STATEMENT) {\n    node.id = (statement & FUNC_NULLABLE_ID) && this.type !== types$1.name ? null : this.parseIdent();\n    if (node.id && !(statement & FUNC_HANGING_STATEMENT))\n      // If it is a regular function declaration in sloppy mode, then it is\n      // subject to Annex B semantics (BIND_FUNCTION). Otherwise, the binding\n      // mode depends on properties of the current scope (see\n      // treatFunctionsAsVar).\n      { this.checkLValSimple(node.id, (this.strict || node.generator || node.async) ? this.treatFunctionsAsVar ? BIND_VAR : BIND_LEXICAL : BIND_FUNCTION); }\n  }\n\n  var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;\n  this.yieldPos = 0;\n  this.awaitPos = 0;\n  this.awaitIdentPos = 0;\n  this.enterScope(functionFlags(node.async, node.generator));\n\n  if (!(statement & FUNC_STATEMENT))\n    { node.id = this.type === types$1.name ? this.parseIdent() : null; }\n\n  this.parseFunctionParams(node);\n  this.parseFunctionBody(node, allowExpressionBody, false, forInit);\n\n  this.yieldPos = oldYieldPos;\n  this.awaitPos = oldAwaitPos;\n  this.awaitIdentPos = oldAwaitIdentPos;\n  return this.finishNode(node, (statement & FUNC_STATEMENT) ? \"FunctionDeclaration\" : \"FunctionExpression\")\n};\n\npp$8.parseFunctionParams = function(node) {\n  this.expect(types$1.parenL);\n  node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);\n  this.checkYieldAwaitInDefaultParams();\n};\n\n// Parse a class declaration or literal (depending on the\n// `isStatement` parameter).\n\npp$8.parseClass = function(node, isStatement) {\n  this.next();\n\n  // ecma-262 14.6 Class Definitions\n  // A class definition is always strict mode code.\n  var oldStrict = this.strict;\n  this.strict = true;\n\n  this.parseClassId(node, isStatement);\n  this.parseClassSuper(node);\n  var privateNameMap = this.enterClassBody();\n  var classBody = this.startNode();\n  var hadConstructor = false;\n  classBody.body = [];\n  this.expect(types$1.braceL);\n  while (this.type !== types$1.braceR) {\n    var element = this.parseClassElement(node.superClass !== null);\n    if (element) {\n      classBody.body.push(element);\n      if (element.type === \"MethodDefinition\" && element.kind === \"constructor\") {\n        if (hadConstructor) { this.raiseRecoverable(element.start, \"Duplicate constructor in the same class\"); }\n        hadConstructor = true;\n      } else if (element.key && element.key.type === \"PrivateIdentifier\" && isPrivateNameConflicted(privateNameMap, element)) {\n        this.raiseRecoverable(element.key.start, (\"Identifier '#\" + (element.key.name) + \"' has already been declared\"));\n      }\n    }\n  }\n  this.strict = oldStrict;\n  this.next();\n  node.body = this.finishNode(classBody, \"ClassBody\");\n  this.exitClassBody();\n  return this.finishNode(node, isStatement ? \"ClassDeclaration\" : \"ClassExpression\")\n};\n\npp$8.parseClassElement = function(constructorAllowsSuper) {\n  if (this.eat(types$1.semi)) { return null }\n\n  var ecmaVersion = this.options.ecmaVersion;\n  var node = this.startNode();\n  var keyName = \"\";\n  var isGenerator = false;\n  var isAsync = false;\n  var kind = \"method\";\n  var isStatic = false;\n\n  if (this.eatContextual(\"static\")) {\n    // Parse static init block\n    if (ecmaVersion >= 13 && this.eat(types$1.braceL)) {\n      this.parseClassStaticBlock(node);\n      return node\n    }\n    if (this.isClassElementNameStart() || this.type === types$1.star) {\n      isStatic = true;\n    } else {\n      keyName = \"static\";\n    }\n  }\n  node.static = isStatic;\n  if (!keyName && ecmaVersion >= 8 && this.eatContextual(\"async\")) {\n    if ((this.isClassElementNameStart() || this.type === types$1.star) && !this.canInsertSemicolon()) {\n      isAsync = true;\n    } else {\n      keyName = \"async\";\n    }\n  }\n  if (!keyName && (ecmaVersion >= 9 || !isAsync) && this.eat(types$1.star)) {\n    isGenerator = true;\n  }\n  if (!keyName && !isAsync && !isGenerator) {\n    var lastValue = this.value;\n    if (this.eatContextual(\"get\") || this.eatContextual(\"set\")) {\n      if (this.isClassElementNameStart()) {\n        kind = lastValue;\n      } else {\n        keyName = lastValue;\n      }\n    }\n  }\n\n  // Parse element name\n  if (keyName) {\n    // 'async', 'get', 'set', or 'static' were not a keyword contextually.\n    // The last token is any of those. Make it the element name.\n    node.computed = false;\n    node.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc);\n    node.key.name = keyName;\n    this.finishNode(node.key, \"Identifier\");\n  } else {\n    this.parseClassElementName(node);\n  }\n\n  // Parse element value\n  if (ecmaVersion < 13 || this.type === types$1.parenL || kind !== \"method\" || isGenerator || isAsync) {\n    var isConstructor = !node.static && checkKeyName(node, \"constructor\");\n    var allowsDirectSuper = isConstructor && constructorAllowsSuper;\n    // Couldn't move this check into the 'parseClassMethod' method for backward compatibility.\n    if (isConstructor && kind !== \"method\") { this.raise(node.key.start, \"Constructor can't have get/set modifier\"); }\n    node.kind = isConstructor ? \"constructor\" : kind;\n    this.parseClassMethod(node, isGenerator, isAsync, allowsDirectSuper);\n  } else {\n    this.parseClassField(node);\n  }\n\n  return node\n};\n\npp$8.isClassElementNameStart = function() {\n  return (\n    this.type === types$1.name ||\n    this.type === types$1.privateId ||\n    this.type === types$1.num ||\n    this.type === types$1.string ||\n    this.type === types$1.bracketL ||\n    this.type.keyword\n  )\n};\n\npp$8.parseClassElementName = function(element) {\n  if (this.type === types$1.privateId) {\n    if (this.value === \"constructor\") {\n      this.raise(this.start, \"Classes can't have an element named '#constructor'\");\n    }\n    element.computed = false;\n    element.key = this.parsePrivateIdent();\n  } else {\n    this.parsePropertyName(element);\n  }\n};\n\npp$8.parseClassMethod = function(method, isGenerator, isAsync, allowsDirectSuper) {\n  // Check key and flags\n  var key = method.key;\n  if (method.kind === \"constructor\") {\n    if (isGenerator) { this.raise(key.start, \"Constructor can't be a generator\"); }\n    if (isAsync) { this.raise(key.start, \"Constructor can't be an async method\"); }\n  } else if (method.static && checkKeyName(method, \"prototype\")) {\n    this.raise(key.start, \"Classes may not have a static property named prototype\");\n  }\n\n  // Parse value\n  var value = method.value = this.parseMethod(isGenerator, isAsync, allowsDirectSuper);\n\n  // Check value\n  if (method.kind === \"get\" && value.params.length !== 0)\n    { this.raiseRecoverable(value.start, \"getter should have no params\"); }\n  if (method.kind === \"set\" && value.params.length !== 1)\n    { this.raiseRecoverable(value.start, \"setter should have exactly one param\"); }\n  if (method.kind === \"set\" && value.params[0].type === \"RestElement\")\n    { this.raiseRecoverable(value.params[0].start, \"Setter cannot use rest params\"); }\n\n  return this.finishNode(method, \"MethodDefinition\")\n};\n\npp$8.parseClassField = function(field) {\n  if (checkKeyName(field, \"constructor\")) {\n    this.raise(field.key.start, \"Classes can't have a field named 'constructor'\");\n  } else if (field.static && checkKeyName(field, \"prototype\")) {\n    this.raise(field.key.start, \"Classes can't have a static field named 'prototype'\");\n  }\n\n  if (this.eat(types$1.eq)) {\n    // To raise SyntaxError if 'arguments' exists in the initializer.\n    var scope = this.currentThisScope();\n    var inClassFieldInit = scope.inClassFieldInit;\n    scope.inClassFieldInit = true;\n    field.value = this.parseMaybeAssign();\n    scope.inClassFieldInit = inClassFieldInit;\n  } else {\n    field.value = null;\n  }\n  this.semicolon();\n\n  return this.finishNode(field, \"PropertyDefinition\")\n};\n\npp$8.parseClassStaticBlock = function(node) {\n  node.body = [];\n\n  var oldLabels = this.labels;\n  this.labels = [];\n  this.enterScope(SCOPE_CLASS_STATIC_BLOCK | SCOPE_SUPER);\n  while (this.type !== types$1.braceR) {\n    var stmt = this.parseStatement(null);\n    node.body.push(stmt);\n  }\n  this.next();\n  this.exitScope();\n  this.labels = oldLabels;\n\n  return this.finishNode(node, \"StaticBlock\")\n};\n\npp$8.parseClassId = function(node, isStatement) {\n  if (this.type === types$1.name) {\n    node.id = this.parseIdent();\n    if (isStatement)\n      { this.checkLValSimple(node.id, BIND_LEXICAL, false); }\n  } else {\n    if (isStatement === true)\n      { this.unexpected(); }\n    node.id = null;\n  }\n};\n\npp$8.parseClassSuper = function(node) {\n  node.superClass = this.eat(types$1._extends) ? this.parseExprSubscripts(null, false) : null;\n};\n\npp$8.enterClassBody = function() {\n  var element = {declared: Object.create(null), used: []};\n  this.privateNameStack.push(element);\n  return element.declared\n};\n\npp$8.exitClassBody = function() {\n  var ref = this.privateNameStack.pop();\n  var declared = ref.declared;\n  var used = ref.used;\n  if (!this.options.checkPrivateFields) { return }\n  var len = this.privateNameStack.length;\n  var parent = len === 0 ? null : this.privateNameStack[len - 1];\n  for (var i = 0; i < used.length; ++i) {\n    var id = used[i];\n    if (!hasOwn(declared, id.name)) {\n      if (parent) {\n        parent.used.push(id);\n      } else {\n        this.raiseRecoverable(id.start, (\"Private field '#\" + (id.name) + \"' must be declared in an enclosing class\"));\n      }\n    }\n  }\n};\n\nfunction isPrivateNameConflicted(privateNameMap, element) {\n  var name = element.key.name;\n  var curr = privateNameMap[name];\n\n  var next = \"true\";\n  if (element.type === \"MethodDefinition\" && (element.kind === \"get\" || element.kind === \"set\")) {\n    next = (element.static ? \"s\" : \"i\") + element.kind;\n  }\n\n  // `class { get #a(){}; static set #a(_){} }` is also conflict.\n  if (\n    curr === \"iget\" && next === \"iset\" ||\n    curr === \"iset\" && next === \"iget\" ||\n    curr === \"sget\" && next === \"sset\" ||\n    curr === \"sset\" && next === \"sget\"\n  ) {\n    privateNameMap[name] = \"true\";\n    return false\n  } else if (!curr) {\n    privateNameMap[name] = next;\n    return false\n  } else {\n    return true\n  }\n}\n\nfunction checkKeyName(node, name) {\n  var computed = node.computed;\n  var key = node.key;\n  return !computed && (\n    key.type === \"Identifier\" && key.name === name ||\n    key.type === \"Literal\" && key.value === name\n  )\n}\n\n// Parses module export declaration.\n\npp$8.parseExportAllDeclaration = function(node, exports) {\n  if (this.options.ecmaVersion >= 11) {\n    if (this.eatContextual(\"as\")) {\n      node.exported = this.parseModuleExportName();\n      this.checkExport(exports, node.exported, this.lastTokStart);\n    } else {\n      node.exported = null;\n    }\n  }\n  this.expectContextual(\"from\");\n  if (this.type !== types$1.string) { this.unexpected(); }\n  node.source = this.parseExprAtom();\n  this.semicolon();\n  return this.finishNode(node, \"ExportAllDeclaration\")\n};\n\npp$8.parseExport = function(node, exports) {\n  this.next();\n  // export * from '...'\n  if (this.eat(types$1.star)) {\n    return this.parseExportAllDeclaration(node, exports)\n  }\n  if (this.eat(types$1._default)) { // export default ...\n    this.checkExport(exports, \"default\", this.lastTokStart);\n    node.declaration = this.parseExportDefaultDeclaration();\n    return this.finishNode(node, \"ExportDefaultDeclaration\")\n  }\n  // export var|const|let|function|class ...\n  if (this.shouldParseExportStatement()) {\n    node.declaration = this.parseExportDeclaration(node);\n    if (node.declaration.type === \"VariableDeclaration\")\n      { this.checkVariableExport(exports, node.declaration.declarations); }\n    else\n      { this.checkExport(exports, node.declaration.id, node.declaration.id.start); }\n    node.specifiers = [];\n    node.source = null;\n  } else { // export { x, y as z } [from '...']\n    node.declaration = null;\n    node.specifiers = this.parseExportSpecifiers(exports);\n    if (this.eatContextual(\"from\")) {\n      if (this.type !== types$1.string) { this.unexpected(); }\n      node.source = this.parseExprAtom();\n    } else {\n      for (var i = 0, list = node.specifiers; i < list.length; i += 1) {\n        // check for keywords used as local names\n        var spec = list[i];\n\n        this.checkUnreserved(spec.local);\n        // check if export is defined\n        this.checkLocalExport(spec.local);\n\n        if (spec.local.type === \"Literal\") {\n          this.raise(spec.local.start, \"A string literal cannot be used as an exported binding without `from`.\");\n        }\n      }\n\n      node.source = null;\n    }\n    this.semicolon();\n  }\n  return this.finishNode(node, \"ExportNamedDeclaration\")\n};\n\npp$8.parseExportDeclaration = function(node) {\n  return this.parseStatement(null)\n};\n\npp$8.parseExportDefaultDeclaration = function() {\n  var isAsync;\n  if (this.type === types$1._function || (isAsync = this.isAsyncFunction())) {\n    var fNode = this.startNode();\n    this.next();\n    if (isAsync) { this.next(); }\n    return this.parseFunction(fNode, FUNC_STATEMENT | FUNC_NULLABLE_ID, false, isAsync)\n  } else if (this.type === types$1._class) {\n    var cNode = this.startNode();\n    return this.parseClass(cNode, \"nullableID\")\n  } else {\n    var declaration = this.parseMaybeAssign();\n    this.semicolon();\n    return declaration\n  }\n};\n\npp$8.checkExport = function(exports, name, pos) {\n  if (!exports) { return }\n  if (typeof name !== \"string\")\n    { name = name.type === \"Identifier\" ? name.name : name.value; }\n  if (hasOwn(exports, name))\n    { this.raiseRecoverable(pos, \"Duplicate export '\" + name + \"'\"); }\n  exports[name] = true;\n};\n\npp$8.checkPatternExport = function(exports, pat) {\n  var type = pat.type;\n  if (type === \"Identifier\")\n    { this.checkExport(exports, pat, pat.start); }\n  else if (type === \"ObjectPattern\")\n    { for (var i = 0, list = pat.properties; i < list.length; i += 1)\n      {\n        var prop = list[i];\n\n        this.checkPatternExport(exports, prop);\n      } }\n  else if (type === \"ArrayPattern\")\n    { for (var i$1 = 0, list$1 = pat.elements; i$1 < list$1.length; i$1 += 1) {\n      var elt = list$1[i$1];\n\n        if (elt) { this.checkPatternExport(exports, elt); }\n    } }\n  else if (type === \"Property\")\n    { this.checkPatternExport(exports, pat.value); }\n  else if (type === \"AssignmentPattern\")\n    { this.checkPatternExport(exports, pat.left); }\n  else if (type === \"RestElement\")\n    { this.checkPatternExport(exports, pat.argument); }\n  else if (type === \"ParenthesizedExpression\")\n    { this.checkPatternExport(exports, pat.expression); }\n};\n\npp$8.checkVariableExport = function(exports, decls) {\n  if (!exports) { return }\n  for (var i = 0, list = decls; i < list.length; i += 1)\n    {\n    var decl = list[i];\n\n    this.checkPatternExport(exports, decl.id);\n  }\n};\n\npp$8.shouldParseExportStatement = function() {\n  return this.type.keyword === \"var\" ||\n    this.type.keyword === \"const\" ||\n    this.type.keyword === \"class\" ||\n    this.type.keyword === \"function\" ||\n    this.isLet() ||\n    this.isAsyncFunction()\n};\n\n// Parses a comma-separated list of module exports.\n\npp$8.parseExportSpecifier = function(exports) {\n  var node = this.startNode();\n  node.local = this.parseModuleExportName();\n\n  node.exported = this.eatContextual(\"as\") ? this.parseModuleExportName() : node.local;\n  this.checkExport(\n    exports,\n    node.exported,\n    node.exported.start\n  );\n\n  return this.finishNode(node, \"ExportSpecifier\")\n};\n\npp$8.parseExportSpecifiers = function(exports) {\n  var nodes = [], first = true;\n  // export { x, y as z } [from '...']\n  this.expect(types$1.braceL);\n  while (!this.eat(types$1.braceR)) {\n    if (!first) {\n      this.expect(types$1.comma);\n      if (this.afterTrailingComma(types$1.braceR)) { break }\n    } else { first = false; }\n\n    nodes.push(this.parseExportSpecifier(exports));\n  }\n  return nodes\n};\n\n// Parses import declaration.\n\npp$8.parseImport = function(node) {\n  this.next();\n\n  // import '...'\n  if (this.type === types$1.string) {\n    node.specifiers = empty$1;\n    node.source = this.parseExprAtom();\n  } else {\n    node.specifiers = this.parseImportSpecifiers();\n    this.expectContextual(\"from\");\n    node.source = this.type === types$1.string ? this.parseExprAtom() : this.unexpected();\n  }\n  this.semicolon();\n  return this.finishNode(node, \"ImportDeclaration\")\n};\n\n// Parses a comma-separated list of module imports.\n\npp$8.parseImportSpecifier = function() {\n  var node = this.startNode();\n  node.imported = this.parseModuleExportName();\n\n  if (this.eatContextual(\"as\")) {\n    node.local = this.parseIdent();\n  } else {\n    this.checkUnreserved(node.imported);\n    node.local = node.imported;\n  }\n  this.checkLValSimple(node.local, BIND_LEXICAL);\n\n  return this.finishNode(node, \"ImportSpecifier\")\n};\n\npp$8.parseImportDefaultSpecifier = function() {\n  // import defaultObj, { x, y as z } from '...'\n  var node = this.startNode();\n  node.local = this.parseIdent();\n  this.checkLValSimple(node.local, BIND_LEXICAL);\n  return this.finishNode(node, \"ImportDefaultSpecifier\")\n};\n\npp$8.parseImportNamespaceSpecifier = function() {\n  var node = this.startNode();\n  this.next();\n  this.expectContextual(\"as\");\n  node.local = this.parseIdent();\n  this.checkLValSimple(node.local, BIND_LEXICAL);\n  return this.finishNode(node, \"ImportNamespaceSpecifier\")\n};\n\npp$8.parseImportSpecifiers = function() {\n  var nodes = [], first = true;\n  if (this.type === types$1.name) {\n    nodes.push(this.parseImportDefaultSpecifier());\n    if (!this.eat(types$1.comma)) { return nodes }\n  }\n  if (this.type === types$1.star) {\n    nodes.push(this.parseImportNamespaceSpecifier());\n    return nodes\n  }\n  this.expect(types$1.braceL);\n  while (!this.eat(types$1.braceR)) {\n    if (!first) {\n      this.expect(types$1.comma);\n      if (this.afterTrailingComma(types$1.braceR)) { break }\n    } else { first = false; }\n\n    nodes.push(this.parseImportSpecifier());\n  }\n  return nodes\n};\n\npp$8.parseModuleExportName = function() {\n  if (this.options.ecmaVersion >= 13 && this.type === types$1.string) {\n    var stringLiteral = this.parseLiteral(this.value);\n    if (loneSurrogate.test(stringLiteral.value)) {\n      this.raise(stringLiteral.start, \"An export name cannot include a lone surrogate.\");\n    }\n    return stringLiteral\n  }\n  return this.parseIdent(true)\n};\n\n// Set `ExpressionStatement#directive` property for directive prologues.\npp$8.adaptDirectivePrologue = function(statements) {\n  for (var i = 0; i < statements.length && this.isDirectiveCandidate(statements[i]); ++i) {\n    statements[i].directive = statements[i].expression.raw.slice(1, -1);\n  }\n};\npp$8.isDirectiveCandidate = function(statement) {\n  return (\n    this.options.ecmaVersion >= 5 &&\n    statement.type === \"ExpressionStatement\" &&\n    statement.expression.type === \"Literal\" &&\n    typeof statement.expression.value === \"string\" &&\n    // Reject parenthesized strings.\n    (this.input[statement.start] === \"\\\"\" || this.input[statement.start] === \"'\")\n  )\n};\n\nvar pp$7 = Parser.prototype;\n\n// Convert existing expression atom to assignable pattern\n// if possible.\n\npp$7.toAssignable = function(node, isBinding, refDestructuringErrors) {\n  if (this.options.ecmaVersion >= 6 && node) {\n    switch (node.type) {\n    case \"Identifier\":\n      if (this.inAsync && node.name === \"await\")\n        { this.raise(node.start, \"Cannot use 'await' as identifier inside an async function\"); }\n      break\n\n    case \"ObjectPattern\":\n    case \"ArrayPattern\":\n    case \"AssignmentPattern\":\n    case \"RestElement\":\n      break\n\n    case \"ObjectExpression\":\n      node.type = \"ObjectPattern\";\n      if (refDestructuringErrors) { this.checkPatternErrors(refDestructuringErrors, true); }\n      for (var i = 0, list = node.properties; i < list.length; i += 1) {\n        var prop = list[i];\n\n      this.toAssignable(prop, isBinding);\n        // Early error:\n        //   AssignmentRestProperty[Yield, Await] :\n        //     `...` DestructuringAssignmentTarget[Yield, Await]\n        //\n        //   It is a Syntax Error if |DestructuringAssignmentTarget| is an |ArrayLiteral| or an |ObjectLiteral|.\n        if (\n          prop.type === \"RestElement\" &&\n          (prop.argument.type === \"ArrayPattern\" || prop.argument.type === \"ObjectPattern\")\n        ) {\n          this.raise(prop.argument.start, \"Unexpected token\");\n        }\n      }\n      break\n\n    case \"Property\":\n      // AssignmentProperty has type === \"Property\"\n      if (node.kind !== \"init\") { this.raise(node.key.start, \"Object pattern can't contain getter or setter\"); }\n      this.toAssignable(node.value, isBinding);\n      break\n\n    case \"ArrayExpression\":\n      node.type = \"ArrayPattern\";\n      if (refDestructuringErrors) { this.checkPatternErrors(refDestructuringErrors, true); }\n      this.toAssignableList(node.elements, isBinding);\n      break\n\n    case \"SpreadElement\":\n      node.type = \"RestElement\";\n      this.toAssignable(node.argument, isBinding);\n      if (node.argument.type === \"AssignmentPattern\")\n        { this.raise(node.argument.start, \"Rest elements cannot have a default value\"); }\n      break\n\n    case \"AssignmentExpression\":\n      if (node.operator !== \"=\") { this.raise(node.left.end, \"Only '=' operator can be used for specifying default value.\"); }\n      node.type = \"AssignmentPattern\";\n      delete node.operator;\n      this.toAssignable(node.left, isBinding);\n      break\n\n    case \"ParenthesizedExpression\":\n      this.toAssignable(node.expression, isBinding, refDestructuringErrors);\n      break\n\n    case \"ChainExpression\":\n      this.raiseRecoverable(node.start, \"Optional chaining cannot appear in left-hand side\");\n      break\n\n    case \"MemberExpression\":\n      if (!isBinding) { break }\n\n    default:\n      this.raise(node.start, \"Assigning to rvalue\");\n    }\n  } else if (refDestructuringErrors) { this.checkPatternErrors(refDestructuringErrors, true); }\n  return node\n};\n\n// Convert list of expression atoms to binding list.\n\npp$7.toAssignableList = function(exprList, isBinding) {\n  var end = exprList.length;\n  for (var i = 0; i < end; i++) {\n    var elt = exprList[i];\n    if (elt) { this.toAssignable(elt, isBinding); }\n  }\n  if (end) {\n    var last = exprList[end - 1];\n    if (this.options.ecmaVersion === 6 && isBinding && last && last.type === \"RestElement\" && last.argument.type !== \"Identifier\")\n      { this.unexpected(last.argument.start); }\n  }\n  return exprList\n};\n\n// Parses spread element.\n\npp$7.parseSpread = function(refDestructuringErrors) {\n  var node = this.startNode();\n  this.next();\n  node.argument = this.parseMaybeAssign(false, refDestructuringErrors);\n  return this.finishNode(node, \"SpreadElement\")\n};\n\npp$7.parseRestBinding = function() {\n  var node = this.startNode();\n  this.next();\n\n  // RestElement inside of a function parameter must be an identifier\n  if (this.options.ecmaVersion === 6 && this.type !== types$1.name)\n    { this.unexpected(); }\n\n  node.argument = this.parseBindingAtom();\n\n  return this.finishNode(node, \"RestElement\")\n};\n\n// Parses lvalue (assignable) atom.\n\npp$7.parseBindingAtom = function() {\n  if (this.options.ecmaVersion >= 6) {\n    switch (this.type) {\n    case types$1.bracketL:\n      var node = this.startNode();\n      this.next();\n      node.elements = this.parseBindingList(types$1.bracketR, true, true);\n      return this.finishNode(node, \"ArrayPattern\")\n\n    case types$1.braceL:\n      return this.parseObj(true)\n    }\n  }\n  return this.parseIdent()\n};\n\npp$7.parseBindingList = function(close, allowEmpty, allowTrailingComma, allowModifiers) {\n  var elts = [], first = true;\n  while (!this.eat(close)) {\n    if (first) { first = false; }\n    else { this.expect(types$1.comma); }\n    if (allowEmpty && this.type === types$1.comma) {\n      elts.push(null);\n    } else if (allowTrailingComma && this.afterTrailingComma(close)) {\n      break\n    } else if (this.type === types$1.ellipsis) {\n      var rest = this.parseRestBinding();\n      this.parseBindingListItem(rest);\n      elts.push(rest);\n      if (this.type === types$1.comma) { this.raiseRecoverable(this.start, \"Comma is not permitted after the rest element\"); }\n      this.expect(close);\n      break\n    } else {\n      elts.push(this.parseAssignableListItem(allowModifiers));\n    }\n  }\n  return elts\n};\n\npp$7.parseAssignableListItem = function(allowModifiers) {\n  var elem = this.parseMaybeDefault(this.start, this.startLoc);\n  this.parseBindingListItem(elem);\n  return elem\n};\n\npp$7.parseBindingListItem = function(param) {\n  return param\n};\n\n// Parses assignment pattern around given atom if possible.\n\npp$7.parseMaybeDefault = function(startPos, startLoc, left) {\n  left = left || this.parseBindingAtom();\n  if (this.options.ecmaVersion < 6 || !this.eat(types$1.eq)) { return left }\n  var node = this.startNodeAt(startPos, startLoc);\n  node.left = left;\n  node.right = this.parseMaybeAssign();\n  return this.finishNode(node, \"AssignmentPattern\")\n};\n\n// The following three functions all verify that a node is an lvalue —\n// something that can be bound, or assigned to. In order to do so, they perform\n// a variety of checks:\n//\n// - Check that none of the bound/assigned-to identifiers are reserved words.\n// - Record name declarations for bindings in the appropriate scope.\n// - Check duplicate argument names, if checkClashes is set.\n//\n// If a complex binding pattern is encountered (e.g., object and array\n// destructuring), the entire pattern is recursively checked.\n//\n// There are three versions of checkLVal*() appropriate for different\n// circumstances:\n//\n// - checkLValSimple() shall be used if the syntactic construct supports\n//   nothing other than identifiers and member expressions. Parenthesized\n//   expressions are also correctly handled. This is generally appropriate for\n//   constructs for which the spec says\n//\n//   > It is a Syntax Error if AssignmentTargetType of [the production] is not\n//   > simple.\n//\n//   It is also appropriate for checking if an identifier is valid and not\n//   defined elsewhere, like import declarations or function/class identifiers.\n//\n//   Examples where this is used include:\n//     a += …;\n//     import a from '…';\n//   where a is the node to be checked.\n//\n// - checkLValPattern() shall be used if the syntactic construct supports\n//   anything checkLValSimple() supports, as well as object and array\n//   destructuring patterns. This is generally appropriate for constructs for\n//   which the spec says\n//\n//   > It is a Syntax Error if [the production] is neither an ObjectLiteral nor\n//   > an ArrayLiteral and AssignmentTargetType of [the production] is not\n//   > simple.\n//\n//   Examples where this is used include:\n//     (a = …);\n//     const a = …;\n//     try { … } catch (a) { … }\n//   where a is the node to be checked.\n//\n// - checkLValInnerPattern() shall be used if the syntactic construct supports\n//   anything checkLValPattern() supports, as well as default assignment\n//   patterns, rest elements, and other constructs that may appear within an\n//   object or array destructuring pattern.\n//\n//   As a special case, function parameters also use checkLValInnerPattern(),\n//   as they also support defaults and rest constructs.\n//\n// These functions deliberately support both assignment and binding constructs,\n// as the logic for both is exceedingly similar. If the node is the target of\n// an assignment, then bindingType should be set to BIND_NONE. Otherwise, it\n// should be set to the appropriate BIND_* constant, like BIND_VAR or\n// BIND_LEXICAL.\n//\n// If the function is called with a non-BIND_NONE bindingType, then\n// additionally a checkClashes object may be specified to allow checking for\n// duplicate argument names. checkClashes is ignored if the provided construct\n// is an assignment (i.e., bindingType is BIND_NONE).\n\npp$7.checkLValSimple = function(expr, bindingType, checkClashes) {\n  if ( bindingType === void 0 ) bindingType = BIND_NONE;\n\n  var isBind = bindingType !== BIND_NONE;\n\n  switch (expr.type) {\n  case \"Identifier\":\n    if (this.strict && this.reservedWordsStrictBind.test(expr.name))\n      { this.raiseRecoverable(expr.start, (isBind ? \"Binding \" : \"Assigning to \") + expr.name + \" in strict mode\"); }\n    if (isBind) {\n      if (bindingType === BIND_LEXICAL && expr.name === \"let\")\n        { this.raiseRecoverable(expr.start, \"let is disallowed as a lexically bound name\"); }\n      if (checkClashes) {\n        if (hasOwn(checkClashes, expr.name))\n          { this.raiseRecoverable(expr.start, \"Argument name clash\"); }\n        checkClashes[expr.name] = true;\n      }\n      if (bindingType !== BIND_OUTSIDE) { this.declareName(expr.name, bindingType, expr.start); }\n    }\n    break\n\n  case \"ChainExpression\":\n    this.raiseRecoverable(expr.start, \"Optional chaining cannot appear in left-hand side\");\n    break\n\n  case \"MemberExpression\":\n    if (isBind) { this.raiseRecoverable(expr.start, \"Binding member expression\"); }\n    break\n\n  case \"ParenthesizedExpression\":\n    if (isBind) { this.raiseRecoverable(expr.start, \"Binding parenthesized expression\"); }\n    return this.checkLValSimple(expr.expression, bindingType, checkClashes)\n\n  default:\n    this.raise(expr.start, (isBind ? \"Binding\" : \"Assigning to\") + \" rvalue\");\n  }\n};\n\npp$7.checkLValPattern = function(expr, bindingType, checkClashes) {\n  if ( bindingType === void 0 ) bindingType = BIND_NONE;\n\n  switch (expr.type) {\n  case \"ObjectPattern\":\n    for (var i = 0, list = expr.properties; i < list.length; i += 1) {\n      var prop = list[i];\n\n    this.checkLValInnerPattern(prop, bindingType, checkClashes);\n    }\n    break\n\n  case \"ArrayPattern\":\n    for (var i$1 = 0, list$1 = expr.elements; i$1 < list$1.length; i$1 += 1) {\n      var elem = list$1[i$1];\n\n    if (elem) { this.checkLValInnerPattern(elem, bindingType, checkClashes); }\n    }\n    break\n\n  default:\n    this.checkLValSimple(expr, bindingType, checkClashes);\n  }\n};\n\npp$7.checkLValInnerPattern = function(expr, bindingType, checkClashes) {\n  if ( bindingType === void 0 ) bindingType = BIND_NONE;\n\n  switch (expr.type) {\n  case \"Property\":\n    // AssignmentProperty has type === \"Property\"\n    this.checkLValInnerPattern(expr.value, bindingType, checkClashes);\n    break\n\n  case \"AssignmentPattern\":\n    this.checkLValPattern(expr.left, bindingType, checkClashes);\n    break\n\n  case \"RestElement\":\n    this.checkLValPattern(expr.argument, bindingType, checkClashes);\n    break\n\n  default:\n    this.checkLValPattern(expr, bindingType, checkClashes);\n  }\n};\n\n// The algorithm used to determine whether a regexp can appear at a\n// given point in the program is loosely based on sweet.js' approach.\n// See https://github.com/mozilla/sweet.js/wiki/design\n\n\nvar TokContext = function TokContext(token, isExpr, preserveSpace, override, generator) {\n  this.token = token;\n  this.isExpr = !!isExpr;\n  this.preserveSpace = !!preserveSpace;\n  this.override = override;\n  this.generator = !!generator;\n};\n\nvar types = {\n  b_stat: new TokContext(\"{\", false),\n  b_expr: new TokContext(\"{\", true),\n  b_tmpl: new TokContext(\"${\", false),\n  p_stat: new TokContext(\"(\", false),\n  p_expr: new TokContext(\"(\", true),\n  q_tmpl: new TokContext(\"`\", true, true, function (p) { return p.tryReadTemplateToken(); }),\n  f_stat: new TokContext(\"function\", false),\n  f_expr: new TokContext(\"function\", true),\n  f_expr_gen: new TokContext(\"function\", true, false, null, true),\n  f_gen: new TokContext(\"function\", false, false, null, true)\n};\n\nvar pp$6 = Parser.prototype;\n\npp$6.initialContext = function() {\n  return [types.b_stat]\n};\n\npp$6.curContext = function() {\n  return this.context[this.context.length - 1]\n};\n\npp$6.braceIsBlock = function(prevType) {\n  var parent = this.curContext();\n  if (parent === types.f_expr || parent === types.f_stat)\n    { return true }\n  if (prevType === types$1.colon && (parent === types.b_stat || parent === types.b_expr))\n    { return !parent.isExpr }\n\n  // The check for `tt.name && exprAllowed` detects whether we are\n  // after a `yield` or `of` construct. See the `updateContext` for\n  // `tt.name`.\n  if (prevType === types$1._return || prevType === types$1.name && this.exprAllowed)\n    { return lineBreak.test(this.input.slice(this.lastTokEnd, this.start)) }\n  if (prevType === types$1._else || prevType === types$1.semi || prevType === types$1.eof || prevType === types$1.parenR || prevType === types$1.arrow)\n    { return true }\n  if (prevType === types$1.braceL)\n    { return parent === types.b_stat }\n  if (prevType === types$1._var || prevType === types$1._const || prevType === types$1.name)\n    { return false }\n  return !this.exprAllowed\n};\n\npp$6.inGeneratorContext = function() {\n  for (var i = this.context.length - 1; i >= 1; i--) {\n    var context = this.context[i];\n    if (context.token === \"function\")\n      { return context.generator }\n  }\n  return false\n};\n\npp$6.updateContext = function(prevType) {\n  var update, type = this.type;\n  if (type.keyword && prevType === types$1.dot)\n    { this.exprAllowed = false; }\n  else if (update = type.updateContext)\n    { update.call(this, prevType); }\n  else\n    { this.exprAllowed = type.beforeExpr; }\n};\n\n// Used to handle egde cases when token context could not be inferred correctly during tokenization phase\n\npp$6.overrideContext = function(tokenCtx) {\n  if (this.curContext() !== tokenCtx) {\n    this.context[this.context.length - 1] = tokenCtx;\n  }\n};\n\n// Token-specific context update code\n\ntypes$1.parenR.updateContext = types$1.braceR.updateContext = function() {\n  if (this.context.length === 1) {\n    this.exprAllowed = true;\n    return\n  }\n  var out = this.context.pop();\n  if (out === types.b_stat && this.curContext().token === \"function\") {\n    out = this.context.pop();\n  }\n  this.exprAllowed = !out.isExpr;\n};\n\ntypes$1.braceL.updateContext = function(prevType) {\n  this.context.push(this.braceIsBlock(prevType) ? types.b_stat : types.b_expr);\n  this.exprAllowed = true;\n};\n\ntypes$1.dollarBraceL.updateContext = function() {\n  this.context.push(types.b_tmpl);\n  this.exprAllowed = true;\n};\n\ntypes$1.parenL.updateContext = function(prevType) {\n  var statementParens = prevType === types$1._if || prevType === types$1._for || prevType === types$1._with || prevType === types$1._while;\n  this.context.push(statementParens ? types.p_stat : types.p_expr);\n  this.exprAllowed = true;\n};\n\ntypes$1.incDec.updateContext = function() {\n  // tokExprAllowed stays unchanged\n};\n\ntypes$1._function.updateContext = types$1._class.updateContext = function(prevType) {\n  if (prevType.beforeExpr && prevType !== types$1._else &&\n      !(prevType === types$1.semi && this.curContext() !== types.p_stat) &&\n      !(prevType === types$1._return && lineBreak.test(this.input.slice(this.lastTokEnd, this.start))) &&\n      !((prevType === types$1.colon || prevType === types$1.braceL) && this.curContext() === types.b_stat))\n    { this.context.push(types.f_expr); }\n  else\n    { this.context.push(types.f_stat); }\n  this.exprAllowed = false;\n};\n\ntypes$1.backQuote.updateContext = function() {\n  if (this.curContext() === types.q_tmpl)\n    { this.context.pop(); }\n  else\n    { this.context.push(types.q_tmpl); }\n  this.exprAllowed = false;\n};\n\ntypes$1.star.updateContext = function(prevType) {\n  if (prevType === types$1._function) {\n    var index = this.context.length - 1;\n    if (this.context[index] === types.f_expr)\n      { this.context[index] = types.f_expr_gen; }\n    else\n      { this.context[index] = types.f_gen; }\n  }\n  this.exprAllowed = true;\n};\n\ntypes$1.name.updateContext = function(prevType) {\n  var allowed = false;\n  if (this.options.ecmaVersion >= 6 && prevType !== types$1.dot) {\n    if (this.value === \"of\" && !this.exprAllowed ||\n        this.value === \"yield\" && this.inGeneratorContext())\n      { allowed = true; }\n  }\n  this.exprAllowed = allowed;\n};\n\n// A recursive descent parser operates by defining functions for all\n// syntactic elements, and recursively calling those, each function\n// advancing the input stream and returning an AST node. Precedence\n// of constructs (for example, the fact that `!x[1]` means `!(x[1])`\n// instead of `(!x)[1]` is handled by the fact that the parser\n// function that parses unary prefix operators is called first, and\n// in turn calls the function that parses `[]` subscripts — that\n// way, it'll receive the node for `x[1]` already parsed, and wraps\n// *that* in the unary operator node.\n//\n// Acorn uses an [operator precedence parser][opp] to handle binary\n// operator precedence, because it is much more compact than using\n// the technique outlined above, which uses different, nesting\n// functions to specify precedence, for all of the ten binary\n// precedence levels that JavaScript defines.\n//\n// [opp]: http://en.wikipedia.org/wiki/Operator-precedence_parser\n\n\nvar pp$5 = Parser.prototype;\n\n// Check if property name clashes with already added.\n// Object/class getters and setters are not allowed to clash —\n// either with each other or with an init property — and in\n// strict mode, init properties are also not allowed to be repeated.\n\npp$5.checkPropClash = function(prop, propHash, refDestructuringErrors) {\n  if (this.options.ecmaVersion >= 9 && prop.type === \"SpreadElement\")\n    { return }\n  if (this.options.ecmaVersion >= 6 && (prop.computed || prop.method || prop.shorthand))\n    { return }\n  var key = prop.key;\n  var name;\n  switch (key.type) {\n  case \"Identifier\": name = key.name; break\n  case \"Literal\": name = String(key.value); break\n  default: return\n  }\n  var kind = prop.kind;\n  if (this.options.ecmaVersion >= 6) {\n    if (name === \"__proto__\" && kind === \"init\") {\n      if (propHash.proto) {\n        if (refDestructuringErrors) {\n          if (refDestructuringErrors.doubleProto < 0) {\n            refDestructuringErrors.doubleProto = key.start;\n          }\n        } else {\n          this.raiseRecoverable(key.start, \"Redefinition of __proto__ property\");\n        }\n      }\n      propHash.proto = true;\n    }\n    return\n  }\n  name = \"$\" + name;\n  var other = propHash[name];\n  if (other) {\n    var redefinition;\n    if (kind === \"init\") {\n      redefinition = this.strict && other.init || other.get || other.set;\n    } else {\n      redefinition = other.init || other[kind];\n    }\n    if (redefinition)\n      { this.raiseRecoverable(key.start, \"Redefinition of property\"); }\n  } else {\n    other = propHash[name] = {\n      init: false,\n      get: false,\n      set: false\n    };\n  }\n  other[kind] = true;\n};\n\n// ### Expression parsing\n\n// These nest, from the most general expression type at the top to\n// 'atomic', nondivisible expression types at the bottom. Most of\n// the functions will simply let the function(s) below them parse,\n// and, *if* the syntactic construct they handle is present, wrap\n// the AST node that the inner parser gave them in another node.\n\n// Parse a full expression. The optional arguments are used to\n// forbid the `in` operator (in for loops initalization expressions)\n// and provide reference for storing '=' operator inside shorthand\n// property assignment in contexts where both object expression\n// and object pattern might appear (so it's possible to raise\n// delayed syntax error at correct position).\n\npp$5.parseExpression = function(forInit, refDestructuringErrors) {\n  var startPos = this.start, startLoc = this.startLoc;\n  var expr = this.parseMaybeAssign(forInit, refDestructuringErrors);\n  if (this.type === types$1.comma) {\n    var node = this.startNodeAt(startPos, startLoc);\n    node.expressions = [expr];\n    while (this.eat(types$1.comma)) { node.expressions.push(this.parseMaybeAssign(forInit, refDestructuringErrors)); }\n    return this.finishNode(node, \"SequenceExpression\")\n  }\n  return expr\n};\n\n// Parse an assignment expression. This includes applications of\n// operators like `+=`.\n\npp$5.parseMaybeAssign = function(forInit, refDestructuringErrors, afterLeftParse) {\n  if (this.isContextual(\"yield\")) {\n    if (this.inGenerator) { return this.parseYield(forInit) }\n    // The tokenizer will assume an expression is allowed after\n    // `yield`, but this isn't that kind of yield\n    else { this.exprAllowed = false; }\n  }\n\n  var ownDestructuringErrors = false, oldParenAssign = -1, oldTrailingComma = -1, oldDoubleProto = -1;\n  if (refDestructuringErrors) {\n    oldParenAssign = refDestructuringErrors.parenthesizedAssign;\n    oldTrailingComma = refDestructuringErrors.trailingComma;\n    oldDoubleProto = refDestructuringErrors.doubleProto;\n    refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = -1;\n  } else {\n    refDestructuringErrors = new DestructuringErrors;\n    ownDestructuringErrors = true;\n  }\n\n  var startPos = this.start, startLoc = this.startLoc;\n  if (this.type === types$1.parenL || this.type === types$1.name) {\n    this.potentialArrowAt = this.start;\n    this.potentialArrowInForAwait = forInit === \"await\";\n  }\n  var left = this.parseMaybeConditional(forInit, refDestructuringErrors);\n  if (afterLeftParse) { left = afterLeftParse.call(this, left, startPos, startLoc); }\n  if (this.type.isAssign) {\n    var node = this.startNodeAt(startPos, startLoc);\n    node.operator = this.value;\n    if (this.type === types$1.eq)\n      { left = this.toAssignable(left, false, refDestructuringErrors); }\n    if (!ownDestructuringErrors) {\n      refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = refDestructuringErrors.doubleProto = -1;\n    }\n    if (refDestructuringErrors.shorthandAssign >= left.start)\n      { refDestructuringErrors.shorthandAssign = -1; } // reset because shorthand default was used correctly\n    if (this.type === types$1.eq)\n      { this.checkLValPattern(left); }\n    else\n      { this.checkLValSimple(left); }\n    node.left = left;\n    this.next();\n    node.right = this.parseMaybeAssign(forInit);\n    if (oldDoubleProto > -1) { refDestructuringErrors.doubleProto = oldDoubleProto; }\n    return this.finishNode(node, \"AssignmentExpression\")\n  } else {\n    if (ownDestructuringErrors) { this.checkExpressionErrors(refDestructuringErrors, true); }\n  }\n  if (oldParenAssign > -1) { refDestructuringErrors.parenthesizedAssign = oldParenAssign; }\n  if (oldTrailingComma > -1) { refDestructuringErrors.trailingComma = oldTrailingComma; }\n  return left\n};\n\n// Parse a ternary conditional (`?:`) operator.\n\npp$5.parseMaybeConditional = function(forInit, refDestructuringErrors) {\n  var startPos = this.start, startLoc = this.startLoc;\n  var expr = this.parseExprOps(forInit, refDestructuringErrors);\n  if (this.checkExpressionErrors(refDestructuringErrors)) { return expr }\n  if (this.eat(types$1.question)) {\n    var node = this.startNodeAt(startPos, startLoc);\n    node.test = expr;\n    node.consequent = this.parseMaybeAssign();\n    this.expect(types$1.colon);\n    node.alternate = this.parseMaybeAssign(forInit);\n    return this.finishNode(node, \"ConditionalExpression\")\n  }\n  return expr\n};\n\n// Start the precedence parser.\n\npp$5.parseExprOps = function(forInit, refDestructuringErrors) {\n  var startPos = this.start, startLoc = this.startLoc;\n  var expr = this.parseMaybeUnary(refDestructuringErrors, false, false, forInit);\n  if (this.checkExpressionErrors(refDestructuringErrors)) { return expr }\n  return expr.start === startPos && expr.type === \"ArrowFunctionExpression\" ? expr : this.parseExprOp(expr, startPos, startLoc, -1, forInit)\n};\n\n// Parse binary operators with the operator precedence parsing\n// algorithm. `left` is the left-hand side of the operator.\n// `minPrec` provides context that allows the function to stop and\n// defer further parser to one of its callers when it encounters an\n// operator that has a lower precedence than the set it is parsing.\n\npp$5.parseExprOp = function(left, leftStartPos, leftStartLoc, minPrec, forInit) {\n  var prec = this.type.binop;\n  if (prec != null && (!forInit || this.type !== types$1._in)) {\n    if (prec > minPrec) {\n      var logical = this.type === types$1.logicalOR || this.type === types$1.logicalAND;\n      var coalesce = this.type === types$1.coalesce;\n      if (coalesce) {\n        // Handle the precedence of `tt.coalesce` as equal to the range of logical expressions.\n        // In other words, `node.right` shouldn't contain logical expressions in order to check the mixed error.\n        prec = types$1.logicalAND.binop;\n      }\n      var op = this.value;\n      this.next();\n      var startPos = this.start, startLoc = this.startLoc;\n      var right = this.parseExprOp(this.parseMaybeUnary(null, false, false, forInit), startPos, startLoc, prec, forInit);\n      var node = this.buildBinary(leftStartPos, leftStartLoc, left, right, op, logical || coalesce);\n      if ((logical && this.type === types$1.coalesce) || (coalesce && (this.type === types$1.logicalOR || this.type === types$1.logicalAND))) {\n        this.raiseRecoverable(this.start, \"Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses\");\n      }\n      return this.parseExprOp(node, leftStartPos, leftStartLoc, minPrec, forInit)\n    }\n  }\n  return left\n};\n\npp$5.buildBinary = function(startPos, startLoc, left, right, op, logical) {\n  if (right.type === \"PrivateIdentifier\") { this.raise(right.start, \"Private identifier can only be left side of binary expression\"); }\n  var node = this.startNodeAt(startPos, startLoc);\n  node.left = left;\n  node.operator = op;\n  node.right = right;\n  return this.finishNode(node, logical ? \"LogicalExpression\" : \"BinaryExpression\")\n};\n\n// Parse unary operators, both prefix and postfix.\n\npp$5.parseMaybeUnary = function(refDestructuringErrors, sawUnary, incDec, forInit) {\n  var startPos = this.start, startLoc = this.startLoc, expr;\n  if (this.isContextual(\"await\") && this.canAwait) {\n    expr = this.parseAwait(forInit);\n    sawUnary = true;\n  } else if (this.type.prefix) {\n    var node = this.startNode(), update = this.type === types$1.incDec;\n    node.operator = this.value;\n    node.prefix = true;\n    this.next();\n    node.argument = this.parseMaybeUnary(null, true, update, forInit);\n    this.checkExpressionErrors(refDestructuringErrors, true);\n    if (update) { this.checkLValSimple(node.argument); }\n    else if (this.strict && node.operator === \"delete\" &&\n             node.argument.type === \"Identifier\")\n      { this.raiseRecoverable(node.start, \"Deleting local variable in strict mode\"); }\n    else if (node.operator === \"delete\" && isPrivateFieldAccess(node.argument))\n      { this.raiseRecoverable(node.start, \"Private fields can not be deleted\"); }\n    else { sawUnary = true; }\n    expr = this.finishNode(node, update ? \"UpdateExpression\" : \"UnaryExpression\");\n  } else if (!sawUnary && this.type === types$1.privateId) {\n    if ((forInit || this.privateNameStack.length === 0) && this.options.checkPrivateFields) { this.unexpected(); }\n    expr = this.parsePrivateIdent();\n    // only could be private fields in 'in', such as #x in obj\n    if (this.type !== types$1._in) { this.unexpected(); }\n  } else {\n    expr = this.parseExprSubscripts(refDestructuringErrors, forInit);\n    if (this.checkExpressionErrors(refDestructuringErrors)) { return expr }\n    while (this.type.postfix && !this.canInsertSemicolon()) {\n      var node$1 = this.startNodeAt(startPos, startLoc);\n      node$1.operator = this.value;\n      node$1.prefix = false;\n      node$1.argument = expr;\n      this.checkLValSimple(expr);\n      this.next();\n      expr = this.finishNode(node$1, \"UpdateExpression\");\n    }\n  }\n\n  if (!incDec && this.eat(types$1.starstar)) {\n    if (sawUnary)\n      { this.unexpected(this.lastTokStart); }\n    else\n      { return this.buildBinary(startPos, startLoc, expr, this.parseMaybeUnary(null, false, false, forInit), \"**\", false) }\n  } else {\n    return expr\n  }\n};\n\nfunction isPrivateFieldAccess(node) {\n  return (\n    node.type === \"MemberExpression\" && node.property.type === \"PrivateIdentifier\" ||\n    node.type === \"ChainExpression\" && isPrivateFieldAccess(node.expression)\n  )\n}\n\n// Parse call, dot, and `[]`-subscript expressions.\n\npp$5.parseExprSubscripts = function(refDestructuringErrors, forInit) {\n  var startPos = this.start, startLoc = this.startLoc;\n  var expr = this.parseExprAtom(refDestructuringErrors, forInit);\n  if (expr.type === \"ArrowFunctionExpression\" && this.input.slice(this.lastTokStart, this.lastTokEnd) !== \")\")\n    { return expr }\n  var result = this.parseSubscripts(expr, startPos, startLoc, false, forInit);\n  if (refDestructuringErrors && result.type === \"MemberExpression\") {\n    if (refDestructuringErrors.parenthesizedAssign >= result.start) { refDestructuringErrors.parenthesizedAssign = -1; }\n    if (refDestructuringErrors.parenthesizedBind >= result.start) { refDestructuringErrors.parenthesizedBind = -1; }\n    if (refDestructuringErrors.trailingComma >= result.start) { refDestructuringErrors.trailingComma = -1; }\n  }\n  return result\n};\n\npp$5.parseSubscripts = function(base, startPos, startLoc, noCalls, forInit) {\n  var maybeAsyncArrow = this.options.ecmaVersion >= 8 && base.type === \"Identifier\" && base.name === \"async\" &&\n      this.lastTokEnd === base.end && !this.canInsertSemicolon() && base.end - base.start === 5 &&\n      this.potentialArrowAt === base.start;\n  var optionalChained = false;\n\n  while (true) {\n    var element = this.parseSubscript(base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit);\n\n    if (element.optional) { optionalChained = true; }\n    if (element === base || element.type === \"ArrowFunctionExpression\") {\n      if (optionalChained) {\n        var chainNode = this.startNodeAt(startPos, startLoc);\n        chainNode.expression = element;\n        element = this.finishNode(chainNode, \"ChainExpression\");\n      }\n      return element\n    }\n\n    base = element;\n  }\n};\n\npp$5.shouldParseAsyncArrow = function() {\n  return !this.canInsertSemicolon() && this.eat(types$1.arrow)\n};\n\npp$5.parseSubscriptAsyncArrow = function(startPos, startLoc, exprList, forInit) {\n  return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, true, forInit)\n};\n\npp$5.parseSubscript = function(base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit) {\n  var optionalSupported = this.options.ecmaVersion >= 11;\n  var optional = optionalSupported && this.eat(types$1.questionDot);\n  if (noCalls && optional) { this.raise(this.lastTokStart, \"Optional chaining cannot appear in the callee of new expressions\"); }\n\n  var computed = this.eat(types$1.bracketL);\n  if (computed || (optional && this.type !== types$1.parenL && this.type !== types$1.backQuote) || this.eat(types$1.dot)) {\n    var node = this.startNodeAt(startPos, startLoc);\n    node.object = base;\n    if (computed) {\n      node.property = this.parseExpression();\n      this.expect(types$1.bracketR);\n    } else if (this.type === types$1.privateId && base.type !== \"Super\") {\n      node.property = this.parsePrivateIdent();\n    } else {\n      node.property = this.parseIdent(this.options.allowReserved !== \"never\");\n    }\n    node.computed = !!computed;\n    if (optionalSupported) {\n      node.optional = optional;\n    }\n    base = this.finishNode(node, \"MemberExpression\");\n  } else if (!noCalls && this.eat(types$1.parenL)) {\n    var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;\n    this.yieldPos = 0;\n    this.awaitPos = 0;\n    this.awaitIdentPos = 0;\n    var exprList = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false, refDestructuringErrors);\n    if (maybeAsyncArrow && !optional && this.shouldParseAsyncArrow()) {\n      this.checkPatternErrors(refDestructuringErrors, false);\n      this.checkYieldAwaitInDefaultParams();\n      if (this.awaitIdentPos > 0)\n        { this.raise(this.awaitIdentPos, \"Cannot use 'await' as identifier inside an async function\"); }\n      this.yieldPos = oldYieldPos;\n      this.awaitPos = oldAwaitPos;\n      this.awaitIdentPos = oldAwaitIdentPos;\n      return this.parseSubscriptAsyncArrow(startPos, startLoc, exprList, forInit)\n    }\n    this.checkExpressionErrors(refDestructuringErrors, true);\n    this.yieldPos = oldYieldPos || this.yieldPos;\n    this.awaitPos = oldAwaitPos || this.awaitPos;\n    this.awaitIdentPos = oldAwaitIdentPos || this.awaitIdentPos;\n    var node$1 = this.startNodeAt(startPos, startLoc);\n    node$1.callee = base;\n    node$1.arguments = exprList;\n    if (optionalSupported) {\n      node$1.optional = optional;\n    }\n    base = this.finishNode(node$1, \"CallExpression\");\n  } else if (this.type === types$1.backQuote) {\n    if (optional || optionalChained) {\n      this.raise(this.start, \"Optional chaining cannot appear in the tag of tagged template expressions\");\n    }\n    var node$2 = this.startNodeAt(startPos, startLoc);\n    node$2.tag = base;\n    node$2.quasi = this.parseTemplate({isTagged: true});\n    base = this.finishNode(node$2, \"TaggedTemplateExpression\");\n  }\n  return base\n};\n\n// Parse an atomic expression — either a single token that is an\n// expression, an expression started by a keyword like `function` or\n// `new`, or an expression wrapped in punctuation like `()`, `[]`,\n// or `{}`.\n\npp$5.parseExprAtom = function(refDestructuringErrors, forInit, forNew) {\n  // If a division operator appears in an expression position, the\n  // tokenizer got confused, and we force it to read a regexp instead.\n  if (this.type === types$1.slash) { this.readRegexp(); }\n\n  var node, canBeArrow = this.potentialArrowAt === this.start;\n  switch (this.type) {\n  case types$1._super:\n    if (!this.allowSuper)\n      { this.raise(this.start, \"'super' keyword outside a method\"); }\n    node = this.startNode();\n    this.next();\n    if (this.type === types$1.parenL && !this.allowDirectSuper)\n      { this.raise(node.start, \"super() call outside constructor of a subclass\"); }\n    // The `super` keyword can appear at below:\n    // SuperProperty:\n    //     super [ Expression ]\n    //     super . IdentifierName\n    // SuperCall:\n    //     super ( Arguments )\n    if (this.type !== types$1.dot && this.type !== types$1.bracketL && this.type !== types$1.parenL)\n      { this.unexpected(); }\n    return this.finishNode(node, \"Super\")\n\n  case types$1._this:\n    node = this.startNode();\n    this.next();\n    return this.finishNode(node, \"ThisExpression\")\n\n  case types$1.name:\n    var startPos = this.start, startLoc = this.startLoc, containsEsc = this.containsEsc;\n    var id = this.parseIdent(false);\n    if (this.options.ecmaVersion >= 8 && !containsEsc && id.name === \"async\" && !this.canInsertSemicolon() && this.eat(types$1._function)) {\n      this.overrideContext(types.f_expr);\n      return this.parseFunction(this.startNodeAt(startPos, startLoc), 0, false, true, forInit)\n    }\n    if (canBeArrow && !this.canInsertSemicolon()) {\n      if (this.eat(types$1.arrow))\n        { return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], false, forInit) }\n      if (this.options.ecmaVersion >= 8 && id.name === \"async\" && this.type === types$1.name && !containsEsc &&\n          (!this.potentialArrowInForAwait || this.value !== \"of\" || this.containsEsc)) {\n        id = this.parseIdent(false);\n        if (this.canInsertSemicolon() || !this.eat(types$1.arrow))\n          { this.unexpected(); }\n        return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], true, forInit)\n      }\n    }\n    return id\n\n  case types$1.regexp:\n    var value = this.value;\n    node = this.parseLiteral(value.value);\n    node.regex = {pattern: value.pattern, flags: value.flags};\n    return node\n\n  case types$1.num: case types$1.string:\n    return this.parseLiteral(this.value)\n\n  case types$1._null: case types$1._true: case types$1._false:\n    node = this.startNode();\n    node.value = this.type === types$1._null ? null : this.type === types$1._true;\n    node.raw = this.type.keyword;\n    this.next();\n    return this.finishNode(node, \"Literal\")\n\n  case types$1.parenL:\n    var start = this.start, expr = this.parseParenAndDistinguishExpression(canBeArrow, forInit);\n    if (refDestructuringErrors) {\n      if (refDestructuringErrors.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(expr))\n        { refDestructuringErrors.parenthesizedAssign = start; }\n      if (refDestructuringErrors.parenthesizedBind < 0)\n        { refDestructuringErrors.parenthesizedBind = start; }\n    }\n    return expr\n\n  case types$1.bracketL:\n    node = this.startNode();\n    this.next();\n    node.elements = this.parseExprList(types$1.bracketR, true, true, refDestructuringErrors);\n    return this.finishNode(node, \"ArrayExpression\")\n\n  case types$1.braceL:\n    this.overrideContext(types.b_expr);\n    return this.parseObj(false, refDestructuringErrors)\n\n  case types$1._function:\n    node = this.startNode();\n    this.next();\n    return this.parseFunction(node, 0)\n\n  case types$1._class:\n    return this.parseClass(this.startNode(), false)\n\n  case types$1._new:\n    return this.parseNew()\n\n  case types$1.backQuote:\n    return this.parseTemplate()\n\n  case types$1._import:\n    if (this.options.ecmaVersion >= 11) {\n      return this.parseExprImport(forNew)\n    } else {\n      return this.unexpected()\n    }\n\n  default:\n    return this.parseExprAtomDefault()\n  }\n};\n\npp$5.parseExprAtomDefault = function() {\n  this.unexpected();\n};\n\npp$5.parseExprImport = function(forNew) {\n  var node = this.startNode();\n\n  // Consume `import` as an identifier for `import.meta`.\n  // Because `this.parseIdent(true)` doesn't check escape sequences, it needs the check of `this.containsEsc`.\n  if (this.containsEsc) { this.raiseRecoverable(this.start, \"Escape sequence in keyword import\"); }\n  var meta = this.parseIdent(true);\n\n  if (this.type === types$1.parenL && !forNew) {\n    return this.parseDynamicImport(node)\n  } else if (this.type === types$1.dot) {\n    node.meta = meta;\n    return this.parseImportMeta(node)\n  } else {\n    this.unexpected();\n  }\n};\n\npp$5.parseDynamicImport = function(node) {\n  this.next(); // skip `(`\n\n  // Parse node.source.\n  node.source = this.parseMaybeAssign();\n\n  // Verify ending.\n  if (!this.eat(types$1.parenR)) {\n    var errorPos = this.start;\n    if (this.eat(types$1.comma) && this.eat(types$1.parenR)) {\n      this.raiseRecoverable(errorPos, \"Trailing comma is not allowed in import()\");\n    } else {\n      this.unexpected(errorPos);\n    }\n  }\n\n  return this.finishNode(node, \"ImportExpression\")\n};\n\npp$5.parseImportMeta = function(node) {\n  this.next(); // skip `.`\n\n  var containsEsc = this.containsEsc;\n  node.property = this.parseIdent(true);\n\n  if (node.property.name !== \"meta\")\n    { this.raiseRecoverable(node.property.start, \"The only valid meta property for import is 'import.meta'\"); }\n  if (containsEsc)\n    { this.raiseRecoverable(node.start, \"'import.meta' must not contain escaped characters\"); }\n  if (this.options.sourceType !== \"module\" && !this.options.allowImportExportEverywhere)\n    { this.raiseRecoverable(node.start, \"Cannot use 'import.meta' outside a module\"); }\n\n  return this.finishNode(node, \"MetaProperty\")\n};\n\npp$5.parseLiteral = function(value) {\n  var node = this.startNode();\n  node.value = value;\n  node.raw = this.input.slice(this.start, this.end);\n  if (node.raw.charCodeAt(node.raw.length - 1) === 110) { node.bigint = node.raw.slice(0, -1).replace(/_/g, \"\"); }\n  this.next();\n  return this.finishNode(node, \"Literal\")\n};\n\npp$5.parseParenExpression = function() {\n  this.expect(types$1.parenL);\n  var val = this.parseExpression();\n  this.expect(types$1.parenR);\n  return val\n};\n\npp$5.shouldParseArrow = function(exprList) {\n  return !this.canInsertSemicolon()\n};\n\npp$5.parseParenAndDistinguishExpression = function(canBeArrow, forInit) {\n  var startPos = this.start, startLoc = this.startLoc, val, allowTrailingComma = this.options.ecmaVersion >= 8;\n  if (this.options.ecmaVersion >= 6) {\n    this.next();\n\n    var innerStartPos = this.start, innerStartLoc = this.startLoc;\n    var exprList = [], first = true, lastIsComma = false;\n    var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, spreadStart;\n    this.yieldPos = 0;\n    this.awaitPos = 0;\n    // Do not save awaitIdentPos to allow checking awaits nested in parameters\n    while (this.type !== types$1.parenR) {\n      first ? first = false : this.expect(types$1.comma);\n      if (allowTrailingComma && this.afterTrailingComma(types$1.parenR, true)) {\n        lastIsComma = true;\n        break\n      } else if (this.type === types$1.ellipsis) {\n        spreadStart = this.start;\n        exprList.push(this.parseParenItem(this.parseRestBinding()));\n        if (this.type === types$1.comma) {\n          this.raiseRecoverable(\n            this.start,\n            \"Comma is not permitted after the rest element\"\n          );\n        }\n        break\n      } else {\n        exprList.push(this.parseMaybeAssign(false, refDestructuringErrors, this.parseParenItem));\n      }\n    }\n    var innerEndPos = this.lastTokEnd, innerEndLoc = this.lastTokEndLoc;\n    this.expect(types$1.parenR);\n\n    if (canBeArrow && this.shouldParseArrow(exprList) && this.eat(types$1.arrow)) {\n      this.checkPatternErrors(refDestructuringErrors, false);\n      this.checkYieldAwaitInDefaultParams();\n      this.yieldPos = oldYieldPos;\n      this.awaitPos = oldAwaitPos;\n      return this.parseParenArrowList(startPos, startLoc, exprList, forInit)\n    }\n\n    if (!exprList.length || lastIsComma) { this.unexpected(this.lastTokStart); }\n    if (spreadStart) { this.unexpected(spreadStart); }\n    this.checkExpressionErrors(refDestructuringErrors, true);\n    this.yieldPos = oldYieldPos || this.yieldPos;\n    this.awaitPos = oldAwaitPos || this.awaitPos;\n\n    if (exprList.length > 1) {\n      val = this.startNodeAt(innerStartPos, innerStartLoc);\n      val.expressions = exprList;\n      this.finishNodeAt(val, \"SequenceExpression\", innerEndPos, innerEndLoc);\n    } else {\n      val = exprList[0];\n    }\n  } else {\n    val = this.parseParenExpression();\n  }\n\n  if (this.options.preserveParens) {\n    var par = this.startNodeAt(startPos, startLoc);\n    par.expression = val;\n    return this.finishNode(par, \"ParenthesizedExpression\")\n  } else {\n    return val\n  }\n};\n\npp$5.parseParenItem = function(item) {\n  return item\n};\n\npp$5.parseParenArrowList = function(startPos, startLoc, exprList, forInit) {\n  return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, false, forInit)\n};\n\n// New's precedence is slightly tricky. It must allow its argument to\n// be a `[]` or dot subscript expression, but not a call — at least,\n// not without wrapping it in parentheses. Thus, it uses the noCalls\n// argument to parseSubscripts to prevent it from consuming the\n// argument list.\n\nvar empty = [];\n\npp$5.parseNew = function() {\n  if (this.containsEsc) { this.raiseRecoverable(this.start, \"Escape sequence in keyword new\"); }\n  var node = this.startNode();\n  var meta = this.parseIdent(true);\n  if (this.options.ecmaVersion >= 6 && this.eat(types$1.dot)) {\n    node.meta = meta;\n    var containsEsc = this.containsEsc;\n    node.property = this.parseIdent(true);\n    if (node.property.name !== \"target\")\n      { this.raiseRecoverable(node.property.start, \"The only valid meta property for new is 'new.target'\"); }\n    if (containsEsc)\n      { this.raiseRecoverable(node.start, \"'new.target' must not contain escaped characters\"); }\n    if (!this.allowNewDotTarget)\n      { this.raiseRecoverable(node.start, \"'new.target' can only be used in functions and class static block\"); }\n    return this.finishNode(node, \"MetaProperty\")\n  }\n  var startPos = this.start, startLoc = this.startLoc;\n  node.callee = this.parseSubscripts(this.parseExprAtom(null, false, true), startPos, startLoc, true, false);\n  if (this.eat(types$1.parenL)) { node.arguments = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false); }\n  else { node.arguments = empty; }\n  return this.finishNode(node, \"NewExpression\")\n};\n\n// Parse template expression.\n\npp$5.parseTemplateElement = function(ref) {\n  var isTagged = ref.isTagged;\n\n  var elem = this.startNode();\n  if (this.type === types$1.invalidTemplate) {\n    if (!isTagged) {\n      this.raiseRecoverable(this.start, \"Bad escape sequence in untagged template literal\");\n    }\n    elem.value = {\n      raw: this.value,\n      cooked: null\n    };\n  } else {\n    elem.value = {\n      raw: this.input.slice(this.start, this.end).replace(/\\r\\n?/g, \"\\n\"),\n      cooked: this.value\n    };\n  }\n  this.next();\n  elem.tail = this.type === types$1.backQuote;\n  return this.finishNode(elem, \"TemplateElement\")\n};\n\npp$5.parseTemplate = function(ref) {\n  if ( ref === void 0 ) ref = {};\n  var isTagged = ref.isTagged; if ( isTagged === void 0 ) isTagged = false;\n\n  var node = this.startNode();\n  this.next();\n  node.expressions = [];\n  var curElt = this.parseTemplateElement({isTagged: isTagged});\n  node.quasis = [curElt];\n  while (!curElt.tail) {\n    if (this.type === types$1.eof) { this.raise(this.pos, \"Unterminated template literal\"); }\n    this.expect(types$1.dollarBraceL);\n    node.expressions.push(this.parseExpression());\n    this.expect(types$1.braceR);\n    node.quasis.push(curElt = this.parseTemplateElement({isTagged: isTagged}));\n  }\n  this.next();\n  return this.finishNode(node, \"TemplateLiteral\")\n};\n\npp$5.isAsyncProp = function(prop) {\n  return !prop.computed && prop.key.type === \"Identifier\" && prop.key.name === \"async\" &&\n    (this.type === types$1.name || this.type === types$1.num || this.type === types$1.string || this.type === types$1.bracketL || this.type.keyword || (this.options.ecmaVersion >= 9 && this.type === types$1.star)) &&\n    !lineBreak.test(this.input.slice(this.lastTokEnd, this.start))\n};\n\n// Parse an object literal or binding pattern.\n\npp$5.parseObj = function(isPattern, refDestructuringErrors) {\n  var node = this.startNode(), first = true, propHash = {};\n  node.properties = [];\n  this.next();\n  while (!this.eat(types$1.braceR)) {\n    if (!first) {\n      this.expect(types$1.comma);\n      if (this.options.ecmaVersion >= 5 && this.afterTrailingComma(types$1.braceR)) { break }\n    } else { first = false; }\n\n    var prop = this.parseProperty(isPattern, refDestructuringErrors);\n    if (!isPattern) { this.checkPropClash(prop, propHash, refDestructuringErrors); }\n    node.properties.push(prop);\n  }\n  return this.finishNode(node, isPattern ? \"ObjectPattern\" : \"ObjectExpression\")\n};\n\npp$5.parseProperty = function(isPattern, refDestructuringErrors) {\n  var prop = this.startNode(), isGenerator, isAsync, startPos, startLoc;\n  if (this.options.ecmaVersion >= 9 && this.eat(types$1.ellipsis)) {\n    if (isPattern) {\n      prop.argument = this.parseIdent(false);\n      if (this.type === types$1.comma) {\n        this.raiseRecoverable(this.start, \"Comma is not permitted after the rest element\");\n      }\n      return this.finishNode(prop, \"RestElement\")\n    }\n    // Parse argument.\n    prop.argument = this.parseMaybeAssign(false, refDestructuringErrors);\n    // To disallow trailing comma via `this.toAssignable()`.\n    if (this.type === types$1.comma && refDestructuringErrors && refDestructuringErrors.trailingComma < 0) {\n      refDestructuringErrors.trailingComma = this.start;\n    }\n    // Finish\n    return this.finishNode(prop, \"SpreadElement\")\n  }\n  if (this.options.ecmaVersion >= 6) {\n    prop.method = false;\n    prop.shorthand = false;\n    if (isPattern || refDestructuringErrors) {\n      startPos = this.start;\n      startLoc = this.startLoc;\n    }\n    if (!isPattern)\n      { isGenerator = this.eat(types$1.star); }\n  }\n  var containsEsc = this.containsEsc;\n  this.parsePropertyName(prop);\n  if (!isPattern && !containsEsc && this.options.ecmaVersion >= 8 && !isGenerator && this.isAsyncProp(prop)) {\n    isAsync = true;\n    isGenerator = this.options.ecmaVersion >= 9 && this.eat(types$1.star);\n    this.parsePropertyName(prop);\n  } else {\n    isAsync = false;\n  }\n  this.parsePropertyValue(prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc);\n  return this.finishNode(prop, \"Property\")\n};\n\npp$5.parseGetterSetter = function(prop) {\n  prop.kind = prop.key.name;\n  this.parsePropertyName(prop);\n  prop.value = this.parseMethod(false);\n  var paramCount = prop.kind === \"get\" ? 0 : 1;\n  if (prop.value.params.length !== paramCount) {\n    var start = prop.value.start;\n    if (prop.kind === \"get\")\n      { this.raiseRecoverable(start, \"getter should have no params\"); }\n    else\n      { this.raiseRecoverable(start, \"setter should have exactly one param\"); }\n  } else {\n    if (prop.kind === \"set\" && prop.value.params[0].type === \"RestElement\")\n      { this.raiseRecoverable(prop.value.params[0].start, \"Setter cannot use rest params\"); }\n  }\n};\n\npp$5.parsePropertyValue = function(prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc) {\n  if ((isGenerator || isAsync) && this.type === types$1.colon)\n    { this.unexpected(); }\n\n  if (this.eat(types$1.colon)) {\n    prop.value = isPattern ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(false, refDestructuringErrors);\n    prop.kind = \"init\";\n  } else if (this.options.ecmaVersion >= 6 && this.type === types$1.parenL) {\n    if (isPattern) { this.unexpected(); }\n    prop.kind = \"init\";\n    prop.method = true;\n    prop.value = this.parseMethod(isGenerator, isAsync);\n  } else if (!isPattern && !containsEsc &&\n             this.options.ecmaVersion >= 5 && !prop.computed && prop.key.type === \"Identifier\" &&\n             (prop.key.name === \"get\" || prop.key.name === \"set\") &&\n             (this.type !== types$1.comma && this.type !== types$1.braceR && this.type !== types$1.eq)) {\n    if (isGenerator || isAsync) { this.unexpected(); }\n    this.parseGetterSetter(prop);\n  } else if (this.options.ecmaVersion >= 6 && !prop.computed && prop.key.type === \"Identifier\") {\n    if (isGenerator || isAsync) { this.unexpected(); }\n    this.checkUnreserved(prop.key);\n    if (prop.key.name === \"await\" && !this.awaitIdentPos)\n      { this.awaitIdentPos = startPos; }\n    prop.kind = \"init\";\n    if (isPattern) {\n      prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));\n    } else if (this.type === types$1.eq && refDestructuringErrors) {\n      if (refDestructuringErrors.shorthandAssign < 0)\n        { refDestructuringErrors.shorthandAssign = this.start; }\n      prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));\n    } else {\n      prop.value = this.copyNode(prop.key);\n    }\n    prop.shorthand = true;\n  } else { this.unexpected(); }\n};\n\npp$5.parsePropertyName = function(prop) {\n  if (this.options.ecmaVersion >= 6) {\n    if (this.eat(types$1.bracketL)) {\n      prop.computed = true;\n      prop.key = this.parseMaybeAssign();\n      this.expect(types$1.bracketR);\n      return prop.key\n    } else {\n      prop.computed = false;\n    }\n  }\n  return prop.key = this.type === types$1.num || this.type === types$1.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== \"never\")\n};\n\n// Initialize empty function node.\n\npp$5.initFunction = function(node) {\n  node.id = null;\n  if (this.options.ecmaVersion >= 6) { node.generator = node.expression = false; }\n  if (this.options.ecmaVersion >= 8) { node.async = false; }\n};\n\n// Parse object or class method.\n\npp$5.parseMethod = function(isGenerator, isAsync, allowDirectSuper) {\n  var node = this.startNode(), oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;\n\n  this.initFunction(node);\n  if (this.options.ecmaVersion >= 6)\n    { node.generator = isGenerator; }\n  if (this.options.ecmaVersion >= 8)\n    { node.async = !!isAsync; }\n\n  this.yieldPos = 0;\n  this.awaitPos = 0;\n  this.awaitIdentPos = 0;\n  this.enterScope(functionFlags(isAsync, node.generator) | SCOPE_SUPER | (allowDirectSuper ? SCOPE_DIRECT_SUPER : 0));\n\n  this.expect(types$1.parenL);\n  node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);\n  this.checkYieldAwaitInDefaultParams();\n  this.parseFunctionBody(node, false, true, false);\n\n  this.yieldPos = oldYieldPos;\n  this.awaitPos = oldAwaitPos;\n  this.awaitIdentPos = oldAwaitIdentPos;\n  return this.finishNode(node, \"FunctionExpression\")\n};\n\n// Parse arrow function expression with given parameters.\n\npp$5.parseArrowExpression = function(node, params, isAsync, forInit) {\n  var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;\n\n  this.enterScope(functionFlags(isAsync, false) | SCOPE_ARROW);\n  this.initFunction(node);\n  if (this.options.ecmaVersion >= 8) { node.async = !!isAsync; }\n\n  this.yieldPos = 0;\n  this.awaitPos = 0;\n  this.awaitIdentPos = 0;\n\n  node.params = this.toAssignableList(params, true);\n  this.parseFunctionBody(node, true, false, forInit);\n\n  this.yieldPos = oldYieldPos;\n  this.awaitPos = oldAwaitPos;\n  this.awaitIdentPos = oldAwaitIdentPos;\n  return this.finishNode(node, \"ArrowFunctionExpression\")\n};\n\n// Parse function body and check parameters.\n\npp$5.parseFunctionBody = function(node, isArrowFunction, isMethod, forInit) {\n  var isExpression = isArrowFunction && this.type !== types$1.braceL;\n  var oldStrict = this.strict, useStrict = false;\n\n  if (isExpression) {\n    node.body = this.parseMaybeAssign(forInit);\n    node.expression = true;\n    this.checkParams(node, false);\n  } else {\n    var nonSimple = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(node.params);\n    if (!oldStrict || nonSimple) {\n      useStrict = this.strictDirective(this.end);\n      // If this is a strict mode function, verify that argument names\n      // are not repeated, and it does not try to bind the words `eval`\n      // or `arguments`.\n      if (useStrict && nonSimple)\n        { this.raiseRecoverable(node.start, \"Illegal 'use strict' directive in function with non-simple parameter list\"); }\n    }\n    // Start a new scope with regard to labels and the `inFunction`\n    // flag (restore them to their old value afterwards).\n    var oldLabels = this.labels;\n    this.labels = [];\n    if (useStrict) { this.strict = true; }\n\n    // Add the params to varDeclaredNames to ensure that an error is thrown\n    // if a let/const declaration in the function clashes with one of the params.\n    this.checkParams(node, !oldStrict && !useStrict && !isArrowFunction && !isMethod && this.isSimpleParamList(node.params));\n    // Ensure the function name isn't a forbidden identifier in strict mode, e.g. 'eval'\n    if (this.strict && node.id) { this.checkLValSimple(node.id, BIND_OUTSIDE); }\n    node.body = this.parseBlock(false, undefined, useStrict && !oldStrict);\n    node.expression = false;\n    this.adaptDirectivePrologue(node.body.body);\n    this.labels = oldLabels;\n  }\n  this.exitScope();\n};\n\npp$5.isSimpleParamList = function(params) {\n  for (var i = 0, list = params; i < list.length; i += 1)\n    {\n    var param = list[i];\n\n    if (param.type !== \"Identifier\") { return false\n  } }\n  return true\n};\n\n// Checks function params for various disallowed patterns such as using \"eval\"\n// or \"arguments\" and duplicate parameters.\n\npp$5.checkParams = function(node, allowDuplicates) {\n  var nameHash = Object.create(null);\n  for (var i = 0, list = node.params; i < list.length; i += 1)\n    {\n    var param = list[i];\n\n    this.checkLValInnerPattern(param, BIND_VAR, allowDuplicates ? null : nameHash);\n  }\n};\n\n// Parses a comma-separated list of expressions, and returns them as\n// an array. `close` is the token type that ends the list, and\n// `allowEmpty` can be turned on to allow subsequent commas with\n// nothing in between them to be parsed as `null` (which is needed\n// for array literals).\n\npp$5.parseExprList = function(close, allowTrailingComma, allowEmpty, refDestructuringErrors) {\n  var elts = [], first = true;\n  while (!this.eat(close)) {\n    if (!first) {\n      this.expect(types$1.comma);\n      if (allowTrailingComma && this.afterTrailingComma(close)) { break }\n    } else { first = false; }\n\n    var elt = (void 0);\n    if (allowEmpty && this.type === types$1.comma)\n      { elt = null; }\n    else if (this.type === types$1.ellipsis) {\n      elt = this.parseSpread(refDestructuringErrors);\n      if (refDestructuringErrors && this.type === types$1.comma && refDestructuringErrors.trailingComma < 0)\n        { refDestructuringErrors.trailingComma = this.start; }\n    } else {\n      elt = this.parseMaybeAssign(false, refDestructuringErrors);\n    }\n    elts.push(elt);\n  }\n  return elts\n};\n\npp$5.checkUnreserved = function(ref) {\n  var start = ref.start;\n  var end = ref.end;\n  var name = ref.name;\n\n  if (this.inGenerator && name === \"yield\")\n    { this.raiseRecoverable(start, \"Cannot use 'yield' as identifier inside a generator\"); }\n  if (this.inAsync && name === \"await\")\n    { this.raiseRecoverable(start, \"Cannot use 'await' as identifier inside an async function\"); }\n  if (this.currentThisScope().inClassFieldInit && name === \"arguments\")\n    { this.raiseRecoverable(start, \"Cannot use 'arguments' in class field initializer\"); }\n  if (this.inClassStaticBlock && (name === \"arguments\" || name === \"await\"))\n    { this.raise(start, (\"Cannot use \" + name + \" in class static initialization block\")); }\n  if (this.keywords.test(name))\n    { this.raise(start, (\"Unexpected keyword '\" + name + \"'\")); }\n  if (this.options.ecmaVersion < 6 &&\n    this.input.slice(start, end).indexOf(\"\\\\\") !== -1) { return }\n  var re = this.strict ? this.reservedWordsStrict : this.reservedWords;\n  if (re.test(name)) {\n    if (!this.inAsync && name === \"await\")\n      { this.raiseRecoverable(start, \"Cannot use keyword 'await' outside an async function\"); }\n    this.raiseRecoverable(start, (\"The keyword '\" + name + \"' is reserved\"));\n  }\n};\n\n// Parse the next token as an identifier. If `liberal` is true (used\n// when parsing properties), it will also convert keywords into\n// identifiers.\n\npp$5.parseIdent = function(liberal) {\n  var node = this.parseIdentNode();\n  this.next(!!liberal);\n  this.finishNode(node, \"Identifier\");\n  if (!liberal) {\n    this.checkUnreserved(node);\n    if (node.name === \"await\" && !this.awaitIdentPos)\n      { this.awaitIdentPos = node.start; }\n  }\n  return node\n};\n\npp$5.parseIdentNode = function() {\n  var node = this.startNode();\n  if (this.type === types$1.name) {\n    node.name = this.value;\n  } else if (this.type.keyword) {\n    node.name = this.type.keyword;\n\n    // To fix https://github.com/acornjs/acorn/issues/575\n    // `class` and `function` keywords push new context into this.context.\n    // But there is no chance to pop the context if the keyword is consumed as an identifier such as a property name.\n    // If the previous token is a dot, this does not apply because the context-managing code already ignored the keyword\n    if ((node.name === \"class\" || node.name === \"function\") &&\n      (this.lastTokEnd !== this.lastTokStart + 1 || this.input.charCodeAt(this.lastTokStart) !== 46)) {\n      this.context.pop();\n    }\n  } else {\n    this.unexpected();\n  }\n  return node\n};\n\npp$5.parsePrivateIdent = function() {\n  var node = this.startNode();\n  if (this.type === types$1.privateId) {\n    node.name = this.value;\n  } else {\n    this.unexpected();\n  }\n  this.next();\n  this.finishNode(node, \"PrivateIdentifier\");\n\n  // For validating existence\n  if (this.options.checkPrivateFields) {\n    if (this.privateNameStack.length === 0) {\n      this.raise(node.start, (\"Private field '#\" + (node.name) + \"' must be declared in an enclosing class\"));\n    } else {\n      this.privateNameStack[this.privateNameStack.length - 1].used.push(node);\n    }\n  }\n\n  return node\n};\n\n// Parses yield expression inside generator.\n\npp$5.parseYield = function(forInit) {\n  if (!this.yieldPos) { this.yieldPos = this.start; }\n\n  var node = this.startNode();\n  this.next();\n  if (this.type === types$1.semi || this.canInsertSemicolon() || (this.type !== types$1.star && !this.type.startsExpr)) {\n    node.delegate = false;\n    node.argument = null;\n  } else {\n    node.delegate = this.eat(types$1.star);\n    node.argument = this.parseMaybeAssign(forInit);\n  }\n  return this.finishNode(node, \"YieldExpression\")\n};\n\npp$5.parseAwait = function(forInit) {\n  if (!this.awaitPos) { this.awaitPos = this.start; }\n\n  var node = this.startNode();\n  this.next();\n  node.argument = this.parseMaybeUnary(null, true, false, forInit);\n  return this.finishNode(node, \"AwaitExpression\")\n};\n\nvar pp$4 = Parser.prototype;\n\n// This function is used to raise exceptions on parse errors. It\n// takes an offset integer (into the current `input`) to indicate\n// the location of the error, attaches the position to the end\n// of the error message, and then raises a `SyntaxError` with that\n// message.\n\npp$4.raise = function(pos, message) {\n  var loc = getLineInfo(this.input, pos);\n  message += \" (\" + loc.line + \":\" + loc.column + \")\";\n  var err = new SyntaxError(message);\n  err.pos = pos; err.loc = loc; err.raisedAt = this.pos;\n  throw err\n};\n\npp$4.raiseRecoverable = pp$4.raise;\n\npp$4.curPosition = function() {\n  if (this.options.locations) {\n    return new Position(this.curLine, this.pos - this.lineStart)\n  }\n};\n\nvar pp$3 = Parser.prototype;\n\nvar Scope = function Scope(flags) {\n  this.flags = flags;\n  // A list of var-declared names in the current lexical scope\n  this.var = [];\n  // A list of lexically-declared names in the current lexical scope\n  this.lexical = [];\n  // A list of lexically-declared FunctionDeclaration names in the current lexical scope\n  this.functions = [];\n  // A switch to disallow the identifier reference 'arguments'\n  this.inClassFieldInit = false;\n};\n\n// The functions in this module keep track of declared variables in the current scope in order to detect duplicate variable names.\n\npp$3.enterScope = function(flags) {\n  this.scopeStack.push(new Scope(flags));\n};\n\npp$3.exitScope = function() {\n  this.scopeStack.pop();\n};\n\n// The spec says:\n// > At the top level of a function, or script, function declarations are\n// > treated like var declarations rather than like lexical declarations.\npp$3.treatFunctionsAsVarInScope = function(scope) {\n  return (scope.flags & SCOPE_FUNCTION) || !this.inModule && (scope.flags & SCOPE_TOP)\n};\n\npp$3.declareName = function(name, bindingType, pos) {\n  var redeclared = false;\n  if (bindingType === BIND_LEXICAL) {\n    var scope = this.currentScope();\n    redeclared = scope.lexical.indexOf(name) > -1 || scope.functions.indexOf(name) > -1 || scope.var.indexOf(name) > -1;\n    scope.lexical.push(name);\n    if (this.inModule && (scope.flags & SCOPE_TOP))\n      { delete this.undefinedExports[name]; }\n  } else if (bindingType === BIND_SIMPLE_CATCH) {\n    var scope$1 = this.currentScope();\n    scope$1.lexical.push(name);\n  } else if (bindingType === BIND_FUNCTION) {\n    var scope$2 = this.currentScope();\n    if (this.treatFunctionsAsVar)\n      { redeclared = scope$2.lexical.indexOf(name) > -1; }\n    else\n      { redeclared = scope$2.lexical.indexOf(name) > -1 || scope$2.var.indexOf(name) > -1; }\n    scope$2.functions.push(name);\n  } else {\n    for (var i = this.scopeStack.length - 1; i >= 0; --i) {\n      var scope$3 = this.scopeStack[i];\n      if (scope$3.lexical.indexOf(name) > -1 && !((scope$3.flags & SCOPE_SIMPLE_CATCH) && scope$3.lexical[0] === name) ||\n          !this.treatFunctionsAsVarInScope(scope$3) && scope$3.functions.indexOf(name) > -1) {\n        redeclared = true;\n        break\n      }\n      scope$3.var.push(name);\n      if (this.inModule && (scope$3.flags & SCOPE_TOP))\n        { delete this.undefinedExports[name]; }\n      if (scope$3.flags & SCOPE_VAR) { break }\n    }\n  }\n  if (redeclared) { this.raiseRecoverable(pos, (\"Identifier '\" + name + \"' has already been declared\")); }\n};\n\npp$3.checkLocalExport = function(id) {\n  // scope.functions must be empty as Module code is always strict.\n  if (this.scopeStack[0].lexical.indexOf(id.name) === -1 &&\n      this.scopeStack[0].var.indexOf(id.name) === -1) {\n    this.undefinedExports[id.name] = id;\n  }\n};\n\npp$3.currentScope = function() {\n  return this.scopeStack[this.scopeStack.length - 1]\n};\n\npp$3.currentVarScope = function() {\n  for (var i = this.scopeStack.length - 1;; i--) {\n    var scope = this.scopeStack[i];\n    if (scope.flags & SCOPE_VAR) { return scope }\n  }\n};\n\n// Could be useful for `this`, `new.target`, `super()`, `super.property`, and `super[property]`.\npp$3.currentThisScope = function() {\n  for (var i = this.scopeStack.length - 1;; i--) {\n    var scope = this.scopeStack[i];\n    if (scope.flags & SCOPE_VAR && !(scope.flags & SCOPE_ARROW)) { return scope }\n  }\n};\n\nvar Node = function Node(parser, pos, loc) {\n  this.type = \"\";\n  this.start = pos;\n  this.end = 0;\n  if (parser.options.locations)\n    { this.loc = new SourceLocation(parser, loc); }\n  if (parser.options.directSourceFile)\n    { this.sourceFile = parser.options.directSourceFile; }\n  if (parser.options.ranges)\n    { this.range = [pos, 0]; }\n};\n\n// Start an AST node, attaching a start offset.\n\nvar pp$2 = Parser.prototype;\n\npp$2.startNode = function() {\n  return new Node(this, this.start, this.startLoc)\n};\n\npp$2.startNodeAt = function(pos, loc) {\n  return new Node(this, pos, loc)\n};\n\n// Finish an AST node, adding `type` and `end` properties.\n\nfunction finishNodeAt(node, type, pos, loc) {\n  node.type = type;\n  node.end = pos;\n  if (this.options.locations)\n    { node.loc.end = loc; }\n  if (this.options.ranges)\n    { node.range[1] = pos; }\n  return node\n}\n\npp$2.finishNode = function(node, type) {\n  return finishNodeAt.call(this, node, type, this.lastTokEnd, this.lastTokEndLoc)\n};\n\n// Finish node at given position\n\npp$2.finishNodeAt = function(node, type, pos, loc) {\n  return finishNodeAt.call(this, node, type, pos, loc)\n};\n\npp$2.copyNode = function(node) {\n  var newNode = new Node(this, node.start, this.startLoc);\n  for (var prop in node) { newNode[prop] = node[prop]; }\n  return newNode\n};\n\n// This file contains Unicode properties extracted from the ECMAScript specification.\n// The lists are extracted like so:\n// $$('#table-binary-unicode-properties > figure > table > tbody > tr > td:nth-child(1) code').map(el => el.innerText)\n\n// #table-binary-unicode-properties\nvar ecma9BinaryProperties = \"ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS\";\nvar ecma10BinaryProperties = ecma9BinaryProperties + \" Extended_Pictographic\";\nvar ecma11BinaryProperties = ecma10BinaryProperties;\nvar ecma12BinaryProperties = ecma11BinaryProperties + \" EBase EComp EMod EPres ExtPict\";\nvar ecma13BinaryProperties = ecma12BinaryProperties;\nvar ecma14BinaryProperties = ecma13BinaryProperties;\n\nvar unicodeBinaryProperties = {\n  9: ecma9BinaryProperties,\n  10: ecma10BinaryProperties,\n  11: ecma11BinaryProperties,\n  12: ecma12BinaryProperties,\n  13: ecma13BinaryProperties,\n  14: ecma14BinaryProperties\n};\n\n// #table-binary-unicode-properties-of-strings\nvar ecma14BinaryPropertiesOfStrings = \"Basic_Emoji Emoji_Keycap_Sequence RGI_Emoji_Modifier_Sequence RGI_Emoji_Flag_Sequence RGI_Emoji_Tag_Sequence RGI_Emoji_ZWJ_Sequence RGI_Emoji\";\n\nvar unicodeBinaryPropertiesOfStrings = {\n  9: \"\",\n  10: \"\",\n  11: \"\",\n  12: \"\",\n  13: \"\",\n  14: ecma14BinaryPropertiesOfStrings\n};\n\n// #table-unicode-general-category-values\nvar unicodeGeneralCategoryValues = \"Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu\";\n\n// #table-unicode-script-values\nvar ecma9ScriptValues = \"Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb\";\nvar ecma10ScriptValues = ecma9ScriptValues + \" Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd\";\nvar ecma11ScriptValues = ecma10ScriptValues + \" Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho\";\nvar ecma12ScriptValues = ecma11ScriptValues + \" Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi\";\nvar ecma13ScriptValues = ecma12ScriptValues + \" Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith\";\nvar ecma14ScriptValues = ecma13ScriptValues + \" Hrkt Katakana_Or_Hiragana Kawi Nag_Mundari Nagm Unknown Zzzz\";\n\nvar unicodeScriptValues = {\n  9: ecma9ScriptValues,\n  10: ecma10ScriptValues,\n  11: ecma11ScriptValues,\n  12: ecma12ScriptValues,\n  13: ecma13ScriptValues,\n  14: ecma14ScriptValues\n};\n\nvar data = {};\nfunction buildUnicodeData(ecmaVersion) {\n  var d = data[ecmaVersion] = {\n    binary: wordsRegexp(unicodeBinaryProperties[ecmaVersion] + \" \" + unicodeGeneralCategoryValues),\n    binaryOfStrings: wordsRegexp(unicodeBinaryPropertiesOfStrings[ecmaVersion]),\n    nonBinary: {\n      General_Category: wordsRegexp(unicodeGeneralCategoryValues),\n      Script: wordsRegexp(unicodeScriptValues[ecmaVersion])\n    }\n  };\n  d.nonBinary.Script_Extensions = d.nonBinary.Script;\n\n  d.nonBinary.gc = d.nonBinary.General_Category;\n  d.nonBinary.sc = d.nonBinary.Script;\n  d.nonBinary.scx = d.nonBinary.Script_Extensions;\n}\n\nfor (var i = 0, list = [9, 10, 11, 12, 13, 14]; i < list.length; i += 1) {\n  var ecmaVersion = list[i];\n\n  buildUnicodeData(ecmaVersion);\n}\n\nvar pp$1 = Parser.prototype;\n\nvar RegExpValidationState = function RegExpValidationState(parser) {\n  this.parser = parser;\n  this.validFlags = \"gim\" + (parser.options.ecmaVersion >= 6 ? \"uy\" : \"\") + (parser.options.ecmaVersion >= 9 ? \"s\" : \"\") + (parser.options.ecmaVersion >= 13 ? \"d\" : \"\") + (parser.options.ecmaVersion >= 15 ? \"v\" : \"\");\n  this.unicodeProperties = data[parser.options.ecmaVersion >= 14 ? 14 : parser.options.ecmaVersion];\n  this.source = \"\";\n  this.flags = \"\";\n  this.start = 0;\n  this.switchU = false;\n  this.switchV = false;\n  this.switchN = false;\n  this.pos = 0;\n  this.lastIntValue = 0;\n  this.lastStringValue = \"\";\n  this.lastAssertionIsQuantifiable = false;\n  this.numCapturingParens = 0;\n  this.maxBackReference = 0;\n  this.groupNames = [];\n  this.backReferenceNames = [];\n};\n\nRegExpValidationState.prototype.reset = function reset (start, pattern, flags) {\n  var unicodeSets = flags.indexOf(\"v\") !== -1;\n  var unicode = flags.indexOf(\"u\") !== -1;\n  this.start = start | 0;\n  this.source = pattern + \"\";\n  this.flags = flags;\n  if (unicodeSets && this.parser.options.ecmaVersion >= 15) {\n    this.switchU = true;\n    this.switchV = true;\n    this.switchN = true;\n  } else {\n    this.switchU = unicode && this.parser.options.ecmaVersion >= 6;\n    this.switchV = false;\n    this.switchN = unicode && this.parser.options.ecmaVersion >= 9;\n  }\n};\n\nRegExpValidationState.prototype.raise = function raise (message) {\n  this.parser.raiseRecoverable(this.start, (\"Invalid regular expression: /\" + (this.source) + \"/: \" + message));\n};\n\n// If u flag is given, this returns the code point at the index (it combines a surrogate pair).\n// Otherwise, this returns the code unit of the index (can be a part of a surrogate pair).\nRegExpValidationState.prototype.at = function at (i, forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  var s = this.source;\n  var l = s.length;\n  if (i >= l) {\n    return -1\n  }\n  var c = s.charCodeAt(i);\n  if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l) {\n    return c\n  }\n  var next = s.charCodeAt(i + 1);\n  return next >= 0xDC00 && next <= 0xDFFF ? (c << 10) + next - 0x35FDC00 : c\n};\n\nRegExpValidationState.prototype.nextIndex = function nextIndex (i, forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  var s = this.source;\n  var l = s.length;\n  if (i >= l) {\n    return l\n  }\n  var c = s.charCodeAt(i), next;\n  if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l ||\n      (next = s.charCodeAt(i + 1)) < 0xDC00 || next > 0xDFFF) {\n    return i + 1\n  }\n  return i + 2\n};\n\nRegExpValidationState.prototype.current = function current (forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  return this.at(this.pos, forceU)\n};\n\nRegExpValidationState.prototype.lookahead = function lookahead (forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  return this.at(this.nextIndex(this.pos, forceU), forceU)\n};\n\nRegExpValidationState.prototype.advance = function advance (forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  this.pos = this.nextIndex(this.pos, forceU);\n};\n\nRegExpValidationState.prototype.eat = function eat (ch, forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  if (this.current(forceU) === ch) {\n    this.advance(forceU);\n    return true\n  }\n  return false\n};\n\nRegExpValidationState.prototype.eatChars = function eatChars (chs, forceU) {\n    if ( forceU === void 0 ) forceU = false;\n\n  var pos = this.pos;\n  for (var i = 0, list = chs; i < list.length; i += 1) {\n    var ch = list[i];\n\n      var current = this.at(pos, forceU);\n    if (current === -1 || current !== ch) {\n      return false\n    }\n    pos = this.nextIndex(pos, forceU);\n  }\n  this.pos = pos;\n  return true\n};\n\n/**\n * Validate the flags part of a given RegExpLiteral.\n *\n * @param {RegExpValidationState} state The state to validate RegExp.\n * @returns {void}\n */\npp$1.validateRegExpFlags = function(state) {\n  var validFlags = state.validFlags;\n  var flags = state.flags;\n\n  var u = false;\n  var v = false;\n\n  for (var i = 0; i < flags.length; i++) {\n    var flag = flags.charAt(i);\n    if (validFlags.indexOf(flag) === -1) {\n      this.raise(state.start, \"Invalid regular expression flag\");\n    }\n    if (flags.indexOf(flag, i + 1) > -1) {\n      this.raise(state.start, \"Duplicate regular expression flag\");\n    }\n    if (flag === \"u\") { u = true; }\n    if (flag === \"v\") { v = true; }\n  }\n  if (this.options.ecmaVersion >= 15 && u && v) {\n    this.raise(state.start, \"Invalid regular expression flag\");\n  }\n};\n\n/**\n * Validate the pattern part of a given RegExpLiteral.\n *\n * @param {RegExpValidationState} state The state to validate RegExp.\n * @returns {void}\n */\npp$1.validateRegExpPattern = function(state) {\n  this.regexp_pattern(state);\n\n  // The goal symbol for the parse is |Pattern[~U, ~N]|. If the result of\n  // parsing contains a |GroupName|, reparse with the goal symbol\n  // |Pattern[~U, +N]| and use this result instead. Throw a *SyntaxError*\n  // exception if _P_ did not conform to the grammar, if any elements of _P_\n  // were not matched by the parse, or if any Early Error conditions exist.\n  if (!state.switchN && this.options.ecmaVersion >= 9 && state.groupNames.length > 0) {\n    state.switchN = true;\n    this.regexp_pattern(state);\n  }\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Pattern\npp$1.regexp_pattern = function(state) {\n  state.pos = 0;\n  state.lastIntValue = 0;\n  state.lastStringValue = \"\";\n  state.lastAssertionIsQuantifiable = false;\n  state.numCapturingParens = 0;\n  state.maxBackReference = 0;\n  state.groupNames.length = 0;\n  state.backReferenceNames.length = 0;\n\n  this.regexp_disjunction(state);\n\n  if (state.pos !== state.source.length) {\n    // Make the same messages as V8.\n    if (state.eat(0x29 /* ) */)) {\n      state.raise(\"Unmatched ')'\");\n    }\n    if (state.eat(0x5D /* ] */) || state.eat(0x7D /* } */)) {\n      state.raise(\"Lone quantifier brackets\");\n    }\n  }\n  if (state.maxBackReference > state.numCapturingParens) {\n    state.raise(\"Invalid escape\");\n  }\n  for (var i = 0, list = state.backReferenceNames; i < list.length; i += 1) {\n    var name = list[i];\n\n    if (state.groupNames.indexOf(name) === -1) {\n      state.raise(\"Invalid named capture referenced\");\n    }\n  }\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Disjunction\npp$1.regexp_disjunction = function(state) {\n  this.regexp_alternative(state);\n  while (state.eat(0x7C /* | */)) {\n    this.regexp_alternative(state);\n  }\n\n  // Make the same message as V8.\n  if (this.regexp_eatQuantifier(state, true)) {\n    state.raise(\"Nothing to repeat\");\n  }\n  if (state.eat(0x7B /* { */)) {\n    state.raise(\"Lone quantifier brackets\");\n  }\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Alternative\npp$1.regexp_alternative = function(state) {\n  while (state.pos < state.source.length && this.regexp_eatTerm(state))\n    { }\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Term\npp$1.regexp_eatTerm = function(state) {\n  if (this.regexp_eatAssertion(state)) {\n    // Handle `QuantifiableAssertion Quantifier` alternative.\n    // `state.lastAssertionIsQuantifiable` is true if the last eaten Assertion\n    // is a QuantifiableAssertion.\n    if (state.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(state)) {\n      // Make the same message as V8.\n      if (state.switchU) {\n        state.raise(\"Invalid quantifier\");\n      }\n    }\n    return true\n  }\n\n  if (state.switchU ? this.regexp_eatAtom(state) : this.regexp_eatExtendedAtom(state)) {\n    this.regexp_eatQuantifier(state);\n    return true\n  }\n\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Assertion\npp$1.regexp_eatAssertion = function(state) {\n  var start = state.pos;\n  state.lastAssertionIsQuantifiable = false;\n\n  // ^, $\n  if (state.eat(0x5E /* ^ */) || state.eat(0x24 /* $ */)) {\n    return true\n  }\n\n  // \\b \\B\n  if (state.eat(0x5C /* \\ */)) {\n    if (state.eat(0x42 /* B */) || state.eat(0x62 /* b */)) {\n      return true\n    }\n    state.pos = start;\n  }\n\n  // Lookahead / Lookbehind\n  if (state.eat(0x28 /* ( */) && state.eat(0x3F /* ? */)) {\n    var lookbehind = false;\n    if (this.options.ecmaVersion >= 9) {\n      lookbehind = state.eat(0x3C /* < */);\n    }\n    if (state.eat(0x3D /* = */) || state.eat(0x21 /* ! */)) {\n      this.regexp_disjunction(state);\n      if (!state.eat(0x29 /* ) */)) {\n        state.raise(\"Unterminated group\");\n      }\n      state.lastAssertionIsQuantifiable = !lookbehind;\n      return true\n    }\n  }\n\n  state.pos = start;\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Quantifier\npp$1.regexp_eatQuantifier = function(state, noError) {\n  if ( noError === void 0 ) noError = false;\n\n  if (this.regexp_eatQuantifierPrefix(state, noError)) {\n    state.eat(0x3F /* ? */);\n    return true\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-QuantifierPrefix\npp$1.regexp_eatQuantifierPrefix = function(state, noError) {\n  return (\n    state.eat(0x2A /* * */) ||\n    state.eat(0x2B /* + */) ||\n    state.eat(0x3F /* ? */) ||\n    this.regexp_eatBracedQuantifier(state, noError)\n  )\n};\npp$1.regexp_eatBracedQuantifier = function(state, noError) {\n  var start = state.pos;\n  if (state.eat(0x7B /* { */)) {\n    var min = 0, max = -1;\n    if (this.regexp_eatDecimalDigits(state)) {\n      min = state.lastIntValue;\n      if (state.eat(0x2C /* , */) && this.regexp_eatDecimalDigits(state)) {\n        max = state.lastIntValue;\n      }\n      if (state.eat(0x7D /* } */)) {\n        // SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-term\n        if (max !== -1 && max < min && !noError) {\n          state.raise(\"numbers out of order in {} quantifier\");\n        }\n        return true\n      }\n    }\n    if (state.switchU && !noError) {\n      state.raise(\"Incomplete quantifier\");\n    }\n    state.pos = start;\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Atom\npp$1.regexp_eatAtom = function(state) {\n  return (\n    this.regexp_eatPatternCharacters(state) ||\n    state.eat(0x2E /* . */) ||\n    this.regexp_eatReverseSolidusAtomEscape(state) ||\n    this.regexp_eatCharacterClass(state) ||\n    this.regexp_eatUncapturingGroup(state) ||\n    this.regexp_eatCapturingGroup(state)\n  )\n};\npp$1.regexp_eatReverseSolidusAtomEscape = function(state) {\n  var start = state.pos;\n  if (state.eat(0x5C /* \\ */)) {\n    if (this.regexp_eatAtomEscape(state)) {\n      return true\n    }\n    state.pos = start;\n  }\n  return false\n};\npp$1.regexp_eatUncapturingGroup = function(state) {\n  var start = state.pos;\n  if (state.eat(0x28 /* ( */)) {\n    if (state.eat(0x3F /* ? */) && state.eat(0x3A /* : */)) {\n      this.regexp_disjunction(state);\n      if (state.eat(0x29 /* ) */)) {\n        return true\n      }\n      state.raise(\"Unterminated group\");\n    }\n    state.pos = start;\n  }\n  return false\n};\npp$1.regexp_eatCapturingGroup = function(state) {\n  if (state.eat(0x28 /* ( */)) {\n    if (this.options.ecmaVersion >= 9) {\n      this.regexp_groupSpecifier(state);\n    } else if (state.current() === 0x3F /* ? */) {\n      state.raise(\"Invalid group\");\n    }\n    this.regexp_disjunction(state);\n    if (state.eat(0x29 /* ) */)) {\n      state.numCapturingParens += 1;\n      return true\n    }\n    state.raise(\"Unterminated group\");\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedAtom\npp$1.regexp_eatExtendedAtom = function(state) {\n  return (\n    state.eat(0x2E /* . */) ||\n    this.regexp_eatReverseSolidusAtomEscape(state) ||\n    this.regexp_eatCharacterClass(state) ||\n    this.regexp_eatUncapturingGroup(state) ||\n    this.regexp_eatCapturingGroup(state) ||\n    this.regexp_eatInvalidBracedQuantifier(state) ||\n    this.regexp_eatExtendedPatternCharacter(state)\n  )\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-InvalidBracedQuantifier\npp$1.regexp_eatInvalidBracedQuantifier = function(state) {\n  if (this.regexp_eatBracedQuantifier(state, true)) {\n    state.raise(\"Nothing to repeat\");\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-SyntaxCharacter\npp$1.regexp_eatSyntaxCharacter = function(state) {\n  var ch = state.current();\n  if (isSyntaxCharacter(ch)) {\n    state.lastIntValue = ch;\n    state.advance();\n    return true\n  }\n  return false\n};\nfunction isSyntaxCharacter(ch) {\n  return (\n    ch === 0x24 /* $ */ ||\n    ch >= 0x28 /* ( */ && ch <= 0x2B /* + */ ||\n    ch === 0x2E /* . */ ||\n    ch === 0x3F /* ? */ ||\n    ch >= 0x5B /* [ */ && ch <= 0x5E /* ^ */ ||\n    ch >= 0x7B /* { */ && ch <= 0x7D /* } */\n  )\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-PatternCharacter\n// But eat eager.\npp$1.regexp_eatPatternCharacters = function(state) {\n  var start = state.pos;\n  var ch = 0;\n  while ((ch = state.current()) !== -1 && !isSyntaxCharacter(ch)) {\n    state.advance();\n  }\n  return state.pos !== start\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedPatternCharacter\npp$1.regexp_eatExtendedPatternCharacter = function(state) {\n  var ch = state.current();\n  if (\n    ch !== -1 &&\n    ch !== 0x24 /* $ */ &&\n    !(ch >= 0x28 /* ( */ && ch <= 0x2B /* + */) &&\n    ch !== 0x2E /* . */ &&\n    ch !== 0x3F /* ? */ &&\n    ch !== 0x5B /* [ */ &&\n    ch !== 0x5E /* ^ */ &&\n    ch !== 0x7C /* | */\n  ) {\n    state.advance();\n    return true\n  }\n  return false\n};\n\n// GroupSpecifier ::\n//   [empty]\n//   `?` GroupName\npp$1.regexp_groupSpecifier = function(state) {\n  if (state.eat(0x3F /* ? */)) {\n    if (this.regexp_eatGroupName(state)) {\n      if (state.groupNames.indexOf(state.lastStringValue) !== -1) {\n        state.raise(\"Duplicate capture group name\");\n      }\n      state.groupNames.push(state.lastStringValue);\n      return\n    }\n    state.raise(\"Invalid group\");\n  }\n};\n\n// GroupName ::\n//   `<` RegExpIdentifierName `>`\n// Note: this updates `state.lastStringValue` property with the eaten name.\npp$1.regexp_eatGroupName = function(state) {\n  state.lastStringValue = \"\";\n  if (state.eat(0x3C /* < */)) {\n    if (this.regexp_eatRegExpIdentifierName(state) && state.eat(0x3E /* > */)) {\n      return true\n    }\n    state.raise(\"Invalid capture group name\");\n  }\n  return false\n};\n\n// RegExpIdentifierName ::\n//   RegExpIdentifierStart\n//   RegExpIdentifierName RegExpIdentifierPart\n// Note: this updates `state.lastStringValue` property with the eaten name.\npp$1.regexp_eatRegExpIdentifierName = function(state) {\n  state.lastStringValue = \"\";\n  if (this.regexp_eatRegExpIdentifierStart(state)) {\n    state.lastStringValue += codePointToString(state.lastIntValue);\n    while (this.regexp_eatRegExpIdentifierPart(state)) {\n      state.lastStringValue += codePointToString(state.lastIntValue);\n    }\n    return true\n  }\n  return false\n};\n\n// RegExpIdentifierStart ::\n//   UnicodeIDStart\n//   `$`\n//   `_`\n//   `\\` RegExpUnicodeEscapeSequence[+U]\npp$1.regexp_eatRegExpIdentifierStart = function(state) {\n  var start = state.pos;\n  var forceU = this.options.ecmaVersion >= 11;\n  var ch = state.current(forceU);\n  state.advance(forceU);\n\n  if (ch === 0x5C /* \\ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {\n    ch = state.lastIntValue;\n  }\n  if (isRegExpIdentifierStart(ch)) {\n    state.lastIntValue = ch;\n    return true\n  }\n\n  state.pos = start;\n  return false\n};\nfunction isRegExpIdentifierStart(ch) {\n  return isIdentifierStart(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F /* _ */\n}\n\n// RegExpIdentifierPart ::\n//   UnicodeIDContinue\n//   `$`\n//   `_`\n//   `\\` RegExpUnicodeEscapeSequence[+U]\n//   <ZWNJ>\n//   <ZWJ>\npp$1.regexp_eatRegExpIdentifierPart = function(state) {\n  var start = state.pos;\n  var forceU = this.options.ecmaVersion >= 11;\n  var ch = state.current(forceU);\n  state.advance(forceU);\n\n  if (ch === 0x5C /* \\ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {\n    ch = state.lastIntValue;\n  }\n  if (isRegExpIdentifierPart(ch)) {\n    state.lastIntValue = ch;\n    return true\n  }\n\n  state.pos = start;\n  return false\n};\nfunction isRegExpIdentifierPart(ch) {\n  return isIdentifierChar(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F /* _ */ || ch === 0x200C /* <ZWNJ> */ || ch === 0x200D /* <ZWJ> */\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-AtomEscape\npp$1.regexp_eatAtomEscape = function(state) {\n  if (\n    this.regexp_eatBackReference(state) ||\n    this.regexp_eatCharacterClassEscape(state) ||\n    this.regexp_eatCharacterEscape(state) ||\n    (state.switchN && this.regexp_eatKGroupName(state))\n  ) {\n    return true\n  }\n  if (state.switchU) {\n    // Make the same message as V8.\n    if (state.current() === 0x63 /* c */) {\n      state.raise(\"Invalid unicode escape\");\n    }\n    state.raise(\"Invalid escape\");\n  }\n  return false\n};\npp$1.regexp_eatBackReference = function(state) {\n  var start = state.pos;\n  if (this.regexp_eatDecimalEscape(state)) {\n    var n = state.lastIntValue;\n    if (state.switchU) {\n      // For SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-atomescape\n      if (n > state.maxBackReference) {\n        state.maxBackReference = n;\n      }\n      return true\n    }\n    if (n <= state.numCapturingParens) {\n      return true\n    }\n    state.pos = start;\n  }\n  return false\n};\npp$1.regexp_eatKGroupName = function(state) {\n  if (state.eat(0x6B /* k */)) {\n    if (this.regexp_eatGroupName(state)) {\n      state.backReferenceNames.push(state.lastStringValue);\n      return true\n    }\n    state.raise(\"Invalid named reference\");\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-CharacterEscape\npp$1.regexp_eatCharacterEscape = function(state) {\n  return (\n    this.regexp_eatControlEscape(state) ||\n    this.regexp_eatCControlLetter(state) ||\n    this.regexp_eatZero(state) ||\n    this.regexp_eatHexEscapeSequence(state) ||\n    this.regexp_eatRegExpUnicodeEscapeSequence(state, false) ||\n    (!state.switchU && this.regexp_eatLegacyOctalEscapeSequence(state)) ||\n    this.regexp_eatIdentityEscape(state)\n  )\n};\npp$1.regexp_eatCControlLetter = function(state) {\n  var start = state.pos;\n  if (state.eat(0x63 /* c */)) {\n    if (this.regexp_eatControlLetter(state)) {\n      return true\n    }\n    state.pos = start;\n  }\n  return false\n};\npp$1.regexp_eatZero = function(state) {\n  if (state.current() === 0x30 /* 0 */ && !isDecimalDigit(state.lookahead())) {\n    state.lastIntValue = 0;\n    state.advance();\n    return true\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-ControlEscape\npp$1.regexp_eatControlEscape = function(state) {\n  var ch = state.current();\n  if (ch === 0x74 /* t */) {\n    state.lastIntValue = 0x09; /* \\t */\n    state.advance();\n    return true\n  }\n  if (ch === 0x6E /* n */) {\n    state.lastIntValue = 0x0A; /* \\n */\n    state.advance();\n    return true\n  }\n  if (ch === 0x76 /* v */) {\n    state.lastIntValue = 0x0B; /* \\v */\n    state.advance();\n    return true\n  }\n  if (ch === 0x66 /* f */) {\n    state.lastIntValue = 0x0C; /* \\f */\n    state.advance();\n    return true\n  }\n  if (ch === 0x72 /* r */) {\n    state.lastIntValue = 0x0D; /* \\r */\n    state.advance();\n    return true\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-ControlLetter\npp$1.regexp_eatControlLetter = function(state) {\n  var ch = state.current();\n  if (isControlLetter(ch)) {\n    state.lastIntValue = ch % 0x20;\n    state.advance();\n    return true\n  }\n  return false\n};\nfunction isControlLetter(ch) {\n  return (\n    (ch >= 0x41 /* A */ && ch <= 0x5A /* Z */) ||\n    (ch >= 0x61 /* a */ && ch <= 0x7A /* z */)\n  )\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-RegExpUnicodeEscapeSequence\npp$1.regexp_eatRegExpUnicodeEscapeSequence = function(state, forceU) {\n  if ( forceU === void 0 ) forceU = false;\n\n  var start = state.pos;\n  var switchU = forceU || state.switchU;\n\n  if (state.eat(0x75 /* u */)) {\n    if (this.regexp_eatFixedHexDigits(state, 4)) {\n      var lead = state.lastIntValue;\n      if (switchU && lead >= 0xD800 && lead <= 0xDBFF) {\n        var leadSurrogateEnd = state.pos;\n        if (state.eat(0x5C /* \\ */) && state.eat(0x75 /* u */) && this.regexp_eatFixedHexDigits(state, 4)) {\n          var trail = state.lastIntValue;\n          if (trail >= 0xDC00 && trail <= 0xDFFF) {\n            state.lastIntValue = (lead - 0xD800) * 0x400 + (trail - 0xDC00) + 0x10000;\n            return true\n          }\n        }\n        state.pos = leadSurrogateEnd;\n        state.lastIntValue = lead;\n      }\n      return true\n    }\n    if (\n      switchU &&\n      state.eat(0x7B /* { */) &&\n      this.regexp_eatHexDigits(state) &&\n      state.eat(0x7D /* } */) &&\n      isValidUnicode(state.lastIntValue)\n    ) {\n      return true\n    }\n    if (switchU) {\n      state.raise(\"Invalid unicode escape\");\n    }\n    state.pos = start;\n  }\n\n  return false\n};\nfunction isValidUnicode(ch) {\n  return ch >= 0 && ch <= 0x10FFFF\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-IdentityEscape\npp$1.regexp_eatIdentityEscape = function(state) {\n  if (state.switchU) {\n    if (this.regexp_eatSyntaxCharacter(state)) {\n      return true\n    }\n    if (state.eat(0x2F /* / */)) {\n      state.lastIntValue = 0x2F; /* / */\n      return true\n    }\n    return false\n  }\n\n  var ch = state.current();\n  if (ch !== 0x63 /* c */ && (!state.switchN || ch !== 0x6B /* k */)) {\n    state.lastIntValue = ch;\n    state.advance();\n    return true\n  }\n\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalEscape\npp$1.regexp_eatDecimalEscape = function(state) {\n  state.lastIntValue = 0;\n  var ch = state.current();\n  if (ch >= 0x31 /* 1 */ && ch <= 0x39 /* 9 */) {\n    do {\n      state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);\n      state.advance();\n    } while ((ch = state.current()) >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */)\n    return true\n  }\n  return false\n};\n\n// Return values used by character set parsing methods, needed to\n// forbid negation of sets that can match strings.\nvar CharSetNone = 0; // Nothing parsed\nvar CharSetOk = 1; // Construct parsed, cannot contain strings\nvar CharSetString = 2; // Construct parsed, can contain strings\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClassEscape\npp$1.regexp_eatCharacterClassEscape = function(state) {\n  var ch = state.current();\n\n  if (isCharacterClassEscape(ch)) {\n    state.lastIntValue = -1;\n    state.advance();\n    return CharSetOk\n  }\n\n  var negate = false;\n  if (\n    state.switchU &&\n    this.options.ecmaVersion >= 9 &&\n    ((negate = ch === 0x50 /* P */) || ch === 0x70 /* p */)\n  ) {\n    state.lastIntValue = -1;\n    state.advance();\n    var result;\n    if (\n      state.eat(0x7B /* { */) &&\n      (result = this.regexp_eatUnicodePropertyValueExpression(state)) &&\n      state.eat(0x7D /* } */)\n    ) {\n      if (negate && result === CharSetString) { state.raise(\"Invalid property name\"); }\n      return result\n    }\n    state.raise(\"Invalid property name\");\n  }\n\n  return CharSetNone\n};\n\nfunction isCharacterClassEscape(ch) {\n  return (\n    ch === 0x64 /* d */ ||\n    ch === 0x44 /* D */ ||\n    ch === 0x73 /* s */ ||\n    ch === 0x53 /* S */ ||\n    ch === 0x77 /* w */ ||\n    ch === 0x57 /* W */\n  )\n}\n\n// UnicodePropertyValueExpression ::\n//   UnicodePropertyName `=` UnicodePropertyValue\n//   LoneUnicodePropertyNameOrValue\npp$1.regexp_eatUnicodePropertyValueExpression = function(state) {\n  var start = state.pos;\n\n  // UnicodePropertyName `=` UnicodePropertyValue\n  if (this.regexp_eatUnicodePropertyName(state) && state.eat(0x3D /* = */)) {\n    var name = state.lastStringValue;\n    if (this.regexp_eatUnicodePropertyValue(state)) {\n      var value = state.lastStringValue;\n      this.regexp_validateUnicodePropertyNameAndValue(state, name, value);\n      return CharSetOk\n    }\n  }\n  state.pos = start;\n\n  // LoneUnicodePropertyNameOrValue\n  if (this.regexp_eatLoneUnicodePropertyNameOrValue(state)) {\n    var nameOrValue = state.lastStringValue;\n    return this.regexp_validateUnicodePropertyNameOrValue(state, nameOrValue)\n  }\n  return CharSetNone\n};\n\npp$1.regexp_validateUnicodePropertyNameAndValue = function(state, name, value) {\n  if (!hasOwn(state.unicodeProperties.nonBinary, name))\n    { state.raise(\"Invalid property name\"); }\n  if (!state.unicodeProperties.nonBinary[name].test(value))\n    { state.raise(\"Invalid property value\"); }\n};\n\npp$1.regexp_validateUnicodePropertyNameOrValue = function(state, nameOrValue) {\n  if (state.unicodeProperties.binary.test(nameOrValue)) { return CharSetOk }\n  if (state.switchV && state.unicodeProperties.binaryOfStrings.test(nameOrValue)) { return CharSetString }\n  state.raise(\"Invalid property name\");\n};\n\n// UnicodePropertyName ::\n//   UnicodePropertyNameCharacters\npp$1.regexp_eatUnicodePropertyName = function(state) {\n  var ch = 0;\n  state.lastStringValue = \"\";\n  while (isUnicodePropertyNameCharacter(ch = state.current())) {\n    state.lastStringValue += codePointToString(ch);\n    state.advance();\n  }\n  return state.lastStringValue !== \"\"\n};\n\nfunction isUnicodePropertyNameCharacter(ch) {\n  return isControlLetter(ch) || ch === 0x5F /* _ */\n}\n\n// UnicodePropertyValue ::\n//   UnicodePropertyValueCharacters\npp$1.regexp_eatUnicodePropertyValue = function(state) {\n  var ch = 0;\n  state.lastStringValue = \"\";\n  while (isUnicodePropertyValueCharacter(ch = state.current())) {\n    state.lastStringValue += codePointToString(ch);\n    state.advance();\n  }\n  return state.lastStringValue !== \"\"\n};\nfunction isUnicodePropertyValueCharacter(ch) {\n  return isUnicodePropertyNameCharacter(ch) || isDecimalDigit(ch)\n}\n\n// LoneUnicodePropertyNameOrValue ::\n//   UnicodePropertyValueCharacters\npp$1.regexp_eatLoneUnicodePropertyNameOrValue = function(state) {\n  return this.regexp_eatUnicodePropertyValue(state)\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClass\npp$1.regexp_eatCharacterClass = function(state) {\n  if (state.eat(0x5B /* [ */)) {\n    var negate = state.eat(0x5E /* ^ */);\n    var result = this.regexp_classContents(state);\n    if (!state.eat(0x5D /* ] */))\n      { state.raise(\"Unterminated character class\"); }\n    if (negate && result === CharSetString)\n      { state.raise(\"Negated character class may contain strings\"); }\n    return true\n  }\n  return false\n};\n\n// https://tc39.es/ecma262/#prod-ClassContents\n// https://www.ecma-international.org/ecma-262/8.0/#prod-ClassRanges\npp$1.regexp_classContents = function(state) {\n  if (state.current() === 0x5D /* ] */) { return CharSetOk }\n  if (state.switchV) { return this.regexp_classSetExpression(state) }\n  this.regexp_nonEmptyClassRanges(state);\n  return CharSetOk\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRanges\n// https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRangesNoDash\npp$1.regexp_nonEmptyClassRanges = function(state) {\n  while (this.regexp_eatClassAtom(state)) {\n    var left = state.lastIntValue;\n    if (state.eat(0x2D /* - */) && this.regexp_eatClassAtom(state)) {\n      var right = state.lastIntValue;\n      if (state.switchU && (left === -1 || right === -1)) {\n        state.raise(\"Invalid character class\");\n      }\n      if (left !== -1 && right !== -1 && left > right) {\n        state.raise(\"Range out of order in character class\");\n      }\n    }\n  }\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtom\n// https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtomNoDash\npp$1.regexp_eatClassAtom = function(state) {\n  var start = state.pos;\n\n  if (state.eat(0x5C /* \\ */)) {\n    if (this.regexp_eatClassEscape(state)) {\n      return true\n    }\n    if (state.switchU) {\n      // Make the same message as V8.\n      var ch$1 = state.current();\n      if (ch$1 === 0x63 /* c */ || isOctalDigit(ch$1)) {\n        state.raise(\"Invalid class escape\");\n      }\n      state.raise(\"Invalid escape\");\n    }\n    state.pos = start;\n  }\n\n  var ch = state.current();\n  if (ch !== 0x5D /* ] */) {\n    state.lastIntValue = ch;\n    state.advance();\n    return true\n  }\n\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassEscape\npp$1.regexp_eatClassEscape = function(state) {\n  var start = state.pos;\n\n  if (state.eat(0x62 /* b */)) {\n    state.lastIntValue = 0x08; /* <BS> */\n    return true\n  }\n\n  if (state.switchU && state.eat(0x2D /* - */)) {\n    state.lastIntValue = 0x2D; /* - */\n    return true\n  }\n\n  if (!state.switchU && state.eat(0x63 /* c */)) {\n    if (this.regexp_eatClassControlLetter(state)) {\n      return true\n    }\n    state.pos = start;\n  }\n\n  return (\n    this.regexp_eatCharacterClassEscape(state) ||\n    this.regexp_eatCharacterEscape(state)\n  )\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetExpression\n// https://tc39.es/ecma262/#prod-ClassUnion\n// https://tc39.es/ecma262/#prod-ClassIntersection\n// https://tc39.es/ecma262/#prod-ClassSubtraction\npp$1.regexp_classSetExpression = function(state) {\n  var result = CharSetOk, subResult;\n  if (this.regexp_eatClassSetRange(state)) ; else if (subResult = this.regexp_eatClassSetOperand(state)) {\n    if (subResult === CharSetString) { result = CharSetString; }\n    // https://tc39.es/ecma262/#prod-ClassIntersection\n    var start = state.pos;\n    while (state.eatChars([0x26, 0x26] /* && */)) {\n      if (\n        state.current() !== 0x26 /* & */ &&\n        (subResult = this.regexp_eatClassSetOperand(state))\n      ) {\n        if (subResult !== CharSetString) { result = CharSetOk; }\n        continue\n      }\n      state.raise(\"Invalid character in character class\");\n    }\n    if (start !== state.pos) { return result }\n    // https://tc39.es/ecma262/#prod-ClassSubtraction\n    while (state.eatChars([0x2D, 0x2D] /* -- */)) {\n      if (this.regexp_eatClassSetOperand(state)) { continue }\n      state.raise(\"Invalid character in character class\");\n    }\n    if (start !== state.pos) { return result }\n  } else {\n    state.raise(\"Invalid character in character class\");\n  }\n  // https://tc39.es/ecma262/#prod-ClassUnion\n  for (;;) {\n    if (this.regexp_eatClassSetRange(state)) { continue }\n    subResult = this.regexp_eatClassSetOperand(state);\n    if (!subResult) { return result }\n    if (subResult === CharSetString) { result = CharSetString; }\n  }\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetRange\npp$1.regexp_eatClassSetRange = function(state) {\n  var start = state.pos;\n  if (this.regexp_eatClassSetCharacter(state)) {\n    var left = state.lastIntValue;\n    if (state.eat(0x2D /* - */) && this.regexp_eatClassSetCharacter(state)) {\n      var right = state.lastIntValue;\n      if (left !== -1 && right !== -1 && left > right) {\n        state.raise(\"Range out of order in character class\");\n      }\n      return true\n    }\n    state.pos = start;\n  }\n  return false\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetOperand\npp$1.regexp_eatClassSetOperand = function(state) {\n  if (this.regexp_eatClassSetCharacter(state)) { return CharSetOk }\n  return this.regexp_eatClassStringDisjunction(state) || this.regexp_eatNestedClass(state)\n};\n\n// https://tc39.es/ecma262/#prod-NestedClass\npp$1.regexp_eatNestedClass = function(state) {\n  var start = state.pos;\n  if (state.eat(0x5B /* [ */)) {\n    var negate = state.eat(0x5E /* ^ */);\n    var result = this.regexp_classContents(state);\n    if (state.eat(0x5D /* ] */)) {\n      if (negate && result === CharSetString) {\n        state.raise(\"Negated character class may contain strings\");\n      }\n      return result\n    }\n    state.pos = start;\n  }\n  if (state.eat(0x5C /* \\ */)) {\n    var result$1 = this.regexp_eatCharacterClassEscape(state);\n    if (result$1) {\n      return result$1\n    }\n    state.pos = start;\n  }\n  return null\n};\n\n// https://tc39.es/ecma262/#prod-ClassStringDisjunction\npp$1.regexp_eatClassStringDisjunction = function(state) {\n  var start = state.pos;\n  if (state.eatChars([0x5C, 0x71] /* \\q */)) {\n    if (state.eat(0x7B /* { */)) {\n      var result = this.regexp_classStringDisjunctionContents(state);\n      if (state.eat(0x7D /* } */)) {\n        return result\n      }\n    } else {\n      // Make the same message as V8.\n      state.raise(\"Invalid escape\");\n    }\n    state.pos = start;\n  }\n  return null\n};\n\n// https://tc39.es/ecma262/#prod-ClassStringDisjunctionContents\npp$1.regexp_classStringDisjunctionContents = function(state) {\n  var result = this.regexp_classString(state);\n  while (state.eat(0x7C /* | */)) {\n    if (this.regexp_classString(state) === CharSetString) { result = CharSetString; }\n  }\n  return result\n};\n\n// https://tc39.es/ecma262/#prod-ClassString\n// https://tc39.es/ecma262/#prod-NonEmptyClassString\npp$1.regexp_classString = function(state) {\n  var count = 0;\n  while (this.regexp_eatClassSetCharacter(state)) { count++; }\n  return count === 1 ? CharSetOk : CharSetString\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetCharacter\npp$1.regexp_eatClassSetCharacter = function(state) {\n  var start = state.pos;\n  if (state.eat(0x5C /* \\ */)) {\n    if (\n      this.regexp_eatCharacterEscape(state) ||\n      this.regexp_eatClassSetReservedPunctuator(state)\n    ) {\n      return true\n    }\n    if (state.eat(0x62 /* b */)) {\n      state.lastIntValue = 0x08; /* <BS> */\n      return true\n    }\n    state.pos = start;\n    return false\n  }\n  var ch = state.current();\n  if (ch < 0 || ch === state.lookahead() && isClassSetReservedDoublePunctuatorCharacter(ch)) { return false }\n  if (isClassSetSyntaxCharacter(ch)) { return false }\n  state.advance();\n  state.lastIntValue = ch;\n  return true\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetReservedDoublePunctuator\nfunction isClassSetReservedDoublePunctuatorCharacter(ch) {\n  return (\n    ch === 0x21 /* ! */ ||\n    ch >= 0x23 /* # */ && ch <= 0x26 /* & */ ||\n    ch >= 0x2A /* * */ && ch <= 0x2C /* , */ ||\n    ch === 0x2E /* . */ ||\n    ch >= 0x3A /* : */ && ch <= 0x40 /* @ */ ||\n    ch === 0x5E /* ^ */ ||\n    ch === 0x60 /* ` */ ||\n    ch === 0x7E /* ~ */\n  )\n}\n\n// https://tc39.es/ecma262/#prod-ClassSetSyntaxCharacter\nfunction isClassSetSyntaxCharacter(ch) {\n  return (\n    ch === 0x28 /* ( */ ||\n    ch === 0x29 /* ) */ ||\n    ch === 0x2D /* - */ ||\n    ch === 0x2F /* / */ ||\n    ch >= 0x5B /* [ */ && ch <= 0x5D /* ] */ ||\n    ch >= 0x7B /* { */ && ch <= 0x7D /* } */\n  )\n}\n\n// https://tc39.es/ecma262/#prod-ClassSetReservedPunctuator\npp$1.regexp_eatClassSetReservedPunctuator = function(state) {\n  var ch = state.current();\n  if (isClassSetReservedPunctuator(ch)) {\n    state.lastIntValue = ch;\n    state.advance();\n    return true\n  }\n  return false\n};\n\n// https://tc39.es/ecma262/#prod-ClassSetReservedPunctuator\nfunction isClassSetReservedPunctuator(ch) {\n  return (\n    ch === 0x21 /* ! */ ||\n    ch === 0x23 /* # */ ||\n    ch === 0x25 /* % */ ||\n    ch === 0x26 /* & */ ||\n    ch === 0x2C /* , */ ||\n    ch === 0x2D /* - */ ||\n    ch >= 0x3A /* : */ && ch <= 0x3E /* > */ ||\n    ch === 0x40 /* @ */ ||\n    ch === 0x60 /* ` */ ||\n    ch === 0x7E /* ~ */\n  )\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassControlLetter\npp$1.regexp_eatClassControlLetter = function(state) {\n  var ch = state.current();\n  if (isDecimalDigit(ch) || ch === 0x5F /* _ */) {\n    state.lastIntValue = ch % 0x20;\n    state.advance();\n    return true\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence\npp$1.regexp_eatHexEscapeSequence = function(state) {\n  var start = state.pos;\n  if (state.eat(0x78 /* x */)) {\n    if (this.regexp_eatFixedHexDigits(state, 2)) {\n      return true\n    }\n    if (state.switchU) {\n      state.raise(\"Invalid escape\");\n    }\n    state.pos = start;\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalDigits\npp$1.regexp_eatDecimalDigits = function(state) {\n  var start = state.pos;\n  var ch = 0;\n  state.lastIntValue = 0;\n  while (isDecimalDigit(ch = state.current())) {\n    state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);\n    state.advance();\n  }\n  return state.pos !== start\n};\nfunction isDecimalDigit(ch) {\n  return ch >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigits\npp$1.regexp_eatHexDigits = function(state) {\n  var start = state.pos;\n  var ch = 0;\n  state.lastIntValue = 0;\n  while (isHexDigit(ch = state.current())) {\n    state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);\n    state.advance();\n  }\n  return state.pos !== start\n};\nfunction isHexDigit(ch) {\n  return (\n    (ch >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */) ||\n    (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) ||\n    (ch >= 0x61 /* a */ && ch <= 0x66 /* f */)\n  )\n}\nfunction hexToInt(ch) {\n  if (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) {\n    return 10 + (ch - 0x41 /* A */)\n  }\n  if (ch >= 0x61 /* a */ && ch <= 0x66 /* f */) {\n    return 10 + (ch - 0x61 /* a */)\n  }\n  return ch - 0x30 /* 0 */\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-LegacyOctalEscapeSequence\n// Allows only 0-377(octal) i.e. 0-255(decimal).\npp$1.regexp_eatLegacyOctalEscapeSequence = function(state) {\n  if (this.regexp_eatOctalDigit(state)) {\n    var n1 = state.lastIntValue;\n    if (this.regexp_eatOctalDigit(state)) {\n      var n2 = state.lastIntValue;\n      if (n1 <= 3 && this.regexp_eatOctalDigit(state)) {\n        state.lastIntValue = n1 * 64 + n2 * 8 + state.lastIntValue;\n      } else {\n        state.lastIntValue = n1 * 8 + n2;\n      }\n    } else {\n      state.lastIntValue = n1;\n    }\n    return true\n  }\n  return false\n};\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-OctalDigit\npp$1.regexp_eatOctalDigit = function(state) {\n  var ch = state.current();\n  if (isOctalDigit(ch)) {\n    state.lastIntValue = ch - 0x30; /* 0 */\n    state.advance();\n    return true\n  }\n  state.lastIntValue = 0;\n  return false\n};\nfunction isOctalDigit(ch) {\n  return ch >= 0x30 /* 0 */ && ch <= 0x37 /* 7 */\n}\n\n// https://www.ecma-international.org/ecma-262/8.0/#prod-Hex4Digits\n// https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigit\n// And HexDigit HexDigit in https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence\npp$1.regexp_eatFixedHexDigits = function(state, length) {\n  var start = state.pos;\n  state.lastIntValue = 0;\n  for (var i = 0; i < length; ++i) {\n    var ch = state.current();\n    if (!isHexDigit(ch)) {\n      state.pos = start;\n      return false\n    }\n    state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);\n    state.advance();\n  }\n  return true\n};\n\n// Object type used to represent tokens. Note that normally, tokens\n// simply exist as properties on the parser object. This is only\n// used for the onToken callback and the external tokenizer.\n\nvar Token = function Token(p) {\n  this.type = p.type;\n  this.value = p.value;\n  this.start = p.start;\n  this.end = p.end;\n  if (p.options.locations)\n    { this.loc = new SourceLocation(p, p.startLoc, p.endLoc); }\n  if (p.options.ranges)\n    { this.range = [p.start, p.end]; }\n};\n\n// ## Tokenizer\n\nvar pp = Parser.prototype;\n\n// Move to the next token\n\npp.next = function(ignoreEscapeSequenceInKeyword) {\n  if (!ignoreEscapeSequenceInKeyword && this.type.keyword && this.containsEsc)\n    { this.raiseRecoverable(this.start, \"Escape sequence in keyword \" + this.type.keyword); }\n  if (this.options.onToken)\n    { this.options.onToken(new Token(this)); }\n\n  this.lastTokEnd = this.end;\n  this.lastTokStart = this.start;\n  this.lastTokEndLoc = this.endLoc;\n  this.lastTokStartLoc = this.startLoc;\n  this.nextToken();\n};\n\npp.getToken = function() {\n  this.next();\n  return new Token(this)\n};\n\n// If we're in an ES6 environment, make parsers iterable\nif (typeof Symbol !== \"undefined\")\n  { pp[Symbol.iterator] = function() {\n    var this$1$1 = this;\n\n    return {\n      next: function () {\n        var token = this$1$1.getToken();\n        return {\n          done: token.type === types$1.eof,\n          value: token\n        }\n      }\n    }\n  }; }\n\n// Toggle strict mode. Re-reads the next number or string to please\n// pedantic tests (`\"use strict\"; 010;` should fail).\n\n// Read a single token, updating the parser object's token-related\n// properties.\n\npp.nextToken = function() {\n  var curContext = this.curContext();\n  if (!curContext || !curContext.preserveSpace) { this.skipSpace(); }\n\n  this.start = this.pos;\n  if (this.options.locations) { this.startLoc = this.curPosition(); }\n  if (this.pos >= this.input.length) { return this.finishToken(types$1.eof) }\n\n  if (curContext.override) { return curContext.override(this) }\n  else { this.readToken(this.fullCharCodeAtPos()); }\n};\n\npp.readToken = function(code) {\n  // Identifier or keyword. '\\uXXXX' sequences are allowed in\n  // identifiers, so '\\' also dispatches to that.\n  if (isIdentifierStart(code, this.options.ecmaVersion >= 6) || code === 92 /* '\\' */)\n    { return this.readWord() }\n\n  return this.getTokenFromCode(code)\n};\n\npp.fullCharCodeAtPos = function() {\n  var code = this.input.charCodeAt(this.pos);\n  if (code <= 0xd7ff || code >= 0xdc00) { return code }\n  var next = this.input.charCodeAt(this.pos + 1);\n  return next <= 0xdbff || next >= 0xe000 ? code : (code << 10) + next - 0x35fdc00\n};\n\npp.skipBlockComment = function() {\n  var startLoc = this.options.onComment && this.curPosition();\n  var start = this.pos, end = this.input.indexOf(\"*/\", this.pos += 2);\n  if (end === -1) { this.raise(this.pos - 2, \"Unterminated comment\"); }\n  this.pos = end + 2;\n  if (this.options.locations) {\n    for (var nextBreak = (void 0), pos = start; (nextBreak = nextLineBreak(this.input, pos, this.pos)) > -1;) {\n      ++this.curLine;\n      pos = this.lineStart = nextBreak;\n    }\n  }\n  if (this.options.onComment)\n    { this.options.onComment(true, this.input.slice(start + 2, end), start, this.pos,\n                           startLoc, this.curPosition()); }\n};\n\npp.skipLineComment = function(startSkip) {\n  var start = this.pos;\n  var startLoc = this.options.onComment && this.curPosition();\n  var ch = this.input.charCodeAt(this.pos += startSkip);\n  while (this.pos < this.input.length && !isNewLine(ch)) {\n    ch = this.input.charCodeAt(++this.pos);\n  }\n  if (this.options.onComment)\n    { this.options.onComment(false, this.input.slice(start + startSkip, this.pos), start, this.pos,\n                           startLoc, this.curPosition()); }\n};\n\n// Called at the start of the parse and after every token. Skips\n// whitespace and comments, and.\n\npp.skipSpace = function() {\n  loop: while (this.pos < this.input.length) {\n    var ch = this.input.charCodeAt(this.pos);\n    switch (ch) {\n    case 32: case 160: // ' '\n      ++this.pos;\n      break\n    case 13:\n      if (this.input.charCodeAt(this.pos + 1) === 10) {\n        ++this.pos;\n      }\n    case 10: case 8232: case 8233:\n      ++this.pos;\n      if (this.options.locations) {\n        ++this.curLine;\n        this.lineStart = this.pos;\n      }\n      break\n    case 47: // '/'\n      switch (this.input.charCodeAt(this.pos + 1)) {\n      case 42: // '*'\n        this.skipBlockComment();\n        break\n      case 47:\n        this.skipLineComment(2);\n        break\n      default:\n        break loop\n      }\n      break\n    default:\n      if (ch > 8 && ch < 14 || ch >= 5760 && nonASCIIwhitespace.test(String.fromCharCode(ch))) {\n        ++this.pos;\n      } else {\n        break loop\n      }\n    }\n  }\n};\n\n// Called at the end of every token. Sets `end`, `val`, and\n// maintains `context` and `exprAllowed`, and skips the space after\n// the token, so that the next one's `start` will point at the\n// right position.\n\npp.finishToken = function(type, val) {\n  this.end = this.pos;\n  if (this.options.locations) { this.endLoc = this.curPosition(); }\n  var prevType = this.type;\n  this.type = type;\n  this.value = val;\n\n  this.updateContext(prevType);\n};\n\n// ### Token reading\n\n// This is the function that is called to fetch the next token. It\n// is somewhat obscure, because it works in character codes rather\n// than characters, and because operator parsing has been inlined\n// into it.\n//\n// All in the name of speed.\n//\npp.readToken_dot = function() {\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (next >= 48 && next <= 57) { return this.readNumber(true) }\n  var next2 = this.input.charCodeAt(this.pos + 2);\n  if (this.options.ecmaVersion >= 6 && next === 46 && next2 === 46) { // 46 = dot '.'\n    this.pos += 3;\n    return this.finishToken(types$1.ellipsis)\n  } else {\n    ++this.pos;\n    return this.finishToken(types$1.dot)\n  }\n};\n\npp.readToken_slash = function() { // '/'\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (this.exprAllowed) { ++this.pos; return this.readRegexp() }\n  if (next === 61) { return this.finishOp(types$1.assign, 2) }\n  return this.finishOp(types$1.slash, 1)\n};\n\npp.readToken_mult_modulo_exp = function(code) { // '%*'\n  var next = this.input.charCodeAt(this.pos + 1);\n  var size = 1;\n  var tokentype = code === 42 ? types$1.star : types$1.modulo;\n\n  // exponentiation operator ** and **=\n  if (this.options.ecmaVersion >= 7 && code === 42 && next === 42) {\n    ++size;\n    tokentype = types$1.starstar;\n    next = this.input.charCodeAt(this.pos + 2);\n  }\n\n  if (next === 61) { return this.finishOp(types$1.assign, size + 1) }\n  return this.finishOp(tokentype, size)\n};\n\npp.readToken_pipe_amp = function(code) { // '|&'\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (next === code) {\n    if (this.options.ecmaVersion >= 12) {\n      var next2 = this.input.charCodeAt(this.pos + 2);\n      if (next2 === 61) { return this.finishOp(types$1.assign, 3) }\n    }\n    return this.finishOp(code === 124 ? types$1.logicalOR : types$1.logicalAND, 2)\n  }\n  if (next === 61) { return this.finishOp(types$1.assign, 2) }\n  return this.finishOp(code === 124 ? types$1.bitwiseOR : types$1.bitwiseAND, 1)\n};\n\npp.readToken_caret = function() { // '^'\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (next === 61) { return this.finishOp(types$1.assign, 2) }\n  return this.finishOp(types$1.bitwiseXOR, 1)\n};\n\npp.readToken_plus_min = function(code) { // '+-'\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (next === code) {\n    if (next === 45 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 62 &&\n        (this.lastTokEnd === 0 || lineBreak.test(this.input.slice(this.lastTokEnd, this.pos)))) {\n      // A `-->` line comment\n      this.skipLineComment(3);\n      this.skipSpace();\n      return this.nextToken()\n    }\n    return this.finishOp(types$1.incDec, 2)\n  }\n  if (next === 61) { return this.finishOp(types$1.assign, 2) }\n  return this.finishOp(types$1.plusMin, 1)\n};\n\npp.readToken_lt_gt = function(code) { // '<>'\n  var next = this.input.charCodeAt(this.pos + 1);\n  var size = 1;\n  if (next === code) {\n    size = code === 62 && this.input.charCodeAt(this.pos + 2) === 62 ? 3 : 2;\n    if (this.input.charCodeAt(this.pos + size) === 61) { return this.finishOp(types$1.assign, size + 1) }\n    return this.finishOp(types$1.bitShift, size)\n  }\n  if (next === 33 && code === 60 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 45 &&\n      this.input.charCodeAt(this.pos + 3) === 45) {\n    // `<!--`, an XML-style comment that should be interpreted as a line comment\n    this.skipLineComment(4);\n    this.skipSpace();\n    return this.nextToken()\n  }\n  if (next === 61) { size = 2; }\n  return this.finishOp(types$1.relational, size)\n};\n\npp.readToken_eq_excl = function(code) { // '=!'\n  var next = this.input.charCodeAt(this.pos + 1);\n  if (next === 61) { return this.finishOp(types$1.equality, this.input.charCodeAt(this.pos + 2) === 61 ? 3 : 2) }\n  if (code === 61 && next === 62 && this.options.ecmaVersion >= 6) { // '=>'\n    this.pos += 2;\n    return this.finishToken(types$1.arrow)\n  }\n  return this.finishOp(code === 61 ? types$1.eq : types$1.prefix, 1)\n};\n\npp.readToken_question = function() { // '?'\n  var ecmaVersion = this.options.ecmaVersion;\n  if (ecmaVersion >= 11) {\n    var next = this.input.charCodeAt(this.pos + 1);\n    if (next === 46) {\n      var next2 = this.input.charCodeAt(this.pos + 2);\n      if (next2 < 48 || next2 > 57) { return this.finishOp(types$1.questionDot, 2) }\n    }\n    if (next === 63) {\n      if (ecmaVersion >= 12) {\n        var next2$1 = this.input.charCodeAt(this.pos + 2);\n        if (next2$1 === 61) { return this.finishOp(types$1.assign, 3) }\n      }\n      return this.finishOp(types$1.coalesce, 2)\n    }\n  }\n  return this.finishOp(types$1.question, 1)\n};\n\npp.readToken_numberSign = function() { // '#'\n  var ecmaVersion = this.options.ecmaVersion;\n  var code = 35; // '#'\n  if (ecmaVersion >= 13) {\n    ++this.pos;\n    code = this.fullCharCodeAtPos();\n    if (isIdentifierStart(code, true) || code === 92 /* '\\' */) {\n      return this.finishToken(types$1.privateId, this.readWord1())\n    }\n  }\n\n  this.raise(this.pos, \"Unexpected character '\" + codePointToString(code) + \"'\");\n};\n\npp.getTokenFromCode = function(code) {\n  switch (code) {\n  // The interpretation of a dot depends on whether it is followed\n  // by a digit or another two dots.\n  case 46: // '.'\n    return this.readToken_dot()\n\n  // Punctuation tokens.\n  case 40: ++this.pos; return this.finishToken(types$1.parenL)\n  case 41: ++this.pos; return this.finishToken(types$1.parenR)\n  case 59: ++this.pos; return this.finishToken(types$1.semi)\n  case 44: ++this.pos; return this.finishToken(types$1.comma)\n  case 91: ++this.pos; return this.finishToken(types$1.bracketL)\n  case 93: ++this.pos; return this.finishToken(types$1.bracketR)\n  case 123: ++this.pos; return this.finishToken(types$1.braceL)\n  case 125: ++this.pos; return this.finishToken(types$1.braceR)\n  case 58: ++this.pos; return this.finishToken(types$1.colon)\n\n  case 96: // '`'\n    if (this.options.ecmaVersion < 6) { break }\n    ++this.pos;\n    return this.finishToken(types$1.backQuote)\n\n  case 48: // '0'\n    var next = this.input.charCodeAt(this.pos + 1);\n    if (next === 120 || next === 88) { return this.readRadixNumber(16) } // '0x', '0X' - hex number\n    if (this.options.ecmaVersion >= 6) {\n      if (next === 111 || next === 79) { return this.readRadixNumber(8) } // '0o', '0O' - octal number\n      if (next === 98 || next === 66) { return this.readRadixNumber(2) } // '0b', '0B' - binary number\n    }\n\n  // Anything else beginning with a digit is an integer, octal\n  // number, or float.\n  case 49: case 50: case 51: case 52: case 53: case 54: case 55: case 56: case 57: // 1-9\n    return this.readNumber(false)\n\n  // Quotes produce strings.\n  case 34: case 39: // '\"', \"'\"\n    return this.readString(code)\n\n  // Operators are parsed inline in tiny state machines. '=' (61) is\n  // often referred to. `finishOp` simply skips the amount of\n  // characters it is given as second argument, and returns a token\n  // of the type given by its first argument.\n  case 47: // '/'\n    return this.readToken_slash()\n\n  case 37: case 42: // '%*'\n    return this.readToken_mult_modulo_exp(code)\n\n  case 124: case 38: // '|&'\n    return this.readToken_pipe_amp(code)\n\n  case 94: // '^'\n    return this.readToken_caret()\n\n  case 43: case 45: // '+-'\n    return this.readToken_plus_min(code)\n\n  case 60: case 62: // '<>'\n    return this.readToken_lt_gt(code)\n\n  case 61: case 33: // '=!'\n    return this.readToken_eq_excl(code)\n\n  case 63: // '?'\n    return this.readToken_question()\n\n  case 126: // '~'\n    return this.finishOp(types$1.prefix, 1)\n\n  case 35: // '#'\n    return this.readToken_numberSign()\n  }\n\n  this.raise(this.pos, \"Unexpected character '\" + codePointToString(code) + \"'\");\n};\n\npp.finishOp = function(type, size) {\n  var str = this.input.slice(this.pos, this.pos + size);\n  this.pos += size;\n  return this.finishToken(type, str)\n};\n\npp.readRegexp = function() {\n  var escaped, inClass, start = this.pos;\n  for (;;) {\n    if (this.pos >= this.input.length) { this.raise(start, \"Unterminated regular expression\"); }\n    var ch = this.input.charAt(this.pos);\n    if (lineBreak.test(ch)) { this.raise(start, \"Unterminated regular expression\"); }\n    if (!escaped) {\n      if (ch === \"[\") { inClass = true; }\n      else if (ch === \"]\" && inClass) { inClass = false; }\n      else if (ch === \"/\" && !inClass) { break }\n      escaped = ch === \"\\\\\";\n    } else { escaped = false; }\n    ++this.pos;\n  }\n  var pattern = this.input.slice(start, this.pos);\n  ++this.pos;\n  var flagsStart = this.pos;\n  var flags = this.readWord1();\n  if (this.containsEsc) { this.unexpected(flagsStart); }\n\n  // Validate pattern\n  var state = this.regexpState || (this.regexpState = new RegExpValidationState(this));\n  state.reset(start, pattern, flags);\n  this.validateRegExpFlags(state);\n  this.validateRegExpPattern(state);\n\n  // Create Literal#value property value.\n  var value = null;\n  try {\n    value = new RegExp(pattern, flags);\n  } catch (e) {\n    // ESTree requires null if it failed to instantiate RegExp object.\n    // https://github.com/estree/estree/blob/a27003adf4fd7bfad44de9cef372a2eacd527b1c/es5.md#regexpliteral\n  }\n\n  return this.finishToken(types$1.regexp, {pattern: pattern, flags: flags, value: value})\n};\n\n// Read an integer in the given radix. Return null if zero digits\n// were read, the integer value otherwise. When `len` is given, this\n// will return `null` unless the integer has exactly `len` digits.\n\npp.readInt = function(radix, len, maybeLegacyOctalNumericLiteral) {\n  // `len` is used for character escape sequences. In that case, disallow separators.\n  var allowSeparators = this.options.ecmaVersion >= 12 && len === undefined;\n\n  // `maybeLegacyOctalNumericLiteral` is true if it doesn't have prefix (0x,0o,0b)\n  // and isn't fraction part nor exponent part. In that case, if the first digit\n  // is zero then disallow separators.\n  var isLegacyOctalNumericLiteral = maybeLegacyOctalNumericLiteral && this.input.charCodeAt(this.pos) === 48;\n\n  var start = this.pos, total = 0, lastCode = 0;\n  for (var i = 0, e = len == null ? Infinity : len; i < e; ++i, ++this.pos) {\n    var code = this.input.charCodeAt(this.pos), val = (void 0);\n\n    if (allowSeparators && code === 95) {\n      if (isLegacyOctalNumericLiteral) { this.raiseRecoverable(this.pos, \"Numeric separator is not allowed in legacy octal numeric literals\"); }\n      if (lastCode === 95) { this.raiseRecoverable(this.pos, \"Numeric separator must be exactly one underscore\"); }\n      if (i === 0) { this.raiseRecoverable(this.pos, \"Numeric separator is not allowed at the first of digits\"); }\n      lastCode = code;\n      continue\n    }\n\n    if (code >= 97) { val = code - 97 + 10; } // a\n    else if (code >= 65) { val = code - 65 + 10; } // A\n    else if (code >= 48 && code <= 57) { val = code - 48; } // 0-9\n    else { val = Infinity; }\n    if (val >= radix) { break }\n    lastCode = code;\n    total = total * radix + val;\n  }\n\n  if (allowSeparators && lastCode === 95) { this.raiseRecoverable(this.pos - 1, \"Numeric separator is not allowed at the last of digits\"); }\n  if (this.pos === start || len != null && this.pos - start !== len) { return null }\n\n  return total\n};\n\nfunction stringToNumber(str, isLegacyOctalNumericLiteral) {\n  if (isLegacyOctalNumericLiteral) {\n    return parseInt(str, 8)\n  }\n\n  // `parseFloat(value)` stops parsing at the first numeric separator then returns a wrong value.\n  return parseFloat(str.replace(/_/g, \"\"))\n}\n\nfunction stringToBigInt(str) {\n  if (typeof BigInt !== \"function\") {\n    return null\n  }\n\n  // `BigInt(value)` throws syntax error if the string contains numeric separators.\n  return BigInt(str.replace(/_/g, \"\"))\n}\n\npp.readRadixNumber = function(radix) {\n  var start = this.pos;\n  this.pos += 2; // 0x\n  var val = this.readInt(radix);\n  if (val == null) { this.raise(this.start + 2, \"Expected number in radix \" + radix); }\n  if (this.options.ecmaVersion >= 11 && this.input.charCodeAt(this.pos) === 110) {\n    val = stringToBigInt(this.input.slice(start, this.pos));\n    ++this.pos;\n  } else if (isIdentifierStart(this.fullCharCodeAtPos())) { this.raise(this.pos, \"Identifier directly after number\"); }\n  return this.finishToken(types$1.num, val)\n};\n\n// Read an integer, octal integer, or floating-point number.\n\npp.readNumber = function(startsWithDot) {\n  var start = this.pos;\n  if (!startsWithDot && this.readInt(10, undefined, true) === null) { this.raise(start, \"Invalid number\"); }\n  var octal = this.pos - start >= 2 && this.input.charCodeAt(start) === 48;\n  if (octal && this.strict) { this.raise(start, \"Invalid number\"); }\n  var next = this.input.charCodeAt(this.pos);\n  if (!octal && !startsWithDot && this.options.ecmaVersion >= 11 && next === 110) {\n    var val$1 = stringToBigInt(this.input.slice(start, this.pos));\n    ++this.pos;\n    if (isIdentifierStart(this.fullCharCodeAtPos())) { this.raise(this.pos, \"Identifier directly after number\"); }\n    return this.finishToken(types$1.num, val$1)\n  }\n  if (octal && /[89]/.test(this.input.slice(start, this.pos))) { octal = false; }\n  if (next === 46 && !octal) { // '.'\n    ++this.pos;\n    this.readInt(10);\n    next = this.input.charCodeAt(this.pos);\n  }\n  if ((next === 69 || next === 101) && !octal) { // 'eE'\n    next = this.input.charCodeAt(++this.pos);\n    if (next === 43 || next === 45) { ++this.pos; } // '+-'\n    if (this.readInt(10) === null) { this.raise(start, \"Invalid number\"); }\n  }\n  if (isIdentifierStart(this.fullCharCodeAtPos())) { this.raise(this.pos, \"Identifier directly after number\"); }\n\n  var val = stringToNumber(this.input.slice(start, this.pos), octal);\n  return this.finishToken(types$1.num, val)\n};\n\n// Read a string value, interpreting backslash-escapes.\n\npp.readCodePoint = function() {\n  var ch = this.input.charCodeAt(this.pos), code;\n\n  if (ch === 123) { // '{'\n    if (this.options.ecmaVersion < 6) { this.unexpected(); }\n    var codePos = ++this.pos;\n    code = this.readHexChar(this.input.indexOf(\"}\", this.pos) - this.pos);\n    ++this.pos;\n    if (code > 0x10FFFF) { this.invalidStringToken(codePos, \"Code point out of bounds\"); }\n  } else {\n    code = this.readHexChar(4);\n  }\n  return code\n};\n\npp.readString = function(quote) {\n  var out = \"\", chunkStart = ++this.pos;\n  for (;;) {\n    if (this.pos >= this.input.length) { this.raise(this.start, \"Unterminated string constant\"); }\n    var ch = this.input.charCodeAt(this.pos);\n    if (ch === quote) { break }\n    if (ch === 92) { // '\\'\n      out += this.input.slice(chunkStart, this.pos);\n      out += this.readEscapedChar(false);\n      chunkStart = this.pos;\n    } else if (ch === 0x2028 || ch === 0x2029) {\n      if (this.options.ecmaVersion < 10) { this.raise(this.start, \"Unterminated string constant\"); }\n      ++this.pos;\n      if (this.options.locations) {\n        this.curLine++;\n        this.lineStart = this.pos;\n      }\n    } else {\n      if (isNewLine(ch)) { this.raise(this.start, \"Unterminated string constant\"); }\n      ++this.pos;\n    }\n  }\n  out += this.input.slice(chunkStart, this.pos++);\n  return this.finishToken(types$1.string, out)\n};\n\n// Reads template string tokens.\n\nvar INVALID_TEMPLATE_ESCAPE_ERROR = {};\n\npp.tryReadTemplateToken = function() {\n  this.inTemplateElement = true;\n  try {\n    this.readTmplToken();\n  } catch (err) {\n    if (err === INVALID_TEMPLATE_ESCAPE_ERROR) {\n      this.readInvalidTemplateToken();\n    } else {\n      throw err\n    }\n  }\n\n  this.inTemplateElement = false;\n};\n\npp.invalidStringToken = function(position, message) {\n  if (this.inTemplateElement && this.options.ecmaVersion >= 9) {\n    throw INVALID_TEMPLATE_ESCAPE_ERROR\n  } else {\n    this.raise(position, message);\n  }\n};\n\npp.readTmplToken = function() {\n  var out = \"\", chunkStart = this.pos;\n  for (;;) {\n    if (this.pos >= this.input.length) { this.raise(this.start, \"Unterminated template\"); }\n    var ch = this.input.charCodeAt(this.pos);\n    if (ch === 96 || ch === 36 && this.input.charCodeAt(this.pos + 1) === 123) { // '`', '${'\n      if (this.pos === this.start && (this.type === types$1.template || this.type === types$1.invalidTemplate)) {\n        if (ch === 36) {\n          this.pos += 2;\n          return this.finishToken(types$1.dollarBraceL)\n        } else {\n          ++this.pos;\n          return this.finishToken(types$1.backQuote)\n        }\n      }\n      out += this.input.slice(chunkStart, this.pos);\n      return this.finishToken(types$1.template, out)\n    }\n    if (ch === 92) { // '\\'\n      out += this.input.slice(chunkStart, this.pos);\n      out += this.readEscapedChar(true);\n      chunkStart = this.pos;\n    } else if (isNewLine(ch)) {\n      out += this.input.slice(chunkStart, this.pos);\n      ++this.pos;\n      switch (ch) {\n      case 13:\n        if (this.input.charCodeAt(this.pos) === 10) { ++this.pos; }\n      case 10:\n        out += \"\\n\";\n        break\n      default:\n        out += String.fromCharCode(ch);\n        break\n      }\n      if (this.options.locations) {\n        ++this.curLine;\n        this.lineStart = this.pos;\n      }\n      chunkStart = this.pos;\n    } else {\n      ++this.pos;\n    }\n  }\n};\n\n// Reads a template token to search for the end, without validating any escape sequences\npp.readInvalidTemplateToken = function() {\n  for (; this.pos < this.input.length; this.pos++) {\n    switch (this.input[this.pos]) {\n    case \"\\\\\":\n      ++this.pos;\n      break\n\n    case \"$\":\n      if (this.input[this.pos + 1] !== \"{\") {\n        break\n      }\n\n    // falls through\n    case \"`\":\n      return this.finishToken(types$1.invalidTemplate, this.input.slice(this.start, this.pos))\n\n    // no default\n    }\n  }\n  this.raise(this.start, \"Unterminated template\");\n};\n\n// Used to read escaped characters\n\npp.readEscapedChar = function(inTemplate) {\n  var ch = this.input.charCodeAt(++this.pos);\n  ++this.pos;\n  switch (ch) {\n  case 110: return \"\\n\" // 'n' -> '\\n'\n  case 114: return \"\\r\" // 'r' -> '\\r'\n  case 120: return String.fromCharCode(this.readHexChar(2)) // 'x'\n  case 117: return codePointToString(this.readCodePoint()) // 'u'\n  case 116: return \"\\t\" // 't' -> '\\t'\n  case 98: return \"\\b\" // 'b' -> '\\b'\n  case 118: return \"\\u000b\" // 'v' -> '\\u000b'\n  case 102: return \"\\f\" // 'f' -> '\\f'\n  case 13: if (this.input.charCodeAt(this.pos) === 10) { ++this.pos; } // '\\r\\n'\n  case 10: // ' \\n'\n    if (this.options.locations) { this.lineStart = this.pos; ++this.curLine; }\n    return \"\"\n  case 56:\n  case 57:\n    if (this.strict) {\n      this.invalidStringToken(\n        this.pos - 1,\n        \"Invalid escape sequence\"\n      );\n    }\n    if (inTemplate) {\n      var codePos = this.pos - 1;\n\n      this.invalidStringToken(\n        codePos,\n        \"Invalid escape sequence in template string\"\n      );\n    }\n  default:\n    if (ch >= 48 && ch <= 55) {\n      var octalStr = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0];\n      var octal = parseInt(octalStr, 8);\n      if (octal > 255) {\n        octalStr = octalStr.slice(0, -1);\n        octal = parseInt(octalStr, 8);\n      }\n      this.pos += octalStr.length - 1;\n      ch = this.input.charCodeAt(this.pos);\n      if ((octalStr !== \"0\" || ch === 56 || ch === 57) && (this.strict || inTemplate)) {\n        this.invalidStringToken(\n          this.pos - 1 - octalStr.length,\n          inTemplate\n            ? \"Octal literal in template string\"\n            : \"Octal literal in strict mode\"\n        );\n      }\n      return String.fromCharCode(octal)\n    }\n    if (isNewLine(ch)) {\n      // Unicode new line characters after \\ get removed from output in both\n      // template literals and strings\n      return \"\"\n    }\n    return String.fromCharCode(ch)\n  }\n};\n\n// Used to read character escape sequences ('\\x', '\\u', '\\U').\n\npp.readHexChar = function(len) {\n  var codePos = this.pos;\n  var n = this.readInt(16, len);\n  if (n === null) { this.invalidStringToken(codePos, \"Bad character escape sequence\"); }\n  return n\n};\n\n// Read an identifier, and return it as a string. Sets `this.containsEsc`\n// to whether the word contained a '\\u' escape.\n//\n// Incrementally adds only escaped chars, adding other chunks as-is\n// as a micro-optimization.\n\npp.readWord1 = function() {\n  this.containsEsc = false;\n  var word = \"\", first = true, chunkStart = this.pos;\n  var astral = this.options.ecmaVersion >= 6;\n  while (this.pos < this.input.length) {\n    var ch = this.fullCharCodeAtPos();\n    if (isIdentifierChar(ch, astral)) {\n      this.pos += ch <= 0xffff ? 1 : 2;\n    } else if (ch === 92) { // \"\\\"\n      this.containsEsc = true;\n      word += this.input.slice(chunkStart, this.pos);\n      var escStart = this.pos;\n      if (this.input.charCodeAt(++this.pos) !== 117) // \"u\"\n        { this.invalidStringToken(this.pos, \"Expecting Unicode escape sequence \\\\uXXXX\"); }\n      ++this.pos;\n      var esc = this.readCodePoint();\n      if (!(first ? isIdentifierStart : isIdentifierChar)(esc, astral))\n        { this.invalidStringToken(escStart, \"Invalid Unicode escape\"); }\n      word += codePointToString(esc);\n      chunkStart = this.pos;\n    } else {\n      break\n    }\n    first = false;\n  }\n  return word + this.input.slice(chunkStart, this.pos)\n};\n\n// Read an identifier or keyword token. Will check for reserved\n// words when necessary.\n\npp.readWord = function() {\n  var word = this.readWord1();\n  var type = types$1.name;\n  if (this.keywords.test(word)) {\n    type = keywords[word];\n  }\n  return this.finishToken(type, word)\n};\n\n// Acorn is a tiny, fast JavaScript parser written in JavaScript.\n//\n// Acorn was written by Marijn Haverbeke, Ingvar Stepanyan, and\n// various contributors and released under an MIT license.\n//\n// Git repositories for Acorn are available at\n//\n//     http://marijnhaverbeke.nl/git/acorn\n//     https://github.com/acornjs/acorn.git\n//\n// Please use the [github bug tracker][ghbt] to report issues.\n//\n// [ghbt]: https://github.com/acornjs/acorn/issues\n//\n// [walk]: util/walk.js\n\n\nvar version = \"8.10.0\";\n\nParser.acorn = {\n  Parser: Parser,\n  version: version,\n  defaultOptions: defaultOptions,\n  Position: Position,\n  SourceLocation: SourceLocation,\n  getLineInfo: getLineInfo,\n  Node: Node,\n  TokenType: TokenType,\n  tokTypes: types$1,\n  keywordTypes: keywords,\n  TokContext: TokContext,\n  tokContexts: types,\n  isIdentifierChar: isIdentifierChar,\n  isIdentifierStart: isIdentifierStart,\n  Token: Token,\n  isNewLine: isNewLine,\n  lineBreak: lineBreak,\n  lineBreakG: lineBreakG,\n  nonASCIIwhitespace: nonASCIIwhitespace\n};\n\n// The main exported interface (under `self.acorn` when in the\n// browser) is a `parse` function that takes a code string and\n// returns an abstract syntax tree as specified by [Mozilla parser\n// API][api].\n//\n// [api]: https://developer.mozilla.org/en-US/docs/SpiderMonkey/Parser_API\n\nfunction parse(input, options) {\n  return Parser.parse(input, options)\n}\n\n// This function tries to parse a single expression at a given\n// offset in a string. Useful for parsing mixed-language formats\n// that embed JavaScript expressions.\n\nfunction parseExpressionAt(input, pos, options) {\n  return Parser.parseExpressionAt(input, pos, options)\n}\n\n// Acorn is organized as a tokenizer and a recursive-descent parser.\n// The `tokenizer` export provides an interface to the tokenizer.\n\nfunction tokenizer(input, options) {\n  return Parser.tokenizer(input, options)\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/acorn/dist/acorn.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/Arrow.dom.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/Arrow.dom.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ArrowType: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.ArrowType),\n/* harmony export */   AsyncByteQueue: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.AsyncByteQueue),\n/* harmony export */   AsyncByteStream: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.AsyncByteStream),\n/* harmony export */   AsyncMessageReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.AsyncMessageReader),\n/* harmony export */   AsyncRecordBatchFileReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.AsyncRecordBatchFileReader),\n/* harmony export */   AsyncRecordBatchStreamReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.AsyncRecordBatchStreamReader),\n/* harmony export */   BaseVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BaseVector),\n/* harmony export */   Binary: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Binary),\n/* harmony export */   BinaryBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BinaryBuilder),\n/* harmony export */   BinaryVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BinaryVector),\n/* harmony export */   Bool: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Bool),\n/* harmony export */   BoolBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BoolBuilder),\n/* harmony export */   BoolVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BoolVector),\n/* harmony export */   BufferType: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.BufferType),\n/* harmony export */   Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Builder),\n/* harmony export */   ByteStream: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.ByteStream),\n/* harmony export */   Chunked: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Chunked),\n/* harmony export */   Column: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Column),\n/* harmony export */   CountByResult: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.CountByResult),\n/* harmony export */   Data: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Data),\n/* harmony export */   DataFrame: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DataFrame),\n/* harmony export */   DataType: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DataType),\n/* harmony export */   DateBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateBuilder),\n/* harmony export */   DateDay: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateDay),\n/* harmony export */   DateDayBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateDayBuilder),\n/* harmony export */   DateDayVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateDayVector),\n/* harmony export */   DateMillisecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateMillisecond),\n/* harmony export */   DateMillisecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateMillisecondBuilder),\n/* harmony export */   DateMillisecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateMillisecondVector),\n/* harmony export */   DateUnit: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateUnit),\n/* harmony export */   DateVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DateVector),\n/* harmony export */   Date_: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Date_),\n/* harmony export */   Decimal: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Decimal),\n/* harmony export */   DecimalBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DecimalBuilder),\n/* harmony export */   DecimalVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DecimalVector),\n/* harmony export */   DenseUnion: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DenseUnion),\n/* harmony export */   DenseUnionBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DenseUnionBuilder),\n/* harmony export */   DenseUnionVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DenseUnionVector),\n/* harmony export */   Dictionary: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Dictionary),\n/* harmony export */   DictionaryBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DictionaryBuilder),\n/* harmony export */   DictionaryVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.DictionaryVector),\n/* harmony export */   Field: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Field),\n/* harmony export */   FilteredDataFrame: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FilteredDataFrame),\n/* harmony export */   FixedSizeBinary: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinary),\n/* harmony export */   FixedSizeBinaryBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinaryBuilder),\n/* harmony export */   FixedSizeBinaryVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinaryVector),\n/* harmony export */   FixedSizeList: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeList),\n/* harmony export */   FixedSizeListBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeListBuilder),\n/* harmony export */   FixedSizeListVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FixedSizeListVector),\n/* harmony export */   Float: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float),\n/* harmony export */   Float16: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float16),\n/* harmony export */   Float16Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float16Builder),\n/* harmony export */   Float16Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float16Vector),\n/* harmony export */   Float32: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float32),\n/* harmony export */   Float32Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float32Builder),\n/* harmony export */   Float32Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float32Vector),\n/* harmony export */   Float64: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float64),\n/* harmony export */   Float64Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float64Builder),\n/* harmony export */   Float64Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Float64Vector),\n/* harmony export */   FloatBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FloatBuilder),\n/* harmony export */   FloatVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.FloatVector),\n/* harmony export */   Int: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int),\n/* harmony export */   Int16: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int16),\n/* harmony export */   Int16Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int16Builder),\n/* harmony export */   Int16Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int16Vector),\n/* harmony export */   Int32: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int32),\n/* harmony export */   Int32Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int32Builder),\n/* harmony export */   Int32Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int32Vector),\n/* harmony export */   Int64: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int64),\n/* harmony export */   Int64Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int64Builder),\n/* harmony export */   Int64Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int64Vector),\n/* harmony export */   Int8: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int8),\n/* harmony export */   Int8Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int8Builder),\n/* harmony export */   Int8Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Int8Vector),\n/* harmony export */   IntBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntBuilder),\n/* harmony export */   IntVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntVector),\n/* harmony export */   Interval: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Interval),\n/* harmony export */   IntervalBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalBuilder),\n/* harmony export */   IntervalDayTime: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalDayTime),\n/* harmony export */   IntervalDayTimeBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalDayTimeBuilder),\n/* harmony export */   IntervalDayTimeVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalDayTimeVector),\n/* harmony export */   IntervalUnit: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalUnit),\n/* harmony export */   IntervalVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalVector),\n/* harmony export */   IntervalYearMonth: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalYearMonth),\n/* harmony export */   IntervalYearMonthBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalYearMonthBuilder),\n/* harmony export */   IntervalYearMonthVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.IntervalYearMonthVector),\n/* harmony export */   JSONMessageReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.JSONMessageReader),\n/* harmony export */   List: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.List),\n/* harmony export */   ListBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.ListBuilder),\n/* harmony export */   ListVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.ListVector),\n/* harmony export */   MapBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.MapBuilder),\n/* harmony export */   MapVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.MapVector),\n/* harmony export */   Map_: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Map_),\n/* harmony export */   Message: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Message),\n/* harmony export */   MessageHeader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.MessageHeader),\n/* harmony export */   MessageReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.MessageReader),\n/* harmony export */   MetadataVersion: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.MetadataVersion),\n/* harmony export */   Null: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Null),\n/* harmony export */   NullBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.NullBuilder),\n/* harmony export */   NullVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.NullVector),\n/* harmony export */   Precision: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Precision),\n/* harmony export */   RecordBatch: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatch),\n/* harmony export */   RecordBatchFileReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchFileReader),\n/* harmony export */   RecordBatchFileWriter: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchFileWriter),\n/* harmony export */   RecordBatchJSONWriter: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchJSONWriter),\n/* harmony export */   RecordBatchReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchReader),\n/* harmony export */   RecordBatchStreamReader: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchStreamReader),\n/* harmony export */   RecordBatchStreamWriter: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchStreamWriter),\n/* harmony export */   RecordBatchWriter: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.RecordBatchWriter),\n/* harmony export */   Schema: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Schema),\n/* harmony export */   SparseUnion: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.SparseUnion),\n/* harmony export */   SparseUnionBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.SparseUnionBuilder),\n/* harmony export */   SparseUnionVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.SparseUnionVector),\n/* harmony export */   Struct: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Struct),\n/* harmony export */   StructBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.StructBuilder),\n/* harmony export */   StructVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.StructVector),\n/* harmony export */   Table: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Table),\n/* harmony export */   Time: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Time),\n/* harmony export */   TimeBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeBuilder),\n/* harmony export */   TimeMicrosecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMicrosecond),\n/* harmony export */   TimeMicrosecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMicrosecondBuilder),\n/* harmony export */   TimeMicrosecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMicrosecondVector),\n/* harmony export */   TimeMillisecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMillisecond),\n/* harmony export */   TimeMillisecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMillisecondBuilder),\n/* harmony export */   TimeMillisecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeMillisecondVector),\n/* harmony export */   TimeNanosecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeNanosecond),\n/* harmony export */   TimeNanosecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeNanosecondBuilder),\n/* harmony export */   TimeNanosecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeNanosecondVector),\n/* harmony export */   TimeSecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeSecond),\n/* harmony export */   TimeSecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeSecondBuilder),\n/* harmony export */   TimeSecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeSecondVector),\n/* harmony export */   TimeUnit: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeUnit),\n/* harmony export */   TimeVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimeVector),\n/* harmony export */   Timestamp: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Timestamp),\n/* harmony export */   TimestampBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampBuilder),\n/* harmony export */   TimestampMicrosecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMicrosecond),\n/* harmony export */   TimestampMicrosecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMicrosecondBuilder),\n/* harmony export */   TimestampMicrosecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMicrosecondVector),\n/* harmony export */   TimestampMillisecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMillisecond),\n/* harmony export */   TimestampMillisecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMillisecondBuilder),\n/* harmony export */   TimestampMillisecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampMillisecondVector),\n/* harmony export */   TimestampNanosecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampNanosecond),\n/* harmony export */   TimestampNanosecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampNanosecondBuilder),\n/* harmony export */   TimestampNanosecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampNanosecondVector),\n/* harmony export */   TimestampSecond: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampSecond),\n/* harmony export */   TimestampSecondBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampSecondBuilder),\n/* harmony export */   TimestampSecondVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampSecondVector),\n/* harmony export */   TimestampVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.TimestampVector),\n/* harmony export */   Type: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Type),\n/* harmony export */   Uint16: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint16),\n/* harmony export */   Uint16Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint16Builder),\n/* harmony export */   Uint16Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint16Vector),\n/* harmony export */   Uint32: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint32),\n/* harmony export */   Uint32Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint32Builder),\n/* harmony export */   Uint32Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint32Vector),\n/* harmony export */   Uint64: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint64),\n/* harmony export */   Uint64Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint64Builder),\n/* harmony export */   Uint64Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint64Vector),\n/* harmony export */   Uint8: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint8),\n/* harmony export */   Uint8Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint8Builder),\n/* harmony export */   Uint8Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Uint8Vector),\n/* harmony export */   Union: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Union),\n/* harmony export */   UnionBuilder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.UnionBuilder),\n/* harmony export */   UnionMode: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.UnionMode),\n/* harmony export */   UnionVector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.UnionVector),\n/* harmony export */   Utf8: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Utf8),\n/* harmony export */   Utf8Builder: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Utf8Builder),\n/* harmony export */   Utf8Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Utf8Vector),\n/* harmony export */   Vector: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Vector),\n/* harmony export */   Visitor: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.Visitor),\n/* harmony export */   predicate: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.predicate),\n/* harmony export */   util: () => (/* reexport safe */ _Arrow__WEBPACK_IMPORTED_MODULE_8__.util)\n/* harmony export */ });\n/* harmony import */ var _io_adapters__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./io/adapters */ \"../../node_modules/apache-arrow/io/adapters.mjs\");\n/* harmony import */ var _builder_index__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./builder/index */ \"../../node_modules/apache-arrow/builder/index.mjs\");\n/* harmony import */ var _ipc_reader__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ipc/reader */ \"../../node_modules/apache-arrow/ipc/reader.mjs\");\n/* harmony import */ var _ipc_writer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./ipc/writer */ \"../../node_modules/apache-arrow/ipc/writer.mjs\");\n/* harmony import */ var _io_whatwg_iterable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./io/whatwg/iterable */ \"../../node_modules/apache-arrow/io/whatwg/iterable.mjs\");\n/* harmony import */ var _io_whatwg_builder__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./io/whatwg/builder */ \"../../node_modules/apache-arrow/io/whatwg/builder.mjs\");\n/* harmony import */ var _io_whatwg_reader__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./io/whatwg/reader */ \"../../node_modules/apache-arrow/io/whatwg/reader.mjs\");\n/* harmony import */ var _io_whatwg_writer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./io/whatwg/writer */ \"../../node_modules/apache-arrow/io/whatwg/writer.mjs\");\n/* harmony import */ var _Arrow__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Arrow */ \"../../node_modules/apache-arrow/Arrow.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n_io_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].toDOMStream = _io_whatwg_iterable__WEBPACK_IMPORTED_MODULE_4__.toDOMStream;\n_builder_index__WEBPACK_IMPORTED_MODULE_1__.Builder['throughDOM'] = _io_whatwg_builder__WEBPACK_IMPORTED_MODULE_5__.builderThroughDOMStream;\n_ipc_reader__WEBPACK_IMPORTED_MODULE_2__.RecordBatchReader['throughDOM'] = _io_whatwg_reader__WEBPACK_IMPORTED_MODULE_6__.recordBatchReaderThroughDOMStream;\n_ipc_writer__WEBPACK_IMPORTED_MODULE_3__.RecordBatchWriter['throughDOM'] = _io_whatwg_writer__WEBPACK_IMPORTED_MODULE_7__.recordBatchWriterThroughDOMStream;\n\n\n//# sourceMappingURL=Arrow.dom.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/Arrow.dom.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/Arrow.mjs":
/*!*************************************************!*\
  !*** ../../node_modules/apache-arrow/Arrow.mjs ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ArrowType: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.ArrowType),\n/* harmony export */   AsyncByteQueue: () => (/* reexport safe */ _io_stream__WEBPACK_IMPORTED_MODULE_9__.AsyncByteQueue),\n/* harmony export */   AsyncByteStream: () => (/* reexport safe */ _io_stream__WEBPACK_IMPORTED_MODULE_9__.AsyncByteStream),\n/* harmony export */   AsyncMessageReader: () => (/* reexport safe */ _ipc_message__WEBPACK_IMPORTED_MODULE_12__.AsyncMessageReader),\n/* harmony export */   AsyncRecordBatchFileReader: () => (/* reexport safe */ _ipc_reader__WEBPACK_IMPORTED_MODULE_10__.AsyncRecordBatchFileReader),\n/* harmony export */   AsyncRecordBatchStreamReader: () => (/* reexport safe */ _ipc_reader__WEBPACK_IMPORTED_MODULE_10__.AsyncRecordBatchStreamReader),\n/* harmony export */   BaseVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.BaseVector),\n/* harmony export */   Binary: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Binary),\n/* harmony export */   BinaryBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.BinaryBuilder),\n/* harmony export */   BinaryVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.BinaryVector),\n/* harmony export */   Bool: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Bool),\n/* harmony export */   BoolBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.BoolBuilder),\n/* harmony export */   BoolVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.BoolVector),\n/* harmony export */   BufferType: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.BufferType),\n/* harmony export */   Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Builder),\n/* harmony export */   ByteStream: () => (/* reexport safe */ _io_stream__WEBPACK_IMPORTED_MODULE_9__.ByteStream),\n/* harmony export */   Chunked: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Chunked),\n/* harmony export */   Column: () => (/* reexport safe */ _column__WEBPACK_IMPORTED_MODULE_4__.Column),\n/* harmony export */   CountByResult: () => (/* reexport safe */ _compute_dataframe__WEBPACK_IMPORTED_MODULE_15__.CountByResult),\n/* harmony export */   Data: () => (/* reexport safe */ _data__WEBPACK_IMPORTED_MODULE_1__.Data),\n/* harmony export */   DataFrame: () => (/* reexport safe */ _compute_dataframe__WEBPACK_IMPORTED_MODULE_15__.DataFrame),\n/* harmony export */   DataType: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.DataType),\n/* harmony export */   DateBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DateBuilder),\n/* harmony export */   DateDay: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.DateDay),\n/* harmony export */   DateDayBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DateDayBuilder),\n/* harmony export */   DateDayVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DateDayVector),\n/* harmony export */   DateMillisecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.DateMillisecond),\n/* harmony export */   DateMillisecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DateMillisecondBuilder),\n/* harmony export */   DateMillisecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DateMillisecondVector),\n/* harmony export */   DateUnit: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.DateUnit),\n/* harmony export */   DateVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DateVector),\n/* harmony export */   Date_: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Date_),\n/* harmony export */   Decimal: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Decimal),\n/* harmony export */   DecimalBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DecimalBuilder),\n/* harmony export */   DecimalVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DecimalVector),\n/* harmony export */   DenseUnion: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.DenseUnion),\n/* harmony export */   DenseUnionBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DenseUnionBuilder),\n/* harmony export */   DenseUnionVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DenseUnionVector),\n/* harmony export */   Dictionary: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Dictionary),\n/* harmony export */   DictionaryBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.DictionaryBuilder),\n/* harmony export */   DictionaryVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.DictionaryVector),\n/* harmony export */   Field: () => (/* reexport safe */ _schema__WEBPACK_IMPORTED_MODULE_6__.Field),\n/* harmony export */   FilteredDataFrame: () => (/* reexport safe */ _compute_dataframe__WEBPACK_IMPORTED_MODULE_15__.FilteredDataFrame),\n/* harmony export */   FixedSizeBinary: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.FixedSizeBinary),\n/* harmony export */   FixedSizeBinaryBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinaryBuilder),\n/* harmony export */   FixedSizeBinaryVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.FixedSizeBinaryVector),\n/* harmony export */   FixedSizeList: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.FixedSizeList),\n/* harmony export */   FixedSizeListBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.FixedSizeListBuilder),\n/* harmony export */   FixedSizeListVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.FixedSizeListVector),\n/* harmony export */   Float: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Float),\n/* harmony export */   Float16: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Float16),\n/* harmony export */   Float16Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Float16Builder),\n/* harmony export */   Float16Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Float16Vector),\n/* harmony export */   Float32: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Float32),\n/* harmony export */   Float32Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Float32Builder),\n/* harmony export */   Float32Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Float32Vector),\n/* harmony export */   Float64: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Float64),\n/* harmony export */   Float64Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Float64Builder),\n/* harmony export */   Float64Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Float64Vector),\n/* harmony export */   FloatBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.FloatBuilder),\n/* harmony export */   FloatVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.FloatVector),\n/* harmony export */   Int: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Int),\n/* harmony export */   Int16: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Int16),\n/* harmony export */   Int16Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Int16Builder),\n/* harmony export */   Int16Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Int16Vector),\n/* harmony export */   Int32: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Int32),\n/* harmony export */   Int32Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Int32Builder),\n/* harmony export */   Int32Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Int32Vector),\n/* harmony export */   Int64: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Int64),\n/* harmony export */   Int64Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Int64Builder),\n/* harmony export */   Int64Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Int64Vector),\n/* harmony export */   Int8: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Int8),\n/* harmony export */   Int8Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Int8Builder),\n/* harmony export */   Int8Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Int8Vector),\n/* harmony export */   IntBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.IntBuilder),\n/* harmony export */   IntVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.IntVector),\n/* harmony export */   Interval: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Interval),\n/* harmony export */   IntervalBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.IntervalBuilder),\n/* harmony export */   IntervalDayTime: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.IntervalDayTime),\n/* harmony export */   IntervalDayTimeBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.IntervalDayTimeBuilder),\n/* harmony export */   IntervalDayTimeVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.IntervalDayTimeVector),\n/* harmony export */   IntervalUnit: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.IntervalUnit),\n/* harmony export */   IntervalVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.IntervalVector),\n/* harmony export */   IntervalYearMonth: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.IntervalYearMonth),\n/* harmony export */   IntervalYearMonthBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.IntervalYearMonthBuilder),\n/* harmony export */   IntervalYearMonthVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.IntervalYearMonthVector),\n/* harmony export */   JSONMessageReader: () => (/* reexport safe */ _ipc_message__WEBPACK_IMPORTED_MODULE_12__.JSONMessageReader),\n/* harmony export */   List: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.List),\n/* harmony export */   ListBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.ListBuilder),\n/* harmony export */   ListVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.ListVector),\n/* harmony export */   MapBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.MapBuilder),\n/* harmony export */   MapVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.MapVector),\n/* harmony export */   Map_: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Map_),\n/* harmony export */   Message: () => (/* reexport safe */ _ipc_metadata_message__WEBPACK_IMPORTED_MODULE_13__.Message),\n/* harmony export */   MessageHeader: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader),\n/* harmony export */   MessageReader: () => (/* reexport safe */ _ipc_message__WEBPACK_IMPORTED_MODULE_12__.MessageReader),\n/* harmony export */   MetadataVersion: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.MetadataVersion),\n/* harmony export */   Null: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Null),\n/* harmony export */   NullBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.NullBuilder),\n/* harmony export */   NullVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.NullVector),\n/* harmony export */   Precision: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.Precision),\n/* harmony export */   RecordBatch: () => (/* reexport safe */ _recordbatch__WEBPACK_IMPORTED_MODULE_14__.RecordBatch),\n/* harmony export */   RecordBatchFileReader: () => (/* reexport safe */ _ipc_reader__WEBPACK_IMPORTED_MODULE_10__.RecordBatchFileReader),\n/* harmony export */   RecordBatchFileWriter: () => (/* reexport safe */ _ipc_writer__WEBPACK_IMPORTED_MODULE_11__.RecordBatchFileWriter),\n/* harmony export */   RecordBatchJSONWriter: () => (/* reexport safe */ _ipc_writer__WEBPACK_IMPORTED_MODULE_11__.RecordBatchJSONWriter),\n/* harmony export */   RecordBatchReader: () => (/* reexport safe */ _ipc_reader__WEBPACK_IMPORTED_MODULE_10__.RecordBatchReader),\n/* harmony export */   RecordBatchStreamReader: () => (/* reexport safe */ _ipc_reader__WEBPACK_IMPORTED_MODULE_10__.RecordBatchStreamReader),\n/* harmony export */   RecordBatchStreamWriter: () => (/* reexport safe */ _ipc_writer__WEBPACK_IMPORTED_MODULE_11__.RecordBatchStreamWriter),\n/* harmony export */   RecordBatchWriter: () => (/* reexport safe */ _ipc_writer__WEBPACK_IMPORTED_MODULE_11__.RecordBatchWriter),\n/* harmony export */   Schema: () => (/* reexport safe */ _schema__WEBPACK_IMPORTED_MODULE_6__.Schema),\n/* harmony export */   SparseUnion: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.SparseUnion),\n/* harmony export */   SparseUnionBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.SparseUnionBuilder),\n/* harmony export */   SparseUnionVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.SparseUnionVector),\n/* harmony export */   Struct: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Struct),\n/* harmony export */   StructBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.StructBuilder),\n/* harmony export */   StructVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.StructVector),\n/* harmony export */   Table: () => (/* reexport safe */ _table__WEBPACK_IMPORTED_MODULE_3__.Table),\n/* harmony export */   Time: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Time),\n/* harmony export */   TimeBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimeBuilder),\n/* harmony export */   TimeMicrosecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimeMicrosecond),\n/* harmony export */   TimeMicrosecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimeMicrosecondBuilder),\n/* harmony export */   TimeMicrosecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimeMicrosecondVector),\n/* harmony export */   TimeMillisecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimeMillisecond),\n/* harmony export */   TimeMillisecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimeMillisecondBuilder),\n/* harmony export */   TimeMillisecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimeMillisecondVector),\n/* harmony export */   TimeNanosecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimeNanosecond),\n/* harmony export */   TimeNanosecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimeNanosecondBuilder),\n/* harmony export */   TimeNanosecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimeNanosecondVector),\n/* harmony export */   TimeSecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimeSecond),\n/* harmony export */   TimeSecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimeSecondBuilder),\n/* harmony export */   TimeSecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimeSecondVector),\n/* harmony export */   TimeUnit: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.TimeUnit),\n/* harmony export */   TimeVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimeVector),\n/* harmony export */   Timestamp: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Timestamp),\n/* harmony export */   TimestampBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimestampBuilder),\n/* harmony export */   TimestampMicrosecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimestampMicrosecond),\n/* harmony export */   TimestampMicrosecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimestampMicrosecondBuilder),\n/* harmony export */   TimestampMicrosecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimestampMicrosecondVector),\n/* harmony export */   TimestampMillisecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimestampMillisecond),\n/* harmony export */   TimestampMillisecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimestampMillisecondBuilder),\n/* harmony export */   TimestampMillisecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimestampMillisecondVector),\n/* harmony export */   TimestampNanosecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimestampNanosecond),\n/* harmony export */   TimestampNanosecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimestampNanosecondBuilder),\n/* harmony export */   TimestampNanosecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimestampNanosecondVector),\n/* harmony export */   TimestampSecond: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.TimestampSecond),\n/* harmony export */   TimestampSecondBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.TimestampSecondBuilder),\n/* harmony export */   TimestampSecondVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimestampSecondVector),\n/* harmony export */   TimestampVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.TimestampVector),\n/* harmony export */   Type: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.Type),\n/* harmony export */   Uint16: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Uint16),\n/* harmony export */   Uint16Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Uint16Builder),\n/* harmony export */   Uint16Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Uint16Vector),\n/* harmony export */   Uint32: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Uint32),\n/* harmony export */   Uint32Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Uint32Builder),\n/* harmony export */   Uint32Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Uint32Vector),\n/* harmony export */   Uint64: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Uint64),\n/* harmony export */   Uint64Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Uint64Builder),\n/* harmony export */   Uint64Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Uint64Vector),\n/* harmony export */   Uint8: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Uint8),\n/* harmony export */   Uint8Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Uint8Builder),\n/* harmony export */   Uint8Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Uint8Vector),\n/* harmony export */   Union: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Union),\n/* harmony export */   UnionBuilder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.UnionBuilder),\n/* harmony export */   UnionMode: () => (/* reexport safe */ _enum__WEBPACK_IMPORTED_MODULE_0__.UnionMode),\n/* harmony export */   UnionVector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.UnionVector),\n/* harmony export */   Utf8: () => (/* reexport safe */ _type__WEBPACK_IMPORTED_MODULE_2__.Utf8),\n/* harmony export */   Utf8Builder: () => (/* reexport safe */ _builder_index__WEBPACK_IMPORTED_MODULE_8__.Utf8Builder),\n/* harmony export */   Utf8Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Utf8Vector),\n/* harmony export */   Vector: () => (/* reexport safe */ _vector_index__WEBPACK_IMPORTED_MODULE_7__.Vector),\n/* harmony export */   Visitor: () => (/* reexport safe */ _visitor__WEBPACK_IMPORTED_MODULE_5__.Visitor),\n/* harmony export */   predicate: () => (/* reexport module object */ _compute_predicate__WEBPACK_IMPORTED_MODULE_22__),\n/* harmony export */   util: () => (/* binding */ util)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./table */ \"../../node_modules/apache-arrow/table.mjs\");\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./column */ \"../../node_modules/apache-arrow/column.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _vector_index__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./vector/index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n/* harmony import */ var _builder_index__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./builder/index */ \"../../node_modules/apache-arrow/builder/index.mjs\");\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _ipc_reader__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./ipc/reader */ \"../../node_modules/apache-arrow/ipc/reader.mjs\");\n/* harmony import */ var _ipc_writer__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./ipc/writer */ \"../../node_modules/apache-arrow/ipc/writer.mjs\");\n/* harmony import */ var _ipc_message__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./ipc/message */ \"../../node_modules/apache-arrow/ipc/message.mjs\");\n/* harmony import */ var _ipc_metadata_message__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./ipc/metadata/message */ \"../../node_modules/apache-arrow/ipc/metadata/message.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _compute_dataframe__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./compute/dataframe */ \"../../node_modules/apache-arrow/compute/dataframe.mjs\");\n/* harmony import */ var _util_bn__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./util/bn */ \"../../node_modules/apache-arrow/util/bn.mjs\");\n/* harmony import */ var _util_int__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./util/int */ \"../../node_modules/apache-arrow/util/int.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_math__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./util/math */ \"../../node_modules/apache-arrow/util/math.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _util_vector__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./util/vector */ \"../../node_modules/apache-arrow/util/vector.mjs\");\n/* harmony import */ var _compute_predicate__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./compute/predicate */ \"../../node_modules/apache-arrow/compute/predicate.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/** @ignore */\nconst util = {\n    ..._util_bn__WEBPACK_IMPORTED_MODULE_16__,\n    ..._util_int__WEBPACK_IMPORTED_MODULE_17__,\n    ..._util_bit__WEBPACK_IMPORTED_MODULE_18__,\n    ..._util_math__WEBPACK_IMPORTED_MODULE_19__,\n    ..._util_buffer__WEBPACK_IMPORTED_MODULE_20__,\n    ..._util_vector__WEBPACK_IMPORTED_MODULE_21__\n};\n\n//# sourceMappingURL=Arrow.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/Arrow.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/builder.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Builder: () => (/* binding */ Builder),\n/* harmony export */   FixedWidthBuilder: () => (/* binding */ FixedWidthBuilder),\n/* harmony export */   VariableWidthBuilder: () => (/* binding */ VariableWidthBuilder)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _builder_valid__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./builder/valid */ \"../../node_modules/apache-arrow/builder/valid.mjs\");\n/* harmony import */ var _builder_buffer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./builder/buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n/**\n * An abstract base class for types that construct Arrow Vectors from arbitrary JavaScript values.\n *\n * A `Builder` is responsible for writing arbitrary JavaScript values\n * to ArrayBuffers and/or child Builders according to the Arrow specification\n * for each DataType, creating or resizing the underlying ArrayBuffers as necessary.\n *\n * The `Builder` for each Arrow `DataType` handles converting and appending\n * values for a given `DataType`. The high-level {@link Builder.new `Builder.new()`} convenience\n * method creates the specific `Builder` subclass for the supplied `DataType`.\n *\n * Once created, `Builder` instances support both appending values to the end\n * of the `Builder`, and random-access writes to specific indices\n * (`Builder.prototype.append(value)` is a convenience method for\n * `builder.set(builder.length, value)`). Appending or setting values beyond the\n * Builder's current length may cause the builder to grow its underlying buffers\n * or child Builders (if applicable) to accommodate the new values.\n *\n * After enough values have been written to a `Builder`, `Builder.prototype.flush()`\n * will commit the values to the underlying ArrayBuffers (or child Builders). The\n * internal Builder state will be reset, and an instance of `Data<T>` is returned.\n * Alternatively, `Builder.prototype.toVector()` will flush the `Builder` and return\n * an instance of `Vector<T>` instead.\n *\n * When there are no more values to write, use `Builder.prototype.finish()` to\n * finalize the `Builder`. This does not reset the internal state, so it is\n * necessary to call `Builder.prototype.flush()` or `toVector()` one last time\n * if there are still values queued to be flushed.\n *\n * Note: calling `Builder.prototype.finish()` is required when using a `DictionaryBuilder`,\n * because this is when it flushes the values that have been enqueued in its internal\n * dictionary's `Builder`, and creates the `dictionaryVector` for the `Dictionary` `DataType`.\n *\n * ```ts\n * import { Builder, Utf8 } from 'apache-arrow';\n *\n * const utf8Builder = Builder.new({\n *     type: new Utf8(),\n *     nullValues: [null, 'n/a']\n * });\n *\n * utf8Builder\n *     .append('hello')\n *     .append('n/a')\n *     .append('world')\n *     .append(null);\n *\n * const utf8Vector = utf8Builder.finish().toVector();\n *\n * console.log(utf8Vector.toJSON());\n * // > [\"hello\", null, \"world\", null]\n * ```\n *\n * @typeparam T The `DataType` of this `Builder`.\n * @typeparam TNull The type(s) of values which will be considered null-value sentinels.\n */\nclass Builder {\n    /**\n     * Construct a builder with the given Arrow DataType with optional null values,\n     * which will be interpreted as \"null\" when set or appended to the `Builder`.\n     * @param {{ type: T, nullValues?: any[] }} options A `BuilderOptions` object used to create this `Builder`.\n     */\n    constructor({ 'type': type, 'nullValues': nulls }) {\n        /**\n         * The number of values written to the `Builder` that haven't been flushed yet.\n         * @readonly\n         */\n        this.length = 0;\n        /**\n         * A boolean indicating whether `Builder.prototype.finish()` has been called on this `Builder`.\n         * @readonly\n         */\n        this.finished = false;\n        this.type = type;\n        this.children = [];\n        this.nullValues = nulls;\n        this.stride = (0,_type__WEBPACK_IMPORTED_MODULE_5__.strideForType)(type);\n        this._nulls = new _builder_buffer__WEBPACK_IMPORTED_MODULE_4__.BitmapBufferBuilder();\n        if (nulls && nulls.length > 0) {\n            this._isValid = (0,_builder_valid__WEBPACK_IMPORTED_MODULE_3__.createIsValidFunction)(nulls);\n        }\n    }\n    /**\n     * Create a `Builder` instance based on the `type` property of the supplied `options` object.\n     * @param {BuilderOptions<T, TNull>} options An object with a required `DataType` instance\n     * and other optional parameters to be passed to the `Builder` subclass for the given `type`.\n     *\n     * @typeparam T The `DataType` of the `Builder` to create.\n     * @typeparam TNull The type(s) of values which will be considered null-value sentinels.\n     * @nocollapse\n     */\n    // @ts-ignore\n    static new(options) { }\n    /** @nocollapse */\n    // @ts-ignore\n    static throughNode(options) {\n        throw new Error(`\"throughNode\" not available in this environment`);\n    }\n    /** @nocollapse */\n    // @ts-ignore\n    static throughDOM(options) {\n        throw new Error(`\"throughDOM\" not available in this environment`);\n    }\n    /**\n     * Transform a synchronous `Iterable` of arbitrary JavaScript values into a\n     * sequence of Arrow Vector<T> following the chunking semantics defined in\n     * the supplied `options` argument.\n     *\n     * This function returns a function that accepts an `Iterable` of values to\n     * transform. When called, this function returns an Iterator of `Vector<T>`.\n     *\n     * The resulting `Iterator<Vector<T>>` yields Vectors based on the\n     * `queueingStrategy` and `highWaterMark` specified in the `options` argument.\n     *\n     * * If `queueingStrategy` is `\"count\"` (or omitted), The `Iterator<Vector<T>>`\n     *   will flush the underlying `Builder` (and yield a new `Vector<T>`) once the\n     *   Builder's `length` reaches or exceeds the supplied `highWaterMark`.\n     * * If `queueingStrategy` is `\"bytes\"`, the `Iterator<Vector<T>>` will flush\n     *   the underlying `Builder` (and yield a new `Vector<T>`) once its `byteLength`\n     *   reaches or exceeds the supplied `highWaterMark`.\n     *\n     * @param {IterableBuilderOptions<T, TNull>} options An object of properties which determine the `Builder` to create and the chunking semantics to use.\n     * @returns A function which accepts a JavaScript `Iterable` of values to\n     *          write, and returns an `Iterator` that yields Vectors according\n     *          to the chunking semantics defined in the `options` argument.\n     * @nocollapse\n     */\n    static throughIterable(options) {\n        return throughIterable(options);\n    }\n    /**\n     * Transform an `AsyncIterable` of arbitrary JavaScript values into a\n     * sequence of Arrow Vector<T> following the chunking semantics defined in\n     * the supplied `options` argument.\n     *\n     * This function returns a function that accepts an `AsyncIterable` of values to\n     * transform. When called, this function returns an AsyncIterator of `Vector<T>`.\n     *\n     * The resulting `AsyncIterator<Vector<T>>` yields Vectors based on the\n     * `queueingStrategy` and `highWaterMark` specified in the `options` argument.\n     *\n     * * If `queueingStrategy` is `\"count\"` (or omitted), The `AsyncIterator<Vector<T>>`\n     *   will flush the underlying `Builder` (and yield a new `Vector<T>`) once the\n     *   Builder's `length` reaches or exceeds the supplied `highWaterMark`.\n     * * If `queueingStrategy` is `\"bytes\"`, the `AsyncIterator<Vector<T>>` will flush\n     *   the underlying `Builder` (and yield a new `Vector<T>`) once its `byteLength`\n     *   reaches or exceeds the supplied `highWaterMark`.\n     *\n     * @param {IterableBuilderOptions<T, TNull>} options An object of properties which determine the `Builder` to create and the chunking semantics to use.\n     * @returns A function which accepts a JavaScript `AsyncIterable` of values\n     *          to write, and returns an `AsyncIterator` that yields Vectors\n     *          according to the chunking semantics defined in the `options`\n     *          argument.\n     * @nocollapse\n     */\n    static throughAsyncIterable(options) {\n        return throughAsyncIterable(options);\n    }\n    /**\n     * Flush the `Builder` and return a `Vector<T>`.\n     * @returns {Vector<T>} A `Vector<T>` of the flushed values.\n     */\n    toVector() { return _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new(this.flush()); }\n    get ArrayType() { return this.type.ArrayType; }\n    get nullCount() { return this._nulls.numInvalid; }\n    get numChildren() { return this.children.length; }\n    /**\n     * @returns The aggregate length (in bytes) of the values that have been written.\n     */\n    get byteLength() {\n        let size = 0;\n        this._offsets && (size += this._offsets.byteLength);\n        this._values && (size += this._values.byteLength);\n        this._nulls && (size += this._nulls.byteLength);\n        this._typeIds && (size += this._typeIds.byteLength);\n        return this.children.reduce((size, child) => size + child.byteLength, size);\n    }\n    /**\n     * @returns The aggregate number of rows that have been reserved to write new values.\n     */\n    get reservedLength() {\n        return this._nulls.reservedLength;\n    }\n    /**\n     * @returns The aggregate length (in bytes) that has been reserved to write new values.\n     */\n    get reservedByteLength() {\n        let size = 0;\n        this._offsets && (size += this._offsets.reservedByteLength);\n        this._values && (size += this._values.reservedByteLength);\n        this._nulls && (size += this._nulls.reservedByteLength);\n        this._typeIds && (size += this._typeIds.reservedByteLength);\n        return this.children.reduce((size, child) => size + child.reservedByteLength, size);\n    }\n    get valueOffsets() { return this._offsets ? this._offsets.buffer : null; }\n    get values() { return this._values ? this._values.buffer : null; }\n    get nullBitmap() { return this._nulls ? this._nulls.buffer : null; }\n    get typeIds() { return this._typeIds ? this._typeIds.buffer : null; }\n    /**\n     * Appends a value (or null) to this `Builder`.\n     * This is equivalent to `builder.set(builder.length, value)`.\n     * @param {T['TValue'] | TNull } value The value to append.\n     */\n    append(value) { return this.set(this.length, value); }\n    /**\n     * Validates whether a value is valid (true), or null (false)\n     * @param {T['TValue'] | TNull } value The value to compare against null the value representations\n     */\n    // @ts-ignore\n    isValid(value) { return this._isValid(value); }\n    /**\n     * Write a value (or null-value sentinel) at the supplied index.\n     * If the value matches one of the null-value representations, a 1-bit is\n     * written to the null `BitmapBufferBuilder`. Otherwise, a 0 is written to\n     * the null `BitmapBufferBuilder`, and the value is passed to\n     * `Builder.prototype.setValue()`.\n     * @param {number} index The index of the value to write.\n     * @param {T['TValue'] | TNull } value The value to write at the supplied index.\n     * @returns {this} The updated `Builder` instance.\n     */\n    set(index, value) {\n        if (this.setValid(index, this.isValid(value))) {\n            this.setValue(index, value);\n        }\n        return this;\n    }\n    /**\n     * Write a value to the underlying buffers at the supplied index, bypassing\n     * the null-value check. This is a low-level method that\n     * @param {number} index\n     * @param {T['TValue'] | TNull } value\n     */\n    // @ts-ignore\n    setValue(index, value) { this._setValue(this, index, value); }\n    setValid(index, valid) {\n        this.length = this._nulls.set(index, +valid).length;\n        return valid;\n    }\n    // @ts-ignore\n    addChild(child, name = `${this.numChildren}`) {\n        throw new Error(`Cannot append children to non-nested type \"${this.type}\"`);\n    }\n    /**\n     * Retrieve the child `Builder` at the supplied `index`, or null if no child\n     * exists at that index.\n     * @param {number} index The index of the child `Builder` to retrieve.\n     * @returns {Builder | null} The child Builder at the supplied index or null.\n     */\n    getChildAt(index) {\n        return this.children[index] || null;\n    }\n    /**\n     * Commit all the values that have been written to their underlying\n     * ArrayBuffers, including any child Builders if applicable, and reset\n     * the internal `Builder` state.\n     * @returns A `Data<T>` of the buffers and childData representing the values written.\n     */\n    flush() {\n        const buffers = [];\n        const values = this._values;\n        const offsets = this._offsets;\n        const typeIds = this._typeIds;\n        const { length, nullCount } = this;\n        if (typeIds) { /* Unions */\n            buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.TYPE] = typeIds.flush(length);\n            // DenseUnions\n            offsets && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] = offsets.flush(length));\n        }\n        else if (offsets) { /* Variable-width primitives (Binary, Utf8) and Lists */\n            // Binary, Utf8\n            values && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] = values.flush(offsets.last()));\n            buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] = offsets.flush(length);\n        }\n        else if (values) { /* Fixed-width primitives (Int, Float, Decimal, Time, Timestamp, and Interval) */\n            buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] = values.flush(length);\n        }\n        nullCount > 0 && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY] = this._nulls.flush(length));\n        const data = _data__WEBPACK_IMPORTED_MODULE_2__.Data.new(this.type, 0, length, nullCount, buffers, this.children.map((child) => child.flush()));\n        this.clear();\n        return data;\n    }\n    /**\n     * Finalize this `Builder`, and child builders if applicable.\n     * @returns {this} The finalized `Builder` instance.\n     */\n    finish() {\n        this.finished = true;\n        this.children.forEach((child) => child.finish());\n        return this;\n    }\n    /**\n     * Clear this Builder's internal state, including child Builders if applicable, and reset the length to 0.\n     * @returns {this} The cleared `Builder` instance.\n     */\n    clear() {\n        this.length = 0;\n        this._offsets && (this._offsets.clear());\n        this._values && (this._values.clear());\n        this._nulls && (this._nulls.clear());\n        this._typeIds && (this._typeIds.clear());\n        this.children.forEach((child) => child.clear());\n        return this;\n    }\n}\nBuilder.prototype.length = 1;\nBuilder.prototype.stride = 1;\nBuilder.prototype.children = null;\nBuilder.prototype.finished = false;\nBuilder.prototype.nullValues = null;\nBuilder.prototype._isValid = () => true;\n/** @ignore */\nclass FixedWidthBuilder extends Builder {\n    constructor(opts) {\n        super(opts);\n        this._values = new _builder_buffer__WEBPACK_IMPORTED_MODULE_4__.DataBufferBuilder(new this.ArrayType(0), this.stride);\n    }\n    setValue(index, value) {\n        const values = this._values;\n        values.reserve(index - values.length + 1);\n        return super.setValue(index, value);\n    }\n}\n/** @ignore */\nclass VariableWidthBuilder extends Builder {\n    constructor(opts) {\n        super(opts);\n        this._pendingLength = 0;\n        this._offsets = new _builder_buffer__WEBPACK_IMPORTED_MODULE_4__.OffsetsBufferBuilder();\n    }\n    setValue(index, value) {\n        const pending = this._pending || (this._pending = new Map());\n        const current = pending.get(index);\n        current && (this._pendingLength -= current.length);\n        this._pendingLength += value.length;\n        pending.set(index, value);\n    }\n    setValid(index, isValid) {\n        if (!super.setValid(index, isValid)) {\n            (this._pending || (this._pending = new Map())).set(index, undefined);\n            return false;\n        }\n        return true;\n    }\n    clear() {\n        this._pendingLength = 0;\n        this._pending = undefined;\n        return super.clear();\n    }\n    flush() {\n        this._flush();\n        return super.flush();\n    }\n    finish() {\n        this._flush();\n        return super.finish();\n    }\n    _flush() {\n        const pending = this._pending;\n        const pendingLength = this._pendingLength;\n        this._pendingLength = 0;\n        this._pending = undefined;\n        if (pending && pending.size > 0) {\n            this._flushPending(pending, pendingLength);\n        }\n        return this;\n    }\n}\n/** @ignore */\nfunction throughIterable(options) {\n    const { ['queueingStrategy']: queueingStrategy = 'count' } = options;\n    const { ['highWaterMark']: highWaterMark = queueingStrategy !== 'bytes' ? 1000 : 2 ** 14 } = options;\n    const sizeProperty = queueingStrategy !== 'bytes' ? 'length' : 'byteLength';\n    return function* (source) {\n        let numChunks = 0;\n        let builder = Builder.new(options);\n        for (const value of source) {\n            if (builder.append(value)[sizeProperty] >= highWaterMark) {\n                ++numChunks && (yield builder.toVector());\n            }\n        }\n        if (builder.finish().length > 0 || numChunks === 0) {\n            yield builder.toVector();\n        }\n    };\n}\n/** @ignore */\nfunction throughAsyncIterable(options) {\n    const { ['queueingStrategy']: queueingStrategy = 'count' } = options;\n    const { ['highWaterMark']: highWaterMark = queueingStrategy !== 'bytes' ? 1000 : 2 ** 14 } = options;\n    const sizeProperty = queueingStrategy !== 'bytes' ? 'length' : 'byteLength';\n    return async function* (source) {\n        let numChunks = 0;\n        let builder = Builder.new(options);\n        for await (const value of source) {\n            if (builder.append(value)[sizeProperty] >= highWaterMark) {\n                ++numChunks && (yield builder.toVector());\n            }\n        }\n        if (builder.finish().length > 0 || numChunks === 0) {\n            yield builder.toVector();\n        }\n    };\n}\n\n//# sourceMappingURL=builder.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/binary.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/binary.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BinaryBuilder: () => (/* binding */ BinaryBuilder)\n/* harmony export */ });\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass BinaryBuilder extends _builder__WEBPACK_IMPORTED_MODULE_2__.VariableWidthBuilder {\n    constructor(opts) {\n        super(opts);\n        this._values = new _buffer__WEBPACK_IMPORTED_MODULE_1__.BufferBuilder(new Uint8Array(0));\n    }\n    get byteLength() {\n        let size = this._pendingLength + (this.length * 4);\n        this._offsets && (size += this._offsets.byteLength);\n        this._values && (size += this._values.byteLength);\n        this._nulls && (size += this._nulls.byteLength);\n        return size;\n    }\n    setValue(index, value) {\n        return super.setValue(index, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(value));\n    }\n    _flushPending(pending, pendingLength) {\n        const offsets = this._offsets;\n        const data = this._values.reserve(pendingLength).buffer;\n        let index = 0, length = 0, offset = 0, value;\n        for ([index, value] of pending) {\n            if (value === undefined) {\n                offsets.set(index, 0);\n            }\n            else {\n                length = value.length;\n                data.set(value, offset);\n                offsets.set(index, length);\n                offset += length;\n            }\n        }\n    }\n}\n\n//# sourceMappingURL=binary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/binary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/bool.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/bool.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BoolBuilder: () => (/* binding */ BoolBuilder)\n/* harmony export */ });\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nclass BoolBuilder extends _builder__WEBPACK_IMPORTED_MODULE_1__.Builder {\n    constructor(options) {\n        super(options);\n        this._values = new _buffer__WEBPACK_IMPORTED_MODULE_0__.BitmapBufferBuilder();\n    }\n    setValue(index, value) {\n        this._values.set(index, +value);\n    }\n}\n\n//# sourceMappingURL=bool.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/bool.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/buffer.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/buffer.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BitmapBufferBuilder: () => (/* binding */ BitmapBufferBuilder),\n/* harmony export */   BufferBuilder: () => (/* binding */ BufferBuilder),\n/* harmony export */   DataBufferBuilder: () => (/* binding */ DataBufferBuilder),\n/* harmony export */   OffsetsBufferBuilder: () => (/* binding */ OffsetsBufferBuilder),\n/* harmony export */   WideBufferBuilder: () => (/* binding */ WideBufferBuilder)\n/* harmony export */ });\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nconst roundLengthUpToNearest64Bytes = (len, BPE) => ((((len * BPE) + 63) & ~63) || 64) / BPE;\n/** @ignore */\nconst sliceOrExtendArray = (arr, len = 0) => (arr.length >= len ? arr.subarray(0, len) : (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.memcpy)(new arr.constructor(len), arr, 0));\n/** @ignore */\nclass BufferBuilder {\n    constructor(buffer, stride = 1) {\n        this.buffer = buffer;\n        this.stride = stride;\n        this.BYTES_PER_ELEMENT = buffer.BYTES_PER_ELEMENT;\n        this.ArrayType = buffer.constructor;\n        this._resize(this.length = buffer.length / stride | 0);\n    }\n    get byteLength() { return this.length * this.stride * this.BYTES_PER_ELEMENT | 0; }\n    get reservedLength() { return this.buffer.length / this.stride; }\n    get reservedByteLength() { return this.buffer.byteLength; }\n    // @ts-ignore\n    set(index, value) { return this; }\n    append(value) { return this.set(this.length, value); }\n    reserve(extra) {\n        if (extra > 0) {\n            this.length += extra;\n            const stride = this.stride;\n            const length = this.length * stride;\n            const reserved = this.buffer.length;\n            if (length >= reserved) {\n                this._resize(reserved === 0\n                    ? roundLengthUpToNearest64Bytes(length * 1, this.BYTES_PER_ELEMENT)\n                    : roundLengthUpToNearest64Bytes(length * 2, this.BYTES_PER_ELEMENT));\n            }\n        }\n        return this;\n    }\n    flush(length = this.length) {\n        length = roundLengthUpToNearest64Bytes(length * this.stride, this.BYTES_PER_ELEMENT);\n        const array = sliceOrExtendArray(this.buffer, length);\n        this.clear();\n        return array;\n    }\n    clear() {\n        this.length = 0;\n        this._resize(0);\n        return this;\n    }\n    _resize(newLength) {\n        return this.buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.memcpy)(new this.ArrayType(newLength), this.buffer);\n    }\n}\nBufferBuilder.prototype.offset = 0;\n/** @ignore */\nclass DataBufferBuilder extends BufferBuilder {\n    last() { return this.get(this.length - 1); }\n    get(index) { return this.buffer[index]; }\n    set(index, value) {\n        this.reserve(index - this.length + 1);\n        this.buffer[index * this.stride] = value;\n        return this;\n    }\n}\n/** @ignore */\nclass BitmapBufferBuilder extends DataBufferBuilder {\n    constructor(data = new Uint8Array(0)) {\n        super(data, 1 / 8);\n        this.numValid = 0;\n    }\n    get numInvalid() { return this.length - this.numValid; }\n    get(idx) { return this.buffer[idx >> 3] >> idx % 8 & 1; }\n    set(idx, val) {\n        const { buffer } = this.reserve(idx - this.length + 1);\n        const byte = idx >> 3, bit = idx % 8, cur = buffer[byte] >> bit & 1;\n        // If `val` is truthy and the current bit is 0, flip it to 1 and increment `numValid`.\n        // If `val` is falsey and the current bit is 1, flip it to 0 and decrement `numValid`.\n        val ? cur === 0 && ((buffer[byte] |= (1 << bit)), ++this.numValid)\n            : cur === 1 && ((buffer[byte] &= ~(1 << bit)), --this.numValid);\n        return this;\n    }\n    clear() {\n        this.numValid = 0;\n        return super.clear();\n    }\n}\n/** @ignore */\nclass OffsetsBufferBuilder extends DataBufferBuilder {\n    constructor(data = new Int32Array(1)) { super(data, 1); }\n    append(value) {\n        return this.set(this.length - 1, value);\n    }\n    set(index, value) {\n        const offset = this.length - 1;\n        const buffer = this.reserve(index - offset + 1).buffer;\n        if (offset < index++) {\n            buffer.fill(buffer[offset], offset, index);\n        }\n        buffer[index] = buffer[index - 1] + value;\n        return this;\n    }\n    flush(length = this.length - 1) {\n        if (length > this.length) {\n            this.set(length - 1, 0);\n        }\n        return super.flush(length + 1);\n    }\n}\n/** @ignore */\nclass WideBufferBuilder extends BufferBuilder {\n    get ArrayType64() {\n        return this._ArrayType64 || (this._ArrayType64 = (this.buffer instanceof Int32Array ? _util_compat__WEBPACK_IMPORTED_MODULE_1__.BigInt64Array : _util_compat__WEBPACK_IMPORTED_MODULE_1__.BigUint64Array));\n    }\n    set(index, value) {\n        this.reserve(index - this.length + 1);\n        switch (typeof value) {\n            case 'bigint':\n                this.buffer64[index] = value;\n                break;\n            case 'number':\n                this.buffer[index * this.stride] = value;\n                break;\n            default: this.buffer.set(value, index * this.stride);\n        }\n        return this;\n    }\n    _resize(newLength) {\n        const data = super._resize(newLength);\n        const length = data.byteLength / (this.BYTES_PER_ELEMENT * this.stride);\n        if (_util_compat__WEBPACK_IMPORTED_MODULE_1__.BigIntAvailable) {\n            this.buffer64 = new this.ArrayType64(data.buffer, data.byteOffset, length);\n        }\n        return data;\n    }\n}\n\n//# sourceMappingURL=buffer.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/buffer.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/date.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/date.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DateBuilder: () => (/* binding */ DateBuilder),\n/* harmony export */   DateDayBuilder: () => (/* binding */ DateDayBuilder),\n/* harmony export */   DateMillisecondBuilder: () => (/* binding */ DateMillisecondBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass DateBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n/** @ignore */\nclass DateDayBuilder extends DateBuilder {\n}\n/** @ignore */\nclass DateMillisecondBuilder extends DateBuilder {\n}\n\n//# sourceMappingURL=date.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/date.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/decimal.mjs":
/*!***********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/decimal.mjs ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DecimalBuilder: () => (/* binding */ DecimalBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass DecimalBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n\n//# sourceMappingURL=decimal.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/decimal.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/dictionary.mjs":
/*!**************************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/dictionary.mjs ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DictionaryBuilder: () => (/* binding */ DictionaryBuilder)\n/* harmony export */ });\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nclass DictionaryBuilder extends _builder__WEBPACK_IMPORTED_MODULE_1__.Builder {\n    constructor({ 'type': type, 'nullValues': nulls, 'dictionaryHashFunction': hashFn }) {\n        super({ type: new _type__WEBPACK_IMPORTED_MODULE_0__.Dictionary(type.dictionary, type.indices, type.id, type.isOrdered) });\n        this._nulls = null;\n        this._dictionaryOffset = 0;\n        this._keysToIndices = Object.create(null);\n        this.indices = _builder__WEBPACK_IMPORTED_MODULE_1__.Builder.new({ 'type': this.type.indices, 'nullValues': nulls });\n        this.dictionary = _builder__WEBPACK_IMPORTED_MODULE_1__.Builder.new({ 'type': this.type.dictionary, 'nullValues': null });\n        if (typeof hashFn === 'function') {\n            this.valueToKey = hashFn;\n        }\n    }\n    get values() { return this.indices.values; }\n    get nullCount() { return this.indices.nullCount; }\n    get nullBitmap() { return this.indices.nullBitmap; }\n    get byteLength() { return this.indices.byteLength + this.dictionary.byteLength; }\n    get reservedLength() { return this.indices.reservedLength + this.dictionary.reservedLength; }\n    get reservedByteLength() { return this.indices.reservedByteLength + this.dictionary.reservedByteLength; }\n    isValid(value) { return this.indices.isValid(value); }\n    setValid(index, valid) {\n        const indices = this.indices;\n        valid = indices.setValid(index, valid);\n        this.length = indices.length;\n        return valid;\n    }\n    setValue(index, value) {\n        let keysToIndices = this._keysToIndices;\n        let key = this.valueToKey(value);\n        let idx = keysToIndices[key];\n        if (idx === undefined) {\n            keysToIndices[key] = idx = this._dictionaryOffset + this.dictionary.append(value).length - 1;\n        }\n        return this.indices.setValue(index, idx);\n    }\n    flush() {\n        const type = this.type;\n        const prev = this._dictionary;\n        const curr = this.dictionary.toVector();\n        const data = this.indices.flush().clone(type);\n        data.dictionary = prev ? prev.concat(curr) : curr;\n        this.finished || (this._dictionaryOffset += curr.length);\n        this._dictionary = data.dictionary;\n        this.clear();\n        return data;\n    }\n    finish() {\n        this.indices.finish();\n        this.dictionary.finish();\n        this._dictionaryOffset = 0;\n        this._keysToIndices = Object.create(null);\n        return super.finish();\n    }\n    clear() {\n        this.indices.clear();\n        this.dictionary.clear();\n        return super.clear();\n    }\n    valueToKey(val) {\n        return typeof val === 'string' ? val : `${val}`;\n    }\n}\n\n//# sourceMappingURL=dictionary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/dictionary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/fixedsizebinary.mjs":
/*!*******************************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/fixedsizebinary.mjs ***!
  \*******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FixedSizeBinaryBuilder: () => (/* binding */ FixedSizeBinaryBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass FixedSizeBinaryBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n\n//# sourceMappingURL=fixedsizebinary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/fixedsizebinary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/fixedsizelist.mjs":
/*!*****************************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/fixedsizelist.mjs ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FixedSizeListBuilder: () => (/* binding */ FixedSizeListBuilder)\n/* harmony export */ });\n/* harmony import */ var _run__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./run */ \"../../node_modules/apache-arrow/builder/run.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass FixedSizeListBuilder extends _builder__WEBPACK_IMPORTED_MODULE_2__.Builder {\n    constructor() {\n        super(...arguments);\n        this._run = new _run__WEBPACK_IMPORTED_MODULE_0__.Run();\n    }\n    setValue(index, value) {\n        super.setValue(index, this._run.bind(value));\n    }\n    addChild(child, name = '0') {\n        if (this.numChildren > 0) {\n            throw new Error('FixedSizeListBuilder can only have one child.');\n        }\n        const childIndex = this.children.push(child);\n        this.type = new _type__WEBPACK_IMPORTED_MODULE_3__.FixedSizeList(this.type.listSize, new _schema__WEBPACK_IMPORTED_MODULE_1__.Field(name, child.type, true));\n        return childIndex;\n    }\n    clear() {\n        this._run.clear();\n        return super.clear();\n    }\n}\n\n//# sourceMappingURL=fixedsizelist.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/fixedsizelist.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/float.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/float.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Float16Builder: () => (/* binding */ Float16Builder),\n/* harmony export */   Float32Builder: () => (/* binding */ Float32Builder),\n/* harmony export */   Float64Builder: () => (/* binding */ Float64Builder),\n/* harmony export */   FloatBuilder: () => (/* binding */ FloatBuilder)\n/* harmony export */ });\n/* harmony import */ var _util_math__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/math */ \"../../node_modules/apache-arrow/util/math.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nclass FloatBuilder extends _builder__WEBPACK_IMPORTED_MODULE_1__.FixedWidthBuilder {\n}\n/** @ignore */\nclass Float16Builder extends FloatBuilder {\n    setValue(index, value) {\n        // convert JS float64 to a uint16\n        this._values.set(index, (0,_util_math__WEBPACK_IMPORTED_MODULE_0__.float64ToUint16)(value));\n    }\n}\n/** @ignore */\nclass Float32Builder extends FloatBuilder {\n    setValue(index, value) {\n        this._values.set(index, value);\n    }\n}\n/** @ignore */\nclass Float64Builder extends FloatBuilder {\n    setValue(index, value) {\n        this._values.set(index, value);\n    }\n}\n\n//# sourceMappingURL=float.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/float.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/index.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/index.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BinaryBuilder: () => (/* reexport safe */ _binary__WEBPACK_IMPORTED_MODULE_13__.BinaryBuilder),\n/* harmony export */   BoolBuilder: () => (/* reexport safe */ _bool__WEBPACK_IMPORTED_MODULE_1__.BoolBuilder),\n/* harmony export */   Builder: () => (/* reexport safe */ _builder__WEBPACK_IMPORTED_MODULE_0__.Builder),\n/* harmony export */   DateBuilder: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_3__.DateBuilder),\n/* harmony export */   DateDayBuilder: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_3__.DateDayBuilder),\n/* harmony export */   DateMillisecondBuilder: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_3__.DateMillisecondBuilder),\n/* harmony export */   DecimalBuilder: () => (/* reexport safe */ _decimal__WEBPACK_IMPORTED_MODULE_4__.DecimalBuilder),\n/* harmony export */   DenseUnionBuilder: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_18__.DenseUnionBuilder),\n/* harmony export */   DictionaryBuilder: () => (/* reexport safe */ _dictionary__WEBPACK_IMPORTED_MODULE_5__.DictionaryBuilder),\n/* harmony export */   FixedSizeBinaryBuilder: () => (/* reexport safe */ _fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__.FixedSizeBinaryBuilder),\n/* harmony export */   FixedSizeListBuilder: () => (/* reexport safe */ _fixedsizelist__WEBPACK_IMPORTED_MODULE_15__.FixedSizeListBuilder),\n/* harmony export */   Float16Builder: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_7__.Float16Builder),\n/* harmony export */   Float32Builder: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_7__.Float32Builder),\n/* harmony export */   Float64Builder: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_7__.Float64Builder),\n/* harmony export */   FloatBuilder: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_7__.FloatBuilder),\n/* harmony export */   Int16Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Int16Builder),\n/* harmony export */   Int32Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Int32Builder),\n/* harmony export */   Int64Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Int64Builder),\n/* harmony export */   Int8Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Int8Builder),\n/* harmony export */   IntBuilder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.IntBuilder),\n/* harmony export */   IntervalBuilder: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalBuilder),\n/* harmony export */   IntervalDayTimeBuilder: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalDayTimeBuilder),\n/* harmony export */   IntervalYearMonthBuilder: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalYearMonthBuilder),\n/* harmony export */   ListBuilder: () => (/* reexport safe */ _list__WEBPACK_IMPORTED_MODULE_14__.ListBuilder),\n/* harmony export */   MapBuilder: () => (/* reexport safe */ _map__WEBPACK_IMPORTED_MODULE_16__.MapBuilder),\n/* harmony export */   NullBuilder: () => (/* reexport safe */ _null__WEBPACK_IMPORTED_MODULE_2__.NullBuilder),\n/* harmony export */   SparseUnionBuilder: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_18__.SparseUnionBuilder),\n/* harmony export */   StructBuilder: () => (/* reexport safe */ _struct__WEBPACK_IMPORTED_MODULE_17__.StructBuilder),\n/* harmony export */   TimeBuilder: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_9__.TimeBuilder),\n/* harmony export */   TimeMicrosecondBuilder: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_9__.TimeMicrosecondBuilder),\n/* harmony export */   TimeMillisecondBuilder: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_9__.TimeMillisecondBuilder),\n/* harmony export */   TimeNanosecondBuilder: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_9__.TimeNanosecondBuilder),\n/* harmony export */   TimeSecondBuilder: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_9__.TimeSecondBuilder),\n/* harmony export */   TimestampBuilder: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_10__.TimestampBuilder),\n/* harmony export */   TimestampMicrosecondBuilder: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_10__.TimestampMicrosecondBuilder),\n/* harmony export */   TimestampMillisecondBuilder: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_10__.TimestampMillisecondBuilder),\n/* harmony export */   TimestampNanosecondBuilder: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_10__.TimestampNanosecondBuilder),\n/* harmony export */   TimestampSecondBuilder: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_10__.TimestampSecondBuilder),\n/* harmony export */   Uint16Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Uint16Builder),\n/* harmony export */   Uint32Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Uint32Builder),\n/* harmony export */   Uint64Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Uint64Builder),\n/* harmony export */   Uint8Builder: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_8__.Uint8Builder),\n/* harmony export */   UnionBuilder: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_18__.UnionBuilder),\n/* harmony export */   Utf8Builder: () => (/* reexport safe */ _utf8__WEBPACK_IMPORTED_MODULE_12__.Utf8Builder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n/* harmony import */ var _bool__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./bool */ \"../../node_modules/apache-arrow/builder/bool.mjs\");\n/* harmony import */ var _null__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./null */ \"../../node_modules/apache-arrow/builder/null.mjs\");\n/* harmony import */ var _date__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./date */ \"../../node_modules/apache-arrow/builder/date.mjs\");\n/* harmony import */ var _decimal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./decimal */ \"../../node_modules/apache-arrow/builder/decimal.mjs\");\n/* harmony import */ var _dictionary__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./dictionary */ \"../../node_modules/apache-arrow/builder/dictionary.mjs\");\n/* harmony import */ var _fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./fixedsizebinary */ \"../../node_modules/apache-arrow/builder/fixedsizebinary.mjs\");\n/* harmony import */ var _float__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./float */ \"../../node_modules/apache-arrow/builder/float.mjs\");\n/* harmony import */ var _int__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./int */ \"../../node_modules/apache-arrow/builder/int.mjs\");\n/* harmony import */ var _time__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./time */ \"../../node_modules/apache-arrow/builder/time.mjs\");\n/* harmony import */ var _timestamp__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./timestamp */ \"../../node_modules/apache-arrow/builder/timestamp.mjs\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./interval */ \"../../node_modules/apache-arrow/builder/interval.mjs\");\n/* harmony import */ var _utf8__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./utf8 */ \"../../node_modules/apache-arrow/builder/utf8.mjs\");\n/* harmony import */ var _binary__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./binary */ \"../../node_modules/apache-arrow/builder/binary.mjs\");\n/* harmony import */ var _list__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./list */ \"../../node_modules/apache-arrow/builder/list.mjs\");\n/* harmony import */ var _fixedsizelist__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./fixedsizelist */ \"../../node_modules/apache-arrow/builder/fixedsizelist.mjs\");\n/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./map */ \"../../node_modules/apache-arrow/builder/map.mjs\");\n/* harmony import */ var _struct__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./struct */ \"../../node_modules/apache-arrow/builder/struct.mjs\");\n/* harmony import */ var _union__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./union */ \"../../node_modules/apache-arrow/builder/union.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _visitor_set__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../visitor/set */ \"../../node_modules/apache-arrow/visitor/set.mjs\");\n/* harmony import */ var _visitor_builderctor__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../visitor/builderctor */ \"../../node_modules/apache-arrow/visitor/builderctor.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/** @ignore */\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/** @nocollapse */\n_builder__WEBPACK_IMPORTED_MODULE_0__.Builder.new = newBuilder;\nfunction newBuilder(options) {\n    const type = options.type;\n    const builder = new (_visitor_builderctor__WEBPACK_IMPORTED_MODULE_21__.instance.getVisitFn(type)())(options);\n    if (type.children && type.children.length > 0) {\n        const children = options['children'] || [];\n        const defaultOptions = { 'nullValues': options['nullValues'] };\n        const getChildOptions = Array.isArray(children)\n            ? ((_, i) => children[i] || defaultOptions)\n            : (({ name }) => children[name] || defaultOptions);\n        type.children.forEach((field, index) => {\n            const { type } = field;\n            const opts = getChildOptions(field, index);\n            builder.children.push(newBuilder({ ...opts, type }));\n        });\n    }\n    return builder;\n}\nObject.keys(_enum__WEBPACK_IMPORTED_MODULE_19__.Type)\n    .map((T) => _enum__WEBPACK_IMPORTED_MODULE_19__.Type[T])\n    .filter((T) => typeof T === 'number' && T !== _enum__WEBPACK_IMPORTED_MODULE_19__.Type.NONE)\n    .forEach((typeId) => {\n    const BuilderCtor = _visitor_builderctor__WEBPACK_IMPORTED_MODULE_21__.instance.visit(typeId);\n    BuilderCtor.prototype._setValue = _visitor_set__WEBPACK_IMPORTED_MODULE_20__.instance.getVisitFn(typeId);\n});\n_utf8__WEBPACK_IMPORTED_MODULE_12__.Utf8Builder.prototype._setValue = _visitor_set__WEBPACK_IMPORTED_MODULE_20__.instance.visitBinary;\n\n//# sourceMappingURL=index.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/index.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/int.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/int.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Int16Builder: () => (/* binding */ Int16Builder),\n/* harmony export */   Int32Builder: () => (/* binding */ Int32Builder),\n/* harmony export */   Int64Builder: () => (/* binding */ Int64Builder),\n/* harmony export */   Int8Builder: () => (/* binding */ Int8Builder),\n/* harmony export */   IntBuilder: () => (/* binding */ IntBuilder),\n/* harmony export */   Uint16Builder: () => (/* binding */ Uint16Builder),\n/* harmony export */   Uint32Builder: () => (/* binding */ Uint32Builder),\n/* harmony export */   Uint64Builder: () => (/* binding */ Uint64Builder),\n/* harmony export */   Uint8Builder: () => (/* binding */ Uint8Builder)\n/* harmony export */ });\n/* harmony import */ var _util_bn__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/bn */ \"../../node_modules/apache-arrow/util/bn.mjs\");\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass IntBuilder extends _builder__WEBPACK_IMPORTED_MODULE_3__.FixedWidthBuilder {\n    setValue(index, value) {\n        this._values.set(index, value);\n    }\n}\n/** @ignore */\nclass Int8Builder extends IntBuilder {\n}\n/** @ignore */\nclass Int16Builder extends IntBuilder {\n}\n/** @ignore */\nclass Int32Builder extends IntBuilder {\n}\n/** @ignore */\nclass Int64Builder extends IntBuilder {\n    constructor(options) {\n        if (options['nullValues']) {\n            options['nullValues'] = options['nullValues'].map(toBigInt);\n        }\n        super(options);\n        this._values = new _buffer__WEBPACK_IMPORTED_MODULE_1__.WideBufferBuilder(new Int32Array(0), 2);\n    }\n    get values64() { return this._values.buffer64; }\n    isValid(value) { return super.isValid(toBigInt(value)); }\n}\n/** @ignore */\nclass Uint8Builder extends IntBuilder {\n}\n/** @ignore */\nclass Uint16Builder extends IntBuilder {\n}\n/** @ignore */\nclass Uint32Builder extends IntBuilder {\n}\n/** @ignore */\nclass Uint64Builder extends IntBuilder {\n    constructor(options) {\n        if (options['nullValues']) {\n            options['nullValues'] = options['nullValues'].map(toBigInt);\n        }\n        super(options);\n        this._values = new _buffer__WEBPACK_IMPORTED_MODULE_1__.WideBufferBuilder(new Uint32Array(0), 2);\n    }\n    get values64() { return this._values.buffer64; }\n    isValid(value) { return super.isValid(toBigInt(value)); }\n}\nconst toBigInt = ((memo) => (value) => {\n    if (ArrayBuffer.isView(value)) {\n        memo.buffer = value.buffer;\n        memo.byteOffset = value.byteOffset;\n        memo.byteLength = value.byteLength;\n        value = (0,_util_bn__WEBPACK_IMPORTED_MODULE_0__.bignumToBigInt)(memo);\n        memo.buffer = null;\n    }\n    return value;\n})({ 'BigIntArray': _util_compat__WEBPACK_IMPORTED_MODULE_2__.BigInt64Array });\n\n//# sourceMappingURL=int.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/int.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/interval.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/interval.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   IntervalBuilder: () => (/* binding */ IntervalBuilder),\n/* harmony export */   IntervalDayTimeBuilder: () => (/* binding */ IntervalDayTimeBuilder),\n/* harmony export */   IntervalYearMonthBuilder: () => (/* binding */ IntervalYearMonthBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass IntervalBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n/** @ignore */\nclass IntervalDayTimeBuilder extends IntervalBuilder {\n}\n/** @ignore */\nclass IntervalYearMonthBuilder extends IntervalBuilder {\n}\n\n//# sourceMappingURL=interval.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/interval.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/list.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/list.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ListBuilder: () => (/* binding */ ListBuilder)\n/* harmony export */ });\n/* harmony import */ var _run__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./run */ \"../../node_modules/apache-arrow/builder/run.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */\nclass ListBuilder extends _builder__WEBPACK_IMPORTED_MODULE_4__.VariableWidthBuilder {\n    constructor(opts) {\n        super(opts);\n        this._run = new _run__WEBPACK_IMPORTED_MODULE_0__.Run();\n        this._offsets = new _buffer__WEBPACK_IMPORTED_MODULE_3__.OffsetsBufferBuilder();\n    }\n    addChild(child, name = '0') {\n        if (this.numChildren > 0) {\n            throw new Error('ListBuilder can only have one child.');\n        }\n        this.children[this.numChildren] = child;\n        this.type = new _type__WEBPACK_IMPORTED_MODULE_2__.List(new _schema__WEBPACK_IMPORTED_MODULE_1__.Field(name, child.type, true));\n        return this.numChildren - 1;\n    }\n    clear() {\n        this._run.clear();\n        return super.clear();\n    }\n    _flushPending(pending) {\n        const run = this._run;\n        const offsets = this._offsets;\n        const setValue = this._setValue;\n        let index = 0, value;\n        for ([index, value] of pending) {\n            if (value === undefined) {\n                offsets.set(index, 0);\n            }\n            else {\n                offsets.set(index, value.length);\n                setValue(this, index, run.bind(value));\n            }\n        }\n    }\n}\n\n//# sourceMappingURL=list.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/list.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/map.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/map.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MapBuilder: () => (/* binding */ MapBuilder)\n/* harmony export */ });\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass MapBuilder extends _builder__WEBPACK_IMPORTED_MODULE_2__.VariableWidthBuilder {\n    set(index, value) {\n        return super.set(index, value);\n    }\n    setValue(index, value) {\n        value = value instanceof Map ? value : new Map(Object.entries(value));\n        const pending = this._pending || (this._pending = new Map());\n        const current = pending.get(index);\n        current && (this._pendingLength -= current.size);\n        this._pendingLength += value.size;\n        pending.set(index, value);\n    }\n    addChild(child, name = `${this.numChildren}`) {\n        if (this.numChildren > 0) {\n            throw new Error('ListBuilder can only have one child.');\n        }\n        this.children[this.numChildren] = child;\n        this.type = new _type__WEBPACK_IMPORTED_MODULE_1__.Map_(new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(name, child.type, true), this.type.keysSorted);\n        return this.numChildren - 1;\n    }\n    _flushPending(pending) {\n        const offsets = this._offsets;\n        const setValue = this._setValue;\n        pending.forEach((value, index) => {\n            if (value === undefined) {\n                offsets.set(index, 0);\n            }\n            else {\n                offsets.set(index, value.size);\n                setValue(this, index, value);\n            }\n        });\n    }\n}\n\n//# sourceMappingURL=map.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/map.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/null.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/null.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   NullBuilder: () => (/* binding */ NullBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass NullBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.Builder {\n    // @ts-ignore\n    setValue(index, value) { }\n    setValid(index, valid) {\n        this.length = Math.max(index + 1, this.length);\n        return valid;\n    }\n}\n\n//# sourceMappingURL=null.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/null.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/run.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/run.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Run: () => (/* binding */ Run)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass Run {\n    get length() { return this._values.length; }\n    get(index) { return this._values[index]; }\n    clear() { this._values = null; return this; }\n    bind(values) {\n        if (values instanceof _vector__WEBPACK_IMPORTED_MODULE_0__.Vector) {\n            return values;\n        }\n        this._values = values;\n        return this;\n    }\n}\n\n//# sourceMappingURL=run.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/run.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/struct.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/struct.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   StructBuilder: () => (/* binding */ StructBuilder)\n/* harmony export */ });\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass StructBuilder extends _builder__WEBPACK_IMPORTED_MODULE_1__.Builder {\n    addChild(child, name = `${this.numChildren}`) {\n        const childIndex = this.children.push(child);\n        this.type = new _type__WEBPACK_IMPORTED_MODULE_2__.Struct([...this.type.children, new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(name, child.type, true)]);\n        return childIndex;\n    }\n}\n\n//# sourceMappingURL=struct.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/struct.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/time.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/time.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TimeBuilder: () => (/* binding */ TimeBuilder),\n/* harmony export */   TimeMicrosecondBuilder: () => (/* binding */ TimeMicrosecondBuilder),\n/* harmony export */   TimeMillisecondBuilder: () => (/* binding */ TimeMillisecondBuilder),\n/* harmony export */   TimeNanosecondBuilder: () => (/* binding */ TimeNanosecondBuilder),\n/* harmony export */   TimeSecondBuilder: () => (/* binding */ TimeSecondBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass TimeBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n/** @ignore */\nclass TimeSecondBuilder extends TimeBuilder {\n}\n/** @ignore */\nclass TimeMillisecondBuilder extends TimeBuilder {\n}\n/** @ignore */\nclass TimeMicrosecondBuilder extends TimeBuilder {\n}\n/** @ignore */\nclass TimeNanosecondBuilder extends TimeBuilder {\n}\n\n//# sourceMappingURL=time.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/time.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/timestamp.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/timestamp.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TimestampBuilder: () => (/* binding */ TimestampBuilder),\n/* harmony export */   TimestampMicrosecondBuilder: () => (/* binding */ TimestampMicrosecondBuilder),\n/* harmony export */   TimestampMillisecondBuilder: () => (/* binding */ TimestampMillisecondBuilder),\n/* harmony export */   TimestampNanosecondBuilder: () => (/* binding */ TimestampNanosecondBuilder),\n/* harmony export */   TimestampSecondBuilder: () => (/* binding */ TimestampSecondBuilder)\n/* harmony export */ });\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass TimestampBuilder extends _builder__WEBPACK_IMPORTED_MODULE_0__.FixedWidthBuilder {\n}\n/** @ignore */\nclass TimestampSecondBuilder extends TimestampBuilder {\n}\n/** @ignore */\nclass TimestampMillisecondBuilder extends TimestampBuilder {\n}\n/** @ignore */\nclass TimestampMicrosecondBuilder extends TimestampBuilder {\n}\n/** @ignore */\nclass TimestampNanosecondBuilder extends TimestampBuilder {\n}\n\n//# sourceMappingURL=timestamp.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/timestamp.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/union.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/union.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DenseUnionBuilder: () => (/* binding */ DenseUnionBuilder),\n/* harmony export */   SparseUnionBuilder: () => (/* binding */ SparseUnionBuilder),\n/* harmony export */   UnionBuilder: () => (/* binding */ UnionBuilder)\n/* harmony export */ });\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass UnionBuilder extends _builder__WEBPACK_IMPORTED_MODULE_2__.Builder {\n    constructor(options) {\n        super(options);\n        this._typeIds = new _buffer__WEBPACK_IMPORTED_MODULE_1__.DataBufferBuilder(new Int8Array(0), 1);\n        if (typeof options['valueToChildTypeId'] === 'function') {\n            this._valueToChildTypeId = options['valueToChildTypeId'];\n        }\n    }\n    get typeIdToChildIndex() { return this.type.typeIdToChildIndex; }\n    append(value, childTypeId) {\n        return this.set(this.length, value, childTypeId);\n    }\n    set(index, value, childTypeId) {\n        if (childTypeId === undefined) {\n            childTypeId = this._valueToChildTypeId(this, value, index);\n        }\n        if (this.setValid(index, this.isValid(value))) {\n            this.setValue(index, value, childTypeId);\n        }\n        return this;\n    }\n    // @ts-ignore\n    setValue(index, value, childTypeId) {\n        this._typeIds.set(index, childTypeId);\n        super.setValue(index, value);\n    }\n    // @ts-ignore\n    addChild(child, name = `${this.children.length}`) {\n        const childTypeId = this.children.push(child);\n        const { type: { children, mode, typeIds } } = this;\n        const fields = [...children, new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(name, child.type)];\n        this.type = new _type__WEBPACK_IMPORTED_MODULE_3__.Union(mode, [...typeIds, childTypeId], fields);\n        return childTypeId;\n    }\n    /** @ignore */\n    // @ts-ignore\n    _valueToChildTypeId(builder, value, offset) {\n        throw new Error(`Cannot map UnionBuilder value to child typeId. \\\nPass the \\`childTypeId\\` as the second argument to unionBuilder.append(), \\\nor supply a \\`valueToChildTypeId\\` function as part of the UnionBuilder constructor options.`);\n    }\n}\n/** @ignore */\nclass SparseUnionBuilder extends UnionBuilder {\n}\n/** @ignore */\nclass DenseUnionBuilder extends UnionBuilder {\n    constructor(options) {\n        super(options);\n        this._offsets = new _buffer__WEBPACK_IMPORTED_MODULE_1__.DataBufferBuilder(new Int32Array(0));\n    }\n    /** @ignore */\n    setValue(index, value, childTypeId) {\n        const childIndex = this.type.typeIdToChildIndex[childTypeId];\n        this._offsets.set(index, this.getChildAt(childIndex).length);\n        return super.setValue(index, value, childTypeId);\n    }\n}\n\n//# sourceMappingURL=union.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/union.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/utf8.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/utf8.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Utf8Builder: () => (/* binding */ Utf8Builder)\n/* harmony export */ });\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _binary__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./binary */ \"../../node_modules/apache-arrow/builder/binary.mjs\");\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/builder/buffer.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass Utf8Builder extends _builder__WEBPACK_IMPORTED_MODULE_3__.VariableWidthBuilder {\n    constructor(opts) {\n        super(opts);\n        this._values = new _buffer__WEBPACK_IMPORTED_MODULE_2__.BufferBuilder(new Uint8Array(0));\n    }\n    get byteLength() {\n        let size = this._pendingLength + (this.length * 4);\n        this._offsets && (size += this._offsets.byteLength);\n        this._values && (size += this._values.byteLength);\n        this._nulls && (size += this._nulls.byteLength);\n        return size;\n    }\n    setValue(index, value) {\n        return super.setValue(index, (0,_util_utf8__WEBPACK_IMPORTED_MODULE_0__.encodeUtf8)(value));\n    }\n    // @ts-ignore\n    _flushPending(pending, pendingLength) { }\n}\nUtf8Builder.prototype._flushPending = _binary__WEBPACK_IMPORTED_MODULE_1__.BinaryBuilder.prototype._flushPending;\n\n//# sourceMappingURL=utf8.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/utf8.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/builder/valid.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/builder/valid.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   createIsValidFunction: () => (/* binding */ createIsValidFunction)\n/* harmony export */ });\n/* harmony import */ var _util_pretty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/pretty */ \"../../node_modules/apache-arrow/util/pretty.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/**\n * Dynamically compile the null values into an `isValid()` function whose\n * implementation is a switch statement. Microbenchmarks in v8 indicate\n * this approach is 25% faster than using an ES6 Map.\n *\n * @example\n * console.log(createIsValidFunction([null, 'N/A', NaN]));\n * `function (x) {\n *     if (x !== x) return false;\n *     switch (x) {\n *         case null:\n *         case \"N/A\":\n *             return false;\n *     }\n *     return true;\n * }`\n *\n * @ignore\n * @param nullValues\n */\nfunction createIsValidFunction(nullValues) {\n    if (!nullValues || nullValues.length <= 0) {\n        // @ts-ignore\n        return function isValid(value) { return true; };\n    }\n    let fnBody = '';\n    let noNaNs = nullValues.filter((x) => x === x);\n    if (noNaNs.length > 0) {\n        fnBody = `\n    switch (x) {${noNaNs.map((x) => `\n        case ${valueToCase(x)}:`).join('')}\n            return false;\n    }`;\n    }\n    // NaN doesn't equal anything including itself, so it doesn't work as a\n    // switch case. Instead we must explicitly check for NaN before the switch.\n    if (nullValues.length !== noNaNs.length) {\n        fnBody = `if (x !== x) return false;\\n${fnBody}`;\n    }\n    return new Function(`x`, `${fnBody}\\nreturn true;`);\n}\n/** @ignore */\nfunction valueToCase(x) {\n    if (typeof x !== 'bigint') {\n        return (0,_util_pretty__WEBPACK_IMPORTED_MODULE_0__.valueToString)(x);\n    }\n    else if (_util_compat__WEBPACK_IMPORTED_MODULE_1__.BigIntAvailable) {\n        return `${(0,_util_pretty__WEBPACK_IMPORTED_MODULE_0__.valueToString)(x)}n`;\n    }\n    return `\"${(0,_util_pretty__WEBPACK_IMPORTED_MODULE_0__.valueToString)(x)}\"`;\n}\n\n//# sourceMappingURL=valid.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/builder/valid.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/column.mjs":
/*!**************************************************!*\
  !*** ../../node_modules/apache-arrow/column.mjs ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Column: () => (/* binding */ Column)\n/* harmony export */ });\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _vector_chunked__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./vector/chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\nclass Column extends _vector_chunked__WEBPACK_IMPORTED_MODULE_2__.Chunked {\n    constructor(field, vectors = [], offsets) {\n        vectors = _vector_chunked__WEBPACK_IMPORTED_MODULE_2__.Chunked.flatten(...vectors);\n        super(field.type, vectors, offsets);\n        this._field = field;\n        if (vectors.length === 1 && !(this instanceof SingleChunkColumn)) {\n            return new SingleChunkColumn(field, vectors[0], this._chunkOffsets);\n        }\n    }\n    /** @nocollapse */\n    static new(...args) {\n        let [field, data, ...rest] = args;\n        if (typeof field !== 'string' && !(field instanceof _schema__WEBPACK_IMPORTED_MODULE_0__.Field)) {\n            data = field;\n            field = '';\n        }\n        const chunks = _vector_chunked__WEBPACK_IMPORTED_MODULE_2__.Chunked.flatten(Array.isArray(data) ? [...data, ...rest] :\n            data instanceof _vector__WEBPACK_IMPORTED_MODULE_1__.Vector ? [data, ...rest] :\n                [_vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(data, ...rest)]);\n        if (typeof field === 'string') {\n            const type = chunks[0].data.type;\n            field = new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(field, type, true);\n        }\n        else if (!field.nullable && chunks.some(({ nullCount }) => nullCount > 0)) {\n            field = field.clone({ nullable: true });\n        }\n        return new Column(field, chunks);\n    }\n    get field() { return this._field; }\n    get name() { return this._field.name; }\n    get nullable() { return this._field.nullable; }\n    get metadata() { return this._field.metadata; }\n    clone(chunks = this._chunks) {\n        return new Column(this._field, chunks);\n    }\n    getChildAt(index) {\n        if (index < 0 || index >= this.numChildren) {\n            return null;\n        }\n        let columns = this._children || (this._children = []);\n        let column, field, chunks;\n        if (column = columns[index]) {\n            return column;\n        }\n        if (field = (this.type.children || [])[index]) {\n            chunks = this._chunks\n                .map((vector) => vector.getChildAt(index))\n                .filter((vec) => vec != null);\n            if (chunks.length > 0) {\n                return (columns[index] = new Column(field, chunks));\n            }\n        }\n        return null;\n    }\n}\n/** @ignore */\nclass SingleChunkColumn extends Column {\n    constructor(field, vector, offsets) {\n        super(field, [vector], offsets);\n        this._chunk = vector;\n    }\n    search(index, then) {\n        return then ? then(this, 0, index) : [0, index];\n    }\n    isValid(index) {\n        return this._chunk.isValid(index);\n    }\n    get(index) {\n        return this._chunk.get(index);\n    }\n    set(index, value) {\n        this._chunk.set(index, value);\n    }\n    indexOf(element, offset) {\n        return this._chunk.indexOf(element, offset);\n    }\n}\n\n//# sourceMappingURL=column.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/column.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/compute/dataframe.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/compute/dataframe.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CountByResult: () => (/* binding */ CountByResult),\n/* harmony export */   DataFrame: () => (/* binding */ DataFrame),\n/* harmony export */   FilteredDataFrame: () => (/* binding */ FilteredDataFrame)\n/* harmony export */ });\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table */ \"../../node_modules/apache-arrow/table.mjs\");\n/* harmony import */ var _vector_int__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector/int */ \"../../node_modules/apache-arrow/vector/int.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _predicate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./predicate */ \"../../node_modules/apache-arrow/compute/predicate.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n_table__WEBPACK_IMPORTED_MODULE_0__.Table.prototype.countBy = function (name) { return new DataFrame(this.chunks).countBy(name); };\n_table__WEBPACK_IMPORTED_MODULE_0__.Table.prototype.scan = function (next, bind) { return new DataFrame(this.chunks).scan(next, bind); };\n_table__WEBPACK_IMPORTED_MODULE_0__.Table.prototype.scanReverse = function (next, bind) { return new DataFrame(this.chunks).scanReverse(next, bind); };\n_table__WEBPACK_IMPORTED_MODULE_0__.Table.prototype.filter = function (predicate) { return new DataFrame(this.chunks).filter(predicate); };\nclass DataFrame extends _table__WEBPACK_IMPORTED_MODULE_0__.Table {\n    filter(predicate) {\n        return new FilteredDataFrame(this.chunks, predicate);\n    }\n    scan(next, bind) {\n        const batches = this.chunks, numBatches = batches.length;\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            if (bind) {\n                bind(batch);\n            }\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                next(index, batch);\n            }\n        }\n    }\n    scanReverse(next, bind) {\n        const batches = this.chunks, numBatches = batches.length;\n        for (let batchIndex = numBatches; --batchIndex >= 0;) {\n            // load batches\n            const batch = batches[batchIndex];\n            if (bind) {\n                bind(batch);\n            }\n            // yield all indices\n            for (let index = batch.length; --index >= 0;) {\n                next(index, batch);\n            }\n        }\n    }\n    countBy(name) {\n        const batches = this.chunks, numBatches = batches.length;\n        const count_by = typeof name === 'string' ? new _predicate__WEBPACK_IMPORTED_MODULE_3__.Col(name) : name;\n        // Assume that all dictionary batches are deltas, which means that the\n        // last record batch has the most complete dictionary\n        count_by.bind(batches[numBatches - 1]);\n        const vector = count_by.vector;\n        if (!_type__WEBPACK_IMPORTED_MODULE_5__.DataType.isDictionary(vector.type)) {\n            throw new Error('countBy currently only supports dictionary-encoded columns');\n        }\n        const countByteLength = Math.ceil(Math.log(vector.length) / Math.log(256));\n        const CountsArrayType = countByteLength == 4 ? Uint32Array :\n            countByteLength >= 2 ? Uint16Array : Uint8Array;\n        const counts = new CountsArrayType(vector.dictionary.length);\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            // rebind the countBy Col\n            count_by.bind(batch);\n            const keys = count_by.vector.indices;\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                let key = keys.get(index);\n                if (key !== null) {\n                    counts[key]++;\n                }\n            }\n        }\n        return new CountByResult(vector.dictionary, _vector_int__WEBPACK_IMPORTED_MODULE_1__.IntVector.from(counts));\n    }\n}\n/** @ignore */\nclass CountByResult extends _table__WEBPACK_IMPORTED_MODULE_0__.Table {\n    constructor(values, counts) {\n        const schema = new _schema__WEBPACK_IMPORTED_MODULE_2__.Schema([\n            new _schema__WEBPACK_IMPORTED_MODULE_2__.Field('values', values.type),\n            new _schema__WEBPACK_IMPORTED_MODULE_2__.Field('counts', counts.type)\n        ]);\n        super(new _recordbatch__WEBPACK_IMPORTED_MODULE_4__.RecordBatch(schema, counts.length, [values, counts]));\n    }\n    toJSON() {\n        const values = this.getColumnAt(0);\n        const counts = this.getColumnAt(1);\n        const result = {};\n        for (let i = -1; ++i < this.length;) {\n            result[values.get(i)] = counts.get(i);\n        }\n        return result;\n    }\n}\n/** @ignore */\nclass FilteredDataFrame extends DataFrame {\n    constructor(batches, predicate) {\n        super(batches);\n        this._predicate = predicate;\n    }\n    scan(next, bind) {\n        // inlined version of this:\n        // this.parent.scan((idx, columns) => {\n        //     if (this.predicate(idx, columns)) next(idx, columns);\n        // });\n        const batches = this._chunks;\n        const numBatches = batches.length;\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            const predicate = this._predicate.bind(batch);\n            let isBound = false;\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                if (predicate(index, batch)) {\n                    // bind batches lazily - if predicate doesn't match anything\n                    // in the batch we don't need to call bind on the batch\n                    if (bind && !isBound) {\n                        bind(batch);\n                        isBound = true;\n                    }\n                    next(index, batch);\n                }\n            }\n        }\n    }\n    scanReverse(next, bind) {\n        const batches = this._chunks;\n        const numBatches = batches.length;\n        for (let batchIndex = numBatches; --batchIndex >= 0;) {\n            // load batches\n            const batch = batches[batchIndex];\n            const predicate = this._predicate.bind(batch);\n            let isBound = false;\n            // yield all indices\n            for (let index = batch.length; --index >= 0;) {\n                if (predicate(index, batch)) {\n                    // bind batches lazily - if predicate doesn't match anything\n                    // in the batch we don't need to call bind on the batch\n                    if (bind && !isBound) {\n                        bind(batch);\n                        isBound = true;\n                    }\n                    next(index, batch);\n                }\n            }\n        }\n    }\n    count() {\n        // inlined version of this:\n        // let sum = 0;\n        // this.parent.scan((idx, columns) => {\n        //     if (this.predicate(idx, columns)) ++sum;\n        // });\n        // return sum;\n        let sum = 0;\n        const batches = this._chunks;\n        const numBatches = batches.length;\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            const predicate = this._predicate.bind(batch);\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                if (predicate(index, batch)) {\n                    ++sum;\n                }\n            }\n        }\n        return sum;\n    }\n    *[Symbol.iterator]() {\n        // inlined version of this:\n        // this.parent.scan((idx, columns) => {\n        //     if (this.predicate(idx, columns)) next(idx, columns);\n        // });\n        const batches = this._chunks;\n        const numBatches = batches.length;\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            // TODO: bind batches lazily\n            // If predicate doesn't match anything in the batch we don't need\n            // to bind the callback\n            const predicate = this._predicate.bind(batch);\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                if (predicate(index, batch)) {\n                    yield batch.get(index);\n                }\n            }\n        }\n    }\n    filter(predicate) {\n        return new FilteredDataFrame(this._chunks, this._predicate.and(predicate));\n    }\n    countBy(name) {\n        const batches = this._chunks, numBatches = batches.length;\n        const count_by = typeof name === 'string' ? new _predicate__WEBPACK_IMPORTED_MODULE_3__.Col(name) : name;\n        // Assume that all dictionary batches are deltas, which means that the\n        // last record batch has the most complete dictionary\n        count_by.bind(batches[numBatches - 1]);\n        const vector = count_by.vector;\n        if (!_type__WEBPACK_IMPORTED_MODULE_5__.DataType.isDictionary(vector.type)) {\n            throw new Error('countBy currently only supports dictionary-encoded columns');\n        }\n        const countByteLength = Math.ceil(Math.log(vector.length) / Math.log(256));\n        const CountsArrayType = countByteLength == 4 ? Uint32Array :\n            countByteLength >= 2 ? Uint16Array : Uint8Array;\n        const counts = new CountsArrayType(vector.dictionary.length);\n        for (let batchIndex = -1; ++batchIndex < numBatches;) {\n            // load batches\n            const batch = batches[batchIndex];\n            const predicate = this._predicate.bind(batch);\n            // rebind the countBy Col\n            count_by.bind(batch);\n            const keys = count_by.vector.indices;\n            // yield all indices\n            for (let index = -1, numRows = batch.length; ++index < numRows;) {\n                let key = keys.get(index);\n                if (key !== null && predicate(index, batch)) {\n                    counts[key]++;\n                }\n            }\n        }\n        return new CountByResult(vector.dictionary, _vector_int__WEBPACK_IMPORTED_MODULE_1__.IntVector.from(counts));\n    }\n}\n\n//# sourceMappingURL=dataframe.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/compute/dataframe.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/compute/predicate.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/compute/predicate.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   And: () => (/* binding */ And),\n/* harmony export */   Col: () => (/* binding */ Col),\n/* harmony export */   CombinationPredicate: () => (/* binding */ CombinationPredicate),\n/* harmony export */   ComparisonPredicate: () => (/* binding */ ComparisonPredicate),\n/* harmony export */   CustomPredicate: () => (/* binding */ CustomPredicate),\n/* harmony export */   Equals: () => (/* binding */ Equals),\n/* harmony export */   GTeq: () => (/* binding */ GTeq),\n/* harmony export */   LTeq: () => (/* binding */ LTeq),\n/* harmony export */   Literal: () => (/* binding */ Literal),\n/* harmony export */   Not: () => (/* binding */ Not),\n/* harmony export */   Or: () => (/* binding */ Or),\n/* harmony export */   Predicate: () => (/* binding */ Predicate),\n/* harmony export */   Value: () => (/* binding */ Value),\n/* harmony export */   and: () => (/* binding */ and),\n/* harmony export */   col: () => (/* binding */ col),\n/* harmony export */   custom: () => (/* binding */ custom),\n/* harmony export */   lit: () => (/* binding */ lit),\n/* harmony export */   or: () => (/* binding */ or)\n/* harmony export */ });\n/* harmony import */ var _vector_dictionary__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector/dictionary */ \"../../node_modules/apache-arrow/vector/dictionary.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass Value {\n    eq(other) {\n        if (!(other instanceof Value)) {\n            other = new Literal(other);\n        }\n        return new Equals(this, other);\n    }\n    le(other) {\n        if (!(other instanceof Value)) {\n            other = new Literal(other);\n        }\n        return new LTeq(this, other);\n    }\n    ge(other) {\n        if (!(other instanceof Value)) {\n            other = new Literal(other);\n        }\n        return new GTeq(this, other);\n    }\n    lt(other) {\n        return new Not(this.ge(other));\n    }\n    gt(other) {\n        return new Not(this.le(other));\n    }\n    ne(other) {\n        return new Not(this.eq(other));\n    }\n}\n/** @ignore */\nclass Literal extends Value {\n    constructor(v) {\n        super();\n        this.v = v;\n    }\n}\n/** @ignore */\nclass Col extends Value {\n    constructor(name) {\n        super();\n        this.name = name;\n    }\n    bind(batch) {\n        if (!this.colidx) {\n            // Assume column index doesn't change between calls to bind\n            //this.colidx = cols.findIndex(v => v.name.indexOf(this.name) != -1);\n            this.colidx = -1;\n            const fields = batch.schema.fields;\n            for (let idx = -1; ++idx < fields.length;) {\n                if (fields[idx].name === this.name) {\n                    this.colidx = idx;\n                    break;\n                }\n            }\n            if (this.colidx < 0) {\n                throw new Error(`Failed to bind Col \"${this.name}\"`);\n            }\n        }\n        const vec = this.vector = batch.getChildAt(this.colidx);\n        return (idx) => vec.get(idx);\n    }\n}\n/** @ignore */\nclass Predicate {\n    and(...expr) { return new And(this, ...expr); }\n    or(...expr) { return new Or(this, ...expr); }\n    not() { return new Not(this); }\n}\n/** @ignore */\nclass ComparisonPredicate extends Predicate {\n    constructor(left, right) {\n        super();\n        this.left = left;\n        this.right = right;\n    }\n    bind(batch) {\n        if (this.left instanceof Literal) {\n            if (this.right instanceof Literal) {\n                return this._bindLitLit(batch, this.left, this.right);\n            }\n            else { // right is a Col\n                return this._bindLitCol(batch, this.left, this.right);\n            }\n        }\n        else { // left is a Col\n            if (this.right instanceof Literal) {\n                return this._bindColLit(batch, this.left, this.right);\n            }\n            else { // right is a Col\n                return this._bindColCol(batch, this.left, this.right);\n            }\n        }\n    }\n}\n/** @ignore */\nclass CombinationPredicate extends Predicate {\n    constructor(...children) {\n        super();\n        this.children = children;\n    }\n}\n// add children to prototype so it doesn't get mangled in es2015/umd\nCombinationPredicate.prototype.children = Object.freeze([]); // freeze for safety\n/** @ignore */\nclass And extends CombinationPredicate {\n    constructor(...children) {\n        // Flatten any Ands\n        children = children.reduce((accum, p) => {\n            return accum.concat(p instanceof And ? p.children : p);\n        }, []);\n        super(...children);\n    }\n    bind(batch) {\n        const bound = this.children.map((p) => p.bind(batch));\n        return (idx, batch) => bound.every((p) => p(idx, batch));\n    }\n}\n/** @ignore */\nclass Or extends CombinationPredicate {\n    constructor(...children) {\n        // Flatten any Ors\n        children = children.reduce((accum, p) => {\n            return accum.concat(p instanceof Or ? p.children : p);\n        }, []);\n        super(...children);\n    }\n    bind(batch) {\n        const bound = this.children.map((p) => p.bind(batch));\n        return (idx, batch) => bound.some((p) => p(idx, batch));\n    }\n}\n/** @ignore */\nclass Equals extends ComparisonPredicate {\n    _bindLitLit(_batch, left, right) {\n        const rtrn = left.v == right.v;\n        return () => rtrn;\n    }\n    _bindColCol(batch, left, right) {\n        const left_func = left.bind(batch);\n        const right_func = right.bind(batch);\n        return (idx, batch) => left_func(idx, batch) == right_func(idx, batch);\n    }\n    _bindColLit(batch, col, lit) {\n        const col_func = col.bind(batch);\n        if (col.vector instanceof _vector_dictionary__WEBPACK_IMPORTED_MODULE_0__.DictionaryVector) {\n            let key;\n            const vector = col.vector;\n            if (vector.dictionary !== this.lastDictionary) {\n                key = vector.reverseLookup(lit.v);\n                this.lastDictionary = vector.dictionary;\n                this.lastKey = key;\n            }\n            else {\n                key = this.lastKey;\n            }\n            if (key === -1) {\n                // the value doesn't exist in the dictionary - always return\n                // false\n                // TODO: special-case of PredicateFunc that encapsulates this\n                // \"always false\" behavior. That way filtering operations don't\n                // have to bother checking\n                return () => false;\n            }\n            else {\n                return (idx) => {\n                    return vector.getKey(idx) === key;\n                };\n            }\n        }\n        else {\n            return (idx, cols) => col_func(idx, cols) == lit.v;\n        }\n    }\n    _bindLitCol(batch, lit, col) {\n        // Equals is commutative\n        return this._bindColLit(batch, col, lit);\n    }\n}\n/** @ignore */\nclass LTeq extends ComparisonPredicate {\n    _bindLitLit(_batch, left, right) {\n        const rtrn = left.v <= right.v;\n        return () => rtrn;\n    }\n    _bindColCol(batch, left, right) {\n        const left_func = left.bind(batch);\n        const right_func = right.bind(batch);\n        return (idx, cols) => left_func(idx, cols) <= right_func(idx, cols);\n    }\n    _bindColLit(batch, col, lit) {\n        const col_func = col.bind(batch);\n        return (idx, cols) => col_func(idx, cols) <= lit.v;\n    }\n    _bindLitCol(batch, lit, col) {\n        const col_func = col.bind(batch);\n        return (idx, cols) => lit.v <= col_func(idx, cols);\n    }\n}\n/** @ignore */\nclass GTeq extends ComparisonPredicate {\n    _bindLitLit(_batch, left, right) {\n        const rtrn = left.v >= right.v;\n        return () => rtrn;\n    }\n    _bindColCol(batch, left, right) {\n        const left_func = left.bind(batch);\n        const right_func = right.bind(batch);\n        return (idx, cols) => left_func(idx, cols) >= right_func(idx, cols);\n    }\n    _bindColLit(batch, col, lit) {\n        const col_func = col.bind(batch);\n        return (idx, cols) => col_func(idx, cols) >= lit.v;\n    }\n    _bindLitCol(batch, lit, col) {\n        const col_func = col.bind(batch);\n        return (idx, cols) => lit.v >= col_func(idx, cols);\n    }\n}\n/** @ignore */\nclass Not extends Predicate {\n    constructor(child) {\n        super();\n        this.child = child;\n    }\n    bind(batch) {\n        const func = this.child.bind(batch);\n        return (idx, batch) => !func(idx, batch);\n    }\n}\n/** @ignore */\nclass CustomPredicate extends Predicate {\n    constructor(next, bind_) {\n        super();\n        this.next = next;\n        this.bind_ = bind_;\n    }\n    bind(batch) {\n        this.bind_(batch);\n        return this.next;\n    }\n}\nfunction lit(v) { return new Literal(v); }\nfunction col(n) { return new Col(n); }\nfunction and(...p) { return new And(...p); }\nfunction or(...p) { return new Or(...p); }\nfunction custom(next, bind) {\n    return new CustomPredicate(next, bind);\n}\n\n//# sourceMappingURL=predicate.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/compute/predicate.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/data.mjs":
/*!************************************************!*\
  !*** ../../node_modules/apache-arrow/data.mjs ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Data: () => (/* binding */ Data),\n/* harmony export */   kUnknownNullCount: () => (/* binding */ kUnknownNullCount)\n/* harmony export */ });\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */ const kUnknownNullCount = -1;\n/** @ignore */\nclass Data {\n    constructor(type, offset, length, nullCount, buffers, childData, dictionary) {\n        this.type = type;\n        this.dictionary = dictionary;\n        this.offset = Math.floor(Math.max(offset || 0, 0));\n        this.length = Math.floor(Math.max(length || 0, 0));\n        this._nullCount = Math.floor(Math.max(nullCount || 0, -1));\n        this.childData = (childData || []).map((x) => x instanceof Data ? x : x.data);\n        let buffer;\n        if (buffers instanceof Data) {\n            this.stride = buffers.stride;\n            this.values = buffers.values;\n            this.typeIds = buffers.typeIds;\n            this.nullBitmap = buffers.nullBitmap;\n            this.valueOffsets = buffers.valueOffsets;\n        }\n        else {\n            this.stride = (0,_type__WEBPACK_IMPORTED_MODULE_2__.strideForType)(type);\n            if (buffers) {\n                (buffer = buffers[0]) && (this.valueOffsets = buffer);\n                (buffer = buffers[1]) && (this.values = buffer);\n                (buffer = buffers[2]) && (this.nullBitmap = buffer);\n                (buffer = buffers[3]) && (this.typeIds = buffer);\n            }\n        }\n    }\n    get typeId() { return this.type.typeId; }\n    get ArrayType() { return this.type.ArrayType; }\n    get buffers() {\n        return [this.valueOffsets, this.values, this.nullBitmap, this.typeIds];\n    }\n    get byteLength() {\n        let byteLength = 0;\n        let { valueOffsets, values, nullBitmap, typeIds } = this;\n        valueOffsets && (byteLength += valueOffsets.byteLength);\n        values && (byteLength += values.byteLength);\n        nullBitmap && (byteLength += nullBitmap.byteLength);\n        typeIds && (byteLength += typeIds.byteLength);\n        return this.childData.reduce((byteLength, child) => byteLength + child.byteLength, byteLength);\n    }\n    get nullCount() {\n        let nullCount = this._nullCount;\n        let nullBitmap;\n        if (nullCount <= kUnknownNullCount && (nullBitmap = this.nullBitmap)) {\n            this._nullCount = nullCount = this.length - (0,_util_bit__WEBPACK_IMPORTED_MODULE_0__.popcnt_bit_range)(nullBitmap, this.offset, this.offset + this.length);\n        }\n        return nullCount;\n    }\n    clone(type, offset = this.offset, length = this.length, nullCount = this._nullCount, buffers = this, childData = this.childData) {\n        return new Data(type, offset, length, nullCount, buffers, childData, this.dictionary);\n    }\n    slice(offset, length) {\n        const { stride, typeId, childData } = this;\n        // +true === 1, +false === 0, so this means\n        // we keep nullCount at 0 if it's already 0,\n        // otherwise set to the invalidated flag -1\n        const nullCount = +(this._nullCount === 0) - 1;\n        const childStride = typeId === 16 /* FixedSizeList */ ? stride : 1;\n        const buffers = this._sliceBuffers(offset, length, stride, typeId);\n        return this.clone(this.type, this.offset + offset, length, nullCount, buffers, \n        // Don't slice children if we have value offsets (the variable-width types)\n        (!childData.length || this.valueOffsets) ? childData : this._sliceChildren(childData, childStride * offset, childStride * length));\n    }\n    _changeLengthAndBackfillNullBitmap(newLength) {\n        if (this.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Null) {\n            return this.clone(this.type, 0, newLength, 0);\n        }\n        const { length, nullCount } = this;\n        // start initialized with 0s (nulls), then fill from 0 to length with 1s (not null)\n        const bitmap = new Uint8Array(((newLength + 63) & ~63) >> 3).fill(255, 0, length >> 3);\n        // set all the bits in the last byte (up to bit `length - length % 8`) to 1 (not null)\n        bitmap[length >> 3] = (1 << (length - (length & ~7))) - 1;\n        // if we have a nullBitmap, truncate + slice and set it over the pre-filled 1s\n        if (nullCount > 0) {\n            bitmap.set((0,_util_bit__WEBPACK_IMPORTED_MODULE_0__.truncateBitmap)(this.offset, length, this.nullBitmap), 0);\n        }\n        const buffers = this.buffers;\n        buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY] = bitmap;\n        return this.clone(this.type, 0, newLength, nullCount + (newLength - length), buffers);\n    }\n    _sliceBuffers(offset, length, stride, typeId) {\n        let arr, { buffers } = this;\n        // If typeIds exist, slice the typeIds buffer\n        (arr = buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.TYPE]) && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.TYPE] = arr.subarray(offset, offset + length));\n        // If offsets exist, only slice the offsets buffer\n        (arr = buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET]) && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] = arr.subarray(offset, offset + length + 1)) ||\n            // Otherwise if no offsets, slice the data buffer. Don't slice the data vector for Booleans, since the offset goes by bits not bytes\n            (arr = buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA]) && (buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] = typeId === 6 ? arr : arr.subarray(stride * offset, stride * (offset + length)));\n        return buffers;\n    }\n    _sliceChildren(childData, offset, length) {\n        return childData.map((child) => child.slice(offset, length));\n    }\n    //\n    // Convenience methods for creating Data instances for each of the Arrow Vector types\n    //\n    /** @nocollapse */\n    static new(type, offset, length, nullCount, buffers, childData, dictionary) {\n        if (buffers instanceof Data) {\n            buffers = buffers.buffers;\n        }\n        else if (!buffers) {\n            buffers = [];\n        }\n        switch (type.typeId) {\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Null: return Data.Null(type, offset, length);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Int: return Data.Int(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Dictionary: return Data.Dictionary(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || [], dictionary);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Float: return Data.Float(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Bool: return Data.Bool(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Decimal: return Data.Decimal(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Date: return Data.Date(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Time: return Data.Time(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Timestamp: return Data.Timestamp(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Interval: return Data.Interval(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeBinary: return Data.FixedSizeBinary(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Binary: return Data.Binary(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] || [], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Utf8: return Data.Utf8(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] || [], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.DATA] || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.List: return Data.List(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] || [], (childData || [])[0]);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeList: return Data.FixedSizeList(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], (childData || [])[0]);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Struct: return Data.Struct(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], childData || []);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Map: return Data.Map(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] || [], (childData || [])[0]);\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Union: return Data.Union(type, offset, length, nullCount || 0, buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.VALIDITY], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.TYPE] || [], buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] || childData, childData);\n        }\n        throw new Error(`Unrecognized typeId ${type.typeId}`);\n    }\n    /** @nocollapse */\n    static Null(type, offset, length) {\n        return new Data(type, offset, length, 0);\n    }\n    /** @nocollapse */\n    static Int(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Dictionary(type, offset, length, nullCount, nullBitmap, data, dictionary) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.indices.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)], [], dictionary);\n    }\n    /** @nocollapse */\n    static Float(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Bool(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Decimal(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Date(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Time(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Timestamp(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Interval(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static FixedSizeBinary(type, offset, length, nullCount, nullBitmap, data) {\n        return new Data(type, offset, length, nullCount, [undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Binary(type, offset, length, nullCount, nullBitmap, valueOffsets, data) {\n        return new Data(type, offset, length, nullCount, [(0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toInt32Array)(valueOffsets), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static Utf8(type, offset, length, nullCount, nullBitmap, valueOffsets, data) {\n        return new Data(type, offset, length, nullCount, [(0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toInt32Array)(valueOffsets), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(data), (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)]);\n    }\n    /** @nocollapse */\n    static List(type, offset, length, nullCount, nullBitmap, valueOffsets, child) {\n        return new Data(type, offset, length, nullCount, [(0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toInt32Array)(valueOffsets), undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)], child ? [child] : []);\n    }\n    /** @nocollapse */\n    static FixedSizeList(type, offset, length, nullCount, nullBitmap, child) {\n        return new Data(type, offset, length, nullCount, [undefined, undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)], child ? [child] : []);\n    }\n    /** @nocollapse */\n    static Struct(type, offset, length, nullCount, nullBitmap, children) {\n        return new Data(type, offset, length, nullCount, [undefined, undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)], children);\n    }\n    /** @nocollapse */\n    static Map(type, offset, length, nullCount, nullBitmap, valueOffsets, child) {\n        return new Data(type, offset, length, nullCount, [(0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toInt32Array)(valueOffsets), undefined, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap)], child ? [child] : []);\n    }\n    /** @nocollapse */\n    static Union(type, offset, length, nullCount, nullBitmap, typeIds, valueOffsetsOrChildren, children) {\n        const buffers = [\n            undefined, undefined,\n            (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(nullBitmap),\n            (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toArrayBufferView)(type.ArrayType, typeIds)\n        ];\n        if (type.mode === _enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode.Sparse) {\n            return new Data(type, offset, length, nullCount, buffers, valueOffsetsOrChildren);\n        }\n        buffers[_enum__WEBPACK_IMPORTED_MODULE_1__.BufferType.OFFSET] = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toInt32Array)(valueOffsetsOrChildren);\n        return new Data(type, offset, length, nullCount, buffers, children);\n    }\n}\nData.prototype.childData = Object.freeze([]);\n\n//# sourceMappingURL=data.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/data.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/enum.mjs":
/*!************************************************!*\
  !*** ../../node_modules/apache-arrow/enum.mjs ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ArrowType: () => (/* binding */ ArrowType),\n/* harmony export */   BufferType: () => (/* binding */ BufferType),\n/* harmony export */   DateUnit: () => (/* binding */ DateUnit),\n/* harmony export */   IntervalUnit: () => (/* binding */ IntervalUnit),\n/* harmony export */   MessageHeader: () => (/* binding */ MessageHeader),\n/* harmony export */   MetadataVersion: () => (/* binding */ MetadataVersion),\n/* harmony export */   Precision: () => (/* binding */ Precision),\n/* harmony export */   TimeUnit: () => (/* binding */ TimeUnit),\n/* harmony export */   Type: () => (/* binding */ Type),\n/* harmony export */   UnionMode: () => (/* binding */ UnionMode)\n/* harmony export */ });\n/* harmony import */ var _fb_Schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./fb/Schema */ \"../../node_modules/apache-arrow/fb/Schema.mjs\");\n/* harmony import */ var _fb_Message__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./fb/Message */ \"../../node_modules/apache-arrow/fb/Message.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\nvar ArrowType = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Type;\nvar DateUnit = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.DateUnit;\nvar TimeUnit = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.TimeUnit;\nvar Precision = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Precision;\nvar UnionMode = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.UnionMode;\nvar IntervalUnit = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.IntervalUnit;\nvar MessageHeader = _fb_Message__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.MessageHeader;\nvar MetadataVersion = _fb_Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.MetadataVersion;\n/**\n * Main data type enumeration.\n *\n * Data types in this library are all *logical*. They can be expressed as\n * either a primitive physical type (bytes or bits of some fixed size), a\n * nested type consisting of other data types, or another data type (e.g. a\n * timestamp encoded as an int64).\n *\n * **Note**: Only enum values 0-17 (NONE through Map) are written to an Arrow\n * IPC payload.\n *\n * The rest of the values are specified here so TypeScript can narrow the type\n * signatures further beyond the base Arrow Types. The Arrow DataTypes include\n * metadata like `bitWidth` that impact the type signatures of the values we\n * accept and return.\n *\n * For example, the `Int8Vector` reads 1-byte numbers from an `Int8Array`, an\n * `Int32Vector` reads a 4-byte number from an `Int32Array`, and an `Int64Vector`\n * reads a pair of 4-byte lo, hi 32-bit integers as a zero-copy slice from the\n * underlying `Int32Array`.\n *\n * Library consumers benefit by knowing the narrowest type, since we can ensure\n * the types across all public methods are propagated, and never bail to `any`.\n * These values are _never_ used at runtime, and they will _never_ be written\n * to the flatbuffers metadata of serialized Arrow IPC payloads.\n */\nvar Type;\n(function (Type) {\n    /** The default placeholder type */\n    Type[Type[\"NONE\"] = 0] = \"NONE\";\n    /** A NULL type having no physical storage */\n    Type[Type[\"Null\"] = 1] = \"Null\";\n    /** Signed or unsigned 8, 16, 32, or 64-bit little-endian integer */\n    Type[Type[\"Int\"] = 2] = \"Int\";\n    /** 2, 4, or 8-byte floating point value */\n    Type[Type[\"Float\"] = 3] = \"Float\";\n    /** Variable-length bytes (no guarantee of UTF8-ness) */\n    Type[Type[\"Binary\"] = 4] = \"Binary\";\n    /** UTF8 variable-length string as List<Char> */\n    Type[Type[\"Utf8\"] = 5] = \"Utf8\";\n    /** Boolean as 1 bit, LSB bit-packed ordering */\n    Type[Type[\"Bool\"] = 6] = \"Bool\";\n    /** Precision-and-scale-based decimal type. Storage type depends on the parameters. */\n    Type[Type[\"Decimal\"] = 7] = \"Decimal\";\n    /** int32_t days or int64_t milliseconds since the UNIX epoch */\n    Type[Type[\"Date\"] = 8] = \"Date\";\n    /** Time as signed 32 or 64-bit integer, representing either seconds, milliseconds, microseconds, or nanoseconds since midnight since midnight */\n    Type[Type[\"Time\"] = 9] = \"Time\";\n    /** Exact timestamp encoded with int64 since UNIX epoch (Default unit millisecond) */\n    Type[Type[\"Timestamp\"] = 10] = \"Timestamp\";\n    /** YEAR_MONTH or DAY_TIME interval in SQL style */\n    Type[Type[\"Interval\"] = 11] = \"Interval\";\n    /** A list of some logical data type */\n    Type[Type[\"List\"] = 12] = \"List\";\n    /** Struct of logical types */\n    Type[Type[\"Struct\"] = 13] = \"Struct\";\n    /** Union of logical types */\n    Type[Type[\"Union\"] = 14] = \"Union\";\n    /** Fixed-size binary. Each value occupies the same number of bytes */\n    Type[Type[\"FixedSizeBinary\"] = 15] = \"FixedSizeBinary\";\n    /** Fixed-size list. Each value occupies the same number of bytes */\n    Type[Type[\"FixedSizeList\"] = 16] = \"FixedSizeList\";\n    /** Map of named logical types */\n    Type[Type[\"Map\"] = 17] = \"Map\";\n    /** Dictionary aka Category type */\n    Type[Type[\"Dictionary\"] = -1] = \"Dictionary\";\n    Type[Type[\"Int8\"] = -2] = \"Int8\";\n    Type[Type[\"Int16\"] = -3] = \"Int16\";\n    Type[Type[\"Int32\"] = -4] = \"Int32\";\n    Type[Type[\"Int64\"] = -5] = \"Int64\";\n    Type[Type[\"Uint8\"] = -6] = \"Uint8\";\n    Type[Type[\"Uint16\"] = -7] = \"Uint16\";\n    Type[Type[\"Uint32\"] = -8] = \"Uint32\";\n    Type[Type[\"Uint64\"] = -9] = \"Uint64\";\n    Type[Type[\"Float16\"] = -10] = \"Float16\";\n    Type[Type[\"Float32\"] = -11] = \"Float32\";\n    Type[Type[\"Float64\"] = -12] = \"Float64\";\n    Type[Type[\"DateDay\"] = -13] = \"DateDay\";\n    Type[Type[\"DateMillisecond\"] = -14] = \"DateMillisecond\";\n    Type[Type[\"TimestampSecond\"] = -15] = \"TimestampSecond\";\n    Type[Type[\"TimestampMillisecond\"] = -16] = \"TimestampMillisecond\";\n    Type[Type[\"TimestampMicrosecond\"] = -17] = \"TimestampMicrosecond\";\n    Type[Type[\"TimestampNanosecond\"] = -18] = \"TimestampNanosecond\";\n    Type[Type[\"TimeSecond\"] = -19] = \"TimeSecond\";\n    Type[Type[\"TimeMillisecond\"] = -20] = \"TimeMillisecond\";\n    Type[Type[\"TimeMicrosecond\"] = -21] = \"TimeMicrosecond\";\n    Type[Type[\"TimeNanosecond\"] = -22] = \"TimeNanosecond\";\n    Type[Type[\"DenseUnion\"] = -23] = \"DenseUnion\";\n    Type[Type[\"SparseUnion\"] = -24] = \"SparseUnion\";\n    Type[Type[\"IntervalDayTime\"] = -25] = \"IntervalDayTime\";\n    Type[Type[\"IntervalYearMonth\"] = -26] = \"IntervalYearMonth\";\n})(Type || (Type = {}));\nvar BufferType;\n(function (BufferType) {\n    /**\n     * used in List type, Dense Union and variable length primitive types (String, Binary)\n     */\n    BufferType[BufferType[\"OFFSET\"] = 0] = \"OFFSET\";\n    /**\n     * actual data, either wixed width primitive types in slots or variable width delimited by an OFFSET vector\n     */\n    BufferType[BufferType[\"DATA\"] = 1] = \"DATA\";\n    /**\n     * Bit vector indicating if each value is null\n     */\n    BufferType[BufferType[\"VALIDITY\"] = 2] = \"VALIDITY\";\n    /**\n     * Type vector used in Union type\n     */\n    BufferType[BufferType[\"TYPE\"] = 3] = \"TYPE\";\n})(BufferType || (BufferType = {}));\n\n//# sourceMappingURL=enum.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/enum.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/fb/File.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/fb/File.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   org: () => (/* binding */ org)\n/* harmony export */ });\n/* harmony import */ var _Schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Schema */ \"../../node_modules/apache-arrow/fb/Schema.mjs\");\n// automatically generated by the FlatBuffers compiler, do not modify\n\n/**\n * ----------------------------------------------------------------------\n * Arrow File metadata\n *\n *\n * @constructor\n */\nvar org;\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Footer {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Footer\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Footer= obj\n                     * @returns Footer\n                     */\n                    static getRootAsFooter(bb, obj) {\n                        return (obj || new Footer).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.MetadataVersion\n                     */\n                    version() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.MetadataVersion.V1;\n                    }\n                    /**\n                     * @param org.apache.arrow.flatbuf.Schema= obj\n                     * @returns org.apache.arrow.flatbuf.Schema|null\n                     */\n                    schema(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? (obj || new _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Schema).__init(this.bb.__indirect(this.bb_pos + offset), this.bb) : null;\n                    }\n                    /**\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.Block= obj\n                     * @returns org.apache.arrow.flatbuf.Block\n                     */\n                    dictionaries(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.Block).__init(this.bb.__vector(this.bb_pos + offset) + index * 24, this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    dictionariesLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.Block= obj\n                     * @returns org.apache.arrow.flatbuf.Block\n                     */\n                    recordBatches(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 10);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.Block).__init(this.bb.__vector(this.bb_pos + offset) + index * 24, this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    recordBatchesLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 10);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startFooter(builder) {\n                        builder.startObject(4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.MetadataVersion version\n                     */\n                    static addVersion(builder, version) {\n                        builder.addFieldInt16(0, version, _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.MetadataVersion.V1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset schemaOffset\n                     */\n                    static addSchema(builder, schemaOffset) {\n                        builder.addFieldOffset(1, schemaOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset dictionariesOffset\n                     */\n                    static addDictionaries(builder, dictionariesOffset) {\n                        builder.addFieldOffset(2, dictionariesOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startDictionariesVector(builder, numElems) {\n                        builder.startVector(24, numElems, 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset recordBatchesOffset\n                     */\n                    static addRecordBatches(builder, recordBatchesOffset) {\n                        builder.addFieldOffset(3, recordBatchesOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startRecordBatchesVector(builder, numElems) {\n                        builder.startVector(24, numElems, 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endFooter(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset offset\n                     */\n                    static finishFooterBuffer(builder, offset) {\n                        builder.finish(offset);\n                    }\n                    static createFooter(builder, version, schemaOffset, dictionariesOffset, recordBatchesOffset) {\n                        Footer.startFooter(builder);\n                        Footer.addVersion(builder, version);\n                        Footer.addSchema(builder, schemaOffset);\n                        Footer.addDictionaries(builder, dictionariesOffset);\n                        Footer.addRecordBatches(builder, recordBatchesOffset);\n                        return Footer.endFooter(builder);\n                    }\n                }\n                flatbuf.Footer = Footer;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Block {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Block\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * Index to the start of the RecordBlock (note this is past the Message header)\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    offset() {\n                        return this.bb.readInt64(this.bb_pos);\n                    }\n                    /**\n                     * Length of the metadata\n                     *\n                     * @returns number\n                     */\n                    metaDataLength() {\n                        return this.bb.readInt32(this.bb_pos + 8);\n                    }\n                    /**\n                     * Length of the data (this is aligned so there can be a gap between this and\n                     * the metatdata).\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    bodyLength() {\n                        return this.bb.readInt64(this.bb_pos + 16);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long offset\n                     * @param number metaDataLength\n                     * @param flatbuffers.Long bodyLength\n                     * @returns flatbuffers.Offset\n                     */\n                    static createBlock(builder, offset, metaDataLength, bodyLength) {\n                        builder.prep(8, 24);\n                        builder.writeInt64(bodyLength);\n                        builder.pad(4);\n                        builder.writeInt32(metaDataLength);\n                        builder.writeInt64(offset);\n                        return builder.offset();\n                    }\n                }\n                flatbuf.Block = Block;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n\n//# sourceMappingURL=File.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/fb/File.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/fb/Message.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/fb/Message.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   org: () => (/* binding */ org)\n/* harmony export */ });\n/* harmony import */ var _Schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Schema */ \"../../node_modules/apache-arrow/fb/Schema.mjs\");\n// automatically generated by the FlatBuffers compiler, do not modify\n\nvar org;\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                flatbuf.Schema = _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Schema;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * The root Message type\n * This union enables us to easily send different message types without\n * redundant storage, and in the future we can easily add new message types.\n *\n * Arrow implementations do not need to implement all of the message types,\n * which may include experimental metadata types. For maximum compatibility,\n * it is best to send data using RecordBatch\n *\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let MessageHeader;\n                (function (MessageHeader) {\n                    MessageHeader[MessageHeader[\"NONE\"] = 0] = \"NONE\";\n                    MessageHeader[MessageHeader[\"Schema\"] = 1] = \"Schema\";\n                    MessageHeader[MessageHeader[\"DictionaryBatch\"] = 2] = \"DictionaryBatch\";\n                    MessageHeader[MessageHeader[\"RecordBatch\"] = 3] = \"RecordBatch\";\n                    MessageHeader[MessageHeader[\"Tensor\"] = 4] = \"Tensor\";\n                    MessageHeader[MessageHeader[\"SparseTensor\"] = 5] = \"SparseTensor\";\n                })(MessageHeader = flatbuf.MessageHeader || (flatbuf.MessageHeader = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * Data structures for describing a table row batch (a collection of\n * equal-length Arrow arrays)\n * Metadata about a field at some level of a nested type tree (but not\n * its children).\n *\n * For example, a List<Int16> with values [[1, 2, 3], null, [4], [5, 6], null]\n * would have {length: 5, null_count: 2} for its List node, and {length: 6,\n * null_count: 0} for its Int16 node, as separate FieldNode structs\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class FieldNode {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns FieldNode\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * The number of value slots in the Arrow array at this level of a nested\n                     * tree\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    length() {\n                        return this.bb.readInt64(this.bb_pos);\n                    }\n                    /**\n                     * The number of observed nulls. Fields with null_count == 0 may choose not\n                     * to write their physical validity bitmap out as a materialized buffer,\n                     * instead setting the length of the bitmap buffer to 0.\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    nullCount() {\n                        return this.bb.readInt64(this.bb_pos + 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long length\n                     * @param flatbuffers.Long null_count\n                     * @returns flatbuffers.Offset\n                     */\n                    static createFieldNode(builder, length, null_count) {\n                        builder.prep(8, 16);\n                        builder.writeInt64(null_count);\n                        builder.writeInt64(length);\n                        return builder.offset();\n                    }\n                }\n                flatbuf.FieldNode = FieldNode;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * A data header describing the shared memory layout of a \"record\" or \"row\"\n * batch. Some systems call this a \"row batch\" internally and others a \"record\n * batch\".\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class RecordBatch {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns RecordBatch\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param RecordBatch= obj\n                     * @returns RecordBatch\n                     */\n                    static getRootAsRecordBatch(bb, obj) {\n                        return (obj || new RecordBatch).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * number of records / rows. The arrays in the batch should all have this\n                     * length\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    length() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt64(this.bb_pos + offset) : this.bb.createLong(0, 0);\n                    }\n                    /**\n                     * Nodes correspond to the pre-ordered flattened logical schema\n                     *\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.FieldNode= obj\n                     * @returns org.apache.arrow.flatbuf.FieldNode\n                     */\n                    nodes(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.FieldNode).__init(this.bb.__vector(this.bb_pos + offset) + index * 16, this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    nodesLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * Buffers correspond to the pre-ordered flattened buffer tree\n                     *\n                     * The number of buffers appended to this list depends on the schema. For\n                     * example, most primitive arrays will have 2 buffers, 1 for the validity\n                     * bitmap and 1 for the values. For struct arrays, there will only be a\n                     * single buffer for the validity (nulls) bitmap\n                     *\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.Buffer= obj\n                     * @returns org.apache.arrow.flatbuf.Buffer\n                     */\n                    buffers(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? (obj || new _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Buffer).__init(this.bb.__vector(this.bb_pos + offset) + index * 16, this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    buffersLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startRecordBatch(builder) {\n                        builder.startObject(3);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long length\n                     */\n                    static addLength(builder, length) {\n                        builder.addFieldInt64(0, length, builder.createLong(0, 0));\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset nodesOffset\n                     */\n                    static addNodes(builder, nodesOffset) {\n                        builder.addFieldOffset(1, nodesOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startNodesVector(builder, numElems) {\n                        builder.startVector(16, numElems, 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset buffersOffset\n                     */\n                    static addBuffers(builder, buffersOffset) {\n                        builder.addFieldOffset(2, buffersOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startBuffersVector(builder, numElems) {\n                        builder.startVector(16, numElems, 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endRecordBatch(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createRecordBatch(builder, length, nodesOffset, buffersOffset) {\n                        RecordBatch.startRecordBatch(builder);\n                        RecordBatch.addLength(builder, length);\n                        RecordBatch.addNodes(builder, nodesOffset);\n                        RecordBatch.addBuffers(builder, buffersOffset);\n                        return RecordBatch.endRecordBatch(builder);\n                    }\n                }\n                flatbuf.RecordBatch = RecordBatch;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * For sending dictionary encoding information. Any Field can be\n * dictionary-encoded, but in this case none of its children may be\n * dictionary-encoded.\n * There is one vector / column per dictionary, but that vector / column\n * may be spread across multiple dictionary batches by using the isDelta\n * flag\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class DictionaryBatch {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns DictionaryBatch\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param DictionaryBatch= obj\n                     * @returns DictionaryBatch\n                     */\n                    static getRootAsDictionaryBatch(bb, obj) {\n                        return (obj || new DictionaryBatch).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns flatbuffers.Long\n                     */\n                    id() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt64(this.bb_pos + offset) : this.bb.createLong(0, 0);\n                    }\n                    /**\n                     * @param org.apache.arrow.flatbuf.RecordBatch= obj\n                     * @returns org.apache.arrow.flatbuf.RecordBatch|null\n                     */\n                    data(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.RecordBatch).__init(this.bb.__indirect(this.bb_pos + offset), this.bb) : null;\n                    }\n                    /**\n                     * If isDelta is true the values in the dictionary are to be appended to a\n                     * dictionary with the indicated id\n                     *\n                     * @returns boolean\n                     */\n                    isDelta() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startDictionaryBatch(builder) {\n                        builder.startObject(3);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long id\n                     */\n                    static addId(builder, id) {\n                        builder.addFieldInt64(0, id, builder.createLong(0, 0));\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset dataOffset\n                     */\n                    static addData(builder, dataOffset) {\n                        builder.addFieldOffset(1, dataOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param boolean isDelta\n                     */\n                    static addIsDelta(builder, isDelta) {\n                        builder.addFieldInt8(2, +isDelta, +false);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endDictionaryBatch(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createDictionaryBatch(builder, id, dataOffset, isDelta) {\n                        DictionaryBatch.startDictionaryBatch(builder);\n                        DictionaryBatch.addId(builder, id);\n                        DictionaryBatch.addData(builder, dataOffset);\n                        DictionaryBatch.addIsDelta(builder, isDelta);\n                        return DictionaryBatch.endDictionaryBatch(builder);\n                    }\n                }\n                flatbuf.DictionaryBatch = DictionaryBatch;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Message {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Message\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Message= obj\n                     * @returns Message\n                     */\n                    static getRootAsMessage(bb, obj) {\n                        return (obj || new Message).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.MetadataVersion\n                     */\n                    version() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.MetadataVersion.V1;\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.MessageHeader\n                     */\n                    headerType() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? /**  */ (this.bb.readUint8(this.bb_pos + offset)) : org.apache.arrow.flatbuf.MessageHeader.NONE;\n                    }\n                    /**\n                     * @param flatbuffers.Table obj\n                     * @returns ?flatbuffers.Table\n                     */\n                    header(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? this.bb.__union(obj, this.bb_pos + offset) : null;\n                    }\n                    /**\n                     * @returns flatbuffers.Long\n                     */\n                    bodyLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 10);\n                        return offset ? this.bb.readInt64(this.bb_pos + offset) : this.bb.createLong(0, 0);\n                    }\n                    /**\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.KeyValue= obj\n                     * @returns org.apache.arrow.flatbuf.KeyValue\n                     */\n                    customMetadata(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 12);\n                        return offset ? (obj || new _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.KeyValue).__init(this.bb.__indirect(this.bb.__vector(this.bb_pos + offset) + index * 4), this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    customMetadataLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 12);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startMessage(builder) {\n                        builder.startObject(5);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.MetadataVersion version\n                     */\n                    static addVersion(builder, version) {\n                        builder.addFieldInt16(0, version, _Schema__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.MetadataVersion.V1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.MessageHeader headerType\n                     */\n                    static addHeaderType(builder, headerType) {\n                        builder.addFieldInt8(1, headerType, org.apache.arrow.flatbuf.MessageHeader.NONE);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset headerOffset\n                     */\n                    static addHeader(builder, headerOffset) {\n                        builder.addFieldOffset(2, headerOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long bodyLength\n                     */\n                    static addBodyLength(builder, bodyLength) {\n                        builder.addFieldInt64(3, bodyLength, builder.createLong(0, 0));\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset customMetadataOffset\n                     */\n                    static addCustomMetadata(builder, customMetadataOffset) {\n                        builder.addFieldOffset(4, customMetadataOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<flatbuffers.Offset> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createCustomMetadataVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addOffset(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startCustomMetadataVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endMessage(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset offset\n                     */\n                    static finishMessageBuffer(builder, offset) {\n                        builder.finish(offset);\n                    }\n                    static createMessage(builder, version, headerType, headerOffset, bodyLength, customMetadataOffset) {\n                        Message.startMessage(builder);\n                        Message.addVersion(builder, version);\n                        Message.addHeaderType(builder, headerType);\n                        Message.addHeader(builder, headerOffset);\n                        Message.addBodyLength(builder, bodyLength);\n                        Message.addCustomMetadata(builder, customMetadataOffset);\n                        return Message.endMessage(builder);\n                    }\n                }\n                flatbuf.Message = Message;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n\n//# sourceMappingURL=Message.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/fb/Message.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/fb/Schema.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/fb/Schema.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   org: () => (/* binding */ org)\n/* harmony export */ });\n/* tslint:disable:class-name */\n/**\n * @enum {number}\n */\nvar org;\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let MetadataVersion;\n                (function (MetadataVersion) {\n                    /**\n                     * 0.1.0\n                     */\n                    MetadataVersion[MetadataVersion[\"V1\"] = 0] = \"V1\";\n                    /**\n                     * 0.2.0\n                     */\n                    MetadataVersion[MetadataVersion[\"V2\"] = 1] = \"V2\";\n                    /**\n                     * 0.3.0 -> 0.7.1\n                     */\n                    MetadataVersion[MetadataVersion[\"V3\"] = 2] = \"V3\";\n                    /**\n                     * >= 0.8.0\n                     */\n                    MetadataVersion[MetadataVersion[\"V4\"] = 3] = \"V4\";\n                })(MetadataVersion = flatbuf.MetadataVersion || (flatbuf.MetadataVersion = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let UnionMode;\n                (function (UnionMode) {\n                    UnionMode[UnionMode[\"Sparse\"] = 0] = \"Sparse\";\n                    UnionMode[UnionMode[\"Dense\"] = 1] = \"Dense\";\n                })(UnionMode = flatbuf.UnionMode || (flatbuf.UnionMode = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let Precision;\n                (function (Precision) {\n                    Precision[Precision[\"HALF\"] = 0] = \"HALF\";\n                    Precision[Precision[\"SINGLE\"] = 1] = \"SINGLE\";\n                    Precision[Precision[\"DOUBLE\"] = 2] = \"DOUBLE\";\n                })(Precision = flatbuf.Precision || (flatbuf.Precision = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let DateUnit;\n                (function (DateUnit) {\n                    DateUnit[DateUnit[\"DAY\"] = 0] = \"DAY\";\n                    DateUnit[DateUnit[\"MILLISECOND\"] = 1] = \"MILLISECOND\";\n                })(DateUnit = flatbuf.DateUnit || (flatbuf.DateUnit = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let TimeUnit;\n                (function (TimeUnit) {\n                    TimeUnit[TimeUnit[\"SECOND\"] = 0] = \"SECOND\";\n                    TimeUnit[TimeUnit[\"MILLISECOND\"] = 1] = \"MILLISECOND\";\n                    TimeUnit[TimeUnit[\"MICROSECOND\"] = 2] = \"MICROSECOND\";\n                    TimeUnit[TimeUnit[\"NANOSECOND\"] = 3] = \"NANOSECOND\";\n                })(TimeUnit = flatbuf.TimeUnit || (flatbuf.TimeUnit = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let IntervalUnit;\n                (function (IntervalUnit) {\n                    IntervalUnit[IntervalUnit[\"YEAR_MONTH\"] = 0] = \"YEAR_MONTH\";\n                    IntervalUnit[IntervalUnit[\"DAY_TIME\"] = 1] = \"DAY_TIME\";\n                })(IntervalUnit = flatbuf.IntervalUnit || (flatbuf.IntervalUnit = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * Top-level Type value, enabling extensible type-specific metadata. We can\n * add new logical types to Type without breaking backwards compatibility\n *\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let Type;\n                (function (Type) {\n                    Type[Type[\"NONE\"] = 0] = \"NONE\";\n                    Type[Type[\"Null\"] = 1] = \"Null\";\n                    Type[Type[\"Int\"] = 2] = \"Int\";\n                    Type[Type[\"FloatingPoint\"] = 3] = \"FloatingPoint\";\n                    Type[Type[\"Binary\"] = 4] = \"Binary\";\n                    Type[Type[\"Utf8\"] = 5] = \"Utf8\";\n                    Type[Type[\"Bool\"] = 6] = \"Bool\";\n                    Type[Type[\"Decimal\"] = 7] = \"Decimal\";\n                    Type[Type[\"Date\"] = 8] = \"Date\";\n                    Type[Type[\"Time\"] = 9] = \"Time\";\n                    Type[Type[\"Timestamp\"] = 10] = \"Timestamp\";\n                    Type[Type[\"Interval\"] = 11] = \"Interval\";\n                    Type[Type[\"List\"] = 12] = \"List\";\n                    Type[Type[\"Struct_\"] = 13] = \"Struct_\";\n                    Type[Type[\"Union\"] = 14] = \"Union\";\n                    Type[Type[\"FixedSizeBinary\"] = 15] = \"FixedSizeBinary\";\n                    Type[Type[\"FixedSizeList\"] = 16] = \"FixedSizeList\";\n                    Type[Type[\"Map\"] = 17] = \"Map\";\n                    Type[Type[\"Duration\"] = 18] = \"Duration\";\n                    Type[Type[\"LargeBinary\"] = 19] = \"LargeBinary\";\n                    Type[Type[\"LargeUtf8\"] = 20] = \"LargeUtf8\";\n                    Type[Type[\"LargeList\"] = 21] = \"LargeList\";\n                })(Type = flatbuf.Type || (flatbuf.Type = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * Endianness of the platform producing the data\n *\n * @enum {number}\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                let Endianness;\n                (function (Endianness) {\n                    Endianness[Endianness[\"Little\"] = 0] = \"Little\";\n                    Endianness[Endianness[\"Big\"] = 1] = \"Big\";\n                })(Endianness = flatbuf.Endianness || (flatbuf.Endianness = {}));\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * These are stored in the flatbuffer in the Type union below\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Null {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Null\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Null= obj\n                     * @returns Null\n                     */\n                    static getRootAsNull(bb, obj) {\n                        return (obj || new Null).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startNull(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endNull(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createNull(builder) {\n                        Null.startNull(builder);\n                        return Null.endNull(builder);\n                    }\n                }\n                flatbuf.Null = Null;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * A Struct_ in the flatbuffer metadata is the same as an Arrow Struct\n * (according to the physical memory layout). We used Struct_ here as\n * Struct is a reserved word in Flatbuffers\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Struct_ {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Struct_\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Struct_= obj\n                     * @returns Struct_\n                     */\n                    static getRootAsStruct_(bb, obj) {\n                        return (obj || new Struct_).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startStruct_(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endStruct_(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createStruct_(builder) {\n                        Struct_.startStruct_(builder);\n                        return Struct_.endStruct_(builder);\n                    }\n                }\n                flatbuf.Struct_ = Struct_;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class List {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns List\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param List= obj\n                     * @returns List\n                     */\n                    static getRootAsList(bb, obj) {\n                        return (obj || new List).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startList(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endList(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createList(builder) {\n                        List.startList(builder);\n                        return List.endList(builder);\n                    }\n                }\n                flatbuf.List = List;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Same as List, but with 64-bit offsets, allowing to represent\n * extremely large data values.\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class LargeList {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns LargeList\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param LargeList= obj\n                     * @returns LargeList\n                     */\n                    static getRootAsLargeList(bb, obj) {\n                        return (obj || new LargeList).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startLargeList(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endLargeList(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createLargeList(builder) {\n                        LargeList.startLargeList(builder);\n                        return LargeList.endLargeList(builder);\n                    }\n                }\n                flatbuf.LargeList = LargeList;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class FixedSizeList {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns FixedSizeList\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param FixedSizeList= obj\n                     * @returns FixedSizeList\n                     */\n                    static getRootAsFixedSizeList(bb, obj) {\n                        return (obj || new FixedSizeList).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * Number of list items per value\n                     *\n                     * @returns number\n                     */\n                    listSize() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startFixedSizeList(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number listSize\n                     */\n                    static addListSize(builder, listSize) {\n                        builder.addFieldInt32(0, listSize, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endFixedSizeList(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createFixedSizeList(builder, listSize) {\n                        FixedSizeList.startFixedSizeList(builder);\n                        FixedSizeList.addListSize(builder, listSize);\n                        return FixedSizeList.endFixedSizeList(builder);\n                    }\n                }\n                flatbuf.FixedSizeList = FixedSizeList;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * A Map is a logical nested type that is represented as\n *\n * List<entry: Struct<key: K, value: V>>\n *\n * In this layout, the keys and values are each respectively contiguous. We do\n * not constrain the key and value types, so the application is responsible\n * for ensuring that the keys are hashable and unique. Whether the keys are sorted\n * may be set in the metadata for this field\n *\n * In a Field with Map type, the Field has a child Struct field, which then\n * has two children: key type and the second the value type. The names of the\n * child fields may be respectively \"entry\", \"key\", and \"value\", but this is\n * not enforced\n *\n * Map\n *   - child[0] entry: Struct\n *     - child[0] key: K\n *     - child[1] value: V\n *\n * Neither the \"entry\" field nor the \"key\" field may be nullable.\n *\n * The metadata is structured so that Arrow systems without special handling\n * for Map can make Map an alias for List. The \"layout\" attribute for the Map\n * field must have the same contents as a List.\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Map {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Map\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Map= obj\n                     * @returns Map\n                     */\n                    static getRootAsMap(bb, obj) {\n                        return (obj || new Map).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * Set to true if the keys within each value are sorted\n                     *\n                     * @returns boolean\n                     */\n                    keysSorted() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startMap(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param boolean keysSorted\n                     */\n                    static addKeysSorted(builder, keysSorted) {\n                        builder.addFieldInt8(0, +keysSorted, +false);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endMap(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createMap(builder, keysSorted) {\n                        Map.startMap(builder);\n                        Map.addKeysSorted(builder, keysSorted);\n                        return Map.endMap(builder);\n                    }\n                }\n                flatbuf.Map = Map;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * A union is a complex type with children in Field\n * By default ids in the type vector refer to the offsets in the children\n * optionally typeIds provides an indirection between the child offset and the type id\n * for each child typeIds[offset] is the id used in the type vector\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Union {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Union\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Union= obj\n                     * @returns Union\n                     */\n                    static getRootAsUnion(bb, obj) {\n                        return (obj || new Union).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.UnionMode\n                     */\n                    mode() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.UnionMode.Sparse;\n                    }\n                    /**\n                     * @param number index\n                     * @returns number\n                     */\n                    typeIds(index) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.readInt32(this.bb.__vector(this.bb_pos + offset) + index * 4) : 0;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    typeIdsLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @returns Int32Array\n                     */\n                    typeIdsArray() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? new Int32Array(this.bb.bytes().buffer, this.bb.bytes().byteOffset + this.bb.__vector(this.bb_pos + offset), this.bb.__vector_len(this.bb_pos + offset)) : null;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startUnion(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.UnionMode mode\n                     */\n                    static addMode(builder, mode) {\n                        builder.addFieldInt16(0, mode, org.apache.arrow.flatbuf.UnionMode.Sparse);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset typeIdsOffset\n                     */\n                    static addTypeIds(builder, typeIdsOffset) {\n                        builder.addFieldOffset(1, typeIdsOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<number> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createTypeIdsVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addInt32(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startTypeIdsVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endUnion(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createUnion(builder, mode, typeIdsOffset) {\n                        Union.startUnion(builder);\n                        Union.addMode(builder, mode);\n                        Union.addTypeIds(builder, typeIdsOffset);\n                        return Union.endUnion(builder);\n                    }\n                }\n                flatbuf.Union = Union;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Int {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Int\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Int= obj\n                     * @returns Int\n                     */\n                    static getRootAsInt(bb, obj) {\n                        return (obj || new Int).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns number\n                     */\n                    bitWidth() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @returns boolean\n                     */\n                    isSigned() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startInt(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number bitWidth\n                     */\n                    static addBitWidth(builder, bitWidth) {\n                        builder.addFieldInt32(0, bitWidth, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param boolean isSigned\n                     */\n                    static addIsSigned(builder, isSigned) {\n                        builder.addFieldInt8(1, +isSigned, +false);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endInt(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createInt(builder, bitWidth, isSigned) {\n                        Int.startInt(builder);\n                        Int.addBitWidth(builder, bitWidth);\n                        Int.addIsSigned(builder, isSigned);\n                        return Int.endInt(builder);\n                    }\n                }\n                flatbuf.Int = Int;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class FloatingPoint {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns FloatingPoint\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param FloatingPoint= obj\n                     * @returns FloatingPoint\n                     */\n                    static getRootAsFloatingPoint(bb, obj) {\n                        return (obj || new FloatingPoint).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.Precision\n                     */\n                    precision() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.Precision.HALF;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startFloatingPoint(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.Precision precision\n                     */\n                    static addPrecision(builder, precision) {\n                        builder.addFieldInt16(0, precision, org.apache.arrow.flatbuf.Precision.HALF);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endFloatingPoint(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createFloatingPoint(builder, precision) {\n                        FloatingPoint.startFloatingPoint(builder);\n                        FloatingPoint.addPrecision(builder, precision);\n                        return FloatingPoint.endFloatingPoint(builder);\n                    }\n                }\n                flatbuf.FloatingPoint = FloatingPoint;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Unicode with UTF-8 encoding\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Utf8 {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Utf8\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Utf8= obj\n                     * @returns Utf8\n                     */\n                    static getRootAsUtf8(bb, obj) {\n                        return (obj || new Utf8).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startUtf8(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endUtf8(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createUtf8(builder) {\n                        Utf8.startUtf8(builder);\n                        return Utf8.endUtf8(builder);\n                    }\n                }\n                flatbuf.Utf8 = Utf8;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Opaque binary data\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Binary {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Binary\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Binary= obj\n                     * @returns Binary\n                     */\n                    static getRootAsBinary(bb, obj) {\n                        return (obj || new Binary).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startBinary(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endBinary(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createBinary(builder) {\n                        Binary.startBinary(builder);\n                        return Binary.endBinary(builder);\n                    }\n                }\n                flatbuf.Binary = Binary;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Same as Utf8, but with 64-bit offsets, allowing to represent\n * extremely large data values.\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class LargeUtf8 {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns LargeUtf8\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param LargeUtf8= obj\n                     * @returns LargeUtf8\n                     */\n                    static getRootAsLargeUtf8(bb, obj) {\n                        return (obj || new LargeUtf8).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startLargeUtf8(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endLargeUtf8(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createLargeUtf8(builder) {\n                        LargeUtf8.startLargeUtf8(builder);\n                        return LargeUtf8.endLargeUtf8(builder);\n                    }\n                }\n                flatbuf.LargeUtf8 = LargeUtf8;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Same as Binary, but with 64-bit offsets, allowing to represent\n * extremely large data values.\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class LargeBinary {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns LargeBinary\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param LargeBinary= obj\n                     * @returns LargeBinary\n                     */\n                    static getRootAsLargeBinary(bb, obj) {\n                        return (obj || new LargeBinary).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startLargeBinary(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endLargeBinary(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createLargeBinary(builder) {\n                        LargeBinary.startLargeBinary(builder);\n                        return LargeBinary.endLargeBinary(builder);\n                    }\n                }\n                flatbuf.LargeBinary = LargeBinary;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class FixedSizeBinary {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns FixedSizeBinary\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param FixedSizeBinary= obj\n                     * @returns FixedSizeBinary\n                     */\n                    static getRootAsFixedSizeBinary(bb, obj) {\n                        return (obj || new FixedSizeBinary).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * Number of bytes per value\n                     *\n                     * @returns number\n                     */\n                    byteWidth() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startFixedSizeBinary(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number byteWidth\n                     */\n                    static addByteWidth(builder, byteWidth) {\n                        builder.addFieldInt32(0, byteWidth, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endFixedSizeBinary(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createFixedSizeBinary(builder, byteWidth) {\n                        FixedSizeBinary.startFixedSizeBinary(builder);\n                        FixedSizeBinary.addByteWidth(builder, byteWidth);\n                        return FixedSizeBinary.endFixedSizeBinary(builder);\n                    }\n                }\n                flatbuf.FixedSizeBinary = FixedSizeBinary;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Bool {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Bool\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Bool= obj\n                     * @returns Bool\n                     */\n                    static getRootAsBool(bb, obj) {\n                        return (obj || new Bool).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startBool(builder) {\n                        builder.startObject(0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endBool(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createBool(builder) {\n                        Bool.startBool(builder);\n                        return Bool.endBool(builder);\n                    }\n                }\n                flatbuf.Bool = Bool;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Decimal {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Decimal\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Decimal= obj\n                     * @returns Decimal\n                     */\n                    static getRootAsDecimal(bb, obj) {\n                        return (obj || new Decimal).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * Total number of decimal digits\n                     *\n                     * @returns number\n                     */\n                    precision() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * Number of digits after the decimal point \".\"\n                     *\n                     * @returns number\n                     */\n                    scale() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startDecimal(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number precision\n                     */\n                    static addPrecision(builder, precision) {\n                        builder.addFieldInt32(0, precision, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number scale\n                     */\n                    static addScale(builder, scale) {\n                        builder.addFieldInt32(1, scale, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endDecimal(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createDecimal(builder, precision, scale) {\n                        Decimal.startDecimal(builder);\n                        Decimal.addPrecision(builder, precision);\n                        Decimal.addScale(builder, scale);\n                        return Decimal.endDecimal(builder);\n                    }\n                }\n                flatbuf.Decimal = Decimal;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Date is either a 32-bit or 64-bit type representing elapsed time since UNIX\n * epoch (1970-01-01), stored in either of two units:\n *\n * * Milliseconds (64 bits) indicating UNIX time elapsed since the epoch (no\n *   leap seconds), where the values are evenly divisible by 86400000\n * * Days (32 bits) since the UNIX epoch\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Date {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Date\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Date= obj\n                     * @returns Date\n                     */\n                    static getRootAsDate(bb, obj) {\n                        return (obj || new Date).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.DateUnit\n                     */\n                    unit() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.DateUnit.MILLISECOND;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startDate(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.DateUnit unit\n                     */\n                    static addUnit(builder, unit) {\n                        builder.addFieldInt16(0, unit, org.apache.arrow.flatbuf.DateUnit.MILLISECOND);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endDate(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createDate(builder, unit) {\n                        Date.startDate(builder);\n                        Date.addUnit(builder, unit);\n                        return Date.endDate(builder);\n                    }\n                }\n                flatbuf.Date = Date;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Time type. The physical storage type depends on the unit\n * - SECOND and MILLISECOND: 32 bits\n * - MICROSECOND and NANOSECOND: 64 bits\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Time {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Time\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Time= obj\n                     * @returns Time\n                     */\n                    static getRootAsTime(bb, obj) {\n                        return (obj || new Time).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.TimeUnit\n                     */\n                    unit() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.TimeUnit.MILLISECOND;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    bitWidth() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.readInt32(this.bb_pos + offset) : 32;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startTime(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.TimeUnit unit\n                     */\n                    static addUnit(builder, unit) {\n                        builder.addFieldInt16(0, unit, org.apache.arrow.flatbuf.TimeUnit.MILLISECOND);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number bitWidth\n                     */\n                    static addBitWidth(builder, bitWidth) {\n                        builder.addFieldInt32(1, bitWidth, 32);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endTime(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createTime(builder, unit, bitWidth) {\n                        Time.startTime(builder);\n                        Time.addUnit(builder, unit);\n                        Time.addBitWidth(builder, bitWidth);\n                        return Time.endTime(builder);\n                    }\n                }\n                flatbuf.Time = Time;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * Time elapsed from the Unix epoch, 00:00:00.000 on 1 January 1970, excluding\n * leap seconds, as a 64-bit integer. Note that UNIX time does not include\n * leap seconds.\n *\n * The Timestamp metadata supports both \"time zone naive\" and \"time zone\n * aware\" timestamps. Read about the timezone attribute for more detail\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Timestamp {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Timestamp\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Timestamp= obj\n                     * @returns Timestamp\n                     */\n                    static getRootAsTimestamp(bb, obj) {\n                        return (obj || new Timestamp).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.TimeUnit\n                     */\n                    unit() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.TimeUnit.SECOND;\n                    }\n                    timezone(optionalEncoding) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startTimestamp(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.TimeUnit unit\n                     */\n                    static addUnit(builder, unit) {\n                        builder.addFieldInt16(0, unit, org.apache.arrow.flatbuf.TimeUnit.SECOND);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset timezoneOffset\n                     */\n                    static addTimezone(builder, timezoneOffset) {\n                        builder.addFieldOffset(1, timezoneOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endTimestamp(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createTimestamp(builder, unit, timezoneOffset) {\n                        Timestamp.startTimestamp(builder);\n                        Timestamp.addUnit(builder, unit);\n                        Timestamp.addTimezone(builder, timezoneOffset);\n                        return Timestamp.endTimestamp(builder);\n                    }\n                }\n                flatbuf.Timestamp = Timestamp;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Interval {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Interval\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Interval= obj\n                     * @returns Interval\n                     */\n                    static getRootAsInterval(bb, obj) {\n                        return (obj || new Interval).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.IntervalUnit\n                     */\n                    unit() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.IntervalUnit.YEAR_MONTH;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startInterval(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.IntervalUnit unit\n                     */\n                    static addUnit(builder, unit) {\n                        builder.addFieldInt16(0, unit, org.apache.arrow.flatbuf.IntervalUnit.YEAR_MONTH);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endInterval(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createInterval(builder, unit) {\n                        Interval.startInterval(builder);\n                        Interval.addUnit(builder, unit);\n                        return Interval.endInterval(builder);\n                    }\n                }\n                flatbuf.Interval = Interval;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Duration {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Duration\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Duration= obj\n                     * @returns Duration\n                     */\n                    static getRootAsDuration(bb, obj) {\n                        return (obj || new Duration).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.TimeUnit\n                     */\n                    unit() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.TimeUnit.MILLISECOND;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startDuration(builder) {\n                        builder.startObject(1);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.TimeUnit unit\n                     */\n                    static addUnit(builder, unit) {\n                        builder.addFieldInt16(0, unit, org.apache.arrow.flatbuf.TimeUnit.MILLISECOND);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endDuration(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createDuration(builder, unit) {\n                        Duration.startDuration(builder);\n                        Duration.addUnit(builder, unit);\n                        return Duration.endDuration(builder);\n                    }\n                }\n                flatbuf.Duration = Duration;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * user defined key value pairs to add custom metadata to arrow\n * key namespacing is the responsibility of the user\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class KeyValue {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns KeyValue\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param KeyValue= obj\n                     * @returns KeyValue\n                     */\n                    static getRootAsKeyValue(bb, obj) {\n                        return (obj || new KeyValue).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    key(optionalEncoding) {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;\n                    }\n                    value(optionalEncoding) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startKeyValue(builder) {\n                        builder.startObject(2);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset keyOffset\n                     */\n                    static addKey(builder, keyOffset) {\n                        builder.addFieldOffset(0, keyOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset valueOffset\n                     */\n                    static addValue(builder, valueOffset) {\n                        builder.addFieldOffset(1, valueOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endKeyValue(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createKeyValue(builder, keyOffset, valueOffset) {\n                        KeyValue.startKeyValue(builder);\n                        KeyValue.addKey(builder, keyOffset);\n                        KeyValue.addValue(builder, valueOffset);\n                        return KeyValue.endKeyValue(builder);\n                    }\n                }\n                flatbuf.KeyValue = KeyValue;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * Dictionary encoding metadata\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class DictionaryEncoding {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns DictionaryEncoding\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param DictionaryEncoding= obj\n                     * @returns DictionaryEncoding\n                     */\n                    static getRootAsDictionaryEncoding(bb, obj) {\n                        return (obj || new DictionaryEncoding).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * The known dictionary id in the application where this data is used. In\n                     * the file or streaming formats, the dictionary ids are found in the\n                     * DictionaryBatch messages\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    id() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.readInt64(this.bb_pos + offset) : this.bb.createLong(0, 0);\n                    }\n                    /**\n                     * The dictionary indices are constrained to be positive integers. If this\n                     * field is null, the indices must be signed int32\n                     *\n                     * @param org.apache.arrow.flatbuf.Int= obj\n                     * @returns org.apache.arrow.flatbuf.Int|null\n                     */\n                    indexType(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.Int).__init(this.bb.__indirect(this.bb_pos + offset), this.bb) : null;\n                    }\n                    /**\n                     * By default, dictionaries are not ordered, or the order does not have\n                     * semantic meaning. In some statistical, applications, dictionary-encoding\n                     * is used to represent ordered categorical data, and we provide a way to\n                     * preserve that metadata here\n                     *\n                     * @returns boolean\n                     */\n                    isOrdered() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startDictionaryEncoding(builder) {\n                        builder.startObject(3);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long id\n                     */\n                    static addId(builder, id) {\n                        builder.addFieldInt64(0, id, builder.createLong(0, 0));\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset indexTypeOffset\n                     */\n                    static addIndexType(builder, indexTypeOffset) {\n                        builder.addFieldOffset(1, indexTypeOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param boolean isOrdered\n                     */\n                    static addIsOrdered(builder, isOrdered) {\n                        builder.addFieldInt8(2, +isOrdered, +false);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endDictionaryEncoding(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createDictionaryEncoding(builder, id, indexTypeOffset, isOrdered) {\n                        DictionaryEncoding.startDictionaryEncoding(builder);\n                        DictionaryEncoding.addId(builder, id);\n                        DictionaryEncoding.addIndexType(builder, indexTypeOffset);\n                        DictionaryEncoding.addIsOrdered(builder, isOrdered);\n                        return DictionaryEncoding.endDictionaryEncoding(builder);\n                    }\n                }\n                flatbuf.DictionaryEncoding = DictionaryEncoding;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * A field represents a named column in a record / row batch or child of a\n * nested type.\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Field {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Field\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Field= obj\n                     * @returns Field\n                     */\n                    static getRootAsField(bb, obj) {\n                        return (obj || new Field).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    name(optionalEncoding) {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;\n                    }\n                    /**\n                     * Whether or not this field can contain nulls. Should be true in general.\n                     *\n                     * @returns boolean\n                     */\n                    nullable() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;\n                    }\n                    /**\n                     * @returns org.apache.arrow.flatbuf.Type\n                     */\n                    typeType() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? /**  */ (this.bb.readUint8(this.bb_pos + offset)) : org.apache.arrow.flatbuf.Type.NONE;\n                    }\n                    /**\n                     * This is the type of the decoded value if the field is dictionary encoded.\n                     *\n                     * @param flatbuffers.Table obj\n                     * @returns ?flatbuffers.Table\n                     */\n                    type(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 10);\n                        return offset ? this.bb.__union(obj, this.bb_pos + offset) : null;\n                    }\n                    /**\n                     * Present only if the field is dictionary encoded.\n                     *\n                     * @param org.apache.arrow.flatbuf.DictionaryEncoding= obj\n                     * @returns org.apache.arrow.flatbuf.DictionaryEncoding|null\n                     */\n                    dictionary(obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 12);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.DictionaryEncoding).__init(this.bb.__indirect(this.bb_pos + offset), this.bb) : null;\n                    }\n                    /**\n                     * children apply only to nested data types like Struct, List and Union. For\n                     * primitive types children will have length 0.\n                     *\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.Field= obj\n                     * @returns org.apache.arrow.flatbuf.Field\n                     */\n                    children(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 14);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.Field).__init(this.bb.__indirect(this.bb.__vector(this.bb_pos + offset) + index * 4), this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    childrenLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 14);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * User-defined metadata\n                     *\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.KeyValue= obj\n                     * @returns org.apache.arrow.flatbuf.KeyValue\n                     */\n                    customMetadata(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 16);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.KeyValue).__init(this.bb.__indirect(this.bb.__vector(this.bb_pos + offset) + index * 4), this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    customMetadataLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 16);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startField(builder) {\n                        builder.startObject(7);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset nameOffset\n                     */\n                    static addName(builder, nameOffset) {\n                        builder.addFieldOffset(0, nameOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param boolean nullable\n                     */\n                    static addNullable(builder, nullable) {\n                        builder.addFieldInt8(1, +nullable, +false);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.Type typeType\n                     */\n                    static addTypeType(builder, typeType) {\n                        builder.addFieldInt8(2, typeType, org.apache.arrow.flatbuf.Type.NONE);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset typeOffset\n                     */\n                    static addType(builder, typeOffset) {\n                        builder.addFieldOffset(3, typeOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset dictionaryOffset\n                     */\n                    static addDictionary(builder, dictionaryOffset) {\n                        builder.addFieldOffset(4, dictionaryOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset childrenOffset\n                     */\n                    static addChildren(builder, childrenOffset) {\n                        builder.addFieldOffset(5, childrenOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<flatbuffers.Offset> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createChildrenVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addOffset(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startChildrenVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset customMetadataOffset\n                     */\n                    static addCustomMetadata(builder, customMetadataOffset) {\n                        builder.addFieldOffset(6, customMetadataOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<flatbuffers.Offset> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createCustomMetadataVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addOffset(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startCustomMetadataVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endField(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    static createField(builder, nameOffset, nullable, typeType, typeOffset, dictionaryOffset, childrenOffset, customMetadataOffset) {\n                        Field.startField(builder);\n                        Field.addName(builder, nameOffset);\n                        Field.addNullable(builder, nullable);\n                        Field.addTypeType(builder, typeType);\n                        Field.addType(builder, typeOffset);\n                        Field.addDictionary(builder, dictionaryOffset);\n                        Field.addChildren(builder, childrenOffset);\n                        Field.addCustomMetadata(builder, customMetadataOffset);\n                        return Field.endField(builder);\n                    }\n                }\n                flatbuf.Field = Field;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * A Buffer represents a single contiguous memory segment\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Buffer {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Buffer\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * The relative offset into the shared memory page where the bytes for this\n                     * buffer starts\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    offset() {\n                        return this.bb.readInt64(this.bb_pos);\n                    }\n                    /**\n                     * The absolute length (in bytes) of the memory buffer. The memory is found\n                     * from offset (inclusive) to offset + length (non-inclusive).\n                     *\n                     * @returns flatbuffers.Long\n                     */\n                    length() {\n                        return this.bb.readInt64(this.bb_pos + 8);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Long offset\n                     * @param flatbuffers.Long length\n                     * @returns flatbuffers.Offset\n                     */\n                    static createBuffer(builder, offset, length) {\n                        builder.prep(8, 16);\n                        builder.writeInt64(length);\n                        builder.writeInt64(offset);\n                        return builder.offset();\n                    }\n                }\n                flatbuf.Buffer = Buffer;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n/**\n * ----------------------------------------------------------------------\n * A Schema describes the columns in a row batch\n *\n * @constructor\n */\n(function (org) {\n    var apache;\n    (function (apache) {\n        var arrow;\n        (function (arrow) {\n            var flatbuf;\n            (function (flatbuf) {\n                class Schema {\n                    constructor() {\n                        this.bb = null;\n                        this.bb_pos = 0;\n                    }\n                    /**\n                     * @param number i\n                     * @param flatbuffers.ByteBuffer bb\n                     * @returns Schema\n                     */\n                    __init(i, bb) {\n                        this.bb_pos = i;\n                        this.bb = bb;\n                        return this;\n                    }\n                    /**\n                     * @param flatbuffers.ByteBuffer bb\n                     * @param Schema= obj\n                     * @returns Schema\n                     */\n                    static getRootAsSchema(bb, obj) {\n                        return (obj || new Schema).__init(bb.readInt32(bb.position()) + bb.position(), bb);\n                    }\n                    /**\n                     * endianness of the buffer\n                     * it is Little Endian by default\n                     * if endianness doesn't match the underlying system then the vectors need to be converted\n                     *\n                     * @returns org.apache.arrow.flatbuf.Endianness\n                     */\n                    endianness() {\n                        let offset = this.bb.__offset(this.bb_pos, 4);\n                        return offset ? /**  */ (this.bb.readInt16(this.bb_pos + offset)) : org.apache.arrow.flatbuf.Endianness.Little;\n                    }\n                    /**\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.Field= obj\n                     * @returns org.apache.arrow.flatbuf.Field\n                     */\n                    fields(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.Field).__init(this.bb.__indirect(this.bb.__vector(this.bb_pos + offset) + index * 4), this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    fieldsLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 6);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param number index\n                     * @param org.apache.arrow.flatbuf.KeyValue= obj\n                     * @returns org.apache.arrow.flatbuf.KeyValue\n                     */\n                    customMetadata(index, obj) {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? (obj || new org.apache.arrow.flatbuf.KeyValue).__init(this.bb.__indirect(this.bb.__vector(this.bb_pos + offset) + index * 4), this.bb) : null;\n                    }\n                    /**\n                     * @returns number\n                     */\n                    customMetadataLength() {\n                        let offset = this.bb.__offset(this.bb_pos, 8);\n                        return offset ? this.bb.__vector_len(this.bb_pos + offset) : 0;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     */\n                    static startSchema(builder) {\n                        builder.startObject(3);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param org.apache.arrow.flatbuf.Endianness endianness\n                     */\n                    static addEndianness(builder, endianness) {\n                        builder.addFieldInt16(0, endianness, org.apache.arrow.flatbuf.Endianness.Little);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset fieldsOffset\n                     */\n                    static addFields(builder, fieldsOffset) {\n                        builder.addFieldOffset(1, fieldsOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<flatbuffers.Offset> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createFieldsVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addOffset(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startFieldsVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset customMetadataOffset\n                     */\n                    static addCustomMetadata(builder, customMetadataOffset) {\n                        builder.addFieldOffset(2, customMetadataOffset, 0);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param Array.<flatbuffers.Offset> data\n                     * @returns flatbuffers.Offset\n                     */\n                    static createCustomMetadataVector(builder, data) {\n                        builder.startVector(4, data.length, 4);\n                        for (let i = data.length - 1; i >= 0; i--) {\n                            builder.addOffset(data[i]);\n                        }\n                        return builder.endVector();\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param number numElems\n                     */\n                    static startCustomMetadataVector(builder, numElems) {\n                        builder.startVector(4, numElems, 4);\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @returns flatbuffers.Offset\n                     */\n                    static endSchema(builder) {\n                        let offset = builder.endObject();\n                        return offset;\n                    }\n                    /**\n                     * @param flatbuffers.Builder builder\n                     * @param flatbuffers.Offset offset\n                     */\n                    static finishSchemaBuffer(builder, offset) {\n                        builder.finish(offset);\n                    }\n                    static createSchema(builder, endianness, fieldsOffset, customMetadataOffset) {\n                        Schema.startSchema(builder);\n                        Schema.addEndianness(builder, endianness);\n                        Schema.addFields(builder, fieldsOffset);\n                        Schema.addCustomMetadata(builder, customMetadataOffset);\n                        return Schema.endSchema(builder);\n                    }\n                }\n                flatbuf.Schema = Schema;\n            })(flatbuf = arrow.flatbuf || (arrow.flatbuf = {}));\n        })(arrow = apache.arrow || (apache.arrow = {}));\n    })(apache = org.apache || (org.apache = {}));\n})(org || (org = {}));\n\n//# sourceMappingURL=Schema.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/fb/Schema.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/adapters.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/io/adapters.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n    fromIterable(source) {\n        return pump(fromIterable(source));\n    },\n    fromAsyncIterable(source) {\n        return pump(fromAsyncIterable(source));\n    },\n    fromDOMStream(source) {\n        return pump(fromDOMStream(source));\n    },\n    fromNodeStream(stream) {\n        return pump(fromNodeStream(stream));\n    },\n    // @ts-ignore\n    toDOMStream(source, options) {\n        throw new Error(`\"toDOMStream\" not available in this environment`);\n    },\n    // @ts-ignore\n    toNodeStream(source, options) {\n        throw new Error(`\"toNodeStream\" not available in this environment`);\n    },\n});\n/** @ignore */\nconst pump = (iterator) => { iterator.next(); return iterator; };\n/** @ignore */\nfunction* fromIterable(source) {\n    let done, threw = false;\n    let buffers = [], buffer;\n    let cmd, size, bufferLength = 0;\n    function byteRange() {\n        if (cmd === 'peek') {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size)[0];\n        }\n        [buffer, buffers, bufferLength] = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size);\n        return buffer;\n    }\n    // Yield so the caller can inject the read command before creating the source Iterator\n    ({ cmd, size } = yield null);\n    // initialize the iterator\n    let it = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8ArrayIterator)(source)[Symbol.iterator]();\n    try {\n        do {\n            // read the next value\n            ({ done, value: buffer } = isNaN(size - bufferLength) ?\n                it.next(undefined) : it.next(size - bufferLength));\n            // if chunk is not null or empty, push it onto the queue\n            if (!done && buffer.byteLength > 0) {\n                buffers.push(buffer);\n                bufferLength += buffer.byteLength;\n            }\n            // If we have enough bytes in our buffer, yield chunks until we don't\n            if (done || size <= bufferLength) {\n                do {\n                    ({ cmd, size } = yield byteRange());\n                } while (size < bufferLength);\n            }\n        } while (!done);\n    }\n    catch (e) {\n        (threw = true) && (typeof it.throw === 'function') && (it.throw(e));\n    }\n    finally {\n        (threw === false) && (typeof it.return === 'function') && (it.return(null));\n    }\n    return null;\n}\n/** @ignore */\nasync function* fromAsyncIterable(source) {\n    let done, threw = false;\n    let buffers = [], buffer;\n    let cmd, size, bufferLength = 0;\n    function byteRange() {\n        if (cmd === 'peek') {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size)[0];\n        }\n        [buffer, buffers, bufferLength] = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size);\n        return buffer;\n    }\n    // Yield so the caller can inject the read command before creating the source AsyncIterator\n    ({ cmd, size } = (yield null));\n    // initialize the iterator\n    let it = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8ArrayAsyncIterator)(source)[Symbol.asyncIterator]();\n    try {\n        do {\n            // read the next value\n            ({ done, value: buffer } = isNaN(size - bufferLength)\n                ? await it.next(undefined)\n                : await it.next(size - bufferLength));\n            // if chunk is not null or empty, push it onto the queue\n            if (!done && buffer.byteLength > 0) {\n                buffers.push(buffer);\n                bufferLength += buffer.byteLength;\n            }\n            // If we have enough bytes in our buffer, yield chunks until we don't\n            if (done || size <= bufferLength) {\n                do {\n                    ({ cmd, size } = yield byteRange());\n                } while (size < bufferLength);\n            }\n        } while (!done);\n    }\n    catch (e) {\n        (threw = true) && (typeof it.throw === 'function') && (await it.throw(e));\n    }\n    finally {\n        (threw === false) && (typeof it.return === 'function') && (await it.return(new Uint8Array(0)));\n    }\n    return null;\n}\n// All this manual Uint8Array chunk management can be avoided if/when engines\n// add support for ArrayBuffer.transfer() or ArrayBuffer.prototype.realloc():\n// https://github.com/domenic/proposal-arraybuffer-transfer\n/** @ignore */\nasync function* fromDOMStream(source) {\n    let done = false, threw = false;\n    let buffers = [], buffer;\n    let cmd, size, bufferLength = 0;\n    function byteRange() {\n        if (cmd === 'peek') {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size)[0];\n        }\n        [buffer, buffers, bufferLength] = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size);\n        return buffer;\n    }\n    // Yield so the caller can inject the read command before we establish the ReadableStream lock\n    ({ cmd, size } = yield null);\n    // initialize the reader and lock the stream\n    let it = new AdaptiveByteReader(source);\n    try {\n        do {\n            // read the next value\n            ({ done, value: buffer } = isNaN(size - bufferLength)\n                ? await it['read'](undefined)\n                : await it['read'](size - bufferLength));\n            // if chunk is not null or empty, push it onto the queue\n            if (!done && buffer.byteLength > 0) {\n                buffers.push((0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(buffer));\n                bufferLength += buffer.byteLength;\n            }\n            // If we have enough bytes in our buffer, yield chunks until we don't\n            if (done || size <= bufferLength) {\n                do {\n                    ({ cmd, size } = yield byteRange());\n                } while (size < bufferLength);\n            }\n        } while (!done);\n    }\n    catch (e) {\n        (threw = true) && (await it['cancel'](e));\n    }\n    finally {\n        (threw === false) ? (await it['cancel']())\n            : source['locked'] && it.releaseLock();\n    }\n    return null;\n}\n/** @ignore */\nclass AdaptiveByteReader {\n    constructor(source) {\n        this.source = source;\n        this.byobReader = null;\n        this.defaultReader = null;\n        try {\n            this.supportsBYOB = !!(this.reader = this.getBYOBReader());\n        }\n        catch (e) {\n            this.supportsBYOB = !!!(this.reader = this.getDefaultReader());\n        }\n    }\n    get closed() {\n        return this.reader ? this.reader['closed'].catch(() => { }) : Promise.resolve();\n    }\n    releaseLock() {\n        if (this.reader) {\n            this.reader.releaseLock();\n        }\n        this.reader = this.byobReader = this.defaultReader = null;\n    }\n    async cancel(reason) {\n        const { reader, source } = this;\n        reader && (await reader['cancel'](reason).catch(() => { }));\n        source && (source['locked'] && this.releaseLock());\n    }\n    async read(size) {\n        if (size === 0) {\n            return { done: this.reader == null, value: new Uint8Array(0) };\n        }\n        const result = !this.supportsBYOB || typeof size !== 'number'\n            ? await this.getDefaultReader().read()\n            : await this.readFromBYOBReader(size);\n        !result.done && (result.value = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(result));\n        return result;\n    }\n    getDefaultReader() {\n        if (this.byobReader) {\n            this.releaseLock();\n        }\n        if (!this.defaultReader) {\n            this.defaultReader = this.source['getReader']();\n            // We have to catch and swallow errors here to avoid uncaught promise rejection exceptions\n            // that seem to be raised when we call `releaseLock()` on this reader. I'm still mystified\n            // about why these errors are raised, but I'm sure there's some important spec reason that\n            // I haven't considered. I hate to employ such an anti-pattern here, but it seems like the\n            // only solution in this case :/\n            this.defaultReader['closed'].catch(() => { });\n        }\n        return (this.reader = this.defaultReader);\n    }\n    getBYOBReader() {\n        if (this.defaultReader) {\n            this.releaseLock();\n        }\n        if (!this.byobReader) {\n            this.byobReader = this.source['getReader']({ mode: 'byob' });\n            // We have to catch and swallow errors here to avoid uncaught promise rejection exceptions\n            // that seem to be raised when we call `releaseLock()` on this reader. I'm still mystified\n            // about why these errors are raised, but I'm sure there's some important spec reason that\n            // I haven't considered. I hate to employ such an anti-pattern here, but it seems like the\n            // only solution in this case :/\n            this.byobReader['closed'].catch(() => { });\n        }\n        return (this.reader = this.byobReader);\n    }\n    // This strategy plucked from the example in the streams spec:\n    // https://streams.spec.whatwg.org/#example-manual-read-bytes\n    async readFromBYOBReader(size) {\n        return await readInto(this.getBYOBReader(), new ArrayBuffer(size), 0, size);\n    }\n}\n/** @ignore */\nasync function readInto(reader, buffer, offset, size) {\n    if (offset >= size) {\n        return { done: false, value: new Uint8Array(buffer, 0, size) };\n    }\n    const { done, value } = await reader.read(new Uint8Array(buffer, offset, size - offset));\n    if (((offset += value.byteLength) < size) && !done) {\n        return await readInto(reader, value.buffer, offset, size);\n    }\n    return { done, value: new Uint8Array(value.buffer, 0, offset) };\n}\n/** @ignore */\nconst onEvent = (stream, event) => {\n    let handler = (_) => resolve([event, _]);\n    let resolve;\n    return [event, handler, new Promise((r) => (resolve = r) && stream['once'](event, handler))];\n};\n/** @ignore */\nasync function* fromNodeStream(stream) {\n    let events = [];\n    let event = 'error';\n    let done = false, err = null;\n    let cmd, size, bufferLength = 0;\n    let buffers = [], buffer;\n    function byteRange() {\n        if (cmd === 'peek') {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size)[0];\n        }\n        [buffer, buffers, bufferLength] = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.joinUint8Arrays)(buffers, size);\n        return buffer;\n    }\n    // Yield so the caller can inject the read command before we\n    // add the listener for the source stream's 'readable' event.\n    ({ cmd, size } = yield null);\n    // ignore stdin if it's a TTY\n    if (stream['isTTY']) {\n        yield new Uint8Array(0);\n        return null;\n    }\n    try {\n        // initialize the stream event handlers\n        events[0] = onEvent(stream, 'end');\n        events[1] = onEvent(stream, 'error');\n        do {\n            events[2] = onEvent(stream, 'readable');\n            // wait on the first message event from the stream\n            [event, err] = await Promise.race(events.map((x) => x[2]));\n            // if the stream emitted an Error, rethrow it\n            if (event === 'error') {\n                break;\n            }\n            if (!(done = event === 'end')) {\n                // If the size is NaN, request to read everything in the stream's internal buffer\n                if (!isFinite(size - bufferLength)) {\n                    buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(stream['read'](undefined));\n                }\n                else {\n                    buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(stream['read'](size - bufferLength));\n                    // If the byteLength is 0, then the requested amount is more than the stream has\n                    // in its internal buffer. In this case the stream needs a \"kick\" to tell it to\n                    // continue emitting readable events, so request to read everything the stream\n                    // has in its internal buffer right now.\n                    if (buffer.byteLength < (size - bufferLength)) {\n                        buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(stream['read'](undefined));\n                    }\n                }\n                // if chunk is not null or empty, push it onto the queue\n                if (buffer.byteLength > 0) {\n                    buffers.push(buffer);\n                    bufferLength += buffer.byteLength;\n                }\n            }\n            // If we have enough bytes in our buffer, yield chunks until we don't\n            if (done || size <= bufferLength) {\n                do {\n                    ({ cmd, size } = yield byteRange());\n                } while (size < bufferLength);\n            }\n        } while (!done);\n    }\n    finally {\n        await cleanup(events, event === 'error' ? err : null);\n    }\n    return null;\n    function cleanup(events, err) {\n        buffer = buffers = null;\n        return new Promise(async (resolve, reject) => {\n            for (const [evt, fn] of events) {\n                stream['off'](evt, fn);\n            }\n            try {\n                // Some stream implementations don't call the destroy callback,\n                // because it's really a node-internal API. Just calling `destroy`\n                // here should be enough to conform to the ReadableStream contract\n                const destroy = stream['destroy'];\n                destroy && destroy.call(stream, err);\n                err = undefined;\n            }\n            catch (e) {\n                err = e || err;\n            }\n            finally {\n                err != null ? reject(err) : resolve();\n            }\n        });\n    }\n}\n\n//# sourceMappingURL=adapters.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/adapters.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/file.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/io/file.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AsyncRandomAccessFile: () => (/* binding */ AsyncRandomAccessFile),\n/* harmony export */   RandomAccessFile: () => (/* binding */ RandomAccessFile)\n/* harmony export */ });\n/* harmony import */ var _stream__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nclass RandomAccessFile extends _stream__WEBPACK_IMPORTED_MODULE_0__.ByteStream {\n    constructor(buffer, byteLength) {\n        super();\n        this.position = 0;\n        this.buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_1__.toUint8Array)(buffer);\n        this.size = typeof byteLength === 'undefined' ? this.buffer.byteLength : byteLength;\n    }\n    readInt32(position) {\n        const { buffer, byteOffset } = this.readAt(position, 4);\n        return new DataView(buffer, byteOffset).getInt32(0, true);\n    }\n    seek(position) {\n        this.position = Math.min(position, this.size);\n        return position < this.size;\n    }\n    read(nBytes) {\n        const { buffer, size, position } = this;\n        if (buffer && position < size) {\n            if (typeof nBytes !== 'number') {\n                nBytes = Infinity;\n            }\n            this.position = Math.min(size, position + Math.min(size - position, nBytes));\n            return buffer.subarray(position, this.position);\n        }\n        return null;\n    }\n    readAt(position, nBytes) {\n        const buf = this.buffer;\n        const end = Math.min(this.size, position + nBytes);\n        return buf ? buf.subarray(position, end) : new Uint8Array(nBytes);\n    }\n    close() { this.buffer && (this.buffer = null); }\n    throw(value) { this.close(); return { done: true, value }; }\n    return(value) { this.close(); return { done: true, value }; }\n}\n/** @ignore */\nclass AsyncRandomAccessFile extends _stream__WEBPACK_IMPORTED_MODULE_0__.AsyncByteStream {\n    constructor(file, byteLength) {\n        super();\n        this.position = 0;\n        this._handle = file;\n        if (typeof byteLength === 'number') {\n            this.size = byteLength;\n        }\n        else {\n            this._pending = (async () => {\n                this.size = (await file.stat()).size;\n                delete this._pending;\n            })();\n        }\n    }\n    async readInt32(position) {\n        const { buffer, byteOffset } = await this.readAt(position, 4);\n        return new DataView(buffer, byteOffset).getInt32(0, true);\n    }\n    async seek(position) {\n        this._pending && await this._pending;\n        this.position = Math.min(position, this.size);\n        return position < this.size;\n    }\n    async read(nBytes) {\n        this._pending && await this._pending;\n        const { _handle: file, size, position } = this;\n        if (file && position < size) {\n            if (typeof nBytes !== 'number') {\n                nBytes = Infinity;\n            }\n            let pos = position, offset = 0, bytesRead = 0;\n            let end = Math.min(size, pos + Math.min(size - pos, nBytes));\n            let buffer = new Uint8Array(Math.max(0, (this.position = end) - pos));\n            while ((pos += bytesRead) < end && (offset += bytesRead) < buffer.byteLength) {\n                ({ bytesRead } = await file.read(buffer, offset, buffer.byteLength - offset, pos));\n            }\n            return buffer;\n        }\n        return null;\n    }\n    async readAt(position, nBytes) {\n        this._pending && await this._pending;\n        const { _handle: file, size } = this;\n        if (file && (position + nBytes) < size) {\n            const end = Math.min(size, position + nBytes);\n            const buffer = new Uint8Array(end - position);\n            return (await file.read(buffer, 0, nBytes, position)).buffer;\n        }\n        return new Uint8Array(nBytes);\n    }\n    async close() { const f = this._handle; this._handle = null; f && await f.close(); }\n    async throw(value) { await this.close(); return { done: true, value }; }\n    async return(value) { await this.close(); return { done: true, value }; }\n}\n\n//# sourceMappingURL=file.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/file.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/interfaces.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/io/interfaces.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ArrowJSON: () => (/* binding */ ArrowJSON),\n/* harmony export */   AsyncQueue: () => (/* binding */ AsyncQueue),\n/* harmony export */   ITERATOR_DONE: () => (/* binding */ ITERATOR_DONE),\n/* harmony export */   ReadableInterop: () => (/* binding */ ReadableInterop)\n/* harmony export */ });\n/* harmony import */ var _adapters__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./adapters */ \"../../node_modules/apache-arrow/io/adapters.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nconst ITERATOR_DONE = Object.freeze({ done: true, value: void (0) });\n/** @ignore */\nclass ArrowJSON {\n    // @ts-ignore\n    constructor(_json) {\n        this._json = _json;\n    }\n    get schema() { return this._json['schema']; }\n    get batches() { return (this._json['batches'] || []); }\n    get dictionaries() { return (this._json['dictionaries'] || []); }\n}\n/** @ignore */\nclass ReadableInterop {\n    tee() {\n        return this._getDOMStream().tee();\n    }\n    pipe(writable, options) {\n        return this._getNodeStream().pipe(writable, options);\n    }\n    pipeTo(writable, options) { return this._getDOMStream().pipeTo(writable, options); }\n    pipeThrough(duplex, options) {\n        return this._getDOMStream().pipeThrough(duplex, options);\n    }\n    _getDOMStream() {\n        return this._DOMStream || (this._DOMStream = this.toDOMStream());\n    }\n    _getNodeStream() {\n        return this._nodeStream || (this._nodeStream = this.toNodeStream());\n    }\n}\n/** @ignore */\nclass AsyncQueue extends ReadableInterop {\n    constructor() {\n        super();\n        this._values = [];\n        this.resolvers = [];\n        this._closedPromise = new Promise((r) => this._closedPromiseResolve = r);\n    }\n    get closed() { return this._closedPromise; }\n    async cancel(reason) { await this.return(reason); }\n    write(value) {\n        if (this._ensureOpen()) {\n            this.resolvers.length <= 0\n                ? (this._values.push(value))\n                : (this.resolvers.shift().resolve({ done: false, value }));\n        }\n    }\n    abort(value) {\n        if (this._closedPromiseResolve) {\n            this.resolvers.length <= 0\n                ? (this._error = { error: value })\n                : (this.resolvers.shift().reject({ done: true, value }));\n        }\n    }\n    close() {\n        if (this._closedPromiseResolve) {\n            const { resolvers } = this;\n            while (resolvers.length > 0) {\n                resolvers.shift().resolve(ITERATOR_DONE);\n            }\n            this._closedPromiseResolve();\n            this._closedPromiseResolve = undefined;\n        }\n    }\n    [Symbol.asyncIterator]() { return this; }\n    toDOMStream(options) {\n        return _adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].toDOMStream((this._closedPromiseResolve || this._error)\n            ? this\n            : this._values, options);\n    }\n    toNodeStream(options) {\n        return _adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].toNodeStream((this._closedPromiseResolve || this._error)\n            ? this\n            : this._values, options);\n    }\n    async throw(_) { await this.abort(_); return ITERATOR_DONE; }\n    async return(_) { await this.close(); return ITERATOR_DONE; }\n    async read(size) { return (await this.next(size, 'read')).value; }\n    async peek(size) { return (await this.next(size, 'peek')).value; }\n    next(..._args) {\n        if (this._values.length > 0) {\n            return Promise.resolve({ done: false, value: this._values.shift() });\n        }\n        else if (this._error) {\n            return Promise.reject({ done: true, value: this._error.error });\n        }\n        else if (!this._closedPromiseResolve) {\n            return Promise.resolve(ITERATOR_DONE);\n        }\n        else {\n            return new Promise((resolve, reject) => {\n                this.resolvers.push({ resolve, reject });\n            });\n        }\n    }\n    _ensureOpen() {\n        if (this._closedPromiseResolve) {\n            return true;\n        }\n        throw new Error(`${this} is closed`);\n    }\n}\n\n//# sourceMappingURL=interfaces.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/interfaces.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/stream.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/io/stream.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AsyncByteQueue: () => (/* binding */ AsyncByteQueue),\n/* harmony export */   AsyncByteStream: () => (/* binding */ AsyncByteStream),\n/* harmony export */   ByteStream: () => (/* binding */ ByteStream)\n/* harmony export */ });\n/* harmony import */ var _adapters__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./adapters */ \"../../node_modules/apache-arrow/io/adapters.mjs\");\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _interfaces__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./interfaces */ \"../../node_modules/apache-arrow/io/interfaces.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */\nclass AsyncByteQueue extends _interfaces__WEBPACK_IMPORTED_MODULE_2__.AsyncQueue {\n    write(value) {\n        if ((value = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.toUint8Array)(value)).byteLength > 0) {\n            return super.write(value);\n        }\n    }\n    toString(sync = false) {\n        return sync\n            ? (0,_util_utf8__WEBPACK_IMPORTED_MODULE_1__.decodeUtf8)(this.toUint8Array(true))\n            : this.toUint8Array(false).then(_util_utf8__WEBPACK_IMPORTED_MODULE_1__.decodeUtf8);\n    }\n    toUint8Array(sync = false) {\n        return sync ? (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.joinUint8Arrays)(this._values)[0] : (async () => {\n            let buffers = [], byteLength = 0;\n            for await (const chunk of this) {\n                buffers.push(chunk);\n                byteLength += chunk.byteLength;\n            }\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.joinUint8Arrays)(buffers, byteLength)[0];\n        })();\n    }\n}\n/** @ignore */\nclass ByteStream {\n    constructor(source) {\n        if (source) {\n            this.source = new ByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromIterable(source));\n        }\n    }\n    [Symbol.iterator]() { return this; }\n    next(value) { return this.source.next(value); }\n    throw(value) { return this.source.throw(value); }\n    return(value) { return this.source.return(value); }\n    peek(size) { return this.source.peek(size); }\n    read(size) { return this.source.read(size); }\n}\n/** @ignore */\nclass AsyncByteStream {\n    constructor(source) {\n        if (source instanceof AsyncByteStream) {\n            this.source = source.source;\n        }\n        else if (source instanceof AsyncByteQueue) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromAsyncIterable(source));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isReadableNodeStream)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromNodeStream(source));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isReadableDOMStream)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromDOMStream(source));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isFetchResponse)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromDOMStream(source.body));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isIterable)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromIterable(source));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isPromise)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromAsyncIterable(source));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_4__.isAsyncIterable)(source)) {\n            this.source = new AsyncByteStreamSource(_adapters__WEBPACK_IMPORTED_MODULE_0__[\"default\"].fromAsyncIterable(source));\n        }\n    }\n    [Symbol.asyncIterator]() { return this; }\n    next(value) { return this.source.next(value); }\n    throw(value) { return this.source.throw(value); }\n    return(value) { return this.source.return(value); }\n    get closed() { return this.source.closed; }\n    cancel(reason) { return this.source.cancel(reason); }\n    peek(size) { return this.source.peek(size); }\n    read(size) { return this.source.read(size); }\n}\n/** @ignore */\nclass ByteStreamSource {\n    constructor(source) {\n        this.source = source;\n    }\n    cancel(reason) { this.return(reason); }\n    peek(size) { return this.next(size, 'peek').value; }\n    read(size) { return this.next(size, 'read').value; }\n    next(size, cmd = 'read') { return this.source.next({ cmd, size }); }\n    throw(value) { return Object.create((this.source.throw && this.source.throw(value)) || _interfaces__WEBPACK_IMPORTED_MODULE_2__.ITERATOR_DONE); }\n    return(value) { return Object.create((this.source.return && this.source.return(value)) || _interfaces__WEBPACK_IMPORTED_MODULE_2__.ITERATOR_DONE); }\n}\n/** @ignore */\nclass AsyncByteStreamSource {\n    constructor(source) {\n        this.source = source;\n        this._closedPromise = new Promise((r) => this._closedPromiseResolve = r);\n    }\n    async cancel(reason) { await this.return(reason); }\n    get closed() { return this._closedPromise; }\n    async read(size) { return (await this.next(size, 'read')).value; }\n    async peek(size) { return (await this.next(size, 'peek')).value; }\n    async next(size, cmd = 'read') { return (await this.source.next({ cmd, size })); }\n    async throw(value) {\n        const result = (this.source.throw && await this.source.throw(value)) || _interfaces__WEBPACK_IMPORTED_MODULE_2__.ITERATOR_DONE;\n        this._closedPromiseResolve && this._closedPromiseResolve();\n        this._closedPromiseResolve = undefined;\n        return Object.create(result);\n    }\n    async return(value) {\n        const result = (this.source.return && await this.source.return(value)) || _interfaces__WEBPACK_IMPORTED_MODULE_2__.ITERATOR_DONE;\n        this._closedPromiseResolve && this._closedPromiseResolve();\n        this._closedPromiseResolve = undefined;\n        return Object.create(result);\n    }\n}\n\n//# sourceMappingURL=stream.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/stream.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/whatwg/builder.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/io/whatwg/builder.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BuilderTransform: () => (/* binding */ BuilderTransform),\n/* harmony export */   builderThroughDOMStream: () => (/* binding */ builderThroughDOMStream)\n/* harmony export */ });\n/* harmony import */ var _builder_index__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../builder/index */ \"../../node_modules/apache-arrow/builder/index.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nfunction builderThroughDOMStream(options) {\n    return new BuilderTransform(options);\n}\n/** @ignore */\nclass BuilderTransform {\n    constructor(options) {\n        // Access properties by string indexers to defeat closure compiler\n        this._numChunks = 0;\n        this._finished = false;\n        this._bufferedSize = 0;\n        const { ['readableStrategy']: readableStrategy, ['writableStrategy']: writableStrategy, ['queueingStrategy']: queueingStrategy = 'count', ...builderOptions } = options;\n        this._controller = null;\n        this._builder = _builder_index__WEBPACK_IMPORTED_MODULE_0__.Builder.new(builderOptions);\n        this._getSize = queueingStrategy !== 'bytes' ? chunkLength : chunkByteLength;\n        const { ['highWaterMark']: readableHighWaterMark = queueingStrategy === 'bytes' ? 2 ** 14 : 1000 } = { ...readableStrategy };\n        const { ['highWaterMark']: writableHighWaterMark = queueingStrategy === 'bytes' ? 2 ** 14 : 1000 } = { ...writableStrategy };\n        this['readable'] = new ReadableStream({\n            ['cancel']: () => { this._builder.clear(); },\n            ['pull']: (c) => { this._maybeFlush(this._builder, this._controller = c); },\n            ['start']: (c) => { this._maybeFlush(this._builder, this._controller = c); },\n        }, {\n            'highWaterMark': readableHighWaterMark,\n            'size': queueingStrategy !== 'bytes' ? chunkLength : chunkByteLength,\n        });\n        this['writable'] = new WritableStream({\n            ['abort']: () => { this._builder.clear(); },\n            ['write']: () => { this._maybeFlush(this._builder, this._controller); },\n            ['close']: () => { this._maybeFlush(this._builder.finish(), this._controller); },\n        }, {\n            'highWaterMark': writableHighWaterMark,\n            'size': (value) => this._writeValueAndReturnChunkSize(value),\n        });\n    }\n    _writeValueAndReturnChunkSize(value) {\n        const bufferedSize = this._bufferedSize;\n        this._bufferedSize = this._getSize(this._builder.append(value));\n        return this._bufferedSize - bufferedSize;\n    }\n    _maybeFlush(builder, controller) {\n        if (controller === null) {\n            return;\n        }\n        if (this._bufferedSize >= controller.desiredSize) {\n            ++this._numChunks && this._enqueue(controller, builder.toVector());\n        }\n        if (builder.finished) {\n            if (builder.length > 0 || this._numChunks === 0) {\n                ++this._numChunks && this._enqueue(controller, builder.toVector());\n            }\n            if (!this._finished && (this._finished = true)) {\n                this._enqueue(controller, null);\n            }\n        }\n    }\n    _enqueue(controller, chunk) {\n        this._bufferedSize = 0;\n        this._controller = null;\n        chunk === null ? controller.close() : controller.enqueue(chunk);\n    }\n}\n/** @ignore */ const chunkLength = (chunk) => chunk.length;\n/** @ignore */ const chunkByteLength = (chunk) => chunk.byteLength;\n\n//# sourceMappingURL=builder.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/whatwg/builder.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/whatwg/iterable.mjs":
/*!**************************************************************!*\
  !*** ../../node_modules/apache-arrow/io/whatwg/iterable.mjs ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   toDOMStream: () => (/* binding */ toDOMStream)\n/* harmony export */ });\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nfunction toDOMStream(source, options) {\n    if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_1__.isAsyncIterable)(source)) {\n        return asyncIterableAsReadableDOMStream(source, options);\n    }\n    if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_1__.isIterable)(source)) {\n        return iterableAsReadableDOMStream(source, options);\n    }\n    /* istanbul ignore next */\n    throw new Error(`toDOMStream() must be called with an Iterable or AsyncIterable`);\n}\n/** @ignore */\nfunction iterableAsReadableDOMStream(source, options) {\n    let it = null;\n    const bm = (options && options.type === 'bytes') || false;\n    const hwm = options && options.highWaterMark || (2 ** 24);\n    return new ReadableStream({\n        ...options,\n        start(controller) { next(controller, it || (it = source[Symbol.iterator]())); },\n        pull(controller) { it ? (next(controller, it)) : controller.close(); },\n        cancel() { (it && (it.return && it.return()) || true) && (it = null); }\n    }, { highWaterMark: bm ? hwm : undefined, ...options });\n    function next(controller, it) {\n        let buf;\n        let r = null;\n        let size = controller.desiredSize || null;\n        while (!(r = it.next(bm ? size : null)).done) {\n            if (ArrayBuffer.isView(r.value) && (buf = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(r.value))) {\n                size != null && bm && (size = size - buf.byteLength + 1);\n                r.value = buf;\n            }\n            controller.enqueue(r.value);\n            if (size != null && --size <= 0) {\n                return;\n            }\n        }\n        controller.close();\n    }\n}\n/** @ignore */\nfunction asyncIterableAsReadableDOMStream(source, options) {\n    let it = null;\n    const bm = (options && options.type === 'bytes') || false;\n    const hwm = options && options.highWaterMark || (2 ** 24);\n    return new ReadableStream({\n        ...options,\n        async start(controller) { await next(controller, it || (it = source[Symbol.asyncIterator]())); },\n        async pull(controller) { it ? (await next(controller, it)) : controller.close(); },\n        async cancel() { (it && (it.return && await it.return()) || true) && (it = null); },\n    }, { highWaterMark: bm ? hwm : undefined, ...options });\n    async function next(controller, it) {\n        let buf;\n        let r = null;\n        let size = controller.desiredSize || null;\n        while (!(r = await it.next(bm ? size : null)).done) {\n            if (ArrayBuffer.isView(r.value) && (buf = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(r.value))) {\n                size != null && bm && (size = size - buf.byteLength + 1);\n                r.value = buf;\n            }\n            controller.enqueue(r.value);\n            if (size != null && --size <= 0) {\n                return;\n            }\n        }\n        controller.close();\n    }\n}\n\n//# sourceMappingURL=iterable.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/whatwg/iterable.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/whatwg/reader.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/io/whatwg/reader.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   recordBatchReaderThroughDOMStream: () => (/* binding */ recordBatchReaderThroughDOMStream)\n/* harmony export */ });\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _ipc_reader__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../ipc/reader */ \"../../node_modules/apache-arrow/ipc/reader.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nfunction recordBatchReaderThroughDOMStream(writableStrategy, readableStrategy) {\n    const queue = new _io_stream__WEBPACK_IMPORTED_MODULE_0__.AsyncByteQueue();\n    let reader = null;\n    const readable = new ReadableStream({\n        async cancel() { await queue.close(); },\n        async start(controller) { await next(controller, reader || (reader = await open())); },\n        async pull(controller) { reader ? await next(controller, reader) : controller.close(); }\n    });\n    return { writable: new WritableStream(queue, { 'highWaterMark': 2 ** 14, ...writableStrategy }), readable };\n    async function open() {\n        return await (await _ipc_reader__WEBPACK_IMPORTED_MODULE_1__.RecordBatchReader.from(queue)).open(readableStrategy);\n    }\n    async function next(controller, reader) {\n        let size = controller.desiredSize;\n        let r = null;\n        while (!(r = await reader.next()).done) {\n            controller.enqueue(r.value);\n            if (size != null && --size <= 0) {\n                return;\n            }\n        }\n        controller.close();\n    }\n}\n\n//# sourceMappingURL=reader.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/whatwg/reader.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/io/whatwg/writer.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/io/whatwg/writer.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   recordBatchWriterThroughDOMStream: () => (/* binding */ recordBatchWriterThroughDOMStream)\n/* harmony export */ });\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nfunction recordBatchWriterThroughDOMStream(writableStrategy, readableStrategy) {\n    const writer = new this(writableStrategy);\n    const reader = new _io_stream__WEBPACK_IMPORTED_MODULE_0__.AsyncByteStream(writer);\n    const readable = new ReadableStream({\n        type: 'bytes',\n        async cancel() { await reader.cancel(); },\n        async pull(controller) { await next(controller); },\n        async start(controller) { await next(controller); },\n    }, { 'highWaterMark': 2 ** 14, ...readableStrategy });\n    return { writable: new WritableStream(writer, writableStrategy), readable };\n    async function next(controller) {\n        let buf = null;\n        let size = controller.desiredSize;\n        while (buf = await reader.read(size || null)) {\n            controller.enqueue(buf);\n            if (size != null && (size -= buf.byteLength) <= 0) {\n                return;\n            }\n        }\n        controller.close();\n    }\n}\n\n//# sourceMappingURL=writer.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/io/whatwg/writer.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/message.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/message.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AsyncMessageReader: () => (/* binding */ AsyncMessageReader),\n/* harmony export */   JSONMessageReader: () => (/* binding */ JSONMessageReader),\n/* harmony export */   MAGIC: () => (/* binding */ MAGIC),\n/* harmony export */   MAGIC_STR: () => (/* binding */ MAGIC_STR),\n/* harmony export */   MessageReader: () => (/* binding */ MessageReader),\n/* harmony export */   PADDING: () => (/* binding */ PADDING),\n/* harmony export */   checkForMagicArrowString: () => (/* binding */ checkForMagicArrowString),\n/* harmony export */   magicAndPadding: () => (/* binding */ magicAndPadding),\n/* harmony export */   magicLength: () => (/* binding */ magicLength),\n/* harmony export */   magicX2AndPadding: () => (/* binding */ magicX2AndPadding)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var flatbuffers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! flatbuffers */ \"../../node_modules/flatbuffers/js/flatbuffers.mjs\");\n/* harmony import */ var _metadata_message__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./metadata/message */ \"../../node_modules/apache-arrow/ipc/metadata/message.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _io_file__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../io/file */ \"../../node_modules/apache-arrow/io/file.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _io_interfaces__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../io/interfaces */ \"../../node_modules/apache-arrow/io/interfaces.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\nvar ByteBuffer = flatbuffers__WEBPACK_IMPORTED_MODULE_1__.flatbuffers.ByteBuffer;\n\n\n\n\n\n\n/** @ignore */ const invalidMessageType = (type) => `Expected ${_enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader[type]} Message in stream, but was null or length 0.`;\n/** @ignore */ const nullMessage = (type) => `Header pointer of flatbuffer-encoded ${_enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader[type]} Message is null or length 0.`;\n/** @ignore */ const invalidMessageMetadata = (expected, actual) => `Expected to read ${expected} metadata bytes, but only read ${actual}.`;\n/** @ignore */ const invalidMessageBodyLength = (expected, actual) => `Expected to read ${expected} bytes for message body, but only read ${actual}.`;\n/** @ignore */\nclass MessageReader {\n    constructor(source) {\n        this.source = source instanceof _io_stream__WEBPACK_IMPORTED_MODULE_6__.ByteStream ? source : new _io_stream__WEBPACK_IMPORTED_MODULE_6__.ByteStream(source);\n    }\n    [Symbol.iterator]() { return this; }\n    next() {\n        let r;\n        if ((r = this.readMetadataLength()).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        // ARROW-6313: If the first 4 bytes are continuation indicator (-1), read\n        // the next 4 for the 32-bit metadata length. Otherwise, assume this is a\n        // pre-v0.15 message, where the first 4 bytes are the metadata length.\n        if ((r.value === -1) &&\n            (r = this.readMetadataLength()).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        if ((r = this.readMetadata(r.value)).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        return r;\n    }\n    throw(value) { return this.source.throw(value); }\n    return(value) { return this.source.return(value); }\n    readMessage(type) {\n        let r;\n        if ((r = this.next()).done) {\n            return null;\n        }\n        if ((type != null) && r.value.headerType !== type) {\n            throw new Error(invalidMessageType(type));\n        }\n        return r.value;\n    }\n    readMessageBody(bodyLength) {\n        if (bodyLength <= 0) {\n            return new Uint8Array(0);\n        }\n        const buf = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_5__.toUint8Array)(this.source.read(bodyLength));\n        if (buf.byteLength < bodyLength) {\n            throw new Error(invalidMessageBodyLength(bodyLength, buf.byteLength));\n        }\n        // 1. Work around bugs in fs.ReadStream's internal Buffer pooling, see: https://github.com/nodejs/node/issues/24817\n        // 2. Work around https://github.com/whatwg/streams/blob/0ebe4b042e467d9876d80ae045de3843092ad797/reference-implementation/lib/helpers.js#L126\n        return /* 1. */ (buf.byteOffset % 8 === 0) &&\n            /* 2. */ (buf.byteOffset + buf.byteLength) <= buf.buffer.byteLength ? buf : buf.slice();\n    }\n    readSchema(throwIfNull = false) {\n        const type = _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.Schema;\n        const message = this.readMessage(type);\n        const schema = message && message.header();\n        if (throwIfNull && !schema) {\n            throw new Error(nullMessage(type));\n        }\n        return schema;\n    }\n    readMetadataLength() {\n        const buf = this.source.read(PADDING);\n        const bb = buf && new ByteBuffer(buf);\n        const len = bb && bb.readInt32(0) || 0;\n        return { done: len === 0, value: len };\n    }\n    readMetadata(metadataLength) {\n        const buf = this.source.read(metadataLength);\n        if (!buf) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        if (buf.byteLength < metadataLength) {\n            throw new Error(invalidMessageMetadata(metadataLength, buf.byteLength));\n        }\n        return { done: false, value: _metadata_message__WEBPACK_IMPORTED_MODULE_2__.Message.decode(buf) };\n    }\n}\n/** @ignore */\nclass AsyncMessageReader {\n    constructor(source, byteLength) {\n        this.source = source instanceof _io_stream__WEBPACK_IMPORTED_MODULE_6__.AsyncByteStream ? source\n            : (0,_util_compat__WEBPACK_IMPORTED_MODULE_3__.isFileHandle)(source)\n                ? new _io_file__WEBPACK_IMPORTED_MODULE_4__.AsyncRandomAccessFile(source, byteLength)\n                : new _io_stream__WEBPACK_IMPORTED_MODULE_6__.AsyncByteStream(source);\n    }\n    [Symbol.asyncIterator]() { return this; }\n    async next() {\n        let r;\n        if ((r = await this.readMetadataLength()).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        // ARROW-6313: If the first 4 bytes are continuation indicator (-1), read\n        // the next 4 for the 32-bit metadata length. Otherwise, assume this is a\n        // pre-v0.15 message, where the first 4 bytes are the metadata length.\n        if ((r.value === -1) &&\n            (r = await this.readMetadataLength()).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        if ((r = await this.readMetadata(r.value)).done) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        return r;\n    }\n    async throw(value) { return await this.source.throw(value); }\n    async return(value) { return await this.source.return(value); }\n    async readMessage(type) {\n        let r;\n        if ((r = await this.next()).done) {\n            return null;\n        }\n        if ((type != null) && r.value.headerType !== type) {\n            throw new Error(invalidMessageType(type));\n        }\n        return r.value;\n    }\n    async readMessageBody(bodyLength) {\n        if (bodyLength <= 0) {\n            return new Uint8Array(0);\n        }\n        const buf = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_5__.toUint8Array)(await this.source.read(bodyLength));\n        if (buf.byteLength < bodyLength) {\n            throw new Error(invalidMessageBodyLength(bodyLength, buf.byteLength));\n        }\n        // 1. Work around bugs in fs.ReadStream's internal Buffer pooling, see: https://github.com/nodejs/node/issues/24817\n        // 2. Work around https://github.com/whatwg/streams/blob/0ebe4b042e467d9876d80ae045de3843092ad797/reference-implementation/lib/helpers.js#L126\n        return /* 1. */ (buf.byteOffset % 8 === 0) &&\n            /* 2. */ (buf.byteOffset + buf.byteLength) <= buf.buffer.byteLength ? buf : buf.slice();\n    }\n    async readSchema(throwIfNull = false) {\n        const type = _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.Schema;\n        const message = await this.readMessage(type);\n        const schema = message && message.header();\n        if (throwIfNull && !schema) {\n            throw new Error(nullMessage(type));\n        }\n        return schema;\n    }\n    async readMetadataLength() {\n        const buf = await this.source.read(PADDING);\n        const bb = buf && new ByteBuffer(buf);\n        const len = bb && bb.readInt32(0) || 0;\n        return { done: len === 0, value: len };\n    }\n    async readMetadata(metadataLength) {\n        const buf = await this.source.read(metadataLength);\n        if (!buf) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n        }\n        if (buf.byteLength < metadataLength) {\n            throw new Error(invalidMessageMetadata(metadataLength, buf.byteLength));\n        }\n        return { done: false, value: _metadata_message__WEBPACK_IMPORTED_MODULE_2__.Message.decode(buf) };\n    }\n}\n/** @ignore */\nclass JSONMessageReader extends MessageReader {\n    constructor(source) {\n        super(new Uint8Array(0));\n        this._schema = false;\n        this._body = [];\n        this._batchIndex = 0;\n        this._dictionaryIndex = 0;\n        this._json = source instanceof _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ArrowJSON ? source : new _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ArrowJSON(source);\n    }\n    next() {\n        const { _json } = this;\n        if (!this._schema) {\n            this._schema = true;\n            const message = _metadata_message__WEBPACK_IMPORTED_MODULE_2__.Message.fromJSON(_json.schema, _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.Schema);\n            return { done: false, value: message };\n        }\n        if (this._dictionaryIndex < _json.dictionaries.length) {\n            const batch = _json.dictionaries[this._dictionaryIndex++];\n            this._body = batch['data']['columns'];\n            const message = _metadata_message__WEBPACK_IMPORTED_MODULE_2__.Message.fromJSON(batch, _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.DictionaryBatch);\n            return { done: false, value: message };\n        }\n        if (this._batchIndex < _json.batches.length) {\n            const batch = _json.batches[this._batchIndex++];\n            this._body = batch['columns'];\n            const message = _metadata_message__WEBPACK_IMPORTED_MODULE_2__.Message.fromJSON(batch, _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.RecordBatch);\n            return { done: false, value: message };\n        }\n        this._body = [];\n        return _io_interfaces__WEBPACK_IMPORTED_MODULE_7__.ITERATOR_DONE;\n    }\n    readMessageBody(_bodyLength) {\n        return flattenDataSources(this._body);\n        function flattenDataSources(xs) {\n            return (xs || []).reduce((buffers, column) => [\n                ...buffers,\n                ...(column['VALIDITY'] && [column['VALIDITY']] || []),\n                ...(column['TYPE'] && [column['TYPE']] || []),\n                ...(column['OFFSET'] && [column['OFFSET']] || []),\n                ...(column['DATA'] && [column['DATA']] || []),\n                ...flattenDataSources(column['children'])\n            ], []);\n        }\n    }\n    readMessage(type) {\n        let r;\n        if ((r = this.next()).done) {\n            return null;\n        }\n        if ((type != null) && r.value.headerType !== type) {\n            throw new Error(invalidMessageType(type));\n        }\n        return r.value;\n    }\n    readSchema() {\n        const type = _enum__WEBPACK_IMPORTED_MODULE_0__.MessageHeader.Schema;\n        const message = this.readMessage(type);\n        const schema = message && message.header();\n        if (!message || !schema) {\n            throw new Error(nullMessage(type));\n        }\n        return schema;\n    }\n}\n/** @ignore */\nconst PADDING = 4;\n/** @ignore */\nconst MAGIC_STR = 'ARROW1';\n/** @ignore */\nconst MAGIC = new Uint8Array(MAGIC_STR.length);\nfor (let i = 0; i < MAGIC_STR.length; i += 1 | 0) {\n    MAGIC[i] = MAGIC_STR.charCodeAt(i);\n}\n/** @ignore */\nfunction checkForMagicArrowString(buffer, index = 0) {\n    for (let i = -1, n = MAGIC.length; ++i < n;) {\n        if (MAGIC[i] !== buffer[index + i]) {\n            return false;\n        }\n    }\n    return true;\n}\n/** @ignore */\nconst magicLength = MAGIC.length;\n/** @ignore */\nconst magicAndPadding = magicLength + PADDING;\n/** @ignore */\nconst magicX2AndPadding = magicLength * 2 + PADDING;\n\n//# sourceMappingURL=message.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/message.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/metadata/file.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/metadata/file.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FileBlock: () => (/* binding */ FileBlock),\n/* harmony export */   Footer: () => (/* binding */ Footer_)\n/* harmony export */ });\n/* harmony import */ var _fb_File__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../fb/File */ \"../../node_modules/apache-arrow/fb/File.mjs\");\n/* harmony import */ var flatbuffers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! flatbuffers */ \"../../node_modules/flatbuffers/js/flatbuffers.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/* tslint:disable:class-name */\n\n\nvar Long = flatbuffers__WEBPACK_IMPORTED_MODULE_1__.flatbuffers.Long;\nvar Builder = flatbuffers__WEBPACK_IMPORTED_MODULE_1__.flatbuffers.Builder;\nvar ByteBuffer = flatbuffers__WEBPACK_IMPORTED_MODULE_1__.flatbuffers.ByteBuffer;\nvar _Block = _fb_File__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Block;\nvar _Footer = _fb_File__WEBPACK_IMPORTED_MODULE_0__.org.apache.arrow.flatbuf.Footer;\n\n\n\n/** @ignore */\nclass Footer_ {\n    constructor(schema, version = _enum__WEBPACK_IMPORTED_MODULE_3__.MetadataVersion.V4, recordBatches, dictionaryBatches) {\n        this.schema = schema;\n        this.version = version;\n        recordBatches && (this._recordBatches = recordBatches);\n        dictionaryBatches && (this._dictionaryBatches = dictionaryBatches);\n    }\n    /** @nocollapse */\n    static decode(buf) {\n        buf = new ByteBuffer((0,_util_buffer__WEBPACK_IMPORTED_MODULE_4__.toUint8Array)(buf));\n        const footer = _Footer.getRootAsFooter(buf);\n        const schema = _schema__WEBPACK_IMPORTED_MODULE_2__.Schema.decode(footer.schema());\n        return new OffHeapFooter(schema, footer);\n    }\n    /** @nocollapse */\n    static encode(footer) {\n        const b = new Builder();\n        const schemaOffset = _schema__WEBPACK_IMPORTED_MODULE_2__.Schema.encode(b, footer.schema);\n        _Footer.startRecordBatchesVector(b, footer.numRecordBatches);\n        [...footer.recordBatches()].slice().reverse().forEach((rb) => FileBlock.encode(b, rb));\n        const recordBatchesOffset = b.endVector();\n        _Footer.startDictionariesVector(b, footer.numDictionaries);\n        [...footer.dictionaryBatches()].slice().reverse().forEach((db) => FileBlock.encode(b, db));\n        const dictionaryBatchesOffset = b.endVector();\n        _Footer.startFooter(b);\n        _Footer.addSchema(b, schemaOffset);\n        _Footer.addVersion(b, _enum__WEBPACK_IMPORTED_MODULE_3__.MetadataVersion.V4);\n        _Footer.addRecordBatches(b, recordBatchesOffset);\n        _Footer.addDictionaries(b, dictionaryBatchesOffset);\n        _Footer.finishFooterBuffer(b, _Footer.endFooter(b));\n        return b.asUint8Array();\n    }\n    get numRecordBatches() { return this._recordBatches.length; }\n    get numDictionaries() { return this._dictionaryBatches.length; }\n    *recordBatches() {\n        for (let block, i = -1, n = this.numRecordBatches; ++i < n;) {\n            if (block = this.getRecordBatch(i)) {\n                yield block;\n            }\n        }\n    }\n    *dictionaryBatches() {\n        for (let block, i = -1, n = this.numDictionaries; ++i < n;) {\n            if (block = this.getDictionaryBatch(i)) {\n                yield block;\n            }\n        }\n    }\n    getRecordBatch(index) {\n        return index >= 0\n            && index < this.numRecordBatches\n            && this._recordBatches[index] || null;\n    }\n    getDictionaryBatch(index) {\n        return index >= 0\n            && index < this.numDictionaries\n            && this._dictionaryBatches[index] || null;\n    }\n}\n\n/** @ignore */\nclass OffHeapFooter extends Footer_ {\n    constructor(schema, _footer) {\n        super(schema, _footer.version());\n        this._footer = _footer;\n    }\n    get numRecordBatches() { return this._footer.recordBatchesLength(); }\n    get numDictionaries() { return this._footer.dictionariesLength(); }\n    getRecordBatch(index) {\n        if (index >= 0 && index < this.numRecordBatches) {\n            const fileBlock = this._footer.recordBatches(index);\n            if (fileBlock) {\n                return FileBlock.decode(fileBlock);\n            }\n        }\n        return null;\n    }\n    getDictionaryBatch(index) {\n        if (index >= 0 && index < this.numDictionaries) {\n            const fileBlock = this._footer.dictionaries(index);\n            if (fileBlock) {\n                return FileBlock.decode(fileBlock);\n            }\n        }\n        return null;\n    }\n}\n/** @ignore */\nclass FileBlock {\n    constructor(metaDataLength, bodyLength, offset) {\n        this.metaDataLength = metaDataLength;\n        this.offset = typeof offset === 'number' ? offset : offset.low;\n        this.bodyLength = typeof bodyLength === 'number' ? bodyLength : bodyLength.low;\n    }\n    /** @nocollapse */\n    static decode(block) {\n        return new FileBlock(block.metaDataLength(), block.bodyLength(), block.offset());\n    }\n    /** @nocollapse */\n    static encode(b, fileBlock) {\n        const { metaDataLength } = fileBlock;\n        const offset = new Long(fileBlock.offset, 0);\n        const bodyLength = new Long(fileBlock.bodyLength, 0);\n        return _Block.createBlock(b, offset, metaDataLength, bodyLength);\n    }\n}\n\n//# sourceMappingURL=file.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/metadata/file.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/metadata/json.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/metadata/json.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   dictionaryBatchFromJSON: () => (/* binding */ dictionaryBatchFromJSON),\n/* harmony export */   fieldFromJSON: () => (/* binding */ fieldFromJSON),\n/* harmony export */   recordBatchFromJSON: () => (/* binding */ recordBatchFromJSON),\n/* harmony export */   schemaFromJSON: () => (/* binding */ schemaFromJSON)\n/* harmony export */ });\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _message__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./message */ \"../../node_modules/apache-arrow/ipc/metadata/message.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nfunction schemaFromJSON(_schema, dictionaries = new Map()) {\n    return new _schema__WEBPACK_IMPORTED_MODULE_0__.Schema(schemaFieldsFromJSON(_schema, dictionaries), customMetadataFromJSON(_schema['customMetadata']), dictionaries);\n}\n/** @ignore */\nfunction recordBatchFromJSON(b) {\n    return new _message__WEBPACK_IMPORTED_MODULE_2__.RecordBatch(b['count'], fieldNodesFromJSON(b['columns']), buffersFromJSON(b['columns']));\n}\n/** @ignore */\nfunction dictionaryBatchFromJSON(b) {\n    return new _message__WEBPACK_IMPORTED_MODULE_2__.DictionaryBatch(recordBatchFromJSON(b['data']), b['id'], b['isDelta']);\n}\n/** @ignore */\nfunction schemaFieldsFromJSON(_schema, dictionaries) {\n    return (_schema['fields'] || []).filter(Boolean).map((f) => _schema__WEBPACK_IMPORTED_MODULE_0__.Field.fromJSON(f, dictionaries));\n}\n/** @ignore */\nfunction fieldChildrenFromJSON(_field, dictionaries) {\n    return (_field['children'] || []).filter(Boolean).map((f) => _schema__WEBPACK_IMPORTED_MODULE_0__.Field.fromJSON(f, dictionaries));\n}\n/** @ignore */\nfunction fieldNodesFromJSON(xs) {\n    return (xs || []).reduce((fieldNodes, column) => [\n        ...fieldNodes,\n        new _message__WEBPACK_IMPORTED_MODULE_2__.FieldNode(column['count'], nullCountFromJSON(column['VALIDITY'])),\n        ...fieldNodesFromJSON(column['children'])\n    ], []);\n}\n/** @ignore */\nfunction buffersFromJSON(xs, buffers = []) {\n    for (let i = -1, n = (xs || []).length; ++i < n;) {\n        const column = xs[i];\n        column['VALIDITY'] && buffers.push(new _message__WEBPACK_IMPORTED_MODULE_2__.BufferRegion(buffers.length, column['VALIDITY'].length));\n        column['TYPE'] && buffers.push(new _message__WEBPACK_IMPORTED_MODULE_2__.BufferRegion(buffers.length, column['TYPE'].length));\n        column['OFFSET'] && buffers.push(new _message__WEBPACK_IMPORTED_MODULE_2__.BufferRegion(buffers.length, column['OFFSET'].length));\n        column['DATA'] && buffers.push(new _message__WEBPACK_IMPORTED_MODULE_2__.BufferRegion(buffers.length, column['DATA'].length));\n        buffers = buffersFromJSON(column['children'], buffers);\n    }\n    return buffers;\n}\n/** @ignore */\nfunction nullCountFromJSON(validity) {\n    return (validity || []).reduce((sum, val) => sum + +(val === 0), 0);\n}\n/** @ignore */\nfunction fieldFromJSON(_field, dictionaries) {\n    let id;\n    let keys;\n    let field;\n    let dictMeta;\n    let type;\n    let dictType;\n    // If no dictionary encoding\n    if (!dictionaries || !(dictMeta = _field['dictionary'])) {\n        type = typeFromJSON(_field, fieldChildrenFromJSON(_field, dictionaries));\n        field = new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(_field['name'], type, _field['nullable'], customMetadataFromJSON(_field['customMetadata']));\n    }\n    // tslint:disable\n    // If dictionary encoded and the first time we've seen this dictionary id, decode\n    // the data type and child fields, then wrap in a Dictionary type and insert the\n    // data type into the dictionary types map.\n    else if (!dictionaries.has(id = dictMeta['id'])) {\n        // a dictionary index defaults to signed 32 bit int if unspecified\n        keys = (keys = dictMeta['indexType']) ? indexTypeFromJSON(keys) : new _type__WEBPACK_IMPORTED_MODULE_1__.Int32();\n        dictionaries.set(id, type = typeFromJSON(_field, fieldChildrenFromJSON(_field, dictionaries)));\n        dictType = new _type__WEBPACK_IMPORTED_MODULE_1__.Dictionary(type, keys, id, dictMeta['isOrdered']);\n        field = new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(_field['name'], dictType, _field['nullable'], customMetadataFromJSON(_field['customMetadata']));\n    }\n    // If dictionary encoded, and have already seen this dictionary Id in the schema, then reuse the\n    // data type and wrap in a new Dictionary type and field.\n    else {\n        // a dictionary index defaults to signed 32 bit int if unspecified\n        keys = (keys = dictMeta['indexType']) ? indexTypeFromJSON(keys) : new _type__WEBPACK_IMPORTED_MODULE_1__.Int32();\n        dictType = new _type__WEBPACK_IMPORTED_MODULE_1__.Dictionary(dictionaries.get(id), keys, id, dictMeta['isOrdered']);\n        field = new _schema__WEBPACK_IMPORTED_MODULE_0__.Field(_field['name'], dictType, _field['nullable'], customMetadataFromJSON(_field['customMetadata']));\n    }\n    return field || null;\n}\n/** @ignore */\nfunction customMetadataFromJSON(_metadata) {\n    return new Map(Object.entries(_metadata || {}));\n}\n/** @ignore */\nfunction indexTypeFromJSON(_type) {\n    return new _type__WEBPACK_IMPORTED_MODULE_1__.Int(_type['isSigned'], _type['bitWidth']);\n}\n/** @ignore */\nfunction typeFromJSON(f, children) {\n    const typeId = f['type']['name'];\n    switch (typeId) {\n        case 'NONE': return new _type__WEBPACK_IMPORTED_MODULE_1__.Null();\n        case 'null': return new _type__WEBPACK_IMPORTED_MODULE_1__.Null();\n        case 'binary': return new _type__WEBPACK_IMPORTED_MODULE_1__.Binary();\n        case 'utf8': return new _type__WEBPACK_IMPORTED_MODULE_1__.Utf8();\n        case 'bool': return new _type__WEBPACK_IMPORTED_MODULE_1__.Bool();\n        case 'list': return new _type__WEBPACK_IMPORTED_MODULE_1__.List((children || [])[0]);\n        case 'struct': return new _type__WEBPACK_IMPORTED_MODULE_1__.Struct(children || []);\n        case 'struct_': return new _type__WEBPACK_IMPORTED_MODULE_1__.Struct(children || []);\n    }\n    switch (typeId) {\n        case 'int': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Int(t['isSigned'], t['bitWidth']);\n        }\n        case 'floatingpoint': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Float(_enum__WEBPACK_IMPORTED_MODULE_3__.Precision[t['precision']]);\n        }\n        case 'decimal': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Decimal(t['scale'], t['precision']);\n        }\n        case 'date': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Date_(_enum__WEBPACK_IMPORTED_MODULE_3__.DateUnit[t['unit']]);\n        }\n        case 'time': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Time(_enum__WEBPACK_IMPORTED_MODULE_3__.TimeUnit[t['unit']], t['bitWidth']);\n        }\n        case 'timestamp': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Timestamp(_enum__WEBPACK_IMPORTED_MODULE_3__.TimeUnit[t['unit']], t['timezone']);\n        }\n        case 'interval': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Interval(_enum__WEBPACK_IMPORTED_MODULE_3__.IntervalUnit[t['unit']]);\n        }\n        case 'union': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Union(_enum__WEBPACK_IMPORTED_MODULE_3__.UnionMode[t['mode']], (t['typeIds'] || []), children || []);\n        }\n        case 'fixedsizebinary': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.FixedSizeBinary(t['byteWidth']);\n        }\n        case 'fixedsizelist': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.FixedSizeList(t['listSize'], (children || [])[0]);\n        }\n        case 'map': {\n            const t = f['type'];\n            return new _type__WEBPACK_IMPORTED_MODULE_1__.Map_((children || [])[0], t['keysSorted']);\n        }\n    }\n    throw new Error(`Unrecognized type: \"${typeId}\"`);\n}\n\n//# sourceMappingURL=json.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/metadata/json.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/metadata/message.mjs":
/*!****************************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/metadata/message.mjs ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BufferRegion: () => (/* binding */ BufferRegion),\n/* harmony export */   DictionaryBatch: () => (/* binding */ DictionaryBatch),\n/* harmony export */   FieldNode: () => (/* binding */ FieldNode),\n/* harmony export */   Message: () => (/* binding */ Message),\n/* harmony export */   RecordBatch: () => (/* binding */ RecordBatch)\n/* harmony export */ });\n/* harmony import */ var flatbuffers__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! flatbuffers */ \"../../node_modules/flatbuffers/js/flatbuffers.mjs\");\n/* harmony import */ var _fb_Schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../fb/Schema */ \"../../node_modules/apache-arrow/fb/Schema.mjs\");\n/* harmony import */ var _fb_Message__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../fb/Message */ \"../../node_modules/apache-arrow/fb/Message.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _visitor_typeassembler__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../visitor/typeassembler */ \"../../node_modules/apache-arrow/visitor/typeassembler.mjs\");\n/* harmony import */ var _json__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./json */ \"../../node_modules/apache-arrow/ipc/metadata/json.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\nvar Long = flatbuffers__WEBPACK_IMPORTED_MODULE_0__.flatbuffers.Long;\nvar Builder = flatbuffers__WEBPACK_IMPORTED_MODULE_0__.flatbuffers.Builder;\nvar ByteBuffer = flatbuffers__WEBPACK_IMPORTED_MODULE_0__.flatbuffers.ByteBuffer;\nvar Type = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Type;\nvar _Field = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Field;\nvar _Schema = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Schema;\nvar _Buffer = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Buffer;\nvar _Message = _fb_Message__WEBPACK_IMPORTED_MODULE_2__.org.apache.arrow.flatbuf.Message;\nvar _KeyValue = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.KeyValue;\nvar _FieldNode = _fb_Message__WEBPACK_IMPORTED_MODULE_2__.org.apache.arrow.flatbuf.FieldNode;\nvar _Endianness = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Endianness;\nvar _RecordBatch = _fb_Message__WEBPACK_IMPORTED_MODULE_2__.org.apache.arrow.flatbuf.RecordBatch;\nvar _DictionaryBatch = _fb_Message__WEBPACK_IMPORTED_MODULE_2__.org.apache.arrow.flatbuf.DictionaryBatch;\n\n/**\n * @ignore\n * @private\n **/\nclass Message {\n    constructor(bodyLength, version, headerType, header) {\n        this._version = version;\n        this._headerType = headerType;\n        this.body = new Uint8Array(0);\n        header && (this._createHeader = () => header);\n        this._bodyLength = typeof bodyLength === 'number' ? bodyLength : bodyLength.low;\n    }\n    /** @nocollapse */\n    static fromJSON(msg, headerType) {\n        const message = new Message(0, _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4, headerType);\n        message._createHeader = messageHeaderFromJSON(msg, headerType);\n        return message;\n    }\n    /** @nocollapse */\n    static decode(buf) {\n        buf = new ByteBuffer((0,_util_buffer__WEBPACK_IMPORTED_MODULE_4__.toUint8Array)(buf));\n        const _message = _Message.getRootAsMessage(buf);\n        const bodyLength = _message.bodyLength();\n        const version = _message.version();\n        const headerType = _message.headerType();\n        const message = new Message(bodyLength, version, headerType);\n        message._createHeader = decodeMessageHeader(_message, headerType);\n        return message;\n    }\n    /** @nocollapse */\n    static encode(message) {\n        let b = new Builder(), headerOffset = -1;\n        if (message.isSchema()) {\n            headerOffset = _schema__WEBPACK_IMPORTED_MODULE_3__.Schema.encode(b, message.header());\n        }\n        else if (message.isRecordBatch()) {\n            headerOffset = RecordBatch.encode(b, message.header());\n        }\n        else if (message.isDictionaryBatch()) {\n            headerOffset = DictionaryBatch.encode(b, message.header());\n        }\n        _Message.startMessage(b);\n        _Message.addVersion(b, _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4);\n        _Message.addHeader(b, headerOffset);\n        _Message.addHeaderType(b, message.headerType);\n        _Message.addBodyLength(b, new Long(message.bodyLength, 0));\n        _Message.finishMessageBuffer(b, _Message.endMessage(b));\n        return b.asUint8Array();\n    }\n    /** @nocollapse */\n    static from(header, bodyLength = 0) {\n        if (header instanceof _schema__WEBPACK_IMPORTED_MODULE_3__.Schema) {\n            return new Message(0, _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4, _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.Schema, header);\n        }\n        if (header instanceof RecordBatch) {\n            return new Message(bodyLength, _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4, _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.RecordBatch, header);\n        }\n        if (header instanceof DictionaryBatch) {\n            return new Message(bodyLength, _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4, _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.DictionaryBatch, header);\n        }\n        throw new Error(`Unrecognized Message header: ${header}`);\n    }\n    get type() { return this.headerType; }\n    get version() { return this._version; }\n    get headerType() { return this._headerType; }\n    get bodyLength() { return this._bodyLength; }\n    header() { return this._createHeader(); }\n    isSchema() { return this.headerType === _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.Schema; }\n    isRecordBatch() { return this.headerType === _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.RecordBatch; }\n    isDictionaryBatch() { return this.headerType === _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.DictionaryBatch; }\n}\n/**\n * @ignore\n * @private\n **/\nclass RecordBatch {\n    constructor(length, nodes, buffers) {\n        this._nodes = nodes;\n        this._buffers = buffers;\n        this._length = typeof length === 'number' ? length : length.low;\n    }\n    get nodes() { return this._nodes; }\n    get length() { return this._length; }\n    get buffers() { return this._buffers; }\n}\n/**\n * @ignore\n * @private\n **/\nclass DictionaryBatch {\n    constructor(data, id, isDelta = false) {\n        this._data = data;\n        this._isDelta = isDelta;\n        this._id = typeof id === 'number' ? id : id.low;\n    }\n    get id() { return this._id; }\n    get data() { return this._data; }\n    get isDelta() { return this._isDelta; }\n    get length() { return this.data.length; }\n    get nodes() { return this.data.nodes; }\n    get buffers() { return this.data.buffers; }\n}\n/**\n * @ignore\n * @private\n **/\nclass BufferRegion {\n    constructor(offset, length) {\n        this.offset = typeof offset === 'number' ? offset : offset.low;\n        this.length = typeof length === 'number' ? length : length.low;\n    }\n}\n/**\n * @ignore\n * @private\n **/\nclass FieldNode {\n    constructor(length, nullCount) {\n        this.length = typeof length === 'number' ? length : length.low;\n        this.nullCount = typeof nullCount === 'number' ? nullCount : nullCount.low;\n    }\n}\n/** @ignore */\nfunction messageHeaderFromJSON(message, type) {\n    return (() => {\n        switch (type) {\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.Schema: return _schema__WEBPACK_IMPORTED_MODULE_3__.Schema.fromJSON(message);\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.RecordBatch: return RecordBatch.fromJSON(message);\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.DictionaryBatch: return DictionaryBatch.fromJSON(message);\n        }\n        throw new Error(`Unrecognized Message type: { name: ${_enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader[type]}, type: ${type} }`);\n    });\n}\n/** @ignore */\nfunction decodeMessageHeader(message, type) {\n    return (() => {\n        switch (type) {\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.Schema: return _schema__WEBPACK_IMPORTED_MODULE_3__.Schema.decode(message.header(new _Schema()));\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.RecordBatch: return RecordBatch.decode(message.header(new _RecordBatch()), message.version());\n            case _enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader.DictionaryBatch: return DictionaryBatch.decode(message.header(new _DictionaryBatch()), message.version());\n        }\n        throw new Error(`Unrecognized Message type: { name: ${_enum__WEBPACK_IMPORTED_MODULE_5__.MessageHeader[type]}, type: ${type} }`);\n    });\n}\n_schema__WEBPACK_IMPORTED_MODULE_3__.Field['encode'] = encodeField;\n_schema__WEBPACK_IMPORTED_MODULE_3__.Field['decode'] = decodeField;\n_schema__WEBPACK_IMPORTED_MODULE_3__.Field['fromJSON'] = _json__WEBPACK_IMPORTED_MODULE_7__.fieldFromJSON;\n_schema__WEBPACK_IMPORTED_MODULE_3__.Schema['encode'] = encodeSchema;\n_schema__WEBPACK_IMPORTED_MODULE_3__.Schema['decode'] = decodeSchema;\n_schema__WEBPACK_IMPORTED_MODULE_3__.Schema['fromJSON'] = _json__WEBPACK_IMPORTED_MODULE_7__.schemaFromJSON;\nRecordBatch['encode'] = encodeRecordBatch;\nRecordBatch['decode'] = decodeRecordBatch;\nRecordBatch['fromJSON'] = _json__WEBPACK_IMPORTED_MODULE_7__.recordBatchFromJSON;\nDictionaryBatch['encode'] = encodeDictionaryBatch;\nDictionaryBatch['decode'] = decodeDictionaryBatch;\nDictionaryBatch['fromJSON'] = _json__WEBPACK_IMPORTED_MODULE_7__.dictionaryBatchFromJSON;\nFieldNode['encode'] = encodeFieldNode;\nFieldNode['decode'] = decodeFieldNode;\nBufferRegion['encode'] = encodeBufferRegion;\nBufferRegion['decode'] = decodeBufferRegion;\n/** @ignore */\nfunction decodeSchema(_schema, dictionaries = new Map()) {\n    const fields = decodeSchemaFields(_schema, dictionaries);\n    return new _schema__WEBPACK_IMPORTED_MODULE_3__.Schema(fields, decodeCustomMetadata(_schema), dictionaries);\n}\n/** @ignore */\nfunction decodeRecordBatch(batch, version = _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4) {\n    return new RecordBatch(batch.length(), decodeFieldNodes(batch), decodeBuffers(batch, version));\n}\n/** @ignore */\nfunction decodeDictionaryBatch(batch, version = _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4) {\n    return new DictionaryBatch(RecordBatch.decode(batch.data(), version), batch.id(), batch.isDelta());\n}\n/** @ignore */\nfunction decodeBufferRegion(b) {\n    return new BufferRegion(b.offset(), b.length());\n}\n/** @ignore */\nfunction decodeFieldNode(f) {\n    return new FieldNode(f.length(), f.nullCount());\n}\n/** @ignore */\nfunction decodeFieldNodes(batch) {\n    const nodes = [];\n    for (let f, i = -1, j = -1, n = batch.nodesLength(); ++i < n;) {\n        if (f = batch.nodes(i)) {\n            nodes[++j] = FieldNode.decode(f);\n        }\n    }\n    return nodes;\n}\n/** @ignore */\nfunction decodeBuffers(batch, version) {\n    const bufferRegions = [];\n    for (let b, i = -1, j = -1, n = batch.buffersLength(); ++i < n;) {\n        if (b = batch.buffers(i)) {\n            // If this Arrow buffer was written before version 4,\n            // advance the buffer's bb_pos 8 bytes to skip past\n            // the now-removed page_id field\n            if (version < _enum__WEBPACK_IMPORTED_MODULE_5__.MetadataVersion.V4) {\n                b.bb_pos += (8 * (i + 1));\n            }\n            bufferRegions[++j] = BufferRegion.decode(b);\n        }\n    }\n    return bufferRegions;\n}\n/** @ignore */\nfunction decodeSchemaFields(schema, dictionaries) {\n    const fields = [];\n    for (let f, i = -1, j = -1, n = schema.fieldsLength(); ++i < n;) {\n        if (f = schema.fields(i)) {\n            fields[++j] = _schema__WEBPACK_IMPORTED_MODULE_3__.Field.decode(f, dictionaries);\n        }\n    }\n    return fields;\n}\n/** @ignore */\nfunction decodeFieldChildren(field, dictionaries) {\n    const children = [];\n    for (let f, i = -1, j = -1, n = field.childrenLength(); ++i < n;) {\n        if (f = field.children(i)) {\n            children[++j] = _schema__WEBPACK_IMPORTED_MODULE_3__.Field.decode(f, dictionaries);\n        }\n    }\n    return children;\n}\n/** @ignore */\nfunction decodeField(f, dictionaries) {\n    let id;\n    let field;\n    let type;\n    let keys;\n    let dictType;\n    let dictMeta;\n    // If no dictionary encoding\n    if (!dictionaries || !(dictMeta = f.dictionary())) {\n        type = decodeFieldType(f, decodeFieldChildren(f, dictionaries));\n        field = new _schema__WEBPACK_IMPORTED_MODULE_3__.Field(f.name(), type, f.nullable(), decodeCustomMetadata(f));\n    }\n    // tslint:disable\n    // If dictionary encoded and the first time we've seen this dictionary id, decode\n    // the data type and child fields, then wrap in a Dictionary type and insert the\n    // data type into the dictionary types map.\n    else if (!dictionaries.has(id = dictMeta.id().low)) {\n        // a dictionary index defaults to signed 32 bit int if unspecified\n        keys = (keys = dictMeta.indexType()) ? decodeIndexType(keys) : new _type__WEBPACK_IMPORTED_MODULE_8__.Int32();\n        dictionaries.set(id, type = decodeFieldType(f, decodeFieldChildren(f, dictionaries)));\n        dictType = new _type__WEBPACK_IMPORTED_MODULE_8__.Dictionary(type, keys, id, dictMeta.isOrdered());\n        field = new _schema__WEBPACK_IMPORTED_MODULE_3__.Field(f.name(), dictType, f.nullable(), decodeCustomMetadata(f));\n    }\n    // If dictionary encoded, and have already seen this dictionary Id in the schema, then reuse the\n    // data type and wrap in a new Dictionary type and field.\n    else {\n        // a dictionary index defaults to signed 32 bit int if unspecified\n        keys = (keys = dictMeta.indexType()) ? decodeIndexType(keys) : new _type__WEBPACK_IMPORTED_MODULE_8__.Int32();\n        dictType = new _type__WEBPACK_IMPORTED_MODULE_8__.Dictionary(dictionaries.get(id), keys, id, dictMeta.isOrdered());\n        field = new _schema__WEBPACK_IMPORTED_MODULE_3__.Field(f.name(), dictType, f.nullable(), decodeCustomMetadata(f));\n    }\n    return field || null;\n}\n/** @ignore */\nfunction decodeCustomMetadata(parent) {\n    const data = new Map();\n    if (parent) {\n        for (let entry, key, i = -1, n = parent.customMetadataLength() | 0; ++i < n;) {\n            if ((entry = parent.customMetadata(i)) && (key = entry.key()) != null) {\n                data.set(key, entry.value());\n            }\n        }\n    }\n    return data;\n}\n/** @ignore */\nfunction decodeIndexType(_type) {\n    return new _type__WEBPACK_IMPORTED_MODULE_8__.Int(_type.isSigned(), _type.bitWidth());\n}\n/** @ignore */\nfunction decodeFieldType(f, children) {\n    const typeId = f.typeType();\n    switch (typeId) {\n        case Type.NONE: return new _type__WEBPACK_IMPORTED_MODULE_8__.Null();\n        case Type.Null: return new _type__WEBPACK_IMPORTED_MODULE_8__.Null();\n        case Type.Binary: return new _type__WEBPACK_IMPORTED_MODULE_8__.Binary();\n        case Type.Utf8: return new _type__WEBPACK_IMPORTED_MODULE_8__.Utf8();\n        case Type.Bool: return new _type__WEBPACK_IMPORTED_MODULE_8__.Bool();\n        case Type.List: return new _type__WEBPACK_IMPORTED_MODULE_8__.List((children || [])[0]);\n        case Type.Struct_: return new _type__WEBPACK_IMPORTED_MODULE_8__.Struct(children || []);\n    }\n    switch (typeId) {\n        case Type.Int: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Int());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Int(t.isSigned(), t.bitWidth());\n        }\n        case Type.FloatingPoint: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FloatingPoint());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Float(t.precision());\n        }\n        case Type.Decimal: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Decimal());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Decimal(t.scale(), t.precision());\n        }\n        case Type.Date: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Date());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Date_(t.unit());\n        }\n        case Type.Time: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Time());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Time(t.unit(), t.bitWidth());\n        }\n        case Type.Timestamp: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Timestamp());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Timestamp(t.unit(), t.timezone());\n        }\n        case Type.Interval: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Interval());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Interval(t.unit());\n        }\n        case Type.Union: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Union());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Union(t.mode(), t.typeIdsArray() || [], children || []);\n        }\n        case Type.FixedSizeBinary: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FixedSizeBinary());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinary(t.byteWidth());\n        }\n        case Type.FixedSizeList: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FixedSizeList());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.FixedSizeList(t.listSize(), (children || [])[0]);\n        }\n        case Type.Map: {\n            const t = f.type(new _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Map());\n            return new _type__WEBPACK_IMPORTED_MODULE_8__.Map_((children || [])[0], t.keysSorted());\n        }\n    }\n    throw new Error(`Unrecognized type: \"${Type[typeId]}\" (${typeId})`);\n}\n/** @ignore */\nfunction encodeSchema(b, schema) {\n    const fieldOffsets = schema.fields.map((f) => _schema__WEBPACK_IMPORTED_MODULE_3__.Field.encode(b, f));\n    _Schema.startFieldsVector(b, fieldOffsets.length);\n    const fieldsVectorOffset = _Schema.createFieldsVector(b, fieldOffsets);\n    const metadataOffset = !(schema.metadata && schema.metadata.size > 0) ? -1 :\n        _Schema.createCustomMetadataVector(b, [...schema.metadata].map(([k, v]) => {\n            const key = b.createString(`${k}`);\n            const val = b.createString(`${v}`);\n            _KeyValue.startKeyValue(b);\n            _KeyValue.addKey(b, key);\n            _KeyValue.addValue(b, val);\n            return _KeyValue.endKeyValue(b);\n        }));\n    _Schema.startSchema(b);\n    _Schema.addFields(b, fieldsVectorOffset);\n    _Schema.addEndianness(b, platformIsLittleEndian ? _Endianness.Little : _Endianness.Big);\n    if (metadataOffset !== -1) {\n        _Schema.addCustomMetadata(b, metadataOffset);\n    }\n    return _Schema.endSchema(b);\n}\n/** @ignore */\nfunction encodeField(b, field) {\n    let nameOffset = -1;\n    let typeOffset = -1;\n    let dictionaryOffset = -1;\n    let type = field.type;\n    let typeId = field.typeId;\n    if (!_type__WEBPACK_IMPORTED_MODULE_8__.DataType.isDictionary(type)) {\n        typeOffset = _visitor_typeassembler__WEBPACK_IMPORTED_MODULE_6__.instance.visit(type, b);\n    }\n    else {\n        typeId = type.dictionary.typeId;\n        dictionaryOffset = _visitor_typeassembler__WEBPACK_IMPORTED_MODULE_6__.instance.visit(type, b);\n        typeOffset = _visitor_typeassembler__WEBPACK_IMPORTED_MODULE_6__.instance.visit(type.dictionary, b);\n    }\n    const childOffsets = (type.children || []).map((f) => _schema__WEBPACK_IMPORTED_MODULE_3__.Field.encode(b, f));\n    const childrenVectorOffset = _Field.createChildrenVector(b, childOffsets);\n    const metadataOffset = !(field.metadata && field.metadata.size > 0) ? -1 :\n        _Field.createCustomMetadataVector(b, [...field.metadata].map(([k, v]) => {\n            const key = b.createString(`${k}`);\n            const val = b.createString(`${v}`);\n            _KeyValue.startKeyValue(b);\n            _KeyValue.addKey(b, key);\n            _KeyValue.addValue(b, val);\n            return _KeyValue.endKeyValue(b);\n        }));\n    if (field.name) {\n        nameOffset = b.createString(field.name);\n    }\n    _Field.startField(b);\n    _Field.addType(b, typeOffset);\n    _Field.addTypeType(b, typeId);\n    _Field.addChildren(b, childrenVectorOffset);\n    _Field.addNullable(b, !!field.nullable);\n    if (nameOffset !== -1) {\n        _Field.addName(b, nameOffset);\n    }\n    if (dictionaryOffset !== -1) {\n        _Field.addDictionary(b, dictionaryOffset);\n    }\n    if (metadataOffset !== -1) {\n        _Field.addCustomMetadata(b, metadataOffset);\n    }\n    return _Field.endField(b);\n}\n/** @ignore */\nfunction encodeRecordBatch(b, recordBatch) {\n    const nodes = recordBatch.nodes || [];\n    const buffers = recordBatch.buffers || [];\n    _RecordBatch.startNodesVector(b, nodes.length);\n    nodes.slice().reverse().forEach((n) => FieldNode.encode(b, n));\n    const nodesVectorOffset = b.endVector();\n    _RecordBatch.startBuffersVector(b, buffers.length);\n    buffers.slice().reverse().forEach((b_) => BufferRegion.encode(b, b_));\n    const buffersVectorOffset = b.endVector();\n    _RecordBatch.startRecordBatch(b);\n    _RecordBatch.addLength(b, new Long(recordBatch.length, 0));\n    _RecordBatch.addNodes(b, nodesVectorOffset);\n    _RecordBatch.addBuffers(b, buffersVectorOffset);\n    return _RecordBatch.endRecordBatch(b);\n}\n/** @ignore */\nfunction encodeDictionaryBatch(b, dictionaryBatch) {\n    const dataOffset = RecordBatch.encode(b, dictionaryBatch.data);\n    _DictionaryBatch.startDictionaryBatch(b);\n    _DictionaryBatch.addId(b, new Long(dictionaryBatch.id, 0));\n    _DictionaryBatch.addIsDelta(b, dictionaryBatch.isDelta);\n    _DictionaryBatch.addData(b, dataOffset);\n    return _DictionaryBatch.endDictionaryBatch(b);\n}\n/** @ignore */\nfunction encodeFieldNode(b, node) {\n    return _FieldNode.createFieldNode(b, new Long(node.length, 0), new Long(node.nullCount, 0));\n}\n/** @ignore */\nfunction encodeBufferRegion(b, node) {\n    return _Buffer.createBuffer(b, new Long(node.offset, 0), new Long(node.length, 0));\n}\n/** @ignore */\nconst platformIsLittleEndian = (function () {\n    const buffer = new ArrayBuffer(2);\n    new DataView(buffer).setInt16(0, 256, true /* littleEndian */);\n    // Int16Array uses the platform's endianness.\n    return new Int16Array(buffer)[0] === 256;\n})();\n\n//# sourceMappingURL=message.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/metadata/message.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/reader.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/reader.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AsyncRecordBatchFileReader: () => (/* binding */ AsyncRecordBatchFileReader),\n/* harmony export */   AsyncRecordBatchStreamReader: () => (/* binding */ AsyncRecordBatchStreamReader),\n/* harmony export */   RecordBatchFileReader: () => (/* binding */ RecordBatchFileReader),\n/* harmony export */   RecordBatchReader: () => (/* binding */ RecordBatchReader),\n/* harmony export */   RecordBatchStreamReader: () => (/* binding */ RecordBatchStreamReader)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _metadata_file__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./metadata/file */ \"../../node_modules/apache-arrow/ipc/metadata/file.mjs\");\n/* harmony import */ var _io_adapters__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../io/adapters */ \"../../node_modules/apache-arrow/io/adapters.mjs\");\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _io_file__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../io/file */ \"../../node_modules/apache-arrow/io/file.mjs\");\n/* harmony import */ var _visitor_vectorloader__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../visitor/vectorloader */ \"../../node_modules/apache-arrow/visitor/vectorloader.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _io_interfaces__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../io/interfaces */ \"../../node_modules/apache-arrow/io/interfaces.mjs\");\n/* harmony import */ var _message__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./message */ \"../../node_modules/apache-arrow/ipc/message.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\nclass RecordBatchReader extends _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ReadableInterop {\n    constructor(impl) {\n        super();\n        this._impl = impl;\n    }\n    get closed() { return this._impl.closed; }\n    get schema() { return this._impl.schema; }\n    get autoDestroy() { return this._impl.autoDestroy; }\n    get dictionaries() { return this._impl.dictionaries; }\n    get numDictionaries() { return this._impl.numDictionaries; }\n    get numRecordBatches() { return this._impl.numRecordBatches; }\n    get footer() { return this._impl.isFile() ? this._impl.footer : null; }\n    isSync() { return this._impl.isSync(); }\n    isAsync() { return this._impl.isAsync(); }\n    isFile() { return this._impl.isFile(); }\n    isStream() { return this._impl.isStream(); }\n    next() {\n        return this._impl.next();\n    }\n    throw(value) {\n        return this._impl.throw(value);\n    }\n    return(value) {\n        return this._impl.return(value);\n    }\n    cancel() {\n        return this._impl.cancel();\n    }\n    reset(schema) {\n        this._impl.reset(schema);\n        this._DOMStream = undefined;\n        this._nodeStream = undefined;\n        return this;\n    }\n    open(options) {\n        const opening = this._impl.open(options);\n        return (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isPromise)(opening) ? opening.then(() => this) : this;\n    }\n    readRecordBatch(index) {\n        return this._impl.isFile() ? this._impl.readRecordBatch(index) : null;\n    }\n    [Symbol.iterator]() {\n        return this._impl[Symbol.iterator]();\n    }\n    [Symbol.asyncIterator]() {\n        return this._impl[Symbol.asyncIterator]();\n    }\n    toDOMStream() {\n        return _io_adapters__WEBPACK_IMPORTED_MODULE_3__[\"default\"].toDOMStream((this.isSync()\n            ? { [Symbol.iterator]: () => this }\n            : { [Symbol.asyncIterator]: () => this }));\n    }\n    toNodeStream() {\n        return _io_adapters__WEBPACK_IMPORTED_MODULE_3__[\"default\"].toNodeStream((this.isSync()\n            ? { [Symbol.iterator]: () => this }\n            : { [Symbol.asyncIterator]: () => this }), { objectMode: true });\n    }\n    /** @nocollapse */\n    // @ts-ignore\n    static throughNode(options) {\n        throw new Error(`\"throughNode\" not available in this environment`);\n    }\n    /** @nocollapse */\n    static throughDOM(\n    // @ts-ignore\n    writableStrategy, \n    // @ts-ignore\n    readableStrategy) {\n        throw new Error(`\"throughDOM\" not available in this environment`);\n    }\n    /** @nocollapse */\n    static from(source) {\n        if (source instanceof RecordBatchReader) {\n            return source;\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isArrowJSON)(source)) {\n            return fromArrowJSON(source);\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isFileHandle)(source)) {\n            return fromFileHandle(source);\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isPromise)(source)) {\n            return (async () => await RecordBatchReader.from(await source))();\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isFetchResponse)(source) || (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isReadableDOMStream)(source) || (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isReadableNodeStream)(source) || (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isAsyncIterable)(source)) {\n            return fromAsyncByteStream(new _io_stream__WEBPACK_IMPORTED_MODULE_4__.AsyncByteStream(source));\n        }\n        return fromByteStream(new _io_stream__WEBPACK_IMPORTED_MODULE_4__.ByteStream(source));\n    }\n    /** @nocollapse */\n    static readAll(source) {\n        if (source instanceof RecordBatchReader) {\n            return source.isSync() ? readAllSync(source) : readAllAsync(source);\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isArrowJSON)(source) || ArrayBuffer.isView(source) || (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isIterable)(source) || (0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isIteratorResult)(source)) {\n            return readAllSync(source);\n        }\n        return readAllAsync(source);\n    }\n}\n//\n// Since TS is a structural type system, we define the following subclass stubs\n// so that concrete types exist to associate with with the interfaces below.\n//\n// The implementation for each RecordBatchReader is hidden away in the set of\n// `RecordBatchReaderImpl` classes in the second half of this file. This allows\n// us to export a single RecordBatchReader class, and swap out the impl based\n// on the io primitives or underlying arrow (JSON, file, or stream) at runtime.\n//\n// Async/await makes our job a bit harder, since it forces everything to be\n// either fully sync or fully async. This is why the logic for the reader impls\n// has been duplicated into both sync and async variants. Since the RBR\n// delegates to its impl, an RBR with an AsyncRecordBatchFileReaderImpl for\n// example will return async/await-friendly Promises, but one with a (sync)\n// RecordBatchStreamReaderImpl will always return values. Nothing should be\n// different about their logic, aside from the async handling. This is also why\n// this code looks highly structured, as it should be nearly identical and easy\n// to follow.\n//\n/** @ignore */\nclass RecordBatchStreamReader extends RecordBatchReader {\n    constructor(_impl) {\n        super(_impl);\n        this._impl = _impl;\n    }\n    [Symbol.iterator]() { return this._impl[Symbol.iterator](); }\n    async *[Symbol.asyncIterator]() { yield* this[Symbol.iterator](); }\n}\n/** @ignore */\nclass AsyncRecordBatchStreamReader extends RecordBatchReader {\n    constructor(_impl) {\n        super(_impl);\n        this._impl = _impl;\n    }\n    [Symbol.iterator]() { throw new Error(`AsyncRecordBatchStreamReader is not Iterable`); }\n    [Symbol.asyncIterator]() { return this._impl[Symbol.asyncIterator](); }\n}\n/** @ignore */\nclass RecordBatchFileReader extends RecordBatchStreamReader {\n    constructor(_impl) {\n        super(_impl);\n        this._impl = _impl;\n    }\n}\n/** @ignore */\nclass AsyncRecordBatchFileReader extends AsyncRecordBatchStreamReader {\n    constructor(_impl) {\n        super(_impl);\n        this._impl = _impl;\n    }\n}\n/** @ignore */\nclass RecordBatchReaderImpl {\n    constructor(dictionaries = new Map()) {\n        this.closed = false;\n        this.autoDestroy = true;\n        this._dictionaryIndex = 0;\n        this._recordBatchIndex = 0;\n        this.dictionaries = dictionaries;\n    }\n    get numDictionaries() { return this._dictionaryIndex; }\n    get numRecordBatches() { return this._recordBatchIndex; }\n    isSync() { return false; }\n    isAsync() { return false; }\n    isFile() { return false; }\n    isStream() { return false; }\n    reset(schema) {\n        this._dictionaryIndex = 0;\n        this._recordBatchIndex = 0;\n        this.schema = schema;\n        this.dictionaries = new Map();\n        return this;\n    }\n    _loadRecordBatch(header, body) {\n        return new _recordbatch__WEBPACK_IMPORTED_MODULE_7__.RecordBatch(this.schema, header.length, this._loadVectors(header, body, this.schema.fields));\n    }\n    _loadDictionaryBatch(header, body) {\n        const { id, isDelta, data } = header;\n        const { dictionaries, schema } = this;\n        const dictionary = dictionaries.get(id);\n        if (isDelta || !dictionary) {\n            const type = schema.dictionaries.get(id);\n            return (dictionary && isDelta ? dictionary.concat(_vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new(this._loadVectors(data, body, [type])[0])) :\n                _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new(this._loadVectors(data, body, [type])[0]));\n        }\n        return dictionary;\n    }\n    _loadVectors(header, body, types) {\n        return new _visitor_vectorloader__WEBPACK_IMPORTED_MODULE_6__.VectorLoader(body, header.nodes, header.buffers, this.dictionaries).visitMany(types);\n    }\n}\n/** @ignore */\nclass RecordBatchStreamReaderImpl extends RecordBatchReaderImpl {\n    constructor(source, dictionaries) {\n        super(dictionaries);\n        this._reader = !(0,_util_compat__WEBPACK_IMPORTED_MODULE_10__.isArrowJSON)(source)\n            ? new _message__WEBPACK_IMPORTED_MODULE_9__.MessageReader(this._handle = source)\n            : new _message__WEBPACK_IMPORTED_MODULE_9__.JSONMessageReader(this._handle = source);\n    }\n    isSync() { return true; }\n    isStream() { return true; }\n    [Symbol.iterator]() {\n        return this;\n    }\n    cancel() {\n        if (!this.closed && (this.closed = true)) {\n            this.reset()._reader.return();\n            this._reader = null;\n            this.dictionaries = null;\n        }\n    }\n    open(options) {\n        if (!this.closed) {\n            this.autoDestroy = shouldAutoDestroy(this, options);\n            if (!(this.schema || (this.schema = this._reader.readSchema()))) {\n                this.cancel();\n            }\n        }\n        return this;\n    }\n    throw(value) {\n        if (!this.closed && this.autoDestroy && (this.closed = true)) {\n            return this.reset()._reader.throw(value);\n        }\n        return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n    }\n    return(value) {\n        if (!this.closed && this.autoDestroy && (this.closed = true)) {\n            return this.reset()._reader.return(value);\n        }\n        return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n    }\n    next() {\n        if (this.closed) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n        }\n        let message, { _reader: reader } = this;\n        while (message = this._readNextMessageAndValidate()) {\n            if (message.isSchema()) {\n                this.reset(message.header());\n            }\n            else if (message.isRecordBatch()) {\n                this._recordBatchIndex++;\n                const header = message.header();\n                const buffer = reader.readMessageBody(message.bodyLength);\n                const recordBatch = this._loadRecordBatch(header, buffer);\n                return { done: false, value: recordBatch };\n            }\n            else if (message.isDictionaryBatch()) {\n                this._dictionaryIndex++;\n                const header = message.header();\n                const buffer = reader.readMessageBody(message.bodyLength);\n                const vector = this._loadDictionaryBatch(header, buffer);\n                this.dictionaries.set(header.id, vector);\n            }\n        }\n        if (this.schema && this._recordBatchIndex === 0) {\n            this._recordBatchIndex++;\n            return { done: false, value: new _recordbatch__WEBPACK_IMPORTED_MODULE_7__._InternalEmptyPlaceholderRecordBatch(this.schema) };\n        }\n        return this.return();\n    }\n    _readNextMessageAndValidate(type) {\n        return this._reader.readMessage(type);\n    }\n}\n/** @ignore */\nclass AsyncRecordBatchStreamReaderImpl extends RecordBatchReaderImpl {\n    constructor(source, dictionaries) {\n        super(dictionaries);\n        this._reader = new _message__WEBPACK_IMPORTED_MODULE_9__.AsyncMessageReader(this._handle = source);\n    }\n    isAsync() { return true; }\n    isStream() { return true; }\n    [Symbol.asyncIterator]() {\n        return this;\n    }\n    async cancel() {\n        if (!this.closed && (this.closed = true)) {\n            await this.reset()._reader.return();\n            this._reader = null;\n            this.dictionaries = null;\n        }\n    }\n    async open(options) {\n        if (!this.closed) {\n            this.autoDestroy = shouldAutoDestroy(this, options);\n            if (!(this.schema || (this.schema = (await this._reader.readSchema())))) {\n                await this.cancel();\n            }\n        }\n        return this;\n    }\n    async throw(value) {\n        if (!this.closed && this.autoDestroy && (this.closed = true)) {\n            return await this.reset()._reader.throw(value);\n        }\n        return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n    }\n    async return(value) {\n        if (!this.closed && this.autoDestroy && (this.closed = true)) {\n            return await this.reset()._reader.return(value);\n        }\n        return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n    }\n    async next() {\n        if (this.closed) {\n            return _io_interfaces__WEBPACK_IMPORTED_MODULE_8__.ITERATOR_DONE;\n        }\n        let message, { _reader: reader } = this;\n        while (message = await this._readNextMessageAndValidate()) {\n            if (message.isSchema()) {\n                await this.reset(message.header());\n            }\n            else if (message.isRecordBatch()) {\n                this._recordBatchIndex++;\n                const header = message.header();\n                const buffer = await reader.readMessageBody(message.bodyLength);\n                const recordBatch = this._loadRecordBatch(header, buffer);\n                return { done: false, value: recordBatch };\n            }\n            else if (message.isDictionaryBatch()) {\n                this._dictionaryIndex++;\n                const header = message.header();\n                const buffer = await reader.readMessageBody(message.bodyLength);\n                const vector = this._loadDictionaryBatch(header, buffer);\n                this.dictionaries.set(header.id, vector);\n            }\n        }\n        if (this.schema && this._recordBatchIndex === 0) {\n            this._recordBatchIndex++;\n            return { done: false, value: new _recordbatch__WEBPACK_IMPORTED_MODULE_7__._InternalEmptyPlaceholderRecordBatch(this.schema) };\n        }\n        return await this.return();\n    }\n    async _readNextMessageAndValidate(type) {\n        return await this._reader.readMessage(type);\n    }\n}\n/** @ignore */\nclass RecordBatchFileReaderImpl extends RecordBatchStreamReaderImpl {\n    constructor(source, dictionaries) {\n        super(source instanceof _io_file__WEBPACK_IMPORTED_MODULE_5__.RandomAccessFile ? source : new _io_file__WEBPACK_IMPORTED_MODULE_5__.RandomAccessFile(source), dictionaries);\n    }\n    get footer() { return this._footer; }\n    get numDictionaries() { return this._footer ? this._footer.numDictionaries : 0; }\n    get numRecordBatches() { return this._footer ? this._footer.numRecordBatches : 0; }\n    isSync() { return true; }\n    isFile() { return true; }\n    open(options) {\n        if (!this.closed && !this._footer) {\n            this.schema = (this._footer = this._readFooter()).schema;\n            for (const block of this._footer.dictionaryBatches()) {\n                block && this._readDictionaryBatch(this._dictionaryIndex++);\n            }\n        }\n        return super.open(options);\n    }\n    readRecordBatch(index) {\n        if (this.closed) {\n            return null;\n        }\n        if (!this._footer) {\n            this.open();\n        }\n        const block = this._footer && this._footer.getRecordBatch(index);\n        if (block && this._handle.seek(block.offset)) {\n            const message = this._reader.readMessage(_enum__WEBPACK_IMPORTED_MODULE_1__.MessageHeader.RecordBatch);\n            if (message && message.isRecordBatch()) {\n                const header = message.header();\n                const buffer = this._reader.readMessageBody(message.bodyLength);\n                const recordBatch = this._loadRecordBatch(header, buffer);\n                return recordBatch;\n            }\n        }\n        return null;\n    }\n    _readDictionaryBatch(index) {\n        const block = this._footer && this._footer.getDictionaryBatch(index);\n        if (block && this._handle.seek(block.offset)) {\n            const message = this._reader.readMessage(_enum__WEBPACK_IMPORTED_MODULE_1__.MessageHeader.DictionaryBatch);\n            if (message && message.isDictionaryBatch()) {\n                const header = message.header();\n                const buffer = this._reader.readMessageBody(message.bodyLength);\n                const vector = this._loadDictionaryBatch(header, buffer);\n                this.dictionaries.set(header.id, vector);\n            }\n        }\n    }\n    _readFooter() {\n        const { _handle } = this;\n        const offset = _handle.size - _message__WEBPACK_IMPORTED_MODULE_9__.magicAndPadding;\n        const length = _handle.readInt32(offset);\n        const buffer = _handle.readAt(offset - length, length);\n        return _metadata_file__WEBPACK_IMPORTED_MODULE_2__.Footer.decode(buffer);\n    }\n    _readNextMessageAndValidate(type) {\n        if (!this._footer) {\n            this.open();\n        }\n        if (this._footer && this._recordBatchIndex < this.numRecordBatches) {\n            const block = this._footer && this._footer.getRecordBatch(this._recordBatchIndex);\n            if (block && this._handle.seek(block.offset)) {\n                return this._reader.readMessage(type);\n            }\n        }\n        return null;\n    }\n}\n/** @ignore */\nclass AsyncRecordBatchFileReaderImpl extends AsyncRecordBatchStreamReaderImpl {\n    constructor(source, ...rest) {\n        const byteLength = typeof rest[0] !== 'number' ? rest.shift() : undefined;\n        const dictionaries = rest[0] instanceof Map ? rest.shift() : undefined;\n        super(source instanceof _io_file__WEBPACK_IMPORTED_MODULE_5__.AsyncRandomAccessFile ? source : new _io_file__WEBPACK_IMPORTED_MODULE_5__.AsyncRandomAccessFile(source, byteLength), dictionaries);\n    }\n    get footer() { return this._footer; }\n    get numDictionaries() { return this._footer ? this._footer.numDictionaries : 0; }\n    get numRecordBatches() { return this._footer ? this._footer.numRecordBatches : 0; }\n    isFile() { return true; }\n    isAsync() { return true; }\n    async open(options) {\n        if (!this.closed && !this._footer) {\n            this.schema = (this._footer = await this._readFooter()).schema;\n            for (const block of this._footer.dictionaryBatches()) {\n                block && await this._readDictionaryBatch(this._dictionaryIndex++);\n            }\n        }\n        return await super.open(options);\n    }\n    async readRecordBatch(index) {\n        if (this.closed) {\n            return null;\n        }\n        if (!this._footer) {\n            await this.open();\n        }\n        const block = this._footer && this._footer.getRecordBatch(index);\n        if (block && (await this._handle.seek(block.offset))) {\n            const message = await this._reader.readMessage(_enum__WEBPACK_IMPORTED_MODULE_1__.MessageHeader.RecordBatch);\n            if (message && message.isRecordBatch()) {\n                const header = message.header();\n                const buffer = await this._reader.readMessageBody(message.bodyLength);\n                const recordBatch = this._loadRecordBatch(header, buffer);\n                return recordBatch;\n            }\n        }\n        return null;\n    }\n    async _readDictionaryBatch(index) {\n        const block = this._footer && this._footer.getDictionaryBatch(index);\n        if (block && (await this._handle.seek(block.offset))) {\n            const message = await this._reader.readMessage(_enum__WEBPACK_IMPORTED_MODULE_1__.MessageHeader.DictionaryBatch);\n            if (message && message.isDictionaryBatch()) {\n                const header = message.header();\n                const buffer = await this._reader.readMessageBody(message.bodyLength);\n                const vector = this._loadDictionaryBatch(header, buffer);\n                this.dictionaries.set(header.id, vector);\n            }\n        }\n    }\n    async _readFooter() {\n        const { _handle } = this;\n        _handle._pending && await _handle._pending;\n        const offset = _handle.size - _message__WEBPACK_IMPORTED_MODULE_9__.magicAndPadding;\n        const length = await _handle.readInt32(offset);\n        const buffer = await _handle.readAt(offset - length, length);\n        return _metadata_file__WEBPACK_IMPORTED_MODULE_2__.Footer.decode(buffer);\n    }\n    async _readNextMessageAndValidate(type) {\n        if (!this._footer) {\n            await this.open();\n        }\n        if (this._footer && this._recordBatchIndex < this.numRecordBatches) {\n            const block = this._footer.getRecordBatch(this._recordBatchIndex);\n            if (block && await this._handle.seek(block.offset)) {\n                return await this._reader.readMessage(type);\n            }\n        }\n        return null;\n    }\n}\n/** @ignore */\nclass RecordBatchJSONReaderImpl extends RecordBatchStreamReaderImpl {\n    constructor(source, dictionaries) {\n        super(source, dictionaries);\n    }\n    _loadVectors(header, body, types) {\n        return new _visitor_vectorloader__WEBPACK_IMPORTED_MODULE_6__.JSONVectorLoader(body, header.nodes, header.buffers, this.dictionaries).visitMany(types);\n    }\n}\n//\n// Define some helper functions and static implementations down here. There's\n// a bit of branching in the static methods that can lead to the same routines\n// being executed, so we've broken those out here for readability.\n//\n/** @ignore */\nfunction shouldAutoDestroy(self, options) {\n    return options && (typeof options['autoDestroy'] === 'boolean') ? options['autoDestroy'] : self['autoDestroy'];\n}\n/** @ignore */\nfunction* readAllSync(source) {\n    const reader = RecordBatchReader.from(source);\n    try {\n        if (!reader.open({ autoDestroy: false }).closed) {\n            do {\n                yield reader;\n            } while (!(reader.reset().open()).closed);\n        }\n    }\n    finally {\n        reader.cancel();\n    }\n}\n/** @ignore */\nasync function* readAllAsync(source) {\n    const reader = await RecordBatchReader.from(source);\n    try {\n        if (!(await reader.open({ autoDestroy: false })).closed) {\n            do {\n                yield reader;\n            } while (!(await reader.reset().open()).closed);\n        }\n    }\n    finally {\n        await reader.cancel();\n    }\n}\n/** @ignore */\nfunction fromArrowJSON(source) {\n    return new RecordBatchStreamReader(new RecordBatchJSONReaderImpl(source));\n}\n/** @ignore */\nfunction fromByteStream(source) {\n    const bytes = source.peek((_message__WEBPACK_IMPORTED_MODULE_9__.magicLength + 7) & ~7);\n    return bytes && bytes.byteLength >= 4 ? !(0,_message__WEBPACK_IMPORTED_MODULE_9__.checkForMagicArrowString)(bytes)\n        ? new RecordBatchStreamReader(new RecordBatchStreamReaderImpl(source))\n        : new RecordBatchFileReader(new RecordBatchFileReaderImpl(source.read()))\n        : new RecordBatchStreamReader(new RecordBatchStreamReaderImpl(function* () { }()));\n}\n/** @ignore */\nasync function fromAsyncByteStream(source) {\n    const bytes = await source.peek((_message__WEBPACK_IMPORTED_MODULE_9__.magicLength + 7) & ~7);\n    return bytes && bytes.byteLength >= 4 ? !(0,_message__WEBPACK_IMPORTED_MODULE_9__.checkForMagicArrowString)(bytes)\n        ? new AsyncRecordBatchStreamReader(new AsyncRecordBatchStreamReaderImpl(source))\n        : new RecordBatchFileReader(new RecordBatchFileReaderImpl(await source.read()))\n        : new AsyncRecordBatchStreamReader(new AsyncRecordBatchStreamReaderImpl(async function* () { }()));\n}\n/** @ignore */\nasync function fromFileHandle(source) {\n    const { size } = await source.stat();\n    const file = new _io_file__WEBPACK_IMPORTED_MODULE_5__.AsyncRandomAccessFile(source, size);\n    if (size >= _message__WEBPACK_IMPORTED_MODULE_9__.magicX2AndPadding) {\n        if ((0,_message__WEBPACK_IMPORTED_MODULE_9__.checkForMagicArrowString)(await file.readAt(0, (_message__WEBPACK_IMPORTED_MODULE_9__.magicLength + 7) & ~7))) {\n            return new AsyncRecordBatchFileReader(new AsyncRecordBatchFileReaderImpl(file));\n        }\n    }\n    return new AsyncRecordBatchStreamReader(new AsyncRecordBatchStreamReaderImpl(file));\n}\n\n//# sourceMappingURL=reader.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/reader.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/ipc/writer.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/ipc/writer.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   RecordBatchFileWriter: () => (/* binding */ RecordBatchFileWriter),\n/* harmony export */   RecordBatchJSONWriter: () => (/* binding */ RecordBatchJSONWriter),\n/* harmony export */   RecordBatchStreamWriter: () => (/* binding */ RecordBatchStreamWriter),\n/* harmony export */   RecordBatchWriter: () => (/* binding */ RecordBatchWriter)\n/* harmony export */ });\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../table */ \"../../node_modules/apache-arrow/table.mjs\");\n/* harmony import */ var _message__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./message */ \"../../node_modules/apache-arrow/ipc/message.mjs\");\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../column */ \"../../node_modules/apache-arrow/column.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _metadata_message__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./metadata/message */ \"../../node_modules/apache-arrow/ipc/metadata/message.mjs\");\n/* harmony import */ var _metadata_file__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./metadata/file */ \"../../node_modules/apache-arrow/ipc/metadata/file.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _io_stream__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../io/stream */ \"../../node_modules/apache-arrow/io/stream.mjs\");\n/* harmony import */ var _visitor_vectorassembler__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../visitor/vectorassembler */ \"../../node_modules/apache-arrow/visitor/vectorassembler.mjs\");\n/* harmony import */ var _visitor_jsontypeassembler__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../visitor/jsontypeassembler */ \"../../node_modules/apache-arrow/visitor/jsontypeassembler.mjs\");\n/* harmony import */ var _visitor_jsonvectorassembler__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../visitor/jsonvectorassembler */ \"../../node_modules/apache-arrow/visitor/jsonvectorassembler.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _io_interfaces__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../io/interfaces */ \"../../node_modules/apache-arrow/io/interfaces.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nclass RecordBatchWriter extends _io_interfaces__WEBPACK_IMPORTED_MODULE_14__.ReadableInterop {\n    constructor(options) {\n        super();\n        this._position = 0;\n        this._started = false;\n        // @ts-ignore\n        this._sink = new _io_stream__WEBPACK_IMPORTED_MODULE_8__.AsyncByteQueue();\n        this._schema = null;\n        this._dictionaryBlocks = [];\n        this._recordBatchBlocks = [];\n        this._dictionaryDeltaOffsets = new Map();\n        (0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isObject)(options) || (options = { autoDestroy: true, writeLegacyIpcFormat: false });\n        this._autoDestroy = (typeof options.autoDestroy === 'boolean') ? options.autoDestroy : true;\n        this._writeLegacyIpcFormat = (typeof options.writeLegacyIpcFormat === 'boolean') ? options.writeLegacyIpcFormat : false;\n    }\n    /** @nocollapse */\n    // @ts-ignore\n    static throughNode(options) {\n        throw new Error(`\"throughNode\" not available in this environment`);\n    }\n    /** @nocollapse */\n    static throughDOM(\n    // @ts-ignore\n    writableStrategy, \n    // @ts-ignore\n    readableStrategy) {\n        throw new Error(`\"throughDOM\" not available in this environment`);\n    }\n    toString(sync = false) {\n        return this._sink.toString(sync);\n    }\n    toUint8Array(sync = false) {\n        return this._sink.toUint8Array(sync);\n    }\n    writeAll(input) {\n        if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isPromise)(input)) {\n            return input.then((x) => this.writeAll(x));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isAsyncIterable)(input)) {\n            return writeAllAsync(this, input);\n        }\n        return writeAll(this, input);\n    }\n    get closed() { return this._sink.closed; }\n    [Symbol.asyncIterator]() { return this._sink[Symbol.asyncIterator](); }\n    toDOMStream(options) { return this._sink.toDOMStream(options); }\n    toNodeStream(options) { return this._sink.toNodeStream(options); }\n    close() {\n        return this.reset()._sink.close();\n    }\n    abort(reason) {\n        return this.reset()._sink.abort(reason);\n    }\n    finish() {\n        this._autoDestroy ? this.close() : this.reset(this._sink, this._schema);\n        return this;\n    }\n    reset(sink = this._sink, schema = null) {\n        if ((sink === this._sink) || (sink instanceof _io_stream__WEBPACK_IMPORTED_MODULE_8__.AsyncByteQueue)) {\n            this._sink = sink;\n        }\n        else {\n            this._sink = new _io_stream__WEBPACK_IMPORTED_MODULE_8__.AsyncByteQueue();\n            if (sink && (0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isWritableDOMStream)(sink)) {\n                this.toDOMStream({ type: 'bytes' }).pipeTo(sink);\n            }\n            else if (sink && (0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isWritableNodeStream)(sink)) {\n                this.toNodeStream({ objectMode: false }).pipe(sink);\n            }\n        }\n        if (this._started && this._schema) {\n            this._writeFooter(this._schema);\n        }\n        this._started = false;\n        this._dictionaryBlocks = [];\n        this._recordBatchBlocks = [];\n        this._dictionaryDeltaOffsets = new Map();\n        if (!schema || !(schema.compareTo(this._schema))) {\n            if (schema === null) {\n                this._position = 0;\n                this._schema = null;\n            }\n            else {\n                this._started = true;\n                this._schema = schema;\n                this._writeSchema(schema);\n            }\n        }\n        return this;\n    }\n    write(payload) {\n        let schema = null;\n        if (!this._sink) {\n            throw new Error(`RecordBatchWriter is closed`);\n        }\n        else if (payload === null || payload === undefined) {\n            return this.finish() && undefined;\n        }\n        else if (payload instanceof _table__WEBPACK_IMPORTED_MODULE_0__.Table && !(schema = payload.schema)) {\n            return this.finish() && undefined;\n        }\n        else if (payload instanceof _recordbatch__WEBPACK_IMPORTED_MODULE_13__.RecordBatch && !(schema = payload.schema)) {\n            return this.finish() && undefined;\n        }\n        if (schema && !schema.compareTo(this._schema)) {\n            if (this._started && this._autoDestroy) {\n                return this.close();\n            }\n            this.reset(this._sink, schema);\n        }\n        if (payload instanceof _recordbatch__WEBPACK_IMPORTED_MODULE_13__.RecordBatch) {\n            if (!(payload instanceof _recordbatch__WEBPACK_IMPORTED_MODULE_13__._InternalEmptyPlaceholderRecordBatch)) {\n                this._writeRecordBatch(payload);\n            }\n        }\n        else if (payload instanceof _table__WEBPACK_IMPORTED_MODULE_0__.Table) {\n            this.writeAll(payload.chunks);\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isIterable)(payload)) {\n            this.writeAll(payload);\n        }\n    }\n    _writeMessage(message, alignment = 8) {\n        const a = alignment - 1;\n        const buffer = _metadata_message__WEBPACK_IMPORTED_MODULE_5__.Message.encode(message);\n        const flatbufferSize = buffer.byteLength;\n        const prefixSize = !this._writeLegacyIpcFormat ? 8 : 4;\n        const alignedSize = (flatbufferSize + prefixSize + a) & ~a;\n        const nPaddingBytes = alignedSize - flatbufferSize - prefixSize;\n        if (message.headerType === _enum__WEBPACK_IMPORTED_MODULE_7__.MessageHeader.RecordBatch) {\n            this._recordBatchBlocks.push(new _metadata_file__WEBPACK_IMPORTED_MODULE_6__.FileBlock(alignedSize, message.bodyLength, this._position));\n        }\n        else if (message.headerType === _enum__WEBPACK_IMPORTED_MODULE_7__.MessageHeader.DictionaryBatch) {\n            this._dictionaryBlocks.push(new _metadata_file__WEBPACK_IMPORTED_MODULE_6__.FileBlock(alignedSize, message.bodyLength, this._position));\n        }\n        // If not in legacy pre-0.15.0 mode, write the stream continuation indicator\n        if (!this._writeLegacyIpcFormat) {\n            this._write(Int32Array.of(-1));\n        }\n        // Write the flatbuffer size prefix including padding\n        this._write(Int32Array.of(alignedSize - prefixSize));\n        // Write the flatbuffer\n        if (flatbufferSize > 0) {\n            this._write(buffer);\n        }\n        // Write any padding\n        return this._writePadding(nPaddingBytes);\n    }\n    _write(chunk) {\n        if (this._started) {\n            const buffer = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_12__.toUint8Array)(chunk);\n            if (buffer && buffer.byteLength > 0) {\n                this._sink.write(buffer);\n                this._position += buffer.byteLength;\n            }\n        }\n        return this;\n    }\n    _writeSchema(schema) {\n        return this._writeMessage(_metadata_message__WEBPACK_IMPORTED_MODULE_5__.Message.from(schema));\n    }\n    // @ts-ignore\n    _writeFooter(schema) {\n        // eos bytes\n        return this._writeLegacyIpcFormat\n            ? this._write(Int32Array.of(0))\n            : this._write(Int32Array.of(-1, 0));\n    }\n    _writeMagic() {\n        return this._write(_message__WEBPACK_IMPORTED_MODULE_1__.MAGIC);\n    }\n    _writePadding(nBytes) {\n        return nBytes > 0 ? this._write(new Uint8Array(nBytes)) : this;\n    }\n    _writeRecordBatch(batch) {\n        const { byteLength, nodes, bufferRegions, buffers } = _visitor_vectorassembler__WEBPACK_IMPORTED_MODULE_9__.VectorAssembler.assemble(batch);\n        const recordBatch = new _metadata_message__WEBPACK_IMPORTED_MODULE_5__.RecordBatch(batch.length, nodes, bufferRegions);\n        const message = _metadata_message__WEBPACK_IMPORTED_MODULE_5__.Message.from(recordBatch, byteLength);\n        return this\n            ._writeDictionaries(batch)\n            ._writeMessage(message)\n            ._writeBodyBuffers(buffers);\n    }\n    _writeDictionaryBatch(dictionary, id, isDelta = false) {\n        this._dictionaryDeltaOffsets.set(id, dictionary.length + (this._dictionaryDeltaOffsets.get(id) || 0));\n        const { byteLength, nodes, bufferRegions, buffers } = _visitor_vectorassembler__WEBPACK_IMPORTED_MODULE_9__.VectorAssembler.assemble(dictionary);\n        const recordBatch = new _metadata_message__WEBPACK_IMPORTED_MODULE_5__.RecordBatch(dictionary.length, nodes, bufferRegions);\n        const dictionaryBatch = new _metadata_message__WEBPACK_IMPORTED_MODULE_5__.DictionaryBatch(recordBatch, id, isDelta);\n        const message = _metadata_message__WEBPACK_IMPORTED_MODULE_5__.Message.from(dictionaryBatch, byteLength);\n        return this\n            ._writeMessage(message)\n            ._writeBodyBuffers(buffers);\n    }\n    _writeBodyBuffers(buffers) {\n        let buffer;\n        let size, padding;\n        for (let i = -1, n = buffers.length; ++i < n;) {\n            if ((buffer = buffers[i]) && (size = buffer.byteLength) > 0) {\n                this._write(buffer);\n                if ((padding = ((size + 7) & ~7) - size) > 0) {\n                    this._writePadding(padding);\n                }\n            }\n        }\n        return this;\n    }\n    _writeDictionaries(batch) {\n        for (let [id, dictionary] of batch.dictionaries) {\n            let offset = this._dictionaryDeltaOffsets.get(id) || 0;\n            if (offset === 0 || (dictionary = dictionary.slice(offset)).length > 0) {\n                const chunks = 'chunks' in dictionary ? dictionary.chunks : [dictionary];\n                for (const chunk of chunks) {\n                    this._writeDictionaryBatch(chunk, id, offset > 0);\n                    offset += chunk.length;\n                }\n            }\n        }\n        return this;\n    }\n}\n/** @ignore */\nclass RecordBatchStreamWriter extends RecordBatchWriter {\n    /** @nocollapse */\n    static writeAll(input, options) {\n        const writer = new RecordBatchStreamWriter(options);\n        if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isPromise)(input)) {\n            return input.then((x) => writer.writeAll(x));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isAsyncIterable)(input)) {\n            return writeAllAsync(writer, input);\n        }\n        return writeAll(writer, input);\n    }\n}\n/** @ignore */\nclass RecordBatchFileWriter extends RecordBatchWriter {\n    /** @nocollapse */\n    static writeAll(input) {\n        const writer = new RecordBatchFileWriter();\n        if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isPromise)(input)) {\n            return input.then((x) => writer.writeAll(x));\n        }\n        else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_15__.isAsyncIterable)(input)) {\n            return writeAllAsync(writer, input);\n        }\n        return writeAll(writer, input);\n    }\n    constructor() {\n        super();\n        this._autoDestroy = true;\n    }\n    // @ts-ignore\n    _writeSchema(schema) {\n        return this._writeMagic()._writePadding(2);\n    }\n    _writeFooter(schema) {\n        const buffer = _metadata_file__WEBPACK_IMPORTED_MODULE_6__.Footer.encode(new _metadata_file__WEBPACK_IMPORTED_MODULE_6__.Footer(schema, _enum__WEBPACK_IMPORTED_MODULE_7__.MetadataVersion.V4, this._recordBatchBlocks, this._dictionaryBlocks));\n        return super\n            ._writeFooter(schema) // EOS bytes for sequential readers\n            ._write(buffer) // Write the flatbuffer\n            ._write(Int32Array.of(buffer.byteLength)) // then the footer size suffix\n            ._writeMagic(); // then the magic suffix\n    }\n}\n/** @ignore */\nclass RecordBatchJSONWriter extends RecordBatchWriter {\n    constructor() {\n        super();\n        this._autoDestroy = true;\n        this._recordBatches = [];\n        this._dictionaries = [];\n    }\n    /** @nocollapse */\n    static writeAll(input) {\n        return new RecordBatchJSONWriter().writeAll(input);\n    }\n    _writeMessage() { return this; }\n    // @ts-ignore\n    _writeFooter(schema) { return this; }\n    _writeSchema(schema) {\n        return this._write(`{\\n  \"schema\": ${JSON.stringify({ fields: schema.fields.map(fieldToJSON) }, null, 2)}`);\n    }\n    _writeDictionaries(batch) {\n        if (batch.dictionaries.size > 0) {\n            this._dictionaries.push(batch);\n        }\n        return this;\n    }\n    _writeDictionaryBatch(dictionary, id, isDelta = false) {\n        this._dictionaryDeltaOffsets.set(id, dictionary.length + (this._dictionaryDeltaOffsets.get(id) || 0));\n        this._write(this._dictionaryBlocks.length === 0 ? `    ` : `,\\n    `);\n        this._write(`${dictionaryBatchToJSON(dictionary, id, isDelta)}`);\n        this._dictionaryBlocks.push(new _metadata_file__WEBPACK_IMPORTED_MODULE_6__.FileBlock(0, 0, 0));\n        return this;\n    }\n    _writeRecordBatch(batch) {\n        this._writeDictionaries(batch);\n        this._recordBatches.push(batch);\n        return this;\n    }\n    close() {\n        if (this._dictionaries.length > 0) {\n            this._write(`,\\n  \"dictionaries\": [\\n`);\n            for (const batch of this._dictionaries) {\n                super._writeDictionaries(batch);\n            }\n            this._write(`\\n  ]`);\n        }\n        if (this._recordBatches.length > 0) {\n            for (let i = -1, n = this._recordBatches.length; ++i < n;) {\n                this._write(i === 0 ? `,\\n  \"batches\": [\\n    ` : `,\\n    `);\n                this._write(`${recordBatchToJSON(this._recordBatches[i])}`);\n                this._recordBatchBlocks.push(new _metadata_file__WEBPACK_IMPORTED_MODULE_6__.FileBlock(0, 0, 0));\n            }\n            this._write(`\\n  ]`);\n        }\n        if (this._schema) {\n            this._write(`\\n}`);\n        }\n        this._dictionaries = [];\n        this._recordBatches = [];\n        return super.close();\n    }\n}\n/** @ignore */\nfunction writeAll(writer, input) {\n    let chunks = input;\n    if (input instanceof _table__WEBPACK_IMPORTED_MODULE_0__.Table) {\n        chunks = input.chunks;\n        writer.reset(undefined, input.schema);\n    }\n    for (const batch of chunks) {\n        writer.write(batch);\n    }\n    return writer.finish();\n}\n/** @ignore */\nasync function writeAllAsync(writer, batches) {\n    for await (const batch of batches) {\n        writer.write(batch);\n    }\n    return writer.finish();\n}\n/** @ignore */\nfunction fieldToJSON({ name, type, nullable }) {\n    const assembler = new _visitor_jsontypeassembler__WEBPACK_IMPORTED_MODULE_10__.JSONTypeAssembler();\n    return {\n        'name': name, 'nullable': nullable,\n        'type': assembler.visit(type),\n        'children': (type.children || []).map(fieldToJSON),\n        'dictionary': !_type__WEBPACK_IMPORTED_MODULE_3__.DataType.isDictionary(type) ? undefined : {\n            'id': type.id,\n            'isOrdered': type.isOrdered,\n            'indexType': assembler.visit(type.indices)\n        }\n    };\n}\n/** @ignore */\nfunction dictionaryBatchToJSON(dictionary, id, isDelta = false) {\n    const field = new _schema__WEBPACK_IMPORTED_MODULE_4__.Field(`${id}`, dictionary.type, dictionary.nullCount > 0);\n    const columns = _visitor_jsonvectorassembler__WEBPACK_IMPORTED_MODULE_11__.JSONVectorAssembler.assemble(new _column__WEBPACK_IMPORTED_MODULE_2__.Column(field, [dictionary]));\n    return JSON.stringify({\n        'id': id,\n        'isDelta': isDelta,\n        'data': {\n            'count': dictionary.length,\n            'columns': columns\n        }\n    }, null, 2);\n}\n/** @ignore */\nfunction recordBatchToJSON(records) {\n    return JSON.stringify({\n        'count': records.length,\n        'columns': _visitor_jsonvectorassembler__WEBPACK_IMPORTED_MODULE_11__.JSONVectorAssembler.assemble(records)\n    }, null, 2);\n}\n\n//# sourceMappingURL=writer.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/ipc/writer.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/recordbatch.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/recordbatch.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   RecordBatch: () => (/* binding */ RecordBatch),\n/* harmony export */   _InternalEmptyPlaceholderRecordBatch: () => (/* binding */ _InternalEmptyPlaceholderRecordBatch)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./table */ \"../../node_modules/apache-arrow/table.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _vector_chunked__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./vector/chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _util_recordbatch__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./util/recordbatch */ \"../../node_modules/apache-arrow/util/recordbatch.mjs\");\n/* harmony import */ var _vector_index__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./vector/index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\nclass RecordBatch extends _vector_index__WEBPACK_IMPORTED_MODULE_10__.StructVector {\n    constructor(...args) {\n        let data;\n        let schema = args[0];\n        let children;\n        if (args[1] instanceof _data__WEBPACK_IMPORTED_MODULE_0__.Data) {\n            [, data, children] = args;\n        }\n        else {\n            const fields = schema.fields;\n            const [, length, childData] = args;\n            data = _data__WEBPACK_IMPORTED_MODULE_0__.Data.Struct(new _type__WEBPACK_IMPORTED_MODULE_8__.Struct(fields), 0, length, 0, null, childData);\n        }\n        super(data, children);\n        this._schema = schema;\n    }\n    /** @nocollapse */\n    static from(options) {\n        if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_5__.isIterable)(options['values'])) {\n            return _table__WEBPACK_IMPORTED_MODULE_1__.Table.from(options);\n        }\n        return _table__WEBPACK_IMPORTED_MODULE_1__.Table.from(options);\n    }\n    /** @nocollapse */\n    static new(...args) {\n        const [fs, xs] = (0,_util_args__WEBPACK_IMPORTED_MODULE_7__.selectFieldArgs)(args);\n        const vs = xs.filter((x) => x instanceof _vector__WEBPACK_IMPORTED_MODULE_2__.Vector);\n        return new RecordBatch(...(0,_util_recordbatch__WEBPACK_IMPORTED_MODULE_9__.ensureSameLengthData)(new _schema__WEBPACK_IMPORTED_MODULE_4__.Schema(fs), vs.map((x) => x.data)));\n    }\n    clone(data, children = this._children) {\n        return new RecordBatch(this._schema, data, children);\n    }\n    concat(...others) {\n        const schema = this._schema, chunks = _vector_chunked__WEBPACK_IMPORTED_MODULE_6__.Chunked.flatten(this, ...others);\n        return new _table__WEBPACK_IMPORTED_MODULE_1__.Table(schema, chunks.map(({ data }) => new RecordBatch(schema, data)));\n    }\n    get schema() { return this._schema; }\n    get numCols() { return this._schema.fields.length; }\n    get dictionaries() {\n        return this._dictionaries || (this._dictionaries = DictionaryCollector.collect(this));\n    }\n    select(...columnNames) {\n        const nameToIndex = this._schema.fields.reduce((m, f, i) => m.set(f.name, i), new Map());\n        return this.selectAt(...columnNames.map((columnName) => nameToIndex.get(columnName)).filter((x) => x > -1));\n    }\n    selectAt(...columnIndices) {\n        const schema = this._schema.selectAt(...columnIndices);\n        const childData = columnIndices.map((i) => this.data.childData[i]).filter(Boolean);\n        return new RecordBatch(schema, this.length, childData);\n    }\n}\n/**\n * An internal class used by the `RecordBatchReader` and `RecordBatchWriter`\n * implementations to differentiate between a stream with valid zero-length\n * RecordBatches, and a stream with a Schema message, but no RecordBatches.\n * @see https://github.com/apache/arrow/pull/4373\n * @ignore\n * @private\n */\n/* tslint:disable:class-name */\nclass _InternalEmptyPlaceholderRecordBatch extends RecordBatch {\n    constructor(schema) {\n        super(schema, 0, schema.fields.map((f) => _data__WEBPACK_IMPORTED_MODULE_0__.Data.new(f.type, 0, 0, 0)));\n    }\n}\n/** @ignore */\nclass DictionaryCollector extends _visitor__WEBPACK_IMPORTED_MODULE_3__.Visitor {\n    constructor() {\n        super(...arguments);\n        this.dictionaries = new Map();\n    }\n    static collect(batch) {\n        return new DictionaryCollector().visit(batch.data, new _type__WEBPACK_IMPORTED_MODULE_8__.Struct(batch.schema.fields)).dictionaries;\n    }\n    visit(data, type) {\n        if (_type__WEBPACK_IMPORTED_MODULE_8__.DataType.isDictionary(type)) {\n            return this.visitDictionary(data, type);\n        }\n        else {\n            data.childData.forEach((child, i) => this.visit(child, type.children[i].type));\n        }\n        return this;\n    }\n    visitDictionary(data, type) {\n        const dictionary = data.dictionary;\n        if (dictionary && dictionary.length > 0) {\n            this.dictionaries.set(type.id, dictionary);\n        }\n        return this;\n    }\n}\n\n//# sourceMappingURL=recordbatch.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/recordbatch.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/schema.mjs":
/*!**************************************************!*\
  !*** ../../node_modules/apache-arrow/schema.mjs ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Field: () => (/* binding */ Field),\n/* harmony export */   Schema: () => (/* binding */ Schema)\n/* harmony export */ });\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _visitor_typecomparator__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./visitor/typecomparator */ \"../../node_modules/apache-arrow/visitor/typecomparator.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\nclass Schema {\n    constructor(fields = [], metadata, dictionaries) {\n        this.fields = (fields || []);\n        this.metadata = metadata || new Map();\n        if (!dictionaries) {\n            dictionaries = generateDictionaryMap(fields);\n        }\n        this.dictionaries = dictionaries;\n    }\n    /** @nocollapse */\n    static from(...args) {\n        return Schema.new(args[0], args[1]);\n    }\n    /** @nocollapse */\n    static new(...args) {\n        return new Schema((0,_util_args__WEBPACK_IMPORTED_MODULE_1__.selectFieldArgs)(args)[0]);\n    }\n    get [Symbol.toStringTag]() { return 'Schema'; }\n    toString() {\n        return `Schema<{ ${this.fields.map((f, i) => `${i}: ${f}`).join(', ')} }>`;\n    }\n    compareTo(other) {\n        return _visitor_typecomparator__WEBPACK_IMPORTED_MODULE_2__.instance.compareSchemas(this, other);\n    }\n    select(...columnNames) {\n        const names = columnNames.reduce((xs, x) => (xs[x] = true) && xs, Object.create(null));\n        return new Schema(this.fields.filter((f) => names[f.name]), this.metadata);\n    }\n    selectAt(...columnIndices) {\n        return new Schema(columnIndices.map((i) => this.fields[i]).filter(Boolean), this.metadata);\n    }\n    assign(...args) {\n        const other = args[0] instanceof Schema ? args[0]\n            : new Schema((0,_util_args__WEBPACK_IMPORTED_MODULE_1__.selectArgs)(Field, args));\n        const curFields = [...this.fields];\n        const metadata = mergeMaps(mergeMaps(new Map(), this.metadata), other.metadata);\n        const newFields = other.fields.filter((f2) => {\n            const i = curFields.findIndex((f) => f.name === f2.name);\n            return ~i ? (curFields[i] = f2.clone({\n                metadata: mergeMaps(mergeMaps(new Map(), curFields[i].metadata), f2.metadata)\n            })) && false : true;\n        });\n        const newDictionaries = generateDictionaryMap(newFields, new Map());\n        return new Schema([...curFields, ...newFields], metadata, new Map([...this.dictionaries, ...newDictionaries]));\n    }\n}\nclass Field {\n    constructor(name, type, nullable = false, metadata) {\n        this.name = name;\n        this.type = type;\n        this.nullable = nullable;\n        this.metadata = metadata || new Map();\n    }\n    /** @nocollapse */\n    static new(...args) {\n        let [name, type, nullable, metadata] = args;\n        if (args[0] && typeof args[0] === 'object') {\n            ({ name } = args[0]);\n            (type === undefined) && (type = args[0].type);\n            (nullable === undefined) && (nullable = args[0].nullable);\n            (metadata === undefined) && (metadata = args[0].metadata);\n        }\n        return new Field(`${name}`, type, nullable, metadata);\n    }\n    get typeId() { return this.type.typeId; }\n    get [Symbol.toStringTag]() { return 'Field'; }\n    toString() { return `${this.name}: ${this.type}`; }\n    compareTo(other) {\n        return _visitor_typecomparator__WEBPACK_IMPORTED_MODULE_2__.instance.compareField(this, other);\n    }\n    clone(...args) {\n        let [name, type, nullable, metadata] = args;\n        (!args[0] || typeof args[0] !== 'object')\n            ? ([name = this.name, type = this.type, nullable = this.nullable, metadata = this.metadata] = args)\n            : ({ name = this.name, type = this.type, nullable = this.nullable, metadata = this.metadata } = args[0]);\n        return Field.new(name, type, nullable, metadata);\n    }\n}\n/** @ignore */\nfunction mergeMaps(m1, m2) {\n    return new Map([...(m1 || new Map()), ...(m2 || new Map())]);\n}\n/** @ignore */\nfunction generateDictionaryMap(fields, dictionaries = new Map()) {\n    for (let i = -1, n = fields.length; ++i < n;) {\n        const field = fields[i];\n        const type = field.type;\n        if (_type__WEBPACK_IMPORTED_MODULE_0__.DataType.isDictionary(type)) {\n            if (!dictionaries.has(type.id)) {\n                dictionaries.set(type.id, type.dictionary);\n            }\n            else if (dictionaries.get(type.id) !== type.dictionary) {\n                throw new Error(`Cannot create Schema containing two different dictionaries with the same Id`);\n            }\n        }\n        if (type.children && type.children.length > 0) {\n            generateDictionaryMap(type.children, dictionaries);\n        }\n    }\n    return dictionaries;\n}\n// Add these here so they're picked up by the externs creator\n// in the build, and closure-compiler doesn't minify them away\nSchema.prototype.fields = null;\nSchema.prototype.metadata = null;\nSchema.prototype.dictionaries = null;\nField.prototype.type = null;\nField.prototype.name = null;\nField.prototype.nullable = null;\nField.prototype.metadata = null;\n\n//# sourceMappingURL=schema.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/schema.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/table.mjs":
/*!*************************************************!*\
  !*** ../../node_modules/apache-arrow/table.mjs ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Table: () => (/* binding */ Table)\n/* harmony export */ });\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./column */ \"../../node_modules/apache-arrow/column.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _ipc_reader__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./ipc/reader */ \"../../node_modules/apache-arrow/ipc/reader.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _ipc_writer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./ipc/writer */ \"../../node_modules/apache-arrow/ipc/writer.mjs\");\n/* harmony import */ var _util_recordbatch__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./util/recordbatch */ \"../../node_modules/apache-arrow/util/recordbatch.mjs\");\n/* harmony import */ var _vector_index__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./vector/index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\nclass Table extends _vector_index__WEBPACK_IMPORTED_MODULE_9__.Chunked {\n    constructor(...args) {\n        let schema = null;\n        if (args[0] instanceof _schema__WEBPACK_IMPORTED_MODULE_1__.Schema) {\n            schema = args.shift();\n        }\n        let chunks = (0,_util_args__WEBPACK_IMPORTED_MODULE_5__.selectArgs)(_recordbatch__WEBPACK_IMPORTED_MODULE_2__.RecordBatch, args);\n        if (!schema && !(schema = chunks[0] && chunks[0].schema)) {\n            throw new TypeError('Table must be initialized with a Schema or at least one RecordBatch');\n        }\n        chunks[0] || (chunks[0] = new _recordbatch__WEBPACK_IMPORTED_MODULE_2__._InternalEmptyPlaceholderRecordBatch(schema));\n        super(new _type__WEBPACK_IMPORTED_MODULE_4__.Struct(schema.fields), chunks);\n        this._schema = schema;\n        this._chunks = chunks;\n    }\n    /** @nocollapse */\n    static empty(schema = new _schema__WEBPACK_IMPORTED_MODULE_1__.Schema([])) { return new Table(schema, []); }\n    /** @nocollapse */\n    static from(input) {\n        if (!input) {\n            return Table.empty();\n        }\n        if (typeof input === 'object') {\n            let table = (0,_util_compat__WEBPACK_IMPORTED_MODULE_6__.isIterable)(input['values']) ? tableFromIterable(input)\n                : (0,_util_compat__WEBPACK_IMPORTED_MODULE_6__.isAsyncIterable)(input['values']) ? tableFromAsyncIterable(input)\n                    : null;\n            if (table !== null) {\n                return table;\n            }\n        }\n        let reader = _ipc_reader__WEBPACK_IMPORTED_MODULE_3__.RecordBatchReader.from(input);\n        if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_6__.isPromise)(reader)) {\n            return (async () => await Table.from(await reader))();\n        }\n        if (reader.isSync() && (reader = reader.open())) {\n            return !reader.schema ? Table.empty() : new Table(reader.schema, [...reader]);\n        }\n        return (async (opening) => {\n            const reader = await opening;\n            const schema = reader.schema;\n            const batches = [];\n            if (schema) {\n                for await (let batch of reader) {\n                    batches.push(batch);\n                }\n                return new Table(schema, batches);\n            }\n            return Table.empty();\n        })(reader.open());\n    }\n    /** @nocollapse */\n    static async fromAsync(source) {\n        return await Table.from(source);\n    }\n    /** @nocollapse */\n    static fromStruct(vector) {\n        return Table.new(vector.data.childData, vector.type.children);\n    }\n    /** @nocollapse */\n    static new(...cols) {\n        return new Table(...(0,_util_recordbatch__WEBPACK_IMPORTED_MODULE_8__.distributeColumnsIntoRecordBatches)((0,_util_args__WEBPACK_IMPORTED_MODULE_5__.selectColumnArgs)(cols)));\n    }\n    get schema() { return this._schema; }\n    get length() { return this._length; }\n    get chunks() { return this._chunks; }\n    get numCols() { return this._numChildren; }\n    clone(chunks = this._chunks) {\n        return new Table(this._schema, chunks);\n    }\n    getColumn(name) {\n        return this.getColumnAt(this.getColumnIndex(name));\n    }\n    getColumnAt(index) {\n        return this.getChildAt(index);\n    }\n    getColumnIndex(name) {\n        return this._schema.fields.findIndex((f) => f.name === name);\n    }\n    getChildAt(index) {\n        if (index < 0 || index >= this.numChildren) {\n            return null;\n        }\n        let field, child;\n        const fields = this._schema.fields;\n        const columns = this._children || (this._children = []);\n        if (child = columns[index]) {\n            return child;\n        }\n        if (field = fields[index]) {\n            const chunks = this._chunks\n                .map((chunk) => chunk.getChildAt(index))\n                .filter((vec) => vec != null);\n            if (chunks.length > 0) {\n                return (columns[index] = new _column__WEBPACK_IMPORTED_MODULE_0__.Column(field, chunks));\n            }\n        }\n        return null;\n    }\n    // @ts-ignore\n    serialize(encoding = 'binary', stream = true) {\n        const Writer = !stream\n            ? _ipc_writer__WEBPACK_IMPORTED_MODULE_7__.RecordBatchFileWriter\n            : _ipc_writer__WEBPACK_IMPORTED_MODULE_7__.RecordBatchStreamWriter;\n        return Writer.writeAll(this).toUint8Array(true);\n    }\n    count() {\n        return this._length;\n    }\n    select(...columnNames) {\n        const nameToIndex = this._schema.fields.reduce((m, f, i) => m.set(f.name, i), new Map());\n        return this.selectAt(...columnNames.map((columnName) => nameToIndex.get(columnName)).filter((x) => x > -1));\n    }\n    selectAt(...columnIndices) {\n        const schema = this._schema.selectAt(...columnIndices);\n        return new Table(schema, this._chunks.map(({ length, data: { childData } }) => {\n            return new _recordbatch__WEBPACK_IMPORTED_MODULE_2__.RecordBatch(schema, length, columnIndices.map((i) => childData[i]).filter(Boolean));\n        }));\n    }\n    assign(other) {\n        const fields = this._schema.fields;\n        const [indices, oldToNew] = other.schema.fields.reduce((memo, f2, newIdx) => {\n            const [indices, oldToNew] = memo;\n            const i = fields.findIndex((f) => f.name === f2.name);\n            ~i ? (oldToNew[i] = newIdx) : indices.push(newIdx);\n            return memo;\n        }, [[], []]);\n        const schema = this._schema.assign(other.schema);\n        const columns = [\n            ...fields.map((_f, i, _fs, j = oldToNew[i]) => (j === undefined ? this.getColumnAt(i) : other.getColumnAt(j))),\n            ...indices.map((i) => other.getColumnAt(i))\n        ].filter(Boolean);\n        return new Table(...(0,_util_recordbatch__WEBPACK_IMPORTED_MODULE_8__.distributeVectorsIntoRecordBatches)(schema, columns));\n    }\n}\nfunction tableFromIterable(input) {\n    const { type } = input;\n    if (type instanceof _type__WEBPACK_IMPORTED_MODULE_4__.Struct) {\n        return Table.fromStruct(_vector_index__WEBPACK_IMPORTED_MODULE_9__.StructVector.from(input));\n    }\n    return null;\n}\nfunction tableFromAsyncIterable(input) {\n    const { type } = input;\n    if (type instanceof _type__WEBPACK_IMPORTED_MODULE_4__.Struct) {\n        return _vector_index__WEBPACK_IMPORTED_MODULE_9__.StructVector.from(input).then((vector) => Table.fromStruct(vector));\n    }\n    return null;\n}\n\n//# sourceMappingURL=table.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/table.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/type.mjs":
/*!************************************************!*\
  !*** ../../node_modules/apache-arrow/type.mjs ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Binary: () => (/* binding */ Binary),\n/* harmony export */   Bool: () => (/* binding */ Bool),\n/* harmony export */   DataType: () => (/* binding */ DataType),\n/* harmony export */   DateDay: () => (/* binding */ DateDay),\n/* harmony export */   DateMillisecond: () => (/* binding */ DateMillisecond),\n/* harmony export */   Date_: () => (/* binding */ Date_),\n/* harmony export */   Decimal: () => (/* binding */ Decimal),\n/* harmony export */   DenseUnion: () => (/* binding */ DenseUnion),\n/* harmony export */   Dictionary: () => (/* binding */ Dictionary),\n/* harmony export */   FixedSizeBinary: () => (/* binding */ FixedSizeBinary),\n/* harmony export */   FixedSizeList: () => (/* binding */ FixedSizeList),\n/* harmony export */   Float: () => (/* binding */ Float),\n/* harmony export */   Float16: () => (/* binding */ Float16),\n/* harmony export */   Float32: () => (/* binding */ Float32),\n/* harmony export */   Float64: () => (/* binding */ Float64),\n/* harmony export */   Int: () => (/* binding */ Int_),\n/* harmony export */   Int16: () => (/* binding */ Int16),\n/* harmony export */   Int32: () => (/* binding */ Int32),\n/* harmony export */   Int64: () => (/* binding */ Int64),\n/* harmony export */   Int8: () => (/* binding */ Int8),\n/* harmony export */   Interval: () => (/* binding */ Interval_),\n/* harmony export */   IntervalDayTime: () => (/* binding */ IntervalDayTime),\n/* harmony export */   IntervalYearMonth: () => (/* binding */ IntervalYearMonth),\n/* harmony export */   List: () => (/* binding */ List),\n/* harmony export */   Map_: () => (/* binding */ Map_),\n/* harmony export */   Null: () => (/* binding */ Null),\n/* harmony export */   SparseUnion: () => (/* binding */ SparseUnion),\n/* harmony export */   Struct: () => (/* binding */ Struct),\n/* harmony export */   Time: () => (/* binding */ Time_),\n/* harmony export */   TimeMicrosecond: () => (/* binding */ TimeMicrosecond),\n/* harmony export */   TimeMillisecond: () => (/* binding */ TimeMillisecond),\n/* harmony export */   TimeNanosecond: () => (/* binding */ TimeNanosecond),\n/* harmony export */   TimeSecond: () => (/* binding */ TimeSecond),\n/* harmony export */   Timestamp: () => (/* binding */ Timestamp_),\n/* harmony export */   TimestampMicrosecond: () => (/* binding */ TimestampMicrosecond),\n/* harmony export */   TimestampMillisecond: () => (/* binding */ TimestampMillisecond),\n/* harmony export */   TimestampNanosecond: () => (/* binding */ TimestampNanosecond),\n/* harmony export */   TimestampSecond: () => (/* binding */ TimestampSecond),\n/* harmony export */   Uint16: () => (/* binding */ Uint16),\n/* harmony export */   Uint32: () => (/* binding */ Uint32),\n/* harmony export */   Uint64: () => (/* binding */ Uint64),\n/* harmony export */   Uint8: () => (/* binding */ Uint8),\n/* harmony export */   Union: () => (/* binding */ Union_),\n/* harmony export */   Utf8: () => (/* binding */ Utf8),\n/* harmony export */   strideForType: () => (/* binding */ strideForType)\n/* harmony export */ });\n/* harmony import */ var _visitor_typecomparator__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./visitor/typecomparator */ \"../../node_modules/apache-arrow/visitor/typecomparator.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/**\n * An abstract base class for classes that encapsulate metadata about each of\n * the logical types that Arrow can represent.\n */\nclass DataType {\n    /** @nocollapse */ static isNull(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Null; }\n    /** @nocollapse */ static isInt(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Int; }\n    /** @nocollapse */ static isFloat(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Float; }\n    /** @nocollapse */ static isBinary(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Binary; }\n    /** @nocollapse */ static isUtf8(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Utf8; }\n    /** @nocollapse */ static isBool(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Bool; }\n    /** @nocollapse */ static isDecimal(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Decimal; }\n    /** @nocollapse */ static isDate(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Date; }\n    /** @nocollapse */ static isTime(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Time; }\n    /** @nocollapse */ static isTimestamp(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Timestamp; }\n    /** @nocollapse */ static isInterval(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Interval; }\n    /** @nocollapse */ static isList(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.List; }\n    /** @nocollapse */ static isStruct(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Struct; }\n    /** @nocollapse */ static isUnion(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Union; }\n    /** @nocollapse */ static isFixedSizeBinary(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeBinary; }\n    /** @nocollapse */ static isFixedSizeList(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeList; }\n    /** @nocollapse */ static isMap(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Map; }\n    /** @nocollapse */ static isDictionary(x) { return x && x.typeId === _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Dictionary; }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.NONE; }\n    compareTo(other) {\n        return _visitor_typecomparator__WEBPACK_IMPORTED_MODULE_0__.instance.visit(this, other);\n    }\n}\nDataType[Symbol.toStringTag] = ((proto) => {\n    proto.children = null;\n    proto.ArrayType = Array;\n    return proto[Symbol.toStringTag] = 'DataType';\n})(DataType.prototype);\n/** @ignore */\nclass Null extends DataType {\n    toString() { return `Null`; }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Null; }\n}\nNull[Symbol.toStringTag] = ((proto) => {\n    return proto[Symbol.toStringTag] = 'Null';\n})(Null.prototype);\n/** @ignore */\nclass Int_ extends DataType {\n    constructor(isSigned, bitWidth) {\n        super();\n        this.isSigned = isSigned;\n        this.bitWidth = bitWidth;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Int; }\n    get ArrayType() {\n        switch (this.bitWidth) {\n            case 8: return this.isSigned ? Int8Array : Uint8Array;\n            case 16: return this.isSigned ? Int16Array : Uint16Array;\n            case 32: return this.isSigned ? Int32Array : Uint32Array;\n            case 64: return this.isSigned ? Int32Array : Uint32Array;\n        }\n        throw new Error(`Unrecognized ${this[Symbol.toStringTag]} type`);\n    }\n    toString() { return `${this.isSigned ? `I` : `Ui`}nt${this.bitWidth}`; }\n}\nInt_[Symbol.toStringTag] = ((proto) => {\n    proto.isSigned = null;\n    proto.bitWidth = null;\n    return proto[Symbol.toStringTag] = 'Int';\n})(Int_.prototype);\n\n/** @ignore */\nclass Int8 extends Int_ {\n    constructor() { super(true, 8); }\n}\n/** @ignore */\nclass Int16 extends Int_ {\n    constructor() { super(true, 16); }\n}\n/** @ignore */\nclass Int32 extends Int_ {\n    constructor() { super(true, 32); }\n}\n/** @ignore */\nclass Int64 extends Int_ {\n    constructor() { super(true, 64); }\n}\n/** @ignore */\nclass Uint8 extends Int_ {\n    constructor() { super(false, 8); }\n}\n/** @ignore */\nclass Uint16 extends Int_ {\n    constructor() { super(false, 16); }\n}\n/** @ignore */\nclass Uint32 extends Int_ {\n    constructor() { super(false, 32); }\n}\n/** @ignore */\nclass Uint64 extends Int_ {\n    constructor() { super(false, 64); }\n}\nObject.defineProperty(Int8.prototype, 'ArrayType', { value: Int8Array });\nObject.defineProperty(Int16.prototype, 'ArrayType', { value: Int16Array });\nObject.defineProperty(Int32.prototype, 'ArrayType', { value: Int32Array });\nObject.defineProperty(Int64.prototype, 'ArrayType', { value: Int32Array });\nObject.defineProperty(Uint8.prototype, 'ArrayType', { value: Uint8Array });\nObject.defineProperty(Uint16.prototype, 'ArrayType', { value: Uint16Array });\nObject.defineProperty(Uint32.prototype, 'ArrayType', { value: Uint32Array });\nObject.defineProperty(Uint64.prototype, 'ArrayType', { value: Uint32Array });\n/** @ignore */\nclass Float extends DataType {\n    constructor(precision) {\n        super();\n        this.precision = precision;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Float; }\n    get ArrayType() {\n        switch (this.precision) {\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Precision.HALF: return Uint16Array;\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Precision.SINGLE: return Float32Array;\n            case _enum__WEBPACK_IMPORTED_MODULE_1__.Precision.DOUBLE: return Float64Array;\n        }\n        // @ts-ignore\n        throw new Error(`Unrecognized ${this[Symbol.toStringTag]} type`);\n    }\n    toString() { return `Float${(this.precision << 5) || 16}`; }\n}\nFloat[Symbol.toStringTag] = ((proto) => {\n    proto.precision = null;\n    return proto[Symbol.toStringTag] = 'Float';\n})(Float.prototype);\n/** @ignore */\nclass Float16 extends Float {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.Precision.HALF); }\n}\n/** @ignore */\nclass Float32 extends Float {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.Precision.SINGLE); }\n}\n/** @ignore */\nclass Float64 extends Float {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.Precision.DOUBLE); }\n}\nObject.defineProperty(Float16.prototype, 'ArrayType', { value: Uint16Array });\nObject.defineProperty(Float32.prototype, 'ArrayType', { value: Float32Array });\nObject.defineProperty(Float64.prototype, 'ArrayType', { value: Float64Array });\n/** @ignore */\nclass Binary extends DataType {\n    constructor() {\n        super();\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Binary; }\n    toString() { return `Binary`; }\n}\nBinary[Symbol.toStringTag] = ((proto) => {\n    proto.ArrayType = Uint8Array;\n    return proto[Symbol.toStringTag] = 'Binary';\n})(Binary.prototype);\n/** @ignore */\nclass Utf8 extends DataType {\n    constructor() {\n        super();\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Utf8; }\n    toString() { return `Utf8`; }\n}\nUtf8[Symbol.toStringTag] = ((proto) => {\n    proto.ArrayType = Uint8Array;\n    return proto[Symbol.toStringTag] = 'Utf8';\n})(Utf8.prototype);\n/** @ignore */\nclass Bool extends DataType {\n    constructor() {\n        super();\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Bool; }\n    toString() { return `Bool`; }\n}\nBool[Symbol.toStringTag] = ((proto) => {\n    proto.ArrayType = Uint8Array;\n    return proto[Symbol.toStringTag] = 'Bool';\n})(Bool.prototype);\n/** @ignore */\nclass Decimal extends DataType {\n    constructor(scale, precision) {\n        super();\n        this.scale = scale;\n        this.precision = precision;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Decimal; }\n    toString() { return `Decimal[${this.precision}e${this.scale > 0 ? `+` : ``}${this.scale}]`; }\n}\nDecimal[Symbol.toStringTag] = ((proto) => {\n    proto.scale = null;\n    proto.precision = null;\n    proto.ArrayType = Uint32Array;\n    return proto[Symbol.toStringTag] = 'Decimal';\n})(Decimal.prototype);\n/** @ignore */\nclass Date_ extends DataType {\n    constructor(unit) {\n        super();\n        this.unit = unit;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Date; }\n    toString() { return `Date${(this.unit + 1) * 32}<${_enum__WEBPACK_IMPORTED_MODULE_1__.DateUnit[this.unit]}>`; }\n}\nDate_[Symbol.toStringTag] = ((proto) => {\n    proto.unit = null;\n    proto.ArrayType = Int32Array;\n    return proto[Symbol.toStringTag] = 'Date';\n})(Date_.prototype);\n/** @ignore */\nclass DateDay extends Date_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.DateUnit.DAY); }\n}\n/** @ignore */\nclass DateMillisecond extends Date_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.DateUnit.MILLISECOND); }\n}\n/** @ignore */\nclass Time_ extends DataType {\n    constructor(unit, bitWidth) {\n        super();\n        this.unit = unit;\n        this.bitWidth = bitWidth;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Time; }\n    toString() { return `Time${this.bitWidth}<${_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit[this.unit]}>`; }\n}\nTime_[Symbol.toStringTag] = ((proto) => {\n    proto.unit = null;\n    proto.bitWidth = null;\n    proto.ArrayType = Int32Array;\n    return proto[Symbol.toStringTag] = 'Time';\n})(Time_.prototype);\n\n/** @ignore */\nclass TimeSecond extends Time_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.SECOND, 32); }\n}\n/** @ignore */\nclass TimeMillisecond extends Time_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.MILLISECOND, 32); }\n}\n/** @ignore */\nclass TimeMicrosecond extends Time_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.MICROSECOND, 64); }\n}\n/** @ignore */\nclass TimeNanosecond extends Time_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.NANOSECOND, 64); }\n}\n/** @ignore */\nclass Timestamp_ extends DataType {\n    constructor(unit, timezone) {\n        super();\n        this.unit = unit;\n        this.timezone = timezone;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Timestamp; }\n    toString() { return `Timestamp<${_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit[this.unit]}${this.timezone ? `, ${this.timezone}` : ``}>`; }\n}\nTimestamp_[Symbol.toStringTag] = ((proto) => {\n    proto.unit = null;\n    proto.timezone = null;\n    proto.ArrayType = Int32Array;\n    return proto[Symbol.toStringTag] = 'Timestamp';\n})(Timestamp_.prototype);\n\n/** @ignore */\nclass TimestampSecond extends Timestamp_ {\n    constructor(timezone) { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.SECOND, timezone); }\n}\n/** @ignore */\nclass TimestampMillisecond extends Timestamp_ {\n    constructor(timezone) { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.MILLISECOND, timezone); }\n}\n/** @ignore */\nclass TimestampMicrosecond extends Timestamp_ {\n    constructor(timezone) { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.MICROSECOND, timezone); }\n}\n/** @ignore */\nclass TimestampNanosecond extends Timestamp_ {\n    constructor(timezone) { super(_enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.NANOSECOND, timezone); }\n}\n/** @ignore */\nclass Interval_ extends DataType {\n    constructor(unit) {\n        super();\n        this.unit = unit;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Interval; }\n    toString() { return `Interval<${_enum__WEBPACK_IMPORTED_MODULE_1__.IntervalUnit[this.unit]}>`; }\n}\nInterval_[Symbol.toStringTag] = ((proto) => {\n    proto.unit = null;\n    proto.ArrayType = Int32Array;\n    return proto[Symbol.toStringTag] = 'Interval';\n})(Interval_.prototype);\n\n/** @ignore */\nclass IntervalDayTime extends Interval_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.IntervalUnit.DAY_TIME); }\n}\n/** @ignore */\nclass IntervalYearMonth extends Interval_ {\n    constructor() { super(_enum__WEBPACK_IMPORTED_MODULE_1__.IntervalUnit.YEAR_MONTH); }\n}\n/** @ignore */\nclass List extends DataType {\n    constructor(child) {\n        super();\n        this.children = [child];\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.List; }\n    toString() { return `List<${this.valueType}>`; }\n    get valueType() { return this.children[0].type; }\n    get valueField() { return this.children[0]; }\n    get ArrayType() { return this.valueType.ArrayType; }\n}\nList[Symbol.toStringTag] = ((proto) => {\n    proto.children = null;\n    return proto[Symbol.toStringTag] = 'List';\n})(List.prototype);\n/** @ignore */\nclass Struct extends DataType {\n    constructor(children) {\n        super();\n        this.children = children;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Struct; }\n    toString() { return `Struct<{${this.children.map((f) => `${f.name}:${f.type}`).join(`, `)}}>`; }\n}\nStruct[Symbol.toStringTag] = ((proto) => {\n    proto.children = null;\n    return proto[Symbol.toStringTag] = 'Struct';\n})(Struct.prototype);\n/** @ignore */\nclass Union_ extends DataType {\n    constructor(mode, typeIds, children) {\n        super();\n        this.mode = mode;\n        this.children = children;\n        this.typeIds = typeIds = Int32Array.from(typeIds);\n        this.typeIdToChildIndex = typeIds.reduce((typeIdToChildIndex, typeId, idx) => {\n            return (typeIdToChildIndex[typeId] = idx) && typeIdToChildIndex || typeIdToChildIndex;\n        }, Object.create(null));\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Union; }\n    toString() {\n        return `${this[Symbol.toStringTag]}<${this.children.map((x) => `${x.type}`).join(` | `)}>`;\n    }\n}\nUnion_[Symbol.toStringTag] = ((proto) => {\n    proto.mode = null;\n    proto.typeIds = null;\n    proto.children = null;\n    proto.typeIdToChildIndex = null;\n    proto.ArrayType = Int8Array;\n    return proto[Symbol.toStringTag] = 'Union';\n})(Union_.prototype);\n\n/** @ignore */\nclass DenseUnion extends Union_ {\n    constructor(typeIds, children) {\n        super(_enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode.Dense, typeIds, children);\n    }\n}\n/** @ignore */\nclass SparseUnion extends Union_ {\n    constructor(typeIds, children) {\n        super(_enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode.Sparse, typeIds, children);\n    }\n}\n/** @ignore */\nclass FixedSizeBinary extends DataType {\n    constructor(byteWidth) {\n        super();\n        this.byteWidth = byteWidth;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeBinary; }\n    toString() { return `FixedSizeBinary[${this.byteWidth}]`; }\n}\nFixedSizeBinary[Symbol.toStringTag] = ((proto) => {\n    proto.byteWidth = null;\n    proto.ArrayType = Uint8Array;\n    return proto[Symbol.toStringTag] = 'FixedSizeBinary';\n})(FixedSizeBinary.prototype);\n/** @ignore */\nclass FixedSizeList extends DataType {\n    constructor(listSize, child) {\n        super();\n        this.listSize = listSize;\n        this.children = [child];\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeList; }\n    get valueType() { return this.children[0].type; }\n    get valueField() { return this.children[0]; }\n    get ArrayType() { return this.valueType.ArrayType; }\n    toString() { return `FixedSizeList[${this.listSize}]<${this.valueType}>`; }\n}\nFixedSizeList[Symbol.toStringTag] = ((proto) => {\n    proto.children = null;\n    proto.listSize = null;\n    return proto[Symbol.toStringTag] = 'FixedSizeList';\n})(FixedSizeList.prototype);\n/** @ignore */\nclass Map_ extends DataType {\n    constructor(child, keysSorted = false) {\n        super();\n        this.children = [child];\n        this.keysSorted = keysSorted;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Map; }\n    get keyType() { return this.children[0].type.children[0].type; }\n    get valueType() { return this.children[0].type.children[1].type; }\n    toString() { return `Map<{${this.children[0].type.children.map((f) => `${f.name}:${f.type}`).join(`, `)}}>`; }\n}\nMap_[Symbol.toStringTag] = ((proto) => {\n    proto.children = null;\n    proto.keysSorted = null;\n    return proto[Symbol.toStringTag] = 'Map_';\n})(Map_.prototype);\n/** @ignore */\nconst getId = ((atomicDictionaryId) => () => ++atomicDictionaryId)(-1);\n/** @ignore */\nclass Dictionary extends DataType {\n    constructor(dictionary, indices, id, isOrdered) {\n        super();\n        this.indices = indices;\n        this.dictionary = dictionary;\n        this.isOrdered = isOrdered || false;\n        this.id = id == null ? getId() : typeof id === 'number' ? id : id.low;\n    }\n    get typeId() { return _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Dictionary; }\n    get children() { return this.dictionary.children; }\n    get valueType() { return this.dictionary; }\n    get ArrayType() { return this.dictionary.ArrayType; }\n    toString() { return `Dictionary<${this.indices}, ${this.dictionary}>`; }\n}\nDictionary[Symbol.toStringTag] = ((proto) => {\n    proto.id = null;\n    proto.indices = null;\n    proto.isOrdered = null;\n    proto.dictionary = null;\n    return proto[Symbol.toStringTag] = 'Dictionary';\n})(Dictionary.prototype);\n/** @ignore */\nfunction strideForType(type) {\n    let t = type;\n    switch (type.typeId) {\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Decimal: return 4;\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Timestamp: return 2;\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Date: return 1 + t.unit;\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Interval: return 1 + t.unit;\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Int: return 1 + +(t.bitWidth > 32);\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.Time: return 1 + +(t.bitWidth > 32);\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeList: return t.listSize;\n        case _enum__WEBPACK_IMPORTED_MODULE_1__.Type.FixedSizeBinary: return t.byteWidth;\n        default: return 1;\n    }\n}\n\n//# sourceMappingURL=type.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/type.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/args.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/util/args.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   selectArgs: () => (/* binding */ selectArgs),\n/* harmony export */   selectChunkArgs: () => (/* binding */ selectChunkArgs),\n/* harmony export */   selectColumnArgs: () => (/* binding */ selectColumnArgs),\n/* harmony export */   selectColumnChildrenArgs: () => (/* binding */ selectColumnChildrenArgs),\n/* harmony export */   selectFieldArgs: () => (/* binding */ selectFieldArgs),\n/* harmony export */   selectVectorChildrenArgs: () => (/* binding */ selectVectorChildrenArgs)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../column */ \"../../node_modules/apache-arrow/column.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _vector_chunked__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../vector/chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\nconst isArray = Array.isArray;\n/** @ignore */\nconst selectArgs = (Ctor, vals) => _selectArgs(Ctor, vals, [], 0);\n/** @ignore */\nconst selectColumnArgs = (args) => {\n    const [fields, values] = _selectFieldArgs(args, [[], []]);\n    return values.map((x, i) => x instanceof _column__WEBPACK_IMPORTED_MODULE_2__.Column ? _column__WEBPACK_IMPORTED_MODULE_2__.Column.new(x.field.clone(fields[i]), x) :\n        x instanceof _vector__WEBPACK_IMPORTED_MODULE_3__.Vector ? _column__WEBPACK_IMPORTED_MODULE_2__.Column.new(fields[i], x) :\n            _column__WEBPACK_IMPORTED_MODULE_2__.Column.new(fields[i], []));\n};\n/** @ignore */\nconst selectFieldArgs = (args) => _selectFieldArgs(args, [[], []]);\n/** @ignore */\nconst selectChunkArgs = (Ctor, vals) => _selectChunkArgs(Ctor, vals, [], 0);\n/** @ignore */\nconst selectVectorChildrenArgs = (Ctor, vals) => _selectVectorChildrenArgs(Ctor, vals, [], 0);\n/** @ignore */\nconst selectColumnChildrenArgs = (Ctor, vals) => _selectColumnChildrenArgs(Ctor, vals, [], 0);\n/** @ignore */\nfunction _selectArgs(Ctor, vals, res, idx) {\n    let value, j = idx;\n    let i = -1, n = vals.length;\n    while (++i < n) {\n        if (isArray(value = vals[i])) {\n            j = _selectArgs(Ctor, value, res, j).length;\n        }\n        else if (value instanceof Ctor) {\n            res[j++] = value;\n        }\n    }\n    return res;\n}\n/** @ignore */\nfunction _selectChunkArgs(Ctor, vals, res, idx) {\n    let value, j = idx;\n    let i = -1, n = vals.length;\n    while (++i < n) {\n        if (isArray(value = vals[i])) {\n            j = _selectChunkArgs(Ctor, value, res, j).length;\n        }\n        else if (value instanceof _vector_chunked__WEBPACK_IMPORTED_MODULE_5__.Chunked) {\n            j = _selectChunkArgs(Ctor, value.chunks, res, j).length;\n        }\n        else if (value instanceof Ctor) {\n            res[j++] = value;\n        }\n    }\n    return res;\n}\n/** @ignore */\nfunction _selectVectorChildrenArgs(Ctor, vals, res, idx) {\n    let value, j = idx;\n    let i = -1, n = vals.length;\n    while (++i < n) {\n        if (isArray(value = vals[i])) {\n            j = _selectVectorChildrenArgs(Ctor, value, res, j).length;\n        }\n        else if (value instanceof Ctor) {\n            j = _selectArgs(_vector__WEBPACK_IMPORTED_MODULE_3__.Vector, value.schema.fields.map((_, i) => value.getChildAt(i)), res, j).length;\n        }\n        else if (value instanceof _vector__WEBPACK_IMPORTED_MODULE_3__.Vector) {\n            res[j++] = value;\n        }\n    }\n    return res;\n}\n/** @ignore */\nfunction _selectColumnChildrenArgs(Ctor, vals, res, idx) {\n    let value, j = idx;\n    let i = -1, n = vals.length;\n    while (++i < n) {\n        if (isArray(value = vals[i])) {\n            j = _selectColumnChildrenArgs(Ctor, value, res, j).length;\n        }\n        else if (value instanceof Ctor) {\n            j = _selectArgs(_column__WEBPACK_IMPORTED_MODULE_2__.Column, value.schema.fields.map((f, i) => _column__WEBPACK_IMPORTED_MODULE_2__.Column.new(f, value.getChildAt(i))), res, j).length;\n        }\n        else if (value instanceof _column__WEBPACK_IMPORTED_MODULE_2__.Column) {\n            res[j++] = value;\n        }\n    }\n    return res;\n}\n/** @ignore */\nconst toKeysAndValues = (xs, [k, v], i) => (xs[0][i] = k, xs[1][i] = v, xs);\n/** @ignore */\nfunction _selectFieldArgs(vals, ret) {\n    let keys, n;\n    switch (n = vals.length) {\n        case 0: return ret;\n        case 1:\n            keys = ret[0];\n            if (!(vals[0])) {\n                return ret;\n            }\n            if (isArray(vals[0])) {\n                return _selectFieldArgs(vals[0], ret);\n            }\n            if (!(vals[0] instanceof _data__WEBPACK_IMPORTED_MODULE_0__.Data || vals[0] instanceof _vector__WEBPACK_IMPORTED_MODULE_3__.Vector || vals[0] instanceof _type__WEBPACK_IMPORTED_MODULE_4__.DataType)) {\n                [keys, vals] = Object.entries(vals[0]).reduce(toKeysAndValues, ret);\n            }\n            break;\n        default:\n            !isArray(keys = vals[n - 1])\n                ? (vals = isArray(vals[0]) ? vals[0] : vals, keys = [])\n                : (vals = isArray(vals[0]) ? vals[0] : vals.slice(0, n - 1));\n    }\n    let fieldIndex = -1;\n    let valueIndex = -1;\n    let idx = -1, len = vals.length;\n    let field;\n    let val;\n    let [fields, values] = ret;\n    while (++idx < len) {\n        val = vals[idx];\n        if (val instanceof _column__WEBPACK_IMPORTED_MODULE_2__.Column && (values[++valueIndex] = val)) {\n            fields[++fieldIndex] = val.field.clone(keys[idx], val.type, true);\n        }\n        else {\n            ({ [idx]: field = idx } = keys);\n            if (val instanceof _type__WEBPACK_IMPORTED_MODULE_4__.DataType && (values[++valueIndex] = val)) {\n                fields[++fieldIndex] = _schema__WEBPACK_IMPORTED_MODULE_1__.Field.new(field, val, true);\n            }\n            else if (val && val.type && (values[++valueIndex] = val)) {\n                val instanceof _data__WEBPACK_IMPORTED_MODULE_0__.Data && (values[valueIndex] = val = _vector__WEBPACK_IMPORTED_MODULE_3__.Vector.new(val));\n                fields[++fieldIndex] = _schema__WEBPACK_IMPORTED_MODULE_1__.Field.new(field, val.type, true);\n            }\n        }\n    }\n    return ret;\n}\n\n//# sourceMappingURL=args.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/args.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/bit.mjs":
/*!****************************************************!*\
  !*** ../../node_modules/apache-arrow/util/bit.mjs ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   getBit: () => (/* binding */ getBit),\n/* harmony export */   getBool: () => (/* binding */ getBool),\n/* harmony export */   iterateBits: () => (/* binding */ iterateBits),\n/* harmony export */   packBools: () => (/* binding */ packBools),\n/* harmony export */   popcnt_array: () => (/* binding */ popcnt_array),\n/* harmony export */   popcnt_bit_range: () => (/* binding */ popcnt_bit_range),\n/* harmony export */   popcnt_uint32: () => (/* binding */ popcnt_uint32),\n/* harmony export */   setBool: () => (/* binding */ setBool),\n/* harmony export */   truncateBitmap: () => (/* binding */ truncateBitmap)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/** @ignore */\nfunction getBool(_data, _index, byte, bit) {\n    return (byte & 1 << bit) !== 0;\n}\n/** @ignore */\nfunction getBit(_data, _index, byte, bit) {\n    return (byte & 1 << bit) >> bit;\n}\n/** @ignore */\nfunction setBool(bytes, index, value) {\n    return value ?\n        !!(bytes[index >> 3] |= (1 << (index % 8))) || true :\n        !(bytes[index >> 3] &= ~(1 << (index % 8))) && false;\n}\n/** @ignore */\nfunction truncateBitmap(offset, length, bitmap) {\n    const alignedSize = (bitmap.byteLength + 7) & ~7;\n    if (offset > 0 || bitmap.byteLength < alignedSize) {\n        const bytes = new Uint8Array(alignedSize);\n        // If the offset is a multiple of 8 bits, it's safe to slice the bitmap\n        bytes.set(offset % 8 === 0 ? bitmap.subarray(offset >> 3) :\n            // Otherwise iterate each bit from the offset and return a new one\n            packBools(iterateBits(bitmap, offset, length, null, getBool)).subarray(0, alignedSize));\n        return bytes;\n    }\n    return bitmap;\n}\n/** @ignore */\nfunction packBools(values) {\n    let xs = [];\n    let i = 0, bit = 0, byte = 0;\n    for (const value of values) {\n        value && (byte |= 1 << bit);\n        if (++bit === 8) {\n            xs[i++] = byte;\n            byte = bit = 0;\n        }\n    }\n    if (i === 0 || bit > 0) {\n        xs[i++] = byte;\n    }\n    let b = new Uint8Array((xs.length + 7) & ~7);\n    b.set(xs);\n    return b;\n}\n/** @ignore */\nfunction* iterateBits(bytes, begin, length, context, get) {\n    let bit = begin % 8;\n    let byteIndex = begin >> 3;\n    let index = 0, remaining = length;\n    for (; remaining > 0; bit = 0) {\n        let byte = bytes[byteIndex++];\n        do {\n            yield get(context, index++, byte, bit);\n        } while (--remaining > 0 && ++bit < 8);\n    }\n}\n/**\n * Compute the population count (the number of bits set to 1) for a range of bits in a Uint8Array.\n * @param vector The Uint8Array of bits for which to compute the population count.\n * @param lhs The range's left-hand side (or start) bit\n * @param rhs The range's right-hand side (or end) bit\n */\n/** @ignore */\nfunction popcnt_bit_range(data, lhs, rhs) {\n    if (rhs - lhs <= 0) {\n        return 0;\n    }\n    // If the bit range is less than one byte, sum the 1 bits in the bit range\n    if (rhs - lhs < 8) {\n        let sum = 0;\n        for (const bit of iterateBits(data, lhs, rhs - lhs, data, getBit)) {\n            sum += bit;\n        }\n        return sum;\n    }\n    // Get the next lowest multiple of 8 from the right hand side\n    const rhsInside = rhs >> 3 << 3;\n    // Get the next highest multiple of 8 from the left hand side\n    const lhsInside = lhs + (lhs % 8 === 0 ? 0 : 8 - lhs % 8);\n    return (\n    // Get the popcnt of bits between the left hand side, and the next highest multiple of 8\n    popcnt_bit_range(data, lhs, lhsInside) +\n        // Get the popcnt of bits between the right hand side, and the next lowest multiple of 8\n        popcnt_bit_range(data, rhsInside, rhs) +\n        // Get the popcnt of all bits between the left and right hand sides' multiples of 8\n        popcnt_array(data, lhsInside >> 3, (rhsInside - lhsInside) >> 3));\n}\n/** @ignore */\nfunction popcnt_array(arr, byteOffset, byteLength) {\n    let cnt = 0, pos = byteOffset | 0;\n    const view = new DataView(arr.buffer, arr.byteOffset, arr.byteLength);\n    const len = byteLength === void 0 ? arr.byteLength : pos + byteLength;\n    while (len - pos >= 4) {\n        cnt += popcnt_uint32(view.getUint32(pos));\n        pos += 4;\n    }\n    while (len - pos >= 2) {\n        cnt += popcnt_uint32(view.getUint16(pos));\n        pos += 2;\n    }\n    while (len - pos >= 1) {\n        cnt += popcnt_uint32(view.getUint8(pos));\n        pos += 1;\n    }\n    return cnt;\n}\n/** @ignore */\nfunction popcnt_uint32(uint32) {\n    let i = uint32 | 0;\n    i = i - ((i >>> 1) & 0x55555555);\n    i = (i & 0x33333333) + ((i >>> 2) & 0x33333333);\n    return (((i + (i >>> 4)) & 0x0F0F0F0F) * 0x01010101) >>> 24;\n}\n\n//# sourceMappingURL=bit.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/bit.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/bn.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/util/bn.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BN: () => (/* binding */ BN),\n/* harmony export */   bignumToBigInt: () => (/* binding */ bignumToBigInt),\n/* harmony export */   bignumToString: () => (/* binding */ bignumToString),\n/* harmony export */   isArrowBigNumSymbol: () => (/* binding */ isArrowBigNumSymbol)\n/* harmony export */ });\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _compat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nconst isArrowBigNumSymbol = Symbol.for('isArrowBigNum');\n/** @ignore */\nfunction BigNum(x, ...xs) {\n    if (xs.length === 0) {\n        return Object.setPrototypeOf((0,_buffer__WEBPACK_IMPORTED_MODULE_0__.toArrayBufferView)(this['TypedArray'], x), this.constructor.prototype);\n    }\n    return Object.setPrototypeOf(new this['TypedArray'](x, ...xs), this.constructor.prototype);\n}\nBigNum.prototype[isArrowBigNumSymbol] = true;\nBigNum.prototype.toJSON = function () { return `\"${bignumToString(this)}\"`; };\nBigNum.prototype.valueOf = function () { return bignumToNumber(this); };\nBigNum.prototype.toString = function () { return bignumToString(this); };\nBigNum.prototype[Symbol.toPrimitive] = function (hint = 'default') {\n    switch (hint) {\n        case 'number': return bignumToNumber(this);\n        case 'string': return bignumToString(this);\n        case 'default': return bignumToBigInt(this);\n    }\n    // @ts-ignore\n    return bignumToString(this);\n};\n/** @ignore */\nfunction SignedBigNum(...args) { return BigNum.apply(this, args); }\n/** @ignore */\nfunction UnsignedBigNum(...args) { return BigNum.apply(this, args); }\n/** @ignore */\nfunction DecimalBigNum(...args) { return BigNum.apply(this, args); }\nObject.setPrototypeOf(SignedBigNum.prototype, Object.create(Int32Array.prototype));\nObject.setPrototypeOf(UnsignedBigNum.prototype, Object.create(Uint32Array.prototype));\nObject.setPrototypeOf(DecimalBigNum.prototype, Object.create(Uint32Array.prototype));\nObject.assign(SignedBigNum.prototype, BigNum.prototype, { 'constructor': SignedBigNum, 'signed': true, 'TypedArray': Int32Array, 'BigIntArray': _compat__WEBPACK_IMPORTED_MODULE_1__.BigInt64Array });\nObject.assign(UnsignedBigNum.prototype, BigNum.prototype, { 'constructor': UnsignedBigNum, 'signed': false, 'TypedArray': Uint32Array, 'BigIntArray': _compat__WEBPACK_IMPORTED_MODULE_1__.BigUint64Array });\nObject.assign(DecimalBigNum.prototype, BigNum.prototype, { 'constructor': DecimalBigNum, 'signed': true, 'TypedArray': Uint32Array, 'BigIntArray': _compat__WEBPACK_IMPORTED_MODULE_1__.BigUint64Array });\n/** @ignore */\nfunction bignumToNumber(bn) {\n    let { buffer, byteOffset, length, 'signed': signed } = bn;\n    let words = new Int32Array(buffer, byteOffset, length);\n    let number = 0, i = 0, n = words.length, hi, lo;\n    while (i < n) {\n        lo = words[i++];\n        hi = words[i++];\n        signed || (hi = hi >>> 0);\n        number += (lo >>> 0) + (hi * (i ** 32));\n    }\n    return number;\n}\n/** @ignore */\nlet bignumToString;\n/** @ignore */\nlet bignumToBigInt;\nif (!_compat__WEBPACK_IMPORTED_MODULE_1__.BigIntAvailable) {\n    bignumToString = decimalToString;\n    bignumToBigInt = bignumToString;\n}\nelse {\n    bignumToBigInt = ((a) => a.byteLength === 8 ? new a['BigIntArray'](a.buffer, a.byteOffset, 1)[0] : decimalToString(a));\n    bignumToString = ((a) => a.byteLength === 8 ? `${new a['BigIntArray'](a.buffer, a.byteOffset, 1)[0]}` : decimalToString(a));\n}\n/** @ignore */\nfunction decimalToString(a) {\n    let digits = '';\n    let base64 = new Uint32Array(2);\n    let base32 = new Uint16Array(a.buffer, a.byteOffset, a.byteLength / 2);\n    let checks = new Uint32Array((base32 = new Uint16Array(base32).reverse()).buffer);\n    let i = -1, n = base32.length - 1;\n    do {\n        for (base64[0] = base32[i = 0]; i < n;) {\n            base32[i++] = base64[1] = base64[0] / 10;\n            base64[0] = ((base64[0] - base64[1] * 10) << 16) + base32[i];\n        }\n        base32[i] = base64[1] = base64[0] / 10;\n        base64[0] = base64[0] - base64[1] * 10;\n        digits = `${base64[0]}${digits}`;\n    } while (checks[0] || checks[1] || checks[2] || checks[3]);\n    return digits ? digits : `0`;\n}\n/** @ignore */\nclass BN {\n    /** @nocollapse */\n    static new(num, isSigned) {\n        switch (isSigned) {\n            case true: return new SignedBigNum(num);\n            case false: return new UnsignedBigNum(num);\n        }\n        switch (num.constructor) {\n            case Int8Array:\n            case Int16Array:\n            case Int32Array:\n            case _compat__WEBPACK_IMPORTED_MODULE_1__.BigInt64Array:\n                return new SignedBigNum(num);\n        }\n        if (num.byteLength === 16) {\n            return new DecimalBigNum(num);\n        }\n        return new UnsignedBigNum(num);\n    }\n    /** @nocollapse */\n    static signed(num) {\n        return new SignedBigNum(num);\n    }\n    /** @nocollapse */\n    static unsigned(num) {\n        return new UnsignedBigNum(num);\n    }\n    /** @nocollapse */\n    static decimal(num) {\n        return new DecimalBigNum(num);\n    }\n    constructor(num, isSigned) {\n        return BN.new(num, isSigned);\n    }\n}\n\n//# sourceMappingURL=bn.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/bn.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/buffer.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/util/buffer.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   compareArrayLike: () => (/* binding */ compareArrayLike),\n/* harmony export */   joinUint8Arrays: () => (/* binding */ joinUint8Arrays),\n/* harmony export */   memcpy: () => (/* binding */ memcpy),\n/* harmony export */   rebaseValueOffsets: () => (/* binding */ rebaseValueOffsets),\n/* harmony export */   toArrayBufferView: () => (/* binding */ toArrayBufferView),\n/* harmony export */   toArrayBufferViewAsyncIterator: () => (/* binding */ toArrayBufferViewAsyncIterator),\n/* harmony export */   toArrayBufferViewIterator: () => (/* binding */ toArrayBufferViewIterator),\n/* harmony export */   toBigInt64Array: () => (/* binding */ toBigInt64Array),\n/* harmony export */   toBigUint64Array: () => (/* binding */ toBigUint64Array),\n/* harmony export */   toFloat32Array: () => (/* binding */ toFloat32Array),\n/* harmony export */   toFloat32ArrayAsyncIterator: () => (/* binding */ toFloat32ArrayAsyncIterator),\n/* harmony export */   toFloat32ArrayIterator: () => (/* binding */ toFloat32ArrayIterator),\n/* harmony export */   toFloat64Array: () => (/* binding */ toFloat64Array),\n/* harmony export */   toFloat64ArrayAsyncIterator: () => (/* binding */ toFloat64ArrayAsyncIterator),\n/* harmony export */   toFloat64ArrayIterator: () => (/* binding */ toFloat64ArrayIterator),\n/* harmony export */   toInt16Array: () => (/* binding */ toInt16Array),\n/* harmony export */   toInt16ArrayAsyncIterator: () => (/* binding */ toInt16ArrayAsyncIterator),\n/* harmony export */   toInt16ArrayIterator: () => (/* binding */ toInt16ArrayIterator),\n/* harmony export */   toInt32Array: () => (/* binding */ toInt32Array),\n/* harmony export */   toInt32ArrayAsyncIterator: () => (/* binding */ toInt32ArrayAsyncIterator),\n/* harmony export */   toInt32ArrayIterator: () => (/* binding */ toInt32ArrayIterator),\n/* harmony export */   toInt8Array: () => (/* binding */ toInt8Array),\n/* harmony export */   toInt8ArrayAsyncIterator: () => (/* binding */ toInt8ArrayAsyncIterator),\n/* harmony export */   toInt8ArrayIterator: () => (/* binding */ toInt8ArrayIterator),\n/* harmony export */   toUint16Array: () => (/* binding */ toUint16Array),\n/* harmony export */   toUint16ArrayAsyncIterator: () => (/* binding */ toUint16ArrayAsyncIterator),\n/* harmony export */   toUint16ArrayIterator: () => (/* binding */ toUint16ArrayIterator),\n/* harmony export */   toUint32Array: () => (/* binding */ toUint32Array),\n/* harmony export */   toUint32ArrayAsyncIterator: () => (/* binding */ toUint32ArrayAsyncIterator),\n/* harmony export */   toUint32ArrayIterator: () => (/* binding */ toUint32ArrayIterator),\n/* harmony export */   toUint8Array: () => (/* binding */ toUint8Array),\n/* harmony export */   toUint8ArrayAsyncIterator: () => (/* binding */ toUint8ArrayAsyncIterator),\n/* harmony export */   toUint8ArrayIterator: () => (/* binding */ toUint8ArrayIterator),\n/* harmony export */   toUint8ClampedArray: () => (/* binding */ toUint8ClampedArray),\n/* harmony export */   toUint8ClampedArrayAsyncIterator: () => (/* binding */ toUint8ClampedArrayAsyncIterator),\n/* harmony export */   toUint8ClampedArrayIterator: () => (/* binding */ toUint8ClampedArrayIterator)\n/* harmony export */ });\n/* harmony import */ var flatbuffers__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! flatbuffers */ \"../../node_modules/flatbuffers/js/flatbuffers.mjs\");\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _compat__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\nvar ByteBuffer = flatbuffers__WEBPACK_IMPORTED_MODULE_0__.flatbuffers.ByteBuffer;\n\n/** @ignore */\nconst SharedArrayBuf = (typeof SharedArrayBuffer !== 'undefined' ? SharedArrayBuffer : ArrayBuffer);\n/** @ignore */\nfunction collapseContiguousByteRanges(chunks) {\n    let result = chunks[0] ? [chunks[0]] : [];\n    let xOffset, yOffset, xLen, yLen;\n    for (let x, y, i = 0, j = 0, n = chunks.length; ++i < n;) {\n        x = result[j];\n        y = chunks[i];\n        // continue if x and y don't share the same underlying ArrayBuffer, or if x isn't before y\n        if (!x || !y || x.buffer !== y.buffer || y.byteOffset < x.byteOffset) {\n            y && (result[++j] = y);\n            continue;\n        }\n        ({ byteOffset: xOffset, byteLength: xLen } = x);\n        ({ byteOffset: yOffset, byteLength: yLen } = y);\n        // continue if the byte ranges of x and y aren't contiguous\n        if ((xOffset + xLen) < yOffset || (yOffset + yLen) < xOffset) {\n            y && (result[++j] = y);\n            continue;\n        }\n        result[j] = new Uint8Array(x.buffer, xOffset, yOffset - xOffset + yLen);\n    }\n    return result;\n}\n/** @ignore */\nfunction memcpy(target, source, targetByteOffset = 0, sourceByteLength = source.byteLength) {\n    const targetByteLength = target.byteLength;\n    const dst = new Uint8Array(target.buffer, target.byteOffset, targetByteLength);\n    const src = new Uint8Array(source.buffer, source.byteOffset, Math.min(sourceByteLength, targetByteLength));\n    dst.set(src, targetByteOffset);\n    return target;\n}\n/** @ignore */\nfunction joinUint8Arrays(chunks, size) {\n    // collapse chunks that share the same underlying ArrayBuffer and whose byte ranges overlap,\n    // to avoid unnecessarily copying the bytes to do this buffer join. This is a common case during\n    // streaming, where we may be reading partial byte ranges out of the same underlying ArrayBuffer\n    let result = collapseContiguousByteRanges(chunks);\n    let byteLength = result.reduce((x, b) => x + b.byteLength, 0);\n    let source, sliced, buffer;\n    let offset = 0, index = -1, length = Math.min(size || Infinity, byteLength);\n    for (let n = result.length; ++index < n;) {\n        source = result[index];\n        sliced = source.subarray(0, Math.min(source.length, length - offset));\n        if (length <= (offset + sliced.length)) {\n            if (sliced.length < source.length) {\n                result[index] = source.subarray(sliced.length);\n            }\n            else if (sliced.length === source.length) {\n                index++;\n            }\n            buffer ? memcpy(buffer, sliced, offset) : (buffer = sliced);\n            break;\n        }\n        memcpy(buffer || (buffer = new Uint8Array(length)), sliced, offset);\n        offset += sliced.length;\n    }\n    return [buffer || new Uint8Array(0), result.slice(index), byteLength - (buffer ? buffer.byteLength : 0)];\n}\nfunction toArrayBufferView(ArrayBufferViewCtor, input) {\n    let value = (0,_compat__WEBPACK_IMPORTED_MODULE_2__.isIteratorResult)(input) ? input.value : input;\n    if (value instanceof ArrayBufferViewCtor) {\n        if (ArrayBufferViewCtor === Uint8Array) {\n            // Node's `Buffer` class passes the `instanceof Uint8Array` check, but we need\n            // a real Uint8Array, since Buffer#slice isn't the same as Uint8Array#slice :/\n            return new ArrayBufferViewCtor(value.buffer, value.byteOffset, value.byteLength);\n        }\n        return value;\n    }\n    if (!value) {\n        return new ArrayBufferViewCtor(0);\n    }\n    if (typeof value === 'string') {\n        value = (0,_util_utf8__WEBPACK_IMPORTED_MODULE_1__.encodeUtf8)(value);\n    }\n    if (value instanceof ArrayBuffer) {\n        return new ArrayBufferViewCtor(value);\n    }\n    if (value instanceof SharedArrayBuf) {\n        return new ArrayBufferViewCtor(value);\n    }\n    if (value instanceof ByteBuffer) {\n        return toArrayBufferView(ArrayBufferViewCtor, value.bytes());\n    }\n    return !ArrayBuffer.isView(value) ? ArrayBufferViewCtor.from(value) : value.byteLength <= 0 ? new ArrayBufferViewCtor(0)\n        : new ArrayBufferViewCtor(value.buffer, value.byteOffset, value.byteLength / ArrayBufferViewCtor.BYTES_PER_ELEMENT);\n}\n/** @ignore */ const toInt8Array = (input) => toArrayBufferView(Int8Array, input);\n/** @ignore */ const toInt16Array = (input) => toArrayBufferView(Int16Array, input);\n/** @ignore */ const toInt32Array = (input) => toArrayBufferView(Int32Array, input);\n/** @ignore */ const toBigInt64Array = (input) => toArrayBufferView(_compat__WEBPACK_IMPORTED_MODULE_2__.BigInt64Array, input);\n/** @ignore */ const toUint8Array = (input) => toArrayBufferView(Uint8Array, input);\n/** @ignore */ const toUint16Array = (input) => toArrayBufferView(Uint16Array, input);\n/** @ignore */ const toUint32Array = (input) => toArrayBufferView(Uint32Array, input);\n/** @ignore */ const toBigUint64Array = (input) => toArrayBufferView(_compat__WEBPACK_IMPORTED_MODULE_2__.BigUint64Array, input);\n/** @ignore */ const toFloat32Array = (input) => toArrayBufferView(Float32Array, input);\n/** @ignore */ const toFloat64Array = (input) => toArrayBufferView(Float64Array, input);\n/** @ignore */ const toUint8ClampedArray = (input) => toArrayBufferView(Uint8ClampedArray, input);\n/** @ignore */\nconst pump = (iterator) => { iterator.next(); return iterator; };\n/** @ignore */\nfunction* toArrayBufferViewIterator(ArrayCtor, source) {\n    const wrap = function* (x) { yield x; };\n    const buffers = (typeof source === 'string') ? wrap(source)\n        : (ArrayBuffer.isView(source)) ? wrap(source)\n            : (source instanceof ArrayBuffer) ? wrap(source)\n                : (source instanceof SharedArrayBuf) ? wrap(source)\n                    : !(0,_compat__WEBPACK_IMPORTED_MODULE_2__.isIterable)(source) ? wrap(source) : source;\n    yield* pump((function* (it) {\n        let r = null;\n        do {\n            r = it.next(yield toArrayBufferView(ArrayCtor, r));\n        } while (!r.done);\n    })(buffers[Symbol.iterator]()));\n    return new ArrayCtor();\n}\n/** @ignore */ const toInt8ArrayIterator = (input) => toArrayBufferViewIterator(Int8Array, input);\n/** @ignore */ const toInt16ArrayIterator = (input) => toArrayBufferViewIterator(Int16Array, input);\n/** @ignore */ const toInt32ArrayIterator = (input) => toArrayBufferViewIterator(Int32Array, input);\n/** @ignore */ const toUint8ArrayIterator = (input) => toArrayBufferViewIterator(Uint8Array, input);\n/** @ignore */ const toUint16ArrayIterator = (input) => toArrayBufferViewIterator(Uint16Array, input);\n/** @ignore */ const toUint32ArrayIterator = (input) => toArrayBufferViewIterator(Uint32Array, input);\n/** @ignore */ const toFloat32ArrayIterator = (input) => toArrayBufferViewIterator(Float32Array, input);\n/** @ignore */ const toFloat64ArrayIterator = (input) => toArrayBufferViewIterator(Float64Array, input);\n/** @ignore */ const toUint8ClampedArrayIterator = (input) => toArrayBufferViewIterator(Uint8ClampedArray, input);\n/** @ignore */\nasync function* toArrayBufferViewAsyncIterator(ArrayCtor, source) {\n    // if a Promise, unwrap the Promise and iterate the resolved value\n    if ((0,_compat__WEBPACK_IMPORTED_MODULE_2__.isPromise)(source)) {\n        return yield* toArrayBufferViewAsyncIterator(ArrayCtor, await source);\n    }\n    const wrap = async function* (x) { yield await x; };\n    const emit = async function* (source) {\n        yield* pump((function* (it) {\n            let r = null;\n            do {\n                r = it.next(yield r && r.value);\n            } while (!r.done);\n        })(source[Symbol.iterator]()));\n    };\n    const buffers = (typeof source === 'string') ? wrap(source) // if string, wrap in an AsyncIterableIterator\n        : (ArrayBuffer.isView(source)) ? wrap(source) // if TypedArray, wrap in an AsyncIterableIterator\n            : (source instanceof ArrayBuffer) ? wrap(source) // if ArrayBuffer, wrap in an AsyncIterableIterator\n                : (source instanceof SharedArrayBuf) ? wrap(source) // if SharedArrayBuffer, wrap in an AsyncIterableIterator\n                    : (0,_compat__WEBPACK_IMPORTED_MODULE_2__.isIterable)(source) ? emit(source) // If Iterable, wrap in an AsyncIterableIterator and compose the `next` values\n                        : !(0,_compat__WEBPACK_IMPORTED_MODULE_2__.isAsyncIterable)(source) ? wrap(source) // If not an AsyncIterable, treat as a sentinel and wrap in an AsyncIterableIterator\n                            : source; // otherwise if AsyncIterable, use it\n    yield* pump((async function* (it) {\n        let r = null;\n        do {\n            r = await it.next(yield toArrayBufferView(ArrayCtor, r));\n        } while (!r.done);\n    })(buffers[Symbol.asyncIterator]()));\n    return new ArrayCtor();\n}\n/** @ignore */ const toInt8ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Int8Array, input);\n/** @ignore */ const toInt16ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Int16Array, input);\n/** @ignore */ const toInt32ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Int32Array, input);\n/** @ignore */ const toUint8ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Uint8Array, input);\n/** @ignore */ const toUint16ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Uint16Array, input);\n/** @ignore */ const toUint32ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Uint32Array, input);\n/** @ignore */ const toFloat32ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Float32Array, input);\n/** @ignore */ const toFloat64ArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Float64Array, input);\n/** @ignore */ const toUint8ClampedArrayAsyncIterator = (input) => toArrayBufferViewAsyncIterator(Uint8ClampedArray, input);\n/** @ignore */\nfunction rebaseValueOffsets(offset, length, valueOffsets) {\n    // If we have a non-zero offset, create a new offsets array with the values\n    // shifted by the start offset, such that the new start offset is 0\n    if (offset !== 0) {\n        valueOffsets = valueOffsets.slice(0, length + 1);\n        for (let i = -1; ++i <= length;) {\n            valueOffsets[i] += offset;\n        }\n    }\n    return valueOffsets;\n}\n/** @ignore */\nfunction compareArrayLike(a, b) {\n    let i = 0, n = a.length;\n    if (n !== b.length) {\n        return false;\n    }\n    if (n > 0) {\n        do {\n            if (a[i] !== b[i]) {\n                return false;\n            }\n        } while (++i < n);\n    }\n    return true;\n}\n\n//# sourceMappingURL=buffer.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/buffer.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/compat.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/util/compat.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BigInt: () => (/* binding */ BigIntCtor),\n/* harmony export */   BigInt64Array: () => (/* binding */ BigInt64ArrayCtor),\n/* harmony export */   BigInt64ArrayAvailable: () => (/* binding */ BigInt64ArrayAvailable),\n/* harmony export */   BigIntAvailable: () => (/* binding */ BigIntAvailable),\n/* harmony export */   BigUint64Array: () => (/* binding */ BigUint64ArrayCtor),\n/* harmony export */   BigUint64ArrayAvailable: () => (/* binding */ BigUint64ArrayAvailable),\n/* harmony export */   isArrayLike: () => (/* binding */ isArrayLike),\n/* harmony export */   isArrowJSON: () => (/* binding */ isArrowJSON),\n/* harmony export */   isAsyncIterable: () => (/* binding */ isAsyncIterable),\n/* harmony export */   isFSReadStream: () => (/* binding */ isFSReadStream),\n/* harmony export */   isFetchResponse: () => (/* binding */ isFetchResponse),\n/* harmony export */   isFileHandle: () => (/* binding */ isFileHandle),\n/* harmony export */   isIterable: () => (/* binding */ isIterable),\n/* harmony export */   isIteratorResult: () => (/* binding */ isIteratorResult),\n/* harmony export */   isObject: () => (/* binding */ isObject),\n/* harmony export */   isObservable: () => (/* binding */ isObservable),\n/* harmony export */   isPromise: () => (/* binding */ isPromise),\n/* harmony export */   isReadableDOMStream: () => (/* binding */ isReadableDOMStream),\n/* harmony export */   isReadableNodeStream: () => (/* binding */ isReadableNodeStream),\n/* harmony export */   isUnderlyingSink: () => (/* binding */ isUnderlyingSink),\n/* harmony export */   isWritableDOMStream: () => (/* binding */ isWritableDOMStream),\n/* harmony export */   isWritableNodeStream: () => (/* binding */ isWritableNodeStream)\n/* harmony export */ });\n/* harmony import */ var _io_interfaces__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../io/interfaces */ \"../../node_modules/apache-arrow/io/interfaces.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nconst [BigIntCtor, BigIntAvailable] = (() => {\n    const BigIntUnavailableError = () => { throw new Error('BigInt is not available in this environment'); };\n    function BigIntUnavailable() { throw BigIntUnavailableError(); }\n    BigIntUnavailable.asIntN = () => { throw BigIntUnavailableError(); };\n    BigIntUnavailable.asUintN = () => { throw BigIntUnavailableError(); };\n    return typeof BigInt !== 'undefined' ? [BigInt, true] : [BigIntUnavailable, false];\n})();\n/** @ignore */\nconst [BigInt64ArrayCtor, BigInt64ArrayAvailable] = (() => {\n    const BigInt64ArrayUnavailableError = () => { throw new Error('BigInt64Array is not available in this environment'); };\n    class BigInt64ArrayUnavailable {\n        static get BYTES_PER_ELEMENT() { return 8; }\n        static of() { throw BigInt64ArrayUnavailableError(); }\n        static from() { throw BigInt64ArrayUnavailableError(); }\n        constructor() { throw BigInt64ArrayUnavailableError(); }\n    }\n    return typeof BigInt64Array !== 'undefined' ? [BigInt64Array, true] : [BigInt64ArrayUnavailable, false];\n})();\n/** @ignore */\nconst [BigUint64ArrayCtor, BigUint64ArrayAvailable] = (() => {\n    const BigUint64ArrayUnavailableError = () => { throw new Error('BigUint64Array is not available in this environment'); };\n    class BigUint64ArrayUnavailable {\n        static get BYTES_PER_ELEMENT() { return 8; }\n        static of() { throw BigUint64ArrayUnavailableError(); }\n        static from() { throw BigUint64ArrayUnavailableError(); }\n        constructor() { throw BigUint64ArrayUnavailableError(); }\n    }\n    return typeof BigUint64Array !== 'undefined' ? [BigUint64Array, true] : [BigUint64ArrayUnavailable, false];\n})();\n\n\n\n/** @ignore */ const isNumber = (x) => typeof x === 'number';\n/** @ignore */ const isBoolean = (x) => typeof x === 'boolean';\n/** @ignore */ const isFunction = (x) => typeof x === 'function';\n/** @ignore */\nconst isObject = (x) => x != null && Object(x) === x;\n/** @ignore */\nconst isPromise = (x) => {\n    return isObject(x) && isFunction(x.then);\n};\n/** @ignore */\nconst isObservable = (x) => {\n    return isObject(x) && isFunction(x.subscribe);\n};\n/** @ignore */\nconst isIterable = (x) => {\n    return isObject(x) && isFunction(x[Symbol.iterator]);\n};\n/** @ignore */\nconst isAsyncIterable = (x) => {\n    return isObject(x) && isFunction(x[Symbol.asyncIterator]);\n};\n/** @ignore */\nconst isArrowJSON = (x) => {\n    return isObject(x) && isObject(x['schema']);\n};\n/** @ignore */\nconst isArrayLike = (x) => {\n    return isObject(x) && isNumber(x['length']);\n};\n/** @ignore */\nconst isIteratorResult = (x) => {\n    return isObject(x) && ('done' in x) && ('value' in x);\n};\n/** @ignore */\nconst isUnderlyingSink = (x) => {\n    return isObject(x) &&\n        isFunction(x['abort']) &&\n        isFunction(x['close']) &&\n        isFunction(x['start']) &&\n        isFunction(x['write']);\n};\n/** @ignore */\nconst isFileHandle = (x) => {\n    return isObject(x) && isFunction(x['stat']) && isNumber(x['fd']);\n};\n/** @ignore */\nconst isFSReadStream = (x) => {\n    return isReadableNodeStream(x) && isNumber(x['bytesRead']);\n};\n/** @ignore */\nconst isFetchResponse = (x) => {\n    return isObject(x) && isReadableDOMStream(x['body']);\n};\n/** @ignore */\nconst isWritableDOMStream = (x) => {\n    return isObject(x) &&\n        isFunction(x['abort']) &&\n        isFunction(x['getWriter']) &&\n        !(x instanceof _io_interfaces__WEBPACK_IMPORTED_MODULE_0__.ReadableInterop);\n};\n/** @ignore */\nconst isReadableDOMStream = (x) => {\n    return isObject(x) &&\n        isFunction(x['cancel']) &&\n        isFunction(x['getReader']) &&\n        !(x instanceof _io_interfaces__WEBPACK_IMPORTED_MODULE_0__.ReadableInterop);\n};\n/** @ignore */\nconst isWritableNodeStream = (x) => {\n    return isObject(x) &&\n        isFunction(x['end']) &&\n        isFunction(x['write']) &&\n        isBoolean(x['writable']) &&\n        !(x instanceof _io_interfaces__WEBPACK_IMPORTED_MODULE_0__.ReadableInterop);\n};\n/** @ignore */\nconst isReadableNodeStream = (x) => {\n    return isObject(x) &&\n        isFunction(x['read']) &&\n        isFunction(x['pipe']) &&\n        isBoolean(x['readable']) &&\n        !(x instanceof _io_interfaces__WEBPACK_IMPORTED_MODULE_0__.ReadableInterop);\n};\n\n//# sourceMappingURL=compat.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/compat.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/fn.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/util/fn.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   partial0: () => (/* binding */ partial0),\n/* harmony export */   partial1: () => (/* binding */ partial1),\n/* harmony export */   partial2: () => (/* binding */ partial2)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/** @ignore */\nfunction partial0(visit) {\n    return function () { return visit(this); };\n}\n/** @ignore */\nfunction partial1(visit) {\n    return function (a) { return visit(this, a); };\n}\n/** @ignore */\nfunction partial2(visit) {\n    return function (a, b) { return visit(this, a, b); };\n}\n\n//# sourceMappingURL=fn.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/fn.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/int.mjs":
/*!****************************************************!*\
  !*** ../../node_modules/apache-arrow/util/int.mjs ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BaseInt64: () => (/* binding */ BaseInt64),\n/* harmony export */   Int128: () => (/* binding */ Int128),\n/* harmony export */   Int64: () => (/* binding */ Int64),\n/* harmony export */   Uint64: () => (/* binding */ Uint64)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/** @ignore */\nconst carryBit16 = 1 << 16;\n/** @ignore */\nfunction intAsHex(value) {\n    if (value < 0) {\n        value = 0xFFFFFFFF + value + 1;\n    }\n    return `0x${value.toString(16)}`;\n}\n/** @ignore */\nconst kInt32DecimalDigits = 8;\n/** @ignore */\nconst kPowersOfTen = [1,\n    10,\n    100,\n    1000,\n    10000,\n    100000,\n    1000000,\n    10000000,\n    100000000];\n/** @ignore */\nclass BaseInt64 {\n    constructor(buffer) {\n        this.buffer = buffer;\n    }\n    high() { return this.buffer[1]; }\n    low() { return this.buffer[0]; }\n    _times(other) {\n        // Break the left and right numbers into 16 bit chunks\n        // so that we can multiply them without overflow.\n        const L = new Uint32Array([\n            this.buffer[1] >>> 16,\n            this.buffer[1] & 0xFFFF,\n            this.buffer[0] >>> 16,\n            this.buffer[0] & 0xFFFF\n        ]);\n        const R = new Uint32Array([\n            other.buffer[1] >>> 16,\n            other.buffer[1] & 0xFFFF,\n            other.buffer[0] >>> 16,\n            other.buffer[0] & 0xFFFF\n        ]);\n        let product = L[3] * R[3];\n        this.buffer[0] = product & 0xFFFF;\n        let sum = product >>> 16;\n        product = L[2] * R[3];\n        sum += product;\n        product = (L[3] * R[2]) >>> 0;\n        sum += product;\n        this.buffer[0] += sum << 16;\n        this.buffer[1] = (sum >>> 0 < product ? carryBit16 : 0);\n        this.buffer[1] += sum >>> 16;\n        this.buffer[1] += L[1] * R[3] + L[2] * R[2] + L[3] * R[1];\n        this.buffer[1] += (L[0] * R[3] + L[1] * R[2] + L[2] * R[1] + L[3] * R[0]) << 16;\n        return this;\n    }\n    _plus(other) {\n        const sum = (this.buffer[0] + other.buffer[0]) >>> 0;\n        this.buffer[1] += other.buffer[1];\n        if (sum < (this.buffer[0] >>> 0)) {\n            ++this.buffer[1];\n        }\n        this.buffer[0] = sum;\n    }\n    lessThan(other) {\n        return this.buffer[1] < other.buffer[1] ||\n            (this.buffer[1] === other.buffer[1] && this.buffer[0] < other.buffer[0]);\n    }\n    equals(other) {\n        return this.buffer[1] === other.buffer[1] && this.buffer[0] == other.buffer[0];\n    }\n    greaterThan(other) {\n        return other.lessThan(this);\n    }\n    hex() {\n        return `${intAsHex(this.buffer[1])} ${intAsHex(this.buffer[0])}`;\n    }\n}\n/** @ignore */\nclass Uint64 extends BaseInt64 {\n    times(other) {\n        this._times(other);\n        return this;\n    }\n    plus(other) {\n        this._plus(other);\n        return this;\n    }\n    /** @nocollapse */\n    static from(val, out_buffer = new Uint32Array(2)) {\n        return Uint64.fromString(typeof (val) === 'string' ? val : val.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromNumber(num, out_buffer = new Uint32Array(2)) {\n        // Always parse numbers as strings - pulling out high and low bits\n        // directly seems to lose precision sometimes\n        // For example:\n        //     > -4613034156400212000 >>> 0\n        //     721782784\n        // The correct lower 32-bits are 721782752\n        return Uint64.fromString(num.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromString(str, out_buffer = new Uint32Array(2)) {\n        const length = str.length;\n        let out = new Uint64(out_buffer);\n        for (let posn = 0; posn < length;) {\n            const group = kInt32DecimalDigits < length - posn ?\n                kInt32DecimalDigits : length - posn;\n            const chunk = new Uint64(new Uint32Array([parseInt(str.substr(posn, group), 10), 0]));\n            const multiple = new Uint64(new Uint32Array([kPowersOfTen[group], 0]));\n            out.times(multiple);\n            out.plus(chunk);\n            posn += group;\n        }\n        return out;\n    }\n    /** @nocollapse */\n    static convertArray(values) {\n        const data = new Uint32Array(values.length * 2);\n        for (let i = -1, n = values.length; ++i < n;) {\n            Uint64.from(values[i], new Uint32Array(data.buffer, data.byteOffset + 2 * i * 4, 2));\n        }\n        return data;\n    }\n    /** @nocollapse */\n    static multiply(left, right) {\n        let rtrn = new Uint64(new Uint32Array(left.buffer));\n        return rtrn.times(right);\n    }\n    /** @nocollapse */\n    static add(left, right) {\n        let rtrn = new Uint64(new Uint32Array(left.buffer));\n        return rtrn.plus(right);\n    }\n}\n/** @ignore */\nclass Int64 extends BaseInt64 {\n    negate() {\n        this.buffer[0] = ~this.buffer[0] + 1;\n        this.buffer[1] = ~this.buffer[1];\n        if (this.buffer[0] == 0) {\n            ++this.buffer[1];\n        }\n        return this;\n    }\n    times(other) {\n        this._times(other);\n        return this;\n    }\n    plus(other) {\n        this._plus(other);\n        return this;\n    }\n    lessThan(other) {\n        // force high bytes to be signed\n        const this_high = this.buffer[1] << 0;\n        const other_high = other.buffer[1] << 0;\n        return this_high < other_high ||\n            (this_high === other_high && this.buffer[0] < other.buffer[0]);\n    }\n    /** @nocollapse */\n    static from(val, out_buffer = new Uint32Array(2)) {\n        return Int64.fromString(typeof (val) === 'string' ? val : val.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromNumber(num, out_buffer = new Uint32Array(2)) {\n        // Always parse numbers as strings - pulling out high and low bits\n        // directly seems to lose precision sometimes\n        // For example:\n        //     > -4613034156400212000 >>> 0\n        //     721782784\n        // The correct lower 32-bits are 721782752\n        return Int64.fromString(num.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromString(str, out_buffer = new Uint32Array(2)) {\n        // TODO: Assert that out_buffer is 0 and length = 2\n        const negate = str.startsWith('-');\n        const length = str.length;\n        let out = new Int64(out_buffer);\n        for (let posn = negate ? 1 : 0; posn < length;) {\n            const group = kInt32DecimalDigits < length - posn ?\n                kInt32DecimalDigits : length - posn;\n            const chunk = new Int64(new Uint32Array([parseInt(str.substr(posn, group), 10), 0]));\n            const multiple = new Int64(new Uint32Array([kPowersOfTen[group], 0]));\n            out.times(multiple);\n            out.plus(chunk);\n            posn += group;\n        }\n        return negate ? out.negate() : out;\n    }\n    /** @nocollapse */\n    static convertArray(values) {\n        const data = new Uint32Array(values.length * 2);\n        for (let i = -1, n = values.length; ++i < n;) {\n            Int64.from(values[i], new Uint32Array(data.buffer, data.byteOffset + 2 * i * 4, 2));\n        }\n        return data;\n    }\n    /** @nocollapse */\n    static multiply(left, right) {\n        let rtrn = new Int64(new Uint32Array(left.buffer));\n        return rtrn.times(right);\n    }\n    /** @nocollapse */\n    static add(left, right) {\n        let rtrn = new Int64(new Uint32Array(left.buffer));\n        return rtrn.plus(right);\n    }\n}\n/** @ignore */\nclass Int128 {\n    constructor(buffer) {\n        this.buffer = buffer;\n        // buffer[3] MSB (high)\n        // buffer[2]\n        // buffer[1]\n        // buffer[0] LSB (low)\n    }\n    high() {\n        return new Int64(new Uint32Array(this.buffer.buffer, this.buffer.byteOffset + 8, 2));\n    }\n    low() {\n        return new Int64(new Uint32Array(this.buffer.buffer, this.buffer.byteOffset, 2));\n    }\n    negate() {\n        this.buffer[0] = ~this.buffer[0] + 1;\n        this.buffer[1] = ~this.buffer[1];\n        this.buffer[2] = ~this.buffer[2];\n        this.buffer[3] = ~this.buffer[3];\n        if (this.buffer[0] == 0) {\n            ++this.buffer[1];\n        }\n        if (this.buffer[1] == 0) {\n            ++this.buffer[2];\n        }\n        if (this.buffer[2] == 0) {\n            ++this.buffer[3];\n        }\n        return this;\n    }\n    times(other) {\n        // Break the left and right numbers into 32 bit chunks\n        // so that we can multiply them without overflow.\n        const L0 = new Uint64(new Uint32Array([this.buffer[3], 0]));\n        const L1 = new Uint64(new Uint32Array([this.buffer[2], 0]));\n        const L2 = new Uint64(new Uint32Array([this.buffer[1], 0]));\n        const L3 = new Uint64(new Uint32Array([this.buffer[0], 0]));\n        const R0 = new Uint64(new Uint32Array([other.buffer[3], 0]));\n        const R1 = new Uint64(new Uint32Array([other.buffer[2], 0]));\n        const R2 = new Uint64(new Uint32Array([other.buffer[1], 0]));\n        const R3 = new Uint64(new Uint32Array([other.buffer[0], 0]));\n        let product = Uint64.multiply(L3, R3);\n        this.buffer[0] = product.low();\n        let sum = new Uint64(new Uint32Array([product.high(), 0]));\n        product = Uint64.multiply(L2, R3);\n        sum.plus(product);\n        product = Uint64.multiply(L3, R2);\n        sum.plus(product);\n        this.buffer[1] = sum.low();\n        this.buffer[3] = (sum.lessThan(product) ? 1 : 0);\n        this.buffer[2] = sum.high();\n        let high = new Uint64(new Uint32Array(this.buffer.buffer, this.buffer.byteOffset + 8, 2));\n        high.plus(Uint64.multiply(L1, R3))\n            .plus(Uint64.multiply(L2, R2))\n            .plus(Uint64.multiply(L3, R1));\n        this.buffer[3] += Uint64.multiply(L0, R3)\n            .plus(Uint64.multiply(L1, R2))\n            .plus(Uint64.multiply(L2, R1))\n            .plus(Uint64.multiply(L3, R0)).low();\n        return this;\n    }\n    plus(other) {\n        let sums = new Uint32Array(4);\n        sums[3] = (this.buffer[3] + other.buffer[3]) >>> 0;\n        sums[2] = (this.buffer[2] + other.buffer[2]) >>> 0;\n        sums[1] = (this.buffer[1] + other.buffer[1]) >>> 0;\n        sums[0] = (this.buffer[0] + other.buffer[0]) >>> 0;\n        if (sums[0] < (this.buffer[0] >>> 0)) {\n            ++sums[1];\n        }\n        if (sums[1] < (this.buffer[1] >>> 0)) {\n            ++sums[2];\n        }\n        if (sums[2] < (this.buffer[2] >>> 0)) {\n            ++sums[3];\n        }\n        this.buffer[3] = sums[3];\n        this.buffer[2] = sums[2];\n        this.buffer[1] = sums[1];\n        this.buffer[0] = sums[0];\n        return this;\n    }\n    hex() {\n        return `${intAsHex(this.buffer[3])} ${intAsHex(this.buffer[2])} ${intAsHex(this.buffer[1])} ${intAsHex(this.buffer[0])}`;\n    }\n    /** @nocollapse */\n    static multiply(left, right) {\n        let rtrn = new Int128(new Uint32Array(left.buffer));\n        return rtrn.times(right);\n    }\n    /** @nocollapse */\n    static add(left, right) {\n        let rtrn = new Int128(new Uint32Array(left.buffer));\n        return rtrn.plus(right);\n    }\n    /** @nocollapse */\n    static from(val, out_buffer = new Uint32Array(4)) {\n        return Int128.fromString(typeof (val) === 'string' ? val : val.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromNumber(num, out_buffer = new Uint32Array(4)) {\n        // Always parse numbers as strings - pulling out high and low bits\n        // directly seems to lose precision sometimes\n        // For example:\n        //     > -4613034156400212000 >>> 0\n        //     721782784\n        // The correct lower 32-bits are 721782752\n        return Int128.fromString(num.toString(), out_buffer);\n    }\n    /** @nocollapse */\n    static fromString(str, out_buffer = new Uint32Array(4)) {\n        // TODO: Assert that out_buffer is 0 and length = 4\n        const negate = str.startsWith('-');\n        const length = str.length;\n        let out = new Int128(out_buffer);\n        for (let posn = negate ? 1 : 0; posn < length;) {\n            const group = kInt32DecimalDigits < length - posn ?\n                kInt32DecimalDigits : length - posn;\n            const chunk = new Int128(new Uint32Array([parseInt(str.substr(posn, group), 10), 0, 0, 0]));\n            const multiple = new Int128(new Uint32Array([kPowersOfTen[group], 0, 0, 0]));\n            out.times(multiple);\n            out.plus(chunk);\n            posn += group;\n        }\n        return negate ? out.negate() : out;\n    }\n    /** @nocollapse */\n    static convertArray(values) {\n        // TODO: Distinguish between string and number at compile-time\n        const data = new Uint32Array(values.length * 4);\n        for (let i = -1, n = values.length; ++i < n;) {\n            Int128.from(values[i], new Uint32Array(data.buffer, data.byteOffset + 4 * 4 * i, 4));\n        }\n        return data;\n    }\n}\n\n//# sourceMappingURL=int.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/int.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/math.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/util/math.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   float64ToUint16: () => (/* binding */ float64ToUint16),\n/* harmony export */   uint16ToFloat64: () => (/* binding */ uint16ToFloat64)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\nconst f64 = new Float64Array(1);\nconst u32 = new Uint32Array(f64.buffer);\n/**\n * Convert uint16 (logically a float16) to a JS float64. Inspired by numpy's `npy_half_to_double`:\n * https://github.com/numpy/numpy/blob/5a5987291dc95376bb098be8d8e5391e89e77a2c/numpy/core/src/npymath/halffloat.c#L29\n * @param h {number} the uint16 to convert\n * @private\n * @ignore\n */\nfunction uint16ToFloat64(h) {\n    let expo = (h & 0x7C00) >> 10;\n    let sigf = (h & 0x03FF) / 1024;\n    let sign = (-1) ** ((h & 0x8000) >> 15);\n    switch (expo) {\n        case 0x1F: return sign * (sigf ? NaN : 1 / 0);\n        case 0x00: return sign * (sigf ? 6.103515625e-5 * sigf : 0);\n    }\n    return sign * (2 ** (expo - 15)) * (1 + sigf);\n}\n/**\n * Convert a float64 to uint16 (assuming the float64 is logically a float16). Inspired by numpy's `npy_double_to_half`:\n * https://github.com/numpy/numpy/blob/5a5987291dc95376bb098be8d8e5391e89e77a2c/numpy/core/src/npymath/halffloat.c#L43\n * @param d {number} The float64 to convert\n * @private\n * @ignore\n */\nfunction float64ToUint16(d) {\n    if (d !== d) {\n        return 0x7E00;\n    } // NaN\n    f64[0] = d;\n    // Magic numbers:\n    // 0x80000000 = 10000000 00000000 00000000 00000000 -- masks the 32nd bit\n    // 0x7ff00000 = 01111111 11110000 00000000 00000000 -- masks the 21st-31st bits\n    // 0x000fffff = 00000000 00001111 11111111 11111111 -- masks the 1st-20th bit\n    let sign = (u32[1] & 0x80000000) >> 16 & 0xFFFF;\n    let expo = (u32[1] & 0x7ff00000), sigf = 0x0000;\n    if (expo >= 0x40f00000) {\n        //\n        // If exponent overflowed, the float16 is either NaN or Infinity.\n        // Rules to propagate the sign bit: mantissa > 0 ? NaN : +/-Infinity\n        //\n        // Magic numbers:\n        // 0x40F00000 = 01000000 11110000 00000000 00000000 -- 6-bit exponent overflow\n        // 0x7C000000 = 01111100 00000000 00000000 00000000 -- masks the 27th-31st bits\n        //\n        // returns:\n        // qNaN, aka 32256 decimal, 0x7E00 hex, or 01111110 00000000 binary\n        // sNaN, aka 32000 decimal, 0x7D00 hex, or 01111101 00000000 binary\n        // +inf, aka 31744 decimal, 0x7C00 hex, or 01111100 00000000 binary\n        // -inf, aka 64512 decimal, 0xFC00 hex, or 11111100 00000000 binary\n        //\n        // If mantissa is greater than 23 bits, set to +Infinity like numpy\n        if (u32[0] > 0) {\n            expo = 0x7C00;\n        }\n        else {\n            expo = (expo & 0x7C000000) >> 16;\n            sigf = (u32[1] & 0x000fffff) >> 10;\n        }\n    }\n    else if (expo <= 0x3f000000) {\n        //\n        // If exponent underflowed, the float is either signed zero or subnormal.\n        //\n        // Magic numbers:\n        // 0x3F000000 = 00111111 00000000 00000000 00000000 -- 6-bit exponent underflow\n        //\n        sigf = 0x100000 + (u32[1] & 0x000fffff);\n        sigf = 0x100000 + (sigf << ((expo >> 20) - 998)) >> 21;\n        expo = 0;\n    }\n    else {\n        //\n        // No overflow or underflow, rebase the exponent and round the mantissa\n        // Magic numbers:\n        // 0x200 = 00000010 00000000 -- masks off the 10th bit\n        //\n        // Ensure the first mantissa bit (the 10th one) is 1 and round\n        expo = (expo - 0x3f000000) >> 10;\n        sigf = ((u32[1] & 0x000fffff) + 0x200) >> 10;\n    }\n    return sign | expo | sigf & 0xFFFF;\n}\n\n//# sourceMappingURL=math.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/math.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/pretty.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/util/pretty.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   valueToString: () => (/* binding */ valueToString)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n/** @ignore */ const undf = void (0);\n/** @ignore */\nfunction valueToString(x) {\n    if (x === null) {\n        return 'null';\n    }\n    if (x === undf) {\n        return 'undefined';\n    }\n    switch (typeof x) {\n        case 'number': return `${x}`;\n        case 'bigint': return `${x}`;\n        case 'string': return `\"${x}\"`;\n    }\n    // If [Symbol.toPrimitive] is implemented (like in BN)\n    // use it instead of JSON.stringify(). This ensures we\n    // print BigInts, Decimals, and Binary in their native\n    // representation\n    if (typeof x[Symbol.toPrimitive] === 'function') {\n        return x[Symbol.toPrimitive]('string');\n    }\n    return ArrayBuffer.isView(x) ? `[${x}]` : JSON.stringify(x);\n}\n\n//# sourceMappingURL=pretty.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/pretty.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/recordbatch.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/util/recordbatch.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   distributeColumnsIntoRecordBatches: () => (/* binding */ distributeColumnsIntoRecordBatches),\n/* harmony export */   distributeVectorsIntoRecordBatches: () => (/* binding */ distributeVectorsIntoRecordBatches),\n/* harmony export */   ensureSameLengthData: () => (/* binding */ ensureSameLengthData)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _vector_chunked__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../vector/chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\nconst noopBuf = new Uint8Array(0);\nconst nullBufs = (bitmapLength) => [\n    noopBuf, noopBuf, new Uint8Array(bitmapLength), noopBuf\n];\n/** @ignore */\nfunction ensureSameLengthData(schema, chunks, batchLength = chunks.reduce((l, c) => Math.max(l, c.length), 0)) {\n    let data;\n    let field;\n    let i = -1, n = chunks.length;\n    const fields = [...schema.fields];\n    const batchData = [];\n    const bitmapLength = ((batchLength + 63) & ~63) >> 3;\n    while (++i < n) {\n        if ((data = chunks[i]) && data.length === batchLength) {\n            batchData[i] = data;\n        }\n        else {\n            (field = fields[i]).nullable || (fields[i] = fields[i].clone({ nullable: true }));\n            batchData[i] = data ? data._changeLengthAndBackfillNullBitmap(batchLength)\n                : _data__WEBPACK_IMPORTED_MODULE_0__.Data.new(field.type, 0, batchLength, batchLength, nullBufs(bitmapLength));\n        }\n    }\n    return [new _schema__WEBPACK_IMPORTED_MODULE_1__.Schema(fields), batchLength, batchData];\n}\n/** @ignore */\nfunction distributeColumnsIntoRecordBatches(columns) {\n    return distributeVectorsIntoRecordBatches(new _schema__WEBPACK_IMPORTED_MODULE_1__.Schema(columns.map(({ field }) => field)), columns);\n}\n/** @ignore */\nfunction distributeVectorsIntoRecordBatches(schema, vecs) {\n    return uniformlyDistributeChunksAcrossRecordBatches(schema, vecs.map((v) => v instanceof _vector_chunked__WEBPACK_IMPORTED_MODULE_2__.Chunked ? v.chunks.map((c) => c.data) : [v.data]));\n}\n/** @ignore */\nfunction uniformlyDistributeChunksAcrossRecordBatches(schema, columns) {\n    const fields = [...schema.fields];\n    const batchArgs = [];\n    const memo = { numBatches: columns.reduce((n, c) => Math.max(n, c.length), 0) };\n    let numBatches = 0, batchLength = 0;\n    let i = -1, numColumns = columns.length;\n    let child, childData = [];\n    while (memo.numBatches-- > 0) {\n        for (batchLength = Number.POSITIVE_INFINITY, i = -1; ++i < numColumns;) {\n            childData[i] = child = columns[i].shift();\n            batchLength = Math.min(batchLength, child ? child.length : batchLength);\n        }\n        if (isFinite(batchLength)) {\n            childData = distributeChildData(fields, batchLength, childData, columns, memo);\n            if (batchLength > 0) {\n                batchArgs[numBatches++] = [batchLength, childData.slice()];\n            }\n        }\n    }\n    return [\n        schema = new _schema__WEBPACK_IMPORTED_MODULE_1__.Schema(fields, schema.metadata),\n        batchArgs.map((xs) => new _recordbatch__WEBPACK_IMPORTED_MODULE_3__.RecordBatch(schema, ...xs))\n    ];\n}\n/** @ignore */\nfunction distributeChildData(fields, batchLength, childData, columns, memo) {\n    let data;\n    let field;\n    let length = 0, i = -1, n = columns.length;\n    const bitmapLength = ((batchLength + 63) & ~63) >> 3;\n    while (++i < n) {\n        if ((data = childData[i]) && ((length = data.length) >= batchLength)) {\n            if (length === batchLength) {\n                childData[i] = data;\n            }\n            else {\n                childData[i] = data.slice(0, batchLength);\n                data = data.slice(batchLength, length - batchLength);\n                memo.numBatches = Math.max(memo.numBatches, columns[i].unshift(data));\n            }\n        }\n        else {\n            (field = fields[i]).nullable || (fields[i] = field.clone({ nullable: true }));\n            childData[i] = data ? data._changeLengthAndBackfillNullBitmap(batchLength)\n                : _data__WEBPACK_IMPORTED_MODULE_0__.Data.new(field.type, 0, batchLength, batchLength, nullBufs(bitmapLength));\n        }\n    }\n    return childData;\n}\n\n//# sourceMappingURL=recordbatch.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/recordbatch.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/utf8.mjs":
/*!*****************************************************!*\
  !*** ../../node_modules/apache-arrow/util/utf8.mjs ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   decodeUtf8: () => (/* binding */ decodeUtf8),\n/* harmony export */   encodeUtf8: () => (/* binding */ encodeUtf8)\n/* harmony export */ });\n/* harmony import */ var _buffer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var text_encoding_utf_8__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! text-encoding-utf-8 */ \"../../node_modules/text-encoding-utf-8/lib/encoding.lib.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore @suppress {missingRequire} */\nconst _Buffer = typeof Buffer === 'function' ? Buffer : null;\n/** @ignore */\nconst useNativeEncoders = typeof TextDecoder === 'function' && typeof TextEncoder === 'function';\n/** @ignore */\nconst decodeUtf8 = ((TextDecoder) => {\n    if (useNativeEncoders || !_Buffer) {\n        const decoder = new TextDecoder('utf-8');\n        return (buffer) => decoder.decode(buffer);\n    }\n    return (input) => {\n        const { buffer, byteOffset, length } = (0,_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(input);\n        return _Buffer.from(buffer, byteOffset, length).toString();\n    };\n})(typeof TextDecoder !== 'undefined' ? TextDecoder : text_encoding_utf_8__WEBPACK_IMPORTED_MODULE_1__.TextDecoder);\n/** @ignore */\nconst encodeUtf8 = ((TextEncoder) => {\n    if (useNativeEncoders || !_Buffer) {\n        const encoder = new TextEncoder();\n        return (value) => encoder.encode(value);\n    }\n    return (input = '') => (0,_buffer__WEBPACK_IMPORTED_MODULE_0__.toUint8Array)(_Buffer.from(input, 'utf8'));\n})(typeof TextEncoder !== 'undefined' ? TextEncoder : text_encoding_utf_8__WEBPACK_IMPORTED_MODULE_1__.TextEncoder);\n\n//# sourceMappingURL=utf8.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/utf8.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/util/vector.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/util/vector.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   clampIndex: () => (/* binding */ clampIndex),\n/* harmony export */   clampRange: () => (/* binding */ clampRange),\n/* harmony export */   createElementComparator: () => (/* binding */ createElementComparator)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _vector_row__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector/row */ \"../../node_modules/apache-arrow/vector/row.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _compat__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nfunction clampIndex(source, index, then) {\n    const length = source.length;\n    const adjust = index > -1 ? index : (length + (index % length));\n    return then ? then(source, adjust) : adjust;\n}\n/** @ignore */\nlet tmp;\n/** @ignore */\nfunction clampRange(source, begin, end, then) {\n    // Adjust args similar to Array.prototype.slice. Normalize begin/end to\n    // clamp between 0 and length, and wrap around on negative indices, e.g.\n    // slice(-1, 5) or slice(5, -1)\n    let { length: len = 0 } = source;\n    let lhs = typeof begin !== 'number' ? 0 : begin;\n    let rhs = typeof end !== 'number' ? len : end;\n    // wrap around on negative start/end positions\n    (lhs < 0) && (lhs = ((lhs % len) + len) % len);\n    (rhs < 0) && (rhs = ((rhs % len) + len) % len);\n    // ensure lhs <= rhs\n    (rhs < lhs) && (tmp = lhs, lhs = rhs, rhs = tmp);\n    // ensure rhs <= length\n    (rhs > len) && (rhs = len);\n    return then ? then(source, lhs, rhs) : [lhs, rhs];\n}\nconst big0 = _compat__WEBPACK_IMPORTED_MODULE_3__.BigIntAvailable ? (0,_compat__WEBPACK_IMPORTED_MODULE_3__.BigInt)(0) : 0;\nconst isNaNFast = (value) => value !== value;\n/** @ignore */\nfunction createElementComparator(search) {\n    let typeofSearch = typeof search;\n    // Compare primitives\n    if (typeofSearch !== 'object' || search === null) {\n        // Compare NaN\n        if (isNaNFast(search)) {\n            return isNaNFast;\n        }\n        return typeofSearch !== 'bigint'\n            ? (value) => value === search\n            : (value) => (big0 + value) === search;\n    }\n    // Compare Dates\n    if (search instanceof Date) {\n        const valueOfSearch = search.valueOf();\n        return (value) => value instanceof Date ? (value.valueOf() === valueOfSearch) : false;\n    }\n    // Compare TypedArrays\n    if (ArrayBuffer.isView(search)) {\n        return (value) => value ? (0,_util_buffer__WEBPACK_IMPORTED_MODULE_2__.compareArrayLike)(search, value) : false;\n    }\n    // Compare Maps and Rows\n    if (search instanceof Map) {\n        return creatMapComparator(search);\n    }\n    // Compare Array-likes\n    if (Array.isArray(search)) {\n        return createArrayLikeComparator(search);\n    }\n    // Compare Vectors\n    if (search instanceof _vector__WEBPACK_IMPORTED_MODULE_0__.Vector) {\n        return createVectorComparator(search);\n    }\n    // Compare non-empty Objects\n    return createObjectComparator(search);\n}\n/** @ignore */\nfunction createArrayLikeComparator(lhs) {\n    const comparators = [];\n    for (let i = -1, n = lhs.length; ++i < n;) {\n        comparators[i] = createElementComparator(lhs[i]);\n    }\n    return createSubElementsComparator(comparators);\n}\n/** @ignore */\nfunction creatMapComparator(lhs) {\n    let i = -1;\n    const comparators = [];\n    lhs.forEach((v) => comparators[++i] = createElementComparator(v));\n    return createSubElementsComparator(comparators);\n}\n/** @ignore */\nfunction createVectorComparator(lhs) {\n    const comparators = [];\n    for (let i = -1, n = lhs.length; ++i < n;) {\n        comparators[i] = createElementComparator(lhs.get(i));\n    }\n    return createSubElementsComparator(comparators);\n}\n/** @ignore */\nfunction createObjectComparator(lhs) {\n    const keys = Object.keys(lhs);\n    // Only compare non-empty Objects\n    if (keys.length === 0) {\n        return () => false;\n    }\n    const comparators = [];\n    for (let i = -1, n = keys.length; ++i < n;) {\n        comparators[i] = createElementComparator(lhs[keys[i]]);\n    }\n    return createSubElementsComparator(comparators, keys);\n}\nfunction createSubElementsComparator(comparators, keys) {\n    return (rhs) => {\n        if (!rhs || typeof rhs !== 'object') {\n            return false;\n        }\n        switch (rhs.constructor) {\n            case Array: return compareArray(comparators, rhs);\n            case Map:\n            case _vector_row__WEBPACK_IMPORTED_MODULE_1__.MapRow:\n            case _vector_row__WEBPACK_IMPORTED_MODULE_1__.StructRow:\n                return compareObject(comparators, rhs, rhs.keys());\n            case Object:\n            case undefined: // support `Object.create(null)` objects\n                return compareObject(comparators, rhs, keys || Object.keys(rhs));\n        }\n        return rhs instanceof _vector__WEBPACK_IMPORTED_MODULE_0__.Vector ? compareVector(comparators, rhs) : false;\n    };\n}\nfunction compareArray(comparators, arr) {\n    const n = comparators.length;\n    if (arr.length !== n) {\n        return false;\n    }\n    for (let i = -1; ++i < n;) {\n        if (!(comparators[i](arr[i]))) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction compareVector(comparators, vec) {\n    const n = comparators.length;\n    if (vec.length !== n) {\n        return false;\n    }\n    for (let i = -1; ++i < n;) {\n        if (!(comparators[i](vec.get(i)))) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction compareObject(comparators, obj, keys) {\n    const lKeyItr = keys[Symbol.iterator]();\n    const rKeyItr = obj instanceof Map ? obj.keys() : Object.keys(obj)[Symbol.iterator]();\n    const rValItr = obj instanceof Map ? obj.values() : Object.values(obj)[Symbol.iterator]();\n    let i = 0;\n    let n = comparators.length;\n    let rVal = rValItr.next();\n    let lKey = lKeyItr.next();\n    let rKey = rKeyItr.next();\n    for (; i < n && !lKey.done && !rKey.done && !rVal.done; ++i, lKey = lKeyItr.next(), rKey = rKeyItr.next(), rVal = rValItr.next()) {\n        if (lKey.value !== rKey.value || !comparators[i](rVal.value)) {\n            break;\n        }\n    }\n    if (i === n && lKey.done && rKey.done && rVal.done) {\n        return true;\n    }\n    lKeyItr.return && lKeyItr.return();\n    rKeyItr.return && rKeyItr.return();\n    rValItr.return && rValItr.return();\n    return false;\n}\n\n//# sourceMappingURL=vector.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/util/vector.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector.mjs":
/*!**************************************************!*\
  !*** ../../node_modules/apache-arrow/vector.mjs ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   AbstractVector: () => (/* binding */ AbstractVector),\n/* harmony export */   Vector: () => (/* binding */ AbstractVector)\n/* harmony export */ });\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\nclass AbstractVector {\n}\nAbstractVector.prototype.data = null;\n\n\n//# sourceMappingURL=vector.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/base.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/base.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BaseVector: () => (/* binding */ BaseVector)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _chunked__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n/* harmony import */ var _util_vector__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/vector */ \"../../node_modules/apache-arrow/util/vector.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass BaseVector extends _vector__WEBPACK_IMPORTED_MODULE_3__.AbstractVector {\n    constructor(data, children) {\n        super();\n        this._children = children;\n        this.numChildren = data.childData.length;\n        this._bindDataAccessors(this.data = data);\n    }\n    get type() { return this.data.type; }\n    get typeId() { return this.data.typeId; }\n    get length() { return this.data.length; }\n    get offset() { return this.data.offset; }\n    get stride() { return this.data.stride; }\n    get nullCount() { return this.data.nullCount; }\n    get byteLength() { return this.data.byteLength; }\n    get VectorName() { return `${_enum__WEBPACK_IMPORTED_MODULE_0__.Type[this.typeId]}Vector`; }\n    get ArrayType() { return this.type.ArrayType; }\n    get values() { return this.data.values; }\n    get typeIds() { return this.data.typeIds; }\n    get nullBitmap() { return this.data.nullBitmap; }\n    get valueOffsets() { return this.data.valueOffsets; }\n    get [Symbol.toStringTag]() { return `${this.VectorName}<${this.type[Symbol.toStringTag]}>`; }\n    clone(data, children = this._children) {\n        return _vector__WEBPACK_IMPORTED_MODULE_3__.Vector.new(data, children);\n    }\n    concat(...others) {\n        return _chunked__WEBPACK_IMPORTED_MODULE_1__.Chunked.concat(this, ...others);\n    }\n    slice(begin, end) {\n        // Adjust args similar to Array.prototype.slice. Normalize begin/end to\n        // clamp between 0 and length, and wrap around on negative indices, e.g.\n        // slice(-1, 5) or slice(5, -1)\n        return (0,_util_vector__WEBPACK_IMPORTED_MODULE_2__.clampRange)(this, begin, end, this._sliceInternal);\n    }\n    isValid(index) {\n        if (this.nullCount > 0) {\n            const idx = this.offset + index;\n            const val = this.nullBitmap[idx >> 3];\n            const mask = (val & (1 << (idx % 8)));\n            return mask !== 0;\n        }\n        return true;\n    }\n    getChildAt(index) {\n        return index < 0 || index >= this.numChildren ? null : ((this._children || (this._children = []))[index] ||\n            (this._children[index] = _vector__WEBPACK_IMPORTED_MODULE_3__.Vector.new(this.data.childData[index])));\n    }\n    toJSON() { return [...this]; }\n    _sliceInternal(self, begin, end) {\n        return self.clone(self.data.slice(begin, end - begin), null);\n    }\n    // @ts-ignore\n    _bindDataAccessors(data) {\n        // Implementation in src/vectors/index.ts due to circular dependency/packaging shenanigans\n    }\n}\nBaseVector.prototype[Symbol.isConcatSpreadable] = true;\n\n//# sourceMappingURL=base.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/base.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/binary.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/binary.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BinaryVector: () => (/* binding */ BinaryVector)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass BinaryVector extends _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector {\n    asUtf8() {\n        return _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new(this.data.clone(new _type__WEBPACK_IMPORTED_MODULE_2__.Utf8()));\n    }\n}\n\n//# sourceMappingURL=binary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/binary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/bool.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/bool.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BoolVector: () => (/* binding */ BoolVector)\n/* harmony export */ });\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass BoolVector extends _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector {\n    /** @nocollapse */\n    static from(input) {\n        return (0,_index__WEBPACK_IMPORTED_MODULE_2__.vectorFromValuesWithType)(() => new _type__WEBPACK_IMPORTED_MODULE_0__.Bool(), input);\n    }\n}\n\n//# sourceMappingURL=bool.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/bool.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/chunked.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/chunked.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Chunked: () => (/* binding */ Chunked)\n/* harmony export */ });\n/* harmony import */ var _util_vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/vector */ \"../../node_modules/apache-arrow/util/vector.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass Chunked extends _vector__WEBPACK_IMPORTED_MODULE_3__.AbstractVector {\n    constructor(type, chunks = [], offsets = calculateOffsets(chunks)) {\n        super();\n        this._nullCount = -1;\n        this._type = type;\n        this._chunks = chunks;\n        this._chunkOffsets = offsets;\n        this._length = offsets[offsets.length - 1];\n        this._numChildren = (this._type.children || []).length;\n    }\n    /** @nocollapse */\n    static flatten(...vectors) {\n        return (0,_util_args__WEBPACK_IMPORTED_MODULE_2__.selectChunkArgs)(_vector__WEBPACK_IMPORTED_MODULE_3__.Vector, vectors);\n    }\n    /** @nocollapse */\n    static concat(...vectors) {\n        const chunks = Chunked.flatten(...vectors);\n        return new Chunked(chunks[0].type, chunks);\n    }\n    get type() { return this._type; }\n    get length() { return this._length; }\n    get chunks() { return this._chunks; }\n    get typeId() { return this._type.typeId; }\n    get VectorName() { return `Chunked<${this._type}>`; }\n    get data() {\n        return this._chunks[0] ? this._chunks[0].data : null;\n    }\n    get ArrayType() { return this._type.ArrayType; }\n    get numChildren() { return this._numChildren; }\n    get stride() { return this._chunks[0] ? this._chunks[0].stride : 1; }\n    get byteLength() {\n        return this._chunks.reduce((byteLength, chunk) => byteLength + chunk.byteLength, 0);\n    }\n    get nullCount() {\n        let nullCount = this._nullCount;\n        if (nullCount < 0) {\n            this._nullCount = nullCount = this._chunks.reduce((x, { nullCount }) => x + nullCount, 0);\n        }\n        return nullCount;\n    }\n    get indices() {\n        if (_type__WEBPACK_IMPORTED_MODULE_1__.DataType.isDictionary(this._type)) {\n            if (!this._indices) {\n                const chunks = this._chunks;\n                this._indices = (chunks.length === 1\n                    ? chunks[0].indices\n                    : Chunked.concat(...chunks.map((x) => x.indices)));\n            }\n            return this._indices;\n        }\n        return null;\n    }\n    get dictionary() {\n        if (_type__WEBPACK_IMPORTED_MODULE_1__.DataType.isDictionary(this._type)) {\n            return this._chunks[this._chunks.length - 1].data.dictionary;\n        }\n        return null;\n    }\n    *[Symbol.iterator]() {\n        for (const chunk of this._chunks) {\n            yield* chunk;\n        }\n    }\n    clone(chunks = this._chunks) {\n        return new Chunked(this._type, chunks);\n    }\n    concat(...others) {\n        return this.clone(Chunked.flatten(this, ...others));\n    }\n    slice(begin, end) {\n        return (0,_util_vector__WEBPACK_IMPORTED_MODULE_0__.clampRange)(this, begin, end, this._sliceInternal);\n    }\n    getChildAt(index) {\n        if (index < 0 || index >= this._numChildren) {\n            return null;\n        }\n        let columns = this._children || (this._children = []);\n        let child, field, chunks;\n        if (child = columns[index]) {\n            return child;\n        }\n        if (field = (this._type.children || [])[index]) {\n            chunks = this._chunks\n                .map((vector) => vector.getChildAt(index))\n                .filter((vec) => vec != null);\n            if (chunks.length > 0) {\n                return (columns[index] = new Chunked(field.type, chunks));\n            }\n        }\n        return null;\n    }\n    search(index, then) {\n        let idx = index;\n        // binary search to find the child vector and value indices\n        let offsets = this._chunkOffsets, rhs = offsets.length - 1;\n        // return early if out of bounds, or if there's just one child\n        if (idx < 0) {\n            return null;\n        }\n        if (idx >= offsets[rhs]) {\n            return null;\n        }\n        if (rhs <= 1) {\n            return then ? then(this, 0, idx) : [0, idx];\n        }\n        let lhs = 0, pos = 0, mid = 0;\n        do {\n            if (lhs + 1 === rhs) {\n                return then ? then(this, lhs, idx - pos) : [lhs, idx - pos];\n            }\n            mid = lhs + ((rhs - lhs) / 2) | 0;\n            idx >= offsets[mid] ? (lhs = mid) : (rhs = mid);\n        } while (idx < offsets[rhs] && idx >= (pos = offsets[lhs]));\n        return null;\n    }\n    isValid(index) {\n        return !!this.search(index, this.isValidInternal);\n    }\n    get(index) {\n        return this.search(index, this.getInternal);\n    }\n    set(index, value) {\n        this.search(index, ({ chunks }, i, j) => chunks[i].set(j, value));\n    }\n    indexOf(element, offset) {\n        if (offset && typeof offset === 'number') {\n            return this.search(offset, (self, i, j) => this.indexOfInternal(self, i, j, element));\n        }\n        return this.indexOfInternal(this, 0, Math.max(0, offset || 0), element);\n    }\n    toArray() {\n        const { chunks } = this;\n        const n = chunks.length;\n        let ArrayType = this._type.ArrayType;\n        if (n <= 0) {\n            return new ArrayType(0);\n        }\n        if (n <= 1) {\n            return chunks[0].toArray();\n        }\n        let len = 0, src = new Array(n);\n        for (let i = -1; ++i < n;) {\n            len += (src[i] = chunks[i].toArray()).length;\n        }\n        if (ArrayType !== src[0].constructor) {\n            ArrayType = src[0].constructor;\n        }\n        let dst = new ArrayType(len);\n        let set = ArrayType === Array ? arraySet : typedSet;\n        for (let i = -1, idx = 0; ++i < n;) {\n            idx = set(src[i], dst, idx);\n        }\n        return dst;\n    }\n    getInternal({ _chunks }, i, j) { return _chunks[i].get(j); }\n    isValidInternal({ _chunks }, i, j) { return _chunks[i].isValid(j); }\n    indexOfInternal({ _chunks }, chunkIndex, fromIndex, element) {\n        let i = chunkIndex - 1, n = _chunks.length;\n        let start = fromIndex, offset = 0, found = -1;\n        while (++i < n) {\n            if (~(found = _chunks[i].indexOf(element, start))) {\n                return offset + found;\n            }\n            start = 0;\n            offset += _chunks[i].length;\n        }\n        return -1;\n    }\n    _sliceInternal(self, begin, end) {\n        const slices = [];\n        const { chunks, _chunkOffsets: chunkOffsets } = self;\n        for (let i = -1, n = chunks.length; ++i < n;) {\n            const chunk = chunks[i];\n            const chunkLength = chunk.length;\n            const chunkOffset = chunkOffsets[i];\n            // If the child is to the right of the slice boundary, we can stop\n            if (chunkOffset >= end) {\n                break;\n            }\n            // If the child is to the left of of the slice boundary, exclude\n            if (begin >= chunkOffset + chunkLength) {\n                continue;\n            }\n            // If the child is between both left and right boundaries, include w/o slicing\n            if (chunkOffset >= begin && (chunkOffset + chunkLength) <= end) {\n                slices.push(chunk);\n                continue;\n            }\n            // If the child overlaps one of the slice boundaries, include that slice\n            const from = Math.max(0, begin - chunkOffset);\n            const to = Math.min(end - chunkOffset, chunkLength);\n            slices.push(chunk.slice(from, to));\n        }\n        return self.clone(slices);\n    }\n}\n/** @ignore */\nfunction calculateOffsets(vectors) {\n    let offsets = new Uint32Array((vectors || []).length + 1);\n    let offset = offsets[0] = 0, length = offsets.length;\n    for (let index = 0; ++index < length;) {\n        offsets[index] = (offset += vectors[index - 1].length);\n    }\n    return offsets;\n}\n/** @ignore */\nconst typedSet = (src, dst, offset) => {\n    dst.set(src, offset);\n    return (offset + src.length);\n};\n/** @ignore */\nconst arraySet = (src, dst, offset) => {\n    let idx = offset;\n    for (let i = -1, n = src.length; ++i < n;) {\n        dst[idx++] = src[i];\n    }\n    return idx;\n};\n\n//# sourceMappingURL=chunked.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/chunked.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/date.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/date.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DateDayVector: () => (/* binding */ DateDayVector),\n/* harmony export */   DateMillisecondVector: () => (/* binding */ DateMillisecondVector),\n/* harmony export */   DateVector: () => (/* binding */ DateVector)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass DateVector extends _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector {\n    /** @nocollapse */\n    static from(...args) {\n        if (args.length === 2) {\n            return (0,_index__WEBPACK_IMPORTED_MODULE_2__.vectorFromValuesWithType)(() => args[1] === _enum__WEBPACK_IMPORTED_MODULE_0__.DateUnit.DAY ? new _type__WEBPACK_IMPORTED_MODULE_3__.DateDay() : new _type__WEBPACK_IMPORTED_MODULE_3__.DateMillisecond(), args[0]);\n        }\n        return (0,_index__WEBPACK_IMPORTED_MODULE_2__.vectorFromValuesWithType)(() => new _type__WEBPACK_IMPORTED_MODULE_3__.DateMillisecond(), args[0]);\n    }\n}\n/** @ignore */\nclass DateDayVector extends DateVector {\n}\n/** @ignore */\nclass DateMillisecondVector extends DateVector {\n}\n\n//# sourceMappingURL=date.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/date.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/decimal.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/decimal.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DecimalVector: () => (/* binding */ DecimalVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass DecimalVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n\n//# sourceMappingURL=decimal.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/decimal.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/dictionary.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/dictionary.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DictionaryVector: () => (/* binding */ DictionaryVector)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */\nclass DictionaryVector extends _base__WEBPACK_IMPORTED_MODULE_2__.BaseVector {\n    constructor(data) {\n        super(data);\n        this.indices = _vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(data.clone(this.type.indices));\n    }\n    /** @nocollapse */\n    static from(...args) {\n        if (args.length === 3) {\n            const [values, indices, keys] = args;\n            const type = new _type__WEBPACK_IMPORTED_MODULE_4__.Dictionary(values.type, indices, null, null);\n            return _vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(_data__WEBPACK_IMPORTED_MODULE_0__.Data.Dictionary(type, 0, keys.length, 0, null, keys, values));\n        }\n        return (0,_index__WEBPACK_IMPORTED_MODULE_3__.vectorFromValuesWithType)(() => args[0].type, args[0]);\n    }\n    get dictionary() { return this.data.dictionary; }\n    reverseLookup(value) { return this.dictionary.indexOf(value); }\n    getKey(idx) { return this.indices.get(idx); }\n    getValue(key) { return this.dictionary.get(key); }\n    setKey(idx, key) { return this.indices.set(idx, key); }\n    setValue(key, value) { return this.dictionary.set(key, value); }\n}\nDictionaryVector.prototype.indices = null;\n\n//# sourceMappingURL=dictionary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/dictionary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/fixedsizebinary.mjs":
/*!******************************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/fixedsizebinary.mjs ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FixedSizeBinaryVector: () => (/* binding */ FixedSizeBinaryVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass FixedSizeBinaryVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n\n//# sourceMappingURL=fixedsizebinary.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/fixedsizebinary.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/fixedsizelist.mjs":
/*!****************************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/fixedsizelist.mjs ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FixedSizeListVector: () => (/* binding */ FixedSizeListVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass FixedSizeListVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n\n//# sourceMappingURL=fixedsizelist.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/fixedsizelist.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/float.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/float.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Float16Vector: () => (/* binding */ Float16Vector),\n/* harmony export */   Float32Vector: () => (/* binding */ Float32Vector),\n/* harmony export */   Float64Vector: () => (/* binding */ Float64Vector),\n/* harmony export */   FloatVector: () => (/* binding */ FloatVector)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */\nclass FloatVector extends _base__WEBPACK_IMPORTED_MODULE_2__.BaseVector {\n    /** @nocollapse */\n    static from(input) {\n        let ArrowType = vectorTypeToDataType(this);\n        if ((input instanceof ArrayBuffer) || ArrayBuffer.isView(input)) {\n            let InputType = arrayTypeToDataType(input.constructor) || ArrowType;\n            // Special case, infer the Arrow DataType from the input if calling the base\n            // FloatVector.from with a TypedArray, e.g. `FloatVector.from(new Float32Array())`\n            if (ArrowType === null) {\n                ArrowType = InputType;\n            }\n            // If the DataType inferred from the Vector constructor matches the\n            // DataType inferred from the input arguments, return zero-copy view\n            if (ArrowType && ArrowType === InputType) {\n                let type = new ArrowType();\n                let length = input.byteLength / type.ArrayType.BYTES_PER_ELEMENT;\n                // If the ArrowType is Float16 but the input type isn't a Uint16Array,\n                // let the Float16Builder handle casting the input values to Uint16s.\n                if (!convertTo16Bit(ArrowType, input.constructor)) {\n                    return _vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(_data__WEBPACK_IMPORTED_MODULE_0__.Data.Float(type, 0, length, 0, null, input));\n                }\n            }\n        }\n        if (ArrowType) {\n            // If the DataType inferred from the Vector constructor is different than\n            // the DataType inferred from the input TypedArray, or if input isn't a\n            // TypedArray, use the Builders to construct the result Vector\n            return (0,_index__WEBPACK_IMPORTED_MODULE_3__.vectorFromValuesWithType)(() => new ArrowType(), input);\n        }\n        if ((input instanceof DataView) || (input instanceof ArrayBuffer)) {\n            throw new TypeError(`Cannot infer float type from instance of ${input.constructor.name}`);\n        }\n        throw new TypeError('Unrecognized FloatVector input');\n    }\n}\n/** @ignore */\nclass Float16Vector extends FloatVector {\n    // Since JS doesn't have half floats, `toArray()` returns a zero-copy slice\n    // of the underlying Uint16Array data. This behavior ensures we don't incur\n    // extra compute or copies if you're calling `toArray()` in order to create\n    // a buffer for something like WebGL. Buf if you're using JS and want typed\n    // arrays of 4-to-8-byte precision, these methods will enumerate the values\n    // and clamp to the desired byte lengths.\n    toFloat32Array() { return new Float32Array(this); }\n    toFloat64Array() { return new Float64Array(this); }\n}\n/** @ignore */\nclass Float32Vector extends FloatVector {\n}\n/** @ignore */\nclass Float64Vector extends FloatVector {\n}\nconst convertTo16Bit = (typeCtor, dataCtor) => {\n    return (typeCtor === _type__WEBPACK_IMPORTED_MODULE_4__.Float16) && (dataCtor !== Uint16Array);\n};\n/** @ignore */\nconst arrayTypeToDataType = (ctor) => {\n    switch (ctor) {\n        case Uint16Array: return _type__WEBPACK_IMPORTED_MODULE_4__.Float16;\n        case Float32Array: return _type__WEBPACK_IMPORTED_MODULE_4__.Float32;\n        case Float64Array: return _type__WEBPACK_IMPORTED_MODULE_4__.Float64;\n        default: return null;\n    }\n};\n/** @ignore */\nconst vectorTypeToDataType = (ctor) => {\n    switch (ctor) {\n        case Float16Vector: return _type__WEBPACK_IMPORTED_MODULE_4__.Float16;\n        case Float32Vector: return _type__WEBPACK_IMPORTED_MODULE_4__.Float32;\n        case Float64Vector: return _type__WEBPACK_IMPORTED_MODULE_4__.Float64;\n        default: return null;\n    }\n};\n\n//# sourceMappingURL=float.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/float.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/index.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/index.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   BaseVector: () => (/* reexport safe */ _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector),\n/* harmony export */   BinaryVector: () => (/* reexport safe */ _binary__WEBPACK_IMPORTED_MODULE_2__.BinaryVector),\n/* harmony export */   BoolVector: () => (/* reexport safe */ _bool__WEBPACK_IMPORTED_MODULE_3__.BoolVector),\n/* harmony export */   Chunked: () => (/* reexport safe */ _chunked__WEBPACK_IMPORTED_MODULE_4__.Chunked),\n/* harmony export */   DateDayVector: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_5__.DateDayVector),\n/* harmony export */   DateMillisecondVector: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_5__.DateMillisecondVector),\n/* harmony export */   DateVector: () => (/* reexport safe */ _date__WEBPACK_IMPORTED_MODULE_5__.DateVector),\n/* harmony export */   DecimalVector: () => (/* reexport safe */ _decimal__WEBPACK_IMPORTED_MODULE_6__.DecimalVector),\n/* harmony export */   DenseUnionVector: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_19__.DenseUnionVector),\n/* harmony export */   DictionaryVector: () => (/* reexport safe */ _dictionary__WEBPACK_IMPORTED_MODULE_7__.DictionaryVector),\n/* harmony export */   FixedSizeBinaryVector: () => (/* reexport safe */ _fixedsizebinary__WEBPACK_IMPORTED_MODULE_8__.FixedSizeBinaryVector),\n/* harmony export */   FixedSizeListVector: () => (/* reexport safe */ _fixedsizelist__WEBPACK_IMPORTED_MODULE_9__.FixedSizeListVector),\n/* harmony export */   Float16Vector: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_10__.Float16Vector),\n/* harmony export */   Float32Vector: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_10__.Float32Vector),\n/* harmony export */   Float64Vector: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_10__.Float64Vector),\n/* harmony export */   FloatVector: () => (/* reexport safe */ _float__WEBPACK_IMPORTED_MODULE_10__.FloatVector),\n/* harmony export */   Int16Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Int16Vector),\n/* harmony export */   Int32Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Int32Vector),\n/* harmony export */   Int64Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Int64Vector),\n/* harmony export */   Int8Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Int8Vector),\n/* harmony export */   IntVector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.IntVector),\n/* harmony export */   IntervalDayTimeVector: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalDayTimeVector),\n/* harmony export */   IntervalVector: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalVector),\n/* harmony export */   IntervalYearMonthVector: () => (/* reexport safe */ _interval__WEBPACK_IMPORTED_MODULE_11__.IntervalYearMonthVector),\n/* harmony export */   ListVector: () => (/* reexport safe */ _list__WEBPACK_IMPORTED_MODULE_13__.ListVector),\n/* harmony export */   MapRow: () => (/* reexport safe */ _row__WEBPACK_IMPORTED_MODULE_21__.MapRow),\n/* harmony export */   MapVector: () => (/* reexport safe */ _map__WEBPACK_IMPORTED_MODULE_14__.MapVector),\n/* harmony export */   NullVector: () => (/* reexport safe */ _null__WEBPACK_IMPORTED_MODULE_15__.NullVector),\n/* harmony export */   SparseUnionVector: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_19__.SparseUnionVector),\n/* harmony export */   StructRow: () => (/* reexport safe */ _row__WEBPACK_IMPORTED_MODULE_21__.StructRow),\n/* harmony export */   StructVector: () => (/* reexport safe */ _struct__WEBPACK_IMPORTED_MODULE_16__.StructVector),\n/* harmony export */   TimeMicrosecondVector: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_18__.TimeMicrosecondVector),\n/* harmony export */   TimeMillisecondVector: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_18__.TimeMillisecondVector),\n/* harmony export */   TimeNanosecondVector: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_18__.TimeNanosecondVector),\n/* harmony export */   TimeSecondVector: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_18__.TimeSecondVector),\n/* harmony export */   TimeVector: () => (/* reexport safe */ _time__WEBPACK_IMPORTED_MODULE_18__.TimeVector),\n/* harmony export */   TimestampMicrosecondVector: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_17__.TimestampMicrosecondVector),\n/* harmony export */   TimestampMillisecondVector: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_17__.TimestampMillisecondVector),\n/* harmony export */   TimestampNanosecondVector: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_17__.TimestampNanosecondVector),\n/* harmony export */   TimestampSecondVector: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_17__.TimestampSecondVector),\n/* harmony export */   TimestampVector: () => (/* reexport safe */ _timestamp__WEBPACK_IMPORTED_MODULE_17__.TimestampVector),\n/* harmony export */   Uint16Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Uint16Vector),\n/* harmony export */   Uint32Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Uint32Vector),\n/* harmony export */   Uint64Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Uint64Vector),\n/* harmony export */   Uint8Vector: () => (/* reexport safe */ _int__WEBPACK_IMPORTED_MODULE_12__.Uint8Vector),\n/* harmony export */   UnionVector: () => (/* reexport safe */ _union__WEBPACK_IMPORTED_MODULE_19__.UnionVector),\n/* harmony export */   Utf8Vector: () => (/* reexport safe */ _utf8__WEBPACK_IMPORTED_MODULE_20__.Utf8Vector),\n/* harmony export */   Vector: () => (/* reexport safe */ _vector__WEBPACK_IMPORTED_MODULE_0__.Vector),\n/* harmony export */   vectorFromValuesWithType: () => (/* binding */ vectorFromValuesWithType)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _binary__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./binary */ \"../../node_modules/apache-arrow/vector/binary.mjs\");\n/* harmony import */ var _bool__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./bool */ \"../../node_modules/apache-arrow/vector/bool.mjs\");\n/* harmony import */ var _chunked__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./chunked */ \"../../node_modules/apache-arrow/vector/chunked.mjs\");\n/* harmony import */ var _date__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./date */ \"../../node_modules/apache-arrow/vector/date.mjs\");\n/* harmony import */ var _decimal__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./decimal */ \"../../node_modules/apache-arrow/vector/decimal.mjs\");\n/* harmony import */ var _dictionary__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./dictionary */ \"../../node_modules/apache-arrow/vector/dictionary.mjs\");\n/* harmony import */ var _fixedsizebinary__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./fixedsizebinary */ \"../../node_modules/apache-arrow/vector/fixedsizebinary.mjs\");\n/* harmony import */ var _fixedsizelist__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./fixedsizelist */ \"../../node_modules/apache-arrow/vector/fixedsizelist.mjs\");\n/* harmony import */ var _float__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./float */ \"../../node_modules/apache-arrow/vector/float.mjs\");\n/* harmony import */ var _interval__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./interval */ \"../../node_modules/apache-arrow/vector/interval.mjs\");\n/* harmony import */ var _int__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./int */ \"../../node_modules/apache-arrow/vector/int.mjs\");\n/* harmony import */ var _list__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./list */ \"../../node_modules/apache-arrow/vector/list.mjs\");\n/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./map */ \"../../node_modules/apache-arrow/vector/map.mjs\");\n/* harmony import */ var _null__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./null */ \"../../node_modules/apache-arrow/vector/null.mjs\");\n/* harmony import */ var _struct__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./struct */ \"../../node_modules/apache-arrow/vector/struct.mjs\");\n/* harmony import */ var _timestamp__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./timestamp */ \"../../node_modules/apache-arrow/vector/timestamp.mjs\");\n/* harmony import */ var _time__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./time */ \"../../node_modules/apache-arrow/vector/time.mjs\");\n/* harmony import */ var _union__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./union */ \"../../node_modules/apache-arrow/vector/union.mjs\");\n/* harmony import */ var _utf8__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./utf8 */ \"../../node_modules/apache-arrow/vector/utf8.mjs\");\n/* harmony import */ var _row__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./row */ \"../../node_modules/apache-arrow/vector/row.mjs\");\n/* harmony import */ var _util_fn__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../util/fn */ \"../../node_modules/apache-arrow/util/fn.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _builder__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ../builder */ \"../../node_modules/apache-arrow/builder.mjs\");\n/* harmony import */ var _visitor_get__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ../visitor/get */ \"../../node_modules/apache-arrow/visitor/get.mjs\");\n/* harmony import */ var _visitor_set__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ../visitor/set */ \"../../node_modules/apache-arrow/visitor/set.mjs\");\n/* harmony import */ var _visitor_indexof__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ../visitor/indexof */ \"../../node_modules/apache-arrow/visitor/indexof.mjs\");\n/* harmony import */ var _visitor_toarray__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ../visitor/toarray */ \"../../node_modules/apache-arrow/visitor/toarray.mjs\");\n/* harmony import */ var _visitor_iterator__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ../visitor/iterator */ \"../../node_modules/apache-arrow/visitor/iterator.mjs\");\n/* harmony import */ var _visitor_bytewidth__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ../visitor/bytewidth */ \"../../node_modules/apache-arrow/visitor/bytewidth.mjs\");\n/* harmony import */ var _visitor_vectorctor__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ../visitor/vectorctor */ \"../../node_modules/apache-arrow/visitor/vectorctor.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/** @nocollapse */\n_vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new = newVector;\n/** @nocollapse */\n_vector__WEBPACK_IMPORTED_MODULE_0__.Vector.from = vectorFrom;\n/** @ignore */\nfunction newVector(data, ...args) {\n    return new (_visitor_vectorctor__WEBPACK_IMPORTED_MODULE_33__.instance.getVisitFn(data)())(data, ...args);\n}\n/** @ignore */\nfunction vectorFromValuesWithType(newDataType, input) {\n    if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_25__.isIterable)(input)) {\n        return _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.from({ 'nullValues': [null, undefined], type: newDataType(), 'values': input });\n    }\n    else if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_25__.isAsyncIterable)(input)) {\n        return _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.from({ 'nullValues': [null, undefined], type: newDataType(), 'values': input });\n    }\n    const { 'values': values = [], 'type': type = newDataType(), 'nullValues': nullValues = [null, undefined], } = { ...input };\n    return (0,_util_compat__WEBPACK_IMPORTED_MODULE_25__.isIterable)(values)\n        ? _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.from({ nullValues, ...input, type })\n        : _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.from({ nullValues, ...input, type });\n}\nfunction vectorFrom(input) {\n    const { 'values': values = [], ...options } = { 'nullValues': [null, undefined], ...input };\n    if ((0,_util_compat__WEBPACK_IMPORTED_MODULE_25__.isIterable)(values)) {\n        const chunks = [..._builder__WEBPACK_IMPORTED_MODULE_26__.Builder.throughIterable(options)(values)];\n        return (chunks.length === 1 ? chunks[0] : _chunked__WEBPACK_IMPORTED_MODULE_4__.Chunked.concat(chunks));\n    }\n    return (async (chunks) => {\n        const transform = _builder__WEBPACK_IMPORTED_MODULE_26__.Builder.throughAsyncIterable(options);\n        for await (const chunk of transform(values)) {\n            chunks.push(chunk);\n        }\n        return (chunks.length === 1 ? chunks[0] : _chunked__WEBPACK_IMPORTED_MODULE_4__.Chunked.concat(chunks));\n    })([]);\n}\n//\n// We provide the following method implementations for code navigability purposes only.\n// They're overridden at runtime below with the specific Visitor implementation for each type,\n// short-circuiting the usual Visitor traversal and reducing intermediate lookups and calls.\n// This comment is here to remind you to not set breakpoints in these function bodies, or to inform\n// you why the breakpoints you have already set are not being triggered. Have a great day!\n//\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype.get = function baseVectorGet(index) {\n    return _visitor_get__WEBPACK_IMPORTED_MODULE_27__.instance.visit(this, index);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype.set = function baseVectorSet(index, value) {\n    return _visitor_set__WEBPACK_IMPORTED_MODULE_28__.instance.visit(this, index, value);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype.indexOf = function baseVectorIndexOf(value, fromIndex) {\n    return _visitor_indexof__WEBPACK_IMPORTED_MODULE_29__.instance.visit(this, value, fromIndex);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype.toArray = function baseVectorToArray() {\n    return _visitor_toarray__WEBPACK_IMPORTED_MODULE_30__.instance.visit(this);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype.getByteWidth = function baseVectorGetByteWidth() {\n    return _visitor_bytewidth__WEBPACK_IMPORTED_MODULE_32__.instance.visit(this.type);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype[Symbol.iterator] = function baseVectorSymbolIterator() {\n    return _visitor_iterator__WEBPACK_IMPORTED_MODULE_31__.instance.visit(this);\n};\n_base__WEBPACK_IMPORTED_MODULE_1__.BaseVector.prototype._bindDataAccessors = bindBaseVectorDataAccessors;\n// Perf: bind and assign the operator Visitor methods to each of the Vector subclasses for each Type\nObject.keys(_enum__WEBPACK_IMPORTED_MODULE_23__.Type)\n    .map((T) => _enum__WEBPACK_IMPORTED_MODULE_23__.Type[T])\n    .filter((T) => typeof T === 'number')\n    .filter((typeId) => typeId !== _enum__WEBPACK_IMPORTED_MODULE_23__.Type.NONE)\n    .forEach((typeId) => {\n    const VectorCtor = _visitor_vectorctor__WEBPACK_IMPORTED_MODULE_33__.instance.visit(typeId);\n    VectorCtor.prototype['get'] = _util_fn__WEBPACK_IMPORTED_MODULE_22__.partial1(_visitor_get__WEBPACK_IMPORTED_MODULE_27__.instance.getVisitFn(typeId));\n    VectorCtor.prototype['set'] = _util_fn__WEBPACK_IMPORTED_MODULE_22__.partial2(_visitor_set__WEBPACK_IMPORTED_MODULE_28__.instance.getVisitFn(typeId));\n    VectorCtor.prototype['indexOf'] = _util_fn__WEBPACK_IMPORTED_MODULE_22__.partial2(_visitor_indexof__WEBPACK_IMPORTED_MODULE_29__.instance.getVisitFn(typeId));\n    VectorCtor.prototype['toArray'] = _util_fn__WEBPACK_IMPORTED_MODULE_22__.partial0(_visitor_toarray__WEBPACK_IMPORTED_MODULE_30__.instance.getVisitFn(typeId));\n    VectorCtor.prototype['getByteWidth'] = partialType0(_visitor_bytewidth__WEBPACK_IMPORTED_MODULE_32__.instance.getVisitFn(typeId));\n    VectorCtor.prototype[Symbol.iterator] = _util_fn__WEBPACK_IMPORTED_MODULE_22__.partial0(_visitor_iterator__WEBPACK_IMPORTED_MODULE_31__.instance.getVisitFn(typeId));\n});\n/** @ignore */\nfunction partialType0(visit) {\n    return function () { return visit(this.type); };\n}\n/** @ignore */\nfunction wrapNullableGet(fn) {\n    return function (i) { return this.isValid(i) ? fn.call(this, i) : null; };\n}\n/** @ignore */\nfunction wrapNullableSet(fn) {\n    return function (i, a) {\n        if ((0,_util_bit__WEBPACK_IMPORTED_MODULE_24__.setBool)(this.nullBitmap, this.offset + i, !(a === null || a === undefined))) {\n            fn.call(this, i, a);\n        }\n    };\n}\n/** @ignore */\nfunction bindBaseVectorDataAccessors() {\n    const nullBitmap = this.nullBitmap;\n    if (nullBitmap && nullBitmap.byteLength > 0) {\n        this.get = wrapNullableGet(this.get);\n        this.set = wrapNullableSet(this.set);\n    }\n}\n\n//# sourceMappingURL=index.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/index.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/int.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/int.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Int16Vector: () => (/* binding */ Int16Vector),\n/* harmony export */   Int32Vector: () => (/* binding */ Int32Vector),\n/* harmony export */   Int64Vector: () => (/* binding */ Int64Vector),\n/* harmony export */   Int8Vector: () => (/* binding */ Int8Vector),\n/* harmony export */   IntVector: () => (/* binding */ IntVector),\n/* harmony export */   Uint16Vector: () => (/* binding */ Uint16Vector),\n/* harmony export */   Uint32Vector: () => (/* binding */ Uint32Vector),\n/* harmony export */   Uint64Vector: () => (/* binding */ Uint64Vector),\n/* harmony export */   Uint8Vector: () => (/* binding */ Uint8Vector)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n/* harmony import */ var _util_compat__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/compat */ \"../../node_modules/apache-arrow/util/compat.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n/** @ignore */\nclass IntVector extends _base__WEBPACK_IMPORTED_MODULE_2__.BaseVector {\n    /** @nocollapse */\n    static from(...args) {\n        let [input, is64bit = false] = args;\n        let ArrowType = vectorTypeToDataType(this, is64bit);\n        if ((input instanceof ArrayBuffer) || ArrayBuffer.isView(input)) {\n            let InputType = arrayTypeToDataType(input.constructor, is64bit) || ArrowType;\n            // Special case, infer the Arrow DataType from the input if calling the base\n            // IntVector.from with a TypedArray, e.g. `IntVector.from(new Int32Array())`\n            if (ArrowType === null) {\n                ArrowType = InputType;\n            }\n            // If the DataType inferred from the Vector constructor matches the\n            // DataType inferred from the input arguments, return zero-copy view\n            if (ArrowType && ArrowType === InputType) {\n                let type = new ArrowType();\n                let length = input.byteLength / type.ArrayType.BYTES_PER_ELEMENT;\n                // If the ArrowType is 64bit but the input type is 32bit pairs, update the logical length\n                if (convert32To64Bit(ArrowType, input.constructor)) {\n                    length *= 0.5;\n                }\n                return _vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(_data__WEBPACK_IMPORTED_MODULE_0__.Data.Int(type, 0, length, 0, null, input));\n            }\n        }\n        if (ArrowType) {\n            // If the DataType inferred from the Vector constructor is different than\n            // the DataType inferred from the input TypedArray, or if input isn't a\n            // TypedArray, use the Builders to construct the result Vector\n            return (0,_index__WEBPACK_IMPORTED_MODULE_3__.vectorFromValuesWithType)(() => new ArrowType(), input);\n        }\n        if ((input instanceof DataView) || (input instanceof ArrayBuffer)) {\n            throw new TypeError(`Cannot infer integer type from instance of ${input.constructor.name}`);\n        }\n        throw new TypeError('Unrecognized IntVector input');\n    }\n}\n/** @ignore */\nclass Int8Vector extends IntVector {\n}\n/** @ignore */\nclass Int16Vector extends IntVector {\n}\n/** @ignore */\nclass Int32Vector extends IntVector {\n}\n/** @ignore */\nclass Int64Vector extends IntVector {\n    toBigInt64Array() {\n        return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_5__.toBigInt64Array)(this.values);\n    }\n    get values64() {\n        return this._values64 || (this._values64 = this.toBigInt64Array());\n    }\n}\n/** @ignore */\nclass Uint8Vector extends IntVector {\n}\n/** @ignore */\nclass Uint16Vector extends IntVector {\n}\n/** @ignore */\nclass Uint32Vector extends IntVector {\n}\n/** @ignore */\nclass Uint64Vector extends IntVector {\n    toBigUint64Array() {\n        return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_5__.toBigUint64Array)(this.values);\n    }\n    get values64() {\n        return this._values64 || (this._values64 = this.toBigUint64Array());\n    }\n}\nconst convert32To64Bit = (typeCtor, dataCtor) => {\n    return (typeCtor === _type__WEBPACK_IMPORTED_MODULE_6__.Int64 || typeCtor === _type__WEBPACK_IMPORTED_MODULE_6__.Uint64) &&\n        (dataCtor === Int32Array || dataCtor === Uint32Array);\n};\n/** @ignore */\nconst arrayTypeToDataType = (ctor, is64bit) => {\n    switch (ctor) {\n        case Int8Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Int8;\n        case Int16Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Int16;\n        case Int32Array: return is64bit ? _type__WEBPACK_IMPORTED_MODULE_6__.Int64 : _type__WEBPACK_IMPORTED_MODULE_6__.Int32;\n        case _util_compat__WEBPACK_IMPORTED_MODULE_4__.BigInt64Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Int64;\n        case Uint8Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint8;\n        case Uint16Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint16;\n        case Uint32Array: return is64bit ? _type__WEBPACK_IMPORTED_MODULE_6__.Uint64 : _type__WEBPACK_IMPORTED_MODULE_6__.Uint32;\n        case _util_compat__WEBPACK_IMPORTED_MODULE_4__.BigUint64Array: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint64;\n        default: return null;\n    }\n};\n/** @ignore */\nconst vectorTypeToDataType = (ctor, is64bit) => {\n    switch (ctor) {\n        case Int8Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Int8;\n        case Int16Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Int16;\n        case Int32Vector: return is64bit ? _type__WEBPACK_IMPORTED_MODULE_6__.Int64 : _type__WEBPACK_IMPORTED_MODULE_6__.Int32;\n        case Int64Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Int64;\n        case Uint8Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint8;\n        case Uint16Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint16;\n        case Uint32Vector: return is64bit ? _type__WEBPACK_IMPORTED_MODULE_6__.Uint64 : _type__WEBPACK_IMPORTED_MODULE_6__.Uint32;\n        case Uint64Vector: return _type__WEBPACK_IMPORTED_MODULE_6__.Uint64;\n        default: return null;\n    }\n};\n\n//# sourceMappingURL=int.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/int.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/interval.mjs":
/*!***********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/interval.mjs ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   IntervalDayTimeVector: () => (/* binding */ IntervalDayTimeVector),\n/* harmony export */   IntervalVector: () => (/* binding */ IntervalVector),\n/* harmony export */   IntervalYearMonthVector: () => (/* binding */ IntervalYearMonthVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass IntervalVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n/** @ignore */\nclass IntervalDayTimeVector extends IntervalVector {\n}\n/** @ignore */\nclass IntervalYearMonthVector extends IntervalVector {\n}\n\n//# sourceMappingURL=interval.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/interval.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/list.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/list.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ListVector: () => (/* binding */ ListVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass ListVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n\n//# sourceMappingURL=list.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/list.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/map.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/map.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MapVector: () => (/* binding */ MapVector)\n/* harmony export */ });\n/* harmony import */ var _row__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./row */ \"../../node_modules/apache-arrow/vector/row.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass MapVector extends _base__WEBPACK_IMPORTED_MODULE_2__.BaseVector {\n    asList() {\n        const child = this.type.children[0];\n        return _vector__WEBPACK_IMPORTED_MODULE_1__.Vector.new(this.data.clone(new _type__WEBPACK_IMPORTED_MODULE_3__.List(child)));\n    }\n    bind(index) {\n        const child = this.getChildAt(0);\n        const { [index]: begin, [index + 1]: end } = this.valueOffsets;\n        return new _row__WEBPACK_IMPORTED_MODULE_0__.MapRow(child.slice(begin, end));\n    }\n}\n\n//# sourceMappingURL=map.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/map.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/null.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/null.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   NullVector: () => (/* binding */ NullVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass NullVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n\n//# sourceMappingURL=null.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/null.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/row.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/row.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   MapRow: () => (/* binding */ MapRow),\n/* harmony export */   StructRow: () => (/* binding */ StructRow)\n/* harmony export */ });\n/* harmony import */ var _util_pretty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/pretty */ \"../../node_modules/apache-arrow/util/pretty.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */ const kParent = Symbol.for('parent');\n/** @ignore */ const kRowIndex = Symbol.for('rowIndex');\n/** @ignore */ const kKeyToIdx = Symbol.for('keyToIdx');\n/** @ignore */ const kIdxToVal = Symbol.for('idxToVal');\n/** @ignore */ const kCustomInspect = Symbol.for('nodejs.util.inspect.custom');\nclass Row {\n    constructor(parent, numKeys) {\n        this[kParent] = parent;\n        this.size = numKeys;\n    }\n    entries() { return this[Symbol.iterator](); }\n    has(key) { return this.get(key) !== undefined; }\n    get(key) {\n        let val = undefined;\n        if (key !== null && key !== undefined) {\n            const ktoi = this[kKeyToIdx] || (this[kKeyToIdx] = new Map());\n            let idx = ktoi.get(key);\n            if (idx !== undefined) {\n                const itov = this[kIdxToVal] || (this[kIdxToVal] = new Array(this.size));\n                ((val = itov[idx]) !== undefined) || (itov[idx] = val = this.getValue(idx));\n            }\n            else if ((idx = this.getIndex(key)) > -1) {\n                ktoi.set(key, idx);\n                const itov = this[kIdxToVal] || (this[kIdxToVal] = new Array(this.size));\n                ((val = itov[idx]) !== undefined) || (itov[idx] = val = this.getValue(idx));\n            }\n        }\n        return val;\n    }\n    set(key, val) {\n        if (key !== null && key !== undefined) {\n            const ktoi = this[kKeyToIdx] || (this[kKeyToIdx] = new Map());\n            let idx = ktoi.get(key);\n            if (idx === undefined) {\n                ktoi.set(key, idx = this.getIndex(key));\n            }\n            if (idx > -1) {\n                const itov = this[kIdxToVal] || (this[kIdxToVal] = new Array(this.size));\n                itov[idx] = this.setValue(idx, val);\n            }\n        }\n        return this;\n    }\n    clear() { throw new Error(`Clearing ${this[Symbol.toStringTag]} not supported.`); }\n    delete(_) { throw new Error(`Deleting ${this[Symbol.toStringTag]} values not supported.`); }\n    *[Symbol.iterator]() {\n        const ki = this.keys();\n        const vi = this.values();\n        const ktoi = this[kKeyToIdx] || (this[kKeyToIdx] = new Map());\n        const itov = this[kIdxToVal] || (this[kIdxToVal] = new Array(this.size));\n        for (let k, v, i = 0, kr, vr; !((kr = ki.next()).done || (vr = vi.next()).done); ++i) {\n            k = kr.value;\n            v = vr.value;\n            itov[i] = v;\n            ktoi.has(k) || ktoi.set(k, i);\n            yield [k, v];\n        }\n    }\n    forEach(callbackfn, thisArg) {\n        const ki = this.keys();\n        const vi = this.values();\n        const callback = thisArg === undefined ? callbackfn :\n            (v, k, m) => callbackfn.call(thisArg, v, k, m);\n        const ktoi = this[kKeyToIdx] || (this[kKeyToIdx] = new Map());\n        const itov = this[kIdxToVal] || (this[kIdxToVal] = new Array(this.size));\n        for (let k, v, i = 0, kr, vr; !((kr = ki.next()).done || (vr = vi.next()).done); ++i) {\n            k = kr.value;\n            v = vr.value;\n            itov[i] = v;\n            ktoi.has(k) || ktoi.set(k, i);\n            callback(v, k, this);\n        }\n    }\n    toArray() { return [...this.values()]; }\n    toJSON() {\n        const obj = {};\n        this.forEach((val, key) => obj[key] = val);\n        return obj;\n    }\n    inspect() { return this.toString(); }\n    [kCustomInspect]() { return this.toString(); }\n    toString() {\n        const str = [];\n        this.forEach((val, key) => {\n            key = (0,_util_pretty__WEBPACK_IMPORTED_MODULE_0__.valueToString)(key);\n            val = (0,_util_pretty__WEBPACK_IMPORTED_MODULE_0__.valueToString)(val);\n            str.push(`${key}: ${val}`);\n        });\n        return `{ ${str.join(', ')} }`;\n    }\n}\nRow[Symbol.toStringTag] = ((proto) => {\n    Object.defineProperties(proto, {\n        'size': { writable: true, enumerable: false, configurable: false, value: 0 },\n        [kParent]: { writable: true, enumerable: false, configurable: false, value: null },\n        [kRowIndex]: { writable: true, enumerable: false, configurable: false, value: -1 },\n    });\n    return proto[Symbol.toStringTag] = 'Row';\n})(Row.prototype);\nclass MapRow extends Row {\n    constructor(slice) {\n        super(slice, slice.length);\n        return createRowProxy(this);\n    }\n    keys() {\n        return this[kParent].getChildAt(0)[Symbol.iterator]();\n    }\n    values() {\n        return this[kParent].getChildAt(1)[Symbol.iterator]();\n    }\n    getKey(idx) {\n        return this[kParent].getChildAt(0).get(idx);\n    }\n    getIndex(key) {\n        return this[kParent].getChildAt(0).indexOf(key);\n    }\n    getValue(index) {\n        return this[kParent].getChildAt(1).get(index);\n    }\n    setValue(index, value) {\n        this[kParent].getChildAt(1).set(index, value);\n    }\n}\nclass StructRow extends Row {\n    constructor(parent) {\n        super(parent, parent.type.children.length);\n        return defineRowProxyProperties(this);\n    }\n    *keys() {\n        for (const field of this[kParent].type.children) {\n            yield field.name;\n        }\n    }\n    *values() {\n        for (const field of this[kParent].type.children) {\n            yield this[field.name];\n        }\n    }\n    getKey(idx) {\n        return this[kParent].type.children[idx].name;\n    }\n    getIndex(key) {\n        return this[kParent].type.children.findIndex((f) => f.name === key);\n    }\n    getValue(index) {\n        return this[kParent].getChildAt(index).get(this[kRowIndex]);\n    }\n    setValue(index, value) {\n        return this[kParent].getChildAt(index).set(this[kRowIndex], value);\n    }\n}\nObject.setPrototypeOf(Row.prototype, Map.prototype);\n/** @ignore */\nconst defineRowProxyProperties = (() => {\n    const desc = { enumerable: true, configurable: false, get: null, set: null };\n    return (row) => {\n        let idx = -1, ktoi = row[kKeyToIdx] || (row[kKeyToIdx] = new Map());\n        const getter = (key) => function () { return this.get(key); };\n        const setter = (key) => function (val) { return this.set(key, val); };\n        for (const key of row.keys()) {\n            ktoi.set(key, ++idx);\n            desc.get = getter(key);\n            desc.set = setter(key);\n            row.hasOwnProperty(key) || (desc.enumerable = true, Object.defineProperty(row, key, desc));\n            row.hasOwnProperty(idx) || (desc.enumerable = false, Object.defineProperty(row, idx, desc));\n        }\n        desc.get = desc.set = null;\n        return row;\n    };\n})();\n/** @ignore */\nconst createRowProxy = (() => {\n    if (typeof Proxy === 'undefined') {\n        return defineRowProxyProperties;\n    }\n    const has = Row.prototype.has;\n    const get = Row.prototype.get;\n    const set = Row.prototype.set;\n    const getKey = Row.prototype.getKey;\n    const RowProxyHandler = {\n        isExtensible() { return false; },\n        deleteProperty() { return false; },\n        preventExtensions() { return true; },\n        ownKeys(row) { return [...row.keys()].map((x) => `${x}`); },\n        has(row, key) {\n            switch (key) {\n                case 'getKey':\n                case 'getIndex':\n                case 'getValue':\n                case 'setValue':\n                case 'toArray':\n                case 'toJSON':\n                case 'inspect':\n                case 'constructor':\n                case 'isPrototypeOf':\n                case 'propertyIsEnumerable':\n                case 'toString':\n                case 'toLocaleString':\n                case 'valueOf':\n                case 'size':\n                case 'has':\n                case 'get':\n                case 'set':\n                case 'clear':\n                case 'delete':\n                case 'keys':\n                case 'values':\n                case 'entries':\n                case 'forEach':\n                case '__proto__':\n                case '__defineGetter__':\n                case '__defineSetter__':\n                case 'hasOwnProperty':\n                case '__lookupGetter__':\n                case '__lookupSetter__':\n                case Symbol.iterator:\n                case Symbol.toStringTag:\n                case kParent:\n                case kRowIndex:\n                case kIdxToVal:\n                case kKeyToIdx:\n                case kCustomInspect:\n                    return true;\n            }\n            if (typeof key === 'number' && !row.has(key)) {\n                key = row.getKey(key);\n            }\n            return row.has(key);\n        },\n        get(row, key, receiver) {\n            switch (key) {\n                case 'getKey':\n                case 'getIndex':\n                case 'getValue':\n                case 'setValue':\n                case 'toArray':\n                case 'toJSON':\n                case 'inspect':\n                case 'constructor':\n                case 'isPrototypeOf':\n                case 'propertyIsEnumerable':\n                case 'toString':\n                case 'toLocaleString':\n                case 'valueOf':\n                case 'size':\n                case 'has':\n                case 'get':\n                case 'set':\n                case 'clear':\n                case 'delete':\n                case 'keys':\n                case 'values':\n                case 'entries':\n                case 'forEach':\n                case '__proto__':\n                case '__defineGetter__':\n                case '__defineSetter__':\n                case 'hasOwnProperty':\n                case '__lookupGetter__':\n                case '__lookupSetter__':\n                case Symbol.iterator:\n                case Symbol.toStringTag:\n                case kParent:\n                case kRowIndex:\n                case kIdxToVal:\n                case kKeyToIdx:\n                case kCustomInspect:\n                    return Reflect.get(row, key, receiver);\n            }\n            if (typeof key === 'number' && !has.call(receiver, key)) {\n                key = getKey.call(receiver, key);\n            }\n            return get.call(receiver, key);\n        },\n        set(row, key, val, receiver) {\n            switch (key) {\n                case kParent:\n                case kRowIndex:\n                case kIdxToVal:\n                case kKeyToIdx:\n                    return Reflect.set(row, key, val, receiver);\n                case 'getKey':\n                case 'getIndex':\n                case 'getValue':\n                case 'setValue':\n                case 'toArray':\n                case 'toJSON':\n                case 'inspect':\n                case 'constructor':\n                case 'isPrototypeOf':\n                case 'propertyIsEnumerable':\n                case 'toString':\n                case 'toLocaleString':\n                case 'valueOf':\n                case 'size':\n                case 'has':\n                case 'get':\n                case 'set':\n                case 'clear':\n                case 'delete':\n                case 'keys':\n                case 'values':\n                case 'entries':\n                case 'forEach':\n                case '__proto__':\n                case '__defineGetter__':\n                case '__defineSetter__':\n                case 'hasOwnProperty':\n                case '__lookupGetter__':\n                case '__lookupSetter__':\n                case Symbol.iterator:\n                case Symbol.toStringTag:\n                    return false;\n            }\n            if (typeof key === 'number' && !has.call(receiver, key)) {\n                key = getKey.call(receiver, key);\n            }\n            return has.call(receiver, key) ? !!set.call(receiver, key, val) : false;\n        },\n    };\n    return (row) => new Proxy(row, RowProxyHandler);\n})();\n\n//# sourceMappingURL=row.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/row.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/struct.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/struct.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   StructVector: () => (/* binding */ StructVector)\n/* harmony export */ });\n/* harmony import */ var _row__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./row */ \"../../node_modules/apache-arrow/vector/row.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */ const kRowIndex = Symbol.for('rowIndex');\n/** @ignore */\nclass StructVector extends _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector {\n    bind(index) {\n        const proto = this._row || (this._row = new _row__WEBPACK_IMPORTED_MODULE_0__.StructRow(this));\n        const bound = Object.create(proto);\n        bound[kRowIndex] = index;\n        return bound;\n    }\n}\n\n//# sourceMappingURL=struct.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/struct.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/time.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/time.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TimeMicrosecondVector: () => (/* binding */ TimeMicrosecondVector),\n/* harmony export */   TimeMillisecondVector: () => (/* binding */ TimeMillisecondVector),\n/* harmony export */   TimeNanosecondVector: () => (/* binding */ TimeNanosecondVector),\n/* harmony export */   TimeSecondVector: () => (/* binding */ TimeSecondVector),\n/* harmony export */   TimeVector: () => (/* binding */ TimeVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass TimeVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n/** @ignore */\nclass TimeSecondVector extends TimeVector {\n}\n/** @ignore */\nclass TimeMillisecondVector extends TimeVector {\n}\n/** @ignore */\nclass TimeMicrosecondVector extends TimeVector {\n}\n/** @ignore */\nclass TimeNanosecondVector extends TimeVector {\n}\n\n//# sourceMappingURL=time.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/time.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/timestamp.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/timestamp.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TimestampMicrosecondVector: () => (/* binding */ TimestampMicrosecondVector),\n/* harmony export */   TimestampMillisecondVector: () => (/* binding */ TimestampMillisecondVector),\n/* harmony export */   TimestampNanosecondVector: () => (/* binding */ TimestampNanosecondVector),\n/* harmony export */   TimestampSecondVector: () => (/* binding */ TimestampSecondVector),\n/* harmony export */   TimestampVector: () => (/* binding */ TimestampVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass TimestampVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n}\n/** @ignore */\nclass TimestampSecondVector extends TimestampVector {\n}\n/** @ignore */\nclass TimestampMillisecondVector extends TimestampVector {\n}\n/** @ignore */\nclass TimestampMicrosecondVector extends TimestampVector {\n}\n/** @ignore */\nclass TimestampNanosecondVector extends TimestampVector {\n}\n\n//# sourceMappingURL=timestamp.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/timestamp.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/union.mjs":
/*!********************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/union.mjs ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   DenseUnionVector: () => (/* binding */ DenseUnionVector),\n/* harmony export */   SparseUnionVector: () => (/* binding */ SparseUnionVector),\n/* harmony export */   UnionVector: () => (/* binding */ UnionVector)\n/* harmony export */ });\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass UnionVector extends _base__WEBPACK_IMPORTED_MODULE_0__.BaseVector {\n    get typeIdToChildIndex() { return this.data.type.typeIdToChildIndex; }\n}\n/** @ignore */\nclass DenseUnionVector extends UnionVector {\n    get valueOffsets() { return this.data.valueOffsets; }\n}\n/** @ignore */\nclass SparseUnionVector extends UnionVector {\n}\n\n//# sourceMappingURL=union.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/union.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/vector/utf8.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/vector/utf8.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Utf8Vector: () => (/* binding */ Utf8Vector)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./base */ \"../../node_modules/apache-arrow/vector/base.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./index */ \"../../node_modules/apache-arrow/vector/index.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass Utf8Vector extends _base__WEBPACK_IMPORTED_MODULE_1__.BaseVector {\n    /** @nocollapse */\n    static from(input) {\n        return (0,_index__WEBPACK_IMPORTED_MODULE_3__.vectorFromValuesWithType)(() => new _type__WEBPACK_IMPORTED_MODULE_2__.Utf8(), input);\n    }\n    asBinary() {\n        return _vector__WEBPACK_IMPORTED_MODULE_0__.Vector.new(this.data.clone(new _type__WEBPACK_IMPORTED_MODULE_2__.Binary()));\n    }\n}\n\n//# sourceMappingURL=utf8.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/vector/utf8.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor.mjs":
/*!***************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor.mjs ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Visitor: () => (/* binding */ Visitor)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\nclass Visitor {\n    visitMany(nodes, ...args) {\n        return nodes.map((node, i) => this.visit(node, ...args.map((x) => x[i])));\n    }\n    visit(...args) {\n        return this.getVisitFn(args[0], false).apply(this, args);\n    }\n    getVisitFn(node, throwIfNotFound = true) {\n        return getVisitFn(this, node, throwIfNotFound);\n    }\n    visitNull(_node, ..._args) { return null; }\n    visitBool(_node, ..._args) { return null; }\n    visitInt(_node, ..._args) { return null; }\n    visitFloat(_node, ..._args) { return null; }\n    visitUtf8(_node, ..._args) { return null; }\n    visitBinary(_node, ..._args) { return null; }\n    visitFixedSizeBinary(_node, ..._args) { return null; }\n    visitDate(_node, ..._args) { return null; }\n    visitTimestamp(_node, ..._args) { return null; }\n    visitTime(_node, ..._args) { return null; }\n    visitDecimal(_node, ..._args) { return null; }\n    visitList(_node, ..._args) { return null; }\n    visitStruct(_node, ..._args) { return null; }\n    visitUnion(_node, ..._args) { return null; }\n    visitDictionary(_node, ..._args) { return null; }\n    visitInterval(_node, ..._args) { return null; }\n    visitFixedSizeList(_node, ..._args) { return null; }\n    visitMap(_node, ..._args) { return null; }\n}\n/** @ignore */\nfunction getVisitFn(visitor, node, throwIfNotFound = true) {\n    let fn = null;\n    let dtype = _enum__WEBPACK_IMPORTED_MODULE_2__.Type.NONE;\n    // tslint:disable\n    if (node instanceof _data__WEBPACK_IMPORTED_MODULE_0__.Data) {\n        dtype = inferDType(node.type);\n    }\n    else if (node instanceof _vector__WEBPACK_IMPORTED_MODULE_1__.Vector) {\n        dtype = inferDType(node.type);\n    }\n    else if (node instanceof _type__WEBPACK_IMPORTED_MODULE_3__.DataType) {\n        dtype = inferDType(node);\n    }\n    else if (typeof (dtype = node) !== 'number') {\n        dtype = _enum__WEBPACK_IMPORTED_MODULE_2__.Type[node];\n    }\n    switch (dtype) {\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Null:\n            fn = visitor.visitNull;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Bool:\n            fn = visitor.visitBool;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int:\n            fn = visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int8:\n            fn = visitor.visitInt8 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int16:\n            fn = visitor.visitInt16 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int32:\n            fn = visitor.visitInt32 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int64:\n            fn = visitor.visitInt64 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint8:\n            fn = visitor.visitUint8 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint16:\n            fn = visitor.visitUint16 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint32:\n            fn = visitor.visitUint32 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint64:\n            fn = visitor.visitUint64 || visitor.visitInt;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float:\n            fn = visitor.visitFloat;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float16:\n            fn = visitor.visitFloat16 || visitor.visitFloat;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float32:\n            fn = visitor.visitFloat32 || visitor.visitFloat;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float64:\n            fn = visitor.visitFloat64 || visitor.visitFloat;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Utf8:\n            fn = visitor.visitUtf8;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Binary:\n            fn = visitor.visitBinary;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeBinary:\n            fn = visitor.visitFixedSizeBinary;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Date:\n            fn = visitor.visitDate;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DateDay:\n            fn = visitor.visitDateDay || visitor.visitDate;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DateMillisecond:\n            fn = visitor.visitDateMillisecond || visitor.visitDate;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Timestamp:\n            fn = visitor.visitTimestamp;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampSecond:\n            fn = visitor.visitTimestampSecond || visitor.visitTimestamp;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampMillisecond:\n            fn = visitor.visitTimestampMillisecond || visitor.visitTimestamp;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampMicrosecond:\n            fn = visitor.visitTimestampMicrosecond || visitor.visitTimestamp;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampNanosecond:\n            fn = visitor.visitTimestampNanosecond || visitor.visitTimestamp;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Time:\n            fn = visitor.visitTime;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeSecond:\n            fn = visitor.visitTimeSecond || visitor.visitTime;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeMillisecond:\n            fn = visitor.visitTimeMillisecond || visitor.visitTime;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeMicrosecond:\n            fn = visitor.visitTimeMicrosecond || visitor.visitTime;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeNanosecond:\n            fn = visitor.visitTimeNanosecond || visitor.visitTime;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Decimal:\n            fn = visitor.visitDecimal;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.List:\n            fn = visitor.visitList;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Struct:\n            fn = visitor.visitStruct;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Union:\n            fn = visitor.visitUnion;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DenseUnion:\n            fn = visitor.visitDenseUnion || visitor.visitUnion;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.SparseUnion:\n            fn = visitor.visitSparseUnion || visitor.visitUnion;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Dictionary:\n            fn = visitor.visitDictionary;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Interval:\n            fn = visitor.visitInterval;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.IntervalDayTime:\n            fn = visitor.visitIntervalDayTime || visitor.visitInterval;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.IntervalYearMonth:\n            fn = visitor.visitIntervalYearMonth || visitor.visitInterval;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeList:\n            fn = visitor.visitFixedSizeList;\n            break;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Map:\n            fn = visitor.visitMap;\n            break;\n    }\n    if (typeof fn === 'function')\n        return fn;\n    if (!throwIfNotFound)\n        return () => null;\n    throw new Error(`Unrecognized type '${_enum__WEBPACK_IMPORTED_MODULE_2__.Type[dtype]}'`);\n}\n/** @ignore */\nfunction inferDType(type) {\n    switch (type.typeId) {\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Null: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Null;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int:\n            const { bitWidth, isSigned } = type;\n            switch (bitWidth) {\n                case 8: return isSigned ? _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int8 : _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint8;\n                case 16: return isSigned ? _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int16 : _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint16;\n                case 32: return isSigned ? _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int32 : _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint32;\n                case 64: return isSigned ? _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int64 : _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Uint64;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Int;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float:\n            switch (type.precision) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.Precision.HALF: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float16;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.Precision.SINGLE: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float32;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.Precision.DOUBLE: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float64;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Float;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Binary: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Binary;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Utf8: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Utf8;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Bool: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Bool;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Decimal: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Decimal;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Time:\n            switch (type.unit) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.SECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeSecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.MILLISECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeMillisecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.MICROSECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeMicrosecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.NANOSECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimeNanosecond;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Time;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Timestamp:\n            switch (type.unit) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.SECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampSecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.MILLISECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampMillisecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.MICROSECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampMicrosecond;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.TimeUnit.NANOSECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.TimestampNanosecond;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Timestamp;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Date:\n            switch (type.unit) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.DateUnit.DAY: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DateDay;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.DateUnit.MILLISECOND: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DateMillisecond;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Date;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Interval:\n            switch (type.unit) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.IntervalUnit.DAY_TIME: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.IntervalDayTime;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.IntervalUnit.YEAR_MONTH: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.IntervalYearMonth;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Interval;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Map: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Map;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.List: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.List;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Struct: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Struct;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Union:\n            switch (type.mode) {\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.UnionMode.Dense: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.DenseUnion;\n                case _enum__WEBPACK_IMPORTED_MODULE_2__.UnionMode.Sparse: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.SparseUnion;\n            }\n            // @ts-ignore\n            return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Union;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeBinary: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeBinary;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeList: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.FixedSizeList;\n        case _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Dictionary: return _enum__WEBPACK_IMPORTED_MODULE_2__.Type.Dictionary;\n    }\n    throw new Error(`Unrecognized type '${_enum__WEBPACK_IMPORTED_MODULE_2__.Type[type.typeId]}'`);\n}\n// Add these here so they're picked up by the externs creator\n// in the build, and closure-compiler doesn't minify them away\nVisitor.prototype.visitInt8 = null;\nVisitor.prototype.visitInt16 = null;\nVisitor.prototype.visitInt32 = null;\nVisitor.prototype.visitInt64 = null;\nVisitor.prototype.visitUint8 = null;\nVisitor.prototype.visitUint16 = null;\nVisitor.prototype.visitUint32 = null;\nVisitor.prototype.visitUint64 = null;\nVisitor.prototype.visitFloat16 = null;\nVisitor.prototype.visitFloat32 = null;\nVisitor.prototype.visitFloat64 = null;\nVisitor.prototype.visitDateDay = null;\nVisitor.prototype.visitDateMillisecond = null;\nVisitor.prototype.visitTimestampSecond = null;\nVisitor.prototype.visitTimestampMillisecond = null;\nVisitor.prototype.visitTimestampMicrosecond = null;\nVisitor.prototype.visitTimestampNanosecond = null;\nVisitor.prototype.visitTimeSecond = null;\nVisitor.prototype.visitTimeMillisecond = null;\nVisitor.prototype.visitTimeMicrosecond = null;\nVisitor.prototype.visitTimeNanosecond = null;\nVisitor.prototype.visitDenseUnion = null;\nVisitor.prototype.visitSparseUnion = null;\nVisitor.prototype.visitIntervalDayTime = null;\nVisitor.prototype.visitIntervalYearMonth = null;\n\n//# sourceMappingURL=visitor.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/builderctor.mjs":
/*!***************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/builderctor.mjs ***!
  \***************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GetBuilderCtor: () => (/* binding */ GetBuilderCtor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _builder_binary__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../builder/binary */ \"../../node_modules/apache-arrow/builder/binary.mjs\");\n/* harmony import */ var _builder_bool__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../builder/bool */ \"../../node_modules/apache-arrow/builder/bool.mjs\");\n/* harmony import */ var _builder_date__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../builder/date */ \"../../node_modules/apache-arrow/builder/date.mjs\");\n/* harmony import */ var _builder_decimal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../builder/decimal */ \"../../node_modules/apache-arrow/builder/decimal.mjs\");\n/* harmony import */ var _builder_dictionary__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../builder/dictionary */ \"../../node_modules/apache-arrow/builder/dictionary.mjs\");\n/* harmony import */ var _builder_fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../builder/fixedsizebinary */ \"../../node_modules/apache-arrow/builder/fixedsizebinary.mjs\");\n/* harmony import */ var _builder_fixedsizelist__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../builder/fixedsizelist */ \"../../node_modules/apache-arrow/builder/fixedsizelist.mjs\");\n/* harmony import */ var _builder_float__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../builder/float */ \"../../node_modules/apache-arrow/builder/float.mjs\");\n/* harmony import */ var _builder_interval__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../builder/interval */ \"../../node_modules/apache-arrow/builder/interval.mjs\");\n/* harmony import */ var _builder_int__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../builder/int */ \"../../node_modules/apache-arrow/builder/int.mjs\");\n/* harmony import */ var _builder_list__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../builder/list */ \"../../node_modules/apache-arrow/builder/list.mjs\");\n/* harmony import */ var _builder_map__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../builder/map */ \"../../node_modules/apache-arrow/builder/map.mjs\");\n/* harmony import */ var _builder_null__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../builder/null */ \"../../node_modules/apache-arrow/builder/null.mjs\");\n/* harmony import */ var _builder_struct__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../builder/struct */ \"../../node_modules/apache-arrow/builder/struct.mjs\");\n/* harmony import */ var _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../builder/timestamp */ \"../../node_modules/apache-arrow/builder/timestamp.mjs\");\n/* harmony import */ var _builder_time__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../builder/time */ \"../../node_modules/apache-arrow/builder/time.mjs\");\n/* harmony import */ var _builder_union__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../builder/union */ \"../../node_modules/apache-arrow/builder/union.mjs\");\n/* harmony import */ var _builder_utf8__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../builder/utf8 */ \"../../node_modules/apache-arrow/builder/utf8.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/** @ignore */\nclass GetBuilderCtor extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    visitNull() { return _builder_null__WEBPACK_IMPORTED_MODULE_13__.NullBuilder; }\n    visitBool() { return _builder_bool__WEBPACK_IMPORTED_MODULE_2__.BoolBuilder; }\n    visitInt() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.IntBuilder; }\n    visitInt8() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Int8Builder; }\n    visitInt16() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Int16Builder; }\n    visitInt32() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Int32Builder; }\n    visitInt64() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Int64Builder; }\n    visitUint8() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Uint8Builder; }\n    visitUint16() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Uint16Builder; }\n    visitUint32() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Uint32Builder; }\n    visitUint64() { return _builder_int__WEBPACK_IMPORTED_MODULE_10__.Uint64Builder; }\n    visitFloat() { return _builder_float__WEBPACK_IMPORTED_MODULE_8__.FloatBuilder; }\n    visitFloat16() { return _builder_float__WEBPACK_IMPORTED_MODULE_8__.Float16Builder; }\n    visitFloat32() { return _builder_float__WEBPACK_IMPORTED_MODULE_8__.Float32Builder; }\n    visitFloat64() { return _builder_float__WEBPACK_IMPORTED_MODULE_8__.Float64Builder; }\n    visitUtf8() { return _builder_utf8__WEBPACK_IMPORTED_MODULE_18__.Utf8Builder; }\n    visitBinary() { return _builder_binary__WEBPACK_IMPORTED_MODULE_1__.BinaryBuilder; }\n    visitFixedSizeBinary() { return _builder_fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__.FixedSizeBinaryBuilder; }\n    visitDate() { return _builder_date__WEBPACK_IMPORTED_MODULE_3__.DateBuilder; }\n    visitDateDay() { return _builder_date__WEBPACK_IMPORTED_MODULE_3__.DateDayBuilder; }\n    visitDateMillisecond() { return _builder_date__WEBPACK_IMPORTED_MODULE_3__.DateMillisecondBuilder; }\n    visitTimestamp() { return _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampBuilder; }\n    visitTimestampSecond() { return _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampSecondBuilder; }\n    visitTimestampMillisecond() { return _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampMillisecondBuilder; }\n    visitTimestampMicrosecond() { return _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampMicrosecondBuilder; }\n    visitTimestampNanosecond() { return _builder_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampNanosecondBuilder; }\n    visitTime() { return _builder_time__WEBPACK_IMPORTED_MODULE_16__.TimeBuilder; }\n    visitTimeSecond() { return _builder_time__WEBPACK_IMPORTED_MODULE_16__.TimeSecondBuilder; }\n    visitTimeMillisecond() { return _builder_time__WEBPACK_IMPORTED_MODULE_16__.TimeMillisecondBuilder; }\n    visitTimeMicrosecond() { return _builder_time__WEBPACK_IMPORTED_MODULE_16__.TimeMicrosecondBuilder; }\n    visitTimeNanosecond() { return _builder_time__WEBPACK_IMPORTED_MODULE_16__.TimeNanosecondBuilder; }\n    visitDecimal() { return _builder_decimal__WEBPACK_IMPORTED_MODULE_4__.DecimalBuilder; }\n    visitList() { return _builder_list__WEBPACK_IMPORTED_MODULE_11__.ListBuilder; }\n    visitStruct() { return _builder_struct__WEBPACK_IMPORTED_MODULE_14__.StructBuilder; }\n    visitUnion() { return _builder_union__WEBPACK_IMPORTED_MODULE_17__.UnionBuilder; }\n    visitDenseUnion() { return _builder_union__WEBPACK_IMPORTED_MODULE_17__.DenseUnionBuilder; }\n    visitSparseUnion() { return _builder_union__WEBPACK_IMPORTED_MODULE_17__.SparseUnionBuilder; }\n    visitDictionary() { return _builder_dictionary__WEBPACK_IMPORTED_MODULE_5__.DictionaryBuilder; }\n    visitInterval() { return _builder_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalBuilder; }\n    visitIntervalDayTime() { return _builder_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalDayTimeBuilder; }\n    visitIntervalYearMonth() { return _builder_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalYearMonthBuilder; }\n    visitFixedSizeList() { return _builder_fixedsizelist__WEBPACK_IMPORTED_MODULE_7__.FixedSizeListBuilder; }\n    visitMap() { return _builder_map__WEBPACK_IMPORTED_MODULE_12__.MapBuilder; }\n}\n/** @ignore */\nconst instance = new GetBuilderCtor();\n\n//# sourceMappingURL=builderctor.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/builderctor.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/bytewidth.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/bytewidth.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ByteWidthVisitor: () => (/* binding */ ByteWidthVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* istanbul ignore file */\n\n\n/** @ignore */ const sum = (x, y) => x + y;\n/** @ignore */ const variableWidthColumnErrorMessage = (type) => `Cannot compute the byte width of variable-width column ${type}`;\n/** @ignore */\nclass ByteWidthVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    visitNull(____) { return 0; }\n    visitInt(type) { return type.bitWidth / 8; }\n    visitFloat(type) { return type.ArrayType.BYTES_PER_ELEMENT; }\n    visitBinary(type) { throw new Error(variableWidthColumnErrorMessage(type)); }\n    visitUtf8(type) { throw new Error(variableWidthColumnErrorMessage(type)); }\n    visitBool(____) { return 1 / 8; }\n    visitDecimal(____) { return 16; }\n    visitDate(type) { return (type.unit + 1) * 4; }\n    visitTime(type) { return type.bitWidth / 8; }\n    visitTimestamp(type) { return type.unit === _enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit.SECOND ? 4 : 8; }\n    visitInterval(type) { return (type.unit + 1) * 4; }\n    visitList(type) { throw new Error(variableWidthColumnErrorMessage(type)); }\n    visitStruct(type) { return this.visitFields(type.children).reduce(sum, 0); }\n    visitUnion(type) { return this.visitFields(type.children).reduce(sum, 0); }\n    visitFixedSizeBinary(type) { return type.byteWidth; }\n    visitFixedSizeList(type) { return type.listSize * this.visitFields(type.children).reduce(sum, 0); }\n    visitMap(type) { return this.visitFields(type.children).reduce(sum, 0); }\n    visitDictionary(type) { return this.visit(type.indices); }\n    visitFields(fields) { return (fields || []).map((field) => this.visit(field.type)); }\n    visitSchema(schema) { return this.visitFields(schema.fields).reduce(sum, 0); }\n}\n/** @ignore */\nconst instance = new ByteWidthVisitor();\n\n//# sourceMappingURL=bytewidth.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/bytewidth.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/get.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/get.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GetVisitor: () => (/* binding */ GetVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _util_bn__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/bn */ \"../../node_modules/apache-arrow/util/bn.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _util_math__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/math */ \"../../node_modules/apache-arrow/util/math.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n/** @ignore */\nclass GetVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_1__.Visitor {\n}\n/** @ignore */ const epochDaysToMs = (data, index) => 86400000 * data[index];\n/** @ignore */ const epochMillisecondsLongToMs = (data, index) => 4294967296 * (data[index + 1]) + (data[index] >>> 0);\n/** @ignore */ const epochMicrosecondsLongToMs = (data, index) => 4294967296 * (data[index + 1] / 1000) + ((data[index] >>> 0) / 1000);\n/** @ignore */ const epochNanosecondsLongToMs = (data, index) => 4294967296 * (data[index + 1] / 1000000) + ((data[index] >>> 0) / 1000000);\n/** @ignore */ const epochMillisecondsToDate = (epochMs) => new Date(epochMs);\n/** @ignore */ const epochDaysToDate = (data, index) => epochMillisecondsToDate(epochDaysToMs(data, index));\n/** @ignore */ const epochMillisecondsLongToDate = (data, index) => epochMillisecondsToDate(epochMillisecondsLongToMs(data, index));\n/** @ignore */\nconst getNull = (_vector, _index) => null;\n/** @ignore */\nconst getVariableWidthBytes = (values, valueOffsets, index) => {\n    const { [index]: x, [index + 1]: y } = valueOffsets;\n    return x != null && y != null ? values.subarray(x, y) : null;\n};\n/** @ignore */\nconst getBool = ({ offset, values }, index) => {\n    const idx = offset + index;\n    const byte = values[idx >> 3];\n    return (byte & 1 << (idx % 8)) !== 0;\n};\n/** @ignore */\nconst getDateDay = ({ values }, index) => epochDaysToDate(values, index);\n/** @ignore */\nconst getDateMillisecond = ({ values }, index) => epochMillisecondsLongToDate(values, index * 2);\n/** @ignore */\nconst getNumeric = ({ stride, values }, index) => values[stride * index];\n/** @ignore */\nconst getFloat16 = ({ stride, values }, index) => (0,_util_math__WEBPACK_IMPORTED_MODULE_3__.uint16ToFloat64)(values[stride * index]);\n/** @ignore */\nconst getBigInts = ({ stride, values, type }, index) => _util_bn__WEBPACK_IMPORTED_MODULE_0__.BN.new(values.subarray(stride * index, stride * (index + 1)), type.isSigned);\n/** @ignore */\nconst getFixedSizeBinary = ({ stride, values }, index) => values.subarray(stride * index, stride * (index + 1));\n/** @ignore */\nconst getBinary = ({ values, valueOffsets }, index) => getVariableWidthBytes(values, valueOffsets, index);\n/** @ignore */\nconst getUtf8 = ({ values, valueOffsets }, index) => {\n    const bytes = getVariableWidthBytes(values, valueOffsets, index);\n    return bytes !== null ? (0,_util_utf8__WEBPACK_IMPORTED_MODULE_2__.decodeUtf8)(bytes) : null;\n};\n/* istanbul ignore next */\n/** @ignore */\nconst getInt = (vector, index) => (vector.type.bitWidth < 64\n    ? getNumeric(vector, index)\n    : getBigInts(vector, index));\n/* istanbul ignore next */\n/** @ignore */\nconst getFloat = (vector, index) => (vector.type.precision !== _enum__WEBPACK_IMPORTED_MODULE_4__.Precision.HALF\n    ? getNumeric(vector, index)\n    : getFloat16(vector, index));\n/* istanbul ignore next */\n/** @ignore */\nconst getDate = (vector, index) => (vector.type.unit === _enum__WEBPACK_IMPORTED_MODULE_4__.DateUnit.DAY\n    ? getDateDay(vector, index)\n    : getDateMillisecond(vector, index));\n/** @ignore */\nconst getTimestampSecond = ({ values }, index) => 1000 * epochMillisecondsLongToMs(values, index * 2);\n/** @ignore */\nconst getTimestampMillisecond = ({ values }, index) => epochMillisecondsLongToMs(values, index * 2);\n/** @ignore */\nconst getTimestampMicrosecond = ({ values }, index) => epochMicrosecondsLongToMs(values, index * 2);\n/** @ignore */\nconst getTimestampNanosecond = ({ values }, index) => epochNanosecondsLongToMs(values, index * 2);\n/* istanbul ignore next */\n/** @ignore */\nconst getTimestamp = (vector, index) => {\n    switch (vector.type.unit) {\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.SECOND: return getTimestampSecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.MILLISECOND: return getTimestampMillisecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.MICROSECOND: return getTimestampMicrosecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.NANOSECOND: return getTimestampNanosecond(vector, index);\n    }\n};\n/** @ignore */\nconst getTimeSecond = ({ values, stride }, index) => values[stride * index];\n/** @ignore */\nconst getTimeMillisecond = ({ values, stride }, index) => values[stride * index];\n/** @ignore */\nconst getTimeMicrosecond = ({ values }, index) => _util_bn__WEBPACK_IMPORTED_MODULE_0__.BN.signed(values.subarray(2 * index, 2 * (index + 1)));\n/** @ignore */\nconst getTimeNanosecond = ({ values }, index) => _util_bn__WEBPACK_IMPORTED_MODULE_0__.BN.signed(values.subarray(2 * index, 2 * (index + 1)));\n/* istanbul ignore next */\n/** @ignore */\nconst getTime = (vector, index) => {\n    switch (vector.type.unit) {\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.SECOND: return getTimeSecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.MILLISECOND: return getTimeMillisecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.MICROSECOND: return getTimeMicrosecond(vector, index);\n        case _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.NANOSECOND: return getTimeNanosecond(vector, index);\n    }\n};\n/** @ignore */\nconst getDecimal = ({ values }, index) => _util_bn__WEBPACK_IMPORTED_MODULE_0__.BN.decimal(values.subarray(4 * index, 4 * (index + 1)));\n/** @ignore */\nconst getList = (vector, index) => {\n    const child = vector.getChildAt(0), { valueOffsets, stride } = vector;\n    return child.slice(valueOffsets[index * stride], valueOffsets[(index * stride) + 1]);\n};\n/** @ignore */\nconst getMap = (vector, index) => {\n    return vector.bind(index);\n};\n/** @ignore */\nconst getStruct = (vector, index) => {\n    return vector.bind(index);\n};\n/* istanbul ignore next */\n/** @ignore */\nconst getUnion = (vector, index) => {\n    return vector.type.mode === _enum__WEBPACK_IMPORTED_MODULE_4__.UnionMode.Dense ?\n        getDenseUnion(vector, index) :\n        getSparseUnion(vector, index);\n};\n/** @ignore */\nconst getDenseUnion = (vector, index) => {\n    const childIndex = vector.typeIdToChildIndex[vector.typeIds[index]];\n    const child = vector.getChildAt(childIndex);\n    return child ? child.get(vector.valueOffsets[index]) : null;\n};\n/** @ignore */\nconst getSparseUnion = (vector, index) => {\n    const childIndex = vector.typeIdToChildIndex[vector.typeIds[index]];\n    const child = vector.getChildAt(childIndex);\n    return child ? child.get(index) : null;\n};\n/** @ignore */\nconst getDictionary = (vector, index) => {\n    return vector.getValue(vector.getKey(index));\n};\n/* istanbul ignore next */\n/** @ignore */\nconst getInterval = (vector, index) => (vector.type.unit === _enum__WEBPACK_IMPORTED_MODULE_4__.IntervalUnit.DAY_TIME)\n    ? getIntervalDayTime(vector, index)\n    : getIntervalYearMonth(vector, index);\n/** @ignore */\nconst getIntervalDayTime = ({ values }, index) => values.subarray(2 * index, 2 * (index + 1));\n/** @ignore */\nconst getIntervalYearMonth = ({ values }, index) => {\n    const interval = values[index];\n    const int32s = new Int32Array(2);\n    int32s[0] = interval / 12 | 0; /* years */\n    int32s[1] = interval % 12 | 0; /* months */\n    return int32s;\n};\n/** @ignore */\nconst getFixedSizeList = (vector, index) => {\n    const child = vector.getChildAt(0), { stride } = vector;\n    return child.slice(index * stride, (index + 1) * stride);\n};\nGetVisitor.prototype.visitNull = getNull;\nGetVisitor.prototype.visitBool = getBool;\nGetVisitor.prototype.visitInt = getInt;\nGetVisitor.prototype.visitInt8 = getNumeric;\nGetVisitor.prototype.visitInt16 = getNumeric;\nGetVisitor.prototype.visitInt32 = getNumeric;\nGetVisitor.prototype.visitInt64 = getBigInts;\nGetVisitor.prototype.visitUint8 = getNumeric;\nGetVisitor.prototype.visitUint16 = getNumeric;\nGetVisitor.prototype.visitUint32 = getNumeric;\nGetVisitor.prototype.visitUint64 = getBigInts;\nGetVisitor.prototype.visitFloat = getFloat;\nGetVisitor.prototype.visitFloat16 = getFloat16;\nGetVisitor.prototype.visitFloat32 = getNumeric;\nGetVisitor.prototype.visitFloat64 = getNumeric;\nGetVisitor.prototype.visitUtf8 = getUtf8;\nGetVisitor.prototype.visitBinary = getBinary;\nGetVisitor.prototype.visitFixedSizeBinary = getFixedSizeBinary;\nGetVisitor.prototype.visitDate = getDate;\nGetVisitor.prototype.visitDateDay = getDateDay;\nGetVisitor.prototype.visitDateMillisecond = getDateMillisecond;\nGetVisitor.prototype.visitTimestamp = getTimestamp;\nGetVisitor.prototype.visitTimestampSecond = getTimestampSecond;\nGetVisitor.prototype.visitTimestampMillisecond = getTimestampMillisecond;\nGetVisitor.prototype.visitTimestampMicrosecond = getTimestampMicrosecond;\nGetVisitor.prototype.visitTimestampNanosecond = getTimestampNanosecond;\nGetVisitor.prototype.visitTime = getTime;\nGetVisitor.prototype.visitTimeSecond = getTimeSecond;\nGetVisitor.prototype.visitTimeMillisecond = getTimeMillisecond;\nGetVisitor.prototype.visitTimeMicrosecond = getTimeMicrosecond;\nGetVisitor.prototype.visitTimeNanosecond = getTimeNanosecond;\nGetVisitor.prototype.visitDecimal = getDecimal;\nGetVisitor.prototype.visitList = getList;\nGetVisitor.prototype.visitStruct = getStruct;\nGetVisitor.prototype.visitUnion = getUnion;\nGetVisitor.prototype.visitDenseUnion = getDenseUnion;\nGetVisitor.prototype.visitSparseUnion = getSparseUnion;\nGetVisitor.prototype.visitDictionary = getDictionary;\nGetVisitor.prototype.visitInterval = getInterval;\nGetVisitor.prototype.visitIntervalDayTime = getIntervalDayTime;\nGetVisitor.prototype.visitIntervalYearMonth = getIntervalYearMonth;\nGetVisitor.prototype.visitFixedSizeList = getFixedSizeList;\nGetVisitor.prototype.visitMap = getMap;\n/** @ignore */\nconst instance = new GetVisitor();\n\n//# sourceMappingURL=get.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/get.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/indexof.mjs":
/*!***********************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/indexof.mjs ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   IndexOfVisitor: () => (/* binding */ IndexOfVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_vector__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/vector */ \"../../node_modules/apache-arrow/util/vector.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass IndexOfVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n}\n/** @ignore */\nfunction nullIndexOf(vector, searchElement) {\n    // if you're looking for nulls and the vector isn't empty, we've got 'em!\n    return searchElement === null && vector.length > 0 ? 0 : -1;\n}\n/** @ignore */\nfunction indexOfNull(vector, fromIndex) {\n    const { nullBitmap } = vector.data;\n    if (!nullBitmap || vector.nullCount <= 0) {\n        return -1;\n    }\n    let i = 0;\n    for (const isValid of (0,_util_bit__WEBPACK_IMPORTED_MODULE_1__.iterateBits)(nullBitmap, vector.data.offset + (fromIndex || 0), vector.length, nullBitmap, _util_bit__WEBPACK_IMPORTED_MODULE_1__.getBool)) {\n        if (!isValid) {\n            return i;\n        }\n        ++i;\n    }\n    return -1;\n}\n/** @ignore */\nfunction indexOfValue(vector, searchElement, fromIndex) {\n    if (searchElement === undefined) {\n        return -1;\n    }\n    if (searchElement === null) {\n        return indexOfNull(vector, fromIndex);\n    }\n    const compare = (0,_util_vector__WEBPACK_IMPORTED_MODULE_2__.createElementComparator)(searchElement);\n    for (let i = (fromIndex || 0) - 1, n = vector.length; ++i < n;) {\n        if (compare(vector.get(i))) {\n            return i;\n        }\n    }\n    return -1;\n}\n/** @ignore */\nfunction indexOfUnion(vector, searchElement, fromIndex) {\n    // Unions are special -- they do have a nullBitmap, but so can their children.\n    // If the searchElement is null, we don't know whether it came from the Union's\n    // bitmap or one of its childrens'. So we don't interrogate the Union's bitmap,\n    // since that will report the wrong index if a child has a null before the Union.\n    const compare = (0,_util_vector__WEBPACK_IMPORTED_MODULE_2__.createElementComparator)(searchElement);\n    for (let i = (fromIndex || 0) - 1, n = vector.length; ++i < n;) {\n        if (compare(vector.get(i))) {\n            return i;\n        }\n    }\n    return -1;\n}\nIndexOfVisitor.prototype.visitNull = nullIndexOf;\nIndexOfVisitor.prototype.visitBool = indexOfValue;\nIndexOfVisitor.prototype.visitInt = indexOfValue;\nIndexOfVisitor.prototype.visitInt8 = indexOfValue;\nIndexOfVisitor.prototype.visitInt16 = indexOfValue;\nIndexOfVisitor.prototype.visitInt32 = indexOfValue;\nIndexOfVisitor.prototype.visitInt64 = indexOfValue;\nIndexOfVisitor.prototype.visitUint8 = indexOfValue;\nIndexOfVisitor.prototype.visitUint16 = indexOfValue;\nIndexOfVisitor.prototype.visitUint32 = indexOfValue;\nIndexOfVisitor.prototype.visitUint64 = indexOfValue;\nIndexOfVisitor.prototype.visitFloat = indexOfValue;\nIndexOfVisitor.prototype.visitFloat16 = indexOfValue;\nIndexOfVisitor.prototype.visitFloat32 = indexOfValue;\nIndexOfVisitor.prototype.visitFloat64 = indexOfValue;\nIndexOfVisitor.prototype.visitUtf8 = indexOfValue;\nIndexOfVisitor.prototype.visitBinary = indexOfValue;\nIndexOfVisitor.prototype.visitFixedSizeBinary = indexOfValue;\nIndexOfVisitor.prototype.visitDate = indexOfValue;\nIndexOfVisitor.prototype.visitDateDay = indexOfValue;\nIndexOfVisitor.prototype.visitDateMillisecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimestamp = indexOfValue;\nIndexOfVisitor.prototype.visitTimestampSecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimestampMillisecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimestampMicrosecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimestampNanosecond = indexOfValue;\nIndexOfVisitor.prototype.visitTime = indexOfValue;\nIndexOfVisitor.prototype.visitTimeSecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimeMillisecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimeMicrosecond = indexOfValue;\nIndexOfVisitor.prototype.visitTimeNanosecond = indexOfValue;\nIndexOfVisitor.prototype.visitDecimal = indexOfValue;\nIndexOfVisitor.prototype.visitList = indexOfValue;\nIndexOfVisitor.prototype.visitStruct = indexOfValue;\nIndexOfVisitor.prototype.visitUnion = indexOfValue;\nIndexOfVisitor.prototype.visitDenseUnion = indexOfUnion;\nIndexOfVisitor.prototype.visitSparseUnion = indexOfUnion;\nIndexOfVisitor.prototype.visitDictionary = indexOfValue;\nIndexOfVisitor.prototype.visitInterval = indexOfValue;\nIndexOfVisitor.prototype.visitIntervalDayTime = indexOfValue;\nIndexOfVisitor.prototype.visitIntervalYearMonth = indexOfValue;\nIndexOfVisitor.prototype.visitFixedSizeList = indexOfValue;\nIndexOfVisitor.prototype.visitMap = indexOfValue;\n/** @ignore */\nconst instance = new IndexOfVisitor();\n\n//# sourceMappingURL=indexof.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/indexof.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/iterator.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/iterator.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   IteratorVisitor: () => (/* binding */ IteratorVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _get__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./get */ \"../../node_modules/apache-arrow/visitor/get.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n/** @ignore */\nclass IteratorVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_1__.Visitor {\n}\n/** @ignore */\nfunction nullableIterator(vector) {\n    const getFn = _get__WEBPACK_IMPORTED_MODULE_3__.instance.getVisitFn(vector);\n    return (0,_util_bit__WEBPACK_IMPORTED_MODULE_2__.iterateBits)(vector.data.nullBitmap, vector.data.offset, vector.length, vector, (vec, idx, nullByte, nullBit) => ((nullByte & 1 << nullBit) !== 0) ? getFn(vec, idx) : null);\n}\n/** @ignore */\nfunction vectorIterator(vector) {\n    // If nullable, iterate manually\n    if (vector.nullCount > 0) {\n        return nullableIterator(vector);\n    }\n    const { type, typeId, length } = vector;\n    // Fast case, defer to native iterators if possible\n    if (vector.stride === 1 && ((typeId === _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Timestamp) ||\n        (typeId === _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Int && type.bitWidth !== 64) ||\n        (typeId === _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Time && type.bitWidth !== 64) ||\n        (typeId === _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Float && type.precision > 0 /* Precision.HALF */))) {\n        return vector.data.values.subarray(0, length)[Symbol.iterator]();\n    }\n    // Otherwise, iterate manually\n    return (function* (getFn) {\n        for (let index = -1; ++index < length;) {\n            yield getFn(vector, index);\n        }\n    })(_get__WEBPACK_IMPORTED_MODULE_3__.instance.getVisitFn(vector));\n}\nIteratorVisitor.prototype.visitNull = vectorIterator;\nIteratorVisitor.prototype.visitBool = vectorIterator;\nIteratorVisitor.prototype.visitInt = vectorIterator;\nIteratorVisitor.prototype.visitInt8 = vectorIterator;\nIteratorVisitor.prototype.visitInt16 = vectorIterator;\nIteratorVisitor.prototype.visitInt32 = vectorIterator;\nIteratorVisitor.prototype.visitInt64 = vectorIterator;\nIteratorVisitor.prototype.visitUint8 = vectorIterator;\nIteratorVisitor.prototype.visitUint16 = vectorIterator;\nIteratorVisitor.prototype.visitUint32 = vectorIterator;\nIteratorVisitor.prototype.visitUint64 = vectorIterator;\nIteratorVisitor.prototype.visitFloat = vectorIterator;\nIteratorVisitor.prototype.visitFloat16 = vectorIterator;\nIteratorVisitor.prototype.visitFloat32 = vectorIterator;\nIteratorVisitor.prototype.visitFloat64 = vectorIterator;\nIteratorVisitor.prototype.visitUtf8 = vectorIterator;\nIteratorVisitor.prototype.visitBinary = vectorIterator;\nIteratorVisitor.prototype.visitFixedSizeBinary = vectorIterator;\nIteratorVisitor.prototype.visitDate = vectorIterator;\nIteratorVisitor.prototype.visitDateDay = vectorIterator;\nIteratorVisitor.prototype.visitDateMillisecond = vectorIterator;\nIteratorVisitor.prototype.visitTimestamp = vectorIterator;\nIteratorVisitor.prototype.visitTimestampSecond = vectorIterator;\nIteratorVisitor.prototype.visitTimestampMillisecond = vectorIterator;\nIteratorVisitor.prototype.visitTimestampMicrosecond = vectorIterator;\nIteratorVisitor.prototype.visitTimestampNanosecond = vectorIterator;\nIteratorVisitor.prototype.visitTime = vectorIterator;\nIteratorVisitor.prototype.visitTimeSecond = vectorIterator;\nIteratorVisitor.prototype.visitTimeMillisecond = vectorIterator;\nIteratorVisitor.prototype.visitTimeMicrosecond = vectorIterator;\nIteratorVisitor.prototype.visitTimeNanosecond = vectorIterator;\nIteratorVisitor.prototype.visitDecimal = vectorIterator;\nIteratorVisitor.prototype.visitList = vectorIterator;\nIteratorVisitor.prototype.visitStruct = vectorIterator;\nIteratorVisitor.prototype.visitUnion = vectorIterator;\nIteratorVisitor.prototype.visitDenseUnion = vectorIterator;\nIteratorVisitor.prototype.visitSparseUnion = vectorIterator;\nIteratorVisitor.prototype.visitDictionary = vectorIterator;\nIteratorVisitor.prototype.visitInterval = vectorIterator;\nIteratorVisitor.prototype.visitIntervalDayTime = vectorIterator;\nIteratorVisitor.prototype.visitIntervalYearMonth = vectorIterator;\nIteratorVisitor.prototype.visitFixedSizeList = vectorIterator;\nIteratorVisitor.prototype.visitMap = vectorIterator;\n/** @ignore */\nconst instance = new IteratorVisitor();\n\n//# sourceMappingURL=iterator.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/iterator.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/jsontypeassembler.mjs":
/*!*********************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/jsontypeassembler.mjs ***!
  \*********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JSONTypeAssembler: () => (/* binding */ JSONTypeAssembler)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n/** @ignore */\nclass JSONTypeAssembler extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    visit(node) {\n        return node == null ? undefined : super.visit(node);\n    }\n    visitNull({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitInt({ typeId, bitWidth, isSigned }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'bitWidth': bitWidth, 'isSigned': isSigned };\n    }\n    visitFloat({ typeId, precision }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'precision': _enum__WEBPACK_IMPORTED_MODULE_1__.Precision[precision] };\n    }\n    visitBinary({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitBool({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitUtf8({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitDecimal({ typeId, scale, precision }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'scale': scale, 'precision': precision };\n    }\n    visitDate({ typeId, unit }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'unit': _enum__WEBPACK_IMPORTED_MODULE_1__.DateUnit[unit] };\n    }\n    visitTime({ typeId, unit, bitWidth }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'unit': _enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit[unit], bitWidth };\n    }\n    visitTimestamp({ typeId, timezone, unit }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'unit': _enum__WEBPACK_IMPORTED_MODULE_1__.TimeUnit[unit], timezone };\n    }\n    visitInterval({ typeId, unit }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'unit': _enum__WEBPACK_IMPORTED_MODULE_1__.IntervalUnit[unit] };\n    }\n    visitList({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitStruct({ typeId }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase() };\n    }\n    visitUnion({ typeId, mode, typeIds }) {\n        return {\n            'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(),\n            'mode': _enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode[mode],\n            'typeIds': [...typeIds]\n        };\n    }\n    visitDictionary(node) {\n        return this.visit(node.dictionary);\n    }\n    visitFixedSizeBinary({ typeId, byteWidth }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'byteWidth': byteWidth };\n    }\n    visitFixedSizeList({ typeId, listSize }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'listSize': listSize };\n    }\n    visitMap({ typeId, keysSorted }) {\n        return { 'name': _enum__WEBPACK_IMPORTED_MODULE_1__.ArrowType[typeId].toLowerCase(), 'keysSorted': keysSorted };\n    }\n}\n\n//# sourceMappingURL=jsontypeassembler.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/jsontypeassembler.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/jsonvectorassembler.mjs":
/*!***********************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/jsonvectorassembler.mjs ***!
  \***********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JSONVectorAssembler: () => (/* binding */ JSONVectorAssembler)\n/* harmony export */ });\n/* harmony import */ var _util_bn__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/bn */ \"../../node_modules/apache-arrow/util/bn.mjs\");\n/* harmony import */ var _column__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../column */ \"../../node_modules/apache-arrow/column.mjs\");\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n/** @ignore */\nclass JSONVectorAssembler extends _visitor__WEBPACK_IMPORTED_MODULE_3__.Visitor {\n    /** @nocollapse */\n    static assemble(...args) {\n        return new JSONVectorAssembler().visitMany((0,_util_args__WEBPACK_IMPORTED_MODULE_7__.selectColumnChildrenArgs)(_recordbatch__WEBPACK_IMPORTED_MODULE_5__.RecordBatch, args));\n    }\n    visit(column) {\n        const { data, name, length } = column;\n        const { offset, nullCount, nullBitmap } = data;\n        const type = _type__WEBPACK_IMPORTED_MODULE_8__.DataType.isDictionary(column.type) ? column.type.indices : column.type;\n        const buffers = Object.assign([], data.buffers, { [_enum__WEBPACK_IMPORTED_MODULE_4__.BufferType.VALIDITY]: undefined });\n        return {\n            'name': name,\n            'count': length,\n            'VALIDITY': _type__WEBPACK_IMPORTED_MODULE_8__.DataType.isNull(type) ? undefined\n                : nullCount <= 0 ? Array.from({ length }, () => 1)\n                    : [...(0,_util_bit__WEBPACK_IMPORTED_MODULE_6__.iterateBits)(nullBitmap, offset, length, null, _util_bit__WEBPACK_IMPORTED_MODULE_6__.getBit)],\n            ...super.visit(_vector__WEBPACK_IMPORTED_MODULE_2__.Vector.new(data.clone(type, offset, length, 0, buffers)))\n        };\n    }\n    visitNull() { return {}; }\n    visitBool({ values, offset, length }) {\n        return { 'DATA': [...(0,_util_bit__WEBPACK_IMPORTED_MODULE_6__.iterateBits)(values, offset, length, null, _util_bit__WEBPACK_IMPORTED_MODULE_6__.getBool)] };\n    }\n    visitInt(vector) {\n        return {\n            'DATA': vector.type.bitWidth < 64\n                ? [...vector.values]\n                : [...bigNumsToStrings(vector.values, 2)]\n        };\n    }\n    visitFloat(vector) {\n        return { 'DATA': [...vector.values] };\n    }\n    visitUtf8(vector) {\n        return { 'DATA': [...vector], 'OFFSET': [...vector.valueOffsets] };\n    }\n    visitBinary(vector) {\n        return { 'DATA': [...binaryToString(vector)], OFFSET: [...vector.valueOffsets] };\n    }\n    visitFixedSizeBinary(vector) {\n        return { 'DATA': [...binaryToString(vector)] };\n    }\n    visitDate(vector) {\n        return {\n            'DATA': vector.type.unit === _enum__WEBPACK_IMPORTED_MODULE_4__.DateUnit.DAY\n                ? [...vector.values]\n                : [...bigNumsToStrings(vector.values, 2)]\n        };\n    }\n    visitTimestamp(vector) {\n        return { 'DATA': [...bigNumsToStrings(vector.values, 2)] };\n    }\n    visitTime(vector) {\n        return {\n            'DATA': vector.type.unit < _enum__WEBPACK_IMPORTED_MODULE_4__.TimeUnit.MICROSECOND\n                ? [...vector.values]\n                : [...bigNumsToStrings(vector.values, 2)]\n        };\n    }\n    visitDecimal(vector) {\n        return { 'DATA': [...bigNumsToStrings(vector.values, 4)] };\n    }\n    visitList(vector) {\n        return {\n            'OFFSET': [...vector.valueOffsets],\n            'children': vector.type.children.map((f, i) => this.visit(new _column__WEBPACK_IMPORTED_MODULE_1__.Column(f, [vector.getChildAt(i)])))\n        };\n    }\n    visitStruct(vector) {\n        return {\n            'children': vector.type.children.map((f, i) => this.visit(new _column__WEBPACK_IMPORTED_MODULE_1__.Column(f, [vector.getChildAt(i)])))\n        };\n    }\n    visitUnion(vector) {\n        return {\n            'TYPE': [...vector.typeIds],\n            'OFFSET': vector.type.mode === _enum__WEBPACK_IMPORTED_MODULE_4__.UnionMode.Dense ? [...vector.valueOffsets] : undefined,\n            'children': vector.type.children.map((f, i) => this.visit(new _column__WEBPACK_IMPORTED_MODULE_1__.Column(f, [vector.getChildAt(i)])))\n        };\n    }\n    visitInterval(vector) {\n        return { 'DATA': [...vector.values] };\n    }\n    visitFixedSizeList(vector) {\n        return {\n            'children': vector.type.children.map((f, i) => this.visit(new _column__WEBPACK_IMPORTED_MODULE_1__.Column(f, [vector.getChildAt(i)])))\n        };\n    }\n    visitMap(vector) {\n        return {\n            'OFFSET': [...vector.valueOffsets],\n            'children': vector.type.children.map((f, i) => this.visit(new _column__WEBPACK_IMPORTED_MODULE_1__.Column(f, [vector.getChildAt(i)])))\n        };\n    }\n}\n/** @ignore */\nfunction* binaryToString(vector) {\n    for (const octets of vector) {\n        yield octets.reduce((str, byte) => {\n            return `${str}${('0' + (byte & 0xFF).toString(16)).slice(-2)}`;\n        }, '').toUpperCase();\n    }\n}\n/** @ignore */\nfunction* bigNumsToStrings(values, stride) {\n    for (let i = -1, n = values.length / stride; ++i < n;) {\n        yield `${_util_bn__WEBPACK_IMPORTED_MODULE_0__.BN.new(values.subarray((i + 0) * stride, (i + 1) * stride), false)}`;\n    }\n}\n\n//# sourceMappingURL=jsonvectorassembler.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/jsonvectorassembler.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/set.mjs":
/*!*******************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/set.mjs ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SetVisitor: () => (/* binding */ SetVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _vector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../vector */ \"../../node_modules/apache-arrow/vector.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _util_math__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/math */ \"../../node_modules/apache-arrow/util/math.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n/** @ignore */\nclass SetVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_1__.Visitor {\n}\n/** @ignore */\nconst setEpochMsToDays = (data, index, epochMs) => { data[index] = (epochMs / 86400000) | 0; };\n/** @ignore */\nconst setEpochMsToMillisecondsLong = (data, index, epochMs) => {\n    data[index] = (epochMs % 4294967296) | 0;\n    data[index + 1] = (epochMs / 4294967296) | 0;\n};\n/** @ignore */\nconst setEpochMsToMicrosecondsLong = (data, index, epochMs) => {\n    data[index] = ((epochMs * 1000) % 4294967296) | 0;\n    data[index + 1] = ((epochMs * 1000) / 4294967296) | 0;\n};\n/** @ignore */\nconst setEpochMsToNanosecondsLong = (data, index, epochMs) => {\n    data[index] = ((epochMs * 1000000) % 4294967296) | 0;\n    data[index + 1] = ((epochMs * 1000000) / 4294967296) | 0;\n};\n/** @ignore */\nconst setVariableWidthBytes = (values, valueOffsets, index, value) => {\n    const { [index]: x, [index + 1]: y } = valueOffsets;\n    if (x != null && y != null) {\n        values.set(value.subarray(0, y - x), x);\n    }\n};\n/** @ignore */\nconst setBool = ({ offset, values }, index, val) => {\n    const idx = offset + index;\n    val ? (values[idx >> 3] |= (1 << (idx % 8))) // true\n        : (values[idx >> 3] &= ~(1 << (idx % 8))); // false\n};\n/** @ignore */\nconst setDateDay = ({ values }, index, value) => { setEpochMsToDays(values, index, value.valueOf()); };\n/** @ignore */\nconst setDateMillisecond = ({ values }, index, value) => { setEpochMsToMillisecondsLong(values, index * 2, value.valueOf()); };\n/** @ignore */\nconst setNumeric = ({ stride, values }, index, value) => { values[stride * index] = value; };\n/** @ignore */\nconst setFloat16 = ({ stride, values }, index, value) => { values[stride * index] = (0,_util_math__WEBPACK_IMPORTED_MODULE_3__.float64ToUint16)(value); };\n/** @ignore */\nconst setNumericX2 = (vector, index, value) => {\n    switch (typeof value) {\n        case 'bigint':\n            vector.values64[index] = value;\n            break;\n        case 'number':\n            vector.values[index * vector.stride] = value;\n            break;\n        default:\n            const val = value;\n            const { stride, ArrayType } = vector;\n            const long = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_4__.toArrayBufferView)(ArrayType, val);\n            vector.values.set(long.subarray(0, stride), stride * index);\n    }\n};\n/** @ignore */\nconst setFixedSizeBinary = ({ stride, values }, index, value) => { values.set(value.subarray(0, stride), stride * index); };\n/** @ignore */\nconst setBinary = ({ values, valueOffsets }, index, value) => setVariableWidthBytes(values, valueOffsets, index, value);\n/** @ignore */\nconst setUtf8 = ({ values, valueOffsets }, index, value) => {\n    setVariableWidthBytes(values, valueOffsets, index, (0,_util_utf8__WEBPACK_IMPORTED_MODULE_2__.encodeUtf8)(value));\n};\n/* istanbul ignore next */\n/** @ignore */\nconst setInt = (vector, index, value) => {\n    vector.type.bitWidth < 64\n        ? setNumeric(vector, index, value)\n        : setNumericX2(vector, index, value);\n};\n/* istanbul ignore next */\n/** @ignore */\nconst setFloat = (vector, index, value) => {\n    vector.type.precision !== _enum__WEBPACK_IMPORTED_MODULE_5__.Precision.HALF\n        ? setNumeric(vector, index, value)\n        : setFloat16(vector, index, value);\n};\n/* istanbul ignore next */\nconst setDate = (vector, index, value) => {\n    vector.type.unit === _enum__WEBPACK_IMPORTED_MODULE_5__.DateUnit.DAY\n        ? setDateDay(vector, index, value)\n        : setDateMillisecond(vector, index, value);\n};\n/** @ignore */\nconst setTimestampSecond = ({ values }, index, value) => setEpochMsToMillisecondsLong(values, index * 2, value / 1000);\n/** @ignore */\nconst setTimestampMillisecond = ({ values }, index, value) => setEpochMsToMillisecondsLong(values, index * 2, value);\n/** @ignore */\nconst setTimestampMicrosecond = ({ values }, index, value) => setEpochMsToMicrosecondsLong(values, index * 2, value);\n/** @ignore */\nconst setTimestampNanosecond = ({ values }, index, value) => setEpochMsToNanosecondsLong(values, index * 2, value);\n/* istanbul ignore next */\n/** @ignore */\nconst setTimestamp = (vector, index, value) => {\n    switch (vector.type.unit) {\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.SECOND: return setTimestampSecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.MILLISECOND: return setTimestampMillisecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.MICROSECOND: return setTimestampMicrosecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.NANOSECOND: return setTimestampNanosecond(vector, index, value);\n    }\n};\n/** @ignore */\nconst setTimeSecond = ({ values, stride }, index, value) => { values[stride * index] = value; };\n/** @ignore */\nconst setTimeMillisecond = ({ values, stride }, index, value) => { values[stride * index] = value; };\n/** @ignore */\nconst setTimeMicrosecond = ({ values }, index, value) => { values.set(value.subarray(0, 2), 2 * index); };\n/** @ignore */\nconst setTimeNanosecond = ({ values }, index, value) => { values.set(value.subarray(0, 2), 2 * index); };\n/* istanbul ignore next */\n/** @ignore */\nconst setTime = (vector, index, value) => {\n    switch (vector.type.unit) {\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.SECOND: return setTimeSecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.MILLISECOND: return setTimeMillisecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.MICROSECOND: return setTimeMicrosecond(vector, index, value);\n        case _enum__WEBPACK_IMPORTED_MODULE_5__.TimeUnit.NANOSECOND: return setTimeNanosecond(vector, index, value);\n    }\n};\n/** @ignore */\nconst setDecimal = ({ values }, index, value) => { values.set(value.subarray(0, 4), 4 * index); };\n/** @ignore */\nconst setList = (vector, index, value) => {\n    const values = vector.getChildAt(0), valueOffsets = vector.valueOffsets;\n    for (let idx = -1, itr = valueOffsets[index], end = valueOffsets[index + 1]; itr < end;) {\n        values.set(itr++, value.get(++idx));\n    }\n};\n/** @ignore */\nconst setMap = (vector, index, value) => {\n    const values = vector.getChildAt(0), valueOffsets = vector.valueOffsets;\n    const entries = value instanceof Map ? [...value] : Object.entries(value);\n    for (let idx = -1, itr = valueOffsets[index], end = valueOffsets[index + 1]; itr < end;) {\n        values.set(itr++, entries[++idx]);\n    }\n};\n/** @ignore */ const _setStructArrayValue = (o, v) => (c, _, i) => c && c.set(o, v[i]);\n/** @ignore */ const _setStructVectorValue = (o, v) => (c, _, i) => c && c.set(o, v.get(i));\n/** @ignore */ const _setStructMapValue = (o, v) => (c, f, _) => c && c.set(o, v.get(f.name));\n/** @ignore */ const _setStructObjectValue = (o, v) => (c, f, _) => c && c.set(o, v[f.name]);\n/** @ignore */\nconst setStruct = (vector, index, value) => {\n    const setValue = value instanceof Map ? _setStructMapValue(index, value) :\n        value instanceof _vector__WEBPACK_IMPORTED_MODULE_0__.Vector ? _setStructVectorValue(index, value) :\n            Array.isArray(value) ? _setStructArrayValue(index, value) :\n                _setStructObjectValue(index, value);\n    vector.type.children.forEach((f, i) => setValue(vector.getChildAt(i), f, i));\n};\n/* istanbul ignore next */\n/** @ignore */\nconst setUnion = (vector, index, value) => {\n    vector.type.mode === _enum__WEBPACK_IMPORTED_MODULE_5__.UnionMode.Dense ?\n        setDenseUnion(vector, index, value) :\n        setSparseUnion(vector, index, value);\n};\n/** @ignore */\nconst setDenseUnion = (vector, index, value) => {\n    const childIndex = vector.typeIdToChildIndex[vector.typeIds[index]];\n    const child = vector.getChildAt(childIndex);\n    child && child.set(vector.valueOffsets[index], value);\n};\n/** @ignore */\nconst setSparseUnion = (vector, index, value) => {\n    const childIndex = vector.typeIdToChildIndex[vector.typeIds[index]];\n    const child = vector.getChildAt(childIndex);\n    child && child.set(index, value);\n};\n/** @ignore */\nconst setDictionary = (vector, index, value) => {\n    const key = vector.getKey(index);\n    if (key !== null) {\n        vector.setValue(key, value);\n    }\n};\n/* istanbul ignore next */\n/** @ignore */\nconst setIntervalValue = (vector, index, value) => {\n    (vector.type.unit === _enum__WEBPACK_IMPORTED_MODULE_5__.IntervalUnit.DAY_TIME)\n        ? setIntervalDayTime(vector, index, value)\n        : setIntervalYearMonth(vector, index, value);\n};\n/** @ignore */\nconst setIntervalDayTime = ({ values }, index, value) => { values.set(value.subarray(0, 2), 2 * index); };\n/** @ignore */\nconst setIntervalYearMonth = ({ values }, index, value) => { values[index] = (value[0] * 12) + (value[1] % 12); };\n/** @ignore */\nconst setFixedSizeList = (vector, index, value) => {\n    const child = vector.getChildAt(0), { stride } = vector;\n    for (let idx = -1, offset = index * stride; ++idx < stride;) {\n        child.set(offset + idx, value.get(idx));\n    }\n};\nSetVisitor.prototype.visitBool = setBool;\nSetVisitor.prototype.visitInt = setInt;\nSetVisitor.prototype.visitInt8 = setNumeric;\nSetVisitor.prototype.visitInt16 = setNumeric;\nSetVisitor.prototype.visitInt32 = setNumeric;\nSetVisitor.prototype.visitInt64 = setNumericX2;\nSetVisitor.prototype.visitUint8 = setNumeric;\nSetVisitor.prototype.visitUint16 = setNumeric;\nSetVisitor.prototype.visitUint32 = setNumeric;\nSetVisitor.prototype.visitUint64 = setNumericX2;\nSetVisitor.prototype.visitFloat = setFloat;\nSetVisitor.prototype.visitFloat16 = setFloat16;\nSetVisitor.prototype.visitFloat32 = setNumeric;\nSetVisitor.prototype.visitFloat64 = setNumeric;\nSetVisitor.prototype.visitUtf8 = setUtf8;\nSetVisitor.prototype.visitBinary = setBinary;\nSetVisitor.prototype.visitFixedSizeBinary = setFixedSizeBinary;\nSetVisitor.prototype.visitDate = setDate;\nSetVisitor.prototype.visitDateDay = setDateDay;\nSetVisitor.prototype.visitDateMillisecond = setDateMillisecond;\nSetVisitor.prototype.visitTimestamp = setTimestamp;\nSetVisitor.prototype.visitTimestampSecond = setTimestampSecond;\nSetVisitor.prototype.visitTimestampMillisecond = setTimestampMillisecond;\nSetVisitor.prototype.visitTimestampMicrosecond = setTimestampMicrosecond;\nSetVisitor.prototype.visitTimestampNanosecond = setTimestampNanosecond;\nSetVisitor.prototype.visitTime = setTime;\nSetVisitor.prototype.visitTimeSecond = setTimeSecond;\nSetVisitor.prototype.visitTimeMillisecond = setTimeMillisecond;\nSetVisitor.prototype.visitTimeMicrosecond = setTimeMicrosecond;\nSetVisitor.prototype.visitTimeNanosecond = setTimeNanosecond;\nSetVisitor.prototype.visitDecimal = setDecimal;\nSetVisitor.prototype.visitList = setList;\nSetVisitor.prototype.visitStruct = setStruct;\nSetVisitor.prototype.visitUnion = setUnion;\nSetVisitor.prototype.visitDenseUnion = setDenseUnion;\nSetVisitor.prototype.visitSparseUnion = setSparseUnion;\nSetVisitor.prototype.visitDictionary = setDictionary;\nSetVisitor.prototype.visitInterval = setIntervalValue;\nSetVisitor.prototype.visitIntervalDayTime = setIntervalDayTime;\nSetVisitor.prototype.visitIntervalYearMonth = setIntervalYearMonth;\nSetVisitor.prototype.visitFixedSizeList = setFixedSizeList;\nSetVisitor.prototype.visitMap = setMap;\n/** @ignore */\nconst instance = new SetVisitor();\n\n//# sourceMappingURL=set.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/set.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/toarray.mjs":
/*!***********************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/toarray.mjs ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ToArrayVisitor: () => (/* binding */ ToArrayVisitor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _iterator__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./iterator */ \"../../node_modules/apache-arrow/visitor/iterator.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n/** @ignore */\nclass ToArrayVisitor extends _visitor__WEBPACK_IMPORTED_MODULE_1__.Visitor {\n}\n/** @ignore */\nfunction arrayOfVector(vector) {\n    const { type, length, stride } = vector;\n    // Fast case, return subarray if possible\n    switch (type.typeId) {\n        case _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Int:\n        case _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Float:\n        case _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Decimal:\n        case _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Time:\n        case _enum__WEBPACK_IMPORTED_MODULE_0__.Type.Timestamp:\n            return vector.data.values.subarray(0, length * stride);\n    }\n    // Otherwise if not primitive, slow copy\n    return [..._iterator__WEBPACK_IMPORTED_MODULE_2__.instance.visit(vector)];\n}\nToArrayVisitor.prototype.visitNull = arrayOfVector;\nToArrayVisitor.prototype.visitBool = arrayOfVector;\nToArrayVisitor.prototype.visitInt = arrayOfVector;\nToArrayVisitor.prototype.visitInt8 = arrayOfVector;\nToArrayVisitor.prototype.visitInt16 = arrayOfVector;\nToArrayVisitor.prototype.visitInt32 = arrayOfVector;\nToArrayVisitor.prototype.visitInt64 = arrayOfVector;\nToArrayVisitor.prototype.visitUint8 = arrayOfVector;\nToArrayVisitor.prototype.visitUint16 = arrayOfVector;\nToArrayVisitor.prototype.visitUint32 = arrayOfVector;\nToArrayVisitor.prototype.visitUint64 = arrayOfVector;\nToArrayVisitor.prototype.visitFloat = arrayOfVector;\nToArrayVisitor.prototype.visitFloat16 = arrayOfVector;\nToArrayVisitor.prototype.visitFloat32 = arrayOfVector;\nToArrayVisitor.prototype.visitFloat64 = arrayOfVector;\nToArrayVisitor.prototype.visitUtf8 = arrayOfVector;\nToArrayVisitor.prototype.visitBinary = arrayOfVector;\nToArrayVisitor.prototype.visitFixedSizeBinary = arrayOfVector;\nToArrayVisitor.prototype.visitDate = arrayOfVector;\nToArrayVisitor.prototype.visitDateDay = arrayOfVector;\nToArrayVisitor.prototype.visitDateMillisecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimestamp = arrayOfVector;\nToArrayVisitor.prototype.visitTimestampSecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimestampMillisecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimestampMicrosecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimestampNanosecond = arrayOfVector;\nToArrayVisitor.prototype.visitTime = arrayOfVector;\nToArrayVisitor.prototype.visitTimeSecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimeMillisecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimeMicrosecond = arrayOfVector;\nToArrayVisitor.prototype.visitTimeNanosecond = arrayOfVector;\nToArrayVisitor.prototype.visitDecimal = arrayOfVector;\nToArrayVisitor.prototype.visitList = arrayOfVector;\nToArrayVisitor.prototype.visitStruct = arrayOfVector;\nToArrayVisitor.prototype.visitUnion = arrayOfVector;\nToArrayVisitor.prototype.visitDenseUnion = arrayOfVector;\nToArrayVisitor.prototype.visitSparseUnion = arrayOfVector;\nToArrayVisitor.prototype.visitDictionary = arrayOfVector;\nToArrayVisitor.prototype.visitInterval = arrayOfVector;\nToArrayVisitor.prototype.visitIntervalDayTime = arrayOfVector;\nToArrayVisitor.prototype.visitIntervalYearMonth = arrayOfVector;\nToArrayVisitor.prototype.visitFixedSizeList = arrayOfVector;\nToArrayVisitor.prototype.visitMap = arrayOfVector;\n/** @ignore */\nconst instance = new ToArrayVisitor();\n\n//# sourceMappingURL=toarray.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/toarray.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/typeassembler.mjs":
/*!*****************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/typeassembler.mjs ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TypeAssembler: () => (/* binding */ TypeAssembler),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var flatbuffers__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! flatbuffers */ \"../../node_modules/flatbuffers/js/flatbuffers.mjs\");\n/* harmony import */ var _fb_Schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../fb/Schema */ \"../../node_modules/apache-arrow/fb/Schema.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\nvar Long = flatbuffers__WEBPACK_IMPORTED_MODULE_0__.flatbuffers.Long;\n\n\nvar Null = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Null;\nvar Int = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Int;\nvar FloatingPoint = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FloatingPoint;\nvar Binary = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Binary;\nvar Bool = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Bool;\nvar Utf8 = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Utf8;\nvar Decimal = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Decimal;\nvar Date = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Date;\nvar Time = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Time;\nvar Timestamp = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Timestamp;\nvar Interval = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Interval;\nvar List = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.List;\nvar Struct = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Struct_;\nvar Union = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Union;\nvar DictionaryEncoding = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.DictionaryEncoding;\nvar FixedSizeBinary = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FixedSizeBinary;\nvar FixedSizeList = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.FixedSizeList;\nvar Map_ = _fb_Schema__WEBPACK_IMPORTED_MODULE_1__.org.apache.arrow.flatbuf.Map;\n/** @ignore */\nclass TypeAssembler extends _visitor__WEBPACK_IMPORTED_MODULE_2__.Visitor {\n    visit(node, builder) {\n        return (node == null || builder == null) ? undefined : super.visit(node, builder);\n    }\n    visitNull(_node, b) {\n        Null.startNull(b);\n        return Null.endNull(b);\n    }\n    visitInt(node, b) {\n        Int.startInt(b);\n        Int.addBitWidth(b, node.bitWidth);\n        Int.addIsSigned(b, node.isSigned);\n        return Int.endInt(b);\n    }\n    visitFloat(node, b) {\n        FloatingPoint.startFloatingPoint(b);\n        FloatingPoint.addPrecision(b, node.precision);\n        return FloatingPoint.endFloatingPoint(b);\n    }\n    visitBinary(_node, b) {\n        Binary.startBinary(b);\n        return Binary.endBinary(b);\n    }\n    visitBool(_node, b) {\n        Bool.startBool(b);\n        return Bool.endBool(b);\n    }\n    visitUtf8(_node, b) {\n        Utf8.startUtf8(b);\n        return Utf8.endUtf8(b);\n    }\n    visitDecimal(node, b) {\n        Decimal.startDecimal(b);\n        Decimal.addScale(b, node.scale);\n        Decimal.addPrecision(b, node.precision);\n        return Decimal.endDecimal(b);\n    }\n    visitDate(node, b) {\n        Date.startDate(b);\n        Date.addUnit(b, node.unit);\n        return Date.endDate(b);\n    }\n    visitTime(node, b) {\n        Time.startTime(b);\n        Time.addUnit(b, node.unit);\n        Time.addBitWidth(b, node.bitWidth);\n        return Time.endTime(b);\n    }\n    visitTimestamp(node, b) {\n        const timezone = (node.timezone && b.createString(node.timezone)) || undefined;\n        Timestamp.startTimestamp(b);\n        Timestamp.addUnit(b, node.unit);\n        if (timezone !== undefined) {\n            Timestamp.addTimezone(b, timezone);\n        }\n        return Timestamp.endTimestamp(b);\n    }\n    visitInterval(node, b) {\n        Interval.startInterval(b);\n        Interval.addUnit(b, node.unit);\n        return Interval.endInterval(b);\n    }\n    visitList(_node, b) {\n        List.startList(b);\n        return List.endList(b);\n    }\n    visitStruct(_node, b) {\n        Struct.startStruct_(b);\n        return Struct.endStruct_(b);\n    }\n    visitUnion(node, b) {\n        Union.startTypeIdsVector(b, node.typeIds.length);\n        const typeIds = Union.createTypeIdsVector(b, node.typeIds);\n        Union.startUnion(b);\n        Union.addMode(b, node.mode);\n        Union.addTypeIds(b, typeIds);\n        return Union.endUnion(b);\n    }\n    visitDictionary(node, b) {\n        const indexType = this.visit(node.indices, b);\n        DictionaryEncoding.startDictionaryEncoding(b);\n        DictionaryEncoding.addId(b, new Long(node.id, 0));\n        DictionaryEncoding.addIsOrdered(b, node.isOrdered);\n        if (indexType !== undefined) {\n            DictionaryEncoding.addIndexType(b, indexType);\n        }\n        return DictionaryEncoding.endDictionaryEncoding(b);\n    }\n    visitFixedSizeBinary(node, b) {\n        FixedSizeBinary.startFixedSizeBinary(b);\n        FixedSizeBinary.addByteWidth(b, node.byteWidth);\n        return FixedSizeBinary.endFixedSizeBinary(b);\n    }\n    visitFixedSizeList(node, b) {\n        FixedSizeList.startFixedSizeList(b);\n        FixedSizeList.addListSize(b, node.listSize);\n        return FixedSizeList.endFixedSizeList(b);\n    }\n    visitMap(node, b) {\n        Map_.startMap(b);\n        Map_.addKeysSorted(b, node.keysSorted);\n        return Map_.endMap(b);\n    }\n}\n/** @ignore */\nconst instance = new TypeAssembler();\n\n//# sourceMappingURL=typeassembler.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/typeassembler.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/typecomparator.mjs":
/*!******************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/typecomparator.mjs ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TypeComparator: () => (/* binding */ TypeComparator),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n/** @ignore */\nclass TypeComparator extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    compareSchemas(schema, other) {\n        return (schema === other) || (other instanceof schema.constructor &&\n            instance.compareFields(schema.fields, other.fields));\n    }\n    compareFields(fields, others) {\n        return (fields === others) || (Array.isArray(fields) &&\n            Array.isArray(others) &&\n            fields.length === others.length &&\n            fields.every((f, i) => instance.compareField(f, others[i])));\n    }\n    compareField(field, other) {\n        return (field === other) || (other instanceof field.constructor &&\n            field.name === other.name &&\n            field.nullable === other.nullable &&\n            instance.visit(field.type, other.type));\n    }\n}\nfunction compareConstructor(type, other) {\n    return other instanceof type.constructor;\n}\nfunction compareAny(type, other) {\n    return (type === other) || compareConstructor(type, other);\n}\nfunction compareInt(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.bitWidth === other.bitWidth &&\n        type.isSigned === other.isSigned);\n}\nfunction compareFloat(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.precision === other.precision);\n}\nfunction compareFixedSizeBinary(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.byteWidth === other.byteWidth);\n}\nfunction compareDate(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.unit === other.unit);\n}\nfunction compareTimestamp(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.unit === other.unit &&\n        type.timezone === other.timezone);\n}\nfunction compareTime(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.unit === other.unit &&\n        type.bitWidth === other.bitWidth);\n}\nfunction compareList(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.children.length === other.children.length &&\n        instance.compareFields(type.children, other.children));\n}\nfunction compareStruct(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.children.length === other.children.length &&\n        instance.compareFields(type.children, other.children));\n}\nfunction compareUnion(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.mode === other.mode &&\n        type.typeIds.every((x, i) => x === other.typeIds[i]) &&\n        instance.compareFields(type.children, other.children));\n}\nfunction compareDictionary(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.id === other.id &&\n        type.isOrdered === other.isOrdered &&\n        instance.visit(type.indices, other.indices) &&\n        instance.visit(type.dictionary, other.dictionary));\n}\nfunction compareInterval(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.unit === other.unit);\n}\nfunction compareFixedSizeList(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.listSize === other.listSize &&\n        type.children.length === other.children.length &&\n        instance.compareFields(type.children, other.children));\n}\nfunction compareMap(type, other) {\n    return (type === other) || (compareConstructor(type, other) &&\n        type.keysSorted === other.keysSorted &&\n        type.children.length === other.children.length &&\n        instance.compareFields(type.children, other.children));\n}\nTypeComparator.prototype.visitNull = compareAny;\nTypeComparator.prototype.visitBool = compareAny;\nTypeComparator.prototype.visitInt = compareInt;\nTypeComparator.prototype.visitInt8 = compareInt;\nTypeComparator.prototype.visitInt16 = compareInt;\nTypeComparator.prototype.visitInt32 = compareInt;\nTypeComparator.prototype.visitInt64 = compareInt;\nTypeComparator.prototype.visitUint8 = compareInt;\nTypeComparator.prototype.visitUint16 = compareInt;\nTypeComparator.prototype.visitUint32 = compareInt;\nTypeComparator.prototype.visitUint64 = compareInt;\nTypeComparator.prototype.visitFloat = compareFloat;\nTypeComparator.prototype.visitFloat16 = compareFloat;\nTypeComparator.prototype.visitFloat32 = compareFloat;\nTypeComparator.prototype.visitFloat64 = compareFloat;\nTypeComparator.prototype.visitUtf8 = compareAny;\nTypeComparator.prototype.visitBinary = compareAny;\nTypeComparator.prototype.visitFixedSizeBinary = compareFixedSizeBinary;\nTypeComparator.prototype.visitDate = compareDate;\nTypeComparator.prototype.visitDateDay = compareDate;\nTypeComparator.prototype.visitDateMillisecond = compareDate;\nTypeComparator.prototype.visitTimestamp = compareTimestamp;\nTypeComparator.prototype.visitTimestampSecond = compareTimestamp;\nTypeComparator.prototype.visitTimestampMillisecond = compareTimestamp;\nTypeComparator.prototype.visitTimestampMicrosecond = compareTimestamp;\nTypeComparator.prototype.visitTimestampNanosecond = compareTimestamp;\nTypeComparator.prototype.visitTime = compareTime;\nTypeComparator.prototype.visitTimeSecond = compareTime;\nTypeComparator.prototype.visitTimeMillisecond = compareTime;\nTypeComparator.prototype.visitTimeMicrosecond = compareTime;\nTypeComparator.prototype.visitTimeNanosecond = compareTime;\nTypeComparator.prototype.visitDecimal = compareAny;\nTypeComparator.prototype.visitList = compareList;\nTypeComparator.prototype.visitStruct = compareStruct;\nTypeComparator.prototype.visitUnion = compareUnion;\nTypeComparator.prototype.visitDenseUnion = compareUnion;\nTypeComparator.prototype.visitSparseUnion = compareUnion;\nTypeComparator.prototype.visitDictionary = compareDictionary;\nTypeComparator.prototype.visitInterval = compareInterval;\nTypeComparator.prototype.visitIntervalDayTime = compareInterval;\nTypeComparator.prototype.visitIntervalYearMonth = compareInterval;\nTypeComparator.prototype.visitFixedSizeList = compareFixedSizeList;\nTypeComparator.prototype.visitMap = compareMap;\n/** @ignore */\nconst instance = new TypeComparator();\n\n//# sourceMappingURL=typecomparator.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/typecomparator.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/vectorassembler.mjs":
/*!*******************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/vectorassembler.mjs ***!
  \*******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   VectorAssembler: () => (/* binding */ VectorAssembler)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _recordbatch__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../recordbatch */ \"../../node_modules/apache-arrow/recordbatch.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_args__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/args */ \"../../node_modules/apache-arrow/util/args.mjs\");\n/* harmony import */ var _ipc_metadata_message__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../ipc/metadata/message */ \"../../node_modules/apache-arrow/ipc/metadata/message.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n/** @ignore */\nclass VectorAssembler extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    constructor() {\n        super();\n        this._byteLength = 0;\n        this._nodes = [];\n        this._buffers = [];\n        this._bufferRegions = [];\n    }\n    /** @nocollapse */\n    static assemble(...args) {\n        const assembler = new VectorAssembler();\n        const vectorChildren = (0,_util_args__WEBPACK_IMPORTED_MODULE_5__.selectVectorChildrenArgs)(_recordbatch__WEBPACK_IMPORTED_MODULE_2__.RecordBatch, args);\n        const [assembleResult = assembler] = assembler.visitMany(vectorChildren);\n        return assembleResult;\n    }\n    visit(vector) {\n        if (!_type__WEBPACK_IMPORTED_MODULE_7__.DataType.isDictionary(vector.type)) {\n            const { data, length, nullCount } = vector;\n            if (length > 2147483647) {\n                /* istanbul ignore next */\n                throw new RangeError('Cannot write arrays larger than 2^31 - 1 in length');\n            }\n            if (!_type__WEBPACK_IMPORTED_MODULE_7__.DataType.isNull(vector.type)) {\n                addBuffer.call(this, nullCount <= 0\n                    ? new Uint8Array(0) // placeholder validity buffer\n                    : (0,_util_bit__WEBPACK_IMPORTED_MODULE_4__.truncateBitmap)(data.offset, length, data.nullBitmap));\n            }\n            this.nodes.push(new _ipc_metadata_message__WEBPACK_IMPORTED_MODULE_6__.FieldNode(length, nullCount));\n        }\n        return super.visit(vector);\n    }\n    visitNull(_nullV) {\n        return this;\n    }\n    visitDictionary(vector) {\n        // Assemble the indices here, Dictionary assembled separately.\n        return this.visit(vector.indices);\n    }\n    get nodes() { return this._nodes; }\n    get buffers() { return this._buffers; }\n    get byteLength() { return this._byteLength; }\n    get bufferRegions() { return this._bufferRegions; }\n}\n/** @ignore */\nfunction addBuffer(values) {\n    const byteLength = (values.byteLength + 7) & ~7; // Round up to a multiple of 8\n    this.buffers.push(values);\n    this.bufferRegions.push(new _ipc_metadata_message__WEBPACK_IMPORTED_MODULE_6__.BufferRegion(this._byteLength, byteLength));\n    this._byteLength += byteLength;\n    return this;\n}\n/** @ignore */\nfunction assembleUnion(vector) {\n    const { type, length, typeIds, valueOffsets } = vector;\n    // All Union Vectors have a typeIds buffer\n    addBuffer.call(this, typeIds);\n    // If this is a Sparse Union, treat it like all other Nested types\n    if (type.mode === _enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode.Sparse) {\n        return assembleNestedVector.call(this, vector);\n    }\n    else if (type.mode === _enum__WEBPACK_IMPORTED_MODULE_1__.UnionMode.Dense) {\n        // If this is a Dense Union, add the valueOffsets buffer and potentially slice the children\n        if (vector.offset <= 0) {\n            // If the Vector hasn't been sliced, write the existing valueOffsets\n            addBuffer.call(this, valueOffsets);\n            // We can treat this like all other Nested types\n            return assembleNestedVector.call(this, vector);\n        }\n        else {\n            // A sliced Dense Union is an unpleasant case. Because the offsets are different for\n            // each child vector, we need to \"rebase\" the valueOffsets for each child\n            // Union typeIds are not necessary 0-indexed\n            const maxChildTypeId = typeIds.reduce((x, y) => Math.max(x, y), typeIds[0]);\n            const childLengths = new Int32Array(maxChildTypeId + 1);\n            // Set all to -1 to indicate that we haven't observed a first occurrence of a particular child yet\n            const childOffsets = new Int32Array(maxChildTypeId + 1).fill(-1);\n            const shiftedOffsets = new Int32Array(length);\n            // If we have a non-zero offset, then the value offsets do not start at\n            // zero. We must a) create a new offsets array with shifted offsets and\n            // b) slice the values array accordingly\n            const unshiftedOffsets = (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.rebaseValueOffsets)(-valueOffsets[0], length, valueOffsets);\n            for (let typeId, shift, index = -1; ++index < length;) {\n                if ((shift = childOffsets[typeId = typeIds[index]]) === -1) {\n                    shift = childOffsets[typeId] = unshiftedOffsets[typeId];\n                }\n                shiftedOffsets[index] = unshiftedOffsets[index] - shift;\n                ++childLengths[typeId];\n            }\n            addBuffer.call(this, shiftedOffsets);\n            // Slice and visit children accordingly\n            for (let child, childIndex = -1, numChildren = type.children.length; ++childIndex < numChildren;) {\n                if (child = vector.getChildAt(childIndex)) {\n                    const typeId = type.typeIds[childIndex];\n                    const childLength = Math.min(length, childLengths[typeId]);\n                    this.visit(child.slice(childOffsets[typeId], childLength));\n                }\n            }\n        }\n    }\n    return this;\n}\n/** @ignore */\nfunction assembleBoolVector(vector) {\n    // Bool vector is a special case of FlatVector, as its data buffer needs to stay packed\n    let values;\n    if (vector.nullCount >= vector.length) {\n        // If all values are null, just insert a placeholder empty data buffer (fastest path)\n        return addBuffer.call(this, new Uint8Array(0));\n    }\n    else if ((values = vector.values) instanceof Uint8Array) {\n        // If values is already a Uint8Array, slice the bitmap (fast path)\n        return addBuffer.call(this, (0,_util_bit__WEBPACK_IMPORTED_MODULE_4__.truncateBitmap)(vector.offset, vector.length, values));\n    }\n    // Otherwise if the underlying data *isn't* a Uint8Array, enumerate the\n    // values as bools and re-pack them into a Uint8Array. This code isn't\n    // reachable unless you're trying to manipulate the Data internals,\n    // we we're only doing this for safety.\n    /* istanbul ignore next */\n    return addBuffer.call(this, (0,_util_bit__WEBPACK_IMPORTED_MODULE_4__.packBools)(vector));\n}\n/** @ignore */\nfunction assembleFlatVector(vector) {\n    return addBuffer.call(this, vector.values.subarray(0, vector.length * vector.stride));\n}\n/** @ignore */\nfunction assembleFlatListVector(vector) {\n    const { length, values, valueOffsets } = vector;\n    const firstOffset = valueOffsets[0];\n    const lastOffset = valueOffsets[length];\n    const byteLength = Math.min(lastOffset - firstOffset, values.byteLength - firstOffset);\n    // Push in the order FlatList types read their buffers\n    addBuffer.call(this, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.rebaseValueOffsets)(-valueOffsets[0], length, valueOffsets)); // valueOffsets buffer first\n    addBuffer.call(this, values.subarray(firstOffset, firstOffset + byteLength)); // sliced values buffer second\n    return this;\n}\n/** @ignore */\nfunction assembleListVector(vector) {\n    const { length, valueOffsets } = vector;\n    // If we have valueOffsets (MapVector, ListVector), push that buffer first\n    if (valueOffsets) {\n        addBuffer.call(this, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_3__.rebaseValueOffsets)(valueOffsets[0], length, valueOffsets));\n    }\n    // Then insert the List's values child\n    return this.visit(vector.getChildAt(0));\n}\n/** @ignore */\nfunction assembleNestedVector(vector) {\n    return this.visitMany(vector.type.children.map((_, i) => vector.getChildAt(i)).filter(Boolean))[0];\n}\nVectorAssembler.prototype.visitBool = assembleBoolVector;\nVectorAssembler.prototype.visitInt = assembleFlatVector;\nVectorAssembler.prototype.visitFloat = assembleFlatVector;\nVectorAssembler.prototype.visitUtf8 = assembleFlatListVector;\nVectorAssembler.prototype.visitBinary = assembleFlatListVector;\nVectorAssembler.prototype.visitFixedSizeBinary = assembleFlatVector;\nVectorAssembler.prototype.visitDate = assembleFlatVector;\nVectorAssembler.prototype.visitTimestamp = assembleFlatVector;\nVectorAssembler.prototype.visitTime = assembleFlatVector;\nVectorAssembler.prototype.visitDecimal = assembleFlatVector;\nVectorAssembler.prototype.visitList = assembleListVector;\nVectorAssembler.prototype.visitStruct = assembleNestedVector;\nVectorAssembler.prototype.visitUnion = assembleUnion;\nVectorAssembler.prototype.visitInterval = assembleFlatVector;\nVectorAssembler.prototype.visitFixedSizeList = assembleListVector;\nVectorAssembler.prototype.visitMap = assembleListVector;\n\n//# sourceMappingURL=vectorassembler.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/vectorassembler.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/vectorctor.mjs":
/*!**************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/vectorctor.mjs ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   GetVectorConstructor: () => (/* binding */ GetVectorConstructor),\n/* harmony export */   instance: () => (/* binding */ instance)\n/* harmony export */ });\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _vector_binary__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../vector/binary */ \"../../node_modules/apache-arrow/vector/binary.mjs\");\n/* harmony import */ var _vector_bool__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../vector/bool */ \"../../node_modules/apache-arrow/vector/bool.mjs\");\n/* harmony import */ var _vector_date__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../vector/date */ \"../../node_modules/apache-arrow/vector/date.mjs\");\n/* harmony import */ var _vector_decimal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../vector/decimal */ \"../../node_modules/apache-arrow/vector/decimal.mjs\");\n/* harmony import */ var _vector_dictionary__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../vector/dictionary */ \"../../node_modules/apache-arrow/vector/dictionary.mjs\");\n/* harmony import */ var _vector_fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../vector/fixedsizebinary */ \"../../node_modules/apache-arrow/vector/fixedsizebinary.mjs\");\n/* harmony import */ var _vector_fixedsizelist__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../vector/fixedsizelist */ \"../../node_modules/apache-arrow/vector/fixedsizelist.mjs\");\n/* harmony import */ var _vector_float__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../vector/float */ \"../../node_modules/apache-arrow/vector/float.mjs\");\n/* harmony import */ var _vector_interval__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../vector/interval */ \"../../node_modules/apache-arrow/vector/interval.mjs\");\n/* harmony import */ var _vector_int__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../vector/int */ \"../../node_modules/apache-arrow/vector/int.mjs\");\n/* harmony import */ var _vector_list__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../vector/list */ \"../../node_modules/apache-arrow/vector/list.mjs\");\n/* harmony import */ var _vector_map__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../vector/map */ \"../../node_modules/apache-arrow/vector/map.mjs\");\n/* harmony import */ var _vector_null__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../vector/null */ \"../../node_modules/apache-arrow/vector/null.mjs\");\n/* harmony import */ var _vector_struct__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../vector/struct */ \"../../node_modules/apache-arrow/vector/struct.mjs\");\n/* harmony import */ var _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../vector/timestamp */ \"../../node_modules/apache-arrow/vector/timestamp.mjs\");\n/* harmony import */ var _vector_time__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../vector/time */ \"../../node_modules/apache-arrow/vector/time.mjs\");\n/* harmony import */ var _vector_union__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../vector/union */ \"../../node_modules/apache-arrow/vector/union.mjs\");\n/* harmony import */ var _vector_utf8__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../vector/utf8 */ \"../../node_modules/apache-arrow/vector/utf8.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/** @ignore */\nclass GetVectorConstructor extends _visitor__WEBPACK_IMPORTED_MODULE_0__.Visitor {\n    visitNull() { return _vector_null__WEBPACK_IMPORTED_MODULE_13__.NullVector; }\n    visitBool() { return _vector_bool__WEBPACK_IMPORTED_MODULE_2__.BoolVector; }\n    visitInt() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.IntVector; }\n    visitInt8() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Int8Vector; }\n    visitInt16() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Int16Vector; }\n    visitInt32() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Int32Vector; }\n    visitInt64() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Int64Vector; }\n    visitUint8() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Uint8Vector; }\n    visitUint16() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Uint16Vector; }\n    visitUint32() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Uint32Vector; }\n    visitUint64() { return _vector_int__WEBPACK_IMPORTED_MODULE_10__.Uint64Vector; }\n    visitFloat() { return _vector_float__WEBPACK_IMPORTED_MODULE_8__.FloatVector; }\n    visitFloat16() { return _vector_float__WEBPACK_IMPORTED_MODULE_8__.Float16Vector; }\n    visitFloat32() { return _vector_float__WEBPACK_IMPORTED_MODULE_8__.Float32Vector; }\n    visitFloat64() { return _vector_float__WEBPACK_IMPORTED_MODULE_8__.Float64Vector; }\n    visitUtf8() { return _vector_utf8__WEBPACK_IMPORTED_MODULE_18__.Utf8Vector; }\n    visitBinary() { return _vector_binary__WEBPACK_IMPORTED_MODULE_1__.BinaryVector; }\n    visitFixedSizeBinary() { return _vector_fixedsizebinary__WEBPACK_IMPORTED_MODULE_6__.FixedSizeBinaryVector; }\n    visitDate() { return _vector_date__WEBPACK_IMPORTED_MODULE_3__.DateVector; }\n    visitDateDay() { return _vector_date__WEBPACK_IMPORTED_MODULE_3__.DateDayVector; }\n    visitDateMillisecond() { return _vector_date__WEBPACK_IMPORTED_MODULE_3__.DateMillisecondVector; }\n    visitTimestamp() { return _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampVector; }\n    visitTimestampSecond() { return _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampSecondVector; }\n    visitTimestampMillisecond() { return _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampMillisecondVector; }\n    visitTimestampMicrosecond() { return _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampMicrosecondVector; }\n    visitTimestampNanosecond() { return _vector_timestamp__WEBPACK_IMPORTED_MODULE_15__.TimestampNanosecondVector; }\n    visitTime() { return _vector_time__WEBPACK_IMPORTED_MODULE_16__.TimeVector; }\n    visitTimeSecond() { return _vector_time__WEBPACK_IMPORTED_MODULE_16__.TimeSecondVector; }\n    visitTimeMillisecond() { return _vector_time__WEBPACK_IMPORTED_MODULE_16__.TimeMillisecondVector; }\n    visitTimeMicrosecond() { return _vector_time__WEBPACK_IMPORTED_MODULE_16__.TimeMicrosecondVector; }\n    visitTimeNanosecond() { return _vector_time__WEBPACK_IMPORTED_MODULE_16__.TimeNanosecondVector; }\n    visitDecimal() { return _vector_decimal__WEBPACK_IMPORTED_MODULE_4__.DecimalVector; }\n    visitList() { return _vector_list__WEBPACK_IMPORTED_MODULE_11__.ListVector; }\n    visitStruct() { return _vector_struct__WEBPACK_IMPORTED_MODULE_14__.StructVector; }\n    visitUnion() { return _vector_union__WEBPACK_IMPORTED_MODULE_17__.UnionVector; }\n    visitDenseUnion() { return _vector_union__WEBPACK_IMPORTED_MODULE_17__.DenseUnionVector; }\n    visitSparseUnion() { return _vector_union__WEBPACK_IMPORTED_MODULE_17__.SparseUnionVector; }\n    visitDictionary() { return _vector_dictionary__WEBPACK_IMPORTED_MODULE_5__.DictionaryVector; }\n    visitInterval() { return _vector_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalVector; }\n    visitIntervalDayTime() { return _vector_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalDayTimeVector; }\n    visitIntervalYearMonth() { return _vector_interval__WEBPACK_IMPORTED_MODULE_9__.IntervalYearMonthVector; }\n    visitFixedSizeList() { return _vector_fixedsizelist__WEBPACK_IMPORTED_MODULE_7__.FixedSizeListVector; }\n    visitMap() { return _vector_map__WEBPACK_IMPORTED_MODULE_12__.MapVector; }\n}\n/** @ignore */\nconst instance = new GetVectorConstructor();\n\n//# sourceMappingURL=vectorctor.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/vectorctor.mjs?");

/***/ }),

/***/ "../../node_modules/apache-arrow/visitor/vectorloader.mjs":
/*!****************************************************************!*\
  !*** ../../node_modules/apache-arrow/visitor/vectorloader.mjs ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JSONVectorLoader: () => (/* binding */ JSONVectorLoader),\n/* harmony export */   VectorLoader: () => (/* binding */ VectorLoader)\n/* harmony export */ });\n/* harmony import */ var _data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data */ \"../../node_modules/apache-arrow/data.mjs\");\n/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../schema */ \"../../node_modules/apache-arrow/schema.mjs\");\n/* harmony import */ var _type__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../type */ \"../../node_modules/apache-arrow/type.mjs\");\n/* harmony import */ var _visitor__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../visitor */ \"../../node_modules/apache-arrow/visitor.mjs\");\n/* harmony import */ var _util_bit__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/bit */ \"../../node_modules/apache-arrow/util/bit.mjs\");\n/* harmony import */ var _util_utf8__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/utf8 */ \"../../node_modules/apache-arrow/util/utf8.mjs\");\n/* harmony import */ var _util_int__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/int */ \"../../node_modules/apache-arrow/util/int.mjs\");\n/* harmony import */ var _enum__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../enum */ \"../../node_modules/apache-arrow/enum.mjs\");\n/* harmony import */ var _util_buffer__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/buffer */ \"../../node_modules/apache-arrow/util/buffer.mjs\");\n// Licensed to the Apache Software Foundation (ASF) under one\n// or more contributor license agreements.  See the NOTICE file\n// distributed with this work for additional information\n// regarding copyright ownership.  The ASF licenses this file\n// to you under the Apache License, Version 2.0 (the\n// \"License\"); you may not use this file except in compliance\n// with the License.  You may obtain a copy of the License at\n//\n//   http://www.apache.org/licenses/LICENSE-2.0\n//\n// Unless required by applicable law or agreed to in writing,\n// software distributed under the License is distributed on an\n// \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n// KIND, either express or implied.  See the License for the\n// specific language governing permissions and limitations\n// under the License.\n\n\n\n\n\n\n\n\n\n/** @ignore */\nclass VectorLoader extends _visitor__WEBPACK_IMPORTED_MODULE_3__.Visitor {\n    constructor(bytes, nodes, buffers, dictionaries) {\n        super();\n        this.nodesIndex = -1;\n        this.buffersIndex = -1;\n        this.bytes = bytes;\n        this.nodes = nodes;\n        this.buffers = buffers;\n        this.dictionaries = dictionaries;\n    }\n    visit(node) {\n        return super.visit(node instanceof _schema__WEBPACK_IMPORTED_MODULE_1__.Field ? node.type : node);\n    }\n    visitNull(type, { length, } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Null(type, 0, length); }\n    visitBool(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Bool(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitInt(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Int(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitFloat(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Float(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitUtf8(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Utf8(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readOffsets(type), this.readData(type)); }\n    visitBinary(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Binary(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readOffsets(type), this.readData(type)); }\n    visitFixedSizeBinary(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.FixedSizeBinary(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitDate(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Date(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitTimestamp(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Timestamp(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitTime(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Time(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitDecimal(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Decimal(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitList(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.List(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readOffsets(type), this.visit(type.children[0])); }\n    visitStruct(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Struct(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.visitMany(type.children)); }\n    visitUnion(type) { return type.mode === _enum__WEBPACK_IMPORTED_MODULE_7__.UnionMode.Sparse ? this.visitSparseUnion(type) : this.visitDenseUnion(type); }\n    visitDenseUnion(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Union(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readTypeIds(type), this.readOffsets(type), this.visitMany(type.children)); }\n    visitSparseUnion(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Union(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readTypeIds(type), this.visitMany(type.children)); }\n    visitDictionary(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Dictionary(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type.indices), this.readDictionary(type)); }\n    visitInterval(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Interval(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readData(type)); }\n    visitFixedSizeList(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.FixedSizeList(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.visit(type.children[0])); }\n    visitMap(type, { length, nullCount } = this.nextFieldNode()) { return _data__WEBPACK_IMPORTED_MODULE_0__.Data.Map(type, 0, length, nullCount, this.readNullBitmap(type, nullCount), this.readOffsets(type), this.visit(type.children[0])); }\n    nextFieldNode() { return this.nodes[++this.nodesIndex]; }\n    nextBufferRange() { return this.buffers[++this.buffersIndex]; }\n    readNullBitmap(type, nullCount, buffer = this.nextBufferRange()) {\n        return nullCount > 0 && this.readData(type, buffer) || new Uint8Array(0);\n    }\n    readOffsets(type, buffer) { return this.readData(type, buffer); }\n    readTypeIds(type, buffer) { return this.readData(type, buffer); }\n    readData(_type, { length, offset } = this.nextBufferRange()) {\n        return this.bytes.subarray(offset, offset + length);\n    }\n    readDictionary(type) {\n        return this.dictionaries.get(type.id);\n    }\n}\n/** @ignore */\nclass JSONVectorLoader extends VectorLoader {\n    constructor(sources, nodes, buffers, dictionaries) {\n        super(new Uint8Array(0), nodes, buffers, dictionaries);\n        this.sources = sources;\n    }\n    readNullBitmap(_type, nullCount, { offset } = this.nextBufferRange()) {\n        return nullCount <= 0 ? new Uint8Array(0) : (0,_util_bit__WEBPACK_IMPORTED_MODULE_4__.packBools)(this.sources[offset]);\n    }\n    readOffsets(_type, { offset } = this.nextBufferRange()) {\n        return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Int32Array, this.sources[offset]));\n    }\n    readTypeIds(type, { offset } = this.nextBufferRange()) {\n        return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(type.ArrayType, this.sources[offset]));\n    }\n    readData(type, { offset } = this.nextBufferRange()) {\n        const { sources } = this;\n        if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isTimestamp(type)) {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, _util_int__WEBPACK_IMPORTED_MODULE_6__.Int64.convertArray(sources[offset]));\n        }\n        else if ((_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isInt(type) || _type__WEBPACK_IMPORTED_MODULE_2__.DataType.isTime(type)) && type.bitWidth === 64) {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, _util_int__WEBPACK_IMPORTED_MODULE_6__.Int64.convertArray(sources[offset]));\n        }\n        else if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isDate(type) && type.unit === _enum__WEBPACK_IMPORTED_MODULE_7__.DateUnit.MILLISECOND) {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, _util_int__WEBPACK_IMPORTED_MODULE_6__.Int64.convertArray(sources[offset]));\n        }\n        else if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isDecimal(type)) {\n            return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, _util_int__WEBPACK_IMPORTED_MODULE_6__.Int128.convertArray(sources[offset]));\n        }\n        else if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isBinary(type) || _type__WEBPACK_IMPORTED_MODULE_2__.DataType.isFixedSizeBinary(type)) {\n            return binaryDataFromJSON(sources[offset]);\n        }\n        else if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isBool(type)) {\n            return (0,_util_bit__WEBPACK_IMPORTED_MODULE_4__.packBools)(sources[offset]);\n        }\n        else if (_type__WEBPACK_IMPORTED_MODULE_2__.DataType.isUtf8(type)) {\n            return (0,_util_utf8__WEBPACK_IMPORTED_MODULE_5__.encodeUtf8)(sources[offset].join(''));\n        }\n        return (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(Uint8Array, (0,_util_buffer__WEBPACK_IMPORTED_MODULE_8__.toArrayBufferView)(type.ArrayType, sources[offset].map((x) => +x)));\n    }\n}\n/** @ignore */\nfunction binaryDataFromJSON(values) {\n    // \"DATA\": [\"49BC7D5B6C47D2\",\"3F5FB6D9322026\"]\n    // There are definitely more efficient ways to do this... but it gets the\n    // job done.\n    const joined = values.join('');\n    const data = new Uint8Array(joined.length / 2);\n    for (let i = 0; i < joined.length; i += 2) {\n        data[i >> 1] = parseInt(joined.substr(i, 2), 16);\n    }\n    return data;\n}\n\n//# sourceMappingURL=vectorloader.mjs.map\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/apache-arrow/visitor/vectorloader.mjs?");

/***/ }),

/***/ "../../node_modules/d3-array/src/ascending.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-array/src/ascending.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ascending)\n/* harmony export */ });\nfunction ascending(a, b) {\n  return a == null || b == null ? NaN : a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/ascending.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/bisect.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-array/src/bisect.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   bisectCenter: () => (/* binding */ bisectCenter),\n/* harmony export */   bisectLeft: () => (/* binding */ bisectLeft),\n/* harmony export */   bisectRight: () => (/* binding */ bisectRight),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _ascending_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ascending.js */ \"../../node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var _bisector_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./bisector.js */ \"../../node_modules/d3-array/src/bisector.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-array/src/number.js\");\n\n\n\n\nconst ascendingBisect = (0,_bisector_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(_ascending_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\nconst bisectRight = ascendingBisect.right;\nconst bisectLeft = ascendingBisect.left;\nconst bisectCenter = (0,_bisector_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(_number_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]).center;\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (bisectRight);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/bisect.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/bisector.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/bisector.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ bisector)\n/* harmony export */ });\n/* harmony import */ var _ascending_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ascending.js */ \"../../node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var _descending_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./descending.js */ \"../../node_modules/d3-array/src/descending.js\");\n\n\n\nfunction bisector(f) {\n  let compare1, compare2, delta;\n\n  // If an accessor is specified, promote it to a comparator. In this case we\n  // can test whether the search value is (self-) comparable. We can’t do this\n  // for a comparator (except for specific, known comparators) because we can’t\n  // tell if the comparator is symmetric, and an asymmetric comparator can’t be\n  // used to test whether a single value is comparable.\n  if (f.length !== 2) {\n    compare1 = _ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n    compare2 = (d, x) => (0,_ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(f(d), x);\n    delta = (d, x) => f(d) - x;\n  } else {\n    compare1 = f === _ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] || f === _descending_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"] ? f : zero;\n    compare2 = f;\n    delta = f;\n  }\n\n  function left(a, x, lo = 0, hi = a.length) {\n    if (lo < hi) {\n      if (compare1(x, x) !== 0) return hi;\n      do {\n        const mid = (lo + hi) >>> 1;\n        if (compare2(a[mid], x) < 0) lo = mid + 1;\n        else hi = mid;\n      } while (lo < hi);\n    }\n    return lo;\n  }\n\n  function right(a, x, lo = 0, hi = a.length) {\n    if (lo < hi) {\n      if (compare1(x, x) !== 0) return hi;\n      do {\n        const mid = (lo + hi) >>> 1;\n        if (compare2(a[mid], x) <= 0) lo = mid + 1;\n        else hi = mid;\n      } while (lo < hi);\n    }\n    return lo;\n  }\n\n  function center(a, x, lo = 0, hi = a.length) {\n    const i = left(a, x, lo, hi - 1);\n    return i > lo && delta(a[i - 1], x) > -delta(a[i], x) ? i - 1 : i;\n  }\n\n  return {left, center, right};\n}\n\nfunction zero() {\n  return 0;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/bisector.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/descending.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-array/src/descending.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ descending)\n/* harmony export */ });\nfunction descending(a, b) {\n  return a == null || b == null ? NaN\n    : b < a ? -1\n    : b > a ? 1\n    : b >= a ? 0\n    : NaN;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/descending.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/deviation.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-array/src/deviation.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ deviation)\n/* harmony export */ });\n/* harmony import */ var _variance_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./variance.js */ \"../../node_modules/d3-array/src/variance.js\");\n\n\nfunction deviation(values, valueof) {\n  const v = (0,_variance_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(values, valueof);\n  return v ? Math.sqrt(v) : v;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/deviation.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/fsum.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-array/src/fsum.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Adder: () => (/* binding */ Adder),\n/* harmony export */   fcumsum: () => (/* binding */ fcumsum),\n/* harmony export */   fsum: () => (/* binding */ fsum)\n/* harmony export */ });\n// https://github.com/python/cpython/blob/a74eea238f5baba15797e2e8b570d153bc8690a7/Modules/mathmodule.c#L1423\nclass Adder {\n  constructor() {\n    this._partials = new Float64Array(32);\n    this._n = 0;\n  }\n  add(x) {\n    const p = this._partials;\n    let i = 0;\n    for (let j = 0; j < this._n && j < 32; j++) {\n      const y = p[j],\n        hi = x + y,\n        lo = Math.abs(x) < Math.abs(y) ? x - (hi - y) : y - (hi - x);\n      if (lo) p[i++] = lo;\n      x = hi;\n    }\n    p[i] = x;\n    this._n = i + 1;\n    return this;\n  }\n  valueOf() {\n    const p = this._partials;\n    let n = this._n, x, y, lo, hi = 0;\n    if (n > 0) {\n      hi = p[--n];\n      while (n > 0) {\n        x = hi;\n        y = p[--n];\n        hi = x + y;\n        lo = y - (hi - x);\n        if (lo) break;\n      }\n      if (n > 0 && ((lo < 0 && p[n - 1] < 0) || (lo > 0 && p[n - 1] > 0))) {\n        y = lo * 2;\n        x = hi + y;\n        if (y == x - hi) hi = x;\n      }\n    }\n    return hi;\n  }\n}\n\nfunction fsum(values, valueof) {\n  const adder = new Adder();\n  if (valueof === undefined) {\n    for (let value of values) {\n      if (value = +value) {\n        adder.add(value);\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if (value = +valueof(value, ++index, values)) {\n        adder.add(value);\n      }\n    }\n  }\n  return +adder;\n}\n\nfunction fcumsum(values, valueof) {\n  const adder = new Adder();\n  let index = -1;\n  return Float64Array.from(values, valueof === undefined\n      ? v => adder.add(+v || 0)\n      : v => adder.add(+valueof(v, ++index, values) || 0)\n  );\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/fsum.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/greatest.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/greatest.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ greatest)\n/* harmony export */ });\n/* harmony import */ var _ascending_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ascending.js */ \"../../node_modules/d3-array/src/ascending.js\");\n\n\nfunction greatest(values, compare = _ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]) {\n  let max;\n  let defined = false;\n  if (compare.length === 1) {\n    let maxValue;\n    for (const element of values) {\n      const value = compare(element);\n      if (defined\n          ? (0,_ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value, maxValue) > 0\n          : (0,_ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value, value) === 0) {\n        max = element;\n        maxValue = value;\n        defined = true;\n      }\n    }\n  } else {\n    for (const value of values) {\n      if (defined\n          ? compare(value, max) > 0\n          : compare(value, value) === 0) {\n        max = value;\n        defined = true;\n      }\n    }\n  }\n  return max;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/greatest.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/max.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-array/src/max.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ max)\n/* harmony export */ });\nfunction max(values, valueof) {\n  let max;\n  if (valueof === undefined) {\n    for (const value of values) {\n      if (value != null\n          && (max < value || (max === undefined && value >= value))) {\n        max = value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null\n          && (max < value || (max === undefined && value >= value))) {\n        max = value;\n      }\n    }\n  }\n  return max;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/max.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/maxIndex.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/maxIndex.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ maxIndex)\n/* harmony export */ });\nfunction maxIndex(values, valueof) {\n  let max;\n  let maxIndex = -1;\n  let index = -1;\n  if (valueof === undefined) {\n    for (const value of values) {\n      ++index;\n      if (value != null\n          && (max < value || (max === undefined && value >= value))) {\n        max = value, maxIndex = index;\n      }\n    }\n  } else {\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null\n          && (max < value || (max === undefined && value >= value))) {\n        max = value, maxIndex = index;\n      }\n    }\n  }\n  return maxIndex;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/maxIndex.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/mean.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-array/src/mean.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ mean)\n/* harmony export */ });\nfunction mean(values, valueof) {\n  let count = 0;\n  let sum = 0;\n  if (valueof === undefined) {\n    for (let value of values) {\n      if (value != null && (value = +value) >= value) {\n        ++count, sum += value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null && (value = +value) >= value) {\n        ++count, sum += value;\n      }\n    }\n  }\n  if (count) return sum / count;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/mean.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/median.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-array/src/median.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ median),\n/* harmony export */   medianIndex: () => (/* binding */ medianIndex)\n/* harmony export */ });\n/* harmony import */ var _quantile_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./quantile.js */ \"../../node_modules/d3-array/src/quantile.js\");\n\n\nfunction median(values, valueof) {\n  return (0,_quantile_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(values, 0.5, valueof);\n}\n\nfunction medianIndex(values, valueof) {\n  return (0,_quantile_js__WEBPACK_IMPORTED_MODULE_0__.quantileIndex)(values, 0.5, valueof);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/median.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/merge.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-array/src/merge.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ merge)\n/* harmony export */ });\nfunction* flatten(arrays) {\n  for (const array of arrays) {\n    yield* array;\n  }\n}\n\nfunction merge(arrays) {\n  return Array.from(flatten(arrays));\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/merge.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/min.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-array/src/min.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ min)\n/* harmony export */ });\nfunction min(values, valueof) {\n  let min;\n  if (valueof === undefined) {\n    for (const value of values) {\n      if (value != null\n          && (min > value || (min === undefined && value >= value))) {\n        min = value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null\n          && (min > value || (min === undefined && value >= value))) {\n        min = value;\n      }\n    }\n  }\n  return min;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/min.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/minIndex.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/minIndex.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ minIndex)\n/* harmony export */ });\nfunction minIndex(values, valueof) {\n  let min;\n  let minIndex = -1;\n  let index = -1;\n  if (valueof === undefined) {\n    for (const value of values) {\n      ++index;\n      if (value != null\n          && (min > value || (min === undefined && value >= value))) {\n        min = value, minIndex = index;\n      }\n    }\n  } else {\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null\n          && (min > value || (min === undefined && value >= value))) {\n        min = value, minIndex = index;\n      }\n    }\n  }\n  return minIndex;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/minIndex.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/number.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-array/src/number.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ number),\n/* harmony export */   numbers: () => (/* binding */ numbers)\n/* harmony export */ });\nfunction number(x) {\n  return x === null ? NaN : +x;\n}\n\nfunction* numbers(values, valueof) {\n  if (valueof === undefined) {\n    for (let value of values) {\n      if (value != null && (value = +value) >= value) {\n        yield value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null && (value = +value) >= value) {\n        yield value;\n      }\n    }\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/number.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/permute.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-array/src/permute.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ permute)\n/* harmony export */ });\nfunction permute(source, keys) {\n  return Array.from(keys, key => source[key]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/permute.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/quantile.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/quantile.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quantile),\n/* harmony export */   quantileIndex: () => (/* binding */ quantileIndex),\n/* harmony export */   quantileSorted: () => (/* binding */ quantileSorted)\n/* harmony export */ });\n/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./max.js */ \"../../node_modules/d3-array/src/max.js\");\n/* harmony import */ var _maxIndex_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./maxIndex.js */ \"../../node_modules/d3-array/src/maxIndex.js\");\n/* harmony import */ var _min_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./min.js */ \"../../node_modules/d3-array/src/min.js\");\n/* harmony import */ var _minIndex_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./minIndex.js */ \"../../node_modules/d3-array/src/minIndex.js\");\n/* harmony import */ var _quickselect_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./quickselect.js */ \"../../node_modules/d3-array/src/quickselect.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-array/src/number.js\");\n/* harmony import */ var _sort_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./sort.js */ \"../../node_modules/d3-array/src/sort.js\");\n/* harmony import */ var _greatest_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./greatest.js */ \"../../node_modules/d3-array/src/greatest.js\");\n\n\n\n\n\n\n\n\n\nfunction quantile(values, p, valueof) {\n  values = Float64Array.from((0,_number_js__WEBPACK_IMPORTED_MODULE_0__.numbers)(values, valueof));\n  if (!(n = values.length) || isNaN(p = +p)) return;\n  if (p <= 0 || n < 2) return (0,_min_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values);\n  if (p >= 1) return (0,_max_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(values);\n  var n,\n      i = (n - 1) * p,\n      i0 = Math.floor(i),\n      value0 = (0,_max_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])((0,_quickselect_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(values, i0).subarray(0, i0 + 1)),\n      value1 = (0,_min_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(values.subarray(i0 + 1));\n  return value0 + (value1 - value0) * (i - i0);\n}\n\nfunction quantileSorted(values, p, valueof = _number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]) {\n  if (!(n = values.length) || isNaN(p = +p)) return;\n  if (p <= 0 || n < 2) return +valueof(values[0], 0, values);\n  if (p >= 1) return +valueof(values[n - 1], n - 1, values);\n  var n,\n      i = (n - 1) * p,\n      i0 = Math.floor(i),\n      value0 = +valueof(values[i0], i0, values),\n      value1 = +valueof(values[i0 + 1], i0 + 1, values);\n  return value0 + (value1 - value0) * (i - i0);\n}\n\nfunction quantileIndex(values, p, valueof = _number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]) {\n  if (isNaN(p = +p)) return;\n  numbers = Float64Array.from(values, (_, i) => (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(valueof(values[i], i, values)));\n  if (p <= 0) return (0,_minIndex_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(numbers);\n  if (p >= 1) return (0,_maxIndex_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(numbers);\n  var numbers,\n      index = Uint32Array.from(values, (_, i) => i),\n      j = numbers.length - 1,\n      i = Math.floor(j * p);\n  (0,_quickselect_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(index, i, 0, j, (i, j) => (0,_sort_js__WEBPACK_IMPORTED_MODULE_6__.ascendingDefined)(numbers[i], numbers[j]));\n  i = (0,_greatest_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(index.subarray(0, i + 1), (i) => numbers[i]);\n  return i >= 0 ? i : -1;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/quantile.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/quickselect.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-array/src/quickselect.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quickselect)\n/* harmony export */ });\n/* harmony import */ var _sort_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./sort.js */ \"../../node_modules/d3-array/src/sort.js\");\n\n\n// Based on https://github.com/mourner/quickselect\n// ISC license, Copyright 2018 Vladimir Agafonkin.\nfunction quickselect(array, k, left = 0, right = Infinity, compare) {\n  k = Math.floor(k);\n  left = Math.floor(Math.max(0, left));\n  right = Math.floor(Math.min(array.length - 1, right));\n\n  if (!(left <= k && k <= right)) return array;\n\n  compare = compare === undefined ? _sort_js__WEBPACK_IMPORTED_MODULE_0__.ascendingDefined : (0,_sort_js__WEBPACK_IMPORTED_MODULE_0__.compareDefined)(compare);\n\n  while (right > left) {\n    if (right - left > 600) {\n      const n = right - left + 1;\n      const m = k - left + 1;\n      const z = Math.log(n);\n      const s = 0.5 * Math.exp(2 * z / 3);\n      const sd = 0.5 * Math.sqrt(z * s * (n - s) / n) * (m - n / 2 < 0 ? -1 : 1);\n      const newLeft = Math.max(left, Math.floor(k - m * s / n + sd));\n      const newRight = Math.min(right, Math.floor(k + (n - m) * s / n + sd));\n      quickselect(array, k, newLeft, newRight, compare);\n    }\n\n    const t = array[k];\n    let i = left;\n    let j = right;\n\n    swap(array, left, k);\n    if (compare(array[right], t) > 0) swap(array, left, right);\n\n    while (i < j) {\n      swap(array, i, j), ++i, --j;\n      while (compare(array[i], t) < 0) ++i;\n      while (compare(array[j], t) > 0) --j;\n    }\n\n    if (compare(array[left], t) === 0) swap(array, left, j);\n    else ++j, swap(array, j, right);\n\n    if (j <= k) left = j + 1;\n    if (k <= j) right = j - 1;\n  }\n\n  return array;\n}\n\nfunction swap(array, i, j) {\n  const t = array[i];\n  array[i] = array[j];\n  array[j] = t;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/quickselect.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/range.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-array/src/range.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ range)\n/* harmony export */ });\nfunction range(start, stop, step) {\n  start = +start, stop = +stop, step = (n = arguments.length) < 2 ? (stop = start, start = 0, 1) : n < 3 ? 1 : +step;\n\n  var i = -1,\n      n = Math.max(0, Math.ceil((stop - start) / step)) | 0,\n      range = new Array(n);\n\n  while (++i < n) {\n    range[i] = start + i * step;\n  }\n\n  return range;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/range.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/sort.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-array/src/sort.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   ascendingDefined: () => (/* binding */ ascendingDefined),\n/* harmony export */   compareDefined: () => (/* binding */ compareDefined),\n/* harmony export */   \"default\": () => (/* binding */ sort)\n/* harmony export */ });\n/* harmony import */ var _ascending_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ascending.js */ \"../../node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var _permute_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./permute.js */ \"../../node_modules/d3-array/src/permute.js\");\n\n\n\nfunction sort(values, ...F) {\n  if (typeof values[Symbol.iterator] !== \"function\") throw new TypeError(\"values is not iterable\");\n  values = Array.from(values);\n  let [f] = F;\n  if ((f && f.length !== 2) || F.length > 1) {\n    const index = Uint32Array.from(values, (d, i) => i);\n    if (F.length > 1) {\n      F = F.map(f => values.map(f));\n      index.sort((i, j) => {\n        for (const f of F) {\n          const c = ascendingDefined(f[i], f[j]);\n          if (c) return c;\n        }\n      });\n    } else {\n      f = values.map(f);\n      index.sort((i, j) => ascendingDefined(f[i], f[j]));\n    }\n    return (0,_permute_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(values, index);\n  }\n  return values.sort(compareDefined(f));\n}\n\nfunction compareDefined(compare = _ascending_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]) {\n  if (compare === _ascending_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]) return ascendingDefined;\n  if (typeof compare !== \"function\") throw new TypeError(\"compare is not a function\");\n  return (a, b) => {\n    const x = compare(a, b);\n    if (x || x === 0) return x;\n    return (compare(b, b) === 0) - (compare(a, a) === 0);\n  };\n}\n\nfunction ascendingDefined(a, b) {\n  return (a == null || !(a >= a)) - (b == null || !(b >= b)) || (a < b ? -1 : a > b ? 1 : 0);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/sort.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/sum.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-array/src/sum.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ sum)\n/* harmony export */ });\nfunction sum(values, valueof) {\n  let sum = 0;\n  if (valueof === undefined) {\n    for (let value of values) {\n      if (value = +value) {\n        sum += value;\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if (value = +valueof(value, ++index, values)) {\n        sum += value;\n      }\n    }\n  }\n  return sum;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/sum.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/ticks.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-array/src/ticks.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ticks),\n/* harmony export */   tickIncrement: () => (/* binding */ tickIncrement),\n/* harmony export */   tickStep: () => (/* binding */ tickStep)\n/* harmony export */ });\nconst e10 = Math.sqrt(50),\n    e5 = Math.sqrt(10),\n    e2 = Math.sqrt(2);\n\nfunction tickSpec(start, stop, count) {\n  const step = (stop - start) / Math.max(0, count),\n      power = Math.floor(Math.log10(step)),\n      error = step / Math.pow(10, power),\n      factor = error >= e10 ? 10 : error >= e5 ? 5 : error >= e2 ? 2 : 1;\n  let i1, i2, inc;\n  if (power < 0) {\n    inc = Math.pow(10, -power) / factor;\n    i1 = Math.round(start * inc);\n    i2 = Math.round(stop * inc);\n    if (i1 / inc < start) ++i1;\n    if (i2 / inc > stop) --i2;\n    inc = -inc;\n  } else {\n    inc = Math.pow(10, power) * factor;\n    i1 = Math.round(start / inc);\n    i2 = Math.round(stop / inc);\n    if (i1 * inc < start) ++i1;\n    if (i2 * inc > stop) --i2;\n  }\n  if (i2 < i1 && 0.5 <= count && count < 2) return tickSpec(start, stop, count * 2);\n  return [i1, i2, inc];\n}\n\nfunction ticks(start, stop, count) {\n  stop = +stop, start = +start, count = +count;\n  if (!(count > 0)) return [];\n  if (start === stop) return [start];\n  const reverse = stop < start, [i1, i2, inc] = reverse ? tickSpec(stop, start, count) : tickSpec(start, stop, count);\n  if (!(i2 >= i1)) return [];\n  const n = i2 - i1 + 1, ticks = new Array(n);\n  if (reverse) {\n    if (inc < 0) for (let i = 0; i < n; ++i) ticks[i] = (i2 - i) / -inc;\n    else for (let i = 0; i < n; ++i) ticks[i] = (i2 - i) * inc;\n  } else {\n    if (inc < 0) for (let i = 0; i < n; ++i) ticks[i] = (i1 + i) / -inc;\n    else for (let i = 0; i < n; ++i) ticks[i] = (i1 + i) * inc;\n  }\n  return ticks;\n}\n\nfunction tickIncrement(start, stop, count) {\n  stop = +stop, start = +start, count = +count;\n  return tickSpec(start, stop, count)[2];\n}\n\nfunction tickStep(start, stop, count) {\n  stop = +stop, start = +start, count = +count;\n  const reverse = stop < start, inc = reverse ? tickIncrement(stop, start, count) : tickIncrement(start, stop, count);\n  return (reverse ? -1 : 1) * (inc < 0 ? 1 / -inc : inc);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/ticks.js?");

/***/ }),

/***/ "../../node_modules/d3-array/src/variance.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-array/src/variance.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ variance)\n/* harmony export */ });\nfunction variance(values, valueof) {\n  let count = 0;\n  let delta;\n  let mean = 0;\n  let sum = 0;\n  if (valueof === undefined) {\n    for (let value of values) {\n      if (value != null && (value = +value) >= value) {\n        delta = value - mean;\n        mean += delta / ++count;\n        sum += delta * (value - mean);\n      }\n    }\n  } else {\n    let index = -1;\n    for (let value of values) {\n      if ((value = valueof(value, ++index, values)) != null && (value = +value) >= value) {\n        delta = value - mean;\n        mean += delta / ++count;\n        sum += delta * (value - mean);\n      }\n    }\n  }\n  if (count > 1) return sum / (count - 1);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-array/src/variance.js?");

/***/ }),

/***/ "../../node_modules/d3-color/src/color.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-color/src/color.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Color: () => (/* binding */ Color),\n/* harmony export */   Rgb: () => (/* binding */ Rgb),\n/* harmony export */   brighter: () => (/* binding */ brighter),\n/* harmony export */   darker: () => (/* binding */ darker),\n/* harmony export */   \"default\": () => (/* binding */ color),\n/* harmony export */   hsl: () => (/* binding */ hsl),\n/* harmony export */   hslConvert: () => (/* binding */ hslConvert),\n/* harmony export */   rgb: () => (/* binding */ rgb),\n/* harmony export */   rgbConvert: () => (/* binding */ rgbConvert)\n/* harmony export */ });\n/* harmony import */ var _define_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./define.js */ \"../../node_modules/d3-color/src/define.js\");\n\n\nfunction Color() {}\n\nvar darker = 0.7;\nvar brighter = 1 / darker;\n\nvar reI = \"\\\\s*([+-]?\\\\d+)\\\\s*\",\n    reN = \"\\\\s*([+-]?(?:\\\\d*\\\\.)?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",\n    reP = \"\\\\s*([+-]?(?:\\\\d*\\\\.)?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",\n    reHex = /^#([0-9a-f]{3,8})$/,\n    reRgbInteger = new RegExp(`^rgb\\\\(${reI},${reI},${reI}\\\\)$`),\n    reRgbPercent = new RegExp(`^rgb\\\\(${reP},${reP},${reP}\\\\)$`),\n    reRgbaInteger = new RegExp(`^rgba\\\\(${reI},${reI},${reI},${reN}\\\\)$`),\n    reRgbaPercent = new RegExp(`^rgba\\\\(${reP},${reP},${reP},${reN}\\\\)$`),\n    reHslPercent = new RegExp(`^hsl\\\\(${reN},${reP},${reP}\\\\)$`),\n    reHslaPercent = new RegExp(`^hsla\\\\(${reN},${reP},${reP},${reN}\\\\)$`);\n\nvar named = {\n  aliceblue: 0xf0f8ff,\n  antiquewhite: 0xfaebd7,\n  aqua: 0x00ffff,\n  aquamarine: 0x7fffd4,\n  azure: 0xf0ffff,\n  beige: 0xf5f5dc,\n  bisque: 0xffe4c4,\n  black: 0x000000,\n  blanchedalmond: 0xffebcd,\n  blue: 0x0000ff,\n  blueviolet: 0x8a2be2,\n  brown: 0xa52a2a,\n  burlywood: 0xdeb887,\n  cadetblue: 0x5f9ea0,\n  chartreuse: 0x7fff00,\n  chocolate: 0xd2691e,\n  coral: 0xff7f50,\n  cornflowerblue: 0x6495ed,\n  cornsilk: 0xfff8dc,\n  crimson: 0xdc143c,\n  cyan: 0x00ffff,\n  darkblue: 0x00008b,\n  darkcyan: 0x008b8b,\n  darkgoldenrod: 0xb8860b,\n  darkgray: 0xa9a9a9,\n  darkgreen: 0x006400,\n  darkgrey: 0xa9a9a9,\n  darkkhaki: 0xbdb76b,\n  darkmagenta: 0x8b008b,\n  darkolivegreen: 0x556b2f,\n  darkorange: 0xff8c00,\n  darkorchid: 0x9932cc,\n  darkred: 0x8b0000,\n  darksalmon: 0xe9967a,\n  darkseagreen: 0x8fbc8f,\n  darkslateblue: 0x483d8b,\n  darkslategray: 0x2f4f4f,\n  darkslategrey: 0x2f4f4f,\n  darkturquoise: 0x00ced1,\n  darkviolet: 0x9400d3,\n  deeppink: 0xff1493,\n  deepskyblue: 0x00bfff,\n  dimgray: 0x696969,\n  dimgrey: 0x696969,\n  dodgerblue: 0x1e90ff,\n  firebrick: 0xb22222,\n  floralwhite: 0xfffaf0,\n  forestgreen: 0x228b22,\n  fuchsia: 0xff00ff,\n  gainsboro: 0xdcdcdc,\n  ghostwhite: 0xf8f8ff,\n  gold: 0xffd700,\n  goldenrod: 0xdaa520,\n  gray: 0x808080,\n  green: 0x008000,\n  greenyellow: 0xadff2f,\n  grey: 0x808080,\n  honeydew: 0xf0fff0,\n  hotpink: 0xff69b4,\n  indianred: 0xcd5c5c,\n  indigo: 0x4b0082,\n  ivory: 0xfffff0,\n  khaki: 0xf0e68c,\n  lavender: 0xe6e6fa,\n  lavenderblush: 0xfff0f5,\n  lawngreen: 0x7cfc00,\n  lemonchiffon: 0xfffacd,\n  lightblue: 0xadd8e6,\n  lightcoral: 0xf08080,\n  lightcyan: 0xe0ffff,\n  lightgoldenrodyellow: 0xfafad2,\n  lightgray: 0xd3d3d3,\n  lightgreen: 0x90ee90,\n  lightgrey: 0xd3d3d3,\n  lightpink: 0xffb6c1,\n  lightsalmon: 0xffa07a,\n  lightseagreen: 0x20b2aa,\n  lightskyblue: 0x87cefa,\n  lightslategray: 0x778899,\n  lightslategrey: 0x778899,\n  lightsteelblue: 0xb0c4de,\n  lightyellow: 0xffffe0,\n  lime: 0x00ff00,\n  limegreen: 0x32cd32,\n  linen: 0xfaf0e6,\n  magenta: 0xff00ff,\n  maroon: 0x800000,\n  mediumaquamarine: 0x66cdaa,\n  mediumblue: 0x0000cd,\n  mediumorchid: 0xba55d3,\n  mediumpurple: 0x9370db,\n  mediumseagreen: 0x3cb371,\n  mediumslateblue: 0x7b68ee,\n  mediumspringgreen: 0x00fa9a,\n  mediumturquoise: 0x48d1cc,\n  mediumvioletred: 0xc71585,\n  midnightblue: 0x191970,\n  mintcream: 0xf5fffa,\n  mistyrose: 0xffe4e1,\n  moccasin: 0xffe4b5,\n  navajowhite: 0xffdead,\n  navy: 0x000080,\n  oldlace: 0xfdf5e6,\n  olive: 0x808000,\n  olivedrab: 0x6b8e23,\n  orange: 0xffa500,\n  orangered: 0xff4500,\n  orchid: 0xda70d6,\n  palegoldenrod: 0xeee8aa,\n  palegreen: 0x98fb98,\n  paleturquoise: 0xafeeee,\n  palevioletred: 0xdb7093,\n  papayawhip: 0xffefd5,\n  peachpuff: 0xffdab9,\n  peru: 0xcd853f,\n  pink: 0xffc0cb,\n  plum: 0xdda0dd,\n  powderblue: 0xb0e0e6,\n  purple: 0x800080,\n  rebeccapurple: 0x663399,\n  red: 0xff0000,\n  rosybrown: 0xbc8f8f,\n  royalblue: 0x4169e1,\n  saddlebrown: 0x8b4513,\n  salmon: 0xfa8072,\n  sandybrown: 0xf4a460,\n  seagreen: 0x2e8b57,\n  seashell: 0xfff5ee,\n  sienna: 0xa0522d,\n  silver: 0xc0c0c0,\n  skyblue: 0x87ceeb,\n  slateblue: 0x6a5acd,\n  slategray: 0x708090,\n  slategrey: 0x708090,\n  snow: 0xfffafa,\n  springgreen: 0x00ff7f,\n  steelblue: 0x4682b4,\n  tan: 0xd2b48c,\n  teal: 0x008080,\n  thistle: 0xd8bfd8,\n  tomato: 0xff6347,\n  turquoise: 0x40e0d0,\n  violet: 0xee82ee,\n  wheat: 0xf5deb3,\n  white: 0xffffff,\n  whitesmoke: 0xf5f5f5,\n  yellow: 0xffff00,\n  yellowgreen: 0x9acd32\n};\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(Color, color, {\n  copy(channels) {\n    return Object.assign(new this.constructor, this, channels);\n  },\n  displayable() {\n    return this.rgb().displayable();\n  },\n  hex: color_formatHex, // Deprecated! Use color.formatHex.\n  formatHex: color_formatHex,\n  formatHex8: color_formatHex8,\n  formatHsl: color_formatHsl,\n  formatRgb: color_formatRgb,\n  toString: color_formatRgb\n});\n\nfunction color_formatHex() {\n  return this.rgb().formatHex();\n}\n\nfunction color_formatHex8() {\n  return this.rgb().formatHex8();\n}\n\nfunction color_formatHsl() {\n  return hslConvert(this).formatHsl();\n}\n\nfunction color_formatRgb() {\n  return this.rgb().formatRgb();\n}\n\nfunction color(format) {\n  var m, l;\n  format = (format + \"\").trim().toLowerCase();\n  return (m = reHex.exec(format)) ? (l = m[1].length, m = parseInt(m[1], 16), l === 6 ? rgbn(m) // #ff0000\n      : l === 3 ? new Rgb((m >> 8 & 0xf) | (m >> 4 & 0xf0), (m >> 4 & 0xf) | (m & 0xf0), ((m & 0xf) << 4) | (m & 0xf), 1) // #f00\n      : l === 8 ? rgba(m >> 24 & 0xff, m >> 16 & 0xff, m >> 8 & 0xff, (m & 0xff) / 0xff) // #ff000000\n      : l === 4 ? rgba((m >> 12 & 0xf) | (m >> 8 & 0xf0), (m >> 8 & 0xf) | (m >> 4 & 0xf0), (m >> 4 & 0xf) | (m & 0xf0), (((m & 0xf) << 4) | (m & 0xf)) / 0xff) // #f000\n      : null) // invalid hex\n      : (m = reRgbInteger.exec(format)) ? new Rgb(m[1], m[2], m[3], 1) // rgb(255, 0, 0)\n      : (m = reRgbPercent.exec(format)) ? new Rgb(m[1] * 255 / 100, m[2] * 255 / 100, m[3] * 255 / 100, 1) // rgb(100%, 0%, 0%)\n      : (m = reRgbaInteger.exec(format)) ? rgba(m[1], m[2], m[3], m[4]) // rgba(255, 0, 0, 1)\n      : (m = reRgbaPercent.exec(format)) ? rgba(m[1] * 255 / 100, m[2] * 255 / 100, m[3] * 255 / 100, m[4]) // rgb(100%, 0%, 0%, 1)\n      : (m = reHslPercent.exec(format)) ? hsla(m[1], m[2] / 100, m[3] / 100, 1) // hsl(120, 50%, 50%)\n      : (m = reHslaPercent.exec(format)) ? hsla(m[1], m[2] / 100, m[3] / 100, m[4]) // hsla(120, 50%, 50%, 1)\n      : named.hasOwnProperty(format) ? rgbn(named[format]) // eslint-disable-line no-prototype-builtins\n      : format === \"transparent\" ? new Rgb(NaN, NaN, NaN, 0)\n      : null;\n}\n\nfunction rgbn(n) {\n  return new Rgb(n >> 16 & 0xff, n >> 8 & 0xff, n & 0xff, 1);\n}\n\nfunction rgba(r, g, b, a) {\n  if (a <= 0) r = g = b = NaN;\n  return new Rgb(r, g, b, a);\n}\n\nfunction rgbConvert(o) {\n  if (!(o instanceof Color)) o = color(o);\n  if (!o) return new Rgb;\n  o = o.rgb();\n  return new Rgb(o.r, o.g, o.b, o.opacity);\n}\n\nfunction rgb(r, g, b, opacity) {\n  return arguments.length === 1 ? rgbConvert(r) : new Rgb(r, g, b, opacity == null ? 1 : opacity);\n}\n\nfunction Rgb(r, g, b, opacity) {\n  this.r = +r;\n  this.g = +g;\n  this.b = +b;\n  this.opacity = +opacity;\n}\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(Rgb, rgb, (0,_define_js__WEBPACK_IMPORTED_MODULE_0__.extend)(Color, {\n  brighter(k) {\n    k = k == null ? brighter : Math.pow(brighter, k);\n    return new Rgb(this.r * k, this.g * k, this.b * k, this.opacity);\n  },\n  darker(k) {\n    k = k == null ? darker : Math.pow(darker, k);\n    return new Rgb(this.r * k, this.g * k, this.b * k, this.opacity);\n  },\n  rgb() {\n    return this;\n  },\n  clamp() {\n    return new Rgb(clampi(this.r), clampi(this.g), clampi(this.b), clampa(this.opacity));\n  },\n  displayable() {\n    return (-0.5 <= this.r && this.r < 255.5)\n        && (-0.5 <= this.g && this.g < 255.5)\n        && (-0.5 <= this.b && this.b < 255.5)\n        && (0 <= this.opacity && this.opacity <= 1);\n  },\n  hex: rgb_formatHex, // Deprecated! Use color.formatHex.\n  formatHex: rgb_formatHex,\n  formatHex8: rgb_formatHex8,\n  formatRgb: rgb_formatRgb,\n  toString: rgb_formatRgb\n}));\n\nfunction rgb_formatHex() {\n  return `#${hex(this.r)}${hex(this.g)}${hex(this.b)}`;\n}\n\nfunction rgb_formatHex8() {\n  return `#${hex(this.r)}${hex(this.g)}${hex(this.b)}${hex((isNaN(this.opacity) ? 1 : this.opacity) * 255)}`;\n}\n\nfunction rgb_formatRgb() {\n  const a = clampa(this.opacity);\n  return `${a === 1 ? \"rgb(\" : \"rgba(\"}${clampi(this.r)}, ${clampi(this.g)}, ${clampi(this.b)}${a === 1 ? \")\" : `, ${a})`}`;\n}\n\nfunction clampa(opacity) {\n  return isNaN(opacity) ? 1 : Math.max(0, Math.min(1, opacity));\n}\n\nfunction clampi(value) {\n  return Math.max(0, Math.min(255, Math.round(value) || 0));\n}\n\nfunction hex(value) {\n  value = clampi(value);\n  return (value < 16 ? \"0\" : \"\") + value.toString(16);\n}\n\nfunction hsla(h, s, l, a) {\n  if (a <= 0) h = s = l = NaN;\n  else if (l <= 0 || l >= 1) h = s = NaN;\n  else if (s <= 0) h = NaN;\n  return new Hsl(h, s, l, a);\n}\n\nfunction hslConvert(o) {\n  if (o instanceof Hsl) return new Hsl(o.h, o.s, o.l, o.opacity);\n  if (!(o instanceof Color)) o = color(o);\n  if (!o) return new Hsl;\n  if (o instanceof Hsl) return o;\n  o = o.rgb();\n  var r = o.r / 255,\n      g = o.g / 255,\n      b = o.b / 255,\n      min = Math.min(r, g, b),\n      max = Math.max(r, g, b),\n      h = NaN,\n      s = max - min,\n      l = (max + min) / 2;\n  if (s) {\n    if (r === max) h = (g - b) / s + (g < b) * 6;\n    else if (g === max) h = (b - r) / s + 2;\n    else h = (r - g) / s + 4;\n    s /= l < 0.5 ? max + min : 2 - max - min;\n    h *= 60;\n  } else {\n    s = l > 0 && l < 1 ? 0 : h;\n  }\n  return new Hsl(h, s, l, o.opacity);\n}\n\nfunction hsl(h, s, l, opacity) {\n  return arguments.length === 1 ? hslConvert(h) : new Hsl(h, s, l, opacity == null ? 1 : opacity);\n}\n\nfunction Hsl(h, s, l, opacity) {\n  this.h = +h;\n  this.s = +s;\n  this.l = +l;\n  this.opacity = +opacity;\n}\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(Hsl, hsl, (0,_define_js__WEBPACK_IMPORTED_MODULE_0__.extend)(Color, {\n  brighter(k) {\n    k = k == null ? brighter : Math.pow(brighter, k);\n    return new Hsl(this.h, this.s, this.l * k, this.opacity);\n  },\n  darker(k) {\n    k = k == null ? darker : Math.pow(darker, k);\n    return new Hsl(this.h, this.s, this.l * k, this.opacity);\n  },\n  rgb() {\n    var h = this.h % 360 + (this.h < 0) * 360,\n        s = isNaN(h) || isNaN(this.s) ? 0 : this.s,\n        l = this.l,\n        m2 = l + (l < 0.5 ? l : 1 - l) * s,\n        m1 = 2 * l - m2;\n    return new Rgb(\n      hsl2rgb(h >= 240 ? h - 240 : h + 120, m1, m2),\n      hsl2rgb(h, m1, m2),\n      hsl2rgb(h < 120 ? h + 240 : h - 120, m1, m2),\n      this.opacity\n    );\n  },\n  clamp() {\n    return new Hsl(clamph(this.h), clampt(this.s), clampt(this.l), clampa(this.opacity));\n  },\n  displayable() {\n    return (0 <= this.s && this.s <= 1 || isNaN(this.s))\n        && (0 <= this.l && this.l <= 1)\n        && (0 <= this.opacity && this.opacity <= 1);\n  },\n  formatHsl() {\n    const a = clampa(this.opacity);\n    return `${a === 1 ? \"hsl(\" : \"hsla(\"}${clamph(this.h)}, ${clampt(this.s) * 100}%, ${clampt(this.l) * 100}%${a === 1 ? \")\" : `, ${a})`}`;\n  }\n}));\n\nfunction clamph(value) {\n  value = (value || 0) % 360;\n  return value < 0 ? value + 360 : value;\n}\n\nfunction clampt(value) {\n  return Math.max(0, Math.min(1, value || 0));\n}\n\n/* From FvD 13.37, CSS Color Module Level 3 */\nfunction hsl2rgb(h, m1, m2) {\n  return (h < 60 ? m1 + (m2 - m1) * h / 60\n      : h < 180 ? m2\n      : h < 240 ? m1 + (m2 - m1) * (240 - h) / 60\n      : m1) * 255;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-color/src/color.js?");

/***/ }),

/***/ "../../node_modules/d3-color/src/cubehelix.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-color/src/cubehelix.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Cubehelix: () => (/* binding */ Cubehelix),\n/* harmony export */   \"default\": () => (/* binding */ cubehelix)\n/* harmony export */ });\n/* harmony import */ var _define_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./define.js */ \"../../node_modules/d3-color/src/define.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-color/src/math.js\");\n\n\n\n\nvar A = -0.14861,\n    B = +1.78277,\n    C = -0.29227,\n    D = -0.90649,\n    E = +1.97294,\n    ED = E * D,\n    EB = E * B,\n    BC_DA = B * C - D * A;\n\nfunction cubehelixConvert(o) {\n  if (o instanceof Cubehelix) return new Cubehelix(o.h, o.s, o.l, o.opacity);\n  if (!(o instanceof _color_js__WEBPACK_IMPORTED_MODULE_0__.Rgb)) o = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__.rgbConvert)(o);\n  var r = o.r / 255,\n      g = o.g / 255,\n      b = o.b / 255,\n      l = (BC_DA * b + ED * r - EB * g) / (BC_DA + ED - EB),\n      bl = b - l,\n      k = (E * (g - l) - C * bl) / D,\n      s = Math.sqrt(k * k + bl * bl) / (E * l * (1 - l)), // NaN if l=0 or l=1\n      h = s ? Math.atan2(k, bl) * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees - 120 : NaN;\n  return new Cubehelix(h < 0 ? h + 360 : h, s, l, o.opacity);\n}\n\nfunction cubehelix(h, s, l, opacity) {\n  return arguments.length === 1 ? cubehelixConvert(h) : new Cubehelix(h, s, l, opacity == null ? 1 : opacity);\n}\n\nfunction Cubehelix(h, s, l, opacity) {\n  this.h = +h;\n  this.s = +s;\n  this.l = +l;\n  this.opacity = +opacity;\n}\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(Cubehelix, cubehelix, (0,_define_js__WEBPACK_IMPORTED_MODULE_2__.extend)(_color_js__WEBPACK_IMPORTED_MODULE_0__.Color, {\n  brighter(k) {\n    k = k == null ? _color_js__WEBPACK_IMPORTED_MODULE_0__.brighter : Math.pow(_color_js__WEBPACK_IMPORTED_MODULE_0__.brighter, k);\n    return new Cubehelix(this.h, this.s, this.l * k, this.opacity);\n  },\n  darker(k) {\n    k = k == null ? _color_js__WEBPACK_IMPORTED_MODULE_0__.darker : Math.pow(_color_js__WEBPACK_IMPORTED_MODULE_0__.darker, k);\n    return new Cubehelix(this.h, this.s, this.l * k, this.opacity);\n  },\n  rgb() {\n    var h = isNaN(this.h) ? 0 : (this.h + 120) * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians,\n        l = +this.l,\n        a = isNaN(this.s) ? 0 : this.s * l * (1 - l),\n        cosh = Math.cos(h),\n        sinh = Math.sin(h);\n    return new _color_js__WEBPACK_IMPORTED_MODULE_0__.Rgb(\n      255 * (l + a * (A * cosh + B * sinh)),\n      255 * (l + a * (C * cosh + D * sinh)),\n      255 * (l + a * (E * cosh)),\n      this.opacity\n    );\n  }\n}));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-color/src/cubehelix.js?");

/***/ }),

/***/ "../../node_modules/d3-color/src/define.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-color/src/define.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   extend: () => (/* binding */ extend)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(constructor, factory, prototype) {\n  constructor.prototype = factory.prototype = prototype;\n  prototype.constructor = constructor;\n}\n\nfunction extend(parent, definition) {\n  var prototype = Object.create(parent.prototype);\n  for (var key in definition) prototype[key] = definition[key];\n  return prototype;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-color/src/define.js?");

/***/ }),

/***/ "../../node_modules/d3-color/src/lab.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-color/src/lab.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Hcl: () => (/* binding */ Hcl),\n/* harmony export */   Lab: () => (/* binding */ Lab),\n/* harmony export */   \"default\": () => (/* binding */ lab),\n/* harmony export */   gray: () => (/* binding */ gray),\n/* harmony export */   hcl: () => (/* binding */ hcl),\n/* harmony export */   lch: () => (/* binding */ lch)\n/* harmony export */ });\n/* harmony import */ var _define_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./define.js */ \"../../node_modules/d3-color/src/define.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-color/src/math.js\");\n\n\n\n\n// https://observablehq.com/@mbostock/lab-and-rgb\nconst K = 18,\n    Xn = 0.96422,\n    Yn = 1,\n    Zn = 0.82521,\n    t0 = 4 / 29,\n    t1 = 6 / 29,\n    t2 = 3 * t1 * t1,\n    t3 = t1 * t1 * t1;\n\nfunction labConvert(o) {\n  if (o instanceof Lab) return new Lab(o.l, o.a, o.b, o.opacity);\n  if (o instanceof Hcl) return hcl2lab(o);\n  if (!(o instanceof _color_js__WEBPACK_IMPORTED_MODULE_0__.Rgb)) o = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__.rgbConvert)(o);\n  var r = rgb2lrgb(o.r),\n      g = rgb2lrgb(o.g),\n      b = rgb2lrgb(o.b),\n      y = xyz2lab((0.2225045 * r + 0.7168786 * g + 0.0606169 * b) / Yn), x, z;\n  if (r === g && g === b) x = z = y; else {\n    x = xyz2lab((0.4360747 * r + 0.3850649 * g + 0.1430804 * b) / Xn);\n    z = xyz2lab((0.0139322 * r + 0.0971045 * g + 0.7141733 * b) / Zn);\n  }\n  return new Lab(116 * y - 16, 500 * (x - y), 200 * (y - z), o.opacity);\n}\n\nfunction gray(l, opacity) {\n  return new Lab(l, 0, 0, opacity == null ? 1 : opacity);\n}\n\nfunction lab(l, a, b, opacity) {\n  return arguments.length === 1 ? labConvert(l) : new Lab(l, a, b, opacity == null ? 1 : opacity);\n}\n\nfunction Lab(l, a, b, opacity) {\n  this.l = +l;\n  this.a = +a;\n  this.b = +b;\n  this.opacity = +opacity;\n}\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(Lab, lab, (0,_define_js__WEBPACK_IMPORTED_MODULE_1__.extend)(_color_js__WEBPACK_IMPORTED_MODULE_0__.Color, {\n  brighter(k) {\n    return new Lab(this.l + K * (k == null ? 1 : k), this.a, this.b, this.opacity);\n  },\n  darker(k) {\n    return new Lab(this.l - K * (k == null ? 1 : k), this.a, this.b, this.opacity);\n  },\n  rgb() {\n    var y = (this.l + 16) / 116,\n        x = isNaN(this.a) ? y : y + this.a / 500,\n        z = isNaN(this.b) ? y : y - this.b / 200;\n    x = Xn * lab2xyz(x);\n    y = Yn * lab2xyz(y);\n    z = Zn * lab2xyz(z);\n    return new _color_js__WEBPACK_IMPORTED_MODULE_0__.Rgb(\n      lrgb2rgb( 3.1338561 * x - 1.6168667 * y - 0.4906146 * z),\n      lrgb2rgb(-0.9787684 * x + 1.9161415 * y + 0.0334540 * z),\n      lrgb2rgb( 0.0719453 * x - 0.2289914 * y + 1.4052427 * z),\n      this.opacity\n    );\n  }\n}));\n\nfunction xyz2lab(t) {\n  return t > t3 ? Math.pow(t, 1 / 3) : t / t2 + t0;\n}\n\nfunction lab2xyz(t) {\n  return t > t1 ? t * t * t : t2 * (t - t0);\n}\n\nfunction lrgb2rgb(x) {\n  return 255 * (x <= 0.0031308 ? 12.92 * x : 1.055 * Math.pow(x, 1 / 2.4) - 0.055);\n}\n\nfunction rgb2lrgb(x) {\n  return (x /= 255) <= 0.04045 ? x / 12.92 : Math.pow((x + 0.055) / 1.055, 2.4);\n}\n\nfunction hclConvert(o) {\n  if (o instanceof Hcl) return new Hcl(o.h, o.c, o.l, o.opacity);\n  if (!(o instanceof Lab)) o = labConvert(o);\n  if (o.a === 0 && o.b === 0) return new Hcl(NaN, 0 < o.l && o.l < 100 ? 0 : NaN, o.l, o.opacity);\n  var h = Math.atan2(o.b, o.a) * _math_js__WEBPACK_IMPORTED_MODULE_2__.degrees;\n  return new Hcl(h < 0 ? h + 360 : h, Math.sqrt(o.a * o.a + o.b * o.b), o.l, o.opacity);\n}\n\nfunction lch(l, c, h, opacity) {\n  return arguments.length === 1 ? hclConvert(l) : new Hcl(h, c, l, opacity == null ? 1 : opacity);\n}\n\nfunction hcl(h, c, l, opacity) {\n  return arguments.length === 1 ? hclConvert(h) : new Hcl(h, c, l, opacity == null ? 1 : opacity);\n}\n\nfunction Hcl(h, c, l, opacity) {\n  this.h = +h;\n  this.c = +c;\n  this.l = +l;\n  this.opacity = +opacity;\n}\n\nfunction hcl2lab(o) {\n  if (isNaN(o.h)) return new Lab(o.l, 0, 0, o.opacity);\n  var h = o.h * _math_js__WEBPACK_IMPORTED_MODULE_2__.radians;\n  return new Lab(o.l, Math.cos(h) * o.c, Math.sin(h) * o.c, o.opacity);\n}\n\n(0,_define_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(Hcl, hcl, (0,_define_js__WEBPACK_IMPORTED_MODULE_1__.extend)(_color_js__WEBPACK_IMPORTED_MODULE_0__.Color, {\n  brighter(k) {\n    return new Hcl(this.h, this.c, this.l + K * (k == null ? 1 : k), this.opacity);\n  },\n  darker(k) {\n    return new Hcl(this.h, this.c, this.l - K * (k == null ? 1 : k), this.opacity);\n  },\n  rgb() {\n    return hcl2lab(this).rgb();\n  }\n}));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-color/src/lab.js?");

/***/ }),

/***/ "../../node_modules/d3-color/src/math.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-color/src/math.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   degrees: () => (/* binding */ degrees),\n/* harmony export */   radians: () => (/* binding */ radians)\n/* harmony export */ });\nconst radians = Math.PI / 180;\nconst degrees = 180 / Math.PI;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-color/src/math.js?");

/***/ }),

/***/ "../../node_modules/d3-delaunay/src/delaunay.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-delaunay/src/delaunay.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Delaunay)\n/* harmony export */ });\n/* harmony import */ var delaunator__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! delaunator */ \"../../node_modules/delaunator/index.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-delaunay/src/path.js\");\n/* harmony import */ var _polygon_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./polygon.js */ \"../../node_modules/d3-delaunay/src/polygon.js\");\n/* harmony import */ var _voronoi_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./voronoi.js */ \"../../node_modules/d3-delaunay/src/voronoi.js\");\n\n\n\n\n\nconst tau = 2 * Math.PI, pow = Math.pow;\n\nfunction pointX(p) {\n  return p[0];\n}\n\nfunction pointY(p) {\n  return p[1];\n}\n\n// A triangulation is collinear if all its triangles have a non-null area\nfunction collinear(d) {\n  const {triangles, coords} = d;\n  for (let i = 0; i < triangles.length; i += 3) {\n    const a = 2 * triangles[i],\n          b = 2 * triangles[i + 1],\n          c = 2 * triangles[i + 2],\n          cross = (coords[c] - coords[a]) * (coords[b + 1] - coords[a + 1])\n                - (coords[b] - coords[a]) * (coords[c + 1] - coords[a + 1]);\n    if (cross > 1e-10) return false;\n  }\n  return true;\n}\n\nfunction jitter(x, y, r) {\n  return [x + Math.sin(x + y) * r, y + Math.cos(x - y) * r];\n}\n\nclass Delaunay {\n  static from(points, fx = pointX, fy = pointY, that) {\n    return new Delaunay(\"length\" in points\n        ? flatArray(points, fx, fy, that)\n        : Float64Array.from(flatIterable(points, fx, fy, that)));\n  }\n  constructor(points) {\n    this._delaunator = new delaunator__WEBPACK_IMPORTED_MODULE_0__[\"default\"](points);\n    this.inedges = new Int32Array(points.length / 2);\n    this._hullIndex = new Int32Array(points.length / 2);\n    this.points = this._delaunator.coords;\n    this._init();\n  }\n  update() {\n    this._delaunator.update();\n    this._init();\n    return this;\n  }\n  _init() {\n    const d = this._delaunator, points = this.points;\n\n    // check for collinear\n    if (d.hull && d.hull.length > 2 && collinear(d)) {\n      this.collinear = Int32Array.from({length: points.length/2}, (_,i) => i)\n        .sort((i, j) => points[2 * i] - points[2 * j] || points[2 * i + 1] - points[2 * j + 1]); // for exact neighbors\n      const e = this.collinear[0], f = this.collinear[this.collinear.length - 1],\n        bounds = [ points[2 * e], points[2 * e + 1], points[2 * f], points[2 * f + 1] ],\n        r = 1e-8 * Math.hypot(bounds[3] - bounds[1], bounds[2] - bounds[0]);\n      for (let i = 0, n = points.length / 2; i < n; ++i) {\n        const p = jitter(points[2 * i], points[2 * i + 1], r);\n        points[2 * i] = p[0];\n        points[2 * i + 1] = p[1];\n      }\n      this._delaunator = new delaunator__WEBPACK_IMPORTED_MODULE_0__[\"default\"](points);\n    } else {\n      delete this.collinear;\n    }\n\n    const halfedges = this.halfedges = this._delaunator.halfedges;\n    const hull = this.hull = this._delaunator.hull;\n    const triangles = this.triangles = this._delaunator.triangles;\n    const inedges = this.inedges.fill(-1);\n    const hullIndex = this._hullIndex.fill(-1);\n\n    // Compute an index from each point to an (arbitrary) incoming halfedge\n    // Used to give the first neighbor of each point; for this reason,\n    // on the hull we give priority to exterior halfedges\n    for (let e = 0, n = halfedges.length; e < n; ++e) {\n      const p = triangles[e % 3 === 2 ? e - 2 : e + 1];\n      if (halfedges[e] === -1 || inedges[p] === -1) inedges[p] = e;\n    }\n    for (let i = 0, n = hull.length; i < n; ++i) {\n      hullIndex[hull[i]] = i;\n    }\n\n    // degenerate case: 1 or 2 (distinct) points\n    if (hull.length <= 2 && hull.length > 0) {\n      this.triangles = new Int32Array(3).fill(-1);\n      this.halfedges = new Int32Array(3).fill(-1);\n      this.triangles[0] = hull[0];\n      inedges[hull[0]] = 1;\n      if (hull.length === 2) {\n        inedges[hull[1]] = 0;\n        this.triangles[1] = hull[1];\n        this.triangles[2] = hull[1];\n      }\n    }\n  }\n  voronoi(bounds) {\n    return new _voronoi_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"](this, bounds);\n  }\n  *neighbors(i) {\n    const {inedges, hull, _hullIndex, halfedges, triangles, collinear} = this;\n\n    // degenerate case with several collinear points\n    if (collinear) {\n      const l = collinear.indexOf(i);\n      if (l > 0) yield collinear[l - 1];\n      if (l < collinear.length - 1) yield collinear[l + 1];\n      return;\n    }\n\n    const e0 = inedges[i];\n    if (e0 === -1) return; // coincident point\n    let e = e0, p0 = -1;\n    do {\n      yield p0 = triangles[e];\n      e = e % 3 === 2 ? e - 2 : e + 1;\n      if (triangles[e] !== i) return; // bad triangulation\n      e = halfedges[e];\n      if (e === -1) {\n        const p = hull[(_hullIndex[i] + 1) % hull.length];\n        if (p !== p0) yield p;\n        return;\n      }\n    } while (e !== e0);\n  }\n  find(x, y, i = 0) {\n    if ((x = +x, x !== x) || (y = +y, y !== y)) return -1;\n    const i0 = i;\n    let c;\n    while ((c = this._step(i, x, y)) >= 0 && c !== i && c !== i0) i = c;\n    return c;\n  }\n  _step(i, x, y) {\n    const {inedges, hull, _hullIndex, halfedges, triangles, points} = this;\n    if (inedges[i] === -1 || !points.length) return (i + 1) % (points.length >> 1);\n    let c = i;\n    let dc = pow(x - points[i * 2], 2) + pow(y - points[i * 2 + 1], 2);\n    const e0 = inedges[i];\n    let e = e0;\n    do {\n      let t = triangles[e];\n      const dt = pow(x - points[t * 2], 2) + pow(y - points[t * 2 + 1], 2);\n      if (dt < dc) dc = dt, c = t;\n      e = e % 3 === 2 ? e - 2 : e + 1;\n      if (triangles[e] !== i) break; // bad triangulation\n      e = halfedges[e];\n      if (e === -1) {\n        e = hull[(_hullIndex[i] + 1) % hull.length];\n        if (e !== t) {\n          if (pow(x - points[e * 2], 2) + pow(y - points[e * 2 + 1], 2) < dc) return e;\n        }\n        break;\n      }\n    } while (e !== e0);\n    return c;\n  }\n  render(context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"] : undefined;\n    const {points, halfedges, triangles} = this;\n    for (let i = 0, n = halfedges.length; i < n; ++i) {\n      const j = halfedges[i];\n      if (j < i) continue;\n      const ti = triangles[i] * 2;\n      const tj = triangles[j] * 2;\n      context.moveTo(points[ti], points[ti + 1]);\n      context.lineTo(points[tj], points[tj + 1]);\n    }\n    this.renderHull(context);\n    return buffer && buffer.value();\n  }\n  renderPoints(context, r) {\n    if (r === undefined && (!context || typeof context.moveTo !== \"function\")) r = context, context = null;\n    r = r == undefined ? 2 : +r;\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"] : undefined;\n    const {points} = this;\n    for (let i = 0, n = points.length; i < n; i += 2) {\n      const x = points[i], y = points[i + 1];\n      context.moveTo(x + r, y);\n      context.arc(x, y, r, 0, tau);\n    }\n    return buffer && buffer.value();\n  }\n  renderHull(context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"] : undefined;\n    const {hull, points} = this;\n    const h = hull[0] * 2, n = hull.length;\n    context.moveTo(points[h], points[h + 1]);\n    for (let i = 1; i < n; ++i) {\n      const h = 2 * hull[i];\n      context.lineTo(points[h], points[h + 1]);\n    }\n    context.closePath();\n    return buffer && buffer.value();\n  }\n  hullPolygon() {\n    const polygon = new _polygon_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n    this.renderHull(polygon);\n    return polygon.value();\n  }\n  renderTriangle(i, context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"] : undefined;\n    const {points, triangles} = this;\n    const t0 = triangles[i *= 3] * 2;\n    const t1 = triangles[i + 1] * 2;\n    const t2 = triangles[i + 2] * 2;\n    context.moveTo(points[t0], points[t0 + 1]);\n    context.lineTo(points[t1], points[t1 + 1]);\n    context.lineTo(points[t2], points[t2 + 1]);\n    context.closePath();\n    return buffer && buffer.value();\n  }\n  *trianglePolygons() {\n    const {triangles} = this;\n    for (let i = 0, n = triangles.length / 3; i < n; ++i) {\n      yield this.trianglePolygon(i);\n    }\n  }\n  trianglePolygon(i) {\n    const polygon = new _polygon_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n    this.renderTriangle(i, polygon);\n    return polygon.value();\n  }\n}\n\nfunction flatArray(points, fx, fy, that) {\n  const n = points.length;\n  const array = new Float64Array(n * 2);\n  for (let i = 0; i < n; ++i) {\n    const p = points[i];\n    array[i * 2] = fx.call(that, p, i, points);\n    array[i * 2 + 1] = fy.call(that, p, i, points);\n  }\n  return array;\n}\n\nfunction* flatIterable(points, fx, fy, that) {\n  let i = 0;\n  for (const p of points) {\n    yield fx.call(that, p, i, points);\n    yield fy.call(that, p, i, points);\n    ++i;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-delaunay/src/delaunay.js?");

/***/ }),

/***/ "../../node_modules/d3-delaunay/src/path.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-delaunay/src/path.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Path)\n/* harmony export */ });\nconst epsilon = 1e-6;\n\nclass Path {\n  constructor() {\n    this._x0 = this._y0 = // start of current subpath\n    this._x1 = this._y1 = null; // end of current subpath\n    this._ = \"\";\n  }\n  moveTo(x, y) {\n    this._ += `M${this._x0 = this._x1 = +x},${this._y0 = this._y1 = +y}`;\n  }\n  closePath() {\n    if (this._x1 !== null) {\n      this._x1 = this._x0, this._y1 = this._y0;\n      this._ += \"Z\";\n    }\n  }\n  lineTo(x, y) {\n    this._ += `L${this._x1 = +x},${this._y1 = +y}`;\n  }\n  arc(x, y, r) {\n    x = +x, y = +y, r = +r;\n    const x0 = x + r;\n    const y0 = y;\n    if (r < 0) throw new Error(\"negative radius\");\n    if (this._x1 === null) this._ += `M${x0},${y0}`;\n    else if (Math.abs(this._x1 - x0) > epsilon || Math.abs(this._y1 - y0) > epsilon) this._ += \"L\" + x0 + \",\" + y0;\n    if (!r) return;\n    this._ += `A${r},${r},0,1,1,${x - r},${y}A${r},${r},0,1,1,${this._x1 = x0},${this._y1 = y0}`;\n  }\n  rect(x, y, w, h) {\n    this._ += `M${this._x0 = this._x1 = +x},${this._y0 = this._y1 = +y}h${+w}v${+h}h${-w}Z`;\n  }\n  value() {\n    return this._ || null;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-delaunay/src/path.js?");

/***/ }),

/***/ "../../node_modules/d3-delaunay/src/polygon.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-delaunay/src/polygon.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Polygon)\n/* harmony export */ });\nclass Polygon {\n  constructor() {\n    this._ = [];\n  }\n  moveTo(x, y) {\n    this._.push([x, y]);\n  }\n  closePath() {\n    this._.push(this._[0].slice());\n  }\n  lineTo(x, y) {\n    this._.push([x, y]);\n  }\n  value() {\n    return this._.length ? this._ : null;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-delaunay/src/polygon.js?");

/***/ }),

/***/ "../../node_modules/d3-delaunay/src/voronoi.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-delaunay/src/voronoi.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Voronoi)\n/* harmony export */ });\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-delaunay/src/path.js\");\n/* harmony import */ var _polygon_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./polygon.js */ \"../../node_modules/d3-delaunay/src/polygon.js\");\n\n\n\nclass Voronoi {\n  constructor(delaunay, [xmin, ymin, xmax, ymax] = [0, 0, 960, 500]) {\n    if (!((xmax = +xmax) >= (xmin = +xmin)) || !((ymax = +ymax) >= (ymin = +ymin))) throw new Error(\"invalid bounds\");\n    this.delaunay = delaunay;\n    this._circumcenters = new Float64Array(delaunay.points.length * 2);\n    this.vectors = new Float64Array(delaunay.points.length * 2);\n    this.xmax = xmax, this.xmin = xmin;\n    this.ymax = ymax, this.ymin = ymin;\n    this._init();\n  }\n  update() {\n    this.delaunay.update();\n    this._init();\n    return this;\n  }\n  _init() {\n    const {delaunay: {points, hull, triangles}, vectors} = this;\n    let bx, by; // lazily computed barycenter of the hull\n\n    // Compute circumcenters.\n    const circumcenters = this.circumcenters = this._circumcenters.subarray(0, triangles.length / 3 * 2);\n    for (let i = 0, j = 0, n = triangles.length, x, y; i < n; i += 3, j += 2) {\n      const t1 = triangles[i] * 2;\n      const t2 = triangles[i + 1] * 2;\n      const t3 = triangles[i + 2] * 2;\n      const x1 = points[t1];\n      const y1 = points[t1 + 1];\n      const x2 = points[t2];\n      const y2 = points[t2 + 1];\n      const x3 = points[t3];\n      const y3 = points[t3 + 1];\n\n      const dx = x2 - x1;\n      const dy = y2 - y1;\n      const ex = x3 - x1;\n      const ey = y3 - y1;\n      const ab = (dx * ey - dy * ex) * 2;\n\n      if (Math.abs(ab) < 1e-9) {\n        // For a degenerate triangle, the circumcenter is at the infinity, in a\n        // direction orthogonal to the halfedge and away from the “center” of\n        // the diagram <bx, by>, defined as the hull’s barycenter.\n        if (bx === undefined) {\n          bx = by = 0;\n          for (const i of hull) bx += points[i * 2], by += points[i * 2 + 1];\n          bx /= hull.length, by /= hull.length;\n        }\n        const a = 1e9 * Math.sign((bx - x1) * ey - (by - y1) * ex);\n        x = (x1 + x3) / 2 - a * ey;\n        y = (y1 + y3) / 2 + a * ex;\n      } else {\n        const d = 1 / ab;\n        const bl = dx * dx + dy * dy;\n        const cl = ex * ex + ey * ey;\n        x = x1 + (ey * bl - dy * cl) * d;\n        y = y1 + (dx * cl - ex * bl) * d;\n      }\n      circumcenters[j] = x;\n      circumcenters[j + 1] = y;\n    }\n\n    // Compute exterior cell rays.\n    let h = hull[hull.length - 1];\n    let p0, p1 = h * 4;\n    let x0, x1 = points[2 * h];\n    let y0, y1 = points[2 * h + 1];\n    vectors.fill(0);\n    for (let i = 0; i < hull.length; ++i) {\n      h = hull[i];\n      p0 = p1, x0 = x1, y0 = y1;\n      p1 = h * 4, x1 = points[2 * h], y1 = points[2 * h + 1];\n      vectors[p0 + 2] = vectors[p1] = y0 - y1;\n      vectors[p0 + 3] = vectors[p1 + 1] = x1 - x0;\n    }\n  }\n  render(context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : undefined;\n    const {delaunay: {halfedges, inedges, hull}, circumcenters, vectors} = this;\n    if (hull.length <= 1) return null;\n    for (let i = 0, n = halfedges.length; i < n; ++i) {\n      const j = halfedges[i];\n      if (j < i) continue;\n      const ti = Math.floor(i / 3) * 2;\n      const tj = Math.floor(j / 3) * 2;\n      const xi = circumcenters[ti];\n      const yi = circumcenters[ti + 1];\n      const xj = circumcenters[tj];\n      const yj = circumcenters[tj + 1];\n      this._renderSegment(xi, yi, xj, yj, context);\n    }\n    let h0, h1 = hull[hull.length - 1];\n    for (let i = 0; i < hull.length; ++i) {\n      h0 = h1, h1 = hull[i];\n      const t = Math.floor(inedges[h1] / 3) * 2;\n      const x = circumcenters[t];\n      const y = circumcenters[t + 1];\n      const v = h0 * 4;\n      const p = this._project(x, y, vectors[v + 2], vectors[v + 3]);\n      if (p) this._renderSegment(x, y, p[0], p[1], context);\n    }\n    return buffer && buffer.value();\n  }\n  renderBounds(context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : undefined;\n    context.rect(this.xmin, this.ymin, this.xmax - this.xmin, this.ymax - this.ymin);\n    return buffer && buffer.value();\n  }\n  renderCell(i, context) {\n    const buffer = context == null ? context = new _path_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : undefined;\n    const points = this._clip(i);\n    if (points === null || !points.length) return;\n    context.moveTo(points[0], points[1]);\n    let n = points.length;\n    while (points[0] === points[n-2] && points[1] === points[n-1] && n > 1) n -= 2;\n    for (let i = 2; i < n; i += 2) {\n      if (points[i] !== points[i-2] || points[i+1] !== points[i-1])\n        context.lineTo(points[i], points[i + 1]);\n    }\n    context.closePath();\n    return buffer && buffer.value();\n  }\n  *cellPolygons() {\n    const {delaunay: {points}} = this;\n    for (let i = 0, n = points.length / 2; i < n; ++i) {\n      const cell = this.cellPolygon(i);\n      if (cell) cell.index = i, yield cell;\n    }\n  }\n  cellPolygon(i) {\n    const polygon = new _polygon_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n    this.renderCell(i, polygon);\n    return polygon.value();\n  }\n  _renderSegment(x0, y0, x1, y1, context) {\n    let S;\n    const c0 = this._regioncode(x0, y0);\n    const c1 = this._regioncode(x1, y1);\n    if (c0 === 0 && c1 === 0) {\n      context.moveTo(x0, y0);\n      context.lineTo(x1, y1);\n    } else if (S = this._clipSegment(x0, y0, x1, y1, c0, c1)) {\n      context.moveTo(S[0], S[1]);\n      context.lineTo(S[2], S[3]);\n    }\n  }\n  contains(i, x, y) {\n    if ((x = +x, x !== x) || (y = +y, y !== y)) return false;\n    return this.delaunay._step(i, x, y) === i;\n  }\n  *neighbors(i) {\n    const ci = this._clip(i);\n    if (ci) for (const j of this.delaunay.neighbors(i)) {\n      const cj = this._clip(j);\n      // find the common edge\n      if (cj) loop: for (let ai = 0, li = ci.length; ai < li; ai += 2) {\n        for (let aj = 0, lj = cj.length; aj < lj; aj += 2) {\n          if (ci[ai] === cj[aj]\n              && ci[ai + 1] === cj[aj + 1]\n              && ci[(ai + 2) % li] === cj[(aj + lj - 2) % lj]\n              && ci[(ai + 3) % li] === cj[(aj + lj - 1) % lj]) {\n            yield j;\n            break loop;\n          }\n        }\n      }\n    }\n  }\n  _cell(i) {\n    const {circumcenters, delaunay: {inedges, halfedges, triangles}} = this;\n    const e0 = inedges[i];\n    if (e0 === -1) return null; // coincident point\n    const points = [];\n    let e = e0;\n    do {\n      const t = Math.floor(e / 3);\n      points.push(circumcenters[t * 2], circumcenters[t * 2 + 1]);\n      e = e % 3 === 2 ? e - 2 : e + 1;\n      if (triangles[e] !== i) break; // bad triangulation\n      e = halfedges[e];\n    } while (e !== e0 && e !== -1);\n    return points;\n  }\n  _clip(i) {\n    // degenerate case (1 valid point: return the box)\n    if (i === 0 && this.delaunay.hull.length === 1) {\n      return [this.xmax, this.ymin, this.xmax, this.ymax, this.xmin, this.ymax, this.xmin, this.ymin];\n    }\n    const points = this._cell(i);\n    if (points === null) return null;\n    const {vectors: V} = this;\n    const v = i * 4;\n    return this._simplify(V[v] || V[v + 1]\n        ? this._clipInfinite(i, points, V[v], V[v + 1], V[v + 2], V[v + 3])\n        : this._clipFinite(i, points));\n  }\n  _clipFinite(i, points) {\n    const n = points.length;\n    let P = null;\n    let x0, y0, x1 = points[n - 2], y1 = points[n - 1];\n    let c0, c1 = this._regioncode(x1, y1);\n    let e0, e1 = 0;\n    for (let j = 0; j < n; j += 2) {\n      x0 = x1, y0 = y1, x1 = points[j], y1 = points[j + 1];\n      c0 = c1, c1 = this._regioncode(x1, y1);\n      if (c0 === 0 && c1 === 0) {\n        e0 = e1, e1 = 0;\n        if (P) P.push(x1, y1);\n        else P = [x1, y1];\n      } else {\n        let S, sx0, sy0, sx1, sy1;\n        if (c0 === 0) {\n          if ((S = this._clipSegment(x0, y0, x1, y1, c0, c1)) === null) continue;\n          [sx0, sy0, sx1, sy1] = S;\n        } else {\n          if ((S = this._clipSegment(x1, y1, x0, y0, c1, c0)) === null) continue;\n          [sx1, sy1, sx0, sy0] = S;\n          e0 = e1, e1 = this._edgecode(sx0, sy0);\n          if (e0 && e1) this._edge(i, e0, e1, P, P.length);\n          if (P) P.push(sx0, sy0);\n          else P = [sx0, sy0];\n        }\n        e0 = e1, e1 = this._edgecode(sx1, sy1);\n        if (e0 && e1) this._edge(i, e0, e1, P, P.length);\n        if (P) P.push(sx1, sy1);\n        else P = [sx1, sy1];\n      }\n    }\n    if (P) {\n      e0 = e1, e1 = this._edgecode(P[0], P[1]);\n      if (e0 && e1) this._edge(i, e0, e1, P, P.length);\n    } else if (this.contains(i, (this.xmin + this.xmax) / 2, (this.ymin + this.ymax) / 2)) {\n      return [this.xmax, this.ymin, this.xmax, this.ymax, this.xmin, this.ymax, this.xmin, this.ymin];\n    }\n    return P;\n  }\n  _clipSegment(x0, y0, x1, y1, c0, c1) {\n    // for more robustness, always consider the segment in the same order\n    const flip = c0 < c1;\n    if (flip) [x0, y0, x1, y1, c0, c1] = [x1, y1, x0, y0, c1, c0];\n    while (true) {\n      if (c0 === 0 && c1 === 0) return flip ? [x1, y1, x0, y0] : [x0, y0, x1, y1];\n      if (c0 & c1) return null;\n      let x, y, c = c0 || c1;\n      if (c & 0b1000) x = x0 + (x1 - x0) * (this.ymax - y0) / (y1 - y0), y = this.ymax;\n      else if (c & 0b0100) x = x0 + (x1 - x0) * (this.ymin - y0) / (y1 - y0), y = this.ymin;\n      else if (c & 0b0010) y = y0 + (y1 - y0) * (this.xmax - x0) / (x1 - x0), x = this.xmax;\n      else y = y0 + (y1 - y0) * (this.xmin - x0) / (x1 - x0), x = this.xmin;\n      if (c0) x0 = x, y0 = y, c0 = this._regioncode(x0, y0);\n      else x1 = x, y1 = y, c1 = this._regioncode(x1, y1);\n    }\n  }\n  _clipInfinite(i, points, vx0, vy0, vxn, vyn) {\n    let P = Array.from(points), p;\n    if (p = this._project(P[0], P[1], vx0, vy0)) P.unshift(p[0], p[1]);\n    if (p = this._project(P[P.length - 2], P[P.length - 1], vxn, vyn)) P.push(p[0], p[1]);\n    if (P = this._clipFinite(i, P)) {\n      for (let j = 0, n = P.length, c0, c1 = this._edgecode(P[n - 2], P[n - 1]); j < n; j += 2) {\n        c0 = c1, c1 = this._edgecode(P[j], P[j + 1]);\n        if (c0 && c1) j = this._edge(i, c0, c1, P, j), n = P.length;\n      }\n    } else if (this.contains(i, (this.xmin + this.xmax) / 2, (this.ymin + this.ymax) / 2)) {\n      P = [this.xmin, this.ymin, this.xmax, this.ymin, this.xmax, this.ymax, this.xmin, this.ymax];\n    }\n    return P;\n  }\n  _edge(i, e0, e1, P, j) {\n    while (e0 !== e1) {\n      let x, y;\n      switch (e0) {\n        case 0b0101: e0 = 0b0100; continue; // top-left\n        case 0b0100: e0 = 0b0110, x = this.xmax, y = this.ymin; break; // top\n        case 0b0110: e0 = 0b0010; continue; // top-right\n        case 0b0010: e0 = 0b1010, x = this.xmax, y = this.ymax; break; // right\n        case 0b1010: e0 = 0b1000; continue; // bottom-right\n        case 0b1000: e0 = 0b1001, x = this.xmin, y = this.ymax; break; // bottom\n        case 0b1001: e0 = 0b0001; continue; // bottom-left\n        case 0b0001: e0 = 0b0101, x = this.xmin, y = this.ymin; break; // left\n      }\n      // Note: this implicitly checks for out of bounds: if P[j] or P[j+1] are\n      // undefined, the conditional statement will be executed.\n      if ((P[j] !== x || P[j + 1] !== y) && this.contains(i, x, y)) {\n        P.splice(j, 0, x, y), j += 2;\n      }\n    }\n    return j;\n  }\n  _project(x0, y0, vx, vy) {\n    let t = Infinity, c, x, y;\n    if (vy < 0) { // top\n      if (y0 <= this.ymin) return null;\n      if ((c = (this.ymin - y0) / vy) < t) y = this.ymin, x = x0 + (t = c) * vx;\n    } else if (vy > 0) { // bottom\n      if (y0 >= this.ymax) return null;\n      if ((c = (this.ymax - y0) / vy) < t) y = this.ymax, x = x0 + (t = c) * vx;\n    }\n    if (vx > 0) { // right\n      if (x0 >= this.xmax) return null;\n      if ((c = (this.xmax - x0) / vx) < t) x = this.xmax, y = y0 + (t = c) * vy;\n    } else if (vx < 0) { // left\n      if (x0 <= this.xmin) return null;\n      if ((c = (this.xmin - x0) / vx) < t) x = this.xmin, y = y0 + (t = c) * vy;\n    }\n    return [x, y];\n  }\n  _edgecode(x, y) {\n    return (x === this.xmin ? 0b0001\n        : x === this.xmax ? 0b0010 : 0b0000)\n        | (y === this.ymin ? 0b0100\n        : y === this.ymax ? 0b1000 : 0b0000);\n  }\n  _regioncode(x, y) {\n    return (x < this.xmin ? 0b0001\n        : x > this.xmax ? 0b0010 : 0b0000)\n        | (y < this.ymin ? 0b0100\n        : y > this.ymax ? 0b1000 : 0b0000);\n  }\n  _simplify(P) {\n    if (P && P.length > 4) {\n      for (let i = 0; i < P.length; i+= 2) {\n        const j = (i + 2) % P.length, k = (i + 4) % P.length;\n        if (P[i] === P[j] && P[j] === P[k] || P[i + 1] === P[j + 1] && P[j + 1] === P[k + 1]) {\n          P.splice(j, 2), i -= 2;\n        }\n      }\n      if (!P.length) P = null;\n    }\n    return P;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-delaunay/src/voronoi.js?");

/***/ }),

/***/ "../../node_modules/d3-dispatch/src/dispatch.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-dispatch/src/dispatch.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nvar noop = {value: () => {}};\n\nfunction dispatch() {\n  for (var i = 0, n = arguments.length, _ = {}, t; i < n; ++i) {\n    if (!(t = arguments[i] + \"\") || (t in _) || /[\\s.]/.test(t)) throw new Error(\"illegal type: \" + t);\n    _[t] = [];\n  }\n  return new Dispatch(_);\n}\n\nfunction Dispatch(_) {\n  this._ = _;\n}\n\nfunction parseTypenames(typenames, types) {\n  return typenames.trim().split(/^|\\s+/).map(function(t) {\n    var name = \"\", i = t.indexOf(\".\");\n    if (i >= 0) name = t.slice(i + 1), t = t.slice(0, i);\n    if (t && !types.hasOwnProperty(t)) throw new Error(\"unknown type: \" + t);\n    return {type: t, name: name};\n  });\n}\n\nDispatch.prototype = dispatch.prototype = {\n  constructor: Dispatch,\n  on: function(typename, callback) {\n    var _ = this._,\n        T = parseTypenames(typename + \"\", _),\n        t,\n        i = -1,\n        n = T.length;\n\n    // If no callback was specified, return the callback of the given type and name.\n    if (arguments.length < 2) {\n      while (++i < n) if ((t = (typename = T[i]).type) && (t = get(_[t], typename.name))) return t;\n      return;\n    }\n\n    // If a type was specified, set the callback for the given type and name.\n    // Otherwise, if a null callback was specified, remove callbacks of the given name.\n    if (callback != null && typeof callback !== \"function\") throw new Error(\"invalid callback: \" + callback);\n    while (++i < n) {\n      if (t = (typename = T[i]).type) _[t] = set(_[t], typename.name, callback);\n      else if (callback == null) for (t in _) _[t] = set(_[t], typename.name, null);\n    }\n\n    return this;\n  },\n  copy: function() {\n    var copy = {}, _ = this._;\n    for (var t in _) copy[t] = _[t].slice();\n    return new Dispatch(copy);\n  },\n  call: function(type, that) {\n    if ((n = arguments.length - 2) > 0) for (var args = new Array(n), i = 0, n, t; i < n; ++i) args[i] = arguments[i + 2];\n    if (!this._.hasOwnProperty(type)) throw new Error(\"unknown type: \" + type);\n    for (t = this._[type], i = 0, n = t.length; i < n; ++i) t[i].value.apply(that, args);\n  },\n  apply: function(type, that, args) {\n    if (!this._.hasOwnProperty(type)) throw new Error(\"unknown type: \" + type);\n    for (var t = this._[type], i = 0, n = t.length; i < n; ++i) t[i].value.apply(that, args);\n  }\n};\n\nfunction get(type, name) {\n  for (var i = 0, n = type.length, c; i < n; ++i) {\n    if ((c = type[i]).name === name) {\n      return c.value;\n    }\n  }\n}\n\nfunction set(type, name, callback) {\n  for (var i = 0, n = type.length; i < n; ++i) {\n    if (type[i].name === name) {\n      type[i] = noop, type = type.slice(0, i).concat(type.slice(i + 1));\n      break;\n    }\n  }\n  if (callback != null) type.push({name: name, value: callback});\n  return type;\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (dispatch);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-dispatch/src/dispatch.js?");

/***/ }),

/***/ "../../node_modules/d3-dsv/src/dsv.js":
/*!********************************************!*\
  !*** ../../node_modules/d3-dsv/src/dsv.js ***!
  \********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nvar EOL = {},\n    EOF = {},\n    QUOTE = 34,\n    NEWLINE = 10,\n    RETURN = 13;\n\nfunction objectConverter(columns) {\n  return new Function(\"d\", \"return {\" + columns.map(function(name, i) {\n    return JSON.stringify(name) + \": d[\" + i + \"] || \\\"\\\"\";\n  }).join(\",\") + \"}\");\n}\n\nfunction customConverter(columns, f) {\n  var object = objectConverter(columns);\n  return function(row, i) {\n    return f(object(row), i, columns);\n  };\n}\n\n// Compute unique columns in order of discovery.\nfunction inferColumns(rows) {\n  var columnSet = Object.create(null),\n      columns = [];\n\n  rows.forEach(function(row) {\n    for (var column in row) {\n      if (!(column in columnSet)) {\n        columns.push(columnSet[column] = column);\n      }\n    }\n  });\n\n  return columns;\n}\n\nfunction pad(value, width) {\n  var s = value + \"\", length = s.length;\n  return length < width ? new Array(width - length + 1).join(0) + s : s;\n}\n\nfunction formatYear(year) {\n  return year < 0 ? \"-\" + pad(-year, 6)\n    : year > 9999 ? \"+\" + pad(year, 6)\n    : pad(year, 4);\n}\n\nfunction formatDate(date) {\n  var hours = date.getUTCHours(),\n      minutes = date.getUTCMinutes(),\n      seconds = date.getUTCSeconds(),\n      milliseconds = date.getUTCMilliseconds();\n  return isNaN(date) ? \"Invalid Date\"\n      : formatYear(date.getUTCFullYear(), 4) + \"-\" + pad(date.getUTCMonth() + 1, 2) + \"-\" + pad(date.getUTCDate(), 2)\n      + (milliseconds ? \"T\" + pad(hours, 2) + \":\" + pad(minutes, 2) + \":\" + pad(seconds, 2) + \".\" + pad(milliseconds, 3) + \"Z\"\n      : seconds ? \"T\" + pad(hours, 2) + \":\" + pad(minutes, 2) + \":\" + pad(seconds, 2) + \"Z\"\n      : minutes || hours ? \"T\" + pad(hours, 2) + \":\" + pad(minutes, 2) + \"Z\"\n      : \"\");\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(delimiter) {\n  var reFormat = new RegExp(\"[\\\"\" + delimiter + \"\\n\\r]\"),\n      DELIMITER = delimiter.charCodeAt(0);\n\n  function parse(text, f) {\n    var convert, columns, rows = parseRows(text, function(row, i) {\n      if (convert) return convert(row, i - 1);\n      columns = row, convert = f ? customConverter(row, f) : objectConverter(row);\n    });\n    rows.columns = columns || [];\n    return rows;\n  }\n\n  function parseRows(text, f) {\n    var rows = [], // output rows\n        N = text.length,\n        I = 0, // current character index\n        n = 0, // current line number\n        t, // current token\n        eof = N <= 0, // current token followed by EOF?\n        eol = false; // current token followed by EOL?\n\n    // Strip the trailing newline.\n    if (text.charCodeAt(N - 1) === NEWLINE) --N;\n    if (text.charCodeAt(N - 1) === RETURN) --N;\n\n    function token() {\n      if (eof) return EOF;\n      if (eol) return eol = false, EOL;\n\n      // Unescape quotes.\n      var i, j = I, c;\n      if (text.charCodeAt(j) === QUOTE) {\n        while (I++ < N && text.charCodeAt(I) !== QUOTE || text.charCodeAt(++I) === QUOTE);\n        if ((i = I) >= N) eof = true;\n        else if ((c = text.charCodeAt(I++)) === NEWLINE) eol = true;\n        else if (c === RETURN) { eol = true; if (text.charCodeAt(I) === NEWLINE) ++I; }\n        return text.slice(j + 1, i - 1).replace(/\"\"/g, \"\\\"\");\n      }\n\n      // Find next delimiter or newline.\n      while (I < N) {\n        if ((c = text.charCodeAt(i = I++)) === NEWLINE) eol = true;\n        else if (c === RETURN) { eol = true; if (text.charCodeAt(I) === NEWLINE) ++I; }\n        else if (c !== DELIMITER) continue;\n        return text.slice(j, i);\n      }\n\n      // Return last token before EOF.\n      return eof = true, text.slice(j, N);\n    }\n\n    while ((t = token()) !== EOF) {\n      var row = [];\n      while (t !== EOL && t !== EOF) row.push(t), t = token();\n      if (f && (row = f(row, n++)) == null) continue;\n      rows.push(row);\n    }\n\n    return rows;\n  }\n\n  function preformatBody(rows, columns) {\n    return rows.map(function(row) {\n      return columns.map(function(column) {\n        return formatValue(row[column]);\n      }).join(delimiter);\n    });\n  }\n\n  function format(rows, columns) {\n    if (columns == null) columns = inferColumns(rows);\n    return [columns.map(formatValue).join(delimiter)].concat(preformatBody(rows, columns)).join(\"\\n\");\n  }\n\n  function formatBody(rows, columns) {\n    if (columns == null) columns = inferColumns(rows);\n    return preformatBody(rows, columns).join(\"\\n\");\n  }\n\n  function formatRows(rows) {\n    return rows.map(formatRow).join(\"\\n\");\n  }\n\n  function formatRow(row) {\n    return row.map(formatValue).join(delimiter);\n  }\n\n  function formatValue(value) {\n    return value == null ? \"\"\n        : value instanceof Date ? formatDate(value)\n        : reFormat.test(value += \"\") ? \"\\\"\" + value.replace(/\"/g, \"\\\"\\\"\") + \"\\\"\"\n        : value;\n  }\n\n  return {\n    parse: parse,\n    parseRows: parseRows,\n    format: format,\n    formatBody: formatBody,\n    formatRows: formatRows,\n    formatRow: formatRow,\n    formatValue: formatValue\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-dsv/src/dsv.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/center.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-force/src/center.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, y) {\n  var nodes, strength = 1;\n\n  if (x == null) x = 0;\n  if (y == null) y = 0;\n\n  function force() {\n    var i,\n        n = nodes.length,\n        node,\n        sx = 0,\n        sy = 0;\n\n    for (i = 0; i < n; ++i) {\n      node = nodes[i], sx += node.x, sy += node.y;\n    }\n\n    for (sx = (sx / n - x) * strength, sy = (sy / n - y) * strength, i = 0; i < n; ++i) {\n      node = nodes[i], node.x -= sx, node.y -= sy;\n    }\n  }\n\n  force.initialize = function(_) {\n    nodes = _;\n  };\n\n  force.x = function(_) {\n    return arguments.length ? (x = +_, force) : x;\n  };\n\n  force.y = function(_) {\n    return arguments.length ? (y = +_, force) : y;\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = +_, force) : strength;\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/center.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/collide.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-force/src/collide.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_quadtree__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-quadtree */ \"../../node_modules/d3-quadtree/src/quadtree.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-force/src/constant.js\");\n/* harmony import */ var _jiggle_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./jiggle.js */ \"../../node_modules/d3-force/src/jiggle.js\");\n\n\n\n\nfunction x(d) {\n  return d.x + d.vx;\n}\n\nfunction y(d) {\n  return d.y + d.vy;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(radius) {\n  var nodes,\n      radii,\n      random,\n      strength = 1,\n      iterations = 1;\n\n  if (typeof radius !== \"function\") radius = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(radius == null ? 1 : +radius);\n\n  function force() {\n    var i, n = nodes.length,\n        tree,\n        node,\n        xi,\n        yi,\n        ri,\n        ri2;\n\n    for (var k = 0; k < iterations; ++k) {\n      tree = (0,d3_quadtree__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(nodes, x, y).visitAfter(prepare);\n      for (i = 0; i < n; ++i) {\n        node = nodes[i];\n        ri = radii[node.index], ri2 = ri * ri;\n        xi = node.x + node.vx;\n        yi = node.y + node.vy;\n        tree.visit(apply);\n      }\n    }\n\n    function apply(quad, x0, y0, x1, y1) {\n      var data = quad.data, rj = quad.r, r = ri + rj;\n      if (data) {\n        if (data.index > node.index) {\n          var x = xi - data.x - data.vx,\n              y = yi - data.y - data.vy,\n              l = x * x + y * y;\n          if (l < r * r) {\n            if (x === 0) x = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(random), l += x * x;\n            if (y === 0) y = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(random), l += y * y;\n            l = (r - (l = Math.sqrt(l))) / l * strength;\n            node.vx += (x *= l) * (r = (rj *= rj) / (ri2 + rj));\n            node.vy += (y *= l) * r;\n            data.vx -= x * (r = 1 - r);\n            data.vy -= y * r;\n          }\n        }\n        return;\n      }\n      return x0 > xi + r || x1 < xi - r || y0 > yi + r || y1 < yi - r;\n    }\n  }\n\n  function prepare(quad) {\n    if (quad.data) return quad.r = radii[quad.data.index];\n    for (var i = quad.r = 0; i < 4; ++i) {\n      if (quad[i] && quad[i].r > quad.r) {\n        quad.r = quad[i].r;\n      }\n    }\n  }\n\n  function initialize() {\n    if (!nodes) return;\n    var i, n = nodes.length, node;\n    radii = new Array(n);\n    for (i = 0; i < n; ++i) node = nodes[i], radii[node.index] = +radius(node, i, nodes);\n  }\n\n  force.initialize = function(_nodes, _random) {\n    nodes = _nodes;\n    random = _random;\n    initialize();\n  };\n\n  force.iterations = function(_) {\n    return arguments.length ? (iterations = +_, force) : iterations;\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = +_, force) : strength;\n  };\n\n  force.radius = function(_) {\n    return arguments.length ? (radius = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : radius;\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/collide.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/constant.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-force/src/constant.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return function() {\n    return x;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/jiggle.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-force/src/jiggle.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(random) {\n  return (random() - 0.5) * 1e-6;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/jiggle.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/lcg.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-force/src/lcg.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n// https://en.wikipedia.org/wiki/Linear_congruential_generator#Parameters_in_common_use\nconst a = 1664525;\nconst c = 1013904223;\nconst m = 4294967296; // 2^32\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  let s = 1;\n  return () => (s = (a * s + c) % m) / m;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/lcg.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/link.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-force/src/link.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-force/src/constant.js\");\n/* harmony import */ var _jiggle_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./jiggle.js */ \"../../node_modules/d3-force/src/jiggle.js\");\n\n\n\nfunction index(d) {\n  return d.index;\n}\n\nfunction find(nodeById, nodeId) {\n  var node = nodeById.get(nodeId);\n  if (!node) throw new Error(\"node not found: \" + nodeId);\n  return node;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(links) {\n  var id = index,\n      strength = defaultStrength,\n      strengths,\n      distance = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(30),\n      distances,\n      nodes,\n      count,\n      bias,\n      random,\n      iterations = 1;\n\n  if (links == null) links = [];\n\n  function defaultStrength(link) {\n    return 1 / Math.min(count[link.source.index], count[link.target.index]);\n  }\n\n  function force(alpha) {\n    for (var k = 0, n = links.length; k < iterations; ++k) {\n      for (var i = 0, link, source, target, x, y, l, b; i < n; ++i) {\n        link = links[i], source = link.source, target = link.target;\n        x = target.x + target.vx - source.x - source.vx || (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(random);\n        y = target.y + target.vy - source.y - source.vy || (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(random);\n        l = Math.sqrt(x * x + y * y);\n        l = (l - distances[i]) / l * alpha * strengths[i];\n        x *= l, y *= l;\n        target.vx -= x * (b = bias[i]);\n        target.vy -= y * b;\n        source.vx += x * (b = 1 - b);\n        source.vy += y * b;\n      }\n    }\n  }\n\n  function initialize() {\n    if (!nodes) return;\n\n    var i,\n        n = nodes.length,\n        m = links.length,\n        nodeById = new Map(nodes.map((d, i) => [id(d, i, nodes), d])),\n        link;\n\n    for (i = 0, count = new Array(n); i < m; ++i) {\n      link = links[i], link.index = i;\n      if (typeof link.source !== \"object\") link.source = find(nodeById, link.source);\n      if (typeof link.target !== \"object\") link.target = find(nodeById, link.target);\n      count[link.source.index] = (count[link.source.index] || 0) + 1;\n      count[link.target.index] = (count[link.target.index] || 0) + 1;\n    }\n\n    for (i = 0, bias = new Array(m); i < m; ++i) {\n      link = links[i], bias[i] = count[link.source.index] / (count[link.source.index] + count[link.target.index]);\n    }\n\n    strengths = new Array(m), initializeStrength();\n    distances = new Array(m), initializeDistance();\n  }\n\n  function initializeStrength() {\n    if (!nodes) return;\n\n    for (var i = 0, n = links.length; i < n; ++i) {\n      strengths[i] = +strength(links[i], i, links);\n    }\n  }\n\n  function initializeDistance() {\n    if (!nodes) return;\n\n    for (var i = 0, n = links.length; i < n; ++i) {\n      distances[i] = +distance(links[i], i, links);\n    }\n  }\n\n  force.initialize = function(_nodes, _random) {\n    nodes = _nodes;\n    random = _random;\n    initialize();\n  };\n\n  force.links = function(_) {\n    return arguments.length ? (links = _, initialize(), force) : links;\n  };\n\n  force.id = function(_) {\n    return arguments.length ? (id = _, force) : id;\n  };\n\n  force.iterations = function(_) {\n    return arguments.length ? (iterations = +_, force) : iterations;\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initializeStrength(), force) : strength;\n  };\n\n  force.distance = function(_) {\n    return arguments.length ? (distance = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initializeDistance(), force) : distance;\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/link.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/manyBody.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-force/src/manyBody.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_quadtree__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-quadtree */ \"../../node_modules/d3-quadtree/src/quadtree.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-force/src/constant.js\");\n/* harmony import */ var _jiggle_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./jiggle.js */ \"../../node_modules/d3-force/src/jiggle.js\");\n/* harmony import */ var _simulation_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./simulation.js */ \"../../node_modules/d3-force/src/simulation.js\");\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var nodes,\n      node,\n      random,\n      alpha,\n      strength = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(-30),\n      strengths,\n      distanceMin2 = 1,\n      distanceMax2 = Infinity,\n      theta2 = 0.81;\n\n  function force(_) {\n    var i, n = nodes.length, tree = (0,d3_quadtree__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(nodes, _simulation_js__WEBPACK_IMPORTED_MODULE_2__.x, _simulation_js__WEBPACK_IMPORTED_MODULE_2__.y).visitAfter(accumulate);\n    for (alpha = _, i = 0; i < n; ++i) node = nodes[i], tree.visit(apply);\n  }\n\n  function initialize() {\n    if (!nodes) return;\n    var i, n = nodes.length, node;\n    strengths = new Array(n);\n    for (i = 0; i < n; ++i) node = nodes[i], strengths[node.index] = +strength(node, i, nodes);\n  }\n\n  function accumulate(quad) {\n    var strength = 0, q, c, weight = 0, x, y, i;\n\n    // For internal nodes, accumulate forces from child quadrants.\n    if (quad.length) {\n      for (x = y = i = 0; i < 4; ++i) {\n        if ((q = quad[i]) && (c = Math.abs(q.value))) {\n          strength += q.value, weight += c, x += c * q.x, y += c * q.y;\n        }\n      }\n      quad.x = x / weight;\n      quad.y = y / weight;\n    }\n\n    // For leaf nodes, accumulate forces from coincident quadrants.\n    else {\n      q = quad;\n      q.x = q.data.x;\n      q.y = q.data.y;\n      do strength += strengths[q.data.index];\n      while (q = q.next);\n    }\n\n    quad.value = strength;\n  }\n\n  function apply(quad, x1, _, x2) {\n    if (!quad.value) return true;\n\n    var x = quad.x - node.x,\n        y = quad.y - node.y,\n        w = x2 - x1,\n        l = x * x + y * y;\n\n    // Apply the Barnes-Hut approximation if possible.\n    // Limit forces for very close nodes; randomize direction if coincident.\n    if (w * w / theta2 < l) {\n      if (l < distanceMax2) {\n        if (x === 0) x = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(random), l += x * x;\n        if (y === 0) y = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(random), l += y * y;\n        if (l < distanceMin2) l = Math.sqrt(distanceMin2 * l);\n        node.vx += x * quad.value * alpha / l;\n        node.vy += y * quad.value * alpha / l;\n      }\n      return true;\n    }\n\n    // Otherwise, process points directly.\n    else if (quad.length || l >= distanceMax2) return;\n\n    // Limit forces for very close nodes; randomize direction if coincident.\n    if (quad.data !== node || quad.next) {\n      if (x === 0) x = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(random), l += x * x;\n      if (y === 0) y = (0,_jiggle_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(random), l += y * y;\n      if (l < distanceMin2) l = Math.sqrt(distanceMin2 * l);\n    }\n\n    do if (quad.data !== node) {\n      w = strengths[quad.data.index] * alpha / l;\n      node.vx += x * w;\n      node.vy += y * w;\n    } while (quad = quad.next);\n  }\n\n  force.initialize = function(_nodes, _random) {\n    nodes = _nodes;\n    random = _random;\n    initialize();\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : strength;\n  };\n\n  force.distanceMin = function(_) {\n    return arguments.length ? (distanceMin2 = _ * _, force) : Math.sqrt(distanceMin2);\n  };\n\n  force.distanceMax = function(_) {\n    return arguments.length ? (distanceMax2 = _ * _, force) : Math.sqrt(distanceMax2);\n  };\n\n  force.theta = function(_) {\n    return arguments.length ? (theta2 = _ * _, force) : Math.sqrt(theta2);\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/manyBody.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/simulation.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-force/src/simulation.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   x: () => (/* binding */ x),\n/* harmony export */   y: () => (/* binding */ y)\n/* harmony export */ });\n/* harmony import */ var d3_dispatch__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-dispatch */ \"../../node_modules/d3-dispatch/src/dispatch.js\");\n/* harmony import */ var d3_timer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-timer */ \"../../node_modules/d3-timer/src/timer.js\");\n/* harmony import */ var _lcg_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lcg.js */ \"../../node_modules/d3-force/src/lcg.js\");\n\n\n\n\nfunction x(d) {\n  return d.x;\n}\n\nfunction y(d) {\n  return d.y;\n}\n\nvar initialRadius = 10,\n    initialAngle = Math.PI * (3 - Math.sqrt(5));\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(nodes) {\n  var simulation,\n      alpha = 1,\n      alphaMin = 0.001,\n      alphaDecay = 1 - Math.pow(alphaMin, 1 / 300),\n      alphaTarget = 0,\n      velocityDecay = 0.6,\n      forces = new Map(),\n      stepper = (0,d3_timer__WEBPACK_IMPORTED_MODULE_0__.timer)(step),\n      event = (0,d3_dispatch__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(\"tick\", \"end\"),\n      random = (0,_lcg_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])();\n\n  if (nodes == null) nodes = [];\n\n  function step() {\n    tick();\n    event.call(\"tick\", simulation);\n    if (alpha < alphaMin) {\n      stepper.stop();\n      event.call(\"end\", simulation);\n    }\n  }\n\n  function tick(iterations) {\n    var i, n = nodes.length, node;\n\n    if (iterations === undefined) iterations = 1;\n\n    for (var k = 0; k < iterations; ++k) {\n      alpha += (alphaTarget - alpha) * alphaDecay;\n\n      forces.forEach(function(force) {\n        force(alpha);\n      });\n\n      for (i = 0; i < n; ++i) {\n        node = nodes[i];\n        if (node.fx == null) node.x += node.vx *= velocityDecay;\n        else node.x = node.fx, node.vx = 0;\n        if (node.fy == null) node.y += node.vy *= velocityDecay;\n        else node.y = node.fy, node.vy = 0;\n      }\n    }\n\n    return simulation;\n  }\n\n  function initializeNodes() {\n    for (var i = 0, n = nodes.length, node; i < n; ++i) {\n      node = nodes[i], node.index = i;\n      if (node.fx != null) node.x = node.fx;\n      if (node.fy != null) node.y = node.fy;\n      if (isNaN(node.x) || isNaN(node.y)) {\n        var radius = initialRadius * Math.sqrt(0.5 + i), angle = i * initialAngle;\n        node.x = radius * Math.cos(angle);\n        node.y = radius * Math.sin(angle);\n      }\n      if (isNaN(node.vx) || isNaN(node.vy)) {\n        node.vx = node.vy = 0;\n      }\n    }\n  }\n\n  function initializeForce(force) {\n    if (force.initialize) force.initialize(nodes, random);\n    return force;\n  }\n\n  initializeNodes();\n\n  return simulation = {\n    tick: tick,\n\n    restart: function() {\n      return stepper.restart(step), simulation;\n    },\n\n    stop: function() {\n      return stepper.stop(), simulation;\n    },\n\n    nodes: function(_) {\n      return arguments.length ? (nodes = _, initializeNodes(), forces.forEach(initializeForce), simulation) : nodes;\n    },\n\n    alpha: function(_) {\n      return arguments.length ? (alpha = +_, simulation) : alpha;\n    },\n\n    alphaMin: function(_) {\n      return arguments.length ? (alphaMin = +_, simulation) : alphaMin;\n    },\n\n    alphaDecay: function(_) {\n      return arguments.length ? (alphaDecay = +_, simulation) : +alphaDecay;\n    },\n\n    alphaTarget: function(_) {\n      return arguments.length ? (alphaTarget = +_, simulation) : alphaTarget;\n    },\n\n    velocityDecay: function(_) {\n      return arguments.length ? (velocityDecay = 1 - _, simulation) : 1 - velocityDecay;\n    },\n\n    randomSource: function(_) {\n      return arguments.length ? (random = _, forces.forEach(initializeForce), simulation) : random;\n    },\n\n    force: function(name, _) {\n      return arguments.length > 1 ? ((_ == null ? forces.delete(name) : forces.set(name, initializeForce(_))), simulation) : forces.get(name);\n    },\n\n    find: function(x, y, radius) {\n      var i = 0,\n          n = nodes.length,\n          dx,\n          dy,\n          d2,\n          node,\n          closest;\n\n      if (radius == null) radius = Infinity;\n      else radius *= radius;\n\n      for (i = 0; i < n; ++i) {\n        node = nodes[i];\n        dx = x - node.x;\n        dy = y - node.y;\n        d2 = dx * dx + dy * dy;\n        if (d2 < radius) closest = node, radius = d2;\n      }\n\n      return closest;\n    },\n\n    on: function(name, _) {\n      return arguments.length > 1 ? (event.on(name, _), simulation) : event.on(name);\n    }\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/simulation.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/x.js":
/*!********************************************!*\
  !*** ../../node_modules/d3-force/src/x.js ***!
  \********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-force/src/constant.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  var strength = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(0.1),\n      nodes,\n      strengths,\n      xz;\n\n  if (typeof x !== \"function\") x = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(x == null ? 0 : +x);\n\n  function force(alpha) {\n    for (var i = 0, n = nodes.length, node; i < n; ++i) {\n      node = nodes[i], node.vx += (xz[i] - node.x) * strengths[i] * alpha;\n    }\n  }\n\n  function initialize() {\n    if (!nodes) return;\n    var i, n = nodes.length;\n    strengths = new Array(n);\n    xz = new Array(n);\n    for (i = 0; i < n; ++i) {\n      strengths[i] = isNaN(xz[i] = +x(nodes[i], i, nodes)) ? 0 : +strength(nodes[i], i, nodes);\n    }\n  }\n\n  force.initialize = function(_) {\n    nodes = _;\n    initialize();\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : strength;\n  };\n\n  force.x = function(_) {\n    return arguments.length ? (x = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : x;\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/x.js?");

/***/ }),

/***/ "../../node_modules/d3-force/src/y.js":
/*!********************************************!*\
  !*** ../../node_modules/d3-force/src/y.js ***!
  \********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-force/src/constant.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(y) {\n  var strength = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(0.1),\n      nodes,\n      strengths,\n      yz;\n\n  if (typeof y !== \"function\") y = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(y == null ? 0 : +y);\n\n  function force(alpha) {\n    for (var i = 0, n = nodes.length, node; i < n; ++i) {\n      node = nodes[i], node.vy += (yz[i] - node.y) * strengths[i] * alpha;\n    }\n  }\n\n  function initialize() {\n    if (!nodes) return;\n    var i, n = nodes.length;\n    strengths = new Array(n);\n    yz = new Array(n);\n    for (i = 0; i < n; ++i) {\n      strengths[i] = isNaN(yz[i] = +y(nodes[i], i, nodes)) ? 0 : +strength(nodes[i], i, nodes);\n    }\n  }\n\n  force.initialize = function(_) {\n    nodes = _;\n    initialize();\n  };\n\n  force.strength = function(_) {\n    return arguments.length ? (strength = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : strength;\n  };\n\n  force.y = function(_) {\n    return arguments.length ? (y = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), initialize(), force) : y;\n  };\n\n  return force;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-force/src/y.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/defaultLocale.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-format/src/defaultLocale.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ defaultLocale),\n/* harmony export */   format: () => (/* binding */ format),\n/* harmony export */   formatPrefix: () => (/* binding */ formatPrefix)\n/* harmony export */ });\n/* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./locale.js */ \"../../node_modules/d3-format/src/locale.js\");\n\n\nvar locale;\nvar format;\nvar formatPrefix;\n\ndefaultLocale({\n  thousands: \",\",\n  grouping: [3],\n  currency: [\"$\", \"\"]\n});\n\nfunction defaultLocale(definition) {\n  locale = (0,_locale_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(definition);\n  format = locale.format;\n  formatPrefix = locale.formatPrefix;\n  return locale;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/defaultLocale.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/exponent.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-format/src/exponent.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./formatDecimal.js */ \"../../node_modules/d3-format/src/formatDecimal.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return x = (0,_formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(Math.abs(x)), x ? x[1] : NaN;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/exponent.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatDecimal.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-format/src/formatDecimal.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   formatDecimalParts: () => (/* binding */ formatDecimalParts)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return Math.abs(x = Math.round(x)) >= 1e21\n      ? x.toLocaleString(\"en\").replace(/,/g, \"\")\n      : x.toString(10);\n}\n\n// Computes the decimal coefficient and exponent of the specified number x with\n// significant digits p, where x is positive and p is in [1, 21] or undefined.\n// For example, formatDecimalParts(1.23) returns [\"123\", 0].\nfunction formatDecimalParts(x, p) {\n  if ((i = (x = p ? x.toExponential(p - 1) : x.toExponential()).indexOf(\"e\")) < 0) return null; // NaN, ±Infinity\n  var i, coefficient = x.slice(0, i);\n\n  // The string returned by toExponential either has the form \\d\\.\\d+e[-+]\\d+\n  // (e.g., 1.2e+3) or the form \\de[-+]\\d+ (e.g., 1e+3).\n  return [\n    coefficient.length > 1 ? coefficient[0] + coefficient.slice(2) : coefficient,\n    +x.slice(i + 1)\n  ];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatDecimal.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatGroup.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-format/src/formatGroup.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(grouping, thousands) {\n  return function(value, width) {\n    var i = value.length,\n        t = [],\n        j = 0,\n        g = grouping[0],\n        length = 0;\n\n    while (i > 0 && g > 0) {\n      if (length + g + 1 > width) g = Math.max(1, width - length);\n      t.push(value.substring(i -= g, i + g));\n      if ((length += g + 1) > width) break;\n      g = grouping[j = (j + 1) % grouping.length];\n    }\n\n    return t.reverse().join(thousands);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatGroup.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatNumerals.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-format/src/formatNumerals.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(numerals) {\n  return function(value) {\n    return value.replace(/[0-9]/g, function(i) {\n      return numerals[+i];\n    });\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatNumerals.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatPrefixAuto.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-format/src/formatPrefixAuto.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   prefixExponent: () => (/* binding */ prefixExponent)\n/* harmony export */ });\n/* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./formatDecimal.js */ \"../../node_modules/d3-format/src/formatDecimal.js\");\n\n\nvar prefixExponent;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, p) {\n  var d = (0,_formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(x, p);\n  if (!d) return x + \"\";\n  var coefficient = d[0],\n      exponent = d[1],\n      i = exponent - (prefixExponent = Math.max(-8, Math.min(8, Math.floor(exponent / 3))) * 3) + 1,\n      n = coefficient.length;\n  return i === n ? coefficient\n      : i > n ? coefficient + new Array(i - n + 1).join(\"0\")\n      : i > 0 ? coefficient.slice(0, i) + \".\" + coefficient.slice(i)\n      : \"0.\" + new Array(1 - i).join(\"0\") + (0,_formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(x, Math.max(0, p + i - 1))[0]; // less than 1y!\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatPrefixAuto.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatRounded.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-format/src/formatRounded.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./formatDecimal.js */ \"../../node_modules/d3-format/src/formatDecimal.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, p) {\n  var d = (0,_formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(x, p);\n  if (!d) return x + \"\";\n  var coefficient = d[0],\n      exponent = d[1];\n  return exponent < 0 ? \"0.\" + new Array(-exponent).join(\"0\") + coefficient\n      : coefficient.length > exponent + 1 ? coefficient.slice(0, exponent + 1) + \".\" + coefficient.slice(exponent + 1)\n      : coefficient + new Array(exponent - coefficient.length + 2).join(\"0\");\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatRounded.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatSpecifier.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-format/src/formatSpecifier.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   FormatSpecifier: () => (/* binding */ FormatSpecifier),\n/* harmony export */   \"default\": () => (/* binding */ formatSpecifier)\n/* harmony export */ });\n// [[fill]align][sign][symbol][0][width][,][.precision][~][type]\nvar re = /^(?:(.)?([<>=^]))?([+\\-( ])?([$#])?(0)?(\\d+)?(,)?(\\.\\d+)?(~)?([a-z%])?$/i;\n\nfunction formatSpecifier(specifier) {\n  if (!(match = re.exec(specifier))) throw new Error(\"invalid format: \" + specifier);\n  var match;\n  return new FormatSpecifier({\n    fill: match[1],\n    align: match[2],\n    sign: match[3],\n    symbol: match[4],\n    zero: match[5],\n    width: match[6],\n    comma: match[7],\n    precision: match[8] && match[8].slice(1),\n    trim: match[9],\n    type: match[10]\n  });\n}\n\nformatSpecifier.prototype = FormatSpecifier.prototype; // instanceof\n\nfunction FormatSpecifier(specifier) {\n  this.fill = specifier.fill === undefined ? \" \" : specifier.fill + \"\";\n  this.align = specifier.align === undefined ? \">\" : specifier.align + \"\";\n  this.sign = specifier.sign === undefined ? \"-\" : specifier.sign + \"\";\n  this.symbol = specifier.symbol === undefined ? \"\" : specifier.symbol + \"\";\n  this.zero = !!specifier.zero;\n  this.width = specifier.width === undefined ? undefined : +specifier.width;\n  this.comma = !!specifier.comma;\n  this.precision = specifier.precision === undefined ? undefined : +specifier.precision;\n  this.trim = !!specifier.trim;\n  this.type = specifier.type === undefined ? \"\" : specifier.type + \"\";\n}\n\nFormatSpecifier.prototype.toString = function() {\n  return this.fill\n      + this.align\n      + this.sign\n      + this.symbol\n      + (this.zero ? \"0\" : \"\")\n      + (this.width === undefined ? \"\" : Math.max(1, this.width | 0))\n      + (this.comma ? \",\" : \"\")\n      + (this.precision === undefined ? \"\" : \".\" + Math.max(0, this.precision | 0))\n      + (this.trim ? \"~\" : \"\")\n      + this.type;\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatSpecifier.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatTrim.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-format/src/formatTrim.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n// Trims insignificant zeros, e.g., replaces 1.2000k with 1.2k.\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(s) {\n  out: for (var n = s.length, i = 1, i0 = -1, i1; i < n; ++i) {\n    switch (s[i]) {\n      case \".\": i0 = i1 = i; break;\n      case \"0\": if (i0 === 0) i0 = i; i1 = i; break;\n      default: if (!+s[i]) break out; if (i0 > 0) i0 = 0; break;\n    }\n  }\n  return i0 > 0 ? s.slice(0, i0) + s.slice(i1 + 1) : s;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatTrim.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/formatTypes.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-format/src/formatTypes.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./formatDecimal.js */ \"../../node_modules/d3-format/src/formatDecimal.js\");\n/* harmony import */ var _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./formatPrefixAuto.js */ \"../../node_modules/d3-format/src/formatPrefixAuto.js\");\n/* harmony import */ var _formatRounded_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./formatRounded.js */ \"../../node_modules/d3-format/src/formatRounded.js\");\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  \"%\": (x, p) => (x * 100).toFixed(p),\n  \"b\": (x) => Math.round(x).toString(2),\n  \"c\": (x) => x + \"\",\n  \"d\": _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  \"e\": (x, p) => x.toExponential(p),\n  \"f\": (x, p) => x.toFixed(p),\n  \"g\": (x, p) => x.toPrecision(p),\n  \"o\": (x) => Math.round(x).toString(8),\n  \"p\": (x, p) => (0,_formatRounded_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(x * 100, p),\n  \"r\": _formatRounded_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  \"s\": _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  \"X\": (x) => Math.round(x).toString(16).toUpperCase(),\n  \"x\": (x) => Math.round(x).toString(16)\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/formatTypes.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/identity.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-format/src/identity.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return x;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/identity.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/locale.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-format/src/locale.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _exponent_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./exponent.js */ \"../../node_modules/d3-format/src/exponent.js\");\n/* harmony import */ var _formatGroup_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./formatGroup.js */ \"../../node_modules/d3-format/src/formatGroup.js\");\n/* harmony import */ var _formatNumerals_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./formatNumerals.js */ \"../../node_modules/d3-format/src/formatNumerals.js\");\n/* harmony import */ var _formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./formatSpecifier.js */ \"../../node_modules/d3-format/src/formatSpecifier.js\");\n/* harmony import */ var _formatTrim_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./formatTrim.js */ \"../../node_modules/d3-format/src/formatTrim.js\");\n/* harmony import */ var _formatTypes_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./formatTypes.js */ \"../../node_modules/d3-format/src/formatTypes.js\");\n/* harmony import */ var _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./formatPrefixAuto.js */ \"../../node_modules/d3-format/src/formatPrefixAuto.js\");\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity.js */ \"../../node_modules/d3-format/src/identity.js\");\n\n\n\n\n\n\n\n\n\nvar map = Array.prototype.map,\n    prefixes = [\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"µ\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"];\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(locale) {\n  var group = locale.grouping === undefined || locale.thousands === undefined ? _identity_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : (0,_formatGroup_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(map.call(locale.grouping, Number), locale.thousands + \"\"),\n      currencyPrefix = locale.currency === undefined ? \"\" : locale.currency[0] + \"\",\n      currencySuffix = locale.currency === undefined ? \"\" : locale.currency[1] + \"\",\n      decimal = locale.decimal === undefined ? \".\" : locale.decimal + \"\",\n      numerals = locale.numerals === undefined ? _identity_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : (0,_formatNumerals_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(map.call(locale.numerals, String)),\n      percent = locale.percent === undefined ? \"%\" : locale.percent + \"\",\n      minus = locale.minus === undefined ? \"−\" : locale.minus + \"\",\n      nan = locale.nan === undefined ? \"NaN\" : locale.nan + \"\";\n\n  function newFormat(specifier) {\n    specifier = (0,_formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(specifier);\n\n    var fill = specifier.fill,\n        align = specifier.align,\n        sign = specifier.sign,\n        symbol = specifier.symbol,\n        zero = specifier.zero,\n        width = specifier.width,\n        comma = specifier.comma,\n        precision = specifier.precision,\n        trim = specifier.trim,\n        type = specifier.type;\n\n    // The \"n\" type is an alias for \",g\".\n    if (type === \"n\") comma = true, type = \"g\";\n\n    // The \"\" type, and any invalid type, is an alias for \".12~g\".\n    else if (!_formatTypes_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"][type]) precision === undefined && (precision = 12), trim = true, type = \"g\";\n\n    // If zero fill is specified, padding goes after sign and before digits.\n    if (zero || (fill === \"0\" && align === \"=\")) zero = true, fill = \"0\", align = \"=\";\n\n    // Compute the prefix and suffix.\n    // For SI-prefix, the suffix is lazily computed.\n    var prefix = symbol === \"$\" ? currencyPrefix : symbol === \"#\" && /[boxX]/.test(type) ? \"0\" + type.toLowerCase() : \"\",\n        suffix = symbol === \"$\" ? currencySuffix : /[%p]/.test(type) ? percent : \"\";\n\n    // What format function should we use?\n    // Is this an integer type?\n    // Can this type generate exponential notation?\n    var formatType = _formatTypes_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"][type],\n        maybeSuffix = /[defgprs%]/.test(type);\n\n    // Set the default precision if not specified,\n    // or clamp the specified precision to the supported range.\n    // For significant precision, it must be in [1, 21].\n    // For fixed precision, it must be in [0, 20].\n    precision = precision === undefined ? 6\n        : /[gprs]/.test(type) ? Math.max(1, Math.min(21, precision))\n        : Math.max(0, Math.min(20, precision));\n\n    function format(value) {\n      var valuePrefix = prefix,\n          valueSuffix = suffix,\n          i, n, c;\n\n      if (type === \"c\") {\n        valueSuffix = formatType(value) + valueSuffix;\n        value = \"\";\n      } else {\n        value = +value;\n\n        // Determine the sign. -0 is not less than 0, but 1 / -0 is!\n        var valueNegative = value < 0 || 1 / value < 0;\n\n        // Perform the initial formatting.\n        value = isNaN(value) ? nan : formatType(Math.abs(value), precision);\n\n        // Trim insignificant zeros.\n        if (trim) value = (0,_formatTrim_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(value);\n\n        // If a negative value rounds to zero after formatting, and no explicit positive sign is requested, hide the sign.\n        if (valueNegative && +value === 0 && sign !== \"+\") valueNegative = false;\n\n        // Compute the prefix and suffix.\n        valuePrefix = (valueNegative ? (sign === \"(\" ? sign : minus) : sign === \"-\" || sign === \"(\" ? \"\" : sign) + valuePrefix;\n        valueSuffix = (type === \"s\" ? prefixes[8 + _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_6__.prefixExponent / 3] : \"\") + valueSuffix + (valueNegative && sign === \"(\" ? \")\" : \"\");\n\n        // Break the formatted value into the integer “value” part that can be\n        // grouped, and fractional or exponential “suffix” part that is not.\n        if (maybeSuffix) {\n          i = -1, n = value.length;\n          while (++i < n) {\n            if (c = value.charCodeAt(i), 48 > c || c > 57) {\n              valueSuffix = (c === 46 ? decimal + value.slice(i + 1) : value.slice(i)) + valueSuffix;\n              value = value.slice(0, i);\n              break;\n            }\n          }\n        }\n      }\n\n      // If the fill character is not \"0\", grouping is applied before padding.\n      if (comma && !zero) value = group(value, Infinity);\n\n      // Compute the padding.\n      var length = valuePrefix.length + value.length + valueSuffix.length,\n          padding = length < width ? new Array(width - length + 1).join(fill) : \"\";\n\n      // If the fill character is \"0\", grouping is applied after padding.\n      if (comma && zero) value = group(padding + value, padding.length ? width - valueSuffix.length : Infinity), padding = \"\";\n\n      // Reconstruct the final output based on the desired alignment.\n      switch (align) {\n        case \"<\": value = valuePrefix + value + valueSuffix + padding; break;\n        case \"=\": value = valuePrefix + padding + value + valueSuffix; break;\n        case \"^\": value = padding.slice(0, length = padding.length >> 1) + valuePrefix + value + valueSuffix + padding.slice(length); break;\n        default: value = padding + valuePrefix + value + valueSuffix; break;\n      }\n\n      return numerals(value);\n    }\n\n    format.toString = function() {\n      return specifier + \"\";\n    };\n\n    return format;\n  }\n\n  function formatPrefix(specifier, value) {\n    var f = newFormat((specifier = (0,_formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(specifier), specifier.type = \"f\", specifier)),\n        e = Math.max(-8, Math.min(8, Math.floor((0,_exponent_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"])(value) / 3))) * 3,\n        k = Math.pow(10, -e),\n        prefix = prefixes[8 + e / 3];\n    return function(value) {\n      return f(k * value) + prefix;\n    };\n  }\n\n  return {\n    format: newFormat,\n    formatPrefix: formatPrefix\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/locale.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/precisionFixed.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-format/src/precisionFixed.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _exponent_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./exponent.js */ \"../../node_modules/d3-format/src/exponent.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(step) {\n  return Math.max(0, -(0,_exponent_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(Math.abs(step)));\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/precisionFixed.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/precisionPrefix.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-format/src/precisionPrefix.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _exponent_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./exponent.js */ \"../../node_modules/d3-format/src/exponent.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(step, value) {\n  return Math.max(0, Math.max(-8, Math.min(8, Math.floor((0,_exponent_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value) / 3))) * 3 - (0,_exponent_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(Math.abs(step)));\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/precisionPrefix.js?");

/***/ }),

/***/ "../../node_modules/d3-format/src/precisionRound.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-format/src/precisionRound.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _exponent_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./exponent.js */ \"../../node_modules/d3-format/src/exponent.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(step, max) {\n  step = Math.abs(step), max = Math.abs(max) - step;\n  return Math.max(0, (0,_exponent_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(max) - (0,_exponent_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(step)) + 1;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-format/src/precisionRound.js?");

/***/ }),

/***/ "../../node_modules/d3-geo-projection/src/math.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-geo-projection/src/math.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   abs: () => (/* binding */ abs),\n/* harmony export */   acos: () => (/* binding */ acos),\n/* harmony export */   arcosh: () => (/* binding */ arcosh),\n/* harmony export */   arsinh: () => (/* binding */ arsinh),\n/* harmony export */   asin: () => (/* binding */ asin),\n/* harmony export */   atan: () => (/* binding */ atan),\n/* harmony export */   atan2: () => (/* binding */ atan2),\n/* harmony export */   ceil: () => (/* binding */ ceil),\n/* harmony export */   cos: () => (/* binding */ cos),\n/* harmony export */   cosh: () => (/* binding */ cosh),\n/* harmony export */   degrees: () => (/* binding */ degrees),\n/* harmony export */   epsilon: () => (/* binding */ epsilon),\n/* harmony export */   epsilon2: () => (/* binding */ epsilon2),\n/* harmony export */   exp: () => (/* binding */ exp),\n/* harmony export */   floor: () => (/* binding */ floor),\n/* harmony export */   halfPi: () => (/* binding */ halfPi),\n/* harmony export */   log: () => (/* binding */ log),\n/* harmony export */   max: () => (/* binding */ max),\n/* harmony export */   min: () => (/* binding */ min),\n/* harmony export */   pi: () => (/* binding */ pi),\n/* harmony export */   pow: () => (/* binding */ pow),\n/* harmony export */   quarterPi: () => (/* binding */ quarterPi),\n/* harmony export */   radians: () => (/* binding */ radians),\n/* harmony export */   round: () => (/* binding */ round),\n/* harmony export */   sign: () => (/* binding */ sign),\n/* harmony export */   sin: () => (/* binding */ sin),\n/* harmony export */   sinci: () => (/* binding */ sinci),\n/* harmony export */   sinh: () => (/* binding */ sinh),\n/* harmony export */   sqrt: () => (/* binding */ sqrt),\n/* harmony export */   sqrt1_2: () => (/* binding */ sqrt1_2),\n/* harmony export */   sqrt2: () => (/* binding */ sqrt2),\n/* harmony export */   sqrtPi: () => (/* binding */ sqrtPi),\n/* harmony export */   tan: () => (/* binding */ tan),\n/* harmony export */   tanh: () => (/* binding */ tanh),\n/* harmony export */   tau: () => (/* binding */ tau)\n/* harmony export */ });\nvar abs = Math.abs;\nvar atan = Math.atan;\nvar atan2 = Math.atan2;\nvar ceil = Math.ceil;\nvar cos = Math.cos;\nvar exp = Math.exp;\nvar floor = Math.floor;\nvar log = Math.log;\nvar max = Math.max;\nvar min = Math.min;\nvar pow = Math.pow;\nvar round = Math.round;\nvar sign = Math.sign || function(x) { return x > 0 ? 1 : x < 0 ? -1 : 0; };\nvar sin = Math.sin;\nvar tan = Math.tan;\n\nvar epsilon = 1e-6;\nvar epsilon2 = 1e-12;\nvar pi = Math.PI;\nvar halfPi = pi / 2;\nvar quarterPi = pi / 4;\nvar sqrt1_2 = Math.SQRT1_2;\nvar sqrt2 = sqrt(2);\nvar sqrtPi = sqrt(pi);\nvar tau = pi * 2;\nvar degrees = 180 / pi;\nvar radians = pi / 180;\n\nfunction sinci(x) {\n  return x ? x / Math.sin(x) : 1;\n}\n\nfunction asin(x) {\n  return x > 1 ? halfPi : x < -1 ? -halfPi : Math.asin(x);\n}\n\nfunction acos(x) {\n  return x > 1 ? 0 : x < -1 ? pi : Math.acos(x);\n}\n\nfunction sqrt(x) {\n  return x > 0 ? Math.sqrt(x) : 0;\n}\n\nfunction tanh(x) {\n  x = exp(2 * x);\n  return (x - 1) / (x + 1);\n}\n\nfunction sinh(x) {\n  return (exp(x) - exp(-x)) / 2;\n}\n\nfunction cosh(x) {\n  return (exp(x) + exp(-x)) / 2;\n}\n\nfunction arsinh(x) {\n  return log(x + sqrt(x * x + 1));\n}\n\nfunction arcosh(x) {\n  return log(x + sqrt(x * x - 1));\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo-projection/src/math.js?");

/***/ }),

/***/ "../../node_modules/d3-geo-projection/src/mollweide.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-geo-projection/src/mollweide.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   mollweideBromleyRaw: () => (/* binding */ mollweideBromleyRaw),\n/* harmony export */   mollweideBromleyTheta: () => (/* binding */ mollweideBromleyTheta),\n/* harmony export */   mollweideRaw: () => (/* binding */ mollweideRaw)\n/* harmony export */ });\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-geo */ \"../../node_modules/d3-geo/src/projection/index.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo-projection/src/math.js\");\n\n\n\nfunction mollweideBromleyTheta(cp, phi) {\n  var cpsinPhi = cp * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi), i = 30, delta;\n  do phi -= delta = (phi + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi) - cpsinPhi) / (1 + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi));\n  while ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(delta) > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon && --i > 0);\n  return phi / 2;\n}\n\nfunction mollweideBromleyRaw(cx, cy, cp) {\n\n  function forward(lambda, phi) {\n    return [cx * lambda * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi = mollweideBromleyTheta(cp, phi)), cy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi)];\n  }\n\n  forward.invert = function(x, y) {\n    return y = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(y / cy), [x / (cx * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y)), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)((2 * y + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(2 * y)) / cp)];\n  };\n\n  return forward;\n}\n\nvar mollweideRaw = mollweideBromleyRaw(_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt2 / _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi, _math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt2, _math_js__WEBPACK_IMPORTED_MODULE_0__.pi);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,d3_geo__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(mollweideRaw)\n      .scale(169.529);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo-projection/src/mollweide.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/area.js":
/*!*********************************************!*\
  !*** ../../node_modules/d3-geo/src/area.js ***!
  \*********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   areaRingSum: () => (/* binding */ areaRingSum),\n/* harmony export */   areaStream: () => (/* binding */ areaStream),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n/* harmony import */ var _stream_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./stream.js */ \"../../node_modules/d3-geo/src/stream.js\");\n\n\n\n\n\nvar areaRingSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n\n// hello?\n\nvar areaSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder(),\n    lambda00,\n    phi00,\n    lambda0,\n    cosPhi0,\n    sinPhi0;\n\nvar areaStream = {\n  point: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  lineStart: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  lineEnd: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  polygonStart: function() {\n    areaRingSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n    areaStream.lineStart = areaRingStart;\n    areaStream.lineEnd = areaRingEnd;\n  },\n  polygonEnd: function() {\n    var areaRing = +areaRingSum;\n    areaSum.add(areaRing < 0 ? _math_js__WEBPACK_IMPORTED_MODULE_2__.tau + areaRing : areaRing);\n    this.lineStart = this.lineEnd = this.point = _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n  },\n  sphere: function() {\n    areaSum.add(_math_js__WEBPACK_IMPORTED_MODULE_2__.tau);\n  }\n};\n\nfunction areaRingStart() {\n  areaStream.point = areaPointFirst;\n}\n\nfunction areaRingEnd() {\n  areaPoint(lambda00, phi00);\n}\n\nfunction areaPointFirst(lambda, phi) {\n  areaStream.point = areaPoint;\n  lambda00 = lambda, phi00 = phi;\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_2__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_2__.radians;\n  lambda0 = lambda, cosPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.cos)(phi = phi / 2 + _math_js__WEBPACK_IMPORTED_MODULE_2__.quarterPi), sinPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.sin)(phi);\n}\n\nfunction areaPoint(lambda, phi) {\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_2__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_2__.radians;\n  phi = phi / 2 + _math_js__WEBPACK_IMPORTED_MODULE_2__.quarterPi; // half the angular distance from south pole\n\n  // Spherical excess E for a spherical triangle with vertices: south pole,\n  // previous point, current point.  Uses a formula derived from Cagnoli’s\n  // theorem.  See Todhunter, Spherical Trig. (1871), Sec. 103, Eq. (2).\n  var dLambda = lambda - lambda0,\n      sdLambda = dLambda >= 0 ? 1 : -1,\n      adLambda = sdLambda * dLambda,\n      cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.cos)(phi),\n      sinPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.sin)(phi),\n      k = sinPhi0 * sinPhi,\n      u = cosPhi0 * cosPhi + k * (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.cos)(adLambda),\n      v = k * sdLambda * (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.sin)(adLambda);\n  areaRingSum.add((0,_math_js__WEBPACK_IMPORTED_MODULE_2__.atan2)(v, u));\n\n  // Advance the previous points.\n  lambda0 = lambda, cosPhi0 = cosPhi, sinPhi0 = sinPhi;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(object) {\n  areaSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n  (0,_stream_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(object, areaStream);\n  return areaSum * 2;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/area.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/bounds.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-geo/src/bounds.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _area_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./area.js */ \"../../node_modules/d3-geo/src/area.js\");\n/* harmony import */ var _cartesian_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./cartesian.js */ \"../../node_modules/d3-geo/src/cartesian.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _stream_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./stream.js */ \"../../node_modules/d3-geo/src/stream.js\");\n\n\n\n\n\n\nvar lambda0, phi0, lambda1, phi1, // bounds\n    lambda2, // previous lambda-coordinate\n    lambda00, phi00, // first point\n    p0, // previous 3D point\n    deltaSum,\n    ranges,\n    range;\n\nvar boundsStream = {\n  point: boundsPoint,\n  lineStart: boundsLineStart,\n  lineEnd: boundsLineEnd,\n  polygonStart: function() {\n    boundsStream.point = boundsRingPoint;\n    boundsStream.lineStart = boundsRingStart;\n    boundsStream.lineEnd = boundsRingEnd;\n    deltaSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n    _area_js__WEBPACK_IMPORTED_MODULE_1__.areaStream.polygonStart();\n  },\n  polygonEnd: function() {\n    _area_js__WEBPACK_IMPORTED_MODULE_1__.areaStream.polygonEnd();\n    boundsStream.point = boundsPoint;\n    boundsStream.lineStart = boundsLineStart;\n    boundsStream.lineEnd = boundsLineEnd;\n    if (_area_js__WEBPACK_IMPORTED_MODULE_1__.areaRingSum < 0) lambda0 = -(lambda1 = 180), phi0 = -(phi1 = 90);\n    else if (deltaSum > _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon) phi1 = 90;\n    else if (deltaSum < -_math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon) phi0 = -90;\n    range[0] = lambda0, range[1] = lambda1;\n  },\n  sphere: function() {\n    lambda0 = -(lambda1 = 180), phi0 = -(phi1 = 90);\n  }\n};\n\nfunction boundsPoint(lambda, phi) {\n  ranges.push(range = [lambda0 = lambda, lambda1 = lambda]);\n  if (phi < phi0) phi0 = phi;\n  if (phi > phi1) phi1 = phi;\n}\n\nfunction linePoint(lambda, phi) {\n  var p = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesian)([lambda * _math_js__WEBPACK_IMPORTED_MODULE_2__.radians, phi * _math_js__WEBPACK_IMPORTED_MODULE_2__.radians]);\n  if (p0) {\n    var normal = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianCross)(p0, p),\n        equatorial = [normal[1], -normal[0], 0],\n        inflection = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianCross)(equatorial, normal);\n    (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianNormalizeInPlace)(inflection);\n    inflection = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.spherical)(inflection);\n    var delta = lambda - lambda2,\n        sign = delta > 0 ? 1 : -1,\n        lambdai = inflection[0] * _math_js__WEBPACK_IMPORTED_MODULE_2__.degrees * sign,\n        phii,\n        antimeridian = (0,_math_js__WEBPACK_IMPORTED_MODULE_2__.abs)(delta) > 180;\n    if (antimeridian ^ (sign * lambda2 < lambdai && lambdai < sign * lambda)) {\n      phii = inflection[1] * _math_js__WEBPACK_IMPORTED_MODULE_2__.degrees;\n      if (phii > phi1) phi1 = phii;\n    } else if (lambdai = (lambdai + 360) % 360 - 180, antimeridian ^ (sign * lambda2 < lambdai && lambdai < sign * lambda)) {\n      phii = -inflection[1] * _math_js__WEBPACK_IMPORTED_MODULE_2__.degrees;\n      if (phii < phi0) phi0 = phii;\n    } else {\n      if (phi < phi0) phi0 = phi;\n      if (phi > phi1) phi1 = phi;\n    }\n    if (antimeridian) {\n      if (lambda < lambda2) {\n        if (angle(lambda0, lambda) > angle(lambda0, lambda1)) lambda1 = lambda;\n      } else {\n        if (angle(lambda, lambda1) > angle(lambda0, lambda1)) lambda0 = lambda;\n      }\n    } else {\n      if (lambda1 >= lambda0) {\n        if (lambda < lambda0) lambda0 = lambda;\n        if (lambda > lambda1) lambda1 = lambda;\n      } else {\n        if (lambda > lambda2) {\n          if (angle(lambda0, lambda) > angle(lambda0, lambda1)) lambda1 = lambda;\n        } else {\n          if (angle(lambda, lambda1) > angle(lambda0, lambda1)) lambda0 = lambda;\n        }\n      }\n    }\n  } else {\n    ranges.push(range = [lambda0 = lambda, lambda1 = lambda]);\n  }\n  if (phi < phi0) phi0 = phi;\n  if (phi > phi1) phi1 = phi;\n  p0 = p, lambda2 = lambda;\n}\n\nfunction boundsLineStart() {\n  boundsStream.point = linePoint;\n}\n\nfunction boundsLineEnd() {\n  range[0] = lambda0, range[1] = lambda1;\n  boundsStream.point = boundsPoint;\n  p0 = null;\n}\n\nfunction boundsRingPoint(lambda, phi) {\n  if (p0) {\n    var delta = lambda - lambda2;\n    deltaSum.add((0,_math_js__WEBPACK_IMPORTED_MODULE_2__.abs)(delta) > 180 ? delta + (delta > 0 ? 360 : -360) : delta);\n  } else {\n    lambda00 = lambda, phi00 = phi;\n  }\n  _area_js__WEBPACK_IMPORTED_MODULE_1__.areaStream.point(lambda, phi);\n  linePoint(lambda, phi);\n}\n\nfunction boundsRingStart() {\n  _area_js__WEBPACK_IMPORTED_MODULE_1__.areaStream.lineStart();\n}\n\nfunction boundsRingEnd() {\n  boundsRingPoint(lambda00, phi00);\n  _area_js__WEBPACK_IMPORTED_MODULE_1__.areaStream.lineEnd();\n  if ((0,_math_js__WEBPACK_IMPORTED_MODULE_2__.abs)(deltaSum) > _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon) lambda0 = -(lambda1 = 180);\n  range[0] = lambda0, range[1] = lambda1;\n  p0 = null;\n}\n\n// Finds the left-right distance between two longitudes.\n// This is almost the same as (lambda1 - lambda0 + 360°) % 360°, except that we want\n// the distance between ±180° to be 360°.\nfunction angle(lambda0, lambda1) {\n  return (lambda1 -= lambda0) < 0 ? lambda1 + 360 : lambda1;\n}\n\nfunction rangeCompare(a, b) {\n  return a[0] - b[0];\n}\n\nfunction rangeContains(range, x) {\n  return range[0] <= range[1] ? range[0] <= x && x <= range[1] : x < range[0] || range[1] < x;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(feature) {\n  var i, n, a, b, merged, deltaMax, delta;\n\n  phi1 = lambda1 = -(lambda0 = phi0 = Infinity);\n  ranges = [];\n  (0,_stream_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(feature, boundsStream);\n\n  // First, sort ranges by their minimum longitudes.\n  if (n = ranges.length) {\n    ranges.sort(rangeCompare);\n\n    // Then, merge any ranges that overlap.\n    for (i = 1, a = ranges[0], merged = [a]; i < n; ++i) {\n      b = ranges[i];\n      if (rangeContains(a, b[0]) || rangeContains(a, b[1])) {\n        if (angle(a[0], b[1]) > angle(a[0], a[1])) a[1] = b[1];\n        if (angle(b[0], a[1]) > angle(a[0], a[1])) a[0] = b[0];\n      } else {\n        merged.push(a = b);\n      }\n    }\n\n    // Finally, find the largest gap between the merged ranges.\n    // The final bounding box will be the inverse of this gap.\n    for (deltaMax = -Infinity, n = merged.length - 1, i = 0, a = merged[n]; i <= n; a = b, ++i) {\n      b = merged[i];\n      if ((delta = angle(a[1], b[0])) > deltaMax) deltaMax = delta, lambda0 = b[0], lambda1 = a[1];\n    }\n  }\n\n  ranges = range = null;\n\n  return lambda0 === Infinity || phi0 === Infinity\n      ? [[NaN, NaN], [NaN, NaN]]\n      : [[lambda0, phi0], [lambda1, phi1]];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/bounds.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/cartesian.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-geo/src/cartesian.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   cartesian: () => (/* binding */ cartesian),\n/* harmony export */   cartesianAddInPlace: () => (/* binding */ cartesianAddInPlace),\n/* harmony export */   cartesianCross: () => (/* binding */ cartesianCross),\n/* harmony export */   cartesianDot: () => (/* binding */ cartesianDot),\n/* harmony export */   cartesianNormalizeInPlace: () => (/* binding */ cartesianNormalizeInPlace),\n/* harmony export */   cartesianScale: () => (/* binding */ cartesianScale),\n/* harmony export */   spherical: () => (/* binding */ spherical)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\nfunction spherical(cartesian) {\n  return [(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(cartesian[1], cartesian[0]), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(cartesian[2])];\n}\n\nfunction cartesian(spherical) {\n  var lambda = spherical[0], phi = spherical[1], cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi);\n  return [cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(lambda), cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(lambda), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi)];\n}\n\nfunction cartesianDot(a, b) {\n  return a[0] * b[0] + a[1] * b[1] + a[2] * b[2];\n}\n\nfunction cartesianCross(a, b) {\n  return [a[1] * b[2] - a[2] * b[1], a[2] * b[0] - a[0] * b[2], a[0] * b[1] - a[1] * b[0]];\n}\n\n// TODO return a\nfunction cartesianAddInPlace(a, b) {\n  a[0] += b[0], a[1] += b[1], a[2] += b[2];\n}\n\nfunction cartesianScale(vector, k) {\n  return [vector[0] * k, vector[1] * k, vector[2] * k];\n}\n\n// TODO return d\nfunction cartesianNormalizeInPlace(d) {\n  var l = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(d[0] * d[0] + d[1] * d[1] + d[2] * d[2]);\n  d[0] /= l, d[1] /= l, d[2] /= l;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/cartesian.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/centroid.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-geo/src/centroid.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n/* harmony import */ var _stream_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./stream.js */ \"../../node_modules/d3-geo/src/stream.js\");\n\n\n\n\n\nvar W0, W1,\n    X0, Y0, Z0,\n    X1, Y1, Z1,\n    X2, Y2, Z2,\n    lambda00, phi00, // first point\n    x0, y0, z0; // previous point\n\nvar centroidStream = {\n  sphere: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  point: centroidPoint,\n  lineStart: centroidLineStart,\n  lineEnd: centroidLineEnd,\n  polygonStart: function() {\n    centroidStream.lineStart = centroidRingStart;\n    centroidStream.lineEnd = centroidRingEnd;\n  },\n  polygonEnd: function() {\n    centroidStream.lineStart = centroidLineStart;\n    centroidStream.lineEnd = centroidLineEnd;\n  }\n};\n\n// Arithmetic mean of Cartesian vectors.\nfunction centroidPoint(lambda, phi) {\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians;\n  var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi);\n  centroidPointCartesian(cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(lambda), cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda), (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi));\n}\n\nfunction centroidPointCartesian(x, y, z) {\n  ++W0;\n  X0 += (x - X0) / W0;\n  Y0 += (y - Y0) / W0;\n  Z0 += (z - Z0) / W0;\n}\n\nfunction centroidLineStart() {\n  centroidStream.point = centroidLinePointFirst;\n}\n\nfunction centroidLinePointFirst(lambda, phi) {\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians;\n  var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi);\n  x0 = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(lambda);\n  y0 = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda);\n  z0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi);\n  centroidStream.point = centroidLinePoint;\n  centroidPointCartesian(x0, y0, z0);\n}\n\nfunction centroidLinePoint(lambda, phi) {\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians;\n  var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi),\n      x = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(lambda),\n      y = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda),\n      z = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi),\n      w = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.atan2)((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sqrt)((w = y0 * z - z0 * y) * w + (w = z0 * x - x0 * z) * w + (w = x0 * y - y0 * x) * w), x0 * x + y0 * y + z0 * z);\n  W1 += w;\n  X1 += w * (x0 + (x0 = x));\n  Y1 += w * (y0 + (y0 = y));\n  Z1 += w * (z0 + (z0 = z));\n  centroidPointCartesian(x0, y0, z0);\n}\n\nfunction centroidLineEnd() {\n  centroidStream.point = centroidPoint;\n}\n\n// See J. E. Brock, The Inertia Tensor for a Spherical Triangle,\n// J. Applied Mechanics 42, 239 (1975).\nfunction centroidRingStart() {\n  centroidStream.point = centroidRingPointFirst;\n}\n\nfunction centroidRingEnd() {\n  centroidRingPoint(lambda00, phi00);\n  centroidStream.point = centroidPoint;\n}\n\nfunction centroidRingPointFirst(lambda, phi) {\n  lambda00 = lambda, phi00 = phi;\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians;\n  centroidStream.point = centroidRingPoint;\n  var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi);\n  x0 = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(lambda);\n  y0 = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda);\n  z0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi);\n  centroidPointCartesian(x0, y0, z0);\n}\n\nfunction centroidRingPoint(lambda, phi) {\n  lambda *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi *= _math_js__WEBPACK_IMPORTED_MODULE_1__.radians;\n  var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi),\n      x = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(lambda),\n      y = cosPhi * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda),\n      z = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi),\n      cx = y0 * z - z0 * y,\n      cy = z0 * x - x0 * z,\n      cz = x0 * y - y0 * x,\n      m = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.hypot)(cx, cy, cz),\n      w = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.asin)(m), // line weight = angle\n      v = m && -w / m; // area weight multiplier\n  X2.add(v * cx);\n  Y2.add(v * cy);\n  Z2.add(v * cz);\n  W1 += w;\n  X1 += w * (x0 + (x0 = x));\n  Y1 += w * (y0 + (y0 = y));\n  Z1 += w * (z0 + (z0 = z));\n  centroidPointCartesian(x0, y0, z0);\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(object) {\n  W0 = W1 =\n  X0 = Y0 = Z0 =\n  X1 = Y1 = Z1 = 0;\n  X2 = new d3_array__WEBPACK_IMPORTED_MODULE_2__.Adder();\n  Y2 = new d3_array__WEBPACK_IMPORTED_MODULE_2__.Adder();\n  Z2 = new d3_array__WEBPACK_IMPORTED_MODULE_2__.Adder();\n  (0,_stream_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(object, centroidStream);\n\n  var x = +X2,\n      y = +Y2,\n      z = +Z2,\n      m = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.hypot)(x, y, z);\n\n  // If the area-weighted ccentroid is undefined, fall back to length-weighted ccentroid.\n  if (m < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon2) {\n    x = X1, y = Y1, z = Z1;\n    // If the feature has zero length, fall back to arithmetic mean of point vectors.\n    if (W1 < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon) x = X0, y = Y0, z = Z0;\n    m = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.hypot)(x, y, z);\n    // If the feature still has an undefined ccentroid, then return.\n    if (m < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon2) return [NaN, NaN];\n  }\n\n  return [(0,_math_js__WEBPACK_IMPORTED_MODULE_1__.atan2)(y, x) * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees, (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.asin)(z / m) * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/centroid.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/circle.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-geo/src/circle.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   circleStream: () => (/* binding */ circleStream),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cartesian_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./cartesian.js */ \"../../node_modules/d3-geo/src/cartesian.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-geo/src/constant.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _rotation_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./rotation.js */ \"../../node_modules/d3-geo/src/rotation.js\");\n\n\n\n\n\n// Generates a circle centered at [0°, 0°], with a given radius and precision.\nfunction circleStream(stream, radius, delta, direction, t0, t1) {\n  if (!delta) return;\n  var cosRadius = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(radius),\n      sinRadius = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(radius),\n      step = direction * delta;\n  if (t0 == null) {\n    t0 = radius + direction * _math_js__WEBPACK_IMPORTED_MODULE_0__.tau;\n    t1 = radius - step / 2;\n  } else {\n    t0 = circleRadius(cosRadius, t0);\n    t1 = circleRadius(cosRadius, t1);\n    if (direction > 0 ? t0 < t1 : t0 > t1) t0 += direction * _math_js__WEBPACK_IMPORTED_MODULE_0__.tau;\n  }\n  for (var point, t = t0; direction > 0 ? t > t1 : t < t1; t -= step) {\n    point = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_1__.spherical)([cosRadius, -sinRadius * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(t), -sinRadius * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(t)]);\n    stream.point(point[0], point[1]);\n  }\n}\n\n// Returns the signed angle of a cartesian point relative to [cosRadius, 0, 0].\nfunction circleRadius(cosRadius, point) {\n  point = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_1__.cartesian)(point), point[0] -= cosRadius;\n  (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_1__.cartesianNormalizeInPlace)(point);\n  var radius = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.acos)(-point[1]);\n  return ((-point[2] < 0 ? -radius : radius) + _math_js__WEBPACK_IMPORTED_MODULE_0__.tau - _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) % _math_js__WEBPACK_IMPORTED_MODULE_0__.tau;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var center = (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])([0, 0]),\n      radius = (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(90),\n      precision = (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(6),\n      ring,\n      rotate,\n      stream = {point: point};\n\n  function point(x, y) {\n    ring.push(x = rotate(x, y));\n    x[0] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, x[1] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees;\n  }\n\n  function circle() {\n    var c = center.apply(this, arguments),\n        r = radius.apply(this, arguments) * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians,\n        p = precision.apply(this, arguments) * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians;\n    ring = [];\n    rotate = (0,_rotation_js__WEBPACK_IMPORTED_MODULE_3__.rotateRadians)(-c[0] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, -c[1] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, 0).invert;\n    circleStream(stream, r, p, 1);\n    c = {type: \"Polygon\", coordinates: [ring]};\n    ring = rotate = null;\n    return c;\n  }\n\n  circle.center = function(_) {\n    return arguments.length ? (center = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])([+_[0], +_[1]]), circle) : center;\n  };\n\n  circle.radius = function(_) {\n    return arguments.length ? (radius = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(+_), circle) : radius;\n  };\n\n  circle.precision = function(_) {\n    return arguments.length ? (precision = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(+_), circle) : precision;\n  };\n\n  return circle;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/circle.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/antimeridian.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/antimeridian.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/clip/index.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((0,_index_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(\n  function() { return true; },\n  clipAntimeridianLine,\n  clipAntimeridianInterpolate,\n  [-_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, -_math_js__WEBPACK_IMPORTED_MODULE_1__.halfPi]\n));\n\n// Takes a line and cuts into visible segments. Return values: 0 - there were\n// intersections or the line was empty; 1 - no intersections; 2 - there were\n// intersections, and the first and last segments should be rejoined.\nfunction clipAntimeridianLine(stream) {\n  var lambda0 = NaN,\n      phi0 = NaN,\n      sign0 = NaN,\n      clean; // no intersections\n\n  return {\n    lineStart: function() {\n      stream.lineStart();\n      clean = 1;\n    },\n    point: function(lambda1, phi1) {\n      var sign1 = lambda1 > 0 ? _math_js__WEBPACK_IMPORTED_MODULE_1__.pi : -_math_js__WEBPACK_IMPORTED_MODULE_1__.pi,\n          delta = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(lambda1 - lambda0);\n      if ((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(delta - _math_js__WEBPACK_IMPORTED_MODULE_1__.pi) < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon) { // line crosses a pole\n        stream.point(lambda0, phi0 = (phi0 + phi1) / 2 > 0 ? _math_js__WEBPACK_IMPORTED_MODULE_1__.halfPi : -_math_js__WEBPACK_IMPORTED_MODULE_1__.halfPi);\n        stream.point(sign0, phi0);\n        stream.lineEnd();\n        stream.lineStart();\n        stream.point(sign1, phi0);\n        stream.point(lambda1, phi0);\n        clean = 0;\n      } else if (sign0 !== sign1 && delta >= _math_js__WEBPACK_IMPORTED_MODULE_1__.pi) { // line crosses antimeridian\n        if ((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(lambda0 - sign0) < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon) lambda0 -= sign0 * _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon; // handle degeneracies\n        if ((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(lambda1 - sign1) < _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon) lambda1 -= sign1 * _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon;\n        phi0 = clipAntimeridianIntersect(lambda0, phi0, lambda1, phi1);\n        stream.point(sign0, phi0);\n        stream.lineEnd();\n        stream.lineStart();\n        stream.point(sign1, phi0);\n        clean = 0;\n      }\n      stream.point(lambda0 = lambda1, phi0 = phi1);\n      sign0 = sign1;\n    },\n    lineEnd: function() {\n      stream.lineEnd();\n      lambda0 = phi0 = NaN;\n    },\n    clean: function() {\n      return 2 - clean; // if intersections, rejoin first and last segments\n    }\n  };\n}\n\nfunction clipAntimeridianIntersect(lambda0, phi0, lambda1, phi1) {\n  var cosPhi0,\n      cosPhi1,\n      sinLambda0Lambda1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda0 - lambda1);\n  return (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(sinLambda0Lambda1) > _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon\n      ? (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.atan)(((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi0) * (cosPhi1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi1)) * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda1)\n          - (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(phi1) * (cosPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(phi0)) * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(lambda0))\n          / (cosPhi0 * cosPhi1 * sinLambda0Lambda1))\n      : (phi0 + phi1) / 2;\n}\n\nfunction clipAntimeridianInterpolate(from, to, direction, stream) {\n  var phi;\n  if (from == null) {\n    phi = direction * _math_js__WEBPACK_IMPORTED_MODULE_1__.halfPi;\n    stream.point(-_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, phi);\n    stream.point(0, phi);\n    stream.point(_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, phi);\n    stream.point(_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, 0);\n    stream.point(_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, -phi);\n    stream.point(0, -phi);\n    stream.point(-_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, -phi);\n    stream.point(-_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, 0);\n    stream.point(-_math_js__WEBPACK_IMPORTED_MODULE_1__.pi, phi);\n  } else if ((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(from[0] - to[0]) > _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon) {\n    var lambda = from[0] < to[0] ? _math_js__WEBPACK_IMPORTED_MODULE_1__.pi : -_math_js__WEBPACK_IMPORTED_MODULE_1__.pi;\n    phi = direction * lambda / 2;\n    stream.point(-lambda, phi);\n    stream.point(0, phi);\n    stream.point(lambda, phi);\n  } else {\n    stream.point(to[0], to[1]);\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/antimeridian.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/buffer.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/buffer.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var lines = [],\n      line;\n  return {\n    point: function(x, y, m) {\n      line.push([x, y, m]);\n    },\n    lineStart: function() {\n      lines.push(line = []);\n    },\n    lineEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n    rejoin: function() {\n      if (lines.length > 1) lines.push(lines.pop().concat(lines.shift()));\n    },\n    result: function() {\n      var result = lines;\n      lines = [];\n      line = null;\n      return result;\n    }\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/buffer.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/circle.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/circle.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cartesian_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../cartesian.js */ \"../../node_modules/d3-geo/src/cartesian.js\");\n/* harmony import */ var _circle_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../circle.js */ \"../../node_modules/d3-geo/src/circle.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _pointEqual_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../pointEqual.js */ \"../../node_modules/d3-geo/src/pointEqual.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/clip/index.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(radius) {\n  var cr = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(radius),\n      delta = 6 * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians,\n      smallRadius = cr > 0,\n      notHemisphere = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(cr) > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon; // TODO optimise for this common case\n\n  function interpolate(from, to, direction, stream) {\n    (0,_circle_js__WEBPACK_IMPORTED_MODULE_1__.circleStream)(stream, radius, delta, direction, from, to);\n  }\n\n  function visible(lambda, phi) {\n    return (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(lambda) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi) > cr;\n  }\n\n  // Takes a line and cuts into visible segments. Return values used for polygon\n  // clipping: 0 - there were intersections or the line was empty; 1 - no\n  // intersections 2 - there were intersections, and the first and last segments\n  // should be rejoined.\n  function clipLine(stream) {\n    var point0, // previous point\n        c0, // code for previous point\n        v0, // visibility of previous point\n        v00, // visibility of first point\n        clean; // no intersections\n    return {\n      lineStart: function() {\n        v00 = v0 = false;\n        clean = 1;\n      },\n      point: function(lambda, phi) {\n        var point1 = [lambda, phi],\n            point2,\n            v = visible(lambda, phi),\n            c = smallRadius\n              ? v ? 0 : code(lambda, phi)\n              : v ? code(lambda + (lambda < 0 ? _math_js__WEBPACK_IMPORTED_MODULE_0__.pi : -_math_js__WEBPACK_IMPORTED_MODULE_0__.pi), phi) : 0;\n        if (!point0 && (v00 = v0 = v)) stream.lineStart();\n        if (v !== v0) {\n          point2 = intersect(point0, point1);\n          if (!point2 || (0,_pointEqual_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(point0, point2) || (0,_pointEqual_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(point1, point2))\n            point1[2] = 1;\n        }\n        if (v !== v0) {\n          clean = 0;\n          if (v) {\n            // outside going in\n            stream.lineStart();\n            point2 = intersect(point1, point0);\n            stream.point(point2[0], point2[1]);\n          } else {\n            // inside going out\n            point2 = intersect(point0, point1);\n            stream.point(point2[0], point2[1], 2);\n            stream.lineEnd();\n          }\n          point0 = point2;\n        } else if (notHemisphere && point0 && smallRadius ^ v) {\n          var t;\n          // If the codes for two points are different, or are both zero,\n          // and there this segment intersects with the small circle.\n          if (!(c & c0) && (t = intersect(point1, point0, true))) {\n            clean = 0;\n            if (smallRadius) {\n              stream.lineStart();\n              stream.point(t[0][0], t[0][1]);\n              stream.point(t[1][0], t[1][1]);\n              stream.lineEnd();\n            } else {\n              stream.point(t[1][0], t[1][1]);\n              stream.lineEnd();\n              stream.lineStart();\n              stream.point(t[0][0], t[0][1], 3);\n            }\n          }\n        }\n        if (v && (!point0 || !(0,_pointEqual_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(point0, point1))) {\n          stream.point(point1[0], point1[1]);\n        }\n        point0 = point1, v0 = v, c0 = c;\n      },\n      lineEnd: function() {\n        if (v0) stream.lineEnd();\n        point0 = null;\n      },\n      // Rejoin first and last segments if there were intersections and the first\n      // and last points were visible.\n      clean: function() {\n        return clean | ((v00 && v0) << 1);\n      }\n    };\n  }\n\n  // Intersects the great circle between a and b with the clip circle.\n  function intersect(a, b, two) {\n    var pa = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesian)(a),\n        pb = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesian)(b);\n\n    // We have two planes, n1.p = d1 and n2.p = d2.\n    // Find intersection line p(t) = c1 n1 + c2 n2 + t (n1 ⨯ n2).\n    var n1 = [1, 0, 0], // normal\n        n2 = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianCross)(pa, pb),\n        n2n2 = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianDot)(n2, n2),\n        n1n2 = n2[0], // cartesianDot(n1, n2),\n        determinant = n2n2 - n1n2 * n1n2;\n\n    // Two polar points.\n    if (!determinant) return !two && a;\n\n    var c1 =  cr * n2n2 / determinant,\n        c2 = -cr * n1n2 / determinant,\n        n1xn2 = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianCross)(n1, n2),\n        A = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianScale)(n1, c1),\n        B = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianScale)(n2, c2);\n    (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianAddInPlace)(A, B);\n\n    // Solve |p(t)|^2 = 1.\n    var u = n1xn2,\n        w = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianDot)(A, u),\n        uu = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianDot)(u, u),\n        t2 = w * w - uu * ((0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianDot)(A, A) - 1);\n\n    if (t2 < 0) return;\n\n    var t = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(t2),\n        q = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianScale)(u, (-w - t) / uu);\n    (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianAddInPlace)(q, A);\n    q = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.spherical)(q);\n\n    if (!two) return q;\n\n    // Two intersection points.\n    var lambda0 = a[0],\n        lambda1 = b[0],\n        phi0 = a[1],\n        phi1 = b[1],\n        z;\n\n    if (lambda1 < lambda0) z = lambda0, lambda0 = lambda1, lambda1 = z;\n\n    var delta = lambda1 - lambda0,\n        polar = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(delta - _math_js__WEBPACK_IMPORTED_MODULE_0__.pi) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon,\n        meridian = polar || delta < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\n    if (!polar && phi1 < phi0) z = phi0, phi0 = phi1, phi1 = z;\n\n    // Check that the first point is between a and b.\n    if (meridian\n        ? polar\n          ? phi0 + phi1 > 0 ^ q[1] < ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(q[0] - lambda0) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon ? phi0 : phi1)\n          : phi0 <= q[1] && q[1] <= phi1\n        : delta > _math_js__WEBPACK_IMPORTED_MODULE_0__.pi ^ (lambda0 <= q[0] && q[0] <= lambda1)) {\n      var q1 = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianScale)(u, (-w + t) / uu);\n      (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.cartesianAddInPlace)(q1, A);\n      return [q, (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_3__.spherical)(q1)];\n    }\n  }\n\n  // Generates a 4-bit vector representing the location of a point relative to\n  // the small circle's bounding box.\n  function code(lambda, phi) {\n    var r = smallRadius ? radius : _math_js__WEBPACK_IMPORTED_MODULE_0__.pi - radius,\n        code = 0;\n    if (lambda < -r) code |= 1; // left\n    else if (lambda > r) code |= 2; // right\n    if (phi < -r) code |= 4; // below\n    else if (phi > r) code |= 8; // above\n    return code;\n  }\n\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(visible, clipLine, interpolate, smallRadius ? [0, -radius] : [-_math_js__WEBPACK_IMPORTED_MODULE_0__.pi, radius - _math_js__WEBPACK_IMPORTED_MODULE_0__.pi]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/circle.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/index.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/index.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _buffer_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./buffer.js */ \"../../node_modules/d3-geo/src/clip/buffer.js\");\n/* harmony import */ var _rejoin_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./rejoin.js */ \"../../node_modules/d3-geo/src/clip/rejoin.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _polygonContains_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../polygonContains.js */ \"../../node_modules/d3-geo/src/polygonContains.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/merge.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(pointVisible, clipLine, interpolate, start) {\n  return function(sink) {\n    var line = clipLine(sink),\n        ringBuffer = (0,_buffer_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(),\n        ringSink = clipLine(ringBuffer),\n        polygonStarted = false,\n        polygon,\n        segments,\n        ring;\n\n    var clip = {\n      point: point,\n      lineStart: lineStart,\n      lineEnd: lineEnd,\n      polygonStart: function() {\n        clip.point = pointRing;\n        clip.lineStart = ringStart;\n        clip.lineEnd = ringEnd;\n        segments = [];\n        polygon = [];\n      },\n      polygonEnd: function() {\n        clip.point = point;\n        clip.lineStart = lineStart;\n        clip.lineEnd = lineEnd;\n        segments = (0,d3_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(segments);\n        var startInside = (0,_polygonContains_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(polygon, start);\n        if (segments.length) {\n          if (!polygonStarted) sink.polygonStart(), polygonStarted = true;\n          (0,_rejoin_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(segments, compareIntersection, startInside, interpolate, sink);\n        } else if (startInside) {\n          if (!polygonStarted) sink.polygonStart(), polygonStarted = true;\n          sink.lineStart();\n          interpolate(null, null, 1, sink);\n          sink.lineEnd();\n        }\n        if (polygonStarted) sink.polygonEnd(), polygonStarted = false;\n        segments = polygon = null;\n      },\n      sphere: function() {\n        sink.polygonStart();\n        sink.lineStart();\n        interpolate(null, null, 1, sink);\n        sink.lineEnd();\n        sink.polygonEnd();\n      }\n    };\n\n    function point(lambda, phi) {\n      if (pointVisible(lambda, phi)) sink.point(lambda, phi);\n    }\n\n    function pointLine(lambda, phi) {\n      line.point(lambda, phi);\n    }\n\n    function lineStart() {\n      clip.point = pointLine;\n      line.lineStart();\n    }\n\n    function lineEnd() {\n      clip.point = point;\n      line.lineEnd();\n    }\n\n    function pointRing(lambda, phi) {\n      ring.push([lambda, phi]);\n      ringSink.point(lambda, phi);\n    }\n\n    function ringStart() {\n      ringSink.lineStart();\n      ring = [];\n    }\n\n    function ringEnd() {\n      pointRing(ring[0][0], ring[0][1]);\n      ringSink.lineEnd();\n\n      var clean = ringSink.clean(),\n          ringSegments = ringBuffer.result(),\n          i, n = ringSegments.length, m,\n          segment,\n          point;\n\n      ring.pop();\n      polygon.push(ring);\n      ring = null;\n\n      if (!n) return;\n\n      // No intersections.\n      if (clean & 1) {\n        segment = ringSegments[0];\n        if ((m = segment.length - 1) > 0) {\n          if (!polygonStarted) sink.polygonStart(), polygonStarted = true;\n          sink.lineStart();\n          for (i = 0; i < m; ++i) sink.point((point = segment[i])[0], point[1]);\n          sink.lineEnd();\n        }\n        return;\n      }\n\n      // Rejoin connected segments.\n      // TODO reuse ringBuffer.rejoin()?\n      if (n > 1 && clean & 2) ringSegments.push(ringSegments.pop().concat(ringSegments.shift()));\n\n      segments.push(ringSegments.filter(validSegment));\n    }\n\n    return clip;\n  };\n}\n\nfunction validSegment(segment) {\n  return segment.length > 1;\n}\n\n// Intersections are sorted along the clip edge. For both antimeridian cutting\n// and circle clipping, the same comparison is used.\nfunction compareIntersection(a, b) {\n  return ((a = a.x)[0] < 0 ? a[1] - _math_js__WEBPACK_IMPORTED_MODULE_4__.halfPi - _math_js__WEBPACK_IMPORTED_MODULE_4__.epsilon : _math_js__WEBPACK_IMPORTED_MODULE_4__.halfPi - a[1])\n       - ((b = b.x)[0] < 0 ? b[1] - _math_js__WEBPACK_IMPORTED_MODULE_4__.halfPi - _math_js__WEBPACK_IMPORTED_MODULE_4__.epsilon : _math_js__WEBPACK_IMPORTED_MODULE_4__.halfPi - b[1]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/index.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/line.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/line.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b, x0, y0, x1, y1) {\n  var ax = a[0],\n      ay = a[1],\n      bx = b[0],\n      by = b[1],\n      t0 = 0,\n      t1 = 1,\n      dx = bx - ax,\n      dy = by - ay,\n      r;\n\n  r = x0 - ax;\n  if (!dx && r > 0) return;\n  r /= dx;\n  if (dx < 0) {\n    if (r < t0) return;\n    if (r < t1) t1 = r;\n  } else if (dx > 0) {\n    if (r > t1) return;\n    if (r > t0) t0 = r;\n  }\n\n  r = x1 - ax;\n  if (!dx && r < 0) return;\n  r /= dx;\n  if (dx < 0) {\n    if (r > t1) return;\n    if (r > t0) t0 = r;\n  } else if (dx > 0) {\n    if (r < t0) return;\n    if (r < t1) t1 = r;\n  }\n\n  r = y0 - ay;\n  if (!dy && r > 0) return;\n  r /= dy;\n  if (dy < 0) {\n    if (r < t0) return;\n    if (r < t1) t1 = r;\n  } else if (dy > 0) {\n    if (r > t1) return;\n    if (r > t0) t0 = r;\n  }\n\n  r = y1 - ay;\n  if (!dy && r < 0) return;\n  r /= dy;\n  if (dy < 0) {\n    if (r > t1) return;\n    if (r > t0) t0 = r;\n  } else if (dy > 0) {\n    if (r < t0) return;\n    if (r < t1) t1 = r;\n  }\n\n  if (t0 > 0) a[0] = ax + t0 * dx, a[1] = ay + t0 * dy;\n  if (t1 < 1) b[0] = ax + t1 * dx, b[1] = ay + t1 * dy;\n  return true;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/line.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/rectangle.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/rectangle.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ clipRectangle)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _buffer_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./buffer.js */ \"../../node_modules/d3-geo/src/clip/buffer.js\");\n/* harmony import */ var _line_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./line.js */ \"../../node_modules/d3-geo/src/clip/line.js\");\n/* harmony import */ var _rejoin_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./rejoin.js */ \"../../node_modules/d3-geo/src/clip/rejoin.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/merge.js\");\n\n\n\n\n\n\nvar clipMax = 1e9, clipMin = -clipMax;\n\n// TODO Use d3-polygon’s polygonContains here for the ring check?\n// TODO Eliminate duplicate buffering in clipBuffer and polygon.push?\n\nfunction clipRectangle(x0, y0, x1, y1) {\n\n  function visible(x, y) {\n    return x0 <= x && x <= x1 && y0 <= y && y <= y1;\n  }\n\n  function interpolate(from, to, direction, stream) {\n    var a = 0, a1 = 0;\n    if (from == null\n        || (a = corner(from, direction)) !== (a1 = corner(to, direction))\n        || comparePoint(from, to) < 0 ^ direction > 0) {\n      do stream.point(a === 0 || a === 3 ? x0 : x1, a > 1 ? y1 : y0);\n      while ((a = (a + direction + 4) % 4) !== a1);\n    } else {\n      stream.point(to[0], to[1]);\n    }\n  }\n\n  function corner(p, direction) {\n    return (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(p[0] - x0) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon ? direction > 0 ? 0 : 3\n        : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(p[0] - x1) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon ? direction > 0 ? 2 : 1\n        : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(p[1] - y0) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon ? direction > 0 ? 1 : 0\n        : direction > 0 ? 3 : 2; // abs(p[1] - y1) < epsilon\n  }\n\n  function compareIntersection(a, b) {\n    return comparePoint(a.x, b.x);\n  }\n\n  function comparePoint(a, b) {\n    var ca = corner(a, 1),\n        cb = corner(b, 1);\n    return ca !== cb ? ca - cb\n        : ca === 0 ? b[1] - a[1]\n        : ca === 1 ? a[0] - b[0]\n        : ca === 2 ? a[1] - b[1]\n        : b[0] - a[0];\n  }\n\n  return function(stream) {\n    var activeStream = stream,\n        bufferStream = (0,_buffer_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(),\n        segments,\n        polygon,\n        ring,\n        x__, y__, v__, // first point\n        x_, y_, v_, // previous point\n        first,\n        clean;\n\n    var clipStream = {\n      point: point,\n      lineStart: lineStart,\n      lineEnd: lineEnd,\n      polygonStart: polygonStart,\n      polygonEnd: polygonEnd\n    };\n\n    function point(x, y) {\n      if (visible(x, y)) activeStream.point(x, y);\n    }\n\n    function polygonInside() {\n      var winding = 0;\n\n      for (var i = 0, n = polygon.length; i < n; ++i) {\n        for (var ring = polygon[i], j = 1, m = ring.length, point = ring[0], a0, a1, b0 = point[0], b1 = point[1]; j < m; ++j) {\n          a0 = b0, a1 = b1, point = ring[j], b0 = point[0], b1 = point[1];\n          if (a1 <= y1) { if (b1 > y1 && (b0 - a0) * (y1 - a1) > (b1 - a1) * (x0 - a0)) ++winding; }\n          else { if (b1 <= y1 && (b0 - a0) * (y1 - a1) < (b1 - a1) * (x0 - a0)) --winding; }\n        }\n      }\n\n      return winding;\n    }\n\n    // Buffer geometry within a polygon and then clip it en masse.\n    function polygonStart() {\n      activeStream = bufferStream, segments = [], polygon = [], clean = true;\n    }\n\n    function polygonEnd() {\n      var startInside = polygonInside(),\n          cleanInside = clean && startInside,\n          visible = (segments = (0,d3_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(segments)).length;\n      if (cleanInside || visible) {\n        stream.polygonStart();\n        if (cleanInside) {\n          stream.lineStart();\n          interpolate(null, null, 1, stream);\n          stream.lineEnd();\n        }\n        if (visible) {\n          (0,_rejoin_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(segments, compareIntersection, startInside, interpolate, stream);\n        }\n        stream.polygonEnd();\n      }\n      activeStream = stream, segments = polygon = ring = null;\n    }\n\n    function lineStart() {\n      clipStream.point = linePoint;\n      if (polygon) polygon.push(ring = []);\n      first = true;\n      v_ = false;\n      x_ = y_ = NaN;\n    }\n\n    // TODO rather than special-case polygons, simply handle them separately.\n    // Ideally, coincident intersection points should be jittered to avoid\n    // clipping issues.\n    function lineEnd() {\n      if (segments) {\n        linePoint(x__, y__);\n        if (v__ && v_) bufferStream.rejoin();\n        segments.push(bufferStream.result());\n      }\n      clipStream.point = point;\n      if (v_) activeStream.lineEnd();\n    }\n\n    function linePoint(x, y) {\n      var v = visible(x, y);\n      if (polygon) ring.push([x, y]);\n      if (first) {\n        x__ = x, y__ = y, v__ = v;\n        first = false;\n        if (v) {\n          activeStream.lineStart();\n          activeStream.point(x, y);\n        }\n      } else {\n        if (v && v_) activeStream.point(x, y);\n        else {\n          var a = [x_ = Math.max(clipMin, Math.min(clipMax, x_)), y_ = Math.max(clipMin, Math.min(clipMax, y_))],\n              b = [x = Math.max(clipMin, Math.min(clipMax, x)), y = Math.max(clipMin, Math.min(clipMax, y))];\n          if ((0,_line_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(a, b, x0, y0, x1, y1)) {\n            if (!v_) {\n              activeStream.lineStart();\n              activeStream.point(a[0], a[1]);\n            }\n            activeStream.point(b[0], b[1]);\n            if (!v) activeStream.lineEnd();\n            clean = false;\n          } else if (v) {\n            activeStream.lineStart();\n            activeStream.point(x, y);\n            clean = false;\n          }\n        }\n      }\n      x_ = x, y_ = y, v_ = v;\n    }\n\n    return clipStream;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/rectangle.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/clip/rejoin.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-geo/src/clip/rejoin.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _pointEqual_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../pointEqual.js */ \"../../node_modules/d3-geo/src/pointEqual.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\nfunction Intersection(point, points, other, entry) {\n  this.x = point;\n  this.z = points;\n  this.o = other; // another intersection\n  this.e = entry; // is an entry?\n  this.v = false; // visited\n  this.n = this.p = null; // next & previous\n}\n\n// A generalized polygon clipping algorithm: given a polygon that has been cut\n// into its visible line segments, and rejoins the segments by interpolating\n// along the clip edge.\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(segments, compareIntersection, startInside, interpolate, stream) {\n  var subject = [],\n      clip = [],\n      i,\n      n;\n\n  segments.forEach(function(segment) {\n    if ((n = segment.length - 1) <= 0) return;\n    var n, p0 = segment[0], p1 = segment[n], x;\n\n    if ((0,_pointEqual_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(p0, p1)) {\n      if (!p0[2] && !p1[2]) {\n        stream.lineStart();\n        for (i = 0; i < n; ++i) stream.point((p0 = segment[i])[0], p0[1]);\n        stream.lineEnd();\n        return;\n      }\n      // handle degenerate cases by moving the point\n      p1[0] += 2 * _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon;\n    }\n\n    subject.push(x = new Intersection(p0, segment, null, true));\n    clip.push(x.o = new Intersection(p0, null, x, false));\n    subject.push(x = new Intersection(p1, segment, null, false));\n    clip.push(x.o = new Intersection(p1, null, x, true));\n  });\n\n  if (!subject.length) return;\n\n  clip.sort(compareIntersection);\n  link(subject);\n  link(clip);\n\n  for (i = 0, n = clip.length; i < n; ++i) {\n    clip[i].e = startInside = !startInside;\n  }\n\n  var start = subject[0],\n      points,\n      point;\n\n  while (1) {\n    // Find first unvisited intersection.\n    var current = start,\n        isSubject = true;\n    while (current.v) if ((current = current.n) === start) return;\n    points = current.z;\n    stream.lineStart();\n    do {\n      current.v = current.o.v = true;\n      if (current.e) {\n        if (isSubject) {\n          for (i = 0, n = points.length; i < n; ++i) stream.point((point = points[i])[0], point[1]);\n        } else {\n          interpolate(current.x, current.n.x, 1, stream);\n        }\n        current = current.n;\n      } else {\n        if (isSubject) {\n          points = current.p.z;\n          for (i = points.length - 1; i >= 0; --i) stream.point((point = points[i])[0], point[1]);\n        } else {\n          interpolate(current.x, current.p.x, -1, stream);\n        }\n        current = current.p;\n      }\n      current = current.o;\n      points = current.z;\n      isSubject = !isSubject;\n    } while (!current.v);\n    stream.lineEnd();\n  }\n}\n\nfunction link(array) {\n  if (!(n = array.length)) return;\n  var n,\n      i = 0,\n      a = array[0],\n      b;\n  while (++i < n) {\n    a.n = b = array[i];\n    b.p = a;\n    a = b;\n  }\n  a.n = b = array[0];\n  b.p = a;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/clip/rejoin.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/compose.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-geo/src/compose.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n\n  function compose(x, y) {\n    return x = a(x, y), b(x[0], x[1]);\n  }\n\n  if (a.invert && b.invert) compose.invert = function(x, y) {\n    return x = b.invert(x, y), x && a.invert(x[0], x[1]);\n  };\n\n  return compose;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/compose.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/constant.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-geo/src/constant.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return function() {\n    return x;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/graticule.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-geo/src/graticule.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ graticule),\n/* harmony export */   graticule10: () => (/* binding */ graticule10)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/range.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\nfunction graticuleX(y0, y1, dy) {\n  var y = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(y0, y1 - _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon, dy).concat(y1);\n  return function(x) { return y.map(function(y) { return [x, y]; }); };\n}\n\nfunction graticuleY(x0, x1, dx) {\n  var x = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(x0, x1 - _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon, dx).concat(x1);\n  return function(y) { return x.map(function(x) { return [x, y]; }); };\n}\n\nfunction graticule() {\n  var x1, x0, X1, X0,\n      y1, y0, Y1, Y0,\n      dx = 10, dy = dx, DX = 90, DY = 360,\n      x, y, X, Y,\n      precision = 2.5;\n\n  function graticule() {\n    return {type: \"MultiLineString\", coordinates: lines()};\n  }\n\n  function lines() {\n    return (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.ceil)(X0 / DX) * DX, X1, DX).map(X)\n        .concat((0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.ceil)(Y0 / DY) * DY, Y1, DY).map(Y))\n        .concat((0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.ceil)(x0 / dx) * dx, x1, dx).filter(function(x) { return (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(x % DX) > _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon; }).map(x))\n        .concat((0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])((0,_math_js__WEBPACK_IMPORTED_MODULE_1__.ceil)(y0 / dy) * dy, y1, dy).filter(function(y) { return (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.abs)(y % DY) > _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon; }).map(y));\n  }\n\n  graticule.lines = function() {\n    return lines().map(function(coordinates) { return {type: \"LineString\", coordinates: coordinates}; });\n  };\n\n  graticule.outline = function() {\n    return {\n      type: \"Polygon\",\n      coordinates: [\n        X(X0).concat(\n        Y(Y1).slice(1),\n        X(X1).reverse().slice(1),\n        Y(Y0).reverse().slice(1))\n      ]\n    };\n  };\n\n  graticule.extent = function(_) {\n    if (!arguments.length) return graticule.extentMinor();\n    return graticule.extentMajor(_).extentMinor(_);\n  };\n\n  graticule.extentMajor = function(_) {\n    if (!arguments.length) return [[X0, Y0], [X1, Y1]];\n    X0 = +_[0][0], X1 = +_[1][0];\n    Y0 = +_[0][1], Y1 = +_[1][1];\n    if (X0 > X1) _ = X0, X0 = X1, X1 = _;\n    if (Y0 > Y1) _ = Y0, Y0 = Y1, Y1 = _;\n    return graticule.precision(precision);\n  };\n\n  graticule.extentMinor = function(_) {\n    if (!arguments.length) return [[x0, y0], [x1, y1]];\n    x0 = +_[0][0], x1 = +_[1][0];\n    y0 = +_[0][1], y1 = +_[1][1];\n    if (x0 > x1) _ = x0, x0 = x1, x1 = _;\n    if (y0 > y1) _ = y0, y0 = y1, y1 = _;\n    return graticule.precision(precision);\n  };\n\n  graticule.step = function(_) {\n    if (!arguments.length) return graticule.stepMinor();\n    return graticule.stepMajor(_).stepMinor(_);\n  };\n\n  graticule.stepMajor = function(_) {\n    if (!arguments.length) return [DX, DY];\n    DX = +_[0], DY = +_[1];\n    return graticule;\n  };\n\n  graticule.stepMinor = function(_) {\n    if (!arguments.length) return [dx, dy];\n    dx = +_[0], dy = +_[1];\n    return graticule;\n  };\n\n  graticule.precision = function(_) {\n    if (!arguments.length) return precision;\n    precision = +_;\n    x = graticuleX(y0, y1, 90);\n    y = graticuleY(x0, x1, precision);\n    X = graticuleX(Y0, Y1, 90);\n    Y = graticuleY(X0, X1, precision);\n    return graticule;\n  };\n\n  return graticule\n      .extentMajor([[-180, -90 + _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon], [180, 90 - _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon]])\n      .extentMinor([[-180, -80 - _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon], [180, 80 + _math_js__WEBPACK_IMPORTED_MODULE_1__.epsilon]]);\n}\n\nfunction graticule10() {\n  return graticule()();\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/graticule.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/identity.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-geo/src/identity.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (x => x);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/identity.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/math.js":
/*!*********************************************!*\
  !*** ../../node_modules/d3-geo/src/math.js ***!
  \*********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   abs: () => (/* binding */ abs),\n/* harmony export */   acos: () => (/* binding */ acos),\n/* harmony export */   asin: () => (/* binding */ asin),\n/* harmony export */   atan: () => (/* binding */ atan),\n/* harmony export */   atan2: () => (/* binding */ atan2),\n/* harmony export */   ceil: () => (/* binding */ ceil),\n/* harmony export */   cos: () => (/* binding */ cos),\n/* harmony export */   degrees: () => (/* binding */ degrees),\n/* harmony export */   epsilon: () => (/* binding */ epsilon),\n/* harmony export */   epsilon2: () => (/* binding */ epsilon2),\n/* harmony export */   exp: () => (/* binding */ exp),\n/* harmony export */   floor: () => (/* binding */ floor),\n/* harmony export */   halfPi: () => (/* binding */ halfPi),\n/* harmony export */   haversin: () => (/* binding */ haversin),\n/* harmony export */   hypot: () => (/* binding */ hypot),\n/* harmony export */   log: () => (/* binding */ log),\n/* harmony export */   pi: () => (/* binding */ pi),\n/* harmony export */   pow: () => (/* binding */ pow),\n/* harmony export */   quarterPi: () => (/* binding */ quarterPi),\n/* harmony export */   radians: () => (/* binding */ radians),\n/* harmony export */   sign: () => (/* binding */ sign),\n/* harmony export */   sin: () => (/* binding */ sin),\n/* harmony export */   sqrt: () => (/* binding */ sqrt),\n/* harmony export */   tan: () => (/* binding */ tan),\n/* harmony export */   tau: () => (/* binding */ tau)\n/* harmony export */ });\nvar epsilon = 1e-6;\nvar epsilon2 = 1e-12;\nvar pi = Math.PI;\nvar halfPi = pi / 2;\nvar quarterPi = pi / 4;\nvar tau = pi * 2;\n\nvar degrees = 180 / pi;\nvar radians = pi / 180;\n\nvar abs = Math.abs;\nvar atan = Math.atan;\nvar atan2 = Math.atan2;\nvar cos = Math.cos;\nvar ceil = Math.ceil;\nvar exp = Math.exp;\nvar floor = Math.floor;\nvar hypot = Math.hypot;\nvar log = Math.log;\nvar pow = Math.pow;\nvar sin = Math.sin;\nvar sign = Math.sign || function(x) { return x > 0 ? 1 : x < 0 ? -1 : 0; };\nvar sqrt = Math.sqrt;\nvar tan = Math.tan;\n\nfunction acos(x) {\n  return x > 1 ? 0 : x < -1 ? pi : Math.acos(x);\n}\n\nfunction asin(x) {\n  return x > 1 ? halfPi : x < -1 ? -halfPi : Math.asin(x);\n}\n\nfunction haversin(x) {\n  return (x = sin(x / 2)) * x;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/math.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/noop.js":
/*!*********************************************!*\
  !*** ../../node_modules/d3-geo/src/noop.js ***!
  \*********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ noop)\n/* harmony export */ });\nfunction noop() {}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/noop.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/area.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/area.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n\n\n\n\nvar areaSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder(),\n    areaRingSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder(),\n    x00,\n    y00,\n    x0,\n    y0;\n\nvar areaStream = {\n  point: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  lineStart: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  lineEnd: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  polygonStart: function() {\n    areaStream.lineStart = areaRingStart;\n    areaStream.lineEnd = areaRingEnd;\n  },\n  polygonEnd: function() {\n    areaStream.lineStart = areaStream.lineEnd = areaStream.point = _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n    areaSum.add((0,_math_js__WEBPACK_IMPORTED_MODULE_2__.abs)(areaRingSum));\n    areaRingSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n  },\n  result: function() {\n    var area = areaSum / 2;\n    areaSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n    return area;\n  }\n};\n\nfunction areaRingStart() {\n  areaStream.point = areaPointFirst;\n}\n\nfunction areaPointFirst(x, y) {\n  areaStream.point = areaPoint;\n  x00 = x0 = x, y00 = y0 = y;\n}\n\nfunction areaPoint(x, y) {\n  areaRingSum.add(y0 * x - x0 * y);\n  x0 = x, y0 = y;\n}\n\nfunction areaRingEnd() {\n  areaPoint(x00, y00);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (areaStream);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/area.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/bounds.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/bounds.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n\n\nvar x0 = Infinity,\n    y0 = x0,\n    x1 = -x0,\n    y1 = x1;\n\nvar boundsStream = {\n  point: boundsPoint,\n  lineStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lineEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  polygonStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  polygonEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  result: function() {\n    var bounds = [[x0, y0], [x1, y1]];\n    x1 = y1 = -(y0 = x0 = Infinity);\n    return bounds;\n  }\n};\n\nfunction boundsPoint(x, y) {\n  if (x < x0) x0 = x;\n  if (x > x1) x1 = x;\n  if (y < y0) y0 = y;\n  if (y > y1) y1 = y;\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (boundsStream);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/bounds.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/centroid.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/centroid.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n// TODO Enforce positive area for exterior, negative area for interior?\n\nvar X0 = 0,\n    Y0 = 0,\n    Z0 = 0,\n    X1 = 0,\n    Y1 = 0,\n    Z1 = 0,\n    X2 = 0,\n    Y2 = 0,\n    Z2 = 0,\n    x00,\n    y00,\n    x0,\n    y0;\n\nvar centroidStream = {\n  point: centroidPoint,\n  lineStart: centroidLineStart,\n  lineEnd: centroidLineEnd,\n  polygonStart: function() {\n    centroidStream.lineStart = centroidRingStart;\n    centroidStream.lineEnd = centroidRingEnd;\n  },\n  polygonEnd: function() {\n    centroidStream.point = centroidPoint;\n    centroidStream.lineStart = centroidLineStart;\n    centroidStream.lineEnd = centroidLineEnd;\n  },\n  result: function() {\n    var centroid = Z2 ? [X2 / Z2, Y2 / Z2]\n        : Z1 ? [X1 / Z1, Y1 / Z1]\n        : Z0 ? [X0 / Z0, Y0 / Z0]\n        : [NaN, NaN];\n    X0 = Y0 = Z0 =\n    X1 = Y1 = Z1 =\n    X2 = Y2 = Z2 = 0;\n    return centroid;\n  }\n};\n\nfunction centroidPoint(x, y) {\n  X0 += x;\n  Y0 += y;\n  ++Z0;\n}\n\nfunction centroidLineStart() {\n  centroidStream.point = centroidPointFirstLine;\n}\n\nfunction centroidPointFirstLine(x, y) {\n  centroidStream.point = centroidPointLine;\n  centroidPoint(x0 = x, y0 = y);\n}\n\nfunction centroidPointLine(x, y) {\n  var dx = x - x0, dy = y - y0, z = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(dx * dx + dy * dy);\n  X1 += z * (x0 + x) / 2;\n  Y1 += z * (y0 + y) / 2;\n  Z1 += z;\n  centroidPoint(x0 = x, y0 = y);\n}\n\nfunction centroidLineEnd() {\n  centroidStream.point = centroidPoint;\n}\n\nfunction centroidRingStart() {\n  centroidStream.point = centroidPointFirstRing;\n}\n\nfunction centroidRingEnd() {\n  centroidPointRing(x00, y00);\n}\n\nfunction centroidPointFirstRing(x, y) {\n  centroidStream.point = centroidPointRing;\n  centroidPoint(x00 = x0 = x, y00 = y0 = y);\n}\n\nfunction centroidPointRing(x, y) {\n  var dx = x - x0,\n      dy = y - y0,\n      z = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(dx * dx + dy * dy);\n\n  X1 += z * (x0 + x) / 2;\n  Y1 += z * (y0 + y) / 2;\n  Z1 += z;\n\n  z = y0 * x - x0 * y;\n  X2 += z * (x0 + x);\n  Y2 += z * (y0 + y);\n  Z2 += z * 3;\n  centroidPoint(x0 = x, y0 = y);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (centroidStream);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/centroid.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/context.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/context.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ PathContext)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n\n\n\nfunction PathContext(context) {\n  this._context = context;\n}\n\nPathContext.prototype = {\n  _radius: 4.5,\n  pointRadius: function(_) {\n    return this._radius = _, this;\n  },\n  polygonStart: function() {\n    this._line = 0;\n  },\n  polygonEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._line === 0) this._context.closePath();\n    this._point = NaN;\n  },\n  point: function(x, y) {\n    switch (this._point) {\n      case 0: {\n        this._context.moveTo(x, y);\n        this._point = 1;\n        break;\n      }\n      case 1: {\n        this._context.lineTo(x, y);\n        break;\n      }\n      default: {\n        this._context.moveTo(x + this._radius, y);\n        this._context.arc(x, y, this._radius, 0, _math_js__WEBPACK_IMPORTED_MODULE_0__.tau);\n        break;\n      }\n    }\n  },\n  result: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/context.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/index.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/index.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../identity.js */ \"../../node_modules/d3-geo/src/identity.js\");\n/* harmony import */ var _stream_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../stream.js */ \"../../node_modules/d3-geo/src/stream.js\");\n/* harmony import */ var _area_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./area.js */ \"../../node_modules/d3-geo/src/path/area.js\");\n/* harmony import */ var _bounds_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./bounds.js */ \"../../node_modules/d3-geo/src/path/bounds.js\");\n/* harmony import */ var _centroid_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./centroid.js */ \"../../node_modules/d3-geo/src/path/centroid.js\");\n/* harmony import */ var _context_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./context.js */ \"../../node_modules/d3-geo/src/path/context.js\");\n/* harmony import */ var _measure_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./measure.js */ \"../../node_modules/d3-geo/src/path/measure.js\");\n/* harmony import */ var _string_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./string.js */ \"../../node_modules/d3-geo/src/path/string.js\");\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(projection, context) {\n  let digits = 3,\n      pointRadius = 4.5,\n      projectionStream,\n      contextStream;\n\n  function path(object) {\n    if (object) {\n      if (typeof pointRadius === \"function\") contextStream.pointRadius(+pointRadius.apply(this, arguments));\n      (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projectionStream(contextStream));\n    }\n    return contextStream.result();\n  }\n\n  path.area = function(object) {\n    (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projectionStream(_area_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]));\n    return _area_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"].result();\n  };\n\n  path.measure = function(object) {\n    (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projectionStream(_measure_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]));\n    return _measure_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"].result();\n  };\n\n  path.bounds = function(object) {\n    (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projectionStream(_bounds_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]));\n    return _bounds_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"].result();\n  };\n\n  path.centroid = function(object) {\n    (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projectionStream(_centroid_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"]));\n    return _centroid_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"].result();\n  };\n\n  path.projection = function(_) {\n    if (!arguments.length) return projection;\n    projectionStream = _ == null ? (projection = null, _identity_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"]) : (projection = _).stream;\n    return path;\n  };\n\n  path.context = function(_) {\n    if (!arguments.length) return context;\n    contextStream = _ == null ? (context = null, new _string_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"](digits)) : new _context_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"](context = _);\n    if (typeof pointRadius !== \"function\") contextStream.pointRadius(pointRadius);\n    return path;\n  };\n\n  path.pointRadius = function(_) {\n    if (!arguments.length) return pointRadius;\n    pointRadius = typeof _ === \"function\" ? _ : (contextStream.pointRadius(+_), +_);\n    return path;\n  };\n\n  path.digits = function(_) {\n    if (!arguments.length) return digits;\n    if (_ == null) digits = null;\n    else {\n      const d = Math.floor(_);\n      if (!(d >= 0)) throw new RangeError(`invalid digits: ${_}`);\n      digits = d;\n    }\n    if (context === null) contextStream = new _string_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"](digits);\n    return path;\n  };\n\n  return path.projection(projection).digits(digits).context(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/index.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/measure.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/measure.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-geo/src/noop.js\");\n\n\n\n\nvar lengthSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder(),\n    lengthRing,\n    x00,\n    y00,\n    x0,\n    y0;\n\nvar lengthStream = {\n  point: _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  lineStart: function() {\n    lengthStream.point = lengthPointFirst;\n  },\n  lineEnd: function() {\n    if (lengthRing) lengthPoint(x00, y00);\n    lengthStream.point = _noop_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n  },\n  polygonStart: function() {\n    lengthRing = true;\n  },\n  polygonEnd: function() {\n    lengthRing = null;\n  },\n  result: function() {\n    var length = +lengthSum;\n    lengthSum = new d3_array__WEBPACK_IMPORTED_MODULE_0__.Adder();\n    return length;\n  }\n};\n\nfunction lengthPointFirst(x, y) {\n  lengthStream.point = lengthPoint;\n  x00 = x0 = x, y00 = y0 = y;\n}\n\nfunction lengthPoint(x, y) {\n  x0 -= x, y0 -= y;\n  lengthSum.add((0,_math_js__WEBPACK_IMPORTED_MODULE_2__.sqrt)(x0 * x0 + y0 * y0));\n  x0 = x, y0 = y;\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (lengthStream);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/measure.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/path/string.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-geo/src/path/string.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ PathString)\n/* harmony export */ });\n// Simple caching for constant-radius points.\nlet cacheDigits, cacheAppend, cacheRadius, cacheCircle;\n\nclass PathString {\n  constructor(digits) {\n    this._append = digits == null ? append : appendRound(digits);\n    this._radius = 4.5;\n    this._ = \"\";\n  }\n  pointRadius(_) {\n    this._radius = +_;\n    return this;\n  }\n  polygonStart() {\n    this._line = 0;\n  }\n  polygonEnd() {\n    this._line = NaN;\n  }\n  lineStart() {\n    this._point = 0;\n  }\n  lineEnd() {\n    if (this._line === 0) this._ += \"Z\";\n    this._point = NaN;\n  }\n  point(x, y) {\n    switch (this._point) {\n      case 0: {\n        this._append`M${x},${y}`;\n        this._point = 1;\n        break;\n      }\n      case 1: {\n        this._append`L${x},${y}`;\n        break;\n      }\n      default: {\n        this._append`M${x},${y}`;\n        if (this._radius !== cacheRadius || this._append !== cacheAppend) {\n          const r = this._radius;\n          const s = this._;\n          this._ = \"\"; // stash the old string so we can cache the circle path fragment\n          this._append`m0,${r}a${r},${r} 0 1,1 0,${-2 * r}a${r},${r} 0 1,1 0,${2 * r}z`;\n          cacheRadius = r;\n          cacheAppend = this._append;\n          cacheCircle = this._;\n          this._ = s;\n        }\n        this._ += cacheCircle;\n        break;\n      }\n    }\n  }\n  result() {\n    const result = this._;\n    this._ = \"\";\n    return result.length ? result : null;\n  }\n}\n\nfunction append(strings) {\n  let i = 1;\n  this._ += strings[0];\n  for (const j = strings.length; i < j; ++i) {\n    this._ += arguments[i] + strings[i];\n  }\n}\n\nfunction appendRound(digits) {\n  const d = Math.floor(digits);\n  if (!(d >= 0)) throw new RangeError(`invalid digits: ${digits}`);\n  if (d > 15) return append;\n  if (d !== cacheDigits) {\n    const k = 10 ** d;\n    cacheDigits = d;\n    cacheAppend = function append(strings) {\n      let i = 1;\n      this._ += strings[0];\n      for (const j = strings.length; i < j; ++i) {\n        this._ += Math.round(arguments[i] * k) / k + strings[i];\n      }\n    };\n  }\n  return cacheAppend;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/path/string.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/pointEqual.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-geo/src/pointEqual.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  return (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(a[0] - b[0]) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon && (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(a[1] - b[1]) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/pointEqual.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/polygonContains.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-geo/src/polygonContains.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/fsum.js\");\n/* harmony import */ var _cartesian_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./cartesian.js */ \"../../node_modules/d3-geo/src/cartesian.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\n\nfunction longitude(point) {\n  return (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(point[0]) <= _math_js__WEBPACK_IMPORTED_MODULE_0__.pi ? point[0] : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(point[0]) * (((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(point[0]) + _math_js__WEBPACK_IMPORTED_MODULE_0__.pi) % _math_js__WEBPACK_IMPORTED_MODULE_0__.tau - _math_js__WEBPACK_IMPORTED_MODULE_0__.pi);\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(polygon, point) {\n  var lambda = longitude(point),\n      phi = point[1],\n      sinPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi),\n      normal = [(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(lambda), -(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(lambda), 0],\n      angle = 0,\n      winding = 0;\n\n  var sum = new d3_array__WEBPACK_IMPORTED_MODULE_1__.Adder();\n\n  if (sinPhi === 1) phi = _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n  else if (sinPhi === -1) phi = -_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi - _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\n  for (var i = 0, n = polygon.length; i < n; ++i) {\n    if (!(m = (ring = polygon[i]).length)) continue;\n    var ring,\n        m,\n        point0 = ring[m - 1],\n        lambda0 = longitude(point0),\n        phi0 = point0[1] / 2 + _math_js__WEBPACK_IMPORTED_MODULE_0__.quarterPi,\n        sinPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi0),\n        cosPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi0);\n\n    for (var j = 0; j < m; ++j, lambda0 = lambda1, sinPhi0 = sinPhi1, cosPhi0 = cosPhi1, point0 = point1) {\n      var point1 = ring[j],\n          lambda1 = longitude(point1),\n          phi1 = point1[1] / 2 + _math_js__WEBPACK_IMPORTED_MODULE_0__.quarterPi,\n          sinPhi1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi1),\n          cosPhi1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi1),\n          delta = lambda1 - lambda0,\n          sign = delta >= 0 ? 1 : -1,\n          absDelta = sign * delta,\n          antimeridian = absDelta > _math_js__WEBPACK_IMPORTED_MODULE_0__.pi,\n          k = sinPhi0 * sinPhi1;\n\n      sum.add((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(k * sign * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(absDelta), cosPhi0 * cosPhi1 + k * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(absDelta)));\n      angle += antimeridian ? delta + sign * _math_js__WEBPACK_IMPORTED_MODULE_0__.tau : delta;\n\n      // Are the longitudes either side of the point’s meridian (lambda),\n      // and are the latitudes smaller than the parallel (phi)?\n      if (antimeridian ^ lambda0 >= lambda ^ lambda1 >= lambda) {\n        var arc = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesianCross)((0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesian)(point0), (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesian)(point1));\n        (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesianNormalizeInPlace)(arc);\n        var intersection = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesianCross)(normal, arc);\n        (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesianNormalizeInPlace)(intersection);\n        var phiArc = (antimeridian ^ delta >= 0 ? -1 : 1) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(intersection[2]);\n        if (phi > phiArc || phi === phiArc && (arc[0] || arc[1])) {\n          winding += antimeridian ^ delta >= 0 ? 1 : -1;\n        }\n      }\n    }\n  }\n\n  // First, determine whether the South pole is inside or outside:\n  //\n  // It is inside if:\n  // * the polygon winds around it in a clockwise direction.\n  // * the polygon does not (cumulatively) wind around it, but has a negative\n  //   (counter-clockwise) area.\n  //\n  // Second, count the (signed) number of times a segment crosses a lambda\n  // from the point to the South pole.  If it is zero, then the point is the\n  // same side as the South pole.\n\n  return (angle < -_math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon || angle < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon && sum < -_math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon2) ^ (winding & 1);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/polygonContains.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/albers.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/albers.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _conicEqualArea_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./conicEqualArea.js */ \"../../node_modules/d3-geo/src/projection/conicEqualArea.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_conicEqualArea_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])()\n      .parallels([29.5, 45.5])\n      .scale(1070)\n      .translate([480, 250])\n      .rotate([96, 0])\n      .center([-0.6, 38.7]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/albers.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/albersUsa.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/albersUsa.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _albers_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./albers.js */ \"../../node_modules/d3-geo/src/projection/albers.js\");\n/* harmony import */ var _conicEqualArea_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./conicEqualArea.js */ \"../../node_modules/d3-geo/src/projection/conicEqualArea.js\");\n/* harmony import */ var _fit_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./fit.js */ \"../../node_modules/d3-geo/src/projection/fit.js\");\n\n\n\n\n\n// The projections must have mutually exclusive clip regions on the sphere,\n// as this will avoid emitting interleaving lines and polygons.\nfunction multiplex(streams) {\n  var n = streams.length;\n  return {\n    point: function(x, y) { var i = -1; while (++i < n) streams[i].point(x, y); },\n    sphere: function() { var i = -1; while (++i < n) streams[i].sphere(); },\n    lineStart: function() { var i = -1; while (++i < n) streams[i].lineStart(); },\n    lineEnd: function() { var i = -1; while (++i < n) streams[i].lineEnd(); },\n    polygonStart: function() { var i = -1; while (++i < n) streams[i].polygonStart(); },\n    polygonEnd: function() { var i = -1; while (++i < n) streams[i].polygonEnd(); }\n  };\n}\n\n// A composite projection for the United States, configured by default for\n// 960×500. The projection also works quite well at 960×600 if you change the\n// scale to 1285 and adjust the translate accordingly. The set of standard\n// parallels for each region comes from USGS, which is published here:\n// http://egsc.usgs.gov/isb/pubs/MapProjections/projections.html#albers\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var cache,\n      cacheStream,\n      lower48 = (0,_albers_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(), lower48Point,\n      alaska = (0,_conicEqualArea_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])().rotate([154, 0]).center([-2, 58.5]).parallels([55, 65]), alaskaPoint, // EPSG:3338\n      hawaii = (0,_conicEqualArea_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])().rotate([157, 0]).center([-3, 19.9]).parallels([8, 18]), hawaiiPoint, // ESRI:102007\n      point, pointStream = {point: function(x, y) { point = [x, y]; }};\n\n  function albersUsa(coordinates) {\n    var x = coordinates[0], y = coordinates[1];\n    return point = null,\n        (lower48Point.point(x, y), point)\n        || (alaskaPoint.point(x, y), point)\n        || (hawaiiPoint.point(x, y), point);\n  }\n\n  albersUsa.invert = function(coordinates) {\n    var k = lower48.scale(),\n        t = lower48.translate(),\n        x = (coordinates[0] - t[0]) / k,\n        y = (coordinates[1] - t[1]) / k;\n    return (y >= 0.120 && y < 0.234 && x >= -0.425 && x < -0.214 ? alaska\n        : y >= 0.166 && y < 0.234 && x >= -0.214 && x < -0.115 ? hawaii\n        : lower48).invert(coordinates);\n  };\n\n  albersUsa.stream = function(stream) {\n    return cache && cacheStream === stream ? cache : cache = multiplex([lower48.stream(cacheStream = stream), alaska.stream(stream), hawaii.stream(stream)]);\n  };\n\n  albersUsa.precision = function(_) {\n    if (!arguments.length) return lower48.precision();\n    lower48.precision(_), alaska.precision(_), hawaii.precision(_);\n    return reset();\n  };\n\n  albersUsa.scale = function(_) {\n    if (!arguments.length) return lower48.scale();\n    lower48.scale(_), alaska.scale(_ * 0.35), hawaii.scale(_);\n    return albersUsa.translate(lower48.translate());\n  };\n\n  albersUsa.translate = function(_) {\n    if (!arguments.length) return lower48.translate();\n    var k = lower48.scale(), x = +_[0], y = +_[1];\n\n    lower48Point = lower48\n        .translate(_)\n        .clipExtent([[x - 0.455 * k, y - 0.238 * k], [x + 0.455 * k, y + 0.238 * k]])\n        .stream(pointStream);\n\n    alaskaPoint = alaska\n        .translate([x - 0.307 * k, y + 0.201 * k])\n        .clipExtent([[x - 0.425 * k + _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon, y + 0.120 * k + _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon], [x - 0.214 * k - _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon, y + 0.234 * k - _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon]])\n        .stream(pointStream);\n\n    hawaiiPoint = hawaii\n        .translate([x - 0.205 * k, y + 0.212 * k])\n        .clipExtent([[x - 0.214 * k + _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon, y + 0.166 * k + _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon], [x - 0.115 * k - _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon, y + 0.234 * k - _math_js__WEBPACK_IMPORTED_MODULE_2__.epsilon]])\n        .stream(pointStream);\n\n    return reset();\n  };\n\n  albersUsa.fitExtent = function(extent, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_3__.fitExtent)(albersUsa, extent, object);\n  };\n\n  albersUsa.fitSize = function(size, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_3__.fitSize)(albersUsa, size, object);\n  };\n\n  albersUsa.fitWidth = function(width, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_3__.fitWidth)(albersUsa, width, object);\n  };\n\n  albersUsa.fitHeight = function(height, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_3__.fitHeight)(albersUsa, height, object);\n  };\n\n  function reset() {\n    cache = cacheStream = null;\n    return albersUsa;\n  }\n\n  return albersUsa.scale(1070);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/albersUsa.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/azimuthal.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/azimuthal.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   azimuthalInvert: () => (/* binding */ azimuthalInvert),\n/* harmony export */   azimuthalRaw: () => (/* binding */ azimuthalRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\nfunction azimuthalRaw(scale) {\n  return function(x, y) {\n    var cx = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(x),\n        cy = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y),\n        k = scale(cx * cy);\n        if (k === Infinity) return [2, 0];\n    return [\n      k * cy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(x),\n      k * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y)\n    ];\n  }\n}\n\nfunction azimuthalInvert(angle) {\n  return function(x, y) {\n    var z = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(x * x + y * y),\n        c = angle(z),\n        sc = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(c),\n        cc = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(c);\n    return [\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(x * sc, z * cc),\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(z && y * sc / z)\n    ];\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/azimuthal.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/azimuthalEqualArea.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/azimuthalEqualArea.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   azimuthalEqualAreaRaw: () => (/* binding */ azimuthalEqualAreaRaw),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _azimuthal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./azimuthal.js */ \"../../node_modules/d3-geo/src/projection/azimuthal.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nvar azimuthalEqualAreaRaw = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_0__.azimuthalRaw)(function(cxcy) {\n  return (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sqrt)(2 / (1 + cxcy));\n});\n\nazimuthalEqualAreaRaw.invert = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_0__.azimuthalInvert)(function(z) {\n  return 2 * (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.asin)(z / 2);\n});\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(azimuthalEqualAreaRaw)\n      .scale(124.75)\n      .clipAngle(180 - 1e-3);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/azimuthalEqualArea.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/azimuthalEquidistant.js":
/*!************************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/azimuthalEquidistant.js ***!
  \************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   azimuthalEquidistantRaw: () => (/* binding */ azimuthalEquidistantRaw),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _azimuthal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./azimuthal.js */ \"../../node_modules/d3-geo/src/projection/azimuthal.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nvar azimuthalEquidistantRaw = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_0__.azimuthalRaw)(function(c) {\n  return (c = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.acos)(c)) && c / (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(c);\n});\n\nazimuthalEquidistantRaw.invert = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_0__.azimuthalInvert)(function(z) {\n  return z;\n});\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(azimuthalEquidistantRaw)\n      .scale(79.4188)\n      .clipAngle(180 - 1e-3);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/azimuthalEquidistant.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/conic.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/conic.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   conicProjection: () => (/* binding */ conicProjection)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\nfunction conicProjection(projectAt) {\n  var phi0 = 0,\n      phi1 = _math_js__WEBPACK_IMPORTED_MODULE_0__.pi / 3,\n      m = (0,_index_js__WEBPACK_IMPORTED_MODULE_1__.projectionMutator)(projectAt),\n      p = m(phi0, phi1);\n\n  p.parallels = function(_) {\n    return arguments.length ? m(phi0 = _[0] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, phi1 = _[1] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians) : [phi0 * _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, phi1 * _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees];\n  };\n\n  return p;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/conic.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/conicConformal.js":
/*!******************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/conicConformal.js ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   conicConformalRaw: () => (/* binding */ conicConformalRaw),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _conic_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./conic.js */ \"../../node_modules/d3-geo/src/projection/conic.js\");\n/* harmony import */ var _mercator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mercator.js */ \"../../node_modules/d3-geo/src/projection/mercator.js\");\n\n\n\n\nfunction tany(y) {\n  return (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.tan)((_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + y) / 2);\n}\n\nfunction conicConformalRaw(y0, y1) {\n  var cy0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y0),\n      n = y0 === y1 ? (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y0) : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.log)(cy0 / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y1)) / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.log)(tany(y1) / tany(y0)),\n      f = cy0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.pow)(tany(y0), n) / n;\n\n  if (!n) return _mercator_js__WEBPACK_IMPORTED_MODULE_1__.mercatorRaw;\n\n  function project(x, y) {\n    if (f > 0) { if (y < -_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) y = -_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon; }\n    else { if (y > _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi - _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) y = _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi - _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon; }\n    var r = f / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.pow)(tany(y), n);\n    return [r * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(n * x), f - r * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(n * x)];\n  }\n\n  project.invert = function(x, y) {\n    var fy = f - y, r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(n) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(x * x + fy * fy),\n      l = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(x, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(fy)) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(fy);\n    if (fy * n < 0)\n      l -= _math_js__WEBPACK_IMPORTED_MODULE_0__.pi * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(x) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(fy);\n    return [l / n, 2 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.pow)(f / r, 1 / n)) - _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi];\n  };\n\n  return project;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_conic_js__WEBPACK_IMPORTED_MODULE_2__.conicProjection)(conicConformalRaw)\n      .scale(109.5)\n      .parallels([30, 30]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/conicConformal.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/conicEqualArea.js":
/*!******************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/conicEqualArea.js ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   conicEqualAreaRaw: () => (/* binding */ conicEqualAreaRaw),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _conic_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./conic.js */ \"../../node_modules/d3-geo/src/projection/conic.js\");\n/* harmony import */ var _cylindricalEqualArea_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./cylindricalEqualArea.js */ \"../../node_modules/d3-geo/src/projection/cylindricalEqualArea.js\");\n\n\n\n\nfunction conicEqualAreaRaw(y0, y1) {\n  var sy0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y0), n = (sy0 + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y1)) / 2;\n\n  // Are the parallels symmetrical around the Equator?\n  if ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(n) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) return (0,_cylindricalEqualArea_js__WEBPACK_IMPORTED_MODULE_1__.cylindricalEqualAreaRaw)(y0);\n\n  var c = 1 + sy0 * (2 * n - sy0), r0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(c) / n;\n\n  function project(x, y) {\n    var r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(c - 2 * n * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y)) / n;\n    return [r * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(x *= n), r0 - r * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(x)];\n  }\n\n  project.invert = function(x, y) {\n    var r0y = r0 - y,\n        l = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(x, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(r0y)) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(r0y);\n    if (r0y * n < 0)\n      l -= _math_js__WEBPACK_IMPORTED_MODULE_0__.pi * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(x) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(r0y);\n    return [l / n, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)((c - (x * x + r0y * r0y) * n * n) / (2 * n))];\n  };\n\n  return project;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_conic_js__WEBPACK_IMPORTED_MODULE_2__.conicProjection)(conicEqualAreaRaw)\n      .scale(155.424)\n      .center([0, 33.6442]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/conicEqualArea.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/conicEquidistant.js":
/*!********************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/conicEquidistant.js ***!
  \********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   conicEquidistantRaw: () => (/* binding */ conicEquidistantRaw),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _conic_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./conic.js */ \"../../node_modules/d3-geo/src/projection/conic.js\");\n/* harmony import */ var _equirectangular_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equirectangular.js */ \"../../node_modules/d3-geo/src/projection/equirectangular.js\");\n\n\n\n\nfunction conicEquidistantRaw(y0, y1) {\n  var cy0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y0),\n      n = y0 === y1 ? (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y0) : (cy0 - (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y1)) / (y1 - y0),\n      g = cy0 / n + y0;\n\n  if ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(n) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) return _equirectangular_js__WEBPACK_IMPORTED_MODULE_1__.equirectangularRaw;\n\n  function project(x, y) {\n    var gy = g - y, nx = n * x;\n    return [gy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(nx), g - gy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(nx)];\n  }\n\n  project.invert = function(x, y) {\n    var gy = g - y,\n        l = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(x, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(gy)) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(gy);\n    if (gy * n < 0)\n      l -= _math_js__WEBPACK_IMPORTED_MODULE_0__.pi * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(x) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(gy);\n    return [l / n, g - (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sign)(n) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(x * x + gy * gy)];\n  };\n\n  return project;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_conic_js__WEBPACK_IMPORTED_MODULE_2__.conicProjection)(conicEquidistantRaw)\n      .scale(131.154)\n      .center([0, 13.9389]);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/conicEquidistant.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/cylindricalEqualArea.js":
/*!************************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/cylindricalEqualArea.js ***!
  \************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   cylindricalEqualAreaRaw: () => (/* binding */ cylindricalEqualAreaRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\nfunction cylindricalEqualAreaRaw(phi0) {\n  var cosPhi0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi0);\n\n  function forward(lambda, phi) {\n    return [lambda * cosPhi0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi) / cosPhi0];\n  }\n\n  forward.invert = function(x, y) {\n    return [x / cosPhi0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(y * cosPhi0)];\n  };\n\n  return forward;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/cylindricalEqualArea.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/equalEarth.js":
/*!**************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/equalEarth.js ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   equalEarthRaw: () => (/* binding */ equalEarthRaw)\n/* harmony export */ });\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\nvar A1 = 1.340264,\n    A2 = -0.081106,\n    A3 = 0.000893,\n    A4 = 0.003796,\n    M = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(3) / 2,\n    iterations = 12;\n\nfunction equalEarthRaw(lambda, phi) {\n  var l = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(M * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi)), l2 = l * l, l6 = l2 * l2 * l2;\n  return [\n    lambda * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(l) / (M * (A1 + 3 * A2 * l2 + l6 * (7 * A3 + 9 * A4 * l2))),\n    l * (A1 + A2 * l2 + l6 * (A3 + A4 * l2))\n  ];\n}\n\nequalEarthRaw.invert = function(x, y) {\n  var l = y, l2 = l * l, l6 = l2 * l2 * l2;\n  for (var i = 0, delta, fy, fpy; i < iterations; ++i) {\n    fy = l * (A1 + A2 * l2 + l6 * (A3 + A4 * l2)) - y;\n    fpy = A1 + 3 * A2 * l2 + l6 * (7 * A3 + 9 * A4 * l2);\n    l -= delta = fy / fpy, l2 = l * l, l6 = l2 * l2 * l2;\n    if ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(delta) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon2) break;\n  }\n  return [\n    M * x * (A1 + 3 * A2 * l2 + l6 * (7 * A3 + 9 * A4 * l2)) / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(l),\n    (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(l) / M)\n  ];\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(equalEarthRaw)\n      .scale(177.158);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/equalEarth.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/equirectangular.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/equirectangular.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   equirectangularRaw: () => (/* binding */ equirectangularRaw)\n/* harmony export */ });\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\nfunction equirectangularRaw(lambda, phi) {\n  return [lambda, phi];\n}\n\nequirectangularRaw.invert = equirectangularRaw;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(equirectangularRaw)\n      .scale(152.63);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/equirectangular.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/fit.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/fit.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   fitExtent: () => (/* binding */ fitExtent),\n/* harmony export */   fitHeight: () => (/* binding */ fitHeight),\n/* harmony export */   fitSize: () => (/* binding */ fitSize),\n/* harmony export */   fitWidth: () => (/* binding */ fitWidth)\n/* harmony export */ });\n/* harmony import */ var _stream_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../stream.js */ \"../../node_modules/d3-geo/src/stream.js\");\n/* harmony import */ var _path_bounds_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../path/bounds.js */ \"../../node_modules/d3-geo/src/path/bounds.js\");\n\n\n\nfunction fit(projection, fitBounds, object) {\n  var clip = projection.clipExtent && projection.clipExtent();\n  projection.scale(150).translate([0, 0]);\n  if (clip != null) projection.clipExtent(null);\n  (0,_stream_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(object, projection.stream(_path_bounds_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]));\n  fitBounds(_path_bounds_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"].result());\n  if (clip != null) projection.clipExtent(clip);\n  return projection;\n}\n\nfunction fitExtent(projection, extent, object) {\n  return fit(projection, function(b) {\n    var w = extent[1][0] - extent[0][0],\n        h = extent[1][1] - extent[0][1],\n        k = Math.min(w / (b[1][0] - b[0][0]), h / (b[1][1] - b[0][1])),\n        x = +extent[0][0] + (w - k * (b[1][0] + b[0][0])) / 2,\n        y = +extent[0][1] + (h - k * (b[1][1] + b[0][1])) / 2;\n    projection.scale(150 * k).translate([x, y]);\n  }, object);\n}\n\nfunction fitSize(projection, size, object) {\n  return fitExtent(projection, [[0, 0], size], object);\n}\n\nfunction fitWidth(projection, width, object) {\n  return fit(projection, function(b) {\n    var w = +width,\n        k = w / (b[1][0] - b[0][0]),\n        x = (w - k * (b[1][0] + b[0][0])) / 2,\n        y = -k * b[0][1];\n    projection.scale(150 * k).translate([x, y]);\n  }, object);\n}\n\nfunction fitHeight(projection, height, object) {\n  return fit(projection, function(b) {\n    var h = +height,\n        k = h / (b[1][1] - b[0][1]),\n        x = -k * b[0][0],\n        y = (h - k * (b[1][1] + b[0][1])) / 2;\n    projection.scale(150 * k).translate([x, y]);\n  }, object);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/fit.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/gnomonic.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/gnomonic.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   gnomonicRaw: () => (/* binding */ gnomonicRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _azimuthal_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./azimuthal.js */ \"../../node_modules/d3-geo/src/projection/azimuthal.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nfunction gnomonicRaw(x, y) {\n  var cy = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y), k = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(x) * cy;\n  return [cy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(x) / k, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y) / k];\n}\n\ngnomonicRaw.invert = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_1__.azimuthalInvert)(_math_js__WEBPACK_IMPORTED_MODULE_0__.atan);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(gnomonicRaw)\n      .scale(144.049)\n      .clipAngle(60);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/gnomonic.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/identity.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/identity.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _clip_rectangle_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../clip/rectangle.js */ \"../../node_modules/d3-geo/src/clip/rectangle.js\");\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../identity.js */ \"../../node_modules/d3-geo/src/identity.js\");\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../transform.js */ \"../../node_modules/d3-geo/src/transform.js\");\n/* harmony import */ var _fit_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./fit.js */ \"../../node_modules/d3-geo/src/projection/fit.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var k = 1, tx = 0, ty = 0, sx = 1, sy = 1, // scale, translate and reflect\n      alpha = 0, ca, sa, // angle\n      x0 = null, y0, x1, y1, // clip extent\n      kx = 1, ky = 1,\n      transform = (0,_transform_js__WEBPACK_IMPORTED_MODULE_0__.transformer)({\n        point: function(x, y) {\n          var p = projection([x, y])\n          this.stream.point(p[0], p[1]);\n        }\n      }),\n      postclip = _identity_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n      cache,\n      cacheStream;\n\n  function reset() {\n    kx = k * sx;\n    ky = k * sy;\n    cache = cacheStream = null;\n    return projection;\n  }\n\n  function projection (p) {\n    var x = p[0] * kx, y = p[1] * ky;\n    if (alpha) {\n      var t = y * ca - x * sa;\n      x = x * ca + y * sa;\n      y = t;\n    }    \n    return [x + tx, y + ty];\n  }\n  projection.invert = function(p) {\n    var x = p[0] - tx, y = p[1] - ty;\n    if (alpha) {\n      var t = y * ca + x * sa;\n      x = x * ca - y * sa;\n      y = t;\n    }\n    return [x / kx, y / ky];\n  };\n  projection.stream = function(stream) {\n    return cache && cacheStream === stream ? cache : cache = transform(postclip(cacheStream = stream));\n  };\n  projection.postclip = function(_) {\n    return arguments.length ? (postclip = _, x0 = y0 = x1 = y1 = null, reset()) : postclip;\n  };\n  projection.clipExtent = function(_) {\n    return arguments.length ? (postclip = _ == null ? (x0 = y0 = x1 = y1 = null, _identity_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]) : (0,_clip_rectangle_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(x0 = +_[0][0], y0 = +_[0][1], x1 = +_[1][0], y1 = +_[1][1]), reset()) : x0 == null ? null : [[x0, y0], [x1, y1]];\n  };\n  projection.scale = function(_) {\n    return arguments.length ? (k = +_, reset()) : k;\n  };\n  projection.translate = function(_) {\n    return arguments.length ? (tx = +_[0], ty = +_[1], reset()) : [tx, ty];\n  }\n  projection.angle = function(_) {\n    return arguments.length ? (alpha = _ % 360 * _math_js__WEBPACK_IMPORTED_MODULE_3__.radians, sa = (0,_math_js__WEBPACK_IMPORTED_MODULE_3__.sin)(alpha), ca = (0,_math_js__WEBPACK_IMPORTED_MODULE_3__.cos)(alpha), reset()) : alpha * _math_js__WEBPACK_IMPORTED_MODULE_3__.degrees;\n  };\n  projection.reflectX = function(_) {\n    return arguments.length ? (sx = _ ? -1 : 1, reset()) : sx < 0;\n  };\n  projection.reflectY = function(_) {\n    return arguments.length ? (sy = _ ? -1 : 1, reset()) : sy < 0;\n  };\n  projection.fitExtent = function(extent, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_4__.fitExtent)(projection, extent, object);\n  };\n  projection.fitSize = function(size, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_4__.fitSize)(projection, size, object);\n  };\n  projection.fitWidth = function(width, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_4__.fitWidth)(projection, width, object);\n  };\n  projection.fitHeight = function(height, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_4__.fitHeight)(projection, height, object);\n  };\n\n  return projection;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/identity.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/index.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/index.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ projection),\n/* harmony export */   projectionMutator: () => (/* binding */ projectionMutator)\n/* harmony export */ });\n/* harmony import */ var _clip_antimeridian_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../clip/antimeridian.js */ \"../../node_modules/d3-geo/src/clip/antimeridian.js\");\n/* harmony import */ var _clip_circle_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../clip/circle.js */ \"../../node_modules/d3-geo/src/clip/circle.js\");\n/* harmony import */ var _clip_rectangle_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../clip/rectangle.js */ \"../../node_modules/d3-geo/src/clip/rectangle.js\");\n/* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../compose.js */ \"../../node_modules/d3-geo/src/compose.js\");\n/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../identity.js */ \"../../node_modules/d3-geo/src/identity.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _rotation_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../rotation.js */ \"../../node_modules/d3-geo/src/rotation.js\");\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../transform.js */ \"../../node_modules/d3-geo/src/transform.js\");\n/* harmony import */ var _fit_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./fit.js */ \"../../node_modules/d3-geo/src/projection/fit.js\");\n/* harmony import */ var _resample_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./resample.js */ \"../../node_modules/d3-geo/src/projection/resample.js\");\n\n\n\n\n\n\n\n\n\n\n\nvar transformRadians = (0,_transform_js__WEBPACK_IMPORTED_MODULE_0__.transformer)({\n  point: function(x, y) {\n    this.stream.point(x * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, y * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians);\n  }\n});\n\nfunction transformRotate(rotate) {\n  return (0,_transform_js__WEBPACK_IMPORTED_MODULE_0__.transformer)({\n    point: function(x, y) {\n      var r = rotate(x, y);\n      return this.stream.point(r[0], r[1]);\n    }\n  });\n}\n\nfunction scaleTranslate(k, dx, dy, sx, sy) {\n  function transform(x, y) {\n    x *= sx; y *= sy;\n    return [dx + k * x, dy - k * y];\n  }\n  transform.invert = function(x, y) {\n    return [(x - dx) / k * sx, (dy - y) / k * sy];\n  };\n  return transform;\n}\n\nfunction scaleTranslateRotate(k, dx, dy, sx, sy, alpha) {\n  if (!alpha) return scaleTranslate(k, dx, dy, sx, sy);\n  var cosAlpha = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.cos)(alpha),\n      sinAlpha = (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sin)(alpha),\n      a = cosAlpha * k,\n      b = sinAlpha * k,\n      ai = cosAlpha / k,\n      bi = sinAlpha / k,\n      ci = (sinAlpha * dy - cosAlpha * dx) / k,\n      fi = (sinAlpha * dx + cosAlpha * dy) / k;\n  function transform(x, y) {\n    x *= sx; y *= sy;\n    return [a * x - b * y + dx, dy - b * x - a * y];\n  }\n  transform.invert = function(x, y) {\n    return [sx * (ai * x - bi * y + ci), sy * (fi - bi * x - ai * y)];\n  };\n  return transform;\n}\n\nfunction projection(project) {\n  return projectionMutator(function() { return project; })();\n}\n\nfunction projectionMutator(projectAt) {\n  var project,\n      k = 150, // scale\n      x = 480, y = 250, // translate\n      lambda = 0, phi = 0, // center\n      deltaLambda = 0, deltaPhi = 0, deltaGamma = 0, rotate, // pre-rotate\n      alpha = 0, // post-rotate angle\n      sx = 1, // reflectX\n      sy = 1, // reflectX\n      theta = null, preclip = _clip_antimeridian_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"], // pre-clip angle\n      x0 = null, y0, x1, y1, postclip = _identity_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"], // post-clip extent\n      delta2 = 0.5, // precision\n      projectResample,\n      projectTransform,\n      projectRotateTransform,\n      cache,\n      cacheStream;\n\n  function projection(point) {\n    return projectRotateTransform(point[0] * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, point[1] * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians);\n  }\n\n  function invert(point) {\n    point = projectRotateTransform.invert(point[0], point[1]);\n    return point && [point[0] * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees, point[1] * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees];\n  }\n\n  projection.stream = function(stream) {\n    return cache && cacheStream === stream ? cache : cache = transformRadians(transformRotate(rotate)(preclip(projectResample(postclip(cacheStream = stream)))));\n  };\n\n  projection.preclip = function(_) {\n    return arguments.length ? (preclip = _, theta = undefined, reset()) : preclip;\n  };\n\n  projection.postclip = function(_) {\n    return arguments.length ? (postclip = _, x0 = y0 = x1 = y1 = null, reset()) : postclip;\n  };\n\n  projection.clipAngle = function(_) {\n    return arguments.length ? (preclip = +_ ? (0,_clip_circle_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(theta = _ * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians) : (theta = null, _clip_antimeridian_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]), reset()) : theta * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees;\n  };\n\n  projection.clipExtent = function(_) {\n    return arguments.length ? (postclip = _ == null ? (x0 = y0 = x1 = y1 = null, _identity_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) : (0,_clip_rectangle_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(x0 = +_[0][0], y0 = +_[0][1], x1 = +_[1][0], y1 = +_[1][1]), reset()) : x0 == null ? null : [[x0, y0], [x1, y1]];\n  };\n\n  projection.scale = function(_) {\n    return arguments.length ? (k = +_, recenter()) : k;\n  };\n\n  projection.translate = function(_) {\n    return arguments.length ? (x = +_[0], y = +_[1], recenter()) : [x, y];\n  };\n\n  projection.center = function(_) {\n    return arguments.length ? (lambda = _[0] % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, phi = _[1] % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, recenter()) : [lambda * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees, phi * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees];\n  };\n\n  projection.rotate = function(_) {\n    return arguments.length ? (deltaLambda = _[0] % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, deltaPhi = _[1] % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, deltaGamma = _.length > 2 ? _[2] % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians : 0, recenter()) : [deltaLambda * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees, deltaPhi * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees, deltaGamma * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees];\n  };\n\n  projection.angle = function(_) {\n    return arguments.length ? (alpha = _ % 360 * _math_js__WEBPACK_IMPORTED_MODULE_1__.radians, recenter()) : alpha * _math_js__WEBPACK_IMPORTED_MODULE_1__.degrees;\n  };\n\n  projection.reflectX = function(_) {\n    return arguments.length ? (sx = _ ? -1 : 1, recenter()) : sx < 0;\n  };\n\n  projection.reflectY = function(_) {\n    return arguments.length ? (sy = _ ? -1 : 1, recenter()) : sy < 0;\n  };\n\n  projection.precision = function(_) {\n    return arguments.length ? (projectResample = (0,_resample_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(projectTransform, delta2 = _ * _), reset()) : (0,_math_js__WEBPACK_IMPORTED_MODULE_1__.sqrt)(delta2);\n  };\n\n  projection.fitExtent = function(extent, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_7__.fitExtent)(projection, extent, object);\n  };\n\n  projection.fitSize = function(size, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_7__.fitSize)(projection, size, object);\n  };\n\n  projection.fitWidth = function(width, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_7__.fitWidth)(projection, width, object);\n  };\n\n  projection.fitHeight = function(height, object) {\n    return (0,_fit_js__WEBPACK_IMPORTED_MODULE_7__.fitHeight)(projection, height, object);\n  };\n\n  function recenter() {\n    var center = scaleTranslateRotate(k, 0, 0, sx, sy, alpha).apply(null, project(lambda, phi)),\n        transform = scaleTranslateRotate(k, x - center[0], y - center[1], sx, sy, alpha);\n    rotate = (0,_rotation_js__WEBPACK_IMPORTED_MODULE_8__.rotateRadians)(deltaLambda, deltaPhi, deltaGamma);\n    projectTransform = (0,_compose_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(project, transform);\n    projectRotateTransform = (0,_compose_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(rotate, projectTransform);\n    projectResample = (0,_resample_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"])(projectTransform, delta2);\n    return reset();\n  }\n\n  function reset() {\n    cache = cacheStream = null;\n    return projection;\n  }\n\n  return function() {\n    project = projectAt.apply(this, arguments);\n    projection.invert = project.invert && invert;\n    return recenter();\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/index.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/mercator.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/mercator.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   mercatorProjection: () => (/* binding */ mercatorProjection),\n/* harmony export */   mercatorRaw: () => (/* binding */ mercatorRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _rotation_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../rotation.js */ \"../../node_modules/d3-geo/src/rotation.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nfunction mercatorRaw(lambda, phi) {\n  return [lambda, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.log)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.tan)((_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + phi) / 2))];\n}\n\nmercatorRaw.invert = function(x, y) {\n  return [x, 2 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.exp)(y)) - _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi];\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return mercatorProjection(mercatorRaw)\n      .scale(961 / _math_js__WEBPACK_IMPORTED_MODULE_0__.tau);\n}\n\nfunction mercatorProjection(project) {\n  var m = (0,_index_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(project),\n      center = m.center,\n      scale = m.scale,\n      translate = m.translate,\n      clipExtent = m.clipExtent,\n      x0 = null, y0, x1, y1; // clip extent\n\n  m.scale = function(_) {\n    return arguments.length ? (scale(_), reclip()) : scale();\n  };\n\n  m.translate = function(_) {\n    return arguments.length ? (translate(_), reclip()) : translate();\n  };\n\n  m.center = function(_) {\n    return arguments.length ? (center(_), reclip()) : center();\n  };\n\n  m.clipExtent = function(_) {\n    return arguments.length ? ((_ == null ? x0 = y0 = x1 = y1 = null : (x0 = +_[0][0], y0 = +_[0][1], x1 = +_[1][0], y1 = +_[1][1])), reclip()) : x0 == null ? null : [[x0, y0], [x1, y1]];\n  };\n\n  function reclip() {\n    var k = _math_js__WEBPACK_IMPORTED_MODULE_0__.pi * scale(),\n        t = m((0,_rotation_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(m.rotate()).invert([0, 0]));\n    return clipExtent(x0 == null\n        ? [[t[0] - k, t[1] - k], [t[0] + k, t[1] + k]] : project === mercatorRaw\n        ? [[Math.max(t[0] - k, x0), y0], [Math.min(t[0] + k, x1), y1]]\n        : [[x0, Math.max(t[1] - k, y0)], [x1, Math.min(t[1] + k, y1)]]);\n  }\n\n  return reclip();\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/mercator.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/naturalEarth1.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/naturalEarth1.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   naturalEarth1Raw: () => (/* binding */ naturalEarth1Raw)\n/* harmony export */ });\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\nfunction naturalEarth1Raw(lambda, phi) {\n  var phi2 = phi * phi, phi4 = phi2 * phi2;\n  return [\n    lambda * (0.8707 - 0.131979 * phi2 + phi4 * (-0.013791 + phi4 * (0.003971 * phi2 - 0.001529 * phi4))),\n    phi * (1.007226 + phi2 * (0.015085 + phi4 * (-0.044475 + 0.028874 * phi2 - 0.005916 * phi4)))\n  ];\n}\n\nnaturalEarth1Raw.invert = function(x, y) {\n  var phi = y, i = 25, delta;\n  do {\n    var phi2 = phi * phi, phi4 = phi2 * phi2;\n    phi -= delta = (phi * (1.007226 + phi2 * (0.015085 + phi4 * (-0.044475 + 0.028874 * phi2 - 0.005916 * phi4))) - y) /\n        (1.007226 + phi2 * (0.015085 * 3 + phi4 * (-0.044475 * 7 + 0.028874 * 9 * phi2 - 0.005916 * 11 * phi4)));\n  } while ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(delta) > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon && --i > 0);\n  return [\n    x / (0.8707 + (phi2 = phi * phi) * (-0.131979 + phi2 * (-0.013791 + phi2 * phi2 * phi2 * (0.003971 - 0.001529 * phi2)))),\n    phi\n  ];\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(naturalEarth1Raw)\n      .scale(175.295);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/naturalEarth1.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/orthographic.js":
/*!****************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/orthographic.js ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   orthographicRaw: () => (/* binding */ orthographicRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _azimuthal_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./azimuthal.js */ \"../../node_modules/d3-geo/src/projection/azimuthal.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nfunction orthographicRaw(x, y) {\n  return [(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(x), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y)];\n}\n\northographicRaw.invert = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_1__.azimuthalInvert)(_math_js__WEBPACK_IMPORTED_MODULE_0__.asin);\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(orthographicRaw)\n      .scale(249.5)\n      .clipAngle(90 + _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/orthographic.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/resample.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/resample.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cartesian_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../cartesian.js */ \"../../node_modules/d3-geo/src/cartesian.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _transform_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../transform.js */ \"../../node_modules/d3-geo/src/transform.js\");\n\n\n\n\nvar maxDepth = 16, // maximum depth of subdivision\n    cosMinDistance = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(30 * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians); // cos(minimum angular distance)\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(project, delta2) {\n  return +delta2 ? resample(project, delta2) : resampleNone(project);\n}\n\nfunction resampleNone(project) {\n  return (0,_transform_js__WEBPACK_IMPORTED_MODULE_1__.transformer)({\n    point: function(x, y) {\n      x = project(x, y);\n      this.stream.point(x[0], x[1]);\n    }\n  });\n}\n\nfunction resample(project, delta2) {\n\n  function resampleLineTo(x0, y0, lambda0, a0, b0, c0, x1, y1, lambda1, a1, b1, c1, depth, stream) {\n    var dx = x1 - x0,\n        dy = y1 - y0,\n        d2 = dx * dx + dy * dy;\n    if (d2 > 4 * delta2 && depth--) {\n      var a = a0 + a1,\n          b = b0 + b1,\n          c = c0 + c1,\n          m = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(a * a + b * b + c * c),\n          phi2 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(c /= m),\n          lambda2 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(c) - 1) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon || (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(lambda0 - lambda1) < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon ? (lambda0 + lambda1) / 2 : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(b, a),\n          p = project(lambda2, phi2),\n          x2 = p[0],\n          y2 = p[1],\n          dx2 = x2 - x0,\n          dy2 = y2 - y0,\n          dz = dy * dx2 - dx * dy2;\n      if (dz * dz / d2 > delta2 // perpendicular projected distance\n          || (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)((dx * dx2 + dy * dy2) / d2 - 0.5) > 0.3 // midpoint close to an end\n          || a0 * a1 + b0 * b1 + c0 * c1 < cosMinDistance) { // angular distance\n        resampleLineTo(x0, y0, lambda0, a0, b0, c0, x2, y2, lambda2, a /= m, b /= m, c, depth, stream);\n        stream.point(x2, y2);\n        resampleLineTo(x2, y2, lambda2, a, b, c, x1, y1, lambda1, a1, b1, c1, depth, stream);\n      }\n    }\n  }\n  return function(stream) {\n    var lambda00, x00, y00, a00, b00, c00, // first point\n        lambda0, x0, y0, a0, b0, c0; // previous point\n\n    var resampleStream = {\n      point: point,\n      lineStart: lineStart,\n      lineEnd: lineEnd,\n      polygonStart: function() { stream.polygonStart(); resampleStream.lineStart = ringStart; },\n      polygonEnd: function() { stream.polygonEnd(); resampleStream.lineStart = lineStart; }\n    };\n\n    function point(x, y) {\n      x = project(x, y);\n      stream.point(x[0], x[1]);\n    }\n\n    function lineStart() {\n      x0 = NaN;\n      resampleStream.point = linePoint;\n      stream.lineStart();\n    }\n\n    function linePoint(lambda, phi) {\n      var c = (0,_cartesian_js__WEBPACK_IMPORTED_MODULE_2__.cartesian)([lambda, phi]), p = project(lambda, phi);\n      resampleLineTo(x0, y0, lambda0, a0, b0, c0, x0 = p[0], y0 = p[1], lambda0 = lambda, a0 = c[0], b0 = c[1], c0 = c[2], maxDepth, stream);\n      stream.point(x0, y0);\n    }\n\n    function lineEnd() {\n      resampleStream.point = point;\n      stream.lineEnd();\n    }\n\n    function ringStart() {\n      lineStart();\n      resampleStream.point = ringPoint;\n      resampleStream.lineEnd = ringEnd;\n    }\n\n    function ringPoint(lambda, phi) {\n      linePoint(lambda00 = lambda, phi), x00 = x0, y00 = y0, a00 = a0, b00 = b0, c00 = c0;\n      resampleStream.point = linePoint;\n    }\n\n    function ringEnd() {\n      resampleLineTo(x0, y0, lambda0, a0, b0, c0, x00, y00, lambda00, a00, b00, c00, maxDepth, stream);\n      resampleStream.lineEnd = lineEnd;\n      lineEnd();\n    }\n\n    return resampleStream;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/resample.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/stereographic.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/stereographic.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   stereographicRaw: () => (/* binding */ stereographicRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _azimuthal_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./azimuthal.js */ \"../../node_modules/d3-geo/src/projection/azimuthal.js\");\n/* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./index.js */ \"../../node_modules/d3-geo/src/projection/index.js\");\n\n\n\n\nfunction stereographicRaw(x, y) {\n  var cy = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(y), k = 1 + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(x) * cy;\n  return [cy * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(x) / k, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(y) / k];\n}\n\nstereographicRaw.invert = (0,_azimuthal_js__WEBPACK_IMPORTED_MODULE_1__.azimuthalInvert)(function(z) {\n  return 2 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan)(z);\n});\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return (0,_index_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(stereographicRaw)\n      .scale(250)\n      .clipAngle(142);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/stereographic.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/projection/transverseMercator.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/d3-geo/src/projection/transverseMercator.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   transverseMercatorRaw: () => (/* binding */ transverseMercatorRaw)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-geo/src/math.js\");\n/* harmony import */ var _mercator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mercator.js */ \"../../node_modules/d3-geo/src/projection/mercator.js\");\n\n\n\nfunction transverseMercatorRaw(lambda, phi) {\n  return [(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.log)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.tan)((_math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi + phi) / 2)), -lambda];\n}\n\ntransverseMercatorRaw.invert = function(x, y) {\n  return [-y, 2 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.exp)(x)) - _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi];\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var m = (0,_mercator_js__WEBPACK_IMPORTED_MODULE_1__.mercatorProjection)(transverseMercatorRaw),\n      center = m.center,\n      rotate = m.rotate;\n\n  m.center = function(_) {\n    return arguments.length ? center([-_[1], _[0]]) : (_ = center(), [_[1], -_[0]]);\n  };\n\n  m.rotate = function(_) {\n    return arguments.length ? rotate([_[0], _[1], _.length > 2 ? _[2] + 90 : 90]) : (_ = rotate(), [_[0], _[1], _[2] - 90]);\n  };\n\n  return rotate([0, 0, 90])\n      .scale(159.155);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/projection/transverseMercator.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/rotation.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-geo/src/rotation.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   rotateRadians: () => (/* binding */ rotateRadians)\n/* harmony export */ });\n/* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./compose.js */ \"../../node_modules/d3-geo/src/compose.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-geo/src/math.js\");\n\n\n\nfunction rotationIdentity(lambda, phi) {\n  if ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(lambda) > _math_js__WEBPACK_IMPORTED_MODULE_0__.pi) lambda -= Math.round(lambda / _math_js__WEBPACK_IMPORTED_MODULE_0__.tau) * _math_js__WEBPACK_IMPORTED_MODULE_0__.tau;\n  return [lambda, phi];\n}\n\nrotationIdentity.invert = rotationIdentity;\n\nfunction rotateRadians(deltaLambda, deltaPhi, deltaGamma) {\n  return (deltaLambda %= _math_js__WEBPACK_IMPORTED_MODULE_0__.tau) ? (deltaPhi || deltaGamma ? (0,_compose_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(rotationLambda(deltaLambda), rotationPhiGamma(deltaPhi, deltaGamma))\n    : rotationLambda(deltaLambda))\n    : (deltaPhi || deltaGamma ? rotationPhiGamma(deltaPhi, deltaGamma)\n    : rotationIdentity);\n}\n\nfunction forwardRotationLambda(deltaLambda) {\n  return function(lambda, phi) {\n    lambda += deltaLambda;\n    if ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(lambda) > _math_js__WEBPACK_IMPORTED_MODULE_0__.pi) lambda -= Math.round(lambda / _math_js__WEBPACK_IMPORTED_MODULE_0__.tau) * _math_js__WEBPACK_IMPORTED_MODULE_0__.tau;\n    return [lambda, phi];\n  };\n}\n\nfunction rotationLambda(deltaLambda) {\n  var rotation = forwardRotationLambda(deltaLambda);\n  rotation.invert = forwardRotationLambda(-deltaLambda);\n  return rotation;\n}\n\nfunction rotationPhiGamma(deltaPhi, deltaGamma) {\n  var cosDeltaPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(deltaPhi),\n      sinDeltaPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(deltaPhi),\n      cosDeltaGamma = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(deltaGamma),\n      sinDeltaGamma = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(deltaGamma);\n\n  function rotation(lambda, phi) {\n    var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi),\n        x = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(lambda) * cosPhi,\n        y = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(lambda) * cosPhi,\n        z = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi),\n        k = z * cosDeltaPhi + x * sinDeltaPhi;\n    return [\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(y * cosDeltaGamma - k * sinDeltaGamma, x * cosDeltaPhi - z * sinDeltaPhi),\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(k * cosDeltaGamma + y * sinDeltaGamma)\n    ];\n  }\n\n  rotation.invert = function(lambda, phi) {\n    var cosPhi = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(phi),\n        x = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(lambda) * cosPhi,\n        y = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(lambda) * cosPhi,\n        z = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(phi),\n        k = z * cosDeltaGamma - y * sinDeltaGamma;\n    return [\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(y * cosDeltaGamma + z * sinDeltaGamma, x * cosDeltaPhi + k * sinDeltaPhi),\n      (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(k * cosDeltaPhi - x * sinDeltaPhi)\n    ];\n  };\n\n  return rotation;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(rotate) {\n  rotate = rotateRadians(rotate[0] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, rotate[1] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, rotate.length > 2 ? rotate[2] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians : 0);\n\n  function forward(coordinates) {\n    coordinates = rotate(coordinates[0] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, coordinates[1] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians);\n    return coordinates[0] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, coordinates[1] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, coordinates;\n  }\n\n  forward.invert = function(coordinates) {\n    coordinates = rotate.invert(coordinates[0] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians, coordinates[1] * _math_js__WEBPACK_IMPORTED_MODULE_0__.radians);\n    return coordinates[0] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, coordinates[1] *= _math_js__WEBPACK_IMPORTED_MODULE_0__.degrees, coordinates;\n  };\n\n  return forward;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/rotation.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/stream.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-geo/src/stream.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction streamGeometry(geometry, stream) {\n  if (geometry && streamGeometryType.hasOwnProperty(geometry.type)) {\n    streamGeometryType[geometry.type](geometry, stream);\n  }\n}\n\nvar streamObjectType = {\n  Feature: function(object, stream) {\n    streamGeometry(object.geometry, stream);\n  },\n  FeatureCollection: function(object, stream) {\n    var features = object.features, i = -1, n = features.length;\n    while (++i < n) streamGeometry(features[i].geometry, stream);\n  }\n};\n\nvar streamGeometryType = {\n  Sphere: function(object, stream) {\n    stream.sphere();\n  },\n  Point: function(object, stream) {\n    object = object.coordinates;\n    stream.point(object[0], object[1], object[2]);\n  },\n  MultiPoint: function(object, stream) {\n    var coordinates = object.coordinates, i = -1, n = coordinates.length;\n    while (++i < n) object = coordinates[i], stream.point(object[0], object[1], object[2]);\n  },\n  LineString: function(object, stream) {\n    streamLine(object.coordinates, stream, 0);\n  },\n  MultiLineString: function(object, stream) {\n    var coordinates = object.coordinates, i = -1, n = coordinates.length;\n    while (++i < n) streamLine(coordinates[i], stream, 0);\n  },\n  Polygon: function(object, stream) {\n    streamPolygon(object.coordinates, stream);\n  },\n  MultiPolygon: function(object, stream) {\n    var coordinates = object.coordinates, i = -1, n = coordinates.length;\n    while (++i < n) streamPolygon(coordinates[i], stream);\n  },\n  GeometryCollection: function(object, stream) {\n    var geometries = object.geometries, i = -1, n = geometries.length;\n    while (++i < n) streamGeometry(geometries[i], stream);\n  }\n};\n\nfunction streamLine(coordinates, stream, closed) {\n  var i = -1, n = coordinates.length - closed, coordinate;\n  stream.lineStart();\n  while (++i < n) coordinate = coordinates[i], stream.point(coordinate[0], coordinate[1], coordinate[2]);\n  stream.lineEnd();\n}\n\nfunction streamPolygon(coordinates, stream) {\n  var i = -1, n = coordinates.length;\n  stream.polygonStart();\n  while (++i < n) streamLine(coordinates[i], stream, 1);\n  stream.polygonEnd();\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(object, stream) {\n  if (object && streamObjectType.hasOwnProperty(object.type)) {\n    streamObjectType[object.type](object, stream);\n  } else {\n    streamGeometry(object, stream);\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/stream.js?");

/***/ }),

/***/ "../../node_modules/d3-geo/src/transform.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-geo/src/transform.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   transformer: () => (/* binding */ transformer)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(methods) {\n  return {\n    stream: transformer(methods)\n  };\n}\n\nfunction transformer(methods) {\n  return function(stream) {\n    var s = new TransformStream;\n    for (var key in methods) s[key] = methods[key];\n    s.stream = stream;\n    return s;\n  };\n}\n\nfunction TransformStream() {}\n\nTransformStream.prototype = {\n  constructor: TransformStream,\n  point: function(x, y) { this.stream.point(x, y); },\n  sphere: function() { this.stream.sphere(); },\n  lineStart: function() { this.stream.lineStart(); },\n  lineEnd: function() { this.stream.lineEnd(); },\n  polygonStart: function() { this.stream.polygonStart(); },\n  polygonEnd: function() { this.stream.polygonEnd(); }\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-geo/src/transform.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/accessors.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/accessors.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   optional: () => (/* binding */ optional),\n/* harmony export */   required: () => (/* binding */ required)\n/* harmony export */ });\nfunction optional(f) {\n  return f == null ? null : required(f);\n}\n\nfunction required(f) {\n  if (typeof f !== \"function\") throw new Error;\n  return f;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/accessors.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/array.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/array.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   shuffle: () => (/* binding */ shuffle)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return typeof x === \"object\" && \"length\" in x\n    ? x // Array, TypedArray, NodeList, array-like\n    : Array.from(x); // Map, Set, iterable, string, or anything else\n}\n\nfunction shuffle(array, random) {\n  let m = array.length,\n      t,\n      i;\n\n  while (m) {\n    i = random() * m-- | 0;\n    t = array[m];\n    array[m] = array[i];\n    array[i] = t;\n  }\n\n  return array;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/array.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/cluster.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/cluster.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction defaultSeparation(a, b) {\n  return a.parent === b.parent ? 1 : 2;\n}\n\nfunction meanX(children) {\n  return children.reduce(meanXReduce, 0) / children.length;\n}\n\nfunction meanXReduce(x, c) {\n  return x + c.x;\n}\n\nfunction maxY(children) {\n  return 1 + children.reduce(maxYReduce, 0);\n}\n\nfunction maxYReduce(y, c) {\n  return Math.max(y, c.y);\n}\n\nfunction leafLeft(node) {\n  var children;\n  while (children = node.children) node = children[0];\n  return node;\n}\n\nfunction leafRight(node) {\n  var children;\n  while (children = node.children) node = children[children.length - 1];\n  return node;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var separation = defaultSeparation,\n      dx = 1,\n      dy = 1,\n      nodeSize = false;\n\n  function cluster(root) {\n    var previousNode,\n        x = 0;\n\n    // First walk, computing the initial x & y values.\n    root.eachAfter(function(node) {\n      var children = node.children;\n      if (children) {\n        node.x = meanX(children);\n        node.y = maxY(children);\n      } else {\n        node.x = previousNode ? x += separation(node, previousNode) : 0;\n        node.y = 0;\n        previousNode = node;\n      }\n    });\n\n    var left = leafLeft(root),\n        right = leafRight(root),\n        x0 = left.x - separation(left, right) / 2,\n        x1 = right.x + separation(right, left) / 2;\n\n    // Second walk, normalizing x & y to the desired size.\n    return root.eachAfter(nodeSize ? function(node) {\n      node.x = (node.x - root.x) * dx;\n      node.y = (root.y - node.y) * dy;\n    } : function(node) {\n      node.x = (node.x - x0) / (x1 - x0) * dx;\n      node.y = (1 - (root.y ? node.y / root.y : 1)) * dy;\n    });\n  }\n\n  cluster.separation = function(x) {\n    return arguments.length ? (separation = x, cluster) : separation;\n  };\n\n  cluster.size = function(x) {\n    return arguments.length ? (nodeSize = false, dx = +x[0], dy = +x[1], cluster) : (nodeSize ? null : [dx, dy]);\n  };\n\n  cluster.nodeSize = function(x) {\n    return arguments.length ? (nodeSize = true, dx = +x[0], dy = +x[1], cluster) : (nodeSize ? [dx, dy] : null);\n  };\n\n  return cluster;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/cluster.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/constant.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/constant.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   constantZero: () => (/* binding */ constantZero),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction constantZero() {\n  return 0;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return function() {\n    return x;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/ancestors.js":
/*!******************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/ancestors.js ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var node = this, nodes = [node];\n  while (node = node.parent) {\n    nodes.push(node);\n  }\n  return nodes;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/ancestors.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/count.js":
/*!**************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/count.js ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction count(node) {\n  var sum = 0,\n      children = node.children,\n      i = children && children.length;\n  if (!i) sum = 1;\n  else while (--i >= 0) sum += children[i].value;\n  node.value = sum;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return this.eachAfter(count);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/count.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/descendants.js":
/*!********************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/descendants.js ***!
  \********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return Array.from(this);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/descendants.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/each.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/each.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback, that) {\n  let index = -1;\n  for (const node of this) {\n    callback.call(that, node, ++index, this);\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/each.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/eachAfter.js":
/*!******************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/eachAfter.js ***!
  \******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback, that) {\n  var node = this, nodes = [node], next = [], children, i, n, index = -1;\n  while (node = nodes.pop()) {\n    next.push(node);\n    if (children = node.children) {\n      for (i = 0, n = children.length; i < n; ++i) {\n        nodes.push(children[i]);\n      }\n    }\n  }\n  while (node = next.pop()) {\n    callback.call(that, node, ++index, this);\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/eachAfter.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/eachBefore.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/eachBefore.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback, that) {\n  var node = this, nodes = [node], children, i, index = -1;\n  while (node = nodes.pop()) {\n    callback.call(that, node, ++index, this);\n    if (children = node.children) {\n      for (i = children.length - 1; i >= 0; --i) {\n        nodes.push(children[i]);\n      }\n    }\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/eachBefore.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/find.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/find.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback, that) {\n  let index = -1;\n  for (const node of this) {\n    if (callback.call(that, node, ++index, this)) {\n      return node;\n    }\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/find.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/index.js":
/*!**************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/index.js ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Node: () => (/* binding */ Node),\n/* harmony export */   computeHeight: () => (/* binding */ computeHeight),\n/* harmony export */   \"default\": () => (/* binding */ hierarchy)\n/* harmony export */ });\n/* harmony import */ var _count_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./count.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/count.js\");\n/* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./each.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/each.js\");\n/* harmony import */ var _eachBefore_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./eachBefore.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/eachBefore.js\");\n/* harmony import */ var _eachAfter_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./eachAfter.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/eachAfter.js\");\n/* harmony import */ var _find_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./find.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/find.js\");\n/* harmony import */ var _sum_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./sum.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/sum.js\");\n/* harmony import */ var _sort_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./sort.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/sort.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/path.js\");\n/* harmony import */ var _ancestors_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./ancestors.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/ancestors.js\");\n/* harmony import */ var _descendants_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./descendants.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/descendants.js\");\n/* harmony import */ var _leaves_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./leaves.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/leaves.js\");\n/* harmony import */ var _links_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./links.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/links.js\");\n/* harmony import */ var _iterator_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./iterator.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/iterator.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction hierarchy(data, children) {\n  if (data instanceof Map) {\n    data = [undefined, data];\n    if (children === undefined) children = mapChildren;\n  } else if (children === undefined) {\n    children = objectChildren;\n  }\n\n  var root = new Node(data),\n      node,\n      nodes = [root],\n      child,\n      childs,\n      i,\n      n;\n\n  while (node = nodes.pop()) {\n    if ((childs = children(node.data)) && (n = (childs = Array.from(childs)).length)) {\n      node.children = childs;\n      for (i = n - 1; i >= 0; --i) {\n        nodes.push(child = childs[i] = new Node(childs[i]));\n        child.parent = node;\n        child.depth = node.depth + 1;\n      }\n    }\n  }\n\n  return root.eachBefore(computeHeight);\n}\n\nfunction node_copy() {\n  return hierarchy(this).eachBefore(copyData);\n}\n\nfunction objectChildren(d) {\n  return d.children;\n}\n\nfunction mapChildren(d) {\n  return Array.isArray(d) ? d[1] : null;\n}\n\nfunction copyData(node) {\n  if (node.data.value !== undefined) node.value = node.data.value;\n  node.data = node.data.data;\n}\n\nfunction computeHeight(node) {\n  var height = 0;\n  do node.height = height;\n  while ((node = node.parent) && (node.height < ++height));\n}\n\nfunction Node(data) {\n  this.data = data;\n  this.depth =\n  this.height = 0;\n  this.parent = null;\n}\n\nNode.prototype = hierarchy.prototype = {\n  constructor: Node,\n  count: _count_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  each: _each_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  eachAfter: _eachAfter_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  eachBefore: _eachBefore_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  find: _find_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  sum: _sum_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  sort: _sort_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"],\n  path: _path_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  ancestors: _ancestors_js__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  descendants: _descendants_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n  leaves: _leaves_js__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n  links: _links_js__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n  copy: node_copy,\n  [Symbol.iterator]: _iterator_js__WEBPACK_IMPORTED_MODULE_12__[\"default\"]\n};\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/index.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/iterator.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/iterator.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function* __WEBPACK_DEFAULT_EXPORT__() {\n  var node = this, current, next = [node], children, i, n;\n  do {\n    current = next.reverse(), next = [];\n    while (node = current.pop()) {\n      yield node;\n      if (children = node.children) {\n        for (i = 0, n = children.length; i < n; ++i) {\n          next.push(children[i]);\n        }\n      }\n    }\n  } while (next.length);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/iterator.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/leaves.js":
/*!***************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/leaves.js ***!
  \***************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var leaves = [];\n  this.eachBefore(function(node) {\n    if (!node.children) {\n      leaves.push(node);\n    }\n  });\n  return leaves;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/leaves.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/links.js":
/*!**************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/links.js ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var root = this, links = [];\n  root.each(function(node) {\n    if (node !== root) { // Don’t include the root’s parent, if any.\n      links.push({source: node.parent, target: node});\n    }\n  });\n  return links;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/links.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/path.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/path.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(end) {\n  var start = this,\n      ancestor = leastCommonAncestor(start, end),\n      nodes = [start];\n  while (start !== ancestor) {\n    start = start.parent;\n    nodes.push(start);\n  }\n  var k = nodes.length;\n  while (end !== ancestor) {\n    nodes.splice(k, 0, end);\n    end = end.parent;\n  }\n  return nodes;\n}\n\nfunction leastCommonAncestor(a, b) {\n  if (a === b) return a;\n  var aNodes = a.ancestors(),\n      bNodes = b.ancestors(),\n      c = null;\n  a = aNodes.pop();\n  b = bNodes.pop();\n  while (a === b) {\n    c = a;\n    a = aNodes.pop();\n    b = bNodes.pop();\n  }\n  return c;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/path.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/sort.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/sort.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(compare) {\n  return this.eachBefore(function(node) {\n    if (node.children) {\n      node.children.sort(compare);\n    }\n  });\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/sort.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/hierarchy/sum.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/hierarchy/sum.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(value) {\n  return this.eachAfter(function(node) {\n    var sum = +value(node.data) || 0,\n        children = node.children,\n        i = children && children.length;\n    while (--i >= 0) sum += children[i].value;\n    node.value = sum;\n  });\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/hierarchy/sum.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/lcg.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/lcg.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n// https://en.wikipedia.org/wiki/Linear_congruential_generator#Parameters_in_common_use\nconst a = 1664525;\nconst c = 1013904223;\nconst m = 4294967296; // 2^32\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  let s = 1;\n  return () => (s = (a * s + c) % m) / m;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/lcg.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/pack/enclose.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/pack/enclose.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   packEncloseRandom: () => (/* binding */ packEncloseRandom)\n/* harmony export */ });\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../array.js */ \"../../node_modules/d3-hierarchy/src/array.js\");\n/* harmony import */ var _lcg_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../lcg.js */ \"../../node_modules/d3-hierarchy/src/lcg.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(circles) {\n  return packEncloseRandom(circles, (0,_lcg_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])());\n}\n\nfunction packEncloseRandom(circles, random) {\n  var i = 0, n = (circles = (0,_array_js__WEBPACK_IMPORTED_MODULE_1__.shuffle)(Array.from(circles), random)).length, B = [], p, e;\n\n  while (i < n) {\n    p = circles[i];\n    if (e && enclosesWeak(e, p)) ++i;\n    else e = encloseBasis(B = extendBasis(B, p)), i = 0;\n  }\n\n  return e;\n}\n\nfunction extendBasis(B, p) {\n  var i, j;\n\n  if (enclosesWeakAll(p, B)) return [p];\n\n  // If we get here then B must have at least one element.\n  for (i = 0; i < B.length; ++i) {\n    if (enclosesNot(p, B[i])\n        && enclosesWeakAll(encloseBasis2(B[i], p), B)) {\n      return [B[i], p];\n    }\n  }\n\n  // If we get here then B must have at least two elements.\n  for (i = 0; i < B.length - 1; ++i) {\n    for (j = i + 1; j < B.length; ++j) {\n      if (enclosesNot(encloseBasis2(B[i], B[j]), p)\n          && enclosesNot(encloseBasis2(B[i], p), B[j])\n          && enclosesNot(encloseBasis2(B[j], p), B[i])\n          && enclosesWeakAll(encloseBasis3(B[i], B[j], p), B)) {\n        return [B[i], B[j], p];\n      }\n    }\n  }\n\n  // If we get here then something is very wrong.\n  throw new Error;\n}\n\nfunction enclosesNot(a, b) {\n  var dr = a.r - b.r, dx = b.x - a.x, dy = b.y - a.y;\n  return dr < 0 || dr * dr < dx * dx + dy * dy;\n}\n\nfunction enclosesWeak(a, b) {\n  var dr = a.r - b.r + Math.max(a.r, b.r, 1) * 1e-9, dx = b.x - a.x, dy = b.y - a.y;\n  return dr > 0 && dr * dr > dx * dx + dy * dy;\n}\n\nfunction enclosesWeakAll(a, B) {\n  for (var i = 0; i < B.length; ++i) {\n    if (!enclosesWeak(a, B[i])) {\n      return false;\n    }\n  }\n  return true;\n}\n\nfunction encloseBasis(B) {\n  switch (B.length) {\n    case 1: return encloseBasis1(B[0]);\n    case 2: return encloseBasis2(B[0], B[1]);\n    case 3: return encloseBasis3(B[0], B[1], B[2]);\n  }\n}\n\nfunction encloseBasis1(a) {\n  return {\n    x: a.x,\n    y: a.y,\n    r: a.r\n  };\n}\n\nfunction encloseBasis2(a, b) {\n  var x1 = a.x, y1 = a.y, r1 = a.r,\n      x2 = b.x, y2 = b.y, r2 = b.r,\n      x21 = x2 - x1, y21 = y2 - y1, r21 = r2 - r1,\n      l = Math.sqrt(x21 * x21 + y21 * y21);\n  return {\n    x: (x1 + x2 + x21 / l * r21) / 2,\n    y: (y1 + y2 + y21 / l * r21) / 2,\n    r: (l + r1 + r2) / 2\n  };\n}\n\nfunction encloseBasis3(a, b, c) {\n  var x1 = a.x, y1 = a.y, r1 = a.r,\n      x2 = b.x, y2 = b.y, r2 = b.r,\n      x3 = c.x, y3 = c.y, r3 = c.r,\n      a2 = x1 - x2,\n      a3 = x1 - x3,\n      b2 = y1 - y2,\n      b3 = y1 - y3,\n      c2 = r2 - r1,\n      c3 = r3 - r1,\n      d1 = x1 * x1 + y1 * y1 - r1 * r1,\n      d2 = d1 - x2 * x2 - y2 * y2 + r2 * r2,\n      d3 = d1 - x3 * x3 - y3 * y3 + r3 * r3,\n      ab = a3 * b2 - a2 * b3,\n      xa = (b2 * d3 - b3 * d2) / (ab * 2) - x1,\n      xb = (b3 * c2 - b2 * c3) / ab,\n      ya = (a3 * d2 - a2 * d3) / (ab * 2) - y1,\n      yb = (a2 * c3 - a3 * c2) / ab,\n      A = xb * xb + yb * yb - 1,\n      B = 2 * (r1 + xa * xb + ya * yb),\n      C = xa * xa + ya * ya - r1 * r1,\n      r = -(Math.abs(A) > 1e-6 ? (B + Math.sqrt(B * B - 4 * A * C)) / (2 * A) : C / B);\n  return {\n    x: x1 + xa + xb * r,\n    y: y1 + ya + yb * r,\n    r: r\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/pack/enclose.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/pack/index.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/pack/index.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _accessors_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../accessors.js */ \"../../node_modules/d3-hierarchy/src/accessors.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../constant.js */ \"../../node_modules/d3-hierarchy/src/constant.js\");\n/* harmony import */ var _lcg_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../lcg.js */ \"../../node_modules/d3-hierarchy/src/lcg.js\");\n/* harmony import */ var _siblings_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./siblings.js */ \"../../node_modules/d3-hierarchy/src/pack/siblings.js\");\n\n\n\n\n\nfunction defaultRadius(d) {\n  return Math.sqrt(d.value);\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var radius = null,\n      dx = 1,\n      dy = 1,\n      padding = _constant_js__WEBPACK_IMPORTED_MODULE_0__.constantZero;\n\n  function pack(root) {\n    const random = (0,_lcg_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])();\n    root.x = dx / 2, root.y = dy / 2;\n    if (radius) {\n      root.eachBefore(radiusLeaf(radius))\n          .eachAfter(packChildrenRandom(padding, 0.5, random))\n          .eachBefore(translateChild(1));\n    } else {\n      root.eachBefore(radiusLeaf(defaultRadius))\n          .eachAfter(packChildrenRandom(_constant_js__WEBPACK_IMPORTED_MODULE_0__.constantZero, 1, random))\n          .eachAfter(packChildrenRandom(padding, root.r / Math.min(dx, dy), random))\n          .eachBefore(translateChild(Math.min(dx, dy) / (2 * root.r)));\n    }\n    return root;\n  }\n\n  pack.radius = function(x) {\n    return arguments.length ? (radius = (0,_accessors_js__WEBPACK_IMPORTED_MODULE_2__.optional)(x), pack) : radius;\n  };\n\n  pack.size = function(x) {\n    return arguments.length ? (dx = +x[0], dy = +x[1], pack) : [dx, dy];\n  };\n\n  pack.padding = function(x) {\n    return arguments.length ? (padding = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+x), pack) : padding;\n  };\n\n  return pack;\n}\n\nfunction radiusLeaf(radius) {\n  return function(node) {\n    if (!node.children) {\n      node.r = Math.max(0, +radius(node) || 0);\n    }\n  };\n}\n\nfunction packChildrenRandom(padding, k, random) {\n  return function(node) {\n    if (children = node.children) {\n      var children,\n          i,\n          n = children.length,\n          r = padding(node) * k || 0,\n          e;\n\n      if (r) for (i = 0; i < n; ++i) children[i].r += r;\n      e = (0,_siblings_js__WEBPACK_IMPORTED_MODULE_3__.packSiblingsRandom)(children, random);\n      if (r) for (i = 0; i < n; ++i) children[i].r -= r;\n      node.r = e + r;\n    }\n  };\n}\n\nfunction translateChild(k) {\n  return function(node) {\n    var parent = node.parent;\n    node.r *= k;\n    if (parent) {\n      node.x = parent.x + k * node.x;\n      node.y = parent.y + k * node.y;\n    }\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/pack/index.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/pack/siblings.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/pack/siblings.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   packSiblingsRandom: () => (/* binding */ packSiblingsRandom)\n/* harmony export */ });\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../array.js */ \"../../node_modules/d3-hierarchy/src/array.js\");\n/* harmony import */ var _lcg_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../lcg.js */ \"../../node_modules/d3-hierarchy/src/lcg.js\");\n/* harmony import */ var _enclose_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./enclose.js */ \"../../node_modules/d3-hierarchy/src/pack/enclose.js\");\n\n\n\n\nfunction place(b, a, c) {\n  var dx = b.x - a.x, x, a2,\n      dy = b.y - a.y, y, b2,\n      d2 = dx * dx + dy * dy;\n  if (d2) {\n    a2 = a.r + c.r, a2 *= a2;\n    b2 = b.r + c.r, b2 *= b2;\n    if (a2 > b2) {\n      x = (d2 + b2 - a2) / (2 * d2);\n      y = Math.sqrt(Math.max(0, b2 / d2 - x * x));\n      c.x = b.x - x * dx - y * dy;\n      c.y = b.y - x * dy + y * dx;\n    } else {\n      x = (d2 + a2 - b2) / (2 * d2);\n      y = Math.sqrt(Math.max(0, a2 / d2 - x * x));\n      c.x = a.x + x * dx - y * dy;\n      c.y = a.y + x * dy + y * dx;\n    }\n  } else {\n    c.x = a.x + c.r;\n    c.y = a.y;\n  }\n}\n\nfunction intersects(a, b) {\n  var dr = a.r + b.r - 1e-6, dx = b.x - a.x, dy = b.y - a.y;\n  return dr > 0 && dr * dr > dx * dx + dy * dy;\n}\n\nfunction score(node) {\n  var a = node._,\n      b = node.next._,\n      ab = a.r + b.r,\n      dx = (a.x * b.r + b.x * a.r) / ab,\n      dy = (a.y * b.r + b.y * a.r) / ab;\n  return dx * dx + dy * dy;\n}\n\nfunction Node(circle) {\n  this._ = circle;\n  this.next = null;\n  this.previous = null;\n}\n\nfunction packSiblingsRandom(circles, random) {\n  if (!(n = (circles = (0,_array_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(circles)).length)) return 0;\n\n  var a, b, c, n, aa, ca, i, j, k, sj, sk;\n\n  // Place the first circle.\n  a = circles[0], a.x = 0, a.y = 0;\n  if (!(n > 1)) return a.r;\n\n  // Place the second circle.\n  b = circles[1], a.x = -b.r, b.x = a.r, b.y = 0;\n  if (!(n > 2)) return a.r + b.r;\n\n  // Place the third circle.\n  place(b, a, c = circles[2]);\n\n  // Initialize the front-chain using the first three circles a, b and c.\n  a = new Node(a), b = new Node(b), c = new Node(c);\n  a.next = c.previous = b;\n  b.next = a.previous = c;\n  c.next = b.previous = a;\n\n  // Attempt to place each remaining circle…\n  pack: for (i = 3; i < n; ++i) {\n    place(a._, b._, c = circles[i]), c = new Node(c);\n\n    // Find the closest intersecting circle on the front-chain, if any.\n    // “Closeness” is determined by linear distance along the front-chain.\n    // “Ahead” or “behind” is likewise determined by linear distance.\n    j = b.next, k = a.previous, sj = b._.r, sk = a._.r;\n    do {\n      if (sj <= sk) {\n        if (intersects(j._, c._)) {\n          b = j, a.next = b, b.previous = a, --i;\n          continue pack;\n        }\n        sj += j._.r, j = j.next;\n      } else {\n        if (intersects(k._, c._)) {\n          a = k, a.next = b, b.previous = a, --i;\n          continue pack;\n        }\n        sk += k._.r, k = k.previous;\n      }\n    } while (j !== k.next);\n\n    // Success! Insert the new circle c between a and b.\n    c.previous = a, c.next = b, a.next = b.previous = b = c;\n\n    // Compute the new closest circle pair to the centroid.\n    aa = score(a);\n    while ((c = c.next) !== b) {\n      if ((ca = score(c)) < aa) {\n        a = c, aa = ca;\n      }\n    }\n    b = a.next;\n  }\n\n  // Compute the enclosing circle of the front chain.\n  a = [b._], c = b; while ((c = c.next) !== b) a.push(c._); c = (0,_enclose_js__WEBPACK_IMPORTED_MODULE_1__.packEncloseRandom)(a, random);\n\n  // Translate the circles to put the enclosing circle around the origin.\n  for (i = 0; i < n; ++i) a = circles[i], a.x -= c.x, a.y -= c.y;\n\n  return c.r;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(circles) {\n  packSiblingsRandom(circles, (0,_lcg_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])());\n  return circles;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/pack/siblings.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/partition.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/partition.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _treemap_round_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./treemap/round.js */ \"../../node_modules/d3-hierarchy/src/treemap/round.js\");\n/* harmony import */ var _treemap_dice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./treemap/dice.js */ \"../../node_modules/d3-hierarchy/src/treemap/dice.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var dx = 1,\n      dy = 1,\n      padding = 0,\n      round = false;\n\n  function partition(root) {\n    var n = root.height + 1;\n    root.x0 =\n    root.y0 = padding;\n    root.x1 = dx;\n    root.y1 = dy / n;\n    root.eachBefore(positionNode(dy, n));\n    if (round) root.eachBefore(_treemap_round_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n    return root;\n  }\n\n  function positionNode(dy, n) {\n    return function(node) {\n      if (node.children) {\n        (0,_treemap_dice_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(node, node.x0, dy * (node.depth + 1) / n, node.x1, dy * (node.depth + 2) / n);\n      }\n      var x0 = node.x0,\n          y0 = node.y0,\n          x1 = node.x1 - padding,\n          y1 = node.y1 - padding;\n      if (x1 < x0) x0 = x1 = (x0 + x1) / 2;\n      if (y1 < y0) y0 = y1 = (y0 + y1) / 2;\n      node.x0 = x0;\n      node.y0 = y0;\n      node.x1 = x1;\n      node.y1 = y1;\n    };\n  }\n\n  partition.round = function(x) {\n    return arguments.length ? (round = !!x, partition) : round;\n  };\n\n  partition.size = function(x) {\n    return arguments.length ? (dx = +x[0], dy = +x[1], partition) : [dx, dy];\n  };\n\n  partition.padding = function(x) {\n    return arguments.length ? (padding = +x, partition) : padding;\n  };\n\n  return partition;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/partition.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/stratify.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/stratify.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _accessors_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./accessors.js */ \"../../node_modules/d3-hierarchy/src/accessors.js\");\n/* harmony import */ var _hierarchy_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./hierarchy/index.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/index.js\");\n\n\n\nvar preroot = {depth: -1},\n    ambiguous = {},\n    imputed = {};\n\nfunction defaultId(d) {\n  return d.id;\n}\n\nfunction defaultParentId(d) {\n  return d.parentId;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var id = defaultId,\n      parentId = defaultParentId,\n      path;\n\n  function stratify(data) {\n    var nodes = Array.from(data),\n        currentId = id,\n        currentParentId = parentId,\n        n,\n        d,\n        i,\n        root,\n        parent,\n        node,\n        nodeId,\n        nodeKey,\n        nodeByKey = new Map;\n\n    if (path != null) {\n      const I = nodes.map((d, i) => normalize(path(d, i, data)));\n      const P = I.map(parentof);\n      const S = new Set(I).add(\"\");\n      for (const i of P) {\n        if (!S.has(i)) {\n          S.add(i);\n          I.push(i);\n          P.push(parentof(i));\n          nodes.push(imputed);\n        }\n      }\n      currentId = (_, i) => I[i];\n      currentParentId = (_, i) => P[i];\n    }\n\n    for (i = 0, n = nodes.length; i < n; ++i) {\n      d = nodes[i], node = nodes[i] = new _hierarchy_index_js__WEBPACK_IMPORTED_MODULE_0__.Node(d);\n      if ((nodeId = currentId(d, i, data)) != null && (nodeId += \"\")) {\n        nodeKey = node.id = nodeId;\n        nodeByKey.set(nodeKey, nodeByKey.has(nodeKey) ? ambiguous : node);\n      }\n      if ((nodeId = currentParentId(d, i, data)) != null && (nodeId += \"\")) {\n        node.parent = nodeId;\n      }\n    }\n\n    for (i = 0; i < n; ++i) {\n      node = nodes[i];\n      if (nodeId = node.parent) {\n        parent = nodeByKey.get(nodeId);\n        if (!parent) throw new Error(\"missing: \" + nodeId);\n        if (parent === ambiguous) throw new Error(\"ambiguous: \" + nodeId);\n        if (parent.children) parent.children.push(node);\n        else parent.children = [node];\n        node.parent = parent;\n      } else {\n        if (root) throw new Error(\"multiple roots\");\n        root = node;\n      }\n    }\n\n    if (!root) throw new Error(\"no root\");\n\n    // When imputing internal nodes, only introduce roots if needed.\n    // Then replace the imputed marker data with null.\n    if (path != null) {\n      while (root.data === imputed && root.children.length === 1) {\n        root = root.children[0], --n;\n      }\n      for (let i = nodes.length - 1; i >= 0; --i) {\n        node = nodes[i];\n        if (node.data !== imputed) break;\n        node.data = null;\n      }\n    }\n\n    root.parent = preroot;\n    root.eachBefore(function(node) { node.depth = node.parent.depth + 1; --n; }).eachBefore(_hierarchy_index_js__WEBPACK_IMPORTED_MODULE_0__.computeHeight);\n    root.parent = null;\n    if (n > 0) throw new Error(\"cycle\");\n\n    return root;\n  }\n\n  stratify.id = function(x) {\n    return arguments.length ? (id = (0,_accessors_js__WEBPACK_IMPORTED_MODULE_1__.optional)(x), stratify) : id;\n  };\n\n  stratify.parentId = function(x) {\n    return arguments.length ? (parentId = (0,_accessors_js__WEBPACK_IMPORTED_MODULE_1__.optional)(x), stratify) : parentId;\n  };\n\n  stratify.path = function(x) {\n    return arguments.length ? (path = (0,_accessors_js__WEBPACK_IMPORTED_MODULE_1__.optional)(x), stratify) : path;\n  };\n\n  return stratify;\n}\n\n// To normalize a path, we coerce to a string, strip the trailing slash if any\n// (as long as the trailing slash is not immediately preceded by another slash),\n// and add leading slash if missing.\nfunction normalize(path) {\n  path = `${path}`;\n  let i = path.length;\n  if (slash(path, i - 1) && !slash(path, i - 2)) path = path.slice(0, -1);\n  return path[0] === \"/\" ? path : `/${path}`;\n}\n\n// Walk backwards to find the first slash that is not the leading slash, e.g.:\n// \"/foo/bar\" ⇥ \"/foo\", \"/foo\" ⇥ \"/\", \"/\" ↦ \"\". (The root is special-cased\n// because the id of the root must be a truthy value.)\nfunction parentof(path) {\n  let i = path.length;\n  if (i < 2) return \"\";\n  while (--i > 1) if (slash(path, i)) break;\n  return path.slice(0, i);\n}\n\n// Slashes can be escaped; to determine whether a slash is a path delimiter, we\n// count the number of preceding backslashes escaping the forward slash: an odd\n// number indicates an escaped forward slash.\nfunction slash(path, i) {\n  if (path[i] === \"/\") {\n    let k = 0;\n    while (i > 0 && path[--i] === \"\\\\\") ++k;\n    if ((k & 1) === 0) return true;\n  }\n  return false;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/stratify.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/tree.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/tree.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _hierarchy_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./hierarchy/index.js */ \"../../node_modules/d3-hierarchy/src/hierarchy/index.js\");\n\n\nfunction defaultSeparation(a, b) {\n  return a.parent === b.parent ? 1 : 2;\n}\n\n// function radialSeparation(a, b) {\n//   return (a.parent === b.parent ? 1 : 2) / a.depth;\n// }\n\n// This function is used to traverse the left contour of a subtree (or\n// subforest). It returns the successor of v on this contour. This successor is\n// either given by the leftmost child of v or by the thread of v. The function\n// returns null if and only if v is on the highest level of its subtree.\nfunction nextLeft(v) {\n  var children = v.children;\n  return children ? children[0] : v.t;\n}\n\n// This function works analogously to nextLeft.\nfunction nextRight(v) {\n  var children = v.children;\n  return children ? children[children.length - 1] : v.t;\n}\n\n// Shifts the current subtree rooted at w+. This is done by increasing\n// prelim(w+) and mod(w+) by shift.\nfunction moveSubtree(wm, wp, shift) {\n  var change = shift / (wp.i - wm.i);\n  wp.c -= change;\n  wp.s += shift;\n  wm.c += change;\n  wp.z += shift;\n  wp.m += shift;\n}\n\n// All other shifts, applied to the smaller subtrees between w- and w+, are\n// performed by this function. To prepare the shifts, we have to adjust\n// change(w+), shift(w+), and change(w-).\nfunction executeShifts(v) {\n  var shift = 0,\n      change = 0,\n      children = v.children,\n      i = children.length,\n      w;\n  while (--i >= 0) {\n    w = children[i];\n    w.z += shift;\n    w.m += shift;\n    shift += w.s + (change += w.c);\n  }\n}\n\n// If vi-’s ancestor is a sibling of v, returns vi-’s ancestor. Otherwise,\n// returns the specified (default) ancestor.\nfunction nextAncestor(vim, v, ancestor) {\n  return vim.a.parent === v.parent ? vim.a : ancestor;\n}\n\nfunction TreeNode(node, i) {\n  this._ = node;\n  this.parent = null;\n  this.children = null;\n  this.A = null; // default ancestor\n  this.a = this; // ancestor\n  this.z = 0; // prelim\n  this.m = 0; // mod\n  this.c = 0; // change\n  this.s = 0; // shift\n  this.t = null; // thread\n  this.i = i; // number\n}\n\nTreeNode.prototype = Object.create(_hierarchy_index_js__WEBPACK_IMPORTED_MODULE_0__.Node.prototype);\n\nfunction treeRoot(root) {\n  var tree = new TreeNode(root, 0),\n      node,\n      nodes = [tree],\n      child,\n      children,\n      i,\n      n;\n\n  while (node = nodes.pop()) {\n    if (children = node._.children) {\n      node.children = new Array(n = children.length);\n      for (i = n - 1; i >= 0; --i) {\n        nodes.push(child = node.children[i] = new TreeNode(children[i], i));\n        child.parent = node;\n      }\n    }\n  }\n\n  (tree.parent = new TreeNode(null, 0)).children = [tree];\n  return tree;\n}\n\n// Node-link tree diagram using the Reingold-Tilford \"tidy\" algorithm\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var separation = defaultSeparation,\n      dx = 1,\n      dy = 1,\n      nodeSize = null;\n\n  function tree(root) {\n    var t = treeRoot(root);\n\n    // Compute the layout using Buchheim et al.’s algorithm.\n    t.eachAfter(firstWalk), t.parent.m = -t.z;\n    t.eachBefore(secondWalk);\n\n    // If a fixed node size is specified, scale x and y.\n    if (nodeSize) root.eachBefore(sizeNode);\n\n    // If a fixed tree size is specified, scale x and y based on the extent.\n    // Compute the left-most, right-most, and depth-most nodes for extents.\n    else {\n      var left = root,\n          right = root,\n          bottom = root;\n      root.eachBefore(function(node) {\n        if (node.x < left.x) left = node;\n        if (node.x > right.x) right = node;\n        if (node.depth > bottom.depth) bottom = node;\n      });\n      var s = left === right ? 1 : separation(left, right) / 2,\n          tx = s - left.x,\n          kx = dx / (right.x + s + tx),\n          ky = dy / (bottom.depth || 1);\n      root.eachBefore(function(node) {\n        node.x = (node.x + tx) * kx;\n        node.y = node.depth * ky;\n      });\n    }\n\n    return root;\n  }\n\n  // Computes a preliminary x-coordinate for v. Before that, FIRST WALK is\n  // applied recursively to the children of v, as well as the function\n  // APPORTION. After spacing out the children by calling EXECUTE SHIFTS, the\n  // node v is placed to the midpoint of its outermost children.\n  function firstWalk(v) {\n    var children = v.children,\n        siblings = v.parent.children,\n        w = v.i ? siblings[v.i - 1] : null;\n    if (children) {\n      executeShifts(v);\n      var midpoint = (children[0].z + children[children.length - 1].z) / 2;\n      if (w) {\n        v.z = w.z + separation(v._, w._);\n        v.m = v.z - midpoint;\n      } else {\n        v.z = midpoint;\n      }\n    } else if (w) {\n      v.z = w.z + separation(v._, w._);\n    }\n    v.parent.A = apportion(v, w, v.parent.A || siblings[0]);\n  }\n\n  // Computes all real x-coordinates by summing up the modifiers recursively.\n  function secondWalk(v) {\n    v._.x = v.z + v.parent.m;\n    v.m += v.parent.m;\n  }\n\n  // The core of the algorithm. Here, a new subtree is combined with the\n  // previous subtrees. Threads are used to traverse the inside and outside\n  // contours of the left and right subtree up to the highest common level. The\n  // vertices used for the traversals are vi+, vi-, vo-, and vo+, where the\n  // superscript o means outside and i means inside, the subscript - means left\n  // subtree and + means right subtree. For summing up the modifiers along the\n  // contour, we use respective variables si+, si-, so-, and so+. Whenever two\n  // nodes of the inside contours conflict, we compute the left one of the\n  // greatest uncommon ancestors using the function ANCESTOR and call MOVE\n  // SUBTREE to shift the subtree and prepare the shifts of smaller subtrees.\n  // Finally, we add a new thread (if necessary).\n  function apportion(v, w, ancestor) {\n    if (w) {\n      var vip = v,\n          vop = v,\n          vim = w,\n          vom = vip.parent.children[0],\n          sip = vip.m,\n          sop = vop.m,\n          sim = vim.m,\n          som = vom.m,\n          shift;\n      while (vim = nextRight(vim), vip = nextLeft(vip), vim && vip) {\n        vom = nextLeft(vom);\n        vop = nextRight(vop);\n        vop.a = v;\n        shift = vim.z + sim - vip.z - sip + separation(vim._, vip._);\n        if (shift > 0) {\n          moveSubtree(nextAncestor(vim, v, ancestor), v, shift);\n          sip += shift;\n          sop += shift;\n        }\n        sim += vim.m;\n        sip += vip.m;\n        som += vom.m;\n        sop += vop.m;\n      }\n      if (vim && !nextRight(vop)) {\n        vop.t = vim;\n        vop.m += sim - sop;\n      }\n      if (vip && !nextLeft(vom)) {\n        vom.t = vip;\n        vom.m += sip - som;\n        ancestor = v;\n      }\n    }\n    return ancestor;\n  }\n\n  function sizeNode(node) {\n    node.x *= dx;\n    node.y = node.depth * dy;\n  }\n\n  tree.separation = function(x) {\n    return arguments.length ? (separation = x, tree) : separation;\n  };\n\n  tree.size = function(x) {\n    return arguments.length ? (nodeSize = false, dx = +x[0], dy = +x[1], tree) : (nodeSize ? null : [dx, dy]);\n  };\n\n  tree.nodeSize = function(x) {\n    return arguments.length ? (nodeSize = true, dx = +x[0], dy = +x[1], tree) : (nodeSize ? [dx, dy] : null);\n  };\n\n  return tree;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/tree.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/binary.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/binary.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(parent, x0, y0, x1, y1) {\n  var nodes = parent.children,\n      i, n = nodes.length,\n      sum, sums = new Array(n + 1);\n\n  for (sums[0] = sum = i = 0; i < n; ++i) {\n    sums[i + 1] = sum += nodes[i].value;\n  }\n\n  partition(0, n, parent.value, x0, y0, x1, y1);\n\n  function partition(i, j, value, x0, y0, x1, y1) {\n    if (i >= j - 1) {\n      var node = nodes[i];\n      node.x0 = x0, node.y0 = y0;\n      node.x1 = x1, node.y1 = y1;\n      return;\n    }\n\n    var valueOffset = sums[i],\n        valueTarget = (value / 2) + valueOffset,\n        k = i + 1,\n        hi = j - 1;\n\n    while (k < hi) {\n      var mid = k + hi >>> 1;\n      if (sums[mid] < valueTarget) k = mid + 1;\n      else hi = mid;\n    }\n\n    if ((valueTarget - sums[k - 1]) < (sums[k] - valueTarget) && i + 1 < k) --k;\n\n    var valueLeft = sums[k] - valueOffset,\n        valueRight = value - valueLeft;\n\n    if ((x1 - x0) > (y1 - y0)) {\n      var xk = value ? (x0 * valueRight + x1 * valueLeft) / value : x1;\n      partition(i, k, valueLeft, x0, y0, xk, y1);\n      partition(k, j, valueRight, xk, y0, x1, y1);\n    } else {\n      var yk = value ? (y0 * valueRight + y1 * valueLeft) / value : y1;\n      partition(i, k, valueLeft, x0, y0, x1, yk);\n      partition(k, j, valueRight, x0, yk, x1, y1);\n    }\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/binary.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/dice.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/dice.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(parent, x0, y0, x1, y1) {\n  var nodes = parent.children,\n      node,\n      i = -1,\n      n = nodes.length,\n      k = parent.value && (x1 - x0) / parent.value;\n\n  while (++i < n) {\n    node = nodes[i], node.y0 = y0, node.y1 = y1;\n    node.x0 = x0, node.x1 = x0 += node.value * k;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/dice.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/index.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/index.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _round_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./round.js */ \"../../node_modules/d3-hierarchy/src/treemap/round.js\");\n/* harmony import */ var _squarify_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./squarify.js */ \"../../node_modules/d3-hierarchy/src/treemap/squarify.js\");\n/* harmony import */ var _accessors_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../accessors.js */ \"../../node_modules/d3-hierarchy/src/accessors.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../constant.js */ \"../../node_modules/d3-hierarchy/src/constant.js\");\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var tile = _squarify_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n      round = false,\n      dx = 1,\n      dy = 1,\n      paddingStack = [0],\n      paddingInner = _constant_js__WEBPACK_IMPORTED_MODULE_1__.constantZero,\n      paddingTop = _constant_js__WEBPACK_IMPORTED_MODULE_1__.constantZero,\n      paddingRight = _constant_js__WEBPACK_IMPORTED_MODULE_1__.constantZero,\n      paddingBottom = _constant_js__WEBPACK_IMPORTED_MODULE_1__.constantZero,\n      paddingLeft = _constant_js__WEBPACK_IMPORTED_MODULE_1__.constantZero;\n\n  function treemap(root) {\n    root.x0 =\n    root.y0 = 0;\n    root.x1 = dx;\n    root.y1 = dy;\n    root.eachBefore(positionNode);\n    paddingStack = [0];\n    if (round) root.eachBefore(_round_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]);\n    return root;\n  }\n\n  function positionNode(node) {\n    var p = paddingStack[node.depth],\n        x0 = node.x0 + p,\n        y0 = node.y0 + p,\n        x1 = node.x1 - p,\n        y1 = node.y1 - p;\n    if (x1 < x0) x0 = x1 = (x0 + x1) / 2;\n    if (y1 < y0) y0 = y1 = (y0 + y1) / 2;\n    node.x0 = x0;\n    node.y0 = y0;\n    node.x1 = x1;\n    node.y1 = y1;\n    if (node.children) {\n      p = paddingStack[node.depth + 1] = paddingInner(node) / 2;\n      x0 += paddingLeft(node) - p;\n      y0 += paddingTop(node) - p;\n      x1 -= paddingRight(node) - p;\n      y1 -= paddingBottom(node) - p;\n      if (x1 < x0) x0 = x1 = (x0 + x1) / 2;\n      if (y1 < y0) y0 = y1 = (y0 + y1) / 2;\n      tile(node, x0, y0, x1, y1);\n    }\n  }\n\n  treemap.round = function(x) {\n    return arguments.length ? (round = !!x, treemap) : round;\n  };\n\n  treemap.size = function(x) {\n    return arguments.length ? (dx = +x[0], dy = +x[1], treemap) : [dx, dy];\n  };\n\n  treemap.tile = function(x) {\n    return arguments.length ? (tile = (0,_accessors_js__WEBPACK_IMPORTED_MODULE_3__.required)(x), treemap) : tile;\n  };\n\n  treemap.padding = function(x) {\n    return arguments.length ? treemap.paddingInner(x).paddingOuter(x) : treemap.paddingInner();\n  };\n\n  treemap.paddingInner = function(x) {\n    return arguments.length ? (paddingInner = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+x), treemap) : paddingInner;\n  };\n\n  treemap.paddingOuter = function(x) {\n    return arguments.length ? treemap.paddingTop(x).paddingRight(x).paddingBottom(x).paddingLeft(x) : treemap.paddingTop();\n  };\n\n  treemap.paddingTop = function(x) {\n    return arguments.length ? (paddingTop = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+x), treemap) : paddingTop;\n  };\n\n  treemap.paddingRight = function(x) {\n    return arguments.length ? (paddingRight = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+x), treemap) : paddingRight;\n  };\n\n  treemap.paddingBottom = function(x) {\n    return arguments.length ? (paddingBottom = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+x), treemap) : paddingBottom;\n  };\n\n  treemap.paddingLeft = function(x) {\n    return arguments.length ? (paddingLeft = typeof x === \"function\" ? x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+x), treemap) : paddingLeft;\n  };\n\n  return treemap;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/index.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/resquarify.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/resquarify.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _dice_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dice.js */ \"../../node_modules/d3-hierarchy/src/treemap/dice.js\");\n/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./slice.js */ \"../../node_modules/d3-hierarchy/src/treemap/slice.js\");\n/* harmony import */ var _squarify_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./squarify.js */ \"../../node_modules/d3-hierarchy/src/treemap/squarify.js\");\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(ratio) {\n\n  function resquarify(parent, x0, y0, x1, y1) {\n    if ((rows = parent._squarify) && (rows.ratio === ratio)) {\n      var rows,\n          row,\n          nodes,\n          i,\n          j = -1,\n          n,\n          m = rows.length,\n          value = parent.value;\n\n      while (++j < m) {\n        row = rows[j], nodes = row.children;\n        for (i = row.value = 0, n = nodes.length; i < n; ++i) row.value += nodes[i].value;\n        if (row.dice) (0,_dice_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(row, x0, y0, x1, value ? y0 += (y1 - y0) * row.value / value : y1);\n        else (0,_slice_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(row, x0, y0, value ? x0 += (x1 - x0) * row.value / value : x1, y1);\n        value -= row.value;\n      }\n    } else {\n      parent._squarify = rows = (0,_squarify_js__WEBPACK_IMPORTED_MODULE_2__.squarifyRatio)(ratio, parent, x0, y0, x1, y1);\n      rows.ratio = ratio;\n    }\n  }\n\n  resquarify.ratio = function(x) {\n    return custom((x = +x) > 1 ? x : 1);\n  };\n\n  return resquarify;\n})(_squarify_js__WEBPACK_IMPORTED_MODULE_2__.phi));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/resquarify.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/round.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/round.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(node) {\n  node.x0 = Math.round(node.x0);\n  node.y0 = Math.round(node.y0);\n  node.x1 = Math.round(node.x1);\n  node.y1 = Math.round(node.y1);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/round.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/slice.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/slice.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(parent, x0, y0, x1, y1) {\n  var nodes = parent.children,\n      node,\n      i = -1,\n      n = nodes.length,\n      k = parent.value && (y1 - y0) / parent.value;\n\n  while (++i < n) {\n    node = nodes[i], node.x0 = x0, node.x1 = x1;\n    node.y0 = y0, node.y1 = y0 += node.value * k;\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/slice.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/sliceDice.js":
/*!****************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/sliceDice.js ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _dice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dice.js */ \"../../node_modules/d3-hierarchy/src/treemap/dice.js\");\n/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./slice.js */ \"../../node_modules/d3-hierarchy/src/treemap/slice.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(parent, x0, y0, x1, y1) {\n  (parent.depth & 1 ? _slice_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : _dice_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(parent, x0, y0, x1, y1);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/sliceDice.js?");

/***/ }),

/***/ "../../node_modules/d3-hierarchy/src/treemap/squarify.js":
/*!***************************************************************!*\
  !*** ../../node_modules/d3-hierarchy/src/treemap/squarify.js ***!
  \***************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   phi: () => (/* binding */ phi),\n/* harmony export */   squarifyRatio: () => (/* binding */ squarifyRatio)\n/* harmony export */ });\n/* harmony import */ var _dice_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dice.js */ \"../../node_modules/d3-hierarchy/src/treemap/dice.js\");\n/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./slice.js */ \"../../node_modules/d3-hierarchy/src/treemap/slice.js\");\n\n\n\nvar phi = (1 + Math.sqrt(5)) / 2;\n\nfunction squarifyRatio(ratio, parent, x0, y0, x1, y1) {\n  var rows = [],\n      nodes = parent.children,\n      row,\n      nodeValue,\n      i0 = 0,\n      i1 = 0,\n      n = nodes.length,\n      dx, dy,\n      value = parent.value,\n      sumValue,\n      minValue,\n      maxValue,\n      newRatio,\n      minRatio,\n      alpha,\n      beta;\n\n  while (i0 < n) {\n    dx = x1 - x0, dy = y1 - y0;\n\n    // Find the next non-empty node.\n    do sumValue = nodes[i1++].value; while (!sumValue && i1 < n);\n    minValue = maxValue = sumValue;\n    alpha = Math.max(dy / dx, dx / dy) / (value * ratio);\n    beta = sumValue * sumValue * alpha;\n    minRatio = Math.max(maxValue / beta, beta / minValue);\n\n    // Keep adding nodes while the aspect ratio maintains or improves.\n    for (; i1 < n; ++i1) {\n      sumValue += nodeValue = nodes[i1].value;\n      if (nodeValue < minValue) minValue = nodeValue;\n      if (nodeValue > maxValue) maxValue = nodeValue;\n      beta = sumValue * sumValue * alpha;\n      newRatio = Math.max(maxValue / beta, beta / minValue);\n      if (newRatio > minRatio) { sumValue -= nodeValue; break; }\n      minRatio = newRatio;\n    }\n\n    // Position and record the row orientation.\n    rows.push(row = {value: sumValue, dice: dx < dy, children: nodes.slice(i0, i1)});\n    if (row.dice) (0,_dice_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(row, x0, y0, x1, value ? y0 += dy * sumValue / value : y1);\n    else (0,_slice_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(row, x0, y0, value ? x0 += dx * sumValue / value : x1, y1);\n    value -= sumValue, i0 = i1;\n  }\n\n  return rows;\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(ratio) {\n\n  function squarify(parent, x0, y0, x1, y1) {\n    squarifyRatio(ratio, parent, x0, y0, x1, y1);\n  }\n\n  squarify.ratio = function(x) {\n    return custom((x = +x) > 1 ? x : 1);\n  };\n\n  return squarify;\n})(phi));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-hierarchy/src/treemap/squarify.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/array.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/array.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   genericArray: () => (/* binding */ genericArray)\n/* harmony export */ });\n/* harmony import */ var _value_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./value.js */ \"../../node_modules/d3-interpolate/src/value.js\");\n/* harmony import */ var _numberArray_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./numberArray.js */ \"../../node_modules/d3-interpolate/src/numberArray.js\");\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  return ((0,_numberArray_js__WEBPACK_IMPORTED_MODULE_0__.isNumberArray)(b) ? _numberArray_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] : genericArray)(a, b);\n}\n\nfunction genericArray(a, b) {\n  var nb = b ? b.length : 0,\n      na = a ? Math.min(nb, a.length) : 0,\n      x = new Array(na),\n      c = new Array(nb),\n      i;\n\n  for (i = 0; i < na; ++i) x[i] = (0,_value_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(a[i], b[i]);\n  for (; i < nb; ++i) c[i] = b[i];\n\n  return function(t) {\n    for (i = 0; i < na; ++i) c[i] = x[i](t);\n    return c;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/array.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/basis.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/basis.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   basis: () => (/* binding */ basis),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction basis(t1, v0, v1, v2, v3) {\n  var t2 = t1 * t1, t3 = t2 * t1;\n  return ((1 - 3 * t1 + 3 * t2 - t3) * v0\n      + (4 - 6 * t2 + 3 * t3) * v1\n      + (1 + 3 * t1 + 3 * t2 - 3 * t3) * v2\n      + t3 * v3) / 6;\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values) {\n  var n = values.length - 1;\n  return function(t) {\n    var i = t <= 0 ? (t = 0) : t >= 1 ? (t = 1, n - 1) : Math.floor(t * n),\n        v1 = values[i],\n        v2 = values[i + 1],\n        v0 = i > 0 ? values[i - 1] : 2 * v1 - v2,\n        v3 = i < n - 1 ? values[i + 2] : 2 * v2 - v1;\n    return basis((t - i / n) * n, v0, v1, v2, v3);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/basis.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/basisClosed.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/basisClosed.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-interpolate/src/basis.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(values) {\n  var n = values.length;\n  return function(t) {\n    var i = Math.floor(((t %= 1) < 0 ? ++t : t) * n),\n        v0 = values[(i + n - 1) % n],\n        v1 = values[i % n],\n        v2 = values[(i + 1) % n],\n        v3 = values[(i + 2) % n];\n    return (0,_basis_js__WEBPACK_IMPORTED_MODULE_0__.basis)((t - i / n) * n, v0, v1, v2, v3);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/basisClosed.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/color.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/color.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ nogamma),\n/* harmony export */   gamma: () => (/* binding */ gamma),\n/* harmony export */   hue: () => (/* binding */ hue)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-interpolate/src/constant.js\");\n\n\nfunction linear(a, d) {\n  return function(t) {\n    return a + t * d;\n  };\n}\n\nfunction exponential(a, b, y) {\n  return a = Math.pow(a, y), b = Math.pow(b, y) - a, y = 1 / y, function(t) {\n    return Math.pow(a + t * b, y);\n  };\n}\n\nfunction hue(a, b) {\n  var d = b - a;\n  return d ? linear(a, d > 180 || d < -180 ? d - 360 * Math.round(d / 360) : d) : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(isNaN(a) ? b : a);\n}\n\nfunction gamma(y) {\n  return (y = +y) === 1 ? nogamma : function(a, b) {\n    return b - a ? exponential(a, b, y) : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(isNaN(a) ? b : a);\n  };\n}\n\nfunction nogamma(a, b) {\n  var d = b - a;\n  return d ? linear(a, d) : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(isNaN(a) ? b : a);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/color.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/constant.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/constant.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (x => () => x);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/cubehelix.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/cubehelix.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   cubehelixLong: () => (/* binding */ cubehelixLong),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/cubehelix.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n\nfunction cubehelix(hue) {\n  return (function cubehelixGamma(y) {\n    y = +y;\n\n    function cubehelix(start, end) {\n      var h = hue((start = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(start)).h, (end = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(end)).h),\n          s = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.s, end.s),\n          l = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.l, end.l),\n          opacity = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.opacity, end.opacity);\n      return function(t) {\n        start.h = h(t);\n        start.s = s(t);\n        start.l = l(Math.pow(t, y));\n        start.opacity = opacity(t);\n        return start + \"\";\n      };\n    }\n\n    cubehelix.gamma = cubehelixGamma;\n\n    return cubehelix;\n  })(1);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (cubehelix(_color_js__WEBPACK_IMPORTED_MODULE_1__.hue));\nvar cubehelixLong = cubehelix(_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/cubehelix.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/date.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/date.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  var d = new Date;\n  return a = +a, b = +b, function(t) {\n    return d.setTime(a * (1 - t) + b * t), d;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/date.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/discrete.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/discrete.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(range) {\n  var n = range.length;\n  return function(t) {\n    return range[Math.max(0, Math.min(n - 1, Math.floor(t * n)))];\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/discrete.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/hcl.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/hcl.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   hclLong: () => (/* binding */ hclLong)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/lab.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n\nfunction hcl(hue) {\n  return function(start, end) {\n    var h = hue((start = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__.hcl)(start)).h, (end = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__.hcl)(end)).h),\n        c = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.c, end.c),\n        l = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.l, end.l),\n        opacity = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.opacity, end.opacity);\n    return function(t) {\n      start.h = h(t);\n      start.c = c(t);\n      start.l = l(t);\n      start.opacity = opacity(t);\n      return start + \"\";\n    };\n  }\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (hcl(_color_js__WEBPACK_IMPORTED_MODULE_1__.hue));\nvar hclLong = hcl(_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/hcl.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/hsl.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/hsl.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   hslLong: () => (/* binding */ hslLong)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n\nfunction hsl(hue) {\n  return function(start, end) {\n    var h = hue((start = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__.hsl)(start)).h, (end = (0,d3_color__WEBPACK_IMPORTED_MODULE_0__.hsl)(end)).h),\n        s = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.s, end.s),\n        l = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.l, end.l),\n        opacity = (0,_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start.opacity, end.opacity);\n    return function(t) {\n      start.h = h(t);\n      start.s = s(t);\n      start.l = l(t);\n      start.opacity = opacity(t);\n      return start + \"\";\n    };\n  }\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (hsl(_color_js__WEBPACK_IMPORTED_MODULE_1__.hue));\nvar hslLong = hsl(_color_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/hsl.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/hue.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/hue.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  var i = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__.hue)(+a, +b);\n  return function(t) {\n    var x = i(t);\n    return x - 360 * Math.floor(x / 360);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/hue.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/index.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/index.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   interpolate: () => (/* reexport safe */ _value_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]),\n/* harmony export */   interpolateArray: () => (/* reexport safe */ _array_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]),\n/* harmony export */   interpolateBasis: () => (/* reexport safe */ _basis_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]),\n/* harmony export */   interpolateBasisClosed: () => (/* reexport safe */ _basisClosed_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]),\n/* harmony export */   interpolateCubehelix: () => (/* reexport safe */ _cubehelix_js__WEBPACK_IMPORTED_MODULE_18__[\"default\"]),\n/* harmony export */   interpolateCubehelixLong: () => (/* reexport safe */ _cubehelix_js__WEBPACK_IMPORTED_MODULE_18__.cubehelixLong),\n/* harmony export */   interpolateDate: () => (/* reexport safe */ _date_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"]),\n/* harmony export */   interpolateDiscrete: () => (/* reexport safe */ _discrete_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"]),\n/* harmony export */   interpolateHcl: () => (/* reexport safe */ _hcl_js__WEBPACK_IMPORTED_MODULE_17__[\"default\"]),\n/* harmony export */   interpolateHclLong: () => (/* reexport safe */ _hcl_js__WEBPACK_IMPORTED_MODULE_17__.hclLong),\n/* harmony export */   interpolateHsl: () => (/* reexport safe */ _hsl_js__WEBPACK_IMPORTED_MODULE_15__[\"default\"]),\n/* harmony export */   interpolateHslLong: () => (/* reexport safe */ _hsl_js__WEBPACK_IMPORTED_MODULE_15__.hslLong),\n/* harmony export */   interpolateHue: () => (/* reexport safe */ _hue_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"]),\n/* harmony export */   interpolateLab: () => (/* reexport safe */ _lab_js__WEBPACK_IMPORTED_MODULE_16__[\"default\"]),\n/* harmony export */   interpolateNumber: () => (/* reexport safe */ _number_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"]),\n/* harmony export */   interpolateNumberArray: () => (/* reexport safe */ _numberArray_js__WEBPACK_IMPORTED_MODULE_8__[\"default\"]),\n/* harmony export */   interpolateObject: () => (/* reexport safe */ _object_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"]),\n/* harmony export */   interpolateRgb: () => (/* reexport safe */ _rgb_js__WEBPACK_IMPORTED_MODULE_14__[\"default\"]),\n/* harmony export */   interpolateRgbBasis: () => (/* reexport safe */ _rgb_js__WEBPACK_IMPORTED_MODULE_14__.rgbBasis),\n/* harmony export */   interpolateRgbBasisClosed: () => (/* reexport safe */ _rgb_js__WEBPACK_IMPORTED_MODULE_14__.rgbBasisClosed),\n/* harmony export */   interpolateRound: () => (/* reexport safe */ _round_js__WEBPACK_IMPORTED_MODULE_10__[\"default\"]),\n/* harmony export */   interpolateString: () => (/* reexport safe */ _string_js__WEBPACK_IMPORTED_MODULE_11__[\"default\"]),\n/* harmony export */   interpolateTransformCss: () => (/* reexport safe */ _transform_index_js__WEBPACK_IMPORTED_MODULE_12__.interpolateTransformCss),\n/* harmony export */   interpolateTransformSvg: () => (/* reexport safe */ _transform_index_js__WEBPACK_IMPORTED_MODULE_12__.interpolateTransformSvg),\n/* harmony export */   interpolateZoom: () => (/* reexport safe */ _zoom_js__WEBPACK_IMPORTED_MODULE_13__[\"default\"]),\n/* harmony export */   piecewise: () => (/* reexport safe */ _piecewise_js__WEBPACK_IMPORTED_MODULE_19__[\"default\"]),\n/* harmony export */   quantize: () => (/* reexport safe */ _quantize_js__WEBPACK_IMPORTED_MODULE_20__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _value_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./value.js */ \"../../node_modules/d3-interpolate/src/value.js\");\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./array.js */ \"../../node_modules/d3-interpolate/src/array.js\");\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-interpolate/src/basis.js\");\n/* harmony import */ var _basisClosed_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./basisClosed.js */ \"../../node_modules/d3-interpolate/src/basisClosed.js\");\n/* harmony import */ var _date_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./date.js */ \"../../node_modules/d3-interpolate/src/date.js\");\n/* harmony import */ var _discrete_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./discrete.js */ \"../../node_modules/d3-interpolate/src/discrete.js\");\n/* harmony import */ var _hue_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./hue.js */ \"../../node_modules/d3-interpolate/src/hue.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-interpolate/src/number.js\");\n/* harmony import */ var _numberArray_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./numberArray.js */ \"../../node_modules/d3-interpolate/src/numberArray.js\");\n/* harmony import */ var _object_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./object.js */ \"../../node_modules/d3-interpolate/src/object.js\");\n/* harmony import */ var _round_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./round.js */ \"../../node_modules/d3-interpolate/src/round.js\");\n/* harmony import */ var _string_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./string.js */ \"../../node_modules/d3-interpolate/src/string.js\");\n/* harmony import */ var _transform_index_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./transform/index.js */ \"../../node_modules/d3-interpolate/src/transform/index.js\");\n/* harmony import */ var _zoom_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./zoom.js */ \"../../node_modules/d3-interpolate/src/zoom.js\");\n/* harmony import */ var _rgb_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./rgb.js */ \"../../node_modules/d3-interpolate/src/rgb.js\");\n/* harmony import */ var _hsl_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./hsl.js */ \"../../node_modules/d3-interpolate/src/hsl.js\");\n/* harmony import */ var _lab_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./lab.js */ \"../../node_modules/d3-interpolate/src/lab.js\");\n/* harmony import */ var _hcl_js__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./hcl.js */ \"../../node_modules/d3-interpolate/src/hcl.js\");\n/* harmony import */ var _cubehelix_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./cubehelix.js */ \"../../node_modules/d3-interpolate/src/cubehelix.js\");\n/* harmony import */ var _piecewise_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./piecewise.js */ \"../../node_modules/d3-interpolate/src/piecewise.js\");\n/* harmony import */ var _quantize_js__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./quantize.js */ \"../../node_modules/d3-interpolate/src/quantize.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/index.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/lab.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/lab.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ lab)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/lab.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n\nfunction lab(start, end) {\n  var l = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])((start = (0,d3_color__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(start)).l, (end = (0,d3_color__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(end)).l),\n      a = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(start.a, end.a),\n      b = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(start.b, end.b),\n      opacity = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(start.opacity, end.opacity);\n  return function(t) {\n    start.l = l(t);\n    start.a = a(t);\n    start.b = b(t);\n    start.opacity = opacity(t);\n    return start + \"\";\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/lab.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/number.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/number.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  return a = +a, b = +b, function(t) {\n    return a * (1 - t) + b * t;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/number.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/numberArray.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/numberArray.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   isNumberArray: () => (/* binding */ isNumberArray)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  if (!b) b = [];\n  var n = a ? Math.min(b.length, a.length) : 0,\n      c = b.slice(),\n      i;\n  return function(t) {\n    for (i = 0; i < n; ++i) c[i] = a[i] * (1 - t) + b[i] * t;\n    return c;\n  };\n}\n\nfunction isNumberArray(x) {\n  return ArrayBuffer.isView(x) && !(x instanceof DataView);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/numberArray.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/object.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/object.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _value_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./value.js */ \"../../node_modules/d3-interpolate/src/value.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  var i = {},\n      c = {},\n      k;\n\n  if (a === null || typeof a !== \"object\") a = {};\n  if (b === null || typeof b !== \"object\") b = {};\n\n  for (k in b) {\n    if (k in a) {\n      i[k] = (0,_value_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(a[k], b[k]);\n    } else {\n      c[k] = b[k];\n    }\n  }\n\n  return function(t) {\n    for (k in i) c[k] = i[k](t);\n    return c;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/object.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/piecewise.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/piecewise.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ piecewise)\n/* harmony export */ });\n/* harmony import */ var _value_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./value.js */ \"../../node_modules/d3-interpolate/src/value.js\");\n\n\nfunction piecewise(interpolate, values) {\n  if (values === undefined) values = interpolate, interpolate = _value_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n  var i = 0, n = values.length - 1, v = values[0], I = new Array(n < 0 ? 0 : n);\n  while (i < n) I[i] = interpolate(v, v = values[++i]);\n  return function(t) {\n    var i = Math.max(0, Math.min(n - 1, Math.floor(t *= n)));\n    return I[i](t - i);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/piecewise.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/quantize.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/quantize.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(interpolator, n) {\n  var samples = new Array(n);\n  for (var i = 0; i < n; ++i) samples[i] = interpolator(i / (n - 1));\n  return samples;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/quantize.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/rgb.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/rgb.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   rgbBasis: () => (/* binding */ rgbBasis),\n/* harmony export */   rgbBasisClosed: () => (/* binding */ rgbBasisClosed)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-interpolate/src/basis.js\");\n/* harmony import */ var _basisClosed_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./basisClosed.js */ \"../../node_modules/d3-interpolate/src/basisClosed.js\");\n/* harmony import */ var _color_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./color.js */ \"../../node_modules/d3-interpolate/src/color.js\");\n\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function rgbGamma(y) {\n  var color = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__.gamma)(y);\n\n  function rgb(start, end) {\n    var r = color((start = (0,d3_color__WEBPACK_IMPORTED_MODULE_1__.rgb)(start)).r, (end = (0,d3_color__WEBPACK_IMPORTED_MODULE_1__.rgb)(end)).r),\n        g = color(start.g, end.g),\n        b = color(start.b, end.b),\n        opacity = (0,_color_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(start.opacity, end.opacity);\n    return function(t) {\n      start.r = r(t);\n      start.g = g(t);\n      start.b = b(t);\n      start.opacity = opacity(t);\n      return start + \"\";\n    };\n  }\n\n  rgb.gamma = rgbGamma;\n\n  return rgb;\n})(1));\n\nfunction rgbSpline(spline) {\n  return function(colors) {\n    var n = colors.length,\n        r = new Array(n),\n        g = new Array(n),\n        b = new Array(n),\n        i, color;\n    for (i = 0; i < n; ++i) {\n      color = (0,d3_color__WEBPACK_IMPORTED_MODULE_1__.rgb)(colors[i]);\n      r[i] = color.r || 0;\n      g[i] = color.g || 0;\n      b[i] = color.b || 0;\n    }\n    r = spline(r);\n    g = spline(g);\n    b = spline(b);\n    color.opacity = 1;\n    return function(t) {\n      color.r = r(t);\n      color.g = g(t);\n      color.b = b(t);\n      return color + \"\";\n    };\n  };\n}\n\nvar rgbBasis = rgbSpline(_basis_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"]);\nvar rgbBasisClosed = rgbSpline(_basisClosed_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]);\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/rgb.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/round.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/round.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  return a = +a, b = +b, function(t) {\n    return Math.round(a * (1 - t) + b * t);\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/round.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/string.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/string.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-interpolate/src/number.js\");\n\n\nvar reA = /[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,\n    reB = new RegExp(reA.source, \"g\");\n\nfunction zero(b) {\n  return function() {\n    return b;\n  };\n}\n\nfunction one(b) {\n  return function(t) {\n    return b(t) + \"\";\n  };\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  var bi = reA.lastIndex = reB.lastIndex = 0, // scan index for next number in b\n      am, // current match in a\n      bm, // current match in b\n      bs, // string preceding current number in b, if any\n      i = -1, // index in s\n      s = [], // string constants and placeholders\n      q = []; // number interpolators\n\n  // Coerce inputs to strings.\n  a = a + \"\", b = b + \"\";\n\n  // Interpolate pairs of numbers in a & b.\n  while ((am = reA.exec(a))\n      && (bm = reB.exec(b))) {\n    if ((bs = bm.index) > bi) { // a string precedes the next number in b\n      bs = b.slice(bi, bs);\n      if (s[i]) s[i] += bs; // coalesce with previous string\n      else s[++i] = bs;\n    }\n    if ((am = am[0]) === (bm = bm[0])) { // numbers in a & b match\n      if (s[i]) s[i] += bm; // coalesce with previous string\n      else s[++i] = bm;\n    } else { // interpolate non-matching numbers\n      s[++i] = null;\n      q.push({i: i, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(am, bm)});\n    }\n    bi = reB.lastIndex;\n  }\n\n  // Add remains of b.\n  if (bi < b.length) {\n    bs = b.slice(bi);\n    if (s[i]) s[i] += bs; // coalesce with previous string\n    else s[++i] = bs;\n  }\n\n  // Special optimization for only a single match.\n  // Otherwise, interpolate each of the numbers and rejoin the string.\n  return s.length < 2 ? (q[0]\n      ? one(q[0].x)\n      : zero(b))\n      : (b = q.length, function(t) {\n          for (var i = 0, o; i < b; ++i) s[(o = q[i]).i] = o.x(t);\n          return s.join(\"\");\n        });\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/string.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/transform/decompose.js":
/*!********************************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/transform/decompose.js ***!
  \********************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   identity: () => (/* binding */ identity)\n/* harmony export */ });\nvar degrees = 180 / Math.PI;\n\nvar identity = {\n  translateX: 0,\n  translateY: 0,\n  rotate: 0,\n  skewX: 0,\n  scaleX: 1,\n  scaleY: 1\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b, c, d, e, f) {\n  var scaleX, scaleY, skewX;\n  if (scaleX = Math.sqrt(a * a + b * b)) a /= scaleX, b /= scaleX;\n  if (skewX = a * c + b * d) c -= a * skewX, d -= b * skewX;\n  if (scaleY = Math.sqrt(c * c + d * d)) c /= scaleY, d /= scaleY, skewX /= scaleY;\n  if (a * d < b * c) a = -a, b = -b, skewX = -skewX, scaleX = -scaleX;\n  return {\n    translateX: e,\n    translateY: f,\n    rotate: Math.atan2(b, a) * degrees,\n    skewX: Math.atan(skewX) * degrees,\n    scaleX: scaleX,\n    scaleY: scaleY\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/transform/decompose.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/transform/index.js":
/*!****************************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/transform/index.js ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   interpolateTransformCss: () => (/* binding */ interpolateTransformCss),\n/* harmony export */   interpolateTransformSvg: () => (/* binding */ interpolateTransformSvg)\n/* harmony export */ });\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../number.js */ \"../../node_modules/d3-interpolate/src/number.js\");\n/* harmony import */ var _parse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./parse.js */ \"../../node_modules/d3-interpolate/src/transform/parse.js\");\n\n\n\nfunction interpolateTransform(parse, pxComma, pxParen, degParen) {\n\n  function pop(s) {\n    return s.length ? s.pop() + \" \" : \"\";\n  }\n\n  function translate(xa, ya, xb, yb, s, q) {\n    if (xa !== xb || ya !== yb) {\n      var i = s.push(\"translate(\", null, pxComma, null, pxParen);\n      q.push({i: i - 4, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(xa, xb)}, {i: i - 2, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(ya, yb)});\n    } else if (xb || yb) {\n      s.push(\"translate(\" + xb + pxComma + yb + pxParen);\n    }\n  }\n\n  function rotate(a, b, s, q) {\n    if (a !== b) {\n      if (a - b > 180) b += 360; else if (b - a > 180) a += 360; // shortest path\n      q.push({i: s.push(pop(s) + \"rotate(\", null, degParen) - 2, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(a, b)});\n    } else if (b) {\n      s.push(pop(s) + \"rotate(\" + b + degParen);\n    }\n  }\n\n  function skewX(a, b, s, q) {\n    if (a !== b) {\n      q.push({i: s.push(pop(s) + \"skewX(\", null, degParen) - 2, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(a, b)});\n    } else if (b) {\n      s.push(pop(s) + \"skewX(\" + b + degParen);\n    }\n  }\n\n  function scale(xa, ya, xb, yb, s, q) {\n    if (xa !== xb || ya !== yb) {\n      var i = s.push(pop(s) + \"scale(\", null, \",\", null, \")\");\n      q.push({i: i - 4, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(xa, xb)}, {i: i - 2, x: (0,_number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(ya, yb)});\n    } else if (xb !== 1 || yb !== 1) {\n      s.push(pop(s) + \"scale(\" + xb + \",\" + yb + \")\");\n    }\n  }\n\n  return function(a, b) {\n    var s = [], // string constants and placeholders\n        q = []; // number interpolators\n    a = parse(a), b = parse(b);\n    translate(a.translateX, a.translateY, b.translateX, b.translateY, s, q);\n    rotate(a.rotate, b.rotate, s, q);\n    skewX(a.skewX, b.skewX, s, q);\n    scale(a.scaleX, a.scaleY, b.scaleX, b.scaleY, s, q);\n    a = b = null; // gc\n    return function(t) {\n      var i = -1, n = q.length, o;\n      while (++i < n) s[(o = q[i]).i] = o.x(t);\n      return s.join(\"\");\n    };\n  };\n}\n\nvar interpolateTransformCss = interpolateTransform(_parse_js__WEBPACK_IMPORTED_MODULE_1__.parseCss, \"px, \", \"px)\", \"deg)\");\nvar interpolateTransformSvg = interpolateTransform(_parse_js__WEBPACK_IMPORTED_MODULE_1__.parseSvg, \", \", \")\", \")\");\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/transform/index.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/transform/parse.js":
/*!****************************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/transform/parse.js ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   parseCss: () => (/* binding */ parseCss),\n/* harmony export */   parseSvg: () => (/* binding */ parseSvg)\n/* harmony export */ });\n/* harmony import */ var _decompose_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./decompose.js */ \"../../node_modules/d3-interpolate/src/transform/decompose.js\");\n\n\nvar svgNode;\n\n/* eslint-disable no-undef */\nfunction parseCss(value) {\n  const m = new (typeof DOMMatrix === \"function\" ? DOMMatrix : WebKitCSSMatrix)(value + \"\");\n  return m.isIdentity ? _decompose_js__WEBPACK_IMPORTED_MODULE_0__.identity : (0,_decompose_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(m.a, m.b, m.c, m.d, m.e, m.f);\n}\n\nfunction parseSvg(value) {\n  if (value == null) return _decompose_js__WEBPACK_IMPORTED_MODULE_0__.identity;\n  if (!svgNode) svgNode = document.createElementNS(\"http://www.w3.org/2000/svg\", \"g\");\n  svgNode.setAttribute(\"transform\", value);\n  if (!(value = svgNode.transform.baseVal.consolidate())) return _decompose_js__WEBPACK_IMPORTED_MODULE_0__.identity;\n  value = value.matrix;\n  return (0,_decompose_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(value.a, value.b, value.c, value.d, value.e, value.f);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/transform/parse.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/value.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/value.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var d3_color__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-color */ \"../../node_modules/d3-color/src/color.js\");\n/* harmony import */ var _rgb_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./rgb.js */ \"../../node_modules/d3-interpolate/src/rgb.js\");\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./array.js */ \"../../node_modules/d3-interpolate/src/array.js\");\n/* harmony import */ var _date_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./date.js */ \"../../node_modules/d3-interpolate/src/date.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-interpolate/src/number.js\");\n/* harmony import */ var _object_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./object.js */ \"../../node_modules/d3-interpolate/src/object.js\");\n/* harmony import */ var _string_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./string.js */ \"../../node_modules/d3-interpolate/src/string.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-interpolate/src/constant.js\");\n/* harmony import */ var _numberArray_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./numberArray.js */ \"../../node_modules/d3-interpolate/src/numberArray.js\");\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(a, b) {\n  var t = typeof b, c;\n  return b == null || t === \"boolean\" ? (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(b)\n      : (t === \"number\" ? _number_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"]\n      : t === \"string\" ? ((c = (0,d3_color__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(b)) ? (b = c, _rgb_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]) : _string_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])\n      : b instanceof d3_color__WEBPACK_IMPORTED_MODULE_2__[\"default\"] ? _rgb_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"]\n      : b instanceof Date ? _date_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"]\n      : (0,_numberArray_js__WEBPACK_IMPORTED_MODULE_6__.isNumberArray)(b) ? _numberArray_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"]\n      : Array.isArray(b) ? _array_js__WEBPACK_IMPORTED_MODULE_7__.genericArray\n      : typeof b.valueOf !== \"function\" && typeof b.toString !== \"function\" || isNaN(b) ? _object_js__WEBPACK_IMPORTED_MODULE_8__[\"default\"]\n      : _number_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(a, b);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/value.js?");

/***/ }),

/***/ "../../node_modules/d3-interpolate/src/zoom.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-interpolate/src/zoom.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nvar epsilon2 = 1e-12;\n\nfunction cosh(x) {\n  return ((x = Math.exp(x)) + 1 / x) / 2;\n}\n\nfunction sinh(x) {\n  return ((x = Math.exp(x)) - 1 / x) / 2;\n}\n\nfunction tanh(x) {\n  return ((x = Math.exp(2 * x)) - 1) / (x + 1);\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function zoomRho(rho, rho2, rho4) {\n\n  // p0 = [ux0, uy0, w0]\n  // p1 = [ux1, uy1, w1]\n  function zoom(p0, p1) {\n    var ux0 = p0[0], uy0 = p0[1], w0 = p0[2],\n        ux1 = p1[0], uy1 = p1[1], w1 = p1[2],\n        dx = ux1 - ux0,\n        dy = uy1 - uy0,\n        d2 = dx * dx + dy * dy,\n        i,\n        S;\n\n    // Special case for u0 ≅ u1.\n    if (d2 < epsilon2) {\n      S = Math.log(w1 / w0) / rho;\n      i = function(t) {\n        return [\n          ux0 + t * dx,\n          uy0 + t * dy,\n          w0 * Math.exp(rho * t * S)\n        ];\n      }\n    }\n\n    // General case.\n    else {\n      var d1 = Math.sqrt(d2),\n          b0 = (w1 * w1 - w0 * w0 + rho4 * d2) / (2 * w0 * rho2 * d1),\n          b1 = (w1 * w1 - w0 * w0 - rho4 * d2) / (2 * w1 * rho2 * d1),\n          r0 = Math.log(Math.sqrt(b0 * b0 + 1) - b0),\n          r1 = Math.log(Math.sqrt(b1 * b1 + 1) - b1);\n      S = (r1 - r0) / rho;\n      i = function(t) {\n        var s = t * S,\n            coshr0 = cosh(r0),\n            u = w0 / (rho2 * d1) * (coshr0 * tanh(rho * s + r0) - sinh(r0));\n        return [\n          ux0 + u * dx,\n          uy0 + u * dy,\n          w0 * coshr0 / cosh(rho * s + r0)\n        ];\n      }\n    }\n\n    i.duration = S * 1000 * rho / Math.SQRT2;\n\n    return i;\n  }\n\n  zoom.rho = function(_) {\n    var _1 = Math.max(1e-3, +_), _2 = _1 * _1, _4 = _2 * _2;\n    return zoomRho(_1, _2, _4);\n  };\n\n  return zoom;\n})(Math.SQRT2, 2, 4));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-interpolate/src/zoom.js?");

/***/ }),

/***/ "../../node_modules/d3-path/src/path.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-path/src/path.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Path: () => (/* binding */ Path),\n/* harmony export */   path: () => (/* binding */ path),\n/* harmony export */   pathRound: () => (/* binding */ pathRound)\n/* harmony export */ });\nconst pi = Math.PI,\n    tau = 2 * pi,\n    epsilon = 1e-6,\n    tauEpsilon = tau - epsilon;\n\nfunction append(strings) {\n  this._ += strings[0];\n  for (let i = 1, n = strings.length; i < n; ++i) {\n    this._ += arguments[i] + strings[i];\n  }\n}\n\nfunction appendRound(digits) {\n  let d = Math.floor(digits);\n  if (!(d >= 0)) throw new Error(`invalid digits: ${digits}`);\n  if (d > 15) return append;\n  const k = 10 ** d;\n  return function(strings) {\n    this._ += strings[0];\n    for (let i = 1, n = strings.length; i < n; ++i) {\n      this._ += Math.round(arguments[i] * k) / k + strings[i];\n    }\n  };\n}\n\nclass Path {\n  constructor(digits) {\n    this._x0 = this._y0 = // start of current subpath\n    this._x1 = this._y1 = null; // end of current subpath\n    this._ = \"\";\n    this._append = digits == null ? append : appendRound(digits);\n  }\n  moveTo(x, y) {\n    this._append`M${this._x0 = this._x1 = +x},${this._y0 = this._y1 = +y}`;\n  }\n  closePath() {\n    if (this._x1 !== null) {\n      this._x1 = this._x0, this._y1 = this._y0;\n      this._append`Z`;\n    }\n  }\n  lineTo(x, y) {\n    this._append`L${this._x1 = +x},${this._y1 = +y}`;\n  }\n  quadraticCurveTo(x1, y1, x, y) {\n    this._append`Q${+x1},${+y1},${this._x1 = +x},${this._y1 = +y}`;\n  }\n  bezierCurveTo(x1, y1, x2, y2, x, y) {\n    this._append`C${+x1},${+y1},${+x2},${+y2},${this._x1 = +x},${this._y1 = +y}`;\n  }\n  arcTo(x1, y1, x2, y2, r) {\n    x1 = +x1, y1 = +y1, x2 = +x2, y2 = +y2, r = +r;\n\n    // Is the radius negative? Error.\n    if (r < 0) throw new Error(`negative radius: ${r}`);\n\n    let x0 = this._x1,\n        y0 = this._y1,\n        x21 = x2 - x1,\n        y21 = y2 - y1,\n        x01 = x0 - x1,\n        y01 = y0 - y1,\n        l01_2 = x01 * x01 + y01 * y01;\n\n    // Is this path empty? Move to (x1,y1).\n    if (this._x1 === null) {\n      this._append`M${this._x1 = x1},${this._y1 = y1}`;\n    }\n\n    // Or, is (x1,y1) coincident with (x0,y0)? Do nothing.\n    else if (!(l01_2 > epsilon));\n\n    // Or, are (x0,y0), (x1,y1) and (x2,y2) collinear?\n    // Equivalently, is (x1,y1) coincident with (x2,y2)?\n    // Or, is the radius zero? Line to (x1,y1).\n    else if (!(Math.abs(y01 * x21 - y21 * x01) > epsilon) || !r) {\n      this._append`L${this._x1 = x1},${this._y1 = y1}`;\n    }\n\n    // Otherwise, draw an arc!\n    else {\n      let x20 = x2 - x0,\n          y20 = y2 - y0,\n          l21_2 = x21 * x21 + y21 * y21,\n          l20_2 = x20 * x20 + y20 * y20,\n          l21 = Math.sqrt(l21_2),\n          l01 = Math.sqrt(l01_2),\n          l = r * Math.tan((pi - Math.acos((l21_2 + l01_2 - l20_2) / (2 * l21 * l01))) / 2),\n          t01 = l / l01,\n          t21 = l / l21;\n\n      // If the start tangent is not coincident with (x0,y0), line to.\n      if (Math.abs(t01 - 1) > epsilon) {\n        this._append`L${x1 + t01 * x01},${y1 + t01 * y01}`;\n      }\n\n      this._append`A${r},${r},0,0,${+(y01 * x20 > x01 * y20)},${this._x1 = x1 + t21 * x21},${this._y1 = y1 + t21 * y21}`;\n    }\n  }\n  arc(x, y, r, a0, a1, ccw) {\n    x = +x, y = +y, r = +r, ccw = !!ccw;\n\n    // Is the radius negative? Error.\n    if (r < 0) throw new Error(`negative radius: ${r}`);\n\n    let dx = r * Math.cos(a0),\n        dy = r * Math.sin(a0),\n        x0 = x + dx,\n        y0 = y + dy,\n        cw = 1 ^ ccw,\n        da = ccw ? a0 - a1 : a1 - a0;\n\n    // Is this path empty? Move to (x0,y0).\n    if (this._x1 === null) {\n      this._append`M${x0},${y0}`;\n    }\n\n    // Or, is (x0,y0) not coincident with the previous point? Line to (x0,y0).\n    else if (Math.abs(this._x1 - x0) > epsilon || Math.abs(this._y1 - y0) > epsilon) {\n      this._append`L${x0},${y0}`;\n    }\n\n    // Is this arc empty? We’re done.\n    if (!r) return;\n\n    // Does the angle go the wrong way? Flip the direction.\n    if (da < 0) da = da % tau + tau;\n\n    // Is this a complete circle? Draw two arcs to complete the circle.\n    if (da > tauEpsilon) {\n      this._append`A${r},${r},0,1,${cw},${x - dx},${y - dy}A${r},${r},0,1,${cw},${this._x1 = x0},${this._y1 = y0}`;\n    }\n\n    // Is this arc non-empty? Draw an arc!\n    else if (da > epsilon) {\n      this._append`A${r},${r},0,${+(da >= pi)},${cw},${this._x1 = x + r * Math.cos(a1)},${this._y1 = y + r * Math.sin(a1)}`;\n    }\n  }\n  rect(x, y, w, h) {\n    this._append`M${this._x0 = this._x1 = +x},${this._y0 = this._y1 = +y}h${w = +w}v${+h}h${-w}Z`;\n  }\n  toString() {\n    return this._;\n  }\n}\n\nfunction path() {\n  return new Path;\n}\n\n// Allow instanceof d3.path\npath.prototype = Path.prototype;\n\nfunction pathRound(digits = 3) {\n  return new Path(+digits);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-path/src/path.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/add.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/add.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   addAll: () => (/* binding */ addAll),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(d) {\n  const x = +this._x.call(null, d),\n      y = +this._y.call(null, d);\n  return add(this.cover(x, y), x, y, d);\n}\n\nfunction add(tree, x, y, d) {\n  if (isNaN(x) || isNaN(y)) return tree; // ignore invalid points\n\n  var parent,\n      node = tree._root,\n      leaf = {data: d},\n      x0 = tree._x0,\n      y0 = tree._y0,\n      x1 = tree._x1,\n      y1 = tree._y1,\n      xm,\n      ym,\n      xp,\n      yp,\n      right,\n      bottom,\n      i,\n      j;\n\n  // If the tree is empty, initialize the root as a leaf.\n  if (!node) return tree._root = leaf, tree;\n\n  // Find the existing leaf for the new point, or add it.\n  while (node.length) {\n    if (right = x >= (xm = (x0 + x1) / 2)) x0 = xm; else x1 = xm;\n    if (bottom = y >= (ym = (y0 + y1) / 2)) y0 = ym; else y1 = ym;\n    if (parent = node, !(node = node[i = bottom << 1 | right])) return parent[i] = leaf, tree;\n  }\n\n  // Is the new point is exactly coincident with the existing point?\n  xp = +tree._x.call(null, node.data);\n  yp = +tree._y.call(null, node.data);\n  if (x === xp && y === yp) return leaf.next = node, parent ? parent[i] = leaf : tree._root = leaf, tree;\n\n  // Otherwise, split the leaf node until the old and new point are separated.\n  do {\n    parent = parent ? parent[i] = new Array(4) : tree._root = new Array(4);\n    if (right = x >= (xm = (x0 + x1) / 2)) x0 = xm; else x1 = xm;\n    if (bottom = y >= (ym = (y0 + y1) / 2)) y0 = ym; else y1 = ym;\n  } while ((i = bottom << 1 | right) === (j = (yp >= ym) << 1 | (xp >= xm)));\n  return parent[j] = node, parent[i] = leaf, tree;\n}\n\nfunction addAll(data) {\n  var d, i, n = data.length,\n      x,\n      y,\n      xz = new Array(n),\n      yz = new Array(n),\n      x0 = Infinity,\n      y0 = Infinity,\n      x1 = -Infinity,\n      y1 = -Infinity;\n\n  // Compute the points and their extent.\n  for (i = 0; i < n; ++i) {\n    if (isNaN(x = +this._x.call(null, d = data[i])) || isNaN(y = +this._y.call(null, d))) continue;\n    xz[i] = x;\n    yz[i] = y;\n    if (x < x0) x0 = x;\n    if (x > x1) x1 = x;\n    if (y < y0) y0 = y;\n    if (y > y1) y1 = y;\n  }\n\n  // If there were no (valid) points, abort.\n  if (x0 > x1 || y0 > y1) return this;\n\n  // Expand the tree to cover the new points.\n  this.cover(x0, y0).cover(x1, y1);\n\n  // Add the new points.\n  for (i = 0; i < n; ++i) {\n    add(this, xz[i], yz[i], data[i]);\n  }\n\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/add.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/cover.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/cover.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, y) {\n  if (isNaN(x = +x) || isNaN(y = +y)) return this; // ignore invalid points\n\n  var x0 = this._x0,\n      y0 = this._y0,\n      x1 = this._x1,\n      y1 = this._y1;\n\n  // If the quadtree has no extent, initialize them.\n  // Integer extent are necessary so that if we later double the extent,\n  // the existing quadrant boundaries don’t change due to floating point error!\n  if (isNaN(x0)) {\n    x1 = (x0 = Math.floor(x)) + 1;\n    y1 = (y0 = Math.floor(y)) + 1;\n  }\n\n  // Otherwise, double repeatedly to cover.\n  else {\n    var z = x1 - x0 || 1,\n        node = this._root,\n        parent,\n        i;\n\n    while (x0 > x || x >= x1 || y0 > y || y >= y1) {\n      i = (y < y0) << 1 | (x < x0);\n      parent = new Array(4), parent[i] = node, node = parent, z *= 2;\n      switch (i) {\n        case 0: x1 = x0 + z, y1 = y0 + z; break;\n        case 1: x0 = x1 - z, y1 = y0 + z; break;\n        case 2: x1 = x0 + z, y0 = y1 - z; break;\n        case 3: x0 = x1 - z, y0 = y1 - z; break;\n      }\n    }\n\n    if (this._root && this._root.length) this._root = node;\n  }\n\n  this._x0 = x0;\n  this._y0 = y0;\n  this._x1 = x1;\n  this._y1 = y1;\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/cover.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/data.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/data.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var data = [];\n  this.visit(function(node) {\n    if (!node.length) do data.push(node.data); while (node = node.next)\n  });\n  return data;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/data.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/extent.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/extent.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(_) {\n  return arguments.length\n      ? this.cover(+_[0][0], +_[0][1]).cover(+_[1][0], +_[1][1])\n      : isNaN(this._x0) ? undefined : [[this._x0, this._y0], [this._x1, this._y1]];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/extent.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/find.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/find.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _quad_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./quad.js */ \"../../node_modules/d3-quadtree/src/quad.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, y, radius) {\n  var data,\n      x0 = this._x0,\n      y0 = this._y0,\n      x1,\n      y1,\n      x2,\n      y2,\n      x3 = this._x1,\n      y3 = this._y1,\n      quads = [],\n      node = this._root,\n      q,\n      i;\n\n  if (node) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node, x0, y0, x3, y3));\n  if (radius == null) radius = Infinity;\n  else {\n    x0 = x - radius, y0 = y - radius;\n    x3 = x + radius, y3 = y + radius;\n    radius *= radius;\n  }\n\n  while (q = quads.pop()) {\n\n    // Stop searching if this quadrant can’t contain a closer node.\n    if (!(node = q.node)\n        || (x1 = q.x0) > x3\n        || (y1 = q.y0) > y3\n        || (x2 = q.x1) < x0\n        || (y2 = q.y1) < y0) continue;\n\n    // Bisect the current quadrant.\n    if (node.length) {\n      var xm = (x1 + x2) / 2,\n          ym = (y1 + y2) / 2;\n\n      quads.push(\n        new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node[3], xm, ym, x2, y2),\n        new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node[2], x1, ym, xm, y2),\n        new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node[1], xm, y1, x2, ym),\n        new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node[0], x1, y1, xm, ym)\n      );\n\n      // Visit the closest quadrant first.\n      if (i = (y >= ym) << 1 | (x >= xm)) {\n        q = quads[quads.length - 1];\n        quads[quads.length - 1] = quads[quads.length - 1 - i];\n        quads[quads.length - 1 - i] = q;\n      }\n    }\n\n    // Visit this point. (Visiting coincident points isn’t necessary!)\n    else {\n      var dx = x - +this._x.call(null, node.data),\n          dy = y - +this._y.call(null, node.data),\n          d2 = dx * dx + dy * dy;\n      if (d2 < radius) {\n        var d = Math.sqrt(radius = d2);\n        x0 = x - d, y0 = y - d;\n        x3 = x + d, y3 = y + d;\n        data = node.data;\n      }\n    }\n  }\n\n  return data;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/find.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/quad.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/quad.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(node, x0, y0, x1, y1) {\n  this.node = node;\n  this.x0 = x0;\n  this.y0 = y0;\n  this.x1 = x1;\n  this.y1 = y1;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/quad.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/quadtree.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/quadtree.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quadtree)\n/* harmony export */ });\n/* harmony import */ var _add_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./add.js */ \"../../node_modules/d3-quadtree/src/add.js\");\n/* harmony import */ var _cover_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./cover.js */ \"../../node_modules/d3-quadtree/src/cover.js\");\n/* harmony import */ var _data_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./data.js */ \"../../node_modules/d3-quadtree/src/data.js\");\n/* harmony import */ var _extent_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./extent.js */ \"../../node_modules/d3-quadtree/src/extent.js\");\n/* harmony import */ var _find_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./find.js */ \"../../node_modules/d3-quadtree/src/find.js\");\n/* harmony import */ var _remove_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./remove.js */ \"../../node_modules/d3-quadtree/src/remove.js\");\n/* harmony import */ var _root_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./root.js */ \"../../node_modules/d3-quadtree/src/root.js\");\n/* harmony import */ var _size_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./size.js */ \"../../node_modules/d3-quadtree/src/size.js\");\n/* harmony import */ var _visit_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./visit.js */ \"../../node_modules/d3-quadtree/src/visit.js\");\n/* harmony import */ var _visitAfter_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./visitAfter.js */ \"../../node_modules/d3-quadtree/src/visitAfter.js\");\n/* harmony import */ var _x_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./x.js */ \"../../node_modules/d3-quadtree/src/x.js\");\n/* harmony import */ var _y_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./y.js */ \"../../node_modules/d3-quadtree/src/y.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\nfunction quadtree(nodes, x, y) {\n  var tree = new Quadtree(x == null ? _x_js__WEBPACK_IMPORTED_MODULE_0__.defaultX : x, y == null ? _y_js__WEBPACK_IMPORTED_MODULE_1__.defaultY : y, NaN, NaN, NaN, NaN);\n  return nodes == null ? tree : tree.addAll(nodes);\n}\n\nfunction Quadtree(x, y, x0, y0, x1, y1) {\n  this._x = x;\n  this._y = y;\n  this._x0 = x0;\n  this._y0 = y0;\n  this._x1 = x1;\n  this._y1 = y1;\n  this._root = undefined;\n}\n\nfunction leaf_copy(leaf) {\n  var copy = {data: leaf.data}, next = copy;\n  while (leaf = leaf.next) next = next.next = {data: leaf.data};\n  return copy;\n}\n\nvar treeProto = quadtree.prototype = Quadtree.prototype;\n\ntreeProto.copy = function() {\n  var copy = new Quadtree(this._x, this._y, this._x0, this._y0, this._x1, this._y1),\n      node = this._root,\n      nodes,\n      child;\n\n  if (!node) return copy;\n\n  if (!node.length) return copy._root = leaf_copy(node), copy;\n\n  nodes = [{source: node, target: copy._root = new Array(4)}];\n  while (node = nodes.pop()) {\n    for (var i = 0; i < 4; ++i) {\n      if (child = node.source[i]) {\n        if (child.length) nodes.push({source: child, target: node.target[i] = new Array(4)});\n        else node.target[i] = leaf_copy(child);\n      }\n    }\n  }\n\n  return copy;\n};\n\ntreeProto.add = _add_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"];\ntreeProto.addAll = _add_js__WEBPACK_IMPORTED_MODULE_2__.addAll;\ntreeProto.cover = _cover_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\ntreeProto.data = _data_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"];\ntreeProto.extent = _extent_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"];\ntreeProto.find = _find_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"];\ntreeProto.remove = _remove_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"];\ntreeProto.removeAll = _remove_js__WEBPACK_IMPORTED_MODULE_7__.removeAll;\ntreeProto.root = _root_js__WEBPACK_IMPORTED_MODULE_8__[\"default\"];\ntreeProto.size = _size_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"];\ntreeProto.visit = _visit_js__WEBPACK_IMPORTED_MODULE_10__[\"default\"];\ntreeProto.visitAfter = _visitAfter_js__WEBPACK_IMPORTED_MODULE_11__[\"default\"];\ntreeProto.x = _x_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\ntreeProto.y = _y_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"];\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/quadtree.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/remove.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/remove.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   removeAll: () => (/* binding */ removeAll)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(d) {\n  if (isNaN(x = +this._x.call(null, d)) || isNaN(y = +this._y.call(null, d))) return this; // ignore invalid points\n\n  var parent,\n      node = this._root,\n      retainer,\n      previous,\n      next,\n      x0 = this._x0,\n      y0 = this._y0,\n      x1 = this._x1,\n      y1 = this._y1,\n      x,\n      y,\n      xm,\n      ym,\n      right,\n      bottom,\n      i,\n      j;\n\n  // If the tree is empty, initialize the root as a leaf.\n  if (!node) return this;\n\n  // Find the leaf node for the point.\n  // While descending, also retain the deepest parent with a non-removed sibling.\n  if (node.length) while (true) {\n    if (right = x >= (xm = (x0 + x1) / 2)) x0 = xm; else x1 = xm;\n    if (bottom = y >= (ym = (y0 + y1) / 2)) y0 = ym; else y1 = ym;\n    if (!(parent = node, node = node[i = bottom << 1 | right])) return this;\n    if (!node.length) break;\n    if (parent[(i + 1) & 3] || parent[(i + 2) & 3] || parent[(i + 3) & 3]) retainer = parent, j = i;\n  }\n\n  // Find the point to remove.\n  while (node.data !== d) if (!(previous = node, node = node.next)) return this;\n  if (next = node.next) delete node.next;\n\n  // If there are multiple coincident points, remove just the point.\n  if (previous) return (next ? previous.next = next : delete previous.next), this;\n\n  // If this is the root point, remove it.\n  if (!parent) return this._root = next, this;\n\n  // Remove this leaf.\n  next ? parent[i] = next : delete parent[i];\n\n  // If the parent now contains exactly one leaf, collapse superfluous parents.\n  if ((node = parent[0] || parent[1] || parent[2] || parent[3])\n      && node === (parent[3] || parent[2] || parent[1] || parent[0])\n      && !node.length) {\n    if (retainer) retainer[j] = node;\n    else this._root = node;\n  }\n\n  return this;\n}\n\nfunction removeAll(data) {\n  for (var i = 0, n = data.length; i < n; ++i) this.remove(data[i]);\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/remove.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/root.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/root.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  return this._root;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/root.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/size.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/size.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var size = 0;\n  this.visit(function(node) {\n    if (!node.length) do ++size; while (node = node.next)\n  });\n  return size;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/size.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/visit.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/visit.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _quad_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./quad.js */ \"../../node_modules/d3-quadtree/src/quad.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback) {\n  var quads = [], q, node = this._root, child, x0, y0, x1, y1;\n  if (node) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](node, this._x0, this._y0, this._x1, this._y1));\n  while (q = quads.pop()) {\n    if (!callback(node = q.node, x0 = q.x0, y0 = q.y0, x1 = q.x1, y1 = q.y1) && node.length) {\n      var xm = (x0 + x1) / 2, ym = (y0 + y1) / 2;\n      if (child = node[3]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, xm, ym, x1, y1));\n      if (child = node[2]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, x0, ym, xm, y1));\n      if (child = node[1]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, xm, y0, x1, ym));\n      if (child = node[0]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, x0, y0, xm, ym));\n    }\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/visit.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/visitAfter.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-quadtree/src/visitAfter.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _quad_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./quad.js */ \"../../node_modules/d3-quadtree/src/quad.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback) {\n  var quads = [], next = [], q;\n  if (this._root) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](this._root, this._x0, this._y0, this._x1, this._y1));\n  while (q = quads.pop()) {\n    var node = q.node;\n    if (node.length) {\n      var child, x0 = q.x0, y0 = q.y0, x1 = q.x1, y1 = q.y1, xm = (x0 + x1) / 2, ym = (y0 + y1) / 2;\n      if (child = node[0]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, x0, y0, xm, ym));\n      if (child = node[1]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, xm, y0, x1, ym));\n      if (child = node[2]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, x0, ym, xm, y1));\n      if (child = node[3]) quads.push(new _quad_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"](child, xm, ym, x1, y1));\n    }\n    next.push(q);\n  }\n  while (q = next.pop()) {\n    callback(q.node, q.x0, q.y0, q.x1, q.y1);\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/visitAfter.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/x.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-quadtree/src/x.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   defaultX: () => (/* binding */ defaultX)\n/* harmony export */ });\nfunction defaultX(d) {\n  return d[0];\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(_) {\n  return arguments.length ? (this._x = _, this) : this._x;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/x.js?");

/***/ }),

/***/ "../../node_modules/d3-quadtree/src/y.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-quadtree/src/y.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   defaultY: () => (/* binding */ defaultY)\n/* harmony export */ });\nfunction defaultY(d) {\n  return d[1];\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(_) {\n  return arguments.length ? (this._y = _, this) : this._y;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-quadtree/src/y.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/constant.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-scale/src/constant.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ constants)\n/* harmony export */ });\nfunction constants(x) {\n  return function() {\n    return x;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/continuous.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-scale/src/continuous.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   copy: () => (/* binding */ copy),\n/* harmony export */   \"default\": () => (/* binding */ continuous),\n/* harmony export */   identity: () => (/* binding */ identity),\n/* harmony export */   transformer: () => (/* binding */ transformer)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/value.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/number.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/round.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-scale/src/constant.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-scale/src/number.js\");\n\n\n\n\n\nvar unit = [0, 1];\n\nfunction identity(x) {\n  return x;\n}\n\nfunction normalize(a, b) {\n  return (b -= (a = +a))\n      ? function(x) { return (x - a) / b; }\n      : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(isNaN(b) ? NaN : 0.5);\n}\n\nfunction clamper(a, b) {\n  var t;\n  if (a > b) t = a, a = b, b = t;\n  return function(x) { return Math.max(a, Math.min(b, x)); };\n}\n\n// normalize(a, b)(x) takes a domain value x in [a,b] and returns the corresponding parameter t in [0,1].\n// interpolate(a, b)(t) takes a parameter t in [0,1] and returns the corresponding range value x in [a,b].\nfunction bimap(domain, range, interpolate) {\n  var d0 = domain[0], d1 = domain[1], r0 = range[0], r1 = range[1];\n  if (d1 < d0) d0 = normalize(d1, d0), r0 = interpolate(r1, r0);\n  else d0 = normalize(d0, d1), r0 = interpolate(r0, r1);\n  return function(x) { return r0(d0(x)); };\n}\n\nfunction polymap(domain, range, interpolate) {\n  var j = Math.min(domain.length, range.length) - 1,\n      d = new Array(j),\n      r = new Array(j),\n      i = -1;\n\n  // Reverse descending domains.\n  if (domain[j] < domain[0]) {\n    domain = domain.slice().reverse();\n    range = range.slice().reverse();\n  }\n\n  while (++i < j) {\n    d[i] = normalize(domain[i], domain[i + 1]);\n    r[i] = interpolate(range[i], range[i + 1]);\n  }\n\n  return function(x) {\n    var i = (0,d3_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(domain, x, 1, j) - 1;\n    return r[i](d[i](x));\n  };\n}\n\nfunction copy(source, target) {\n  return target\n      .domain(source.domain())\n      .range(source.range())\n      .interpolate(source.interpolate())\n      .clamp(source.clamp())\n      .unknown(source.unknown());\n}\n\nfunction transformer() {\n  var domain = unit,\n      range = unit,\n      interpolate = d3_interpolate__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n      transform,\n      untransform,\n      unknown,\n      clamp = identity,\n      piecewise,\n      output,\n      input;\n\n  function rescale() {\n    var n = Math.min(domain.length, range.length);\n    if (clamp !== identity) clamp = clamper(domain[0], domain[n - 1]);\n    piecewise = n > 2 ? polymap : bimap;\n    output = input = null;\n    return scale;\n  }\n\n  function scale(x) {\n    return x == null || isNaN(x = +x) ? unknown : (output || (output = piecewise(domain.map(transform), range, interpolate)))(transform(clamp(x)));\n  }\n\n  scale.invert = function(y) {\n    return clamp(untransform((input || (input = piecewise(range, domain.map(transform), d3_interpolate__WEBPACK_IMPORTED_MODULE_3__[\"default\"])))(y)));\n  };\n\n  scale.domain = function(_) {\n    return arguments.length ? (domain = Array.from(_, _number_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"]), rescale()) : domain.slice();\n  };\n\n  scale.range = function(_) {\n    return arguments.length ? (range = Array.from(_), rescale()) : range.slice();\n  };\n\n  scale.rangeRound = function(_) {\n    return range = Array.from(_), interpolate = d3_interpolate__WEBPACK_IMPORTED_MODULE_5__[\"default\"], rescale();\n  };\n\n  scale.clamp = function(_) {\n    return arguments.length ? (clamp = _ ? true : identity, rescale()) : clamp !== identity;\n  };\n\n  scale.interpolate = function(_) {\n    return arguments.length ? (interpolate = _, rescale()) : interpolate;\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  return function(t, u) {\n    transform = t, untransform = u;\n    return rescale();\n  };\n}\n\nfunction continuous() {\n  return transformer()(identity, identity);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/continuous.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/diverging.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-scale/src/diverging.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ diverging),\n/* harmony export */   divergingLog: () => (/* binding */ divergingLog),\n/* harmony export */   divergingPow: () => (/* binding */ divergingPow),\n/* harmony export */   divergingSqrt: () => (/* binding */ divergingSqrt),\n/* harmony export */   divergingSymlog: () => (/* binding */ divergingSymlog)\n/* harmony export */ });\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/piecewise.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/value.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/round.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _log_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./log.js */ \"../../node_modules/d3-scale/src/log.js\");\n/* harmony import */ var _sequential_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./sequential.js */ \"../../node_modules/d3-scale/src/sequential.js\");\n/* harmony import */ var _symlog_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./symlog.js */ \"../../node_modules/d3-scale/src/symlog.js\");\n/* harmony import */ var _pow_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./pow.js */ \"../../node_modules/d3-scale/src/pow.js\");\n\n\n\n\n\n\n\n\n\nfunction transformer() {\n  var x0 = 0,\n      x1 = 0.5,\n      x2 = 1,\n      s = 1,\n      t0,\n      t1,\n      t2,\n      k10,\n      k21,\n      interpolator = _continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity,\n      transform,\n      clamp = false,\n      unknown;\n\n  function scale(x) {\n    return isNaN(x = +x) ? unknown : (x = 0.5 + ((x = +transform(x)) - t1) * (s * x < s * t1 ? k10 : k21), interpolator(clamp ? Math.max(0, Math.min(1, x)) : x));\n  }\n\n  scale.domain = function(_) {\n    return arguments.length ? ([x0, x1, x2] = _, t0 = transform(x0 = +x0), t1 = transform(x1 = +x1), t2 = transform(x2 = +x2), k10 = t0 === t1 ? 0 : 0.5 / (t1 - t0), k21 = t1 === t2 ? 0 : 0.5 / (t2 - t1), s = t1 < t0 ? -1 : 1, scale) : [x0, x1, x2];\n  };\n\n  scale.clamp = function(_) {\n    return arguments.length ? (clamp = !!_, scale) : clamp;\n  };\n\n  scale.interpolator = function(_) {\n    return arguments.length ? (interpolator = _, scale) : interpolator;\n  };\n\n  function range(interpolate) {\n    return function(_) {\n      var r0, r1, r2;\n      return arguments.length ? ([r0, r1, r2] = _, interpolator = (0,d3_interpolate__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(interpolate, [r0, r1, r2]), scale) : [interpolator(0), interpolator(0.5), interpolator(1)];\n    };\n  }\n\n  scale.range = range(d3_interpolate__WEBPACK_IMPORTED_MODULE_2__[\"default\"]);\n\n  scale.rangeRound = range(d3_interpolate__WEBPACK_IMPORTED_MODULE_3__[\"default\"]);\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  return function(t) {\n    transform = t, t0 = t(x0), t1 = t(x1), t2 = t(x2), k10 = t0 === t1 ? 0 : 0.5 / (t1 - t0), k21 = t1 === t2 ? 0 : 0.5 / (t2 - t1), s = t1 < t0 ? -1 : 1;\n    return scale;\n  };\n}\n\nfunction diverging() {\n  var scale = (0,_linear_js__WEBPACK_IMPORTED_MODULE_4__.linearish)(transformer()(_continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity));\n\n  scale.copy = function() {\n    return (0,_sequential_js__WEBPACK_IMPORTED_MODULE_5__.copy)(scale, diverging());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_6__.initInterpolator.apply(scale, arguments);\n}\n\nfunction divergingLog() {\n  var scale = (0,_log_js__WEBPACK_IMPORTED_MODULE_7__.loggish)(transformer()).domain([0.1, 1, 10]);\n\n  scale.copy = function() {\n    return (0,_sequential_js__WEBPACK_IMPORTED_MODULE_5__.copy)(scale, divergingLog()).base(scale.base());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_6__.initInterpolator.apply(scale, arguments);\n}\n\nfunction divergingSymlog() {\n  var scale = (0,_symlog_js__WEBPACK_IMPORTED_MODULE_8__.symlogish)(transformer());\n\n  scale.copy = function() {\n    return (0,_sequential_js__WEBPACK_IMPORTED_MODULE_5__.copy)(scale, divergingSymlog()).constant(scale.constant());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_6__.initInterpolator.apply(scale, arguments);\n}\n\nfunction divergingPow() {\n  var scale = (0,_pow_js__WEBPACK_IMPORTED_MODULE_9__.powish)(transformer());\n\n  scale.copy = function() {\n    return (0,_sequential_js__WEBPACK_IMPORTED_MODULE_5__.copy)(scale, divergingPow()).exponent(scale.exponent());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_6__.initInterpolator.apply(scale, arguments);\n}\n\nfunction divergingSqrt() {\n  return divergingPow.apply(null, arguments).exponent(0.5);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/diverging.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/identity.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-scale/src/identity.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ identity)\n/* harmony export */ });\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _number_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./number.js */ \"../../node_modules/d3-scale/src/number.js\");\n\n\n\nfunction identity(domain) {\n  var unknown;\n\n  function scale(x) {\n    return x == null || isNaN(x = +x) ? unknown : x;\n  }\n\n  scale.invert = scale;\n\n  scale.domain = scale.range = function(_) {\n    return arguments.length ? (domain = Array.from(_, _number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]), scale) : domain.slice();\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  scale.copy = function() {\n    return identity(domain).unknown(unknown);\n  };\n\n  domain = arguments.length ? Array.from(domain, _number_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]) : [0, 1];\n\n  return (0,_linear_js__WEBPACK_IMPORTED_MODULE_1__.linearish)(scale);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/identity.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/init.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-scale/src/init.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   initInterpolator: () => (/* binding */ initInterpolator),\n/* harmony export */   initRange: () => (/* binding */ initRange)\n/* harmony export */ });\nfunction initRange(domain, range) {\n  switch (arguments.length) {\n    case 0: break;\n    case 1: this.range(domain); break;\n    default: this.range(range).domain(domain); break;\n  }\n  return this;\n}\n\nfunction initInterpolator(domain, interpolator) {\n  switch (arguments.length) {\n    case 0: break;\n    case 1: {\n      if (typeof domain === \"function\") this.interpolator(domain);\n      else this.range(domain);\n      break;\n    }\n    default: {\n      this.domain(domain);\n      if (typeof interpolator === \"function\") this.interpolator(interpolator);\n      else this.range(interpolator);\n      break;\n    }\n  }\n  return this;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/init.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/linear.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-scale/src/linear.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ linear),\n/* harmony export */   linearish: () => (/* binding */ linearish)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n/* harmony import */ var _tickFormat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./tickFormat.js */ \"../../node_modules/d3-scale/src/tickFormat.js\");\n\n\n\n\n\nfunction linearish(scale) {\n  var domain = scale.domain;\n\n  scale.ticks = function(count) {\n    var d = domain();\n    return (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(d[0], d[d.length - 1], count == null ? 10 : count);\n  };\n\n  scale.tickFormat = function(count, specifier) {\n    var d = domain();\n    return (0,_tickFormat_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(d[0], d[d.length - 1], count == null ? 10 : count, specifier);\n  };\n\n  scale.nice = function(count) {\n    if (count == null) count = 10;\n\n    var d = domain();\n    var i0 = 0;\n    var i1 = d.length - 1;\n    var start = d[i0];\n    var stop = d[i1];\n    var prestep;\n    var step;\n    var maxIter = 10;\n\n    if (stop < start) {\n      step = start, start = stop, stop = step;\n      step = i0, i0 = i1, i1 = step;\n    }\n    \n    while (maxIter-- > 0) {\n      step = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__.tickIncrement)(start, stop, count);\n      if (step === prestep) {\n        d[i0] = start\n        d[i1] = stop\n        return domain(d);\n      } else if (step > 0) {\n        start = Math.floor(start / step) * step;\n        stop = Math.ceil(stop / step) * step;\n      } else if (step < 0) {\n        start = Math.ceil(start * step) / step;\n        stop = Math.floor(stop * step) / step;\n      } else {\n        break;\n      }\n      prestep = step;\n    }\n\n    return scale;\n  };\n\n  return scale;\n}\n\nfunction linear() {\n  var scale = (0,_continuous_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"])();\n\n  scale.copy = function() {\n    return (0,_continuous_js__WEBPACK_IMPORTED_MODULE_2__.copy)(scale, linear());\n  };\n\n  _init_js__WEBPACK_IMPORTED_MODULE_3__.initRange.apply(scale, arguments);\n\n  return linearish(scale);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/linear.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/log.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-scale/src/log.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ log),\n/* harmony export */   loggish: () => (/* binding */ loggish)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/formatSpecifier.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/defaultLocale.js\");\n/* harmony import */ var _nice_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./nice.js */ \"../../node_modules/d3-scale/src/nice.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\n\n\n\nfunction transformLog(x) {\n  return Math.log(x);\n}\n\nfunction transformExp(x) {\n  return Math.exp(x);\n}\n\nfunction transformLogn(x) {\n  return -Math.log(-x);\n}\n\nfunction transformExpn(x) {\n  return -Math.exp(-x);\n}\n\nfunction pow10(x) {\n  return isFinite(x) ? +(\"1e\" + x) : x < 0 ? 0 : x;\n}\n\nfunction powp(base) {\n  return base === 10 ? pow10\n      : base === Math.E ? Math.exp\n      : x => Math.pow(base, x);\n}\n\nfunction logp(base) {\n  return base === Math.E ? Math.log\n      : base === 10 && Math.log10\n      || base === 2 && Math.log2\n      || (base = Math.log(base), x => Math.log(x) / base);\n}\n\nfunction reflect(f) {\n  return (x, k) => -f(-x, k);\n}\n\nfunction loggish(transform) {\n  const scale = transform(transformLog, transformExp);\n  const domain = scale.domain;\n  let base = 10;\n  let logs;\n  let pows;\n\n  function rescale() {\n    logs = logp(base), pows = powp(base);\n    if (domain()[0] < 0) {\n      logs = reflect(logs), pows = reflect(pows);\n      transform(transformLogn, transformExpn);\n    } else {\n      transform(transformLog, transformExp);\n    }\n    return scale;\n  }\n\n  scale.base = function(_) {\n    return arguments.length ? (base = +_, rescale()) : base;\n  };\n\n  scale.domain = function(_) {\n    return arguments.length ? (domain(_), rescale()) : domain();\n  };\n\n  scale.ticks = count => {\n    const d = domain();\n    let u = d[0];\n    let v = d[d.length - 1];\n    const r = v < u;\n\n    if (r) ([u, v] = [v, u]);\n\n    let i = logs(u);\n    let j = logs(v);\n    let k;\n    let t;\n    const n = count == null ? 10 : +count;\n    let z = [];\n\n    if (!(base % 1) && j - i < n) {\n      i = Math.floor(i), j = Math.ceil(j);\n      if (u > 0) for (; i <= j; ++i) {\n        for (k = 1; k < base; ++k) {\n          t = i < 0 ? k / pows(-i) : k * pows(i);\n          if (t < u) continue;\n          if (t > v) break;\n          z.push(t);\n        }\n      } else for (; i <= j; ++i) {\n        for (k = base - 1; k >= 1; --k) {\n          t = i > 0 ? k / pows(-i) : k * pows(i);\n          if (t < u) continue;\n          if (t > v) break;\n          z.push(t);\n        }\n      }\n      if (z.length * 2 < n) z = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(u, v, n);\n    } else {\n      z = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(i, j, Math.min(j - i, n)).map(pows);\n    }\n    return r ? z.reverse() : z;\n  };\n\n  scale.tickFormat = (count, specifier) => {\n    if (count == null) count = 10;\n    if (specifier == null) specifier = base === 10 ? \"s\" : \",\";\n    if (typeof specifier !== \"function\") {\n      if (!(base % 1) && (specifier = (0,d3_format__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(specifier)).precision == null) specifier.trim = true;\n      specifier = (0,d3_format__WEBPACK_IMPORTED_MODULE_2__.format)(specifier);\n    }\n    if (count === Infinity) return specifier;\n    const k = Math.max(1, base * count / scale.ticks().length); // TODO fast estimate?\n    return d => {\n      let i = d / pows(Math.round(logs(d)));\n      if (i * base < base - 0.5) i *= base;\n      return i <= k ? specifier(d) : \"\";\n    };\n  };\n\n  scale.nice = () => {\n    return domain((0,_nice_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(domain(), {\n      floor: x => pows(Math.floor(logs(x))),\n      ceil: x => pows(Math.ceil(logs(x)))\n    }));\n  };\n\n  return scale;\n}\n\nfunction log() {\n  const scale = loggish((0,_continuous_js__WEBPACK_IMPORTED_MODULE_4__.transformer)()).domain([1, 10]);\n  scale.copy = () => (0,_continuous_js__WEBPACK_IMPORTED_MODULE_4__.copy)(scale, log()).base(scale.base());\n  _init_js__WEBPACK_IMPORTED_MODULE_5__.initRange.apply(scale, arguments);\n  return scale;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/log.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/nice.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-scale/src/nice.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ nice)\n/* harmony export */ });\nfunction nice(domain, interval) {\n  domain = domain.slice();\n\n  var i0 = 0,\n      i1 = domain.length - 1,\n      x0 = domain[i0],\n      x1 = domain[i1],\n      t;\n\n  if (x1 < x0) {\n    t = i0, i0 = i1, i1 = t;\n    t = x0, x0 = x1, x1 = t;\n  }\n\n  domain[i0] = interval.floor(x0);\n  domain[i1] = interval.ceil(x1);\n  return domain;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/nice.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/number.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-scale/src/number.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ number)\n/* harmony export */ });\nfunction number(x) {\n  return +x;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/number.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/ordinal.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-scale/src/ordinal.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ordinal),\n/* harmony export */   implicit: () => (/* binding */ implicit)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/internmap/src/index.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\nconst implicit = Symbol(\"implicit\");\n\nfunction ordinal() {\n  var index = new d3_array__WEBPACK_IMPORTED_MODULE_0__.InternMap(),\n      domain = [],\n      range = [],\n      unknown = implicit;\n\n  function scale(d) {\n    let i = index.get(d);\n    if (i === undefined) {\n      if (unknown !== implicit) return unknown;\n      index.set(d, i = domain.push(d) - 1);\n    }\n    return range[i % range.length];\n  }\n\n  scale.domain = function(_) {\n    if (!arguments.length) return domain.slice();\n    domain = [], index = new d3_array__WEBPACK_IMPORTED_MODULE_0__.InternMap();\n    for (const value of _) {\n      if (index.has(value)) continue;\n      index.set(value, domain.push(value) - 1);\n    }\n    return scale;\n  };\n\n  scale.range = function(_) {\n    return arguments.length ? (range = Array.from(_), scale) : range.slice();\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  scale.copy = function() {\n    return ordinal(domain, range).unknown(unknown);\n  };\n\n  _init_js__WEBPACK_IMPORTED_MODULE_1__.initRange.apply(scale, arguments);\n\n  return scale;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/ordinal.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/pow.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-scale/src/pow.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ pow),\n/* harmony export */   powish: () => (/* binding */ powish),\n/* harmony export */   sqrt: () => (/* binding */ sqrt)\n/* harmony export */ });\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\n\nfunction transformPow(exponent) {\n  return function(x) {\n    return x < 0 ? -Math.pow(-x, exponent) : Math.pow(x, exponent);\n  };\n}\n\nfunction transformSqrt(x) {\n  return x < 0 ? -Math.sqrt(-x) : Math.sqrt(x);\n}\n\nfunction transformSquare(x) {\n  return x < 0 ? -x * x : x * x;\n}\n\nfunction powish(transform) {\n  var scale = transform(_continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity, _continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity),\n      exponent = 1;\n\n  function rescale() {\n    return exponent === 1 ? transform(_continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity, _continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity)\n        : exponent === 0.5 ? transform(transformSqrt, transformSquare)\n        : transform(transformPow(exponent), transformPow(1 / exponent));\n  }\n\n  scale.exponent = function(_) {\n    return arguments.length ? (exponent = +_, rescale()) : exponent;\n  };\n\n  return (0,_linear_js__WEBPACK_IMPORTED_MODULE_1__.linearish)(scale);\n}\n\nfunction pow() {\n  var scale = powish((0,_continuous_js__WEBPACK_IMPORTED_MODULE_0__.transformer)());\n\n  scale.copy = function() {\n    return (0,_continuous_js__WEBPACK_IMPORTED_MODULE_0__.copy)(scale, pow()).exponent(scale.exponent());\n  };\n\n  _init_js__WEBPACK_IMPORTED_MODULE_2__.initRange.apply(scale, arguments);\n\n  return scale;\n}\n\nfunction sqrt() {\n  return pow.apply(null, arguments).exponent(0.5);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/pow.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/quantile.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-scale/src/quantile.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quantile)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/quantile.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\nfunction quantile() {\n  var domain = [],\n      range = [],\n      thresholds = [],\n      unknown;\n\n  function rescale() {\n    var i = 0, n = Math.max(1, range.length);\n    thresholds = new Array(n - 1);\n    while (++i < n) thresholds[i - 1] = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__.quantileSorted)(domain, i / n);\n    return scale;\n  }\n\n  function scale(x) {\n    return x == null || isNaN(x = +x) ? unknown : range[(0,d3_array__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(thresholds, x)];\n  }\n\n  scale.invertExtent = function(y) {\n    var i = range.indexOf(y);\n    return i < 0 ? [NaN, NaN] : [\n      i > 0 ? thresholds[i - 1] : domain[0],\n      i < thresholds.length ? thresholds[i] : domain[domain.length - 1]\n    ];\n  };\n\n  scale.domain = function(_) {\n    if (!arguments.length) return domain.slice();\n    domain = [];\n    for (let d of _) if (d != null && !isNaN(d = +d)) domain.push(d);\n    domain.sort(d3_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"]);\n    return rescale();\n  };\n\n  scale.range = function(_) {\n    return arguments.length ? (range = Array.from(_), rescale()) : range.slice();\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  scale.quantiles = function() {\n    return thresholds.slice();\n  };\n\n  scale.copy = function() {\n    return quantile()\n        .domain(domain)\n        .range(range)\n        .unknown(unknown);\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_3__.initRange.apply(scale, arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/quantile.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/quantize.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-scale/src/quantize.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ quantize)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\n\nfunction quantize() {\n  var x0 = 0,\n      x1 = 1,\n      n = 1,\n      domain = [0.5],\n      range = [0, 1],\n      unknown;\n\n  function scale(x) {\n    return x != null && x <= x ? range[(0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(domain, x, 0, n)] : unknown;\n  }\n\n  function rescale() {\n    var i = -1;\n    domain = new Array(n);\n    while (++i < n) domain[i] = ((i + 1) * x1 - (i - n) * x0) / (n + 1);\n    return scale;\n  }\n\n  scale.domain = function(_) {\n    return arguments.length ? ([x0, x1] = _, x0 = +x0, x1 = +x1, rescale()) : [x0, x1];\n  };\n\n  scale.range = function(_) {\n    return arguments.length ? (n = (range = Array.from(_)).length - 1, rescale()) : range.slice();\n  };\n\n  scale.invertExtent = function(y) {\n    var i = range.indexOf(y);\n    return i < 0 ? [NaN, NaN]\n        : i < 1 ? [x0, domain[0]]\n        : i >= n ? [domain[n - 1], x1]\n        : [domain[i - 1], domain[i]];\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : scale;\n  };\n\n  scale.thresholds = function() {\n    return domain.slice();\n  };\n\n  scale.copy = function() {\n    return quantize()\n        .domain([x0, x1])\n        .range(range)\n        .unknown(unknown);\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_1__.initRange.apply((0,_linear_js__WEBPACK_IMPORTED_MODULE_2__.linearish)(scale), arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/quantize.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/sequential.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-scale/src/sequential.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   copy: () => (/* binding */ copy),\n/* harmony export */   \"default\": () => (/* binding */ sequential),\n/* harmony export */   sequentialLog: () => (/* binding */ sequentialLog),\n/* harmony export */   sequentialPow: () => (/* binding */ sequentialPow),\n/* harmony export */   sequentialSqrt: () => (/* binding */ sequentialSqrt),\n/* harmony export */   sequentialSymlog: () => (/* binding */ sequentialSymlog)\n/* harmony export */ });\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/value.js\");\n/* harmony import */ var d3_interpolate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-interpolate */ \"../../node_modules/d3-interpolate/src/round.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _log_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./log.js */ \"../../node_modules/d3-scale/src/log.js\");\n/* harmony import */ var _symlog_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./symlog.js */ \"../../node_modules/d3-scale/src/symlog.js\");\n/* harmony import */ var _pow_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./pow.js */ \"../../node_modules/d3-scale/src/pow.js\");\n\n\n\n\n\n\n\n\nfunction transformer() {\n  var x0 = 0,\n      x1 = 1,\n      t0,\n      t1,\n      k10,\n      transform,\n      interpolator = _continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity,\n      clamp = false,\n      unknown;\n\n  function scale(x) {\n    return x == null || isNaN(x = +x) ? unknown : interpolator(k10 === 0 ? 0.5 : (x = (transform(x) - t0) * k10, clamp ? Math.max(0, Math.min(1, x)) : x));\n  }\n\n  scale.domain = function(_) {\n    return arguments.length ? ([x0, x1] = _, t0 = transform(x0 = +x0), t1 = transform(x1 = +x1), k10 = t0 === t1 ? 0 : 1 / (t1 - t0), scale) : [x0, x1];\n  };\n\n  scale.clamp = function(_) {\n    return arguments.length ? (clamp = !!_, scale) : clamp;\n  };\n\n  scale.interpolator = function(_) {\n    return arguments.length ? (interpolator = _, scale) : interpolator;\n  };\n\n  function range(interpolate) {\n    return function(_) {\n      var r0, r1;\n      return arguments.length ? ([r0, r1] = _, interpolator = interpolate(r0, r1), scale) : [interpolator(0), interpolator(1)];\n    };\n  }\n\n  scale.range = range(d3_interpolate__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n  scale.rangeRound = range(d3_interpolate__WEBPACK_IMPORTED_MODULE_2__[\"default\"]);\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  return function(t) {\n    transform = t, t0 = t(x0), t1 = t(x1), k10 = t0 === t1 ? 0 : 1 / (t1 - t0);\n    return scale;\n  };\n}\n\nfunction copy(source, target) {\n  return target\n      .domain(source.domain())\n      .interpolator(source.interpolator())\n      .clamp(source.clamp())\n      .unknown(source.unknown());\n}\n\nfunction sequential() {\n  var scale = (0,_linear_js__WEBPACK_IMPORTED_MODULE_3__.linearish)(transformer()(_continuous_js__WEBPACK_IMPORTED_MODULE_0__.identity));\n\n  scale.copy = function() {\n    return copy(scale, sequential());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_4__.initInterpolator.apply(scale, arguments);\n}\n\nfunction sequentialLog() {\n  var scale = (0,_log_js__WEBPACK_IMPORTED_MODULE_5__.loggish)(transformer()).domain([1, 10]);\n\n  scale.copy = function() {\n    return copy(scale, sequentialLog()).base(scale.base());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_4__.initInterpolator.apply(scale, arguments);\n}\n\nfunction sequentialSymlog() {\n  var scale = (0,_symlog_js__WEBPACK_IMPORTED_MODULE_6__.symlogish)(transformer());\n\n  scale.copy = function() {\n    return copy(scale, sequentialSymlog()).constant(scale.constant());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_4__.initInterpolator.apply(scale, arguments);\n}\n\nfunction sequentialPow() {\n  var scale = (0,_pow_js__WEBPACK_IMPORTED_MODULE_7__.powish)(transformer());\n\n  scale.copy = function() {\n    return copy(scale, sequentialPow()).exponent(scale.exponent());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_4__.initInterpolator.apply(scale, arguments);\n}\n\nfunction sequentialSqrt() {\n  return sequentialPow.apply(null, arguments).exponent(0.5);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/sequential.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/symlog.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-scale/src/symlog.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ symlog),\n/* harmony export */   symlogish: () => (/* binding */ symlogish)\n/* harmony export */ });\n/* harmony import */ var _linear_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./linear.js */ \"../../node_modules/d3-scale/src/linear.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\n\nfunction transformSymlog(c) {\n  return function(x) {\n    return Math.sign(x) * Math.log1p(Math.abs(x / c));\n  };\n}\n\nfunction transformSymexp(c) {\n  return function(x) {\n    return Math.sign(x) * Math.expm1(Math.abs(x)) * c;\n  };\n}\n\nfunction symlogish(transform) {\n  var c = 1, scale = transform(transformSymlog(c), transformSymexp(c));\n\n  scale.constant = function(_) {\n    return arguments.length ? transform(transformSymlog(c = +_), transformSymexp(c)) : c;\n  };\n\n  return (0,_linear_js__WEBPACK_IMPORTED_MODULE_0__.linearish)(scale);\n}\n\nfunction symlog() {\n  var scale = symlogish((0,_continuous_js__WEBPACK_IMPORTED_MODULE_1__.transformer)());\n\n  scale.copy = function() {\n    return (0,_continuous_js__WEBPACK_IMPORTED_MODULE_1__.copy)(scale, symlog()).constant(scale.constant());\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_2__.initRange.apply(scale, arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/symlog.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/threshold.js":
/*!****************************************************!*\
  !*** ../../node_modules/d3-scale/src/threshold.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ threshold)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisect.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\nfunction threshold() {\n  var domain = [0.5],\n      range = [0, 1],\n      unknown,\n      n = 1;\n\n  function scale(x) {\n    return x != null && x <= x ? range[(0,d3_array__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(domain, x, 0, n)] : unknown;\n  }\n\n  scale.domain = function(_) {\n    return arguments.length ? (domain = Array.from(_), n = Math.min(domain.length, range.length - 1), scale) : domain.slice();\n  };\n\n  scale.range = function(_) {\n    return arguments.length ? (range = Array.from(_), n = Math.min(domain.length, range.length - 1), scale) : range.slice();\n  };\n\n  scale.invertExtent = function(y) {\n    var i = range.indexOf(y);\n    return [domain[i - 1], domain[i]];\n  };\n\n  scale.unknown = function(_) {\n    return arguments.length ? (unknown = _, scale) : unknown;\n  };\n\n  scale.copy = function() {\n    return threshold()\n        .domain(domain)\n        .range(range)\n        .unknown(unknown);\n  };\n\n  return _init_js__WEBPACK_IMPORTED_MODULE_1__.initRange.apply(scale, arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/threshold.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/tickFormat.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-scale/src/tickFormat.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ tickFormat)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/formatSpecifier.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionPrefix.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/defaultLocale.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionRound.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-format */ \"../../node_modules/d3-format/src/precisionFixed.js\");\n\n\n\nfunction tickFormat(start, stop, count, specifier) {\n  var step = (0,d3_array__WEBPACK_IMPORTED_MODULE_0__.tickStep)(start, stop, count),\n      precision;\n  specifier = (0,d3_format__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(specifier == null ? \",f\" : specifier);\n  switch (specifier.type) {\n    case \"s\": {\n      var value = Math.max(Math.abs(start), Math.abs(stop));\n      if (specifier.precision == null && !isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(step, value))) specifier.precision = precision;\n      return (0,d3_format__WEBPACK_IMPORTED_MODULE_3__.formatPrefix)(specifier, value);\n    }\n    case \"\":\n    case \"e\":\n    case \"g\":\n    case \"p\":\n    case \"r\": {\n      if (specifier.precision == null && !isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(step, Math.max(Math.abs(start), Math.abs(stop))))) specifier.precision = precision - (specifier.type === \"e\");\n      break;\n    }\n    case \"f\":\n    case \"%\": {\n      if (specifier.precision == null && !isNaN(precision = (0,d3_format__WEBPACK_IMPORTED_MODULE_5__[\"default\"])(step))) specifier.precision = precision - (specifier.type === \"%\") * 2;\n      break;\n    }\n  }\n  return (0,d3_format__WEBPACK_IMPORTED_MODULE_3__.format)(specifier);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/tickFormat.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/time.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-scale/src/time.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   calendar: () => (/* binding */ calendar),\n/* harmony export */   \"default\": () => (/* binding */ time)\n/* harmony export */ });\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/ticks.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/year.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/month.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/week.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/day.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/hour.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/minute.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/second.js\");\n/* harmony import */ var d3_time_format__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! d3-time-format */ \"../../node_modules/d3-time-format/src/defaultLocale.js\");\n/* harmony import */ var _continuous_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./continuous.js */ \"../../node_modules/d3-scale/src/continuous.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n/* harmony import */ var _nice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./nice.js */ \"../../node_modules/d3-scale/src/nice.js\");\n\n\n\n\n\n\nfunction date(t) {\n  return new Date(t);\n}\n\nfunction number(t) {\n  return t instanceof Date ? +t : +new Date(+t);\n}\n\nfunction calendar(ticks, tickInterval, year, month, week, day, hour, minute, second, format) {\n  var scale = (0,_continuous_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(),\n      invert = scale.invert,\n      domain = scale.domain;\n\n  var formatMillisecond = format(\".%L\"),\n      formatSecond = format(\":%S\"),\n      formatMinute = format(\"%I:%M\"),\n      formatHour = format(\"%I %p\"),\n      formatDay = format(\"%a %d\"),\n      formatWeek = format(\"%b %d\"),\n      formatMonth = format(\"%B\"),\n      formatYear = format(\"%Y\");\n\n  function tickFormat(date) {\n    return (second(date) < date ? formatMillisecond\n        : minute(date) < date ? formatSecond\n        : hour(date) < date ? formatMinute\n        : day(date) < date ? formatHour\n        : month(date) < date ? (week(date) < date ? formatDay : formatWeek)\n        : year(date) < date ? formatMonth\n        : formatYear)(date);\n  }\n\n  scale.invert = function(y) {\n    return new Date(invert(y));\n  };\n\n  scale.domain = function(_) {\n    return arguments.length ? domain(Array.from(_, number)) : domain().map(date);\n  };\n\n  scale.ticks = function(interval) {\n    var d = domain();\n    return ticks(d[0], d[d.length - 1], interval == null ? 10 : interval);\n  };\n\n  scale.tickFormat = function(count, specifier) {\n    return specifier == null ? tickFormat : format(specifier);\n  };\n\n  scale.nice = function(interval) {\n    var d = domain();\n    if (!interval || typeof interval.range !== \"function\") interval = tickInterval(d[0], d[d.length - 1], interval == null ? 10 : interval);\n    return interval ? domain((0,_nice_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(d, interval)) : scale;\n  };\n\n  scale.copy = function() {\n    return (0,_continuous_js__WEBPACK_IMPORTED_MODULE_0__.copy)(scale, calendar(ticks, tickInterval, year, month, week, day, hour, minute, second, format));\n  };\n\n  return scale;\n}\n\nfunction time() {\n  return _init_js__WEBPACK_IMPORTED_MODULE_2__.initRange.apply(calendar(d3_time__WEBPACK_IMPORTED_MODULE_3__.timeTicks, d3_time__WEBPACK_IMPORTED_MODULE_3__.timeTickInterval, d3_time__WEBPACK_IMPORTED_MODULE_4__.timeYear, d3_time__WEBPACK_IMPORTED_MODULE_5__.timeMonth, d3_time__WEBPACK_IMPORTED_MODULE_6__.timeSunday, d3_time__WEBPACK_IMPORTED_MODULE_7__.timeDay, d3_time__WEBPACK_IMPORTED_MODULE_8__.timeHour, d3_time__WEBPACK_IMPORTED_MODULE_9__.timeMinute, d3_time__WEBPACK_IMPORTED_MODULE_10__.second, d3_time_format__WEBPACK_IMPORTED_MODULE_11__.timeFormat).domain([new Date(2000, 0, 1), new Date(2000, 0, 2)]), arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/time.js?");

/***/ }),

/***/ "../../node_modules/d3-scale/src/utcTime.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-scale/src/utcTime.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ utcTime)\n/* harmony export */ });\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/ticks.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/year.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/month.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/week.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/day.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/hour.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/minute.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/second.js\");\n/* harmony import */ var d3_time_format__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! d3-time-format */ \"../../node_modules/d3-time-format/src/defaultLocale.js\");\n/* harmony import */ var _time_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./time.js */ \"../../node_modules/d3-scale/src/time.js\");\n/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./init.js */ \"../../node_modules/d3-scale/src/init.js\");\n\n\n\n\n\nfunction utcTime() {\n  return _init_js__WEBPACK_IMPORTED_MODULE_0__.initRange.apply((0,_time_js__WEBPACK_IMPORTED_MODULE_1__.calendar)(d3_time__WEBPACK_IMPORTED_MODULE_2__.utcTicks, d3_time__WEBPACK_IMPORTED_MODULE_2__.utcTickInterval, d3_time__WEBPACK_IMPORTED_MODULE_3__.utcYear, d3_time__WEBPACK_IMPORTED_MODULE_4__.utcMonth, d3_time__WEBPACK_IMPORTED_MODULE_5__.utcSunday, d3_time__WEBPACK_IMPORTED_MODULE_6__.utcDay, d3_time__WEBPACK_IMPORTED_MODULE_7__.utcHour, d3_time__WEBPACK_IMPORTED_MODULE_8__.utcMinute, d3_time__WEBPACK_IMPORTED_MODULE_9__.second, d3_time_format__WEBPACK_IMPORTED_MODULE_10__.utcFormat).domain([Date.UTC(2000, 0, 1), Date.UTC(2000, 0, 2)]), arguments);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-scale/src/utcTime.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/arc.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-shape/src/arc.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-shape/src/constant.js\");\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./math.js */ \"../../node_modules/d3-shape/src/math.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-shape/src/path.js\");\n\n\n\n\nfunction arcInnerRadius(d) {\n  return d.innerRadius;\n}\n\nfunction arcOuterRadius(d) {\n  return d.outerRadius;\n}\n\nfunction arcStartAngle(d) {\n  return d.startAngle;\n}\n\nfunction arcEndAngle(d) {\n  return d.endAngle;\n}\n\nfunction arcPadAngle(d) {\n  return d && d.padAngle; // Note: optional!\n}\n\nfunction intersect(x0, y0, x1, y1, x2, y2, x3, y3) {\n  var x10 = x1 - x0, y10 = y1 - y0,\n      x32 = x3 - x2, y32 = y3 - y2,\n      t = y32 * x10 - x32 * y10;\n  if (t * t < _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) return;\n  t = (x32 * (y0 - y2) - y32 * (x0 - x2)) / t;\n  return [x0 + t * x10, y0 + t * y10];\n}\n\n// Compute perpendicular offset line of length rc.\n// http://mathworld.wolfram.com/Circle-LineIntersection.html\nfunction cornerTangents(x0, y0, x1, y1, r1, rc, cw) {\n  var x01 = x0 - x1,\n      y01 = y0 - y1,\n      lo = (cw ? rc : -rc) / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(x01 * x01 + y01 * y01),\n      ox = lo * y01,\n      oy = -lo * x01,\n      x11 = x0 + ox,\n      y11 = y0 + oy,\n      x10 = x1 + ox,\n      y10 = y1 + oy,\n      x00 = (x11 + x10) / 2,\n      y00 = (y11 + y10) / 2,\n      dx = x10 - x11,\n      dy = y10 - y11,\n      d2 = dx * dx + dy * dy,\n      r = r1 - rc,\n      D = x11 * y10 - x10 * y11,\n      d = (dy < 0 ? -1 : 1) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.max)(0, r * r * d2 - D * D)),\n      cx0 = (D * dy - dx * d) / d2,\n      cy0 = (-D * dx - dy * d) / d2,\n      cx1 = (D * dy + dx * d) / d2,\n      cy1 = (-D * dx + dy * d) / d2,\n      dx0 = cx0 - x00,\n      dy0 = cy0 - y00,\n      dx1 = cx1 - x00,\n      dy1 = cy1 - y00;\n\n  // Pick the closer of the two intersection points.\n  // TODO Is there a faster way to determine which intersection to use?\n  if (dx0 * dx0 + dy0 * dy0 > dx1 * dx1 + dy1 * dy1) cx0 = cx1, cy0 = cy1;\n\n  return {\n    cx: cx0,\n    cy: cy0,\n    x01: -ox,\n    y01: -oy,\n    x11: cx0 * (r1 / r - 1),\n    y11: cy0 * (r1 / r - 1)\n  };\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {\n  var innerRadius = arcInnerRadius,\n      outerRadius = arcOuterRadius,\n      cornerRadius = (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(0),\n      padRadius = null,\n      startAngle = arcStartAngle,\n      endAngle = arcEndAngle,\n      padAngle = arcPadAngle,\n      context = null,\n      path = (0,_path_js__WEBPACK_IMPORTED_MODULE_2__.withPath)(arc);\n\n  function arc() {\n    var buffer,\n        r,\n        r0 = +innerRadius.apply(this, arguments),\n        r1 = +outerRadius.apply(this, arguments),\n        a0 = startAngle.apply(this, arguments) - _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi,\n        a1 = endAngle.apply(this, arguments) - _math_js__WEBPACK_IMPORTED_MODULE_0__.halfPi,\n        da = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(a1 - a0),\n        cw = a1 > a0;\n\n    if (!context) context = buffer = path();\n\n    // Ensure that the outer radius is always larger than the inner radius.\n    if (r1 < r0) r = r1, r1 = r0, r0 = r;\n\n    // Is it a point?\n    if (!(r1 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon)) context.moveTo(0, 0);\n\n    // Or is it a circle or annulus?\n    else if (da > _math_js__WEBPACK_IMPORTED_MODULE_0__.tau - _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n      context.moveTo(r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a0), r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a0));\n      context.arc(0, 0, r1, a0, a1, !cw);\n      if (r0 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n        context.moveTo(r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a1), r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a1));\n        context.arc(0, 0, r0, a1, a0, cw);\n      }\n    }\n\n    // Or is it a circular or annular sector?\n    else {\n      var a01 = a0,\n          a11 = a1,\n          a00 = a0,\n          a10 = a1,\n          da0 = da,\n          da1 = da,\n          ap = padAngle.apply(this, arguments) / 2,\n          rp = (ap > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) && (padRadius ? +padRadius.apply(this, arguments) : (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(r0 * r0 + r1 * r1)),\n          rc = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.abs)(r1 - r0) / 2, +cornerRadius.apply(this, arguments)),\n          rc0 = rc,\n          rc1 = rc,\n          t0,\n          t1;\n\n      // Apply padding? Note that since r1 ≥ r0, da1 ≥ da0.\n      if (rp > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n        var p0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(rp / r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(ap)),\n            p1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.asin)(rp / r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(ap));\n        if ((da0 -= p0 * 2) > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) p0 *= (cw ? 1 : -1), a00 += p0, a10 -= p0;\n        else da0 = 0, a00 = a10 = (a0 + a1) / 2;\n        if ((da1 -= p1 * 2) > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) p1 *= (cw ? 1 : -1), a01 += p1, a11 -= p1;\n        else da1 = 0, a01 = a11 = (a0 + a1) / 2;\n      }\n\n      var x01 = r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a01),\n          y01 = r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a01),\n          x10 = r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a10),\n          y10 = r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a10);\n\n      // Apply rounded corners?\n      if (rc > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n        var x11 = r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a11),\n            y11 = r1 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a11),\n            x00 = r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a00),\n            y00 = r0 * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a00),\n            oc;\n\n        // Restrict the corner radius according to the sector angle. If this\n        // intersection fails, it’s probably because the arc is too small, so\n        // disable the corner radius entirely.\n        if (da < _math_js__WEBPACK_IMPORTED_MODULE_0__.pi) {\n          if (oc = intersect(x01, y01, x00, y00, x11, y11, x10, y10)) {\n            var ax = x01 - oc[0],\n                ay = y01 - oc[1],\n                bx = x11 - oc[0],\n                by = y11 - oc[1],\n                kc = 1 / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.acos)((ax * bx + ay * by) / ((0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(ax * ax + ay * ay) * (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(bx * bx + by * by))) / 2),\n                lc = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(oc[0] * oc[0] + oc[1] * oc[1]);\n            rc0 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)(rc, (r0 - lc) / (kc - 1));\n            rc1 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)(rc, (r1 - lc) / (kc + 1));\n          } else {\n            rc0 = rc1 = 0;\n          }\n        }\n      }\n\n      // Is the sector collapsed to a line?\n      if (!(da1 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon)) context.moveTo(x01, y01);\n\n      // Does the sector’s outer ring have rounded corners?\n      else if (rc1 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n        t0 = cornerTangents(x00, y00, x01, y01, r1, rc1, cw);\n        t1 = cornerTangents(x11, y11, x10, y10, r1, rc1, cw);\n\n        context.moveTo(t0.cx + t0.x01, t0.cy + t0.y01);\n\n        // Have the corners merged?\n        if (rc1 < rc) context.arc(t0.cx, t0.cy, rc1, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y01, t0.x01), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y01, t1.x01), !cw);\n\n        // Otherwise, draw the two corners and the ring.\n        else {\n          context.arc(t0.cx, t0.cy, rc1, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y01, t0.x01), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y11, t0.x11), !cw);\n          context.arc(0, 0, r1, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.cy + t0.y11, t0.cx + t0.x11), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.cy + t1.y11, t1.cx + t1.x11), !cw);\n          context.arc(t1.cx, t1.cy, rc1, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y11, t1.x11), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y01, t1.x01), !cw);\n        }\n      }\n\n      // Or is the outer ring just a circular arc?\n      else context.moveTo(x01, y01), context.arc(0, 0, r1, a01, a11, !cw);\n\n      // Is there no inner ring, and it’s a circular sector?\n      // Or perhaps it’s an annular sector collapsed due to padding?\n      if (!(r0 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) || !(da0 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon)) context.lineTo(x10, y10);\n\n      // Does the sector’s inner ring (or point) have rounded corners?\n      else if (rc0 > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n        t0 = cornerTangents(x10, y10, x11, y11, r0, -rc0, cw);\n        t1 = cornerTangents(x01, y01, x00, y00, r0, -rc0, cw);\n\n        context.lineTo(t0.cx + t0.x01, t0.cy + t0.y01);\n\n        // Have the corners merged?\n        if (rc0 < rc) context.arc(t0.cx, t0.cy, rc0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y01, t0.x01), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y01, t1.x01), !cw);\n\n        // Otherwise, draw the two corners and the ring.\n        else {\n          context.arc(t0.cx, t0.cy, rc0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y01, t0.x01), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.y11, t0.x11), !cw);\n          context.arc(0, 0, r0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t0.cy + t0.y11, t0.cx + t0.x11), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.cy + t1.y11, t1.cx + t1.x11), cw);\n          context.arc(t1.cx, t1.cy, rc0, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y11, t1.x11), (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.atan2)(t1.y01, t1.x01), !cw);\n        }\n      }\n\n      // Or is the inner ring just a circular arc?\n      else context.arc(0, 0, r0, a10, a00, cw);\n    }\n\n    context.closePath();\n\n    if (buffer) return context = null, buffer + \"\" || null;\n  }\n\n  arc.centroid = function() {\n    var r = (+innerRadius.apply(this, arguments) + +outerRadius.apply(this, arguments)) / 2,\n        a = (+startAngle.apply(this, arguments) + +endAngle.apply(this, arguments)) / 2 - _math_js__WEBPACK_IMPORTED_MODULE_0__.pi / 2;\n    return [(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a) * r, (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a) * r];\n  };\n\n  arc.innerRadius = function(_) {\n    return arguments.length ? (innerRadius = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : innerRadius;\n  };\n\n  arc.outerRadius = function(_) {\n    return arguments.length ? (outerRadius = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : outerRadius;\n  };\n\n  arc.cornerRadius = function(_) {\n    return arguments.length ? (cornerRadius = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : cornerRadius;\n  };\n\n  arc.padRadius = function(_) {\n    return arguments.length ? (padRadius = _ == null ? null : typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : padRadius;\n  };\n\n  arc.startAngle = function(_) {\n    return arguments.length ? (startAngle = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : startAngle;\n  };\n\n  arc.endAngle = function(_) {\n    return arguments.length ? (endAngle = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : endAngle;\n  };\n\n  arc.padAngle = function(_) {\n    return arguments.length ? (padAngle = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"])(+_), arc) : padAngle;\n  };\n\n  arc.context = function(_) {\n    return arguments.length ? ((context = _ == null ? null : _), arc) : context;\n  };\n\n  return arc;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/arc.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/area.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-shape/src/area.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./array.js */ \"../../node_modules/d3-shape/src/array.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-shape/src/constant.js\");\n/* harmony import */ var _curve_linear_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curve/linear.js */ \"../../node_modules/d3-shape/src/curve/linear.js\");\n/* harmony import */ var _line_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./line.js */ \"../../node_modules/d3-shape/src/line.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-shape/src/path.js\");\n/* harmony import */ var _point_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./point.js */ \"../../node_modules/d3-shape/src/point.js\");\n\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x0, y0, y1) {\n  var x1 = null,\n      defined = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(true),\n      context = null,\n      curve = _curve_linear_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n      output = null,\n      path = (0,_path_js__WEBPACK_IMPORTED_MODULE_2__.withPath)(area);\n\n  x0 = typeof x0 === \"function\" ? x0 : (x0 === undefined) ? _point_js__WEBPACK_IMPORTED_MODULE_3__.x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+x0);\n  y0 = typeof y0 === \"function\" ? y0 : (y0 === undefined) ? (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(0) : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+y0);\n  y1 = typeof y1 === \"function\" ? y1 : (y1 === undefined) ? _point_js__WEBPACK_IMPORTED_MODULE_3__.y : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+y1);\n\n  function area(data) {\n    var i,\n        j,\n        k,\n        n = (data = (0,_array_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(data)).length,\n        d,\n        defined0 = false,\n        buffer,\n        x0z = new Array(n),\n        y0z = new Array(n);\n\n    if (context == null) output = curve(buffer = path());\n\n    for (i = 0; i <= n; ++i) {\n      if (!(i < n && defined(d = data[i], i, data)) === defined0) {\n        if (defined0 = !defined0) {\n          j = i;\n          output.areaStart();\n          output.lineStart();\n        } else {\n          output.lineEnd();\n          output.lineStart();\n          for (k = i - 1; k >= j; --k) {\n            output.point(x0z[k], y0z[k]);\n          }\n          output.lineEnd();\n          output.areaEnd();\n        }\n      }\n      if (defined0) {\n        x0z[i] = +x0(d, i, data), y0z[i] = +y0(d, i, data);\n        output.point(x1 ? +x1(d, i, data) : x0z[i], y1 ? +y1(d, i, data) : y0z[i]);\n      }\n    }\n\n    if (buffer) return output = null, buffer + \"\" || null;\n  }\n\n  function arealine() {\n    return (0,_line_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"])().defined(defined).curve(curve).context(context);\n  }\n\n  area.x = function(_) {\n    return arguments.length ? (x0 = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), x1 = null, area) : x0;\n  };\n\n  area.x0 = function(_) {\n    return arguments.length ? (x0 = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), area) : x0;\n  };\n\n  area.x1 = function(_) {\n    return arguments.length ? (x1 = _ == null ? null : typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), area) : x1;\n  };\n\n  area.y = function(_) {\n    return arguments.length ? (y0 = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), y1 = null, area) : y0;\n  };\n\n  area.y0 = function(_) {\n    return arguments.length ? (y0 = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), area) : y0;\n  };\n\n  area.y1 = function(_) {\n    return arguments.length ? (y1 = _ == null ? null : typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), area) : y1;\n  };\n\n  area.lineX0 =\n  area.lineY0 = function() {\n    return arealine().x(x0).y(y0);\n  };\n\n  area.lineY1 = function() {\n    return arealine().x(x0).y(y1);\n  };\n\n  area.lineX1 = function() {\n    return arealine().x(x1).y(y0);\n  };\n\n  area.defined = function(_) {\n    return arguments.length ? (defined = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(!!_), area) : defined;\n  };\n\n  area.curve = function(_) {\n    return arguments.length ? (curve = _, context != null && (output = curve(context)), area) : curve;\n  };\n\n  area.context = function(_) {\n    return arguments.length ? (_ == null ? context = output = null : output = curve(context = _), area) : context;\n  };\n\n  return area;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/area.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/array.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-shape/src/array.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   slice: () => (/* binding */ slice)\n/* harmony export */ });\nvar slice = Array.prototype.slice;\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return typeof x === \"object\" && \"length\" in x\n    ? x // Array, TypedArray, NodeList, array-like\n    : Array.from(x); // Map, Set, iterable, string, or anything else\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/array.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/constant.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-shape/src/constant.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {\n  return function constant() {\n    return x;\n  };\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/constant.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/basis.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/basis.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Basis: () => (/* binding */ Basis),\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   point: () => (/* binding */ point)\n/* harmony export */ });\nfunction point(that, x, y) {\n  that._context.bezierCurveTo(\n    (2 * that._x0 + that._x1) / 3,\n    (2 * that._y0 + that._y1) / 3,\n    (that._x0 + 2 * that._x1) / 3,\n    (that._y0 + 2 * that._y1) / 3,\n    (that._x0 + 4 * that._x1 + x) / 6,\n    (that._y0 + 4 * that._y1 + y) / 6\n  );\n}\n\nfunction Basis(context) {\n  this._context = context;\n}\n\nBasis.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 =\n    this._y0 = this._y1 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 3: point(this, this._x1, this._y1); // falls through\n      case 2: this._context.lineTo(this._x1, this._y1); break;\n    }\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; this._context.lineTo((5 * this._x0 + this._x1) / 6, (5 * this._y0 + this._y1) / 6); // falls through\n      default: point(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = x;\n    this._y0 = this._y1, this._y1 = y;\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new Basis(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/basis.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/basisClosed.js":
/*!************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/basisClosed.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-shape/src/noop.js\");\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-shape/src/curve/basis.js\");\n\n\n\nfunction BasisClosed(context) {\n  this._context = context;\n}\n\nBasisClosed.prototype = {\n  areaStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  areaEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 =\n    this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 1: {\n        this._context.moveTo(this._x2, this._y2);\n        this._context.closePath();\n        break;\n      }\n      case 2: {\n        this._context.moveTo((this._x2 + 2 * this._x3) / 3, (this._y2 + 2 * this._y3) / 3);\n        this._context.lineTo((this._x3 + 2 * this._x2) / 3, (this._y3 + 2 * this._y2) / 3);\n        this._context.closePath();\n        break;\n      }\n      case 3: {\n        this.point(this._x2, this._y2);\n        this.point(this._x3, this._y3);\n        this.point(this._x4, this._y4);\n        break;\n      }\n    }\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._x2 = x, this._y2 = y; break;\n      case 1: this._point = 2; this._x3 = x, this._y3 = y; break;\n      case 2: this._point = 3; this._x4 = x, this._y4 = y; this._context.moveTo((this._x0 + 4 * this._x1 + x) / 6, (this._y0 + 4 * this._y1 + y) / 6); break;\n      default: (0,_basis_js__WEBPACK_IMPORTED_MODULE_1__.point)(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = x;\n    this._y0 = this._y1, this._y1 = y;\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new BasisClosed(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/basisClosed.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/basisOpen.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/basisOpen.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-shape/src/curve/basis.js\");\n\n\nfunction BasisOpen(context) {\n  this._context = context;\n}\n\nBasisOpen.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 =\n    this._y0 = this._y1 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._line || (this._line !== 0 && this._point === 3)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; var x0 = (this._x0 + 4 * this._x1 + x) / 6, y0 = (this._y0 + 4 * this._y1 + y) / 6; this._line ? this._context.lineTo(x0, y0) : this._context.moveTo(x0, y0); break;\n      case 3: this._point = 4; // falls through\n      default: (0,_basis_js__WEBPACK_IMPORTED_MODULE_0__.point)(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = x;\n    this._y0 = this._y1, this._y1 = y;\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new BasisOpen(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/basisOpen.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/bundle.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/bundle.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _basis_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./basis.js */ \"../../node_modules/d3-shape/src/curve/basis.js\");\n\n\nfunction Bundle(context, beta) {\n  this._basis = new _basis_js__WEBPACK_IMPORTED_MODULE_0__.Basis(context);\n  this._beta = beta;\n}\n\nBundle.prototype = {\n  lineStart: function() {\n    this._x = [];\n    this._y = [];\n    this._basis.lineStart();\n  },\n  lineEnd: function() {\n    var x = this._x,\n        y = this._y,\n        j = x.length - 1;\n\n    if (j > 0) {\n      var x0 = x[0],\n          y0 = y[0],\n          dx = x[j] - x0,\n          dy = y[j] - y0,\n          i = -1,\n          t;\n\n      while (++i <= j) {\n        t = i / j;\n        this._basis.point(\n          this._beta * x[i] + (1 - this._beta) * (x0 + t * dx),\n          this._beta * y[i] + (1 - this._beta) * (y0 + t * dy)\n        );\n      }\n    }\n\n    this._x = this._y = null;\n    this._basis.lineEnd();\n  },\n  point: function(x, y) {\n    this._x.push(+x);\n    this._y.push(+y);\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(beta) {\n\n  function bundle(context) {\n    return beta === 1 ? new _basis_js__WEBPACK_IMPORTED_MODULE_0__.Basis(context) : new Bundle(context, beta);\n  }\n\n  bundle.beta = function(beta) {\n    return custom(+beta);\n  };\n\n  return bundle;\n})(0.85));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/bundle.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/cardinal.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/cardinal.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Cardinal: () => (/* binding */ Cardinal),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   point: () => (/* binding */ point)\n/* harmony export */ });\nfunction point(that, x, y) {\n  that._context.bezierCurveTo(\n    that._x1 + that._k * (that._x2 - that._x0),\n    that._y1 + that._k * (that._y2 - that._y0),\n    that._x2 + that._k * (that._x1 - x),\n    that._y2 + that._k * (that._y1 - y),\n    that._x2,\n    that._y2\n  );\n}\n\nfunction Cardinal(context, tension) {\n  this._context = context;\n  this._k = (1 - tension) / 6;\n}\n\nCardinal.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 =\n    this._y0 = this._y1 = this._y2 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 2: this._context.lineTo(this._x2, this._y2); break;\n      case 3: point(this, this._x1, this._y1); break;\n    }\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; this._x1 = x, this._y1 = y; break;\n      case 2: this._point = 3; // falls through\n      default: point(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(tension) {\n\n  function cardinal(context) {\n    return new Cardinal(context, tension);\n  }\n\n  cardinal.tension = function(tension) {\n    return custom(+tension);\n  };\n\n  return cardinal;\n})(0));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/cardinal.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/cardinalClosed.js":
/*!***************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/cardinalClosed.js ***!
  \***************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CardinalClosed: () => (/* binding */ CardinalClosed),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-shape/src/noop.js\");\n/* harmony import */ var _cardinal_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./cardinal.js */ \"../../node_modules/d3-shape/src/curve/cardinal.js\");\n\n\n\nfunction CardinalClosed(context, tension) {\n  this._context = context;\n  this._k = (1 - tension) / 6;\n}\n\nCardinalClosed.prototype = {\n  areaStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  areaEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 = this._x5 =\n    this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = this._y5 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 1: {\n        this._context.moveTo(this._x3, this._y3);\n        this._context.closePath();\n        break;\n      }\n      case 2: {\n        this._context.lineTo(this._x3, this._y3);\n        this._context.closePath();\n        break;\n      }\n      case 3: {\n        this.point(this._x3, this._y3);\n        this.point(this._x4, this._y4);\n        this.point(this._x5, this._y5);\n        break;\n      }\n    }\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._x3 = x, this._y3 = y; break;\n      case 1: this._point = 2; this._context.moveTo(this._x4 = x, this._y4 = y); break;\n      case 2: this._point = 3; this._x5 = x, this._y5 = y; break;\n      default: (0,_cardinal_js__WEBPACK_IMPORTED_MODULE_1__.point)(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(tension) {\n\n  function cardinal(context) {\n    return new CardinalClosed(context, tension);\n  }\n\n  cardinal.tension = function(tension) {\n    return custom(+tension);\n  };\n\n  return cardinal;\n})(0));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/cardinalClosed.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/cardinalOpen.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/cardinalOpen.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   CardinalOpen: () => (/* binding */ CardinalOpen),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cardinal_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./cardinal.js */ \"../../node_modules/d3-shape/src/curve/cardinal.js\");\n\n\nfunction CardinalOpen(context, tension) {\n  this._context = context;\n  this._k = (1 - tension) / 6;\n}\n\nCardinalOpen.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 =\n    this._y0 = this._y1 = this._y2 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._line || (this._line !== 0 && this._point === 3)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; this._line ? this._context.lineTo(this._x2, this._y2) : this._context.moveTo(this._x2, this._y2); break;\n      case 3: this._point = 4; // falls through\n      default: (0,_cardinal_js__WEBPACK_IMPORTED_MODULE_0__.point)(this, x, y); break;\n    }\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(tension) {\n\n  function cardinal(context) {\n    return new CardinalOpen(context, tension);\n  }\n\n  cardinal.tension = function(tension) {\n    return custom(+tension);\n  };\n\n  return cardinal;\n})(0));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/cardinalOpen.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/catmullRom.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/catmullRom.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   point: () => (/* binding */ point)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n/* harmony import */ var _cardinal_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./cardinal.js */ \"../../node_modules/d3-shape/src/curve/cardinal.js\");\n\n\n\nfunction point(that, x, y) {\n  var x1 = that._x1,\n      y1 = that._y1,\n      x2 = that._x2,\n      y2 = that._y2;\n\n  if (that._l01_a > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n    var a = 2 * that._l01_2a + 3 * that._l01_a * that._l12_a + that._l12_2a,\n        n = 3 * that._l01_a * (that._l01_a + that._l12_a);\n    x1 = (x1 * a - that._x0 * that._l12_2a + that._x2 * that._l01_2a) / n;\n    y1 = (y1 * a - that._y0 * that._l12_2a + that._y2 * that._l01_2a) / n;\n  }\n\n  if (that._l23_a > _math_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) {\n    var b = 2 * that._l23_2a + 3 * that._l23_a * that._l12_a + that._l12_2a,\n        m = 3 * that._l23_a * (that._l23_a + that._l12_a);\n    x2 = (x2 * b + that._x1 * that._l23_2a - x * that._l12_2a) / m;\n    y2 = (y2 * b + that._y1 * that._l23_2a - y * that._l12_2a) / m;\n  }\n\n  that._context.bezierCurveTo(x1, y1, x2, y2, that._x2, that._y2);\n}\n\nfunction CatmullRom(context, alpha) {\n  this._context = context;\n  this._alpha = alpha;\n}\n\nCatmullRom.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 =\n    this._y0 = this._y1 = this._y2 = NaN;\n    this._l01_a = this._l12_a = this._l23_a =\n    this._l01_2a = this._l12_2a = this._l23_2a =\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 2: this._context.lineTo(this._x2, this._y2); break;\n      case 3: this.point(this._x2, this._y2); break;\n    }\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n\n    if (this._point) {\n      var x23 = this._x2 - x,\n          y23 = this._y2 - y;\n      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(x23 * x23 + y23 * y23, this._alpha));\n    }\n\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; // falls through\n      default: point(this, x, y); break;\n    }\n\n    this._l01_a = this._l12_a, this._l12_a = this._l23_a;\n    this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a;\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(alpha) {\n\n  function catmullRom(context) {\n    return alpha ? new CatmullRom(context, alpha) : new _cardinal_js__WEBPACK_IMPORTED_MODULE_1__.Cardinal(context, 0);\n  }\n\n  catmullRom.alpha = function(alpha) {\n    return custom(+alpha);\n  };\n\n  return catmullRom;\n})(0.5));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/catmullRom.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/catmullRomClosed.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/catmullRomClosed.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cardinalClosed_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./cardinalClosed.js */ \"../../node_modules/d3-shape/src/curve/cardinalClosed.js\");\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-shape/src/noop.js\");\n/* harmony import */ var _catmullRom_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./catmullRom.js */ \"../../node_modules/d3-shape/src/curve/catmullRom.js\");\n\n\n\n\nfunction CatmullRomClosed(context, alpha) {\n  this._context = context;\n  this._alpha = alpha;\n}\n\nCatmullRomClosed.prototype = {\n  areaStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  areaEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 = this._x5 =\n    this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = this._y5 = NaN;\n    this._l01_a = this._l12_a = this._l23_a =\n    this._l01_2a = this._l12_2a = this._l23_2a =\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 1: {\n        this._context.moveTo(this._x3, this._y3);\n        this._context.closePath();\n        break;\n      }\n      case 2: {\n        this._context.lineTo(this._x3, this._y3);\n        this._context.closePath();\n        break;\n      }\n      case 3: {\n        this.point(this._x3, this._y3);\n        this.point(this._x4, this._y4);\n        this.point(this._x5, this._y5);\n        break;\n      }\n    }\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n\n    if (this._point) {\n      var x23 = this._x2 - x,\n          y23 = this._y2 - y;\n      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(x23 * x23 + y23 * y23, this._alpha));\n    }\n\n    switch (this._point) {\n      case 0: this._point = 1; this._x3 = x, this._y3 = y; break;\n      case 1: this._point = 2; this._context.moveTo(this._x4 = x, this._y4 = y); break;\n      case 2: this._point = 3; this._x5 = x, this._y5 = y; break;\n      default: (0,_catmullRom_js__WEBPACK_IMPORTED_MODULE_1__.point)(this, x, y); break;\n    }\n\n    this._l01_a = this._l12_a, this._l12_a = this._l23_a;\n    this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a;\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(alpha) {\n\n  function catmullRom(context) {\n    return alpha ? new CatmullRomClosed(context, alpha) : new _cardinalClosed_js__WEBPACK_IMPORTED_MODULE_2__.CardinalClosed(context, 0);\n  }\n\n  catmullRom.alpha = function(alpha) {\n    return custom(+alpha);\n  };\n\n  return catmullRom;\n})(0.5));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/catmullRomClosed.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/catmullRomOpen.js":
/*!***************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/catmullRomOpen.js ***!
  \***************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _cardinalOpen_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./cardinalOpen.js */ \"../../node_modules/d3-shape/src/curve/cardinalOpen.js\");\n/* harmony import */ var _catmullRom_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./catmullRom.js */ \"../../node_modules/d3-shape/src/curve/catmullRom.js\");\n\n\n\nfunction CatmullRomOpen(context, alpha) {\n  this._context = context;\n  this._alpha = alpha;\n}\n\nCatmullRomOpen.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 = this._x2 =\n    this._y0 = this._y1 = this._y2 = NaN;\n    this._l01_a = this._l12_a = this._l23_a =\n    this._l01_2a = this._l12_2a = this._l23_2a =\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._line || (this._line !== 0 && this._point === 3)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n\n    if (this._point) {\n      var x23 = this._x2 - x,\n          y23 = this._y2 - y;\n      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(x23 * x23 + y23 * y23, this._alpha));\n    }\n\n    switch (this._point) {\n      case 0: this._point = 1; break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; this._line ? this._context.lineTo(this._x2, this._y2) : this._context.moveTo(this._x2, this._y2); break;\n      case 3: this._point = 4; // falls through\n      default: (0,_catmullRom_js__WEBPACK_IMPORTED_MODULE_0__.point)(this, x, y); break;\n    }\n\n    this._l01_a = this._l12_a, this._l12_a = this._l23_a;\n    this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a;\n    this._x0 = this._x1, this._x1 = this._x2, this._x2 = x;\n    this._y0 = this._y1, this._y1 = this._y2, this._y2 = y;\n  }\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function custom(alpha) {\n\n  function catmullRom(context) {\n    return alpha ? new CatmullRomOpen(context, alpha) : new _cardinalOpen_js__WEBPACK_IMPORTED_MODULE_1__.CardinalOpen(context, 0);\n  }\n\n  catmullRom.alpha = function(alpha) {\n    return custom(+alpha);\n  };\n\n  return catmullRom;\n})(0.5));\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/catmullRomOpen.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/linear.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/linear.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction Linear(context) {\n  this._context = context;\n}\n\nLinear.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; // falls through\n      default: this._context.lineTo(x, y); break;\n    }\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new Linear(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/linear.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/linearClosed.js":
/*!*************************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/linearClosed.js ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../noop.js */ \"../../node_modules/d3-shape/src/noop.js\");\n\n\nfunction LinearClosed(context) {\n  this._context = context;\n}\n\nLinearClosed.prototype = {\n  areaStart: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  areaEnd: _noop_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  lineStart: function() {\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (this._point) this._context.closePath();\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    if (this._point) this._context.lineTo(x, y);\n    else this._point = 1, this._context.moveTo(x, y);\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new LinearClosed(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/linearClosed.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/monotone.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/monotone.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   monotoneX: () => (/* binding */ monotoneX),\n/* harmony export */   monotoneY: () => (/* binding */ monotoneY)\n/* harmony export */ });\nfunction sign(x) {\n  return x < 0 ? -1 : 1;\n}\n\n// Calculate the slopes of the tangents (Hermite-type interpolation) based on\n// the following paper: Steffen, M. 1990. A Simple Method for Monotonic\n// Interpolation in One Dimension. Astronomy and Astrophysics, Vol. 239, NO.\n// NOV(II), P. 443, 1990.\nfunction slope3(that, x2, y2) {\n  var h0 = that._x1 - that._x0,\n      h1 = x2 - that._x1,\n      s0 = (that._y1 - that._y0) / (h0 || h1 < 0 && -0),\n      s1 = (y2 - that._y1) / (h1 || h0 < 0 && -0),\n      p = (s0 * h1 + s1 * h0) / (h0 + h1);\n  return (sign(s0) + sign(s1)) * Math.min(Math.abs(s0), Math.abs(s1), 0.5 * Math.abs(p)) || 0;\n}\n\n// Calculate a one-sided slope.\nfunction slope2(that, t) {\n  var h = that._x1 - that._x0;\n  return h ? (3 * (that._y1 - that._y0) / h - t) / 2 : t;\n}\n\n// According to https://en.wikipedia.org/wiki/Cubic_Hermite_spline#Representations\n// \"you can express cubic Hermite interpolation in terms of cubic Bézier curves\n// with respect to the four values p0, p0 + m0 / 3, p1 - m1 / 3, p1\".\nfunction point(that, t0, t1) {\n  var x0 = that._x0,\n      y0 = that._y0,\n      x1 = that._x1,\n      y1 = that._y1,\n      dx = (x1 - x0) / 3;\n  that._context.bezierCurveTo(x0 + dx, y0 + dx * t0, x1 - dx, y1 - dx * t1, x1, y1);\n}\n\nfunction MonotoneX(context) {\n  this._context = context;\n}\n\nMonotoneX.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x0 = this._x1 =\n    this._y0 = this._y1 =\n    this._t0 = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    switch (this._point) {\n      case 2: this._context.lineTo(this._x1, this._y1); break;\n      case 3: point(this, this._t0, slope2(this, this._t0)); break;\n    }\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    var t1 = NaN;\n\n    x = +x, y = +y;\n    if (x === this._x1 && y === this._y1) return; // Ignore coincident points.\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; break;\n      case 2: this._point = 3; point(this, slope2(this, t1 = slope3(this, x, y)), t1); break;\n      default: point(this, this._t0, t1 = slope3(this, x, y)); break;\n    }\n\n    this._x0 = this._x1, this._x1 = x;\n    this._y0 = this._y1, this._y1 = y;\n    this._t0 = t1;\n  }\n}\n\nfunction MonotoneY(context) {\n  this._context = new ReflectContext(context);\n}\n\n(MonotoneY.prototype = Object.create(MonotoneX.prototype)).point = function(x, y) {\n  MonotoneX.prototype.point.call(this, y, x);\n};\n\nfunction ReflectContext(context) {\n  this._context = context;\n}\n\nReflectContext.prototype = {\n  moveTo: function(x, y) { this._context.moveTo(y, x); },\n  closePath: function() { this._context.closePath(); },\n  lineTo: function(x, y) { this._context.lineTo(y, x); },\n  bezierCurveTo: function(x1, y1, x2, y2, x, y) { this._context.bezierCurveTo(y1, x1, y2, x2, y, x); }\n};\n\nfunction monotoneX(context) {\n  return new MonotoneX(context);\n}\n\nfunction monotoneY(context) {\n  return new MonotoneY(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/monotone.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/natural.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/natural.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\nfunction Natural(context) {\n  this._context = context;\n}\n\nNatural.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x = [];\n    this._y = [];\n  },\n  lineEnd: function() {\n    var x = this._x,\n        y = this._y,\n        n = x.length;\n\n    if (n) {\n      this._line ? this._context.lineTo(x[0], y[0]) : this._context.moveTo(x[0], y[0]);\n      if (n === 2) {\n        this._context.lineTo(x[1], y[1]);\n      } else {\n        var px = controlPoints(x),\n            py = controlPoints(y);\n        for (var i0 = 0, i1 = 1; i1 < n; ++i0, ++i1) {\n          this._context.bezierCurveTo(px[0][i0], py[0][i0], px[1][i0], py[1][i0], x[i1], y[i1]);\n        }\n      }\n    }\n\n    if (this._line || (this._line !== 0 && n === 1)) this._context.closePath();\n    this._line = 1 - this._line;\n    this._x = this._y = null;\n  },\n  point: function(x, y) {\n    this._x.push(+x);\n    this._y.push(+y);\n  }\n};\n\n// See https://www.particleincell.com/2012/bezier-splines/ for derivation.\nfunction controlPoints(x) {\n  var i,\n      n = x.length - 1,\n      m,\n      a = new Array(n),\n      b = new Array(n),\n      r = new Array(n);\n  a[0] = 0, b[0] = 2, r[0] = x[0] + 2 * x[1];\n  for (i = 1; i < n - 1; ++i) a[i] = 1, b[i] = 4, r[i] = 4 * x[i] + 2 * x[i + 1];\n  a[n - 1] = 2, b[n - 1] = 7, r[n - 1] = 8 * x[n - 1] + x[n];\n  for (i = 1; i < n; ++i) m = a[i] / b[i - 1], b[i] -= m, r[i] -= m * r[i - 1];\n  a[n - 1] = r[n - 1] / b[n - 1];\n  for (i = n - 2; i >= 0; --i) a[i] = (r[i] - a[i + 1]) / b[i];\n  b[n - 1] = (x[n] + a[n - 1]) / 2;\n  for (i = 0; i < n - 1; ++i) b[i] = 2 * x[i + 1] - a[i + 1];\n  return [a, b];\n}\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new Natural(context);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/natural.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/curve/step.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-shape/src/curve/step.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   stepAfter: () => (/* binding */ stepAfter),\n/* harmony export */   stepBefore: () => (/* binding */ stepBefore)\n/* harmony export */ });\nfunction Step(context, t) {\n  this._context = context;\n  this._t = t;\n}\n\nStep.prototype = {\n  areaStart: function() {\n    this._line = 0;\n  },\n  areaEnd: function() {\n    this._line = NaN;\n  },\n  lineStart: function() {\n    this._x = this._y = NaN;\n    this._point = 0;\n  },\n  lineEnd: function() {\n    if (0 < this._t && this._t < 1 && this._point === 2) this._context.lineTo(this._x, this._y);\n    if (this._line || (this._line !== 0 && this._point === 1)) this._context.closePath();\n    if (this._line >= 0) this._t = 1 - this._t, this._line = 1 - this._line;\n  },\n  point: function(x, y) {\n    x = +x, y = +y;\n    switch (this._point) {\n      case 0: this._point = 1; this._line ? this._context.lineTo(x, y) : this._context.moveTo(x, y); break;\n      case 1: this._point = 2; // falls through\n      default: {\n        if (this._t <= 0) {\n          this._context.lineTo(this._x, y);\n          this._context.lineTo(x, y);\n        } else {\n          var x1 = this._x * (1 - this._t) + x * this._t;\n          this._context.lineTo(x1, this._y);\n          this._context.lineTo(x1, y);\n        }\n        break;\n      }\n    }\n    this._x = x, this._y = y;\n  }\n};\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(context) {\n  return new Step(context, 0.5);\n}\n\nfunction stepBefore(context) {\n  return new Step(context, 0);\n}\n\nfunction stepAfter(context) {\n  return new Step(context, 1);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/curve/step.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/line.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-shape/src/line.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _array_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./array.js */ \"../../node_modules/d3-shape/src/array.js\");\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-shape/src/constant.js\");\n/* harmony import */ var _curve_linear_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curve/linear.js */ \"../../node_modules/d3-shape/src/curve/linear.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-shape/src/path.js\");\n/* harmony import */ var _point_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./point.js */ \"../../node_modules/d3-shape/src/point.js\");\n\n\n\n\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, y) {\n  var defined = (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(true),\n      context = null,\n      curve = _curve_linear_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n      output = null,\n      path = (0,_path_js__WEBPACK_IMPORTED_MODULE_2__.withPath)(line);\n\n  x = typeof x === \"function\" ? x : (x === undefined) ? _point_js__WEBPACK_IMPORTED_MODULE_3__.x : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(x);\n  y = typeof y === \"function\" ? y : (y === undefined) ? _point_js__WEBPACK_IMPORTED_MODULE_3__.y : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(y);\n\n  function line(data) {\n    var i,\n        n = (data = (0,_array_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"])(data)).length,\n        d,\n        defined0 = false,\n        buffer;\n\n    if (context == null) output = curve(buffer = path());\n\n    for (i = 0; i <= n; ++i) {\n      if (!(i < n && defined(d = data[i], i, data)) === defined0) {\n        if (defined0 = !defined0) output.lineStart();\n        else output.lineEnd();\n      }\n      if (defined0) output.point(+x(d, i, data), +y(d, i, data));\n    }\n\n    if (buffer) return output = null, buffer + \"\" || null;\n  }\n\n  line.x = function(_) {\n    return arguments.length ? (x = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), line) : x;\n  };\n\n  line.y = function(_) {\n    return arguments.length ? (y = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(+_), line) : y;\n  };\n\n  line.defined = function(_) {\n    return arguments.length ? (defined = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(!!_), line) : defined;\n  };\n\n  line.curve = function(_) {\n    return arguments.length ? (curve = _, context != null && (output = curve(context)), line) : curve;\n  };\n\n  line.context = function(_) {\n    return arguments.length ? (_ == null ? context = output = null : output = curve(context = _), line) : context;\n  };\n\n  return line;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/line.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/math.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-shape/src/math.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   abs: () => (/* binding */ abs),\n/* harmony export */   acos: () => (/* binding */ acos),\n/* harmony export */   asin: () => (/* binding */ asin),\n/* harmony export */   atan2: () => (/* binding */ atan2),\n/* harmony export */   cos: () => (/* binding */ cos),\n/* harmony export */   epsilon: () => (/* binding */ epsilon),\n/* harmony export */   halfPi: () => (/* binding */ halfPi),\n/* harmony export */   max: () => (/* binding */ max),\n/* harmony export */   min: () => (/* binding */ min),\n/* harmony export */   pi: () => (/* binding */ pi),\n/* harmony export */   sin: () => (/* binding */ sin),\n/* harmony export */   sqrt: () => (/* binding */ sqrt),\n/* harmony export */   tau: () => (/* binding */ tau)\n/* harmony export */ });\nconst abs = Math.abs;\nconst atan2 = Math.atan2;\nconst cos = Math.cos;\nconst max = Math.max;\nconst min = Math.min;\nconst sin = Math.sin;\nconst sqrt = Math.sqrt;\n\nconst epsilon = 1e-12;\nconst pi = Math.PI;\nconst halfPi = pi / 2;\nconst tau = 2 * pi;\n\nfunction acos(x) {\n  return x > 1 ? 0 : x < -1 ? pi : Math.acos(x);\n}\n\nfunction asin(x) {\n  return x >= 1 ? halfPi : x <= -1 ? -halfPi : Math.asin(x);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/math.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/noop.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-shape/src/noop.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/noop.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/path.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-shape/src/path.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   withPath: () => (/* binding */ withPath)\n/* harmony export */ });\n/* harmony import */ var d3_path__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-path */ \"../../node_modules/d3-path/src/path.js\");\n\n\nfunction withPath(shape) {\n  let digits = 3;\n\n  shape.digits = function(_) {\n    if (!arguments.length) return digits;\n    if (_ == null) {\n      digits = null;\n    } else {\n      const d = Math.floor(_);\n      if (!(d >= 0)) throw new RangeError(`invalid digits: ${_}`);\n      digits = d;\n    }\n    return shape;\n  };\n\n  return () => new d3_path__WEBPACK_IMPORTED_MODULE_0__.Path(digits);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/path.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/point.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-shape/src/point.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   x: () => (/* binding */ x),\n/* harmony export */   y: () => (/* binding */ y)\n/* harmony export */ });\nfunction x(p) {\n  return p[0];\n}\n\nfunction y(p) {\n  return p[1];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/point.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol.js":
/*!*************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Symbol),\n/* harmony export */   symbolsFill: () => (/* binding */ symbolsFill),\n/* harmony export */   symbolsStroke: () => (/* binding */ symbolsStroke)\n/* harmony export */ });\n/* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./constant.js */ \"../../node_modules/d3-shape/src/constant.js\");\n/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./path.js */ \"../../node_modules/d3-shape/src/path.js\");\n/* harmony import */ var _symbol_asterisk_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./symbol/asterisk.js */ \"../../node_modules/d3-shape/src/symbol/asterisk.js\");\n/* harmony import */ var _symbol_circle_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./symbol/circle.js */ \"../../node_modules/d3-shape/src/symbol/circle.js\");\n/* harmony import */ var _symbol_cross_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./symbol/cross.js */ \"../../node_modules/d3-shape/src/symbol/cross.js\");\n/* harmony import */ var _symbol_diamond_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./symbol/diamond.js */ \"../../node_modules/d3-shape/src/symbol/diamond.js\");\n/* harmony import */ var _symbol_diamond2_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./symbol/diamond2.js */ \"../../node_modules/d3-shape/src/symbol/diamond2.js\");\n/* harmony import */ var _symbol_plus_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./symbol/plus.js */ \"../../node_modules/d3-shape/src/symbol/plus.js\");\n/* harmony import */ var _symbol_square_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./symbol/square.js */ \"../../node_modules/d3-shape/src/symbol/square.js\");\n/* harmony import */ var _symbol_square2_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./symbol/square2.js */ \"../../node_modules/d3-shape/src/symbol/square2.js\");\n/* harmony import */ var _symbol_star_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./symbol/star.js */ \"../../node_modules/d3-shape/src/symbol/star.js\");\n/* harmony import */ var _symbol_triangle_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./symbol/triangle.js */ \"../../node_modules/d3-shape/src/symbol/triangle.js\");\n/* harmony import */ var _symbol_triangle2_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./symbol/triangle2.js */ \"../../node_modules/d3-shape/src/symbol/triangle2.js\");\n/* harmony import */ var _symbol_wye_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./symbol/wye.js */ \"../../node_modules/d3-shape/src/symbol/wye.js\");\n/* harmony import */ var _symbol_times_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./symbol/times.js */ \"../../node_modules/d3-shape/src/symbol/times.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n// These symbols are designed to be filled.\nconst symbolsFill = [\n  _symbol_circle_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  _symbol_cross_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"],\n  _symbol_diamond_js__WEBPACK_IMPORTED_MODULE_2__[\"default\"],\n  _symbol_square_js__WEBPACK_IMPORTED_MODULE_3__[\"default\"],\n  _symbol_star_js__WEBPACK_IMPORTED_MODULE_4__[\"default\"],\n  _symbol_triangle_js__WEBPACK_IMPORTED_MODULE_5__[\"default\"],\n  _symbol_wye_js__WEBPACK_IMPORTED_MODULE_6__[\"default\"]\n];\n\n// These symbols are designed to be stroked (with a width of 1.5px and round caps).\nconst symbolsStroke = [\n  _symbol_circle_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"],\n  _symbol_plus_js__WEBPACK_IMPORTED_MODULE_7__[\"default\"],\n  _symbol_times_js__WEBPACK_IMPORTED_MODULE_8__[\"default\"],\n  _symbol_triangle2_js__WEBPACK_IMPORTED_MODULE_9__[\"default\"],\n  _symbol_asterisk_js__WEBPACK_IMPORTED_MODULE_10__[\"default\"],\n  _symbol_square2_js__WEBPACK_IMPORTED_MODULE_11__[\"default\"],\n  _symbol_diamond2_js__WEBPACK_IMPORTED_MODULE_12__[\"default\"]\n];\n\nfunction Symbol(type, size) {\n  let context = null,\n      path = (0,_path_js__WEBPACK_IMPORTED_MODULE_13__.withPath)(symbol);\n\n  type = typeof type === \"function\" ? type : (0,_constant_js__WEBPACK_IMPORTED_MODULE_14__[\"default\"])(type || _symbol_circle_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"]);\n  size = typeof size === \"function\" ? size : (0,_constant_js__WEBPACK_IMPORTED_MODULE_14__[\"default\"])(size === undefined ? 64 : +size);\n\n  function symbol() {\n    let buffer;\n    if (!context) context = buffer = path();\n    type.apply(this, arguments).draw(context, +size.apply(this, arguments));\n    if (buffer) return context = null, buffer + \"\" || null;\n  }\n\n  symbol.type = function(_) {\n    return arguments.length ? (type = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_14__[\"default\"])(_), symbol) : type;\n  };\n\n  symbol.size = function(_) {\n    return arguments.length ? (size = typeof _ === \"function\" ? _ : (0,_constant_js__WEBPACK_IMPORTED_MODULE_14__[\"default\"])(+_), symbol) : size;\n  };\n\n  symbol.context = function(_) {\n    return arguments.length ? (context = _ == null ? null : _, symbol) : context;\n  };\n\n  return symbol;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/asterisk.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/asterisk.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst sqrt3 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(3);\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size + (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)(size / 28, 0.75)) * 0.59436;\n    const t = r / 2;\n    const u = t * sqrt3;\n    context.moveTo(0, r);\n    context.lineTo(0, -r);\n    context.moveTo(-u, -t);\n    context.lineTo(u, t);\n    context.moveTo(-u, t);\n    context.lineTo(u, -t);\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/asterisk.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/circle.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/circle.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size / _math_js__WEBPACK_IMPORTED_MODULE_0__.pi);\n    context.moveTo(r, 0);\n    context.arc(0, 0, r, 0, _math_js__WEBPACK_IMPORTED_MODULE_0__.tau);\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/circle.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/cross.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/cross.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size / 5) / 2;\n    context.moveTo(-3 * r, -r);\n    context.lineTo(-r, -r);\n    context.lineTo(-r, -3 * r);\n    context.lineTo(r, -3 * r);\n    context.lineTo(r, -r);\n    context.lineTo(3 * r, -r);\n    context.lineTo(3 * r, r);\n    context.lineTo(r, r);\n    context.lineTo(r, 3 * r);\n    context.lineTo(-r, 3 * r);\n    context.lineTo(-r, r);\n    context.lineTo(-3 * r, r);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/cross.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/diamond.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/diamond.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst tan30 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(1 / 3);\nconst tan30_2 = tan30 * 2;\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const y = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size / tan30_2);\n    const x = y * tan30;\n    context.moveTo(0, -y);\n    context.lineTo(x, 0);\n    context.lineTo(0, y);\n    context.lineTo(-x, 0);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/diamond.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/diamond2.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/diamond2.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size) * 0.62625;\n    context.moveTo(0, -r);\n    context.lineTo(r, 0);\n    context.lineTo(0, r);\n    context.lineTo(-r, 0);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/diamond2.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/plus.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/plus.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size - (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)(size / 7, 2)) * 0.87559;\n    context.moveTo(-r, 0);\n    context.lineTo(r, 0);\n    context.moveTo(0, r);\n    context.lineTo(0, -r);\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/plus.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/square.js":
/*!********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/square.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const w = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size);\n    const x = -w / 2;\n    context.rect(x, x, w, w);\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/square.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/square2.js":
/*!*********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/square2.js ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size) * 0.4431;\n    context.moveTo(r, r);\n    context.lineTo(r, -r);\n    context.lineTo(-r, -r);\n    context.lineTo(-r, r);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/square2.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/star.js":
/*!******************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/star.js ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst ka = 0.89081309152928522810;\nconst kr = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(_math_js__WEBPACK_IMPORTED_MODULE_0__.pi / 10) / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(7 * _math_js__WEBPACK_IMPORTED_MODULE_0__.pi / 10);\nconst kx = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(_math_js__WEBPACK_IMPORTED_MODULE_0__.tau / 10) * kr;\nconst ky = -(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(_math_js__WEBPACK_IMPORTED_MODULE_0__.tau / 10) * kr;\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size * ka);\n    const x = kx * r;\n    const y = ky * r;\n    context.moveTo(0, -r);\n    context.lineTo(x, y);\n    for (let i = 1; i < 5; ++i) {\n      const a = _math_js__WEBPACK_IMPORTED_MODULE_0__.tau * i / 5;\n      const c = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.cos)(a);\n      const s = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sin)(a);\n      context.lineTo(s * r, -c * r);\n      context.lineTo(c * x - s * y, s * x + c * y);\n    }\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/star.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/times.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/times.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size - (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.min)(size / 6, 1.7)) * 0.6189;\n    context.moveTo(-r, -r);\n    context.lineTo(r, r);\n    context.moveTo(-r, r);\n    context.lineTo(r, -r);\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/times.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/triangle.js":
/*!**********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/triangle.js ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst sqrt3 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(3);\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const y = -(0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size / (sqrt3 * 3));\n    context.moveTo(0, y * 2);\n    context.lineTo(-sqrt3 * y, -y);\n    context.lineTo(sqrt3 * y, -y);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/triangle.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/triangle2.js":
/*!***********************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/triangle2.js ***!
  \***********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst sqrt3 = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(3);\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const s = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size) * 0.6824;\n    const t = s  / 2;\n    const u = (s * sqrt3) / 2; // cos(Math.PI / 6)\n    context.moveTo(0, -s);\n    context.lineTo(u, t);\n    context.lineTo(-u, t);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/triangle2.js?");

/***/ }),

/***/ "../../node_modules/d3-shape/src/symbol/wye.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-shape/src/symbol/wye.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _math_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../math.js */ \"../../node_modules/d3-shape/src/math.js\");\n\n\nconst c = -0.5;\nconst s = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(3) / 2;\nconst k = 1 / (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(12);\nconst a = (k / 2 + 1) * 3;\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({\n  draw(context, size) {\n    const r = (0,_math_js__WEBPACK_IMPORTED_MODULE_0__.sqrt)(size / a);\n    const x0 = r / 2, y0 = r * k;\n    const x1 = x0, y1 = r * k + r;\n    const x2 = -x1, y2 = y1;\n    context.moveTo(x0, y0);\n    context.lineTo(x1, y1);\n    context.lineTo(x2, y2);\n    context.lineTo(c * x0 - s * y0, s * x0 + c * y0);\n    context.lineTo(c * x1 - s * y1, s * x1 + c * y1);\n    context.lineTo(c * x2 - s * y2, s * x2 + c * y2);\n    context.lineTo(c * x0 + s * y0, c * y0 - s * x0);\n    context.lineTo(c * x1 + s * y1, c * y1 - s * x1);\n    context.lineTo(c * x2 + s * y2, c * y2 - s * x2);\n    context.closePath();\n  }\n});\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-shape/src/symbol/wye.js?");

/***/ }),

/***/ "../../node_modules/d3-time-format/src/defaultLocale.js":
/*!**************************************************************!*\
  !*** ../../node_modules/d3-time-format/src/defaultLocale.js ***!
  \**************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ defaultLocale),\n/* harmony export */   timeFormat: () => (/* binding */ timeFormat),\n/* harmony export */   timeParse: () => (/* binding */ timeParse),\n/* harmony export */   utcFormat: () => (/* binding */ utcFormat),\n/* harmony export */   utcParse: () => (/* binding */ utcParse)\n/* harmony export */ });\n/* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./locale.js */ \"../../node_modules/d3-time-format/src/locale.js\");\n\n\nvar locale;\nvar timeFormat;\nvar timeParse;\nvar utcFormat;\nvar utcParse;\n\ndefaultLocale({\n  dateTime: \"%x, %X\",\n  date: \"%-m/%-d/%Y\",\n  time: \"%-I:%M:%S %p\",\n  periods: [\"AM\", \"PM\"],\n  days: [\"Sunday\", \"Monday\", \"Tuesday\", \"Wednesday\", \"Thursday\", \"Friday\", \"Saturday\"],\n  shortDays: [\"Sun\", \"Mon\", \"Tue\", \"Wed\", \"Thu\", \"Fri\", \"Sat\"],\n  months: [\"January\", \"February\", \"March\", \"April\", \"May\", \"June\", \"July\", \"August\", \"September\", \"October\", \"November\", \"December\"],\n  shortMonths: [\"Jan\", \"Feb\", \"Mar\", \"Apr\", \"May\", \"Jun\", \"Jul\", \"Aug\", \"Sep\", \"Oct\", \"Nov\", \"Dec\"]\n});\n\nfunction defaultLocale(definition) {\n  locale = (0,_locale_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(definition);\n  timeFormat = locale.format;\n  timeParse = locale.parse;\n  utcFormat = locale.utcFormat;\n  utcParse = locale.utcParse;\n  return locale;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time-format/src/defaultLocale.js?");

/***/ }),

/***/ "../../node_modules/d3-time-format/src/locale.js":
/*!*******************************************************!*\
  !*** ../../node_modules/d3-time-format/src/locale.js ***!
  \*******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ formatLocale)\n/* harmony export */ });\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/week.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/day.js\");\n/* harmony import */ var d3_time__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-time */ \"../../node_modules/d3-time/src/year.js\");\n\n\nfunction localDate(d) {\n  if (0 <= d.y && d.y < 100) {\n    var date = new Date(-1, d.m, d.d, d.H, d.M, d.S, d.L);\n    date.setFullYear(d.y);\n    return date;\n  }\n  return new Date(d.y, d.m, d.d, d.H, d.M, d.S, d.L);\n}\n\nfunction utcDate(d) {\n  if (0 <= d.y && d.y < 100) {\n    var date = new Date(Date.UTC(-1, d.m, d.d, d.H, d.M, d.S, d.L));\n    date.setUTCFullYear(d.y);\n    return date;\n  }\n  return new Date(Date.UTC(d.y, d.m, d.d, d.H, d.M, d.S, d.L));\n}\n\nfunction newDate(y, m, d) {\n  return {y: y, m: m, d: d, H: 0, M: 0, S: 0, L: 0};\n}\n\nfunction formatLocale(locale) {\n  var locale_dateTime = locale.dateTime,\n      locale_date = locale.date,\n      locale_time = locale.time,\n      locale_periods = locale.periods,\n      locale_weekdays = locale.days,\n      locale_shortWeekdays = locale.shortDays,\n      locale_months = locale.months,\n      locale_shortMonths = locale.shortMonths;\n\n  var periodRe = formatRe(locale_periods),\n      periodLookup = formatLookup(locale_periods),\n      weekdayRe = formatRe(locale_weekdays),\n      weekdayLookup = formatLookup(locale_weekdays),\n      shortWeekdayRe = formatRe(locale_shortWeekdays),\n      shortWeekdayLookup = formatLookup(locale_shortWeekdays),\n      monthRe = formatRe(locale_months),\n      monthLookup = formatLookup(locale_months),\n      shortMonthRe = formatRe(locale_shortMonths),\n      shortMonthLookup = formatLookup(locale_shortMonths);\n\n  var formats = {\n    \"a\": formatShortWeekday,\n    \"A\": formatWeekday,\n    \"b\": formatShortMonth,\n    \"B\": formatMonth,\n    \"c\": null,\n    \"d\": formatDayOfMonth,\n    \"e\": formatDayOfMonth,\n    \"f\": formatMicroseconds,\n    \"g\": formatYearISO,\n    \"G\": formatFullYearISO,\n    \"H\": formatHour24,\n    \"I\": formatHour12,\n    \"j\": formatDayOfYear,\n    \"L\": formatMilliseconds,\n    \"m\": formatMonthNumber,\n    \"M\": formatMinutes,\n    \"p\": formatPeriod,\n    \"q\": formatQuarter,\n    \"Q\": formatUnixTimestamp,\n    \"s\": formatUnixTimestampSeconds,\n    \"S\": formatSeconds,\n    \"u\": formatWeekdayNumberMonday,\n    \"U\": formatWeekNumberSunday,\n    \"V\": formatWeekNumberISO,\n    \"w\": formatWeekdayNumberSunday,\n    \"W\": formatWeekNumberMonday,\n    \"x\": null,\n    \"X\": null,\n    \"y\": formatYear,\n    \"Y\": formatFullYear,\n    \"Z\": formatZone,\n    \"%\": formatLiteralPercent\n  };\n\n  var utcFormats = {\n    \"a\": formatUTCShortWeekday,\n    \"A\": formatUTCWeekday,\n    \"b\": formatUTCShortMonth,\n    \"B\": formatUTCMonth,\n    \"c\": null,\n    \"d\": formatUTCDayOfMonth,\n    \"e\": formatUTCDayOfMonth,\n    \"f\": formatUTCMicroseconds,\n    \"g\": formatUTCYearISO,\n    \"G\": formatUTCFullYearISO,\n    \"H\": formatUTCHour24,\n    \"I\": formatUTCHour12,\n    \"j\": formatUTCDayOfYear,\n    \"L\": formatUTCMilliseconds,\n    \"m\": formatUTCMonthNumber,\n    \"M\": formatUTCMinutes,\n    \"p\": formatUTCPeriod,\n    \"q\": formatUTCQuarter,\n    \"Q\": formatUnixTimestamp,\n    \"s\": formatUnixTimestampSeconds,\n    \"S\": formatUTCSeconds,\n    \"u\": formatUTCWeekdayNumberMonday,\n    \"U\": formatUTCWeekNumberSunday,\n    \"V\": formatUTCWeekNumberISO,\n    \"w\": formatUTCWeekdayNumberSunday,\n    \"W\": formatUTCWeekNumberMonday,\n    \"x\": null,\n    \"X\": null,\n    \"y\": formatUTCYear,\n    \"Y\": formatUTCFullYear,\n    \"Z\": formatUTCZone,\n    \"%\": formatLiteralPercent\n  };\n\n  var parses = {\n    \"a\": parseShortWeekday,\n    \"A\": parseWeekday,\n    \"b\": parseShortMonth,\n    \"B\": parseMonth,\n    \"c\": parseLocaleDateTime,\n    \"d\": parseDayOfMonth,\n    \"e\": parseDayOfMonth,\n    \"f\": parseMicroseconds,\n    \"g\": parseYear,\n    \"G\": parseFullYear,\n    \"H\": parseHour24,\n    \"I\": parseHour24,\n    \"j\": parseDayOfYear,\n    \"L\": parseMilliseconds,\n    \"m\": parseMonthNumber,\n    \"M\": parseMinutes,\n    \"p\": parsePeriod,\n    \"q\": parseQuarter,\n    \"Q\": parseUnixTimestamp,\n    \"s\": parseUnixTimestampSeconds,\n    \"S\": parseSeconds,\n    \"u\": parseWeekdayNumberMonday,\n    \"U\": parseWeekNumberSunday,\n    \"V\": parseWeekNumberISO,\n    \"w\": parseWeekdayNumberSunday,\n    \"W\": parseWeekNumberMonday,\n    \"x\": parseLocaleDate,\n    \"X\": parseLocaleTime,\n    \"y\": parseYear,\n    \"Y\": parseFullYear,\n    \"Z\": parseZone,\n    \"%\": parseLiteralPercent\n  };\n\n  // These recursive directive definitions must be deferred.\n  formats.x = newFormat(locale_date, formats);\n  formats.X = newFormat(locale_time, formats);\n  formats.c = newFormat(locale_dateTime, formats);\n  utcFormats.x = newFormat(locale_date, utcFormats);\n  utcFormats.X = newFormat(locale_time, utcFormats);\n  utcFormats.c = newFormat(locale_dateTime, utcFormats);\n\n  function newFormat(specifier, formats) {\n    return function(date) {\n      var string = [],\n          i = -1,\n          j = 0,\n          n = specifier.length,\n          c,\n          pad,\n          format;\n\n      if (!(date instanceof Date)) date = new Date(+date);\n\n      while (++i < n) {\n        if (specifier.charCodeAt(i) === 37) {\n          string.push(specifier.slice(j, i));\n          if ((pad = pads[c = specifier.charAt(++i)]) != null) c = specifier.charAt(++i);\n          else pad = c === \"e\" ? \" \" : \"0\";\n          if (format = formats[c]) c = format(date, pad);\n          string.push(c);\n          j = i + 1;\n        }\n      }\n\n      string.push(specifier.slice(j, i));\n      return string.join(\"\");\n    };\n  }\n\n  function newParse(specifier, Z) {\n    return function(string) {\n      var d = newDate(1900, undefined, 1),\n          i = parseSpecifier(d, specifier, string += \"\", 0),\n          week, day;\n      if (i != string.length) return null;\n\n      // If a UNIX timestamp is specified, return it.\n      if (\"Q\" in d) return new Date(d.Q);\n      if (\"s\" in d) return new Date(d.s * 1000 + (\"L\" in d ? d.L : 0));\n\n      // If this is utcParse, never use the local timezone.\n      if (Z && !(\"Z\" in d)) d.Z = 0;\n\n      // The am-pm flag is 0 for AM, and 1 for PM.\n      if (\"p\" in d) d.H = d.H % 12 + d.p * 12;\n\n      // If the month was not specified, inherit from the quarter.\n      if (d.m === undefined) d.m = \"q\" in d ? d.q : 0;\n\n      // Convert day-of-week and week-of-year to day-of-year.\n      if (\"V\" in d) {\n        if (d.V < 1 || d.V > 53) return null;\n        if (!(\"w\" in d)) d.w = 1;\n        if (\"Z\" in d) {\n          week = utcDate(newDate(d.y, 0, 1)), day = week.getUTCDay();\n          week = day > 4 || day === 0 ? d3_time__WEBPACK_IMPORTED_MODULE_0__.utcMonday.ceil(week) : (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.utcMonday)(week);\n          week = d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay.offset(week, (d.V - 1) * 7);\n          d.y = week.getUTCFullYear();\n          d.m = week.getUTCMonth();\n          d.d = week.getUTCDate() + (d.w + 6) % 7;\n        } else {\n          week = localDate(newDate(d.y, 0, 1)), day = week.getDay();\n          week = day > 4 || day === 0 ? d3_time__WEBPACK_IMPORTED_MODULE_0__.timeMonday.ceil(week) : (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.timeMonday)(week);\n          week = d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay.offset(week, (d.V - 1) * 7);\n          d.y = week.getFullYear();\n          d.m = week.getMonth();\n          d.d = week.getDate() + (d.w + 6) % 7;\n        }\n      } else if (\"W\" in d || \"U\" in d) {\n        if (!(\"w\" in d)) d.w = \"u\" in d ? d.u % 7 : \"W\" in d ? 1 : 0;\n        day = \"Z\" in d ? utcDate(newDate(d.y, 0, 1)).getUTCDay() : localDate(newDate(d.y, 0, 1)).getDay();\n        d.m = 0;\n        d.d = \"W\" in d ? (d.w + 6) % 7 + d.W * 7 - (day + 5) % 7 : d.w + d.U * 7 - (day + 6) % 7;\n      }\n\n      // If a time zone is specified, all fields are interpreted as UTC and then\n      // offset according to the specified time zone.\n      if (\"Z\" in d) {\n        d.H += d.Z / 100 | 0;\n        d.M += d.Z % 100;\n        return utcDate(d);\n      }\n\n      // Otherwise, all fields are in local time.\n      return localDate(d);\n    };\n  }\n\n  function parseSpecifier(d, specifier, string, j) {\n    var i = 0,\n        n = specifier.length,\n        m = string.length,\n        c,\n        parse;\n\n    while (i < n) {\n      if (j >= m) return -1;\n      c = specifier.charCodeAt(i++);\n      if (c === 37) {\n        c = specifier.charAt(i++);\n        parse = parses[c in pads ? specifier.charAt(i++) : c];\n        if (!parse || ((j = parse(d, string, j)) < 0)) return -1;\n      } else if (c != string.charCodeAt(j++)) {\n        return -1;\n      }\n    }\n\n    return j;\n  }\n\n  function parsePeriod(d, string, i) {\n    var n = periodRe.exec(string.slice(i));\n    return n ? (d.p = periodLookup.get(n[0].toLowerCase()), i + n[0].length) : -1;\n  }\n\n  function parseShortWeekday(d, string, i) {\n    var n = shortWeekdayRe.exec(string.slice(i));\n    return n ? (d.w = shortWeekdayLookup.get(n[0].toLowerCase()), i + n[0].length) : -1;\n  }\n\n  function parseWeekday(d, string, i) {\n    var n = weekdayRe.exec(string.slice(i));\n    return n ? (d.w = weekdayLookup.get(n[0].toLowerCase()), i + n[0].length) : -1;\n  }\n\n  function parseShortMonth(d, string, i) {\n    var n = shortMonthRe.exec(string.slice(i));\n    return n ? (d.m = shortMonthLookup.get(n[0].toLowerCase()), i + n[0].length) : -1;\n  }\n\n  function parseMonth(d, string, i) {\n    var n = monthRe.exec(string.slice(i));\n    return n ? (d.m = monthLookup.get(n[0].toLowerCase()), i + n[0].length) : -1;\n  }\n\n  function parseLocaleDateTime(d, string, i) {\n    return parseSpecifier(d, locale_dateTime, string, i);\n  }\n\n  function parseLocaleDate(d, string, i) {\n    return parseSpecifier(d, locale_date, string, i);\n  }\n\n  function parseLocaleTime(d, string, i) {\n    return parseSpecifier(d, locale_time, string, i);\n  }\n\n  function formatShortWeekday(d) {\n    return locale_shortWeekdays[d.getDay()];\n  }\n\n  function formatWeekday(d) {\n    return locale_weekdays[d.getDay()];\n  }\n\n  function formatShortMonth(d) {\n    return locale_shortMonths[d.getMonth()];\n  }\n\n  function formatMonth(d) {\n    return locale_months[d.getMonth()];\n  }\n\n  function formatPeriod(d) {\n    return locale_periods[+(d.getHours() >= 12)];\n  }\n\n  function formatQuarter(d) {\n    return 1 + ~~(d.getMonth() / 3);\n  }\n\n  function formatUTCShortWeekday(d) {\n    return locale_shortWeekdays[d.getUTCDay()];\n  }\n\n  function formatUTCWeekday(d) {\n    return locale_weekdays[d.getUTCDay()];\n  }\n\n  function formatUTCShortMonth(d) {\n    return locale_shortMonths[d.getUTCMonth()];\n  }\n\n  function formatUTCMonth(d) {\n    return locale_months[d.getUTCMonth()];\n  }\n\n  function formatUTCPeriod(d) {\n    return locale_periods[+(d.getUTCHours() >= 12)];\n  }\n\n  function formatUTCQuarter(d) {\n    return 1 + ~~(d.getUTCMonth() / 3);\n  }\n\n  return {\n    format: function(specifier) {\n      var f = newFormat(specifier += \"\", formats);\n      f.toString = function() { return specifier; };\n      return f;\n    },\n    parse: function(specifier) {\n      var p = newParse(specifier += \"\", false);\n      p.toString = function() { return specifier; };\n      return p;\n    },\n    utcFormat: function(specifier) {\n      var f = newFormat(specifier += \"\", utcFormats);\n      f.toString = function() { return specifier; };\n      return f;\n    },\n    utcParse: function(specifier) {\n      var p = newParse(specifier += \"\", true);\n      p.toString = function() { return specifier; };\n      return p;\n    }\n  };\n}\n\nvar pads = {\"-\": \"\", \"_\": \" \", \"0\": \"0\"},\n    numberRe = /^\\s*\\d+/, // note: ignores next directive\n    percentRe = /^%/,\n    requoteRe = /[\\\\^$*+?|[\\]().{}]/g;\n\nfunction pad(value, fill, width) {\n  var sign = value < 0 ? \"-\" : \"\",\n      string = (sign ? -value : value) + \"\",\n      length = string.length;\n  return sign + (length < width ? new Array(width - length + 1).join(fill) + string : string);\n}\n\nfunction requote(s) {\n  return s.replace(requoteRe, \"\\\\$&\");\n}\n\nfunction formatRe(names) {\n  return new RegExp(\"^(?:\" + names.map(requote).join(\"|\") + \")\", \"i\");\n}\n\nfunction formatLookup(names) {\n  return new Map(names.map((name, i) => [name.toLowerCase(), i]));\n}\n\nfunction parseWeekdayNumberSunday(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 1));\n  return n ? (d.w = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseWeekdayNumberMonday(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 1));\n  return n ? (d.u = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseWeekNumberSunday(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.U = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseWeekNumberISO(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.V = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseWeekNumberMonday(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.W = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseFullYear(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 4));\n  return n ? (d.y = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseYear(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.y = +n[0] + (+n[0] > 68 ? 1900 : 2000), i + n[0].length) : -1;\n}\n\nfunction parseZone(d, string, i) {\n  var n = /^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(string.slice(i, i + 6));\n  return n ? (d.Z = n[1] ? 0 : -(n[2] + (n[3] || \"00\")), i + n[0].length) : -1;\n}\n\nfunction parseQuarter(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 1));\n  return n ? (d.q = n[0] * 3 - 3, i + n[0].length) : -1;\n}\n\nfunction parseMonthNumber(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.m = n[0] - 1, i + n[0].length) : -1;\n}\n\nfunction parseDayOfMonth(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.d = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseDayOfYear(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 3));\n  return n ? (d.m = 0, d.d = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseHour24(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.H = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseMinutes(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.M = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseSeconds(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 2));\n  return n ? (d.S = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseMilliseconds(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 3));\n  return n ? (d.L = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseMicroseconds(d, string, i) {\n  var n = numberRe.exec(string.slice(i, i + 6));\n  return n ? (d.L = Math.floor(n[0] / 1000), i + n[0].length) : -1;\n}\n\nfunction parseLiteralPercent(d, string, i) {\n  var n = percentRe.exec(string.slice(i, i + 1));\n  return n ? i + n[0].length : -1;\n}\n\nfunction parseUnixTimestamp(d, string, i) {\n  var n = numberRe.exec(string.slice(i));\n  return n ? (d.Q = +n[0], i + n[0].length) : -1;\n}\n\nfunction parseUnixTimestampSeconds(d, string, i) {\n  var n = numberRe.exec(string.slice(i));\n  return n ? (d.s = +n[0], i + n[0].length) : -1;\n}\n\nfunction formatDayOfMonth(d, p) {\n  return pad(d.getDate(), p, 2);\n}\n\nfunction formatHour24(d, p) {\n  return pad(d.getHours(), p, 2);\n}\n\nfunction formatHour12(d, p) {\n  return pad(d.getHours() % 12 || 12, p, 2);\n}\n\nfunction formatDayOfYear(d, p) {\n  return pad(1 + d3_time__WEBPACK_IMPORTED_MODULE_1__.timeDay.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.timeYear)(d), d), p, 3);\n}\n\nfunction formatMilliseconds(d, p) {\n  return pad(d.getMilliseconds(), p, 3);\n}\n\nfunction formatMicroseconds(d, p) {\n  return formatMilliseconds(d, p) + \"000\";\n}\n\nfunction formatMonthNumber(d, p) {\n  return pad(d.getMonth() + 1, p, 2);\n}\n\nfunction formatMinutes(d, p) {\n  return pad(d.getMinutes(), p, 2);\n}\n\nfunction formatSeconds(d, p) {\n  return pad(d.getSeconds(), p, 2);\n}\n\nfunction formatWeekdayNumberMonday(d) {\n  var day = d.getDay();\n  return day === 0 ? 7 : day;\n}\n\nfunction formatWeekNumberSunday(d, p) {\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.timeSunday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.timeYear)(d) - 1, d), p, 2);\n}\n\nfunction dISO(d) {\n  var day = d.getDay();\n  return (day >= 4 || day === 0) ? (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.timeThursday)(d) : d3_time__WEBPACK_IMPORTED_MODULE_0__.timeThursday.ceil(d);\n}\n\nfunction formatWeekNumberISO(d, p) {\n  d = dISO(d);\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.timeThursday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.timeYear)(d), d) + ((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.timeYear)(d).getDay() === 4), p, 2);\n}\n\nfunction formatWeekdayNumberSunday(d) {\n  return d.getDay();\n}\n\nfunction formatWeekNumberMonday(d, p) {\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.timeMonday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.timeYear)(d) - 1, d), p, 2);\n}\n\nfunction formatYear(d, p) {\n  return pad(d.getFullYear() % 100, p, 2);\n}\n\nfunction formatYearISO(d, p) {\n  d = dISO(d);\n  return pad(d.getFullYear() % 100, p, 2);\n}\n\nfunction formatFullYear(d, p) {\n  return pad(d.getFullYear() % 10000, p, 4);\n}\n\nfunction formatFullYearISO(d, p) {\n  var day = d.getDay();\n  d = (day >= 4 || day === 0) ? (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.timeThursday)(d) : d3_time__WEBPACK_IMPORTED_MODULE_0__.timeThursday.ceil(d);\n  return pad(d.getFullYear() % 10000, p, 4);\n}\n\nfunction formatZone(d) {\n  var z = d.getTimezoneOffset();\n  return (z > 0 ? \"-\" : (z *= -1, \"+\"))\n      + pad(z / 60 | 0, \"0\", 2)\n      + pad(z % 60, \"0\", 2);\n}\n\nfunction formatUTCDayOfMonth(d, p) {\n  return pad(d.getUTCDate(), p, 2);\n}\n\nfunction formatUTCHour24(d, p) {\n  return pad(d.getUTCHours(), p, 2);\n}\n\nfunction formatUTCHour12(d, p) {\n  return pad(d.getUTCHours() % 12 || 12, p, 2);\n}\n\nfunction formatUTCDayOfYear(d, p) {\n  return pad(1 + d3_time__WEBPACK_IMPORTED_MODULE_1__.utcDay.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.utcYear)(d), d), p, 3);\n}\n\nfunction formatUTCMilliseconds(d, p) {\n  return pad(d.getUTCMilliseconds(), p, 3);\n}\n\nfunction formatUTCMicroseconds(d, p) {\n  return formatUTCMilliseconds(d, p) + \"000\";\n}\n\nfunction formatUTCMonthNumber(d, p) {\n  return pad(d.getUTCMonth() + 1, p, 2);\n}\n\nfunction formatUTCMinutes(d, p) {\n  return pad(d.getUTCMinutes(), p, 2);\n}\n\nfunction formatUTCSeconds(d, p) {\n  return pad(d.getUTCSeconds(), p, 2);\n}\n\nfunction formatUTCWeekdayNumberMonday(d) {\n  var dow = d.getUTCDay();\n  return dow === 0 ? 7 : dow;\n}\n\nfunction formatUTCWeekNumberSunday(d, p) {\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.utcSunday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.utcYear)(d) - 1, d), p, 2);\n}\n\nfunction UTCdISO(d) {\n  var day = d.getUTCDay();\n  return (day >= 4 || day === 0) ? (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.utcThursday)(d) : d3_time__WEBPACK_IMPORTED_MODULE_0__.utcThursday.ceil(d);\n}\n\nfunction formatUTCWeekNumberISO(d, p) {\n  d = UTCdISO(d);\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.utcThursday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.utcYear)(d), d) + ((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.utcYear)(d).getUTCDay() === 4), p, 2);\n}\n\nfunction formatUTCWeekdayNumberSunday(d) {\n  return d.getUTCDay();\n}\n\nfunction formatUTCWeekNumberMonday(d, p) {\n  return pad(d3_time__WEBPACK_IMPORTED_MODULE_0__.utcMonday.count((0,d3_time__WEBPACK_IMPORTED_MODULE_2__.utcYear)(d) - 1, d), p, 2);\n}\n\nfunction formatUTCYear(d, p) {\n  return pad(d.getUTCFullYear() % 100, p, 2);\n}\n\nfunction formatUTCYearISO(d, p) {\n  d = UTCdISO(d);\n  return pad(d.getUTCFullYear() % 100, p, 2);\n}\n\nfunction formatUTCFullYear(d, p) {\n  return pad(d.getUTCFullYear() % 10000, p, 4);\n}\n\nfunction formatUTCFullYearISO(d, p) {\n  var day = d.getUTCDay();\n  d = (day >= 4 || day === 0) ? (0,d3_time__WEBPACK_IMPORTED_MODULE_0__.utcThursday)(d) : d3_time__WEBPACK_IMPORTED_MODULE_0__.utcThursday.ceil(d);\n  return pad(d.getUTCFullYear() % 10000, p, 4);\n}\n\nfunction formatUTCZone() {\n  return \"+0000\";\n}\n\nfunction formatLiteralPercent() {\n  return \"%\";\n}\n\nfunction formatUnixTimestamp(d) {\n  return +d;\n}\n\nfunction formatUnixTimestampSeconds(d) {\n  return Math.floor(+d / 1000);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time-format/src/locale.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/day.js":
/*!*********************************************!*\
  !*** ../../node_modules/d3-time/src/day.js ***!
  \*********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeDay: () => (/* binding */ timeDay),\n/* harmony export */   timeDays: () => (/* binding */ timeDays),\n/* harmony export */   unixDay: () => (/* binding */ unixDay),\n/* harmony export */   unixDays: () => (/* binding */ unixDays),\n/* harmony export */   utcDay: () => (/* binding */ utcDay),\n/* harmony export */   utcDays: () => (/* binding */ utcDays)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n\n\n\nconst timeDay = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)(\n  date => date.setHours(0, 0, 0, 0),\n  (date, step) => date.setDate(date.getDate() + step),\n  (start, end) => (end - start - (end.getTimezoneOffset() - start.getTimezoneOffset()) * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay,\n  date => date.getDate() - 1\n);\n\nconst timeDays = timeDay.range;\n\nconst utcDay = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setUTCDate(date.getUTCDate() + step);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay;\n}, (date) => {\n  return date.getUTCDate() - 1;\n});\n\nconst utcDays = utcDay.range;\n\nconst unixDay = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setUTCDate(date.getUTCDate() + step);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay;\n}, (date) => {\n  return Math.floor(date / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay);\n});\n\nconst unixDays = unixDay.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/day.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/duration.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-time/src/duration.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   durationDay: () => (/* binding */ durationDay),\n/* harmony export */   durationHour: () => (/* binding */ durationHour),\n/* harmony export */   durationMinute: () => (/* binding */ durationMinute),\n/* harmony export */   durationMonth: () => (/* binding */ durationMonth),\n/* harmony export */   durationSecond: () => (/* binding */ durationSecond),\n/* harmony export */   durationWeek: () => (/* binding */ durationWeek),\n/* harmony export */   durationYear: () => (/* binding */ durationYear)\n/* harmony export */ });\nconst durationSecond = 1000;\nconst durationMinute = durationSecond * 60;\nconst durationHour = durationMinute * 60;\nconst durationDay = durationHour * 24;\nconst durationWeek = durationDay * 7;\nconst durationMonth = durationDay * 30;\nconst durationYear = durationDay * 365;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/duration.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/hour.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-time/src/hour.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeHour: () => (/* binding */ timeHour),\n/* harmony export */   timeHours: () => (/* binding */ timeHours),\n/* harmony export */   utcHour: () => (/* binding */ utcHour),\n/* harmony export */   utcHours: () => (/* binding */ utcHours)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n\n\n\nconst timeHour = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setTime(date - date.getMilliseconds() - date.getSeconds() * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond - date.getMinutes() * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute);\n}, (date, step) => {\n  date.setTime(+date + step * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour;\n}, (date) => {\n  return date.getHours();\n});\n\nconst timeHours = timeHour.range;\n\nconst utcHour = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCMinutes(0, 0, 0);\n}, (date, step) => {\n  date.setTime(+date + step * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour;\n}, (date) => {\n  return date.getUTCHours();\n});\n\nconst utcHours = utcHour.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/hour.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/interval.js":
/*!**************************************************!*\
  !*** ../../node_modules/d3-time/src/interval.js ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeInterval: () => (/* binding */ timeInterval)\n/* harmony export */ });\nconst t0 = new Date, t1 = new Date;\n\nfunction timeInterval(floori, offseti, count, field) {\n\n  function interval(date) {\n    return floori(date = arguments.length === 0 ? new Date : new Date(+date)), date;\n  }\n\n  interval.floor = (date) => {\n    return floori(date = new Date(+date)), date;\n  };\n\n  interval.ceil = (date) => {\n    return floori(date = new Date(date - 1)), offseti(date, 1), floori(date), date;\n  };\n\n  interval.round = (date) => {\n    const d0 = interval(date), d1 = interval.ceil(date);\n    return date - d0 < d1 - date ? d0 : d1;\n  };\n\n  interval.offset = (date, step) => {\n    return offseti(date = new Date(+date), step == null ? 1 : Math.floor(step)), date;\n  };\n\n  interval.range = (start, stop, step) => {\n    const range = [];\n    start = interval.ceil(start);\n    step = step == null ? 1 : Math.floor(step);\n    if (!(start < stop) || !(step > 0)) return range; // also handles Invalid Date\n    let previous;\n    do range.push(previous = new Date(+start)), offseti(start, step), floori(start);\n    while (previous < start && start < stop);\n    return range;\n  };\n\n  interval.filter = (test) => {\n    return timeInterval((date) => {\n      if (date >= date) while (floori(date), !test(date)) date.setTime(date - 1);\n    }, (date, step) => {\n      if (date >= date) {\n        if (step < 0) while (++step <= 0) {\n          while (offseti(date, -1), !test(date)) {} // eslint-disable-line no-empty\n        } else while (--step >= 0) {\n          while (offseti(date, +1), !test(date)) {} // eslint-disable-line no-empty\n        }\n      }\n    });\n  };\n\n  if (count) {\n    interval.count = (start, end) => {\n      t0.setTime(+start), t1.setTime(+end);\n      floori(t0), floori(t1);\n      return Math.floor(count(t0, t1));\n    };\n\n    interval.every = (step) => {\n      step = Math.floor(step);\n      return !isFinite(step) || !(step > 0) ? null\n          : !(step > 1) ? interval\n          : interval.filter(field\n              ? (d) => field(d) % step === 0\n              : (d) => interval.count(0, d) % step === 0);\n    };\n  }\n\n  return interval;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/interval.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/millisecond.js":
/*!*****************************************************!*\
  !*** ../../node_modules/d3-time/src/millisecond.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   millisecond: () => (/* binding */ millisecond),\n/* harmony export */   milliseconds: () => (/* binding */ milliseconds)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n\n\nconst millisecond = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)(() => {\n  // noop\n}, (date, step) => {\n  date.setTime(+date + step);\n}, (start, end) => {\n  return end - start;\n});\n\n// An optimized implementation for this simple case.\nmillisecond.every = (k) => {\n  k = Math.floor(k);\n  if (!isFinite(k) || !(k > 0)) return null;\n  if (!(k > 1)) return millisecond;\n  return (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n    date.setTime(Math.floor(date / k) * k);\n  }, (date, step) => {\n    date.setTime(+date + step * k);\n  }, (start, end) => {\n    return (end - start) / k;\n  });\n};\n\nconst milliseconds = millisecond.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/millisecond.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/minute.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-time/src/minute.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeMinute: () => (/* binding */ timeMinute),\n/* harmony export */   timeMinutes: () => (/* binding */ timeMinutes),\n/* harmony export */   utcMinute: () => (/* binding */ utcMinute),\n/* harmony export */   utcMinutes: () => (/* binding */ utcMinutes)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n\n\n\nconst timeMinute = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setTime(date - date.getMilliseconds() - date.getSeconds() * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond);\n}, (date, step) => {\n  date.setTime(+date + step * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute;\n}, (date) => {\n  return date.getMinutes();\n});\n\nconst timeMinutes = timeMinute.range;\n\nconst utcMinute = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCSeconds(0, 0);\n}, (date, step) => {\n  date.setTime(+date + step * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute;\n}, (date) => {\n  return date.getUTCMinutes();\n});\n\nconst utcMinutes = utcMinute.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/minute.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/month.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-time/src/month.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeMonth: () => (/* binding */ timeMonth),\n/* harmony export */   timeMonths: () => (/* binding */ timeMonths),\n/* harmony export */   utcMonth: () => (/* binding */ utcMonth),\n/* harmony export */   utcMonths: () => (/* binding */ utcMonths)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n\n\nconst timeMonth = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setDate(1);\n  date.setHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setMonth(date.getMonth() + step);\n}, (start, end) => {\n  return end.getMonth() - start.getMonth() + (end.getFullYear() - start.getFullYear()) * 12;\n}, (date) => {\n  return date.getMonth();\n});\n\nconst timeMonths = timeMonth.range;\n\nconst utcMonth = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCDate(1);\n  date.setUTCHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setUTCMonth(date.getUTCMonth() + step);\n}, (start, end) => {\n  return end.getUTCMonth() - start.getUTCMonth() + (end.getUTCFullYear() - start.getUTCFullYear()) * 12;\n}, (date) => {\n  return date.getUTCMonth();\n});\n\nconst utcMonths = utcMonth.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/month.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/second.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-time/src/second.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   second: () => (/* binding */ second),\n/* harmony export */   seconds: () => (/* binding */ seconds)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n\n\n\nconst second = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setTime(date - date.getMilliseconds());\n}, (date, step) => {\n  date.setTime(+date + step * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond);\n}, (start, end) => {\n  return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond;\n}, (date) => {\n  return date.getUTCSeconds();\n});\n\nconst seconds = second.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/second.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/ticks.js":
/*!***********************************************!*\
  !*** ../../node_modules/d3-time/src/ticks.js ***!
  \***********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeTickInterval: () => (/* binding */ timeTickInterval),\n/* harmony export */   timeTicks: () => (/* binding */ timeTicks),\n/* harmony export */   utcTickInterval: () => (/* binding */ utcTickInterval),\n/* harmony export */   utcTicks: () => (/* binding */ utcTicks)\n/* harmony export */ });\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/bisector.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! d3-array */ \"../../node_modules/d3-array/src/ticks.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n/* harmony import */ var _millisecond_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./millisecond.js */ \"../../node_modules/d3-time/src/millisecond.js\");\n/* harmony import */ var _second_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./second.js */ \"../../node_modules/d3-time/src/second.js\");\n/* harmony import */ var _minute_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./minute.js */ \"../../node_modules/d3-time/src/minute.js\");\n/* harmony import */ var _hour_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./hour.js */ \"../../node_modules/d3-time/src/hour.js\");\n/* harmony import */ var _day_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./day.js */ \"../../node_modules/d3-time/src/day.js\");\n/* harmony import */ var _week_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./week.js */ \"../../node_modules/d3-time/src/week.js\");\n/* harmony import */ var _month_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./month.js */ \"../../node_modules/d3-time/src/month.js\");\n/* harmony import */ var _year_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./year.js */ \"../../node_modules/d3-time/src/year.js\");\n\n\n\n\n\n\n\n\n\n\n\nfunction ticker(year, month, week, day, hour, minute) {\n\n  const tickIntervals = [\n    [_second_js__WEBPACK_IMPORTED_MODULE_0__.second,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond],\n    [_second_js__WEBPACK_IMPORTED_MODULE_0__.second,  5,  5 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond],\n    [_second_js__WEBPACK_IMPORTED_MODULE_0__.second, 15, 15 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond],\n    [_second_js__WEBPACK_IMPORTED_MODULE_0__.second, 30, 30 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationSecond],\n    [minute,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute],\n    [minute,  5,  5 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute],\n    [minute, 15, 15 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute],\n    [minute, 30, 30 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute],\n    [  hour,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour  ],\n    [  hour,  3,  3 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour  ],\n    [  hour,  6,  6 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour  ],\n    [  hour, 12, 12 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationHour  ],\n    [   day,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay   ],\n    [   day,  2,  2 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationDay   ],\n    [  week,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationWeek  ],\n    [ month,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMonth ],\n    [ month,  3,  3 * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMonth ],\n    [  year,  1,      _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationYear  ]\n  ];\n\n  function ticks(start, stop, count) {\n    const reverse = stop < start;\n    if (reverse) [start, stop] = [stop, start];\n    const interval = count && typeof count.range === \"function\" ? count : tickInterval(start, stop, count);\n    const ticks = interval ? interval.range(start, +stop + 1) : []; // inclusive stop\n    return reverse ? ticks.reverse() : ticks;\n  }\n\n  function tickInterval(start, stop, count) {\n    const target = Math.abs(stop - start) / count;\n    const i = (0,d3_array__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(([,, step]) => step).right(tickIntervals, target);\n    if (i === tickIntervals.length) return year.every((0,d3_array__WEBPACK_IMPORTED_MODULE_3__.tickStep)(start / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationYear, stop / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationYear, count));\n    if (i === 0) return _millisecond_js__WEBPACK_IMPORTED_MODULE_4__.millisecond.every(Math.max((0,d3_array__WEBPACK_IMPORTED_MODULE_3__.tickStep)(start, stop, count), 1));\n    const [t, step] = tickIntervals[target / tickIntervals[i - 1][2] < tickIntervals[i][2] / target ? i - 1 : i];\n    return t.every(step);\n  }\n\n  return [ticks, tickInterval];\n}\n\nconst [utcTicks, utcTickInterval] = ticker(_year_js__WEBPACK_IMPORTED_MODULE_5__.utcYear, _month_js__WEBPACK_IMPORTED_MODULE_6__.utcMonth, _week_js__WEBPACK_IMPORTED_MODULE_7__.utcSunday, _day_js__WEBPACK_IMPORTED_MODULE_8__.unixDay, _hour_js__WEBPACK_IMPORTED_MODULE_9__.utcHour, _minute_js__WEBPACK_IMPORTED_MODULE_10__.utcMinute);\nconst [timeTicks, timeTickInterval] = ticker(_year_js__WEBPACK_IMPORTED_MODULE_5__.timeYear, _month_js__WEBPACK_IMPORTED_MODULE_6__.timeMonth, _week_js__WEBPACK_IMPORTED_MODULE_7__.timeSunday, _day_js__WEBPACK_IMPORTED_MODULE_8__.timeDay, _hour_js__WEBPACK_IMPORTED_MODULE_9__.timeHour, _minute_js__WEBPACK_IMPORTED_MODULE_10__.timeMinute);\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/ticks.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/week.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-time/src/week.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeFriday: () => (/* binding */ timeFriday),\n/* harmony export */   timeFridays: () => (/* binding */ timeFridays),\n/* harmony export */   timeMonday: () => (/* binding */ timeMonday),\n/* harmony export */   timeMondays: () => (/* binding */ timeMondays),\n/* harmony export */   timeSaturday: () => (/* binding */ timeSaturday),\n/* harmony export */   timeSaturdays: () => (/* binding */ timeSaturdays),\n/* harmony export */   timeSunday: () => (/* binding */ timeSunday),\n/* harmony export */   timeSundays: () => (/* binding */ timeSundays),\n/* harmony export */   timeThursday: () => (/* binding */ timeThursday),\n/* harmony export */   timeThursdays: () => (/* binding */ timeThursdays),\n/* harmony export */   timeTuesday: () => (/* binding */ timeTuesday),\n/* harmony export */   timeTuesdays: () => (/* binding */ timeTuesdays),\n/* harmony export */   timeWednesday: () => (/* binding */ timeWednesday),\n/* harmony export */   timeWednesdays: () => (/* binding */ timeWednesdays),\n/* harmony export */   utcFriday: () => (/* binding */ utcFriday),\n/* harmony export */   utcFridays: () => (/* binding */ utcFridays),\n/* harmony export */   utcMonday: () => (/* binding */ utcMonday),\n/* harmony export */   utcMondays: () => (/* binding */ utcMondays),\n/* harmony export */   utcSaturday: () => (/* binding */ utcSaturday),\n/* harmony export */   utcSaturdays: () => (/* binding */ utcSaturdays),\n/* harmony export */   utcSunday: () => (/* binding */ utcSunday),\n/* harmony export */   utcSundays: () => (/* binding */ utcSundays),\n/* harmony export */   utcThursday: () => (/* binding */ utcThursday),\n/* harmony export */   utcThursdays: () => (/* binding */ utcThursdays),\n/* harmony export */   utcTuesday: () => (/* binding */ utcTuesday),\n/* harmony export */   utcTuesdays: () => (/* binding */ utcTuesdays),\n/* harmony export */   utcWednesday: () => (/* binding */ utcWednesday),\n/* harmony export */   utcWednesdays: () => (/* binding */ utcWednesdays)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n/* harmony import */ var _duration_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./duration.js */ \"../../node_modules/d3-time/src/duration.js\");\n\n\n\nfunction timeWeekday(i) {\n  return (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n    date.setDate(date.getDate() - (date.getDay() + 7 - i) % 7);\n    date.setHours(0, 0, 0, 0);\n  }, (date, step) => {\n    date.setDate(date.getDate() + step * 7);\n  }, (start, end) => {\n    return (end - start - (end.getTimezoneOffset() - start.getTimezoneOffset()) * _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationMinute) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationWeek;\n  });\n}\n\nconst timeSunday = timeWeekday(0);\nconst timeMonday = timeWeekday(1);\nconst timeTuesday = timeWeekday(2);\nconst timeWednesday = timeWeekday(3);\nconst timeThursday = timeWeekday(4);\nconst timeFriday = timeWeekday(5);\nconst timeSaturday = timeWeekday(6);\n\nconst timeSundays = timeSunday.range;\nconst timeMondays = timeMonday.range;\nconst timeTuesdays = timeTuesday.range;\nconst timeWednesdays = timeWednesday.range;\nconst timeThursdays = timeThursday.range;\nconst timeFridays = timeFriday.range;\nconst timeSaturdays = timeSaturday.range;\n\nfunction utcWeekday(i) {\n  return (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n    date.setUTCDate(date.getUTCDate() - (date.getUTCDay() + 7 - i) % 7);\n    date.setUTCHours(0, 0, 0, 0);\n  }, (date, step) => {\n    date.setUTCDate(date.getUTCDate() + step * 7);\n  }, (start, end) => {\n    return (end - start) / _duration_js__WEBPACK_IMPORTED_MODULE_1__.durationWeek;\n  });\n}\n\nconst utcSunday = utcWeekday(0);\nconst utcMonday = utcWeekday(1);\nconst utcTuesday = utcWeekday(2);\nconst utcWednesday = utcWeekday(3);\nconst utcThursday = utcWeekday(4);\nconst utcFriday = utcWeekday(5);\nconst utcSaturday = utcWeekday(6);\n\nconst utcSundays = utcSunday.range;\nconst utcMondays = utcMonday.range;\nconst utcTuesdays = utcTuesday.range;\nconst utcWednesdays = utcWednesday.range;\nconst utcThursdays = utcThursday.range;\nconst utcFridays = utcFriday.range;\nconst utcSaturdays = utcSaturday.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/week.js?");

/***/ }),

/***/ "../../node_modules/d3-time/src/year.js":
/*!**********************************************!*\
  !*** ../../node_modules/d3-time/src/year.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   timeYear: () => (/* binding */ timeYear),\n/* harmony export */   timeYears: () => (/* binding */ timeYears),\n/* harmony export */   utcYear: () => (/* binding */ utcYear),\n/* harmony export */   utcYears: () => (/* binding */ utcYears)\n/* harmony export */ });\n/* harmony import */ var _interval_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./interval.js */ \"../../node_modules/d3-time/src/interval.js\");\n\n\nconst timeYear = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setMonth(0, 1);\n  date.setHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setFullYear(date.getFullYear() + step);\n}, (start, end) => {\n  return end.getFullYear() - start.getFullYear();\n}, (date) => {\n  return date.getFullYear();\n});\n\n// An optimized implementation for this simple case.\ntimeYear.every = (k) => {\n  return !isFinite(k = Math.floor(k)) || !(k > 0) ? null : (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n    date.setFullYear(Math.floor(date.getFullYear() / k) * k);\n    date.setMonth(0, 1);\n    date.setHours(0, 0, 0, 0);\n  }, (date, step) => {\n    date.setFullYear(date.getFullYear() + step * k);\n  });\n};\n\nconst timeYears = timeYear.range;\n\nconst utcYear = (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n  date.setUTCMonth(0, 1);\n  date.setUTCHours(0, 0, 0, 0);\n}, (date, step) => {\n  date.setUTCFullYear(date.getUTCFullYear() + step);\n}, (start, end) => {\n  return end.getUTCFullYear() - start.getUTCFullYear();\n}, (date) => {\n  return date.getUTCFullYear();\n});\n\n// An optimized implementation for this simple case.\nutcYear.every = (k) => {\n  return !isFinite(k = Math.floor(k)) || !(k > 0) ? null : (0,_interval_js__WEBPACK_IMPORTED_MODULE_0__.timeInterval)((date) => {\n    date.setUTCFullYear(Math.floor(date.getUTCFullYear() / k) * k);\n    date.setUTCMonth(0, 1);\n    date.setUTCHours(0, 0, 0, 0);\n  }, (date, step) => {\n    date.setUTCFullYear(date.getUTCFullYear() + step * k);\n  });\n};\n\nconst utcYears = utcYear.range;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-time/src/year.js?");

/***/ }),

/***/ "../../node_modules/d3-timer/src/interval.js":
/*!***************************************************!*\
  !*** ../../node_modules/d3-timer/src/interval.js ***!
  \***************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _timer_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./timer.js */ \"../../node_modules/d3-timer/src/timer.js\");\n\n\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(callback, delay, time) {\n  var t = new _timer_js__WEBPACK_IMPORTED_MODULE_0__.Timer, total = delay;\n  if (delay == null) return t.restart(callback, delay, time), t;\n  t._restart = t.restart;\n  t.restart = function(callback, delay, time) {\n    delay = +delay, time = time == null ? (0,_timer_js__WEBPACK_IMPORTED_MODULE_0__.now)() : +time;\n    t._restart(function tick(elapsed) {\n      elapsed += total;\n      t._restart(tick, total += delay, time);\n      callback(elapsed);\n    }, delay, time);\n  }\n  t.restart(callback, delay, time);\n  return t;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-timer/src/interval.js?");

/***/ }),

/***/ "../../node_modules/d3-timer/src/timer.js":
/*!************************************************!*\
  !*** ../../node_modules/d3-timer/src/timer.js ***!
  \************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Timer: () => (/* binding */ Timer),\n/* harmony export */   now: () => (/* binding */ now),\n/* harmony export */   timer: () => (/* binding */ timer),\n/* harmony export */   timerFlush: () => (/* binding */ timerFlush)\n/* harmony export */ });\nvar frame = 0, // is an animation frame pending?\n    timeout = 0, // is a timeout pending?\n    interval = 0, // are any timers active?\n    pokeDelay = 1000, // how frequently we check for clock skew\n    taskHead,\n    taskTail,\n    clockLast = 0,\n    clockNow = 0,\n    clockSkew = 0,\n    clock = typeof performance === \"object\" && performance.now ? performance : Date,\n    setFrame = typeof window === \"object\" && window.requestAnimationFrame ? window.requestAnimationFrame.bind(window) : function(f) { setTimeout(f, 17); };\n\nfunction now() {\n  return clockNow || (setFrame(clearNow), clockNow = clock.now() + clockSkew);\n}\n\nfunction clearNow() {\n  clockNow = 0;\n}\n\nfunction Timer() {\n  this._call =\n  this._time =\n  this._next = null;\n}\n\nTimer.prototype = timer.prototype = {\n  constructor: Timer,\n  restart: function(callback, delay, time) {\n    if (typeof callback !== \"function\") throw new TypeError(\"callback is not a function\");\n    time = (time == null ? now() : +time) + (delay == null ? 0 : +delay);\n    if (!this._next && taskTail !== this) {\n      if (taskTail) taskTail._next = this;\n      else taskHead = this;\n      taskTail = this;\n    }\n    this._call = callback;\n    this._time = time;\n    sleep();\n  },\n  stop: function() {\n    if (this._call) {\n      this._call = null;\n      this._time = Infinity;\n      sleep();\n    }\n  }\n};\n\nfunction timer(callback, delay, time) {\n  var t = new Timer;\n  t.restart(callback, delay, time);\n  return t;\n}\n\nfunction timerFlush() {\n  now(); // Get the current time, if not already set.\n  ++frame; // Pretend we’ve set an alarm, if we haven’t already.\n  var t = taskHead, e;\n  while (t) {\n    if ((e = clockNow - t._time) >= 0) t._call.call(undefined, e);\n    t = t._next;\n  }\n  --frame;\n}\n\nfunction wake() {\n  clockNow = (clockLast = clock.now()) + clockSkew;\n  frame = timeout = 0;\n  try {\n    timerFlush();\n  } finally {\n    frame = 0;\n    nap();\n    clockNow = 0;\n  }\n}\n\nfunction poke() {\n  var now = clock.now(), delay = now - clockLast;\n  if (delay > pokeDelay) clockSkew -= delay, clockLast = now;\n}\n\nfunction nap() {\n  var t0, t1 = taskHead, t2, time = Infinity;\n  while (t1) {\n    if (t1._call) {\n      if (time > t1._time) time = t1._time;\n      t0 = t1, t1 = t1._next;\n    } else {\n      t2 = t1._next, t1._next = null;\n      t1 = t0 ? t0._next = t2 : taskHead = t2;\n    }\n  }\n  taskTail = t0;\n  sleep(time);\n}\n\nfunction sleep(time) {\n  if (frame) return; // Soonest alarm already set, or will be.\n  if (timeout) timeout = clearTimeout(timeout);\n  var delay = time - clockNow; // Strictly less than if we recomputed clockNow.\n  if (delay > 24) {\n    if (time < Infinity) timeout = setTimeout(wake, time - clock.now() - clockSkew);\n    if (interval) interval = clearInterval(interval);\n  } else {\n    if (!interval) clockLast = clock.now(), interval = setInterval(poke, pokeDelay);\n    frame = 1, setFrame(wake);\n  }\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/d3-timer/src/timer.js?");

/***/ }),

/***/ "../../node_modules/delaunator/index.js":
/*!**********************************************!*\
  !*** ../../node_modules/delaunator/index.js ***!
  \**********************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ Delaunator)\n/* harmony export */ });\n/* harmony import */ var robust_predicates__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! robust-predicates */ \"../../node_modules/robust-predicates/index.js\");\n\nconst EPSILON = Math.pow(2, -52);\nconst EDGE_STACK = new Uint32Array(512);\n\n\n\nclass Delaunator {\n\n    static from(points, getX = defaultGetX, getY = defaultGetY) {\n        const n = points.length;\n        const coords = new Float64Array(n * 2);\n\n        for (let i = 0; i < n; i++) {\n            const p = points[i];\n            coords[2 * i] = getX(p);\n            coords[2 * i + 1] = getY(p);\n        }\n\n        return new Delaunator(coords);\n    }\n\n    constructor(coords) {\n        const n = coords.length >> 1;\n        if (n > 0 && typeof coords[0] !== 'number') throw new Error('Expected coords to contain numbers.');\n\n        this.coords = coords;\n\n        // arrays that will store the triangulation graph\n        const maxTriangles = Math.max(2 * n - 5, 0);\n        this._triangles = new Uint32Array(maxTriangles * 3);\n        this._halfedges = new Int32Array(maxTriangles * 3);\n\n        // temporary arrays for tracking the edges of the advancing convex hull\n        this._hashSize = Math.ceil(Math.sqrt(n));\n        this._hullPrev = new Uint32Array(n); // edge to prev edge\n        this._hullNext = new Uint32Array(n); // edge to next edge\n        this._hullTri = new Uint32Array(n); // edge to adjacent triangle\n        this._hullHash = new Int32Array(this._hashSize).fill(-1); // angular edge hash\n\n        // temporary arrays for sorting points\n        this._ids = new Uint32Array(n);\n        this._dists = new Float64Array(n);\n\n        this.update();\n    }\n\n    update() {\n        const {coords, _hullPrev: hullPrev, _hullNext: hullNext, _hullTri: hullTri, _hullHash: hullHash} =  this;\n        const n = coords.length >> 1;\n\n        // populate an array of point indices; calculate input data bbox\n        let minX = Infinity;\n        let minY = Infinity;\n        let maxX = -Infinity;\n        let maxY = -Infinity;\n\n        for (let i = 0; i < n; i++) {\n            const x = coords[2 * i];\n            const y = coords[2 * i + 1];\n            if (x < minX) minX = x;\n            if (y < minY) minY = y;\n            if (x > maxX) maxX = x;\n            if (y > maxY) maxY = y;\n            this._ids[i] = i;\n        }\n        const cx = (minX + maxX) / 2;\n        const cy = (minY + maxY) / 2;\n\n        let minDist = Infinity;\n        let i0, i1, i2;\n\n        // pick a seed point close to the center\n        for (let i = 0; i < n; i++) {\n            const d = dist(cx, cy, coords[2 * i], coords[2 * i + 1]);\n            if (d < minDist) {\n                i0 = i;\n                minDist = d;\n            }\n        }\n        const i0x = coords[2 * i0];\n        const i0y = coords[2 * i0 + 1];\n\n        minDist = Infinity;\n\n        // find the point closest to the seed\n        for (let i = 0; i < n; i++) {\n            if (i === i0) continue;\n            const d = dist(i0x, i0y, coords[2 * i], coords[2 * i + 1]);\n            if (d < minDist && d > 0) {\n                i1 = i;\n                minDist = d;\n            }\n        }\n        let i1x = coords[2 * i1];\n        let i1y = coords[2 * i1 + 1];\n\n        let minRadius = Infinity;\n\n        // find the third point which forms the smallest circumcircle with the first two\n        for (let i = 0; i < n; i++) {\n            if (i === i0 || i === i1) continue;\n            const r = circumradius(i0x, i0y, i1x, i1y, coords[2 * i], coords[2 * i + 1]);\n            if (r < minRadius) {\n                i2 = i;\n                minRadius = r;\n            }\n        }\n        let i2x = coords[2 * i2];\n        let i2y = coords[2 * i2 + 1];\n\n        if (minRadius === Infinity) {\n            // order collinear points by dx (or dy if all x are identical)\n            // and return the list as a hull\n            for (let i = 0; i < n; i++) {\n                this._dists[i] = (coords[2 * i] - coords[0]) || (coords[2 * i + 1] - coords[1]);\n            }\n            quicksort(this._ids, this._dists, 0, n - 1);\n            const hull = new Uint32Array(n);\n            let j = 0;\n            for (let i = 0, d0 = -Infinity; i < n; i++) {\n                const id = this._ids[i];\n                if (this._dists[id] > d0) {\n                    hull[j++] = id;\n                    d0 = this._dists[id];\n                }\n            }\n            this.hull = hull.subarray(0, j);\n            this.triangles = new Uint32Array(0);\n            this.halfedges = new Uint32Array(0);\n            return;\n        }\n\n        // swap the order of the seed points for counter-clockwise orientation\n        if ((0,robust_predicates__WEBPACK_IMPORTED_MODULE_0__.orient2d)(i0x, i0y, i1x, i1y, i2x, i2y) < 0) {\n            const i = i1;\n            const x = i1x;\n            const y = i1y;\n            i1 = i2;\n            i1x = i2x;\n            i1y = i2y;\n            i2 = i;\n            i2x = x;\n            i2y = y;\n        }\n\n        const center = circumcenter(i0x, i0y, i1x, i1y, i2x, i2y);\n        this._cx = center.x;\n        this._cy = center.y;\n\n        for (let i = 0; i < n; i++) {\n            this._dists[i] = dist(coords[2 * i], coords[2 * i + 1], center.x, center.y);\n        }\n\n        // sort the points by distance from the seed triangle circumcenter\n        quicksort(this._ids, this._dists, 0, n - 1);\n\n        // set up the seed triangle as the starting hull\n        this._hullStart = i0;\n        let hullSize = 3;\n\n        hullNext[i0] = hullPrev[i2] = i1;\n        hullNext[i1] = hullPrev[i0] = i2;\n        hullNext[i2] = hullPrev[i1] = i0;\n\n        hullTri[i0] = 0;\n        hullTri[i1] = 1;\n        hullTri[i2] = 2;\n\n        hullHash.fill(-1);\n        hullHash[this._hashKey(i0x, i0y)] = i0;\n        hullHash[this._hashKey(i1x, i1y)] = i1;\n        hullHash[this._hashKey(i2x, i2y)] = i2;\n\n        this.trianglesLen = 0;\n        this._addTriangle(i0, i1, i2, -1, -1, -1);\n\n        for (let k = 0, xp, yp; k < this._ids.length; k++) {\n            const i = this._ids[k];\n            const x = coords[2 * i];\n            const y = coords[2 * i + 1];\n\n            // skip near-duplicate points\n            if (k > 0 && Math.abs(x - xp) <= EPSILON && Math.abs(y - yp) <= EPSILON) continue;\n            xp = x;\n            yp = y;\n\n            // skip seed triangle points\n            if (i === i0 || i === i1 || i === i2) continue;\n\n            // find a visible edge on the convex hull using edge hash\n            let start = 0;\n            for (let j = 0, key = this._hashKey(x, y); j < this._hashSize; j++) {\n                start = hullHash[(key + j) % this._hashSize];\n                if (start !== -1 && start !== hullNext[start]) break;\n            }\n\n            start = hullPrev[start];\n            let e = start, q;\n            while (q = hullNext[e], (0,robust_predicates__WEBPACK_IMPORTED_MODULE_0__.orient2d)(x, y, coords[2 * e], coords[2 * e + 1], coords[2 * q], coords[2 * q + 1]) >= 0) {\n                e = q;\n                if (e === start) {\n                    e = -1;\n                    break;\n                }\n            }\n            if (e === -1) continue; // likely a near-duplicate point; skip it\n\n            // add the first triangle from the point\n            let t = this._addTriangle(e, i, hullNext[e], -1, -1, hullTri[e]);\n\n            // recursively flip triangles from the point until they satisfy the Delaunay condition\n            hullTri[i] = this._legalize(t + 2);\n            hullTri[e] = t; // keep track of boundary triangles on the hull\n            hullSize++;\n\n            // walk forward through the hull, adding more triangles and flipping recursively\n            let n = hullNext[e];\n            while (q = hullNext[n], (0,robust_predicates__WEBPACK_IMPORTED_MODULE_0__.orient2d)(x, y, coords[2 * n], coords[2 * n + 1], coords[2 * q], coords[2 * q + 1]) < 0) {\n                t = this._addTriangle(n, i, q, hullTri[i], -1, hullTri[n]);\n                hullTri[i] = this._legalize(t + 2);\n                hullNext[n] = n; // mark as removed\n                hullSize--;\n                n = q;\n            }\n\n            // walk backward from the other side, adding more triangles and flipping\n            if (e === start) {\n                while (q = hullPrev[e], (0,robust_predicates__WEBPACK_IMPORTED_MODULE_0__.orient2d)(x, y, coords[2 * q], coords[2 * q + 1], coords[2 * e], coords[2 * e + 1]) < 0) {\n                    t = this._addTriangle(q, i, e, -1, hullTri[e], hullTri[q]);\n                    this._legalize(t + 2);\n                    hullTri[q] = t;\n                    hullNext[e] = e; // mark as removed\n                    hullSize--;\n                    e = q;\n                }\n            }\n\n            // update the hull indices\n            this._hullStart = hullPrev[i] = e;\n            hullNext[e] = hullPrev[n] = i;\n            hullNext[i] = n;\n\n            // save the two new edges in the hash table\n            hullHash[this._hashKey(x, y)] = i;\n            hullHash[this._hashKey(coords[2 * e], coords[2 * e + 1])] = e;\n        }\n\n        this.hull = new Uint32Array(hullSize);\n        for (let i = 0, e = this._hullStart; i < hullSize; i++) {\n            this.hull[i] = e;\n            e = hullNext[e];\n        }\n\n        // trim typed triangle mesh arrays\n        this.triangles = this._triangles.subarray(0, this.trianglesLen);\n        this.halfedges = this._halfedges.subarray(0, this.trianglesLen);\n    }\n\n    _hashKey(x, y) {\n        return Math.floor(pseudoAngle(x - this._cx, y - this._cy) * this._hashSize) % this._hashSize;\n    }\n\n    _legalize(a) {\n        const {_triangles: triangles, _halfedges: halfedges, coords} = this;\n\n        let i = 0;\n        let ar = 0;\n\n        // recursion eliminated with a fixed-size stack\n        while (true) {\n            const b = halfedges[a];\n\n            /* if the pair of triangles doesn't satisfy the Delaunay condition\n             * (p1 is inside the circumcircle of [p0, pl, pr]), flip them,\n             * then do the same check/flip recursively for the new pair of triangles\n             *\n             *           pl                    pl\n             *          /||\\                  /  \\\n             *       al/ || \\bl            al/    \\a\n             *        /  ||  \\              /      \\\n             *       /  a||b  \\    flip    /___ar___\\\n             *     p0\\   ||   /p1   =>   p0\\---bl---/p1\n             *        \\  ||  /              \\      /\n             *       ar\\ || /br             b\\    /br\n             *          \\||/                  \\  /\n             *           pr                    pr\n             */\n            const a0 = a - a % 3;\n            ar = a0 + (a + 2) % 3;\n\n            if (b === -1) { // convex hull edge\n                if (i === 0) break;\n                a = EDGE_STACK[--i];\n                continue;\n            }\n\n            const b0 = b - b % 3;\n            const al = a0 + (a + 1) % 3;\n            const bl = b0 + (b + 2) % 3;\n\n            const p0 = triangles[ar];\n            const pr = triangles[a];\n            const pl = triangles[al];\n            const p1 = triangles[bl];\n\n            const illegal = inCircle(\n                coords[2 * p0], coords[2 * p0 + 1],\n                coords[2 * pr], coords[2 * pr + 1],\n                coords[2 * pl], coords[2 * pl + 1],\n                coords[2 * p1], coords[2 * p1 + 1]);\n\n            if (illegal) {\n                triangles[a] = p1;\n                triangles[b] = p0;\n\n                const hbl = halfedges[bl];\n\n                // edge swapped on the other side of the hull (rare); fix the halfedge reference\n                if (hbl === -1) {\n                    let e = this._hullStart;\n                    do {\n                        if (this._hullTri[e] === bl) {\n                            this._hullTri[e] = a;\n                            break;\n                        }\n                        e = this._hullPrev[e];\n                    } while (e !== this._hullStart);\n                }\n                this._link(a, hbl);\n                this._link(b, halfedges[ar]);\n                this._link(ar, bl);\n\n                const br = b0 + (b + 1) % 3;\n\n                // don't worry about hitting the cap: it can only happen on extremely degenerate input\n                if (i < EDGE_STACK.length) {\n                    EDGE_STACK[i++] = br;\n                }\n            } else {\n                if (i === 0) break;\n                a = EDGE_STACK[--i];\n            }\n        }\n\n        return ar;\n    }\n\n    _link(a, b) {\n        this._halfedges[a] = b;\n        if (b !== -1) this._halfedges[b] = a;\n    }\n\n    // add a new triangle given vertex indices and adjacent half-edge ids\n    _addTriangle(i0, i1, i2, a, b, c) {\n        const t = this.trianglesLen;\n\n        this._triangles[t] = i0;\n        this._triangles[t + 1] = i1;\n        this._triangles[t + 2] = i2;\n\n        this._link(t, a);\n        this._link(t + 1, b);\n        this._link(t + 2, c);\n\n        this.trianglesLen += 3;\n\n        return t;\n    }\n}\n\n// monotonically increases with real angle, but doesn't need expensive trigonometry\nfunction pseudoAngle(dx, dy) {\n    const p = dx / (Math.abs(dx) + Math.abs(dy));\n    return (dy > 0 ? 3 - p : 1 + p) / 4; // [0..1]\n}\n\nfunction dist(ax, ay, bx, by) {\n    const dx = ax - bx;\n    const dy = ay - by;\n    return dx * dx + dy * dy;\n}\n\nfunction inCircle(ax, ay, bx, by, cx, cy, px, py) {\n    const dx = ax - px;\n    const dy = ay - py;\n    const ex = bx - px;\n    const ey = by - py;\n    const fx = cx - px;\n    const fy = cy - py;\n\n    const ap = dx * dx + dy * dy;\n    const bp = ex * ex + ey * ey;\n    const cp = fx * fx + fy * fy;\n\n    return dx * (ey * cp - bp * fy) -\n           dy * (ex * cp - bp * fx) +\n           ap * (ex * fy - ey * fx) < 0;\n}\n\nfunction circumradius(ax, ay, bx, by, cx, cy) {\n    const dx = bx - ax;\n    const dy = by - ay;\n    const ex = cx - ax;\n    const ey = cy - ay;\n\n    const bl = dx * dx + dy * dy;\n    const cl = ex * ex + ey * ey;\n    const d = 0.5 / (dx * ey - dy * ex);\n\n    const x = (ey * bl - dy * cl) * d;\n    const y = (dx * cl - ex * bl) * d;\n\n    return x * x + y * y;\n}\n\nfunction circumcenter(ax, ay, bx, by, cx, cy) {\n    const dx = bx - ax;\n    const dy = by - ay;\n    const ex = cx - ax;\n    const ey = cy - ay;\n\n    const bl = dx * dx + dy * dy;\n    const cl = ex * ex + ey * ey;\n    const d = 0.5 / (dx * ey - dy * ex);\n\n    const x = ax + (ey * bl - dy * cl) * d;\n    const y = ay + (dx * cl - ex * bl) * d;\n\n    return {x, y};\n}\n\nfunction quicksort(ids, dists, left, right) {\n    if (right - left <= 20) {\n        for (let i = left + 1; i <= right; i++) {\n            const temp = ids[i];\n            const tempDist = dists[temp];\n            let j = i - 1;\n            while (j >= left && dists[ids[j]] > tempDist) ids[j + 1] = ids[j--];\n            ids[j + 1] = temp;\n        }\n    } else {\n        const median = (left + right) >> 1;\n        let i = left + 1;\n        let j = right;\n        swap(ids, median, i);\n        if (dists[ids[left]] > dists[ids[right]]) swap(ids, left, right);\n        if (dists[ids[i]] > dists[ids[right]]) swap(ids, i, right);\n        if (dists[ids[left]] > dists[ids[i]]) swap(ids, left, i);\n\n        const temp = ids[i];\n        const tempDist = dists[temp];\n        while (true) {\n            do i++; while (dists[ids[i]] < tempDist);\n            do j--; while (dists[ids[j]] > tempDist);\n            if (j < i) break;\n            swap(ids, i, j);\n        }\n        ids[left + 1] = ids[j];\n        ids[j] = temp;\n\n        if (right - i + 1 >= j - left) {\n            quicksort(ids, dists, i, right);\n            quicksort(ids, dists, left, j - 1);\n        } else {\n            quicksort(ids, dists, left, j - 1);\n            quicksort(ids, dists, i, right);\n        }\n    }\n}\n\nfunction swap(arr, i, j) {\n    const tmp = arr[i];\n    arr[i] = arr[j];\n    arr[j] = tmp;\n}\n\nfunction defaultGetX(p) {\n    return p[0];\n}\nfunction defaultGetY(p) {\n    return p[1];\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/delaunator/index.js?");

/***/ }),

/***/ "../../node_modules/fast-json-patch/index.mjs":
/*!****************************************************!*\
  !*** ../../node_modules/fast-json-patch/index.mjs ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JsonPatchError: () => (/* reexport safe */ _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.PatchError),\n/* harmony export */   _areEquals: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__._areEquals),\n/* harmony export */   applyOperation: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.applyOperation),\n/* harmony export */   applyPatch: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.applyPatch),\n/* harmony export */   applyReducer: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.applyReducer),\n/* harmony export */   compare: () => (/* reexport safe */ _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__.compare),\n/* harmony export */   deepClone: () => (/* reexport safe */ _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__._deepClone),\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__),\n/* harmony export */   escapePathComponent: () => (/* reexport safe */ _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.escapePathComponent),\n/* harmony export */   generate: () => (/* reexport safe */ _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__.generate),\n/* harmony export */   getValueByPointer: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.getValueByPointer),\n/* harmony export */   observe: () => (/* reexport safe */ _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__.observe),\n/* harmony export */   unescapePathComponent: () => (/* reexport safe */ _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.unescapePathComponent),\n/* harmony export */   unobserve: () => (/* reexport safe */ _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__.unobserve),\n/* harmony export */   validate: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.validate),\n/* harmony export */   validator: () => (/* reexport safe */ _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__.validator)\n/* harmony export */ });\n/* harmony import */ var _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./module/core.mjs */ \"../../node_modules/fast-json-patch/module/core.mjs\");\n/* harmony import */ var _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./module/duplex.mjs */ \"../../node_modules/fast-json-patch/module/duplex.mjs\");\n/* harmony import */ var _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./module/helpers.mjs */ \"../../node_modules/fast-json-patch/module/helpers.mjs\");\n\n\n\n\n\n/**\n * Default export for backwards compat\n */\n\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Object.assign({}, _module_core_mjs__WEBPACK_IMPORTED_MODULE_0__, _module_duplex_mjs__WEBPACK_IMPORTED_MODULE_1__, {\n    JsonPatchError: _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.PatchError,\n    deepClone: _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__._deepClone,\n    escapePathComponent: _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.escapePathComponent,\n    unescapePathComponent: _module_helpers_mjs__WEBPACK_IMPORTED_MODULE_2__.unescapePathComponent\n}));\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-json-patch/index.mjs?");

/***/ }),

/***/ "../../node_modules/fast-json-patch/module/core.mjs":
/*!**********************************************************!*\
  !*** ../../node_modules/fast-json-patch/module/core.mjs ***!
  \**********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   JsonPatchError: () => (/* binding */ JsonPatchError),\n/* harmony export */   _areEquals: () => (/* binding */ _areEquals),\n/* harmony export */   applyOperation: () => (/* binding */ applyOperation),\n/* harmony export */   applyPatch: () => (/* binding */ applyPatch),\n/* harmony export */   applyReducer: () => (/* binding */ applyReducer),\n/* harmony export */   deepClone: () => (/* binding */ deepClone),\n/* harmony export */   getValueByPointer: () => (/* binding */ getValueByPointer),\n/* harmony export */   validate: () => (/* binding */ validate),\n/* harmony export */   validator: () => (/* binding */ validator)\n/* harmony export */ });\n/* harmony import */ var _helpers_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./helpers.mjs */ \"../../node_modules/fast-json-patch/module/helpers.mjs\");\n\nvar JsonPatchError = _helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.PatchError;\nvar deepClone = _helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone;\n/* We use a Javascript hash to store each\n function. Each hash entry (property) uses\n the operation identifiers specified in rfc6902.\n In this way, we can map each patch operation\n to its dedicated function in efficient way.\n */\n/* The operations applicable to an object */\nvar objOps = {\n    add: function (obj, key, document) {\n        obj[key] = this.value;\n        return { newDocument: document };\n    },\n    remove: function (obj, key, document) {\n        var removed = obj[key];\n        delete obj[key];\n        return { newDocument: document, removed: removed };\n    },\n    replace: function (obj, key, document) {\n        var removed = obj[key];\n        obj[key] = this.value;\n        return { newDocument: document, removed: removed };\n    },\n    move: function (obj, key, document) {\n        /* in case move target overwrites an existing value,\n        return the removed value, this can be taxing performance-wise,\n        and is potentially unneeded */\n        var removed = getValueByPointer(document, this.path);\n        if (removed) {\n            removed = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(removed);\n        }\n        var originalValue = applyOperation(document, { op: \"remove\", path: this.from }).removed;\n        applyOperation(document, { op: \"add\", path: this.path, value: originalValue });\n        return { newDocument: document, removed: removed };\n    },\n    copy: function (obj, key, document) {\n        var valueToCopy = getValueByPointer(document, this.from);\n        // enforce copy by value so further operations don't affect source (see issue #177)\n        applyOperation(document, { op: \"add\", path: this.path, value: (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(valueToCopy) });\n        return { newDocument: document };\n    },\n    test: function (obj, key, document) {\n        return { newDocument: document, test: _areEquals(obj[key], this.value) };\n    },\n    _get: function (obj, key, document) {\n        this.value = obj[key];\n        return { newDocument: document };\n    }\n};\n/* The operations applicable to an array. Many are the same as for the object */\nvar arrOps = {\n    add: function (arr, i, document) {\n        if ((0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.isInteger)(i)) {\n            arr.splice(i, 0, this.value);\n        }\n        else { // array props\n            arr[i] = this.value;\n        }\n        // this may be needed when using '-' in an array\n        return { newDocument: document, index: i };\n    },\n    remove: function (arr, i, document) {\n        var removedList = arr.splice(i, 1);\n        return { newDocument: document, removed: removedList[0] };\n    },\n    replace: function (arr, i, document) {\n        var removed = arr[i];\n        arr[i] = this.value;\n        return { newDocument: document, removed: removed };\n    },\n    move: objOps.move,\n    copy: objOps.copy,\n    test: objOps.test,\n    _get: objOps._get\n};\n/**\n * Retrieves a value from a JSON document by a JSON pointer.\n * Returns the value.\n *\n * @param document The document to get the value from\n * @param pointer an escaped JSON pointer\n * @return The retrieved value\n */\nfunction getValueByPointer(document, pointer) {\n    if (pointer == '') {\n        return document;\n    }\n    var getOriginalDestination = { op: \"_get\", path: pointer };\n    applyOperation(document, getOriginalDestination);\n    return getOriginalDestination.value;\n}\n/**\n * Apply a single JSON Patch Operation on a JSON document.\n * Returns the {newDocument, result} of the operation.\n * It modifies the `document` and `operation` objects - it gets the values by reference.\n * If you would like to avoid touching your values, clone them:\n * `jsonpatch.applyOperation(document, jsonpatch._deepClone(operation))`.\n *\n * @param document The document to patch\n * @param operation The operation to apply\n * @param validateOperation `false` is without validation, `true` to use default jsonpatch's validation, or you can pass a `validateOperation` callback to be used for validation.\n * @param mutateDocument Whether to mutate the original document or clone it before applying\n * @param banPrototypeModifications Whether to ban modifications to `__proto__`, defaults to `true`.\n * @return `{newDocument, result}` after the operation\n */\nfunction applyOperation(document, operation, validateOperation, mutateDocument, banPrototypeModifications, index) {\n    if (validateOperation === void 0) { validateOperation = false; }\n    if (mutateDocument === void 0) { mutateDocument = true; }\n    if (banPrototypeModifications === void 0) { banPrototypeModifications = true; }\n    if (index === void 0) { index = 0; }\n    if (validateOperation) {\n        if (typeof validateOperation == 'function') {\n            validateOperation(operation, 0, document, operation.path);\n        }\n        else {\n            validator(operation, 0);\n        }\n    }\n    /* ROOT OPERATIONS */\n    if (operation.path === \"\") {\n        var returnValue = { newDocument: document };\n        if (operation.op === 'add') {\n            returnValue.newDocument = operation.value;\n            return returnValue;\n        }\n        else if (operation.op === 'replace') {\n            returnValue.newDocument = operation.value;\n            returnValue.removed = document; //document we removed\n            return returnValue;\n        }\n        else if (operation.op === 'move' || operation.op === 'copy') { // it's a move or copy to root\n            returnValue.newDocument = getValueByPointer(document, operation.from); // get the value by json-pointer in `from` field\n            if (operation.op === 'move') { // report removed item\n                returnValue.removed = document;\n            }\n            return returnValue;\n        }\n        else if (operation.op === 'test') {\n            returnValue.test = _areEquals(document, operation.value);\n            if (returnValue.test === false) {\n                throw new JsonPatchError(\"Test operation failed\", 'TEST_OPERATION_FAILED', index, operation, document);\n            }\n            returnValue.newDocument = document;\n            return returnValue;\n        }\n        else if (operation.op === 'remove') { // a remove on root\n            returnValue.removed = document;\n            returnValue.newDocument = null;\n            return returnValue;\n        }\n        else if (operation.op === '_get') {\n            operation.value = document;\n            return returnValue;\n        }\n        else { /* bad operation */\n            if (validateOperation) {\n                throw new JsonPatchError('Operation `op` property is not one of operations defined in RFC-6902', 'OPERATION_OP_INVALID', index, operation, document);\n            }\n            else {\n                return returnValue;\n            }\n        }\n    } /* END ROOT OPERATIONS */\n    else {\n        if (!mutateDocument) {\n            document = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(document);\n        }\n        var path = operation.path || \"\";\n        var keys = path.split('/');\n        var obj = document;\n        var t = 1; //skip empty element - http://jsperf.com/to-shift-or-not-to-shift\n        var len = keys.length;\n        var existingPathFragment = undefined;\n        var key = void 0;\n        var validateFunction = void 0;\n        if (typeof validateOperation == 'function') {\n            validateFunction = validateOperation;\n        }\n        else {\n            validateFunction = validator;\n        }\n        while (true) {\n            key = keys[t];\n            if (key && key.indexOf('~') != -1) {\n                key = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.unescapePathComponent)(key);\n            }\n            if (banPrototypeModifications &&\n                (key == '__proto__' ||\n                    (key == 'prototype' && t > 0 && keys[t - 1] == 'constructor'))) {\n                throw new TypeError('JSON-Patch: modifying `__proto__` or `constructor/prototype` prop is banned for security reasons, if this was on purpose, please set `banPrototypeModifications` flag false and pass it to this function. More info in fast-json-patch README');\n            }\n            if (validateOperation) {\n                if (existingPathFragment === undefined) {\n                    if (obj[key] === undefined) {\n                        existingPathFragment = keys.slice(0, t).join('/');\n                    }\n                    else if (t == len - 1) {\n                        existingPathFragment = operation.path;\n                    }\n                    if (existingPathFragment !== undefined) {\n                        validateFunction(operation, 0, document, existingPathFragment);\n                    }\n                }\n            }\n            t++;\n            if (Array.isArray(obj)) {\n                if (key === '-') {\n                    key = obj.length;\n                }\n                else {\n                    if (validateOperation && !(0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.isInteger)(key)) {\n                        throw new JsonPatchError(\"Expected an unsigned base-10 integer value, making the new referenced value the array element with the zero-based index\", \"OPERATION_PATH_ILLEGAL_ARRAY_INDEX\", index, operation, document);\n                    } // only parse key when it's an integer for `arr.prop` to work\n                    else if ((0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.isInteger)(key)) {\n                        key = ~~key;\n                    }\n                }\n                if (t >= len) {\n                    if (validateOperation && operation.op === \"add\" && key > obj.length) {\n                        throw new JsonPatchError(\"The specified index MUST NOT be greater than the number of elements in the array\", \"OPERATION_VALUE_OUT_OF_BOUNDS\", index, operation, document);\n                    }\n                    var returnValue = arrOps[operation.op].call(operation, obj, key, document); // Apply patch\n                    if (returnValue.test === false) {\n                        throw new JsonPatchError(\"Test operation failed\", 'TEST_OPERATION_FAILED', index, operation, document);\n                    }\n                    return returnValue;\n                }\n            }\n            else {\n                if (t >= len) {\n                    var returnValue = objOps[operation.op].call(operation, obj, key, document); // Apply patch\n                    if (returnValue.test === false) {\n                        throw new JsonPatchError(\"Test operation failed\", 'TEST_OPERATION_FAILED', index, operation, document);\n                    }\n                    return returnValue;\n                }\n            }\n            obj = obj[key];\n            // If we have more keys in the path, but the next value isn't a non-null object,\n            // throw an OPERATION_PATH_UNRESOLVABLE error instead of iterating again.\n            if (validateOperation && t < len && (!obj || typeof obj !== \"object\")) {\n                throw new JsonPatchError('Cannot perform operation at the desired path', 'OPERATION_PATH_UNRESOLVABLE', index, operation, document);\n            }\n        }\n    }\n}\n/**\n * Apply a full JSON Patch array on a JSON document.\n * Returns the {newDocument, result} of the patch.\n * It modifies the `document` object and `patch` - it gets the values by reference.\n * If you would like to avoid touching your values, clone them:\n * `jsonpatch.applyPatch(document, jsonpatch._deepClone(patch))`.\n *\n * @param document The document to patch\n * @param patch The patch to apply\n * @param validateOperation `false` is without validation, `true` to use default jsonpatch's validation, or you can pass a `validateOperation` callback to be used for validation.\n * @param mutateDocument Whether to mutate the original document or clone it before applying\n * @param banPrototypeModifications Whether to ban modifications to `__proto__`, defaults to `true`.\n * @return An array of `{newDocument, result}` after the patch\n */\nfunction applyPatch(document, patch, validateOperation, mutateDocument, banPrototypeModifications) {\n    if (mutateDocument === void 0) { mutateDocument = true; }\n    if (banPrototypeModifications === void 0) { banPrototypeModifications = true; }\n    if (validateOperation) {\n        if (!Array.isArray(patch)) {\n            throw new JsonPatchError('Patch sequence must be an array', 'SEQUENCE_NOT_AN_ARRAY');\n        }\n    }\n    if (!mutateDocument) {\n        document = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(document);\n    }\n    var results = new Array(patch.length);\n    for (var i = 0, length_1 = patch.length; i < length_1; i++) {\n        // we don't need to pass mutateDocument argument because if it was true, we already deep cloned the object, we'll just pass `true`\n        results[i] = applyOperation(document, patch[i], validateOperation, true, banPrototypeModifications, i);\n        document = results[i].newDocument; // in case root was replaced\n    }\n    results.newDocument = document;\n    return results;\n}\n/**\n * Apply a single JSON Patch Operation on a JSON document.\n * Returns the updated document.\n * Suitable as a reducer.\n *\n * @param document The document to patch\n * @param operation The operation to apply\n * @return The updated document\n */\nfunction applyReducer(document, operation, index) {\n    var operationResult = applyOperation(document, operation);\n    if (operationResult.test === false) { // failed test\n        throw new JsonPatchError(\"Test operation failed\", 'TEST_OPERATION_FAILED', index, operation, document);\n    }\n    return operationResult.newDocument;\n}\n/**\n * Validates a single operation. Called from `jsonpatch.validate`. Throws `JsonPatchError` in case of an error.\n * @param {object} operation - operation object (patch)\n * @param {number} index - index of operation in the sequence\n * @param {object} [document] - object where the operation is supposed to be applied\n * @param {string} [existingPathFragment] - comes along with `document`\n */\nfunction validator(operation, index, document, existingPathFragment) {\n    if (typeof operation !== 'object' || operation === null || Array.isArray(operation)) {\n        throw new JsonPatchError('Operation is not an object', 'OPERATION_NOT_AN_OBJECT', index, operation, document);\n    }\n    else if (!objOps[operation.op]) {\n        throw new JsonPatchError('Operation `op` property is not one of operations defined in RFC-6902', 'OPERATION_OP_INVALID', index, operation, document);\n    }\n    else if (typeof operation.path !== 'string') {\n        throw new JsonPatchError('Operation `path` property is not a string', 'OPERATION_PATH_INVALID', index, operation, document);\n    }\n    else if (operation.path.indexOf('/') !== 0 && operation.path.length > 0) {\n        // paths that aren't empty string should start with \"/\"\n        throw new JsonPatchError('Operation `path` property must start with \"/\"', 'OPERATION_PATH_INVALID', index, operation, document);\n    }\n    else if ((operation.op === 'move' || operation.op === 'copy') && typeof operation.from !== 'string') {\n        throw new JsonPatchError('Operation `from` property is not present (applicable in `move` and `copy` operations)', 'OPERATION_FROM_REQUIRED', index, operation, document);\n    }\n    else if ((operation.op === 'add' || operation.op === 'replace' || operation.op === 'test') && operation.value === undefined) {\n        throw new JsonPatchError('Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)', 'OPERATION_VALUE_REQUIRED', index, operation, document);\n    }\n    else if ((operation.op === 'add' || operation.op === 'replace' || operation.op === 'test') && (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.hasUndefined)(operation.value)) {\n        throw new JsonPatchError('Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)', 'OPERATION_VALUE_CANNOT_CONTAIN_UNDEFINED', index, operation, document);\n    }\n    else if (document) {\n        if (operation.op == \"add\") {\n            var pathLen = operation.path.split(\"/\").length;\n            var existingPathLen = existingPathFragment.split(\"/\").length;\n            if (pathLen !== existingPathLen + 1 && pathLen !== existingPathLen) {\n                throw new JsonPatchError('Cannot perform an `add` operation at the desired path', 'OPERATION_PATH_CANNOT_ADD', index, operation, document);\n            }\n        }\n        else if (operation.op === 'replace' || operation.op === 'remove' || operation.op === '_get') {\n            if (operation.path !== existingPathFragment) {\n                throw new JsonPatchError('Cannot perform the operation at a path that does not exist', 'OPERATION_PATH_UNRESOLVABLE', index, operation, document);\n            }\n        }\n        else if (operation.op === 'move' || operation.op === 'copy') {\n            var existingValue = { op: \"_get\", path: operation.from, value: undefined };\n            var error = validate([existingValue], document);\n            if (error && error.name === 'OPERATION_PATH_UNRESOLVABLE') {\n                throw new JsonPatchError('Cannot perform the operation from a path that does not exist', 'OPERATION_FROM_UNRESOLVABLE', index, operation, document);\n            }\n        }\n    }\n}\n/**\n * Validates a sequence of operations. If `document` parameter is provided, the sequence is additionally validated against the object document.\n * If error is encountered, returns a JsonPatchError object\n * @param sequence\n * @param document\n * @returns {JsonPatchError|undefined}\n */\nfunction validate(sequence, document, externalValidator) {\n    try {\n        if (!Array.isArray(sequence)) {\n            throw new JsonPatchError('Patch sequence must be an array', 'SEQUENCE_NOT_AN_ARRAY');\n        }\n        if (document) {\n            //clone document and sequence so that we can safely try applying operations\n            applyPatch((0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(document), (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(sequence), externalValidator || true);\n        }\n        else {\n            externalValidator = externalValidator || validator;\n            for (var i = 0; i < sequence.length; i++) {\n                externalValidator(sequence[i], i, document, undefined);\n            }\n        }\n    }\n    catch (e) {\n        if (e instanceof JsonPatchError) {\n            return e;\n        }\n        else {\n            throw e;\n        }\n    }\n}\n// based on https://github.com/epoberezkin/fast-deep-equal\n// MIT License\n// Copyright (c) 2017 Evgeny Poberezkin\n// Permission is hereby granted, free of charge, to any person obtaining a copy\n// of this software and associated documentation files (the \"Software\"), to deal\n// in the Software without restriction, including without limitation the rights\n// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n// copies of the Software, and to permit persons to whom the Software is\n// furnished to do so, subject to the following conditions:\n// The above copyright notice and this permission notice shall be included in all\n// copies or substantial portions of the Software.\n// THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\n// SOFTWARE.\nfunction _areEquals(a, b) {\n    if (a === b)\n        return true;\n    if (a && b && typeof a == 'object' && typeof b == 'object') {\n        var arrA = Array.isArray(a), arrB = Array.isArray(b), i, length, key;\n        if (arrA && arrB) {\n            length = a.length;\n            if (length != b.length)\n                return false;\n            for (i = length; i-- !== 0;)\n                if (!_areEquals(a[i], b[i]))\n                    return false;\n            return true;\n        }\n        if (arrA != arrB)\n            return false;\n        var keys = Object.keys(a);\n        length = keys.length;\n        if (length !== Object.keys(b).length)\n            return false;\n        for (i = length; i-- !== 0;)\n            if (!b.hasOwnProperty(keys[i]))\n                return false;\n        for (i = length; i-- !== 0;) {\n            key = keys[i];\n            if (!_areEquals(a[key], b[key]))\n                return false;\n        }\n        return true;\n    }\n    return a !== a && b !== b;\n}\n;\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-json-patch/module/core.mjs?");

/***/ }),

/***/ "../../node_modules/fast-json-patch/module/duplex.mjs":
/*!************************************************************!*\
  !*** ../../node_modules/fast-json-patch/module/duplex.mjs ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   compare: () => (/* binding */ compare),\n/* harmony export */   generate: () => (/* binding */ generate),\n/* harmony export */   observe: () => (/* binding */ observe),\n/* harmony export */   unobserve: () => (/* binding */ unobserve)\n/* harmony export */ });\n/* harmony import */ var _helpers_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./helpers.mjs */ \"../../node_modules/fast-json-patch/module/helpers.mjs\");\n/* harmony import */ var _core_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./core.mjs */ \"../../node_modules/fast-json-patch/module/core.mjs\");\n/*!\n * https://github.com/Starcounter-Jack/JSON-Patch\n * (c) 2017-2021 Joachim Wester\n * MIT license\n */\n\n\nvar beforeDict = new WeakMap();\nvar Mirror = /** @class */ (function () {\n    function Mirror(obj) {\n        this.observers = new Map();\n        this.obj = obj;\n    }\n    return Mirror;\n}());\nvar ObserverInfo = /** @class */ (function () {\n    function ObserverInfo(callback, observer) {\n        this.callback = callback;\n        this.observer = observer;\n    }\n    return ObserverInfo;\n}());\nfunction getMirror(obj) {\n    return beforeDict.get(obj);\n}\nfunction getObserverFromMirror(mirror, callback) {\n    return mirror.observers.get(callback);\n}\nfunction removeObserverFromMirror(mirror, observer) {\n    mirror.observers.delete(observer.callback);\n}\n/**\n * Detach an observer from an object\n */\nfunction unobserve(root, observer) {\n    observer.unobserve();\n}\n/**\n * Observes changes made to an object, which can then be retrieved using generate\n */\nfunction observe(obj, callback) {\n    var patches = [];\n    var observer;\n    var mirror = getMirror(obj);\n    if (!mirror) {\n        mirror = new Mirror(obj);\n        beforeDict.set(obj, mirror);\n    }\n    else {\n        var observerInfo = getObserverFromMirror(mirror, callback);\n        observer = observerInfo && observerInfo.observer;\n    }\n    if (observer) {\n        return observer;\n    }\n    observer = {};\n    mirror.value = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(obj);\n    if (callback) {\n        observer.callback = callback;\n        observer.next = null;\n        var dirtyCheck = function () {\n            generate(observer);\n        };\n        var fastCheck = function () {\n            clearTimeout(observer.next);\n            observer.next = setTimeout(dirtyCheck);\n        };\n        if (typeof window !== 'undefined') { //not Node\n            window.addEventListener('mouseup', fastCheck);\n            window.addEventListener('keyup', fastCheck);\n            window.addEventListener('mousedown', fastCheck);\n            window.addEventListener('keydown', fastCheck);\n            window.addEventListener('change', fastCheck);\n        }\n    }\n    observer.patches = patches;\n    observer.object = obj;\n    observer.unobserve = function () {\n        generate(observer);\n        clearTimeout(observer.next);\n        removeObserverFromMirror(mirror, observer);\n        if (typeof window !== 'undefined') {\n            window.removeEventListener('mouseup', fastCheck);\n            window.removeEventListener('keyup', fastCheck);\n            window.removeEventListener('mousedown', fastCheck);\n            window.removeEventListener('keydown', fastCheck);\n            window.removeEventListener('change', fastCheck);\n        }\n    };\n    mirror.observers.set(callback, new ObserverInfo(callback, observer));\n    return observer;\n}\n/**\n * Generate an array of patches from an observer\n */\nfunction generate(observer, invertible) {\n    if (invertible === void 0) { invertible = false; }\n    var mirror = beforeDict.get(observer.object);\n    _generate(mirror.value, observer.object, observer.patches, \"\", invertible);\n    if (observer.patches.length) {\n        (0,_core_mjs__WEBPACK_IMPORTED_MODULE_1__.applyPatch)(mirror.value, observer.patches);\n    }\n    var temp = observer.patches;\n    if (temp.length > 0) {\n        observer.patches = [];\n        if (observer.callback) {\n            observer.callback(temp);\n        }\n    }\n    return temp;\n}\n// Dirty check if obj is different from mirror, generate patches and update mirror\nfunction _generate(mirror, obj, patches, path, invertible) {\n    if (obj === mirror) {\n        return;\n    }\n    if (typeof obj.toJSON === \"function\") {\n        obj = obj.toJSON();\n    }\n    var newKeys = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._objectKeys)(obj);\n    var oldKeys = (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._objectKeys)(mirror);\n    var changed = false;\n    var deleted = false;\n    //if ever \"move\" operation is implemented here, make sure this test runs OK: \"should not generate the same patch twice (move)\"\n    for (var t = oldKeys.length - 1; t >= 0; t--) {\n        var key = oldKeys[t];\n        var oldVal = mirror[key];\n        if ((0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(obj, key) && !(obj[key] === undefined && oldVal !== undefined && Array.isArray(obj) === false)) {\n            var newVal = obj[key];\n            if (typeof oldVal == \"object\" && oldVal != null && typeof newVal == \"object\" && newVal != null && Array.isArray(oldVal) === Array.isArray(newVal)) {\n                _generate(oldVal, newVal, patches, path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key), invertible);\n            }\n            else {\n                if (oldVal !== newVal) {\n                    changed = true;\n                    if (invertible) {\n                        patches.push({ op: \"test\", path: path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key), value: (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(oldVal) });\n                    }\n                    patches.push({ op: \"replace\", path: path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key), value: (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(newVal) });\n                }\n            }\n        }\n        else if (Array.isArray(mirror) === Array.isArray(obj)) {\n            if (invertible) {\n                patches.push({ op: \"test\", path: path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key), value: (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(oldVal) });\n            }\n            patches.push({ op: \"remove\", path: path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key) });\n            deleted = true; // property has been deleted\n        }\n        else {\n            if (invertible) {\n                patches.push({ op: \"test\", path: path, value: mirror });\n            }\n            patches.push({ op: \"replace\", path: path, value: obj });\n            changed = true;\n        }\n    }\n    if (!deleted && newKeys.length == oldKeys.length) {\n        return;\n    }\n    for (var t = 0; t < newKeys.length; t++) {\n        var key = newKeys[t];\n        if (!(0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty)(mirror, key) && obj[key] !== undefined) {\n            patches.push({ op: \"add\", path: path + \"/\" + (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__.escapePathComponent)(key), value: (0,_helpers_mjs__WEBPACK_IMPORTED_MODULE_0__._deepClone)(obj[key]) });\n        }\n    }\n}\n/**\n * Create an array of patches from the differences in two objects\n */\nfunction compare(tree1, tree2, invertible) {\n    if (invertible === void 0) { invertible = false; }\n    var patches = [];\n    _generate(tree1, tree2, patches, '', invertible);\n    return patches;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-json-patch/module/duplex.mjs?");

/***/ }),

/***/ "../../node_modules/fast-json-patch/module/helpers.mjs":
/*!*************************************************************!*\
  !*** ../../node_modules/fast-json-patch/module/helpers.mjs ***!
  \*************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   PatchError: () => (/* binding */ PatchError),\n/* harmony export */   _deepClone: () => (/* binding */ _deepClone),\n/* harmony export */   _getPathRecursive: () => (/* binding */ _getPathRecursive),\n/* harmony export */   _objectKeys: () => (/* binding */ _objectKeys),\n/* harmony export */   escapePathComponent: () => (/* binding */ escapePathComponent),\n/* harmony export */   getPath: () => (/* binding */ getPath),\n/* harmony export */   hasOwnProperty: () => (/* binding */ hasOwnProperty),\n/* harmony export */   hasUndefined: () => (/* binding */ hasUndefined),\n/* harmony export */   isInteger: () => (/* binding */ isInteger),\n/* harmony export */   unescapePathComponent: () => (/* binding */ unescapePathComponent)\n/* harmony export */ });\n/*!\n * https://github.com/Starcounter-Jack/JSON-Patch\n * (c) 2017-2022 Joachim Wester\n * MIT licensed\n */\nvar __extends = (undefined && undefined.__extends) || (function () {\n    var extendStatics = function (d, b) {\n        extendStatics = Object.setPrototypeOf ||\n            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\n            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\n        return extendStatics(d, b);\n    };\n    return function (d, b) {\n        extendStatics(d, b);\n        function __() { this.constructor = d; }\n        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n    };\n})();\nvar _hasOwnProperty = Object.prototype.hasOwnProperty;\nfunction hasOwnProperty(obj, key) {\n    return _hasOwnProperty.call(obj, key);\n}\nfunction _objectKeys(obj) {\n    if (Array.isArray(obj)) {\n        var keys_1 = new Array(obj.length);\n        for (var k = 0; k < keys_1.length; k++) {\n            keys_1[k] = \"\" + k;\n        }\n        return keys_1;\n    }\n    if (Object.keys) {\n        return Object.keys(obj);\n    }\n    var keys = [];\n    for (var i in obj) {\n        if (hasOwnProperty(obj, i)) {\n            keys.push(i);\n        }\n    }\n    return keys;\n}\n;\n/**\n* Deeply clone the object.\n* https://jsperf.com/deep-copy-vs-json-stringify-json-parse/25 (recursiveDeepCopy)\n* @param  {any} obj value to clone\n* @return {any} cloned obj\n*/\nfunction _deepClone(obj) {\n    switch (typeof obj) {\n        case \"object\":\n            return JSON.parse(JSON.stringify(obj)); //Faster than ES5 clone - http://jsperf.com/deep-cloning-of-objects/5\n        case \"undefined\":\n            return null; //this is how JSON.stringify behaves for array items\n        default:\n            return obj; //no need to clone primitives\n    }\n}\n//3x faster than cached /^\\d+$/.test(str)\nfunction isInteger(str) {\n    var i = 0;\n    var len = str.length;\n    var charCode;\n    while (i < len) {\n        charCode = str.charCodeAt(i);\n        if (charCode >= 48 && charCode <= 57) {\n            i++;\n            continue;\n        }\n        return false;\n    }\n    return true;\n}\n/**\n* Escapes a json pointer path\n* @param path The raw pointer\n* @return the Escaped path\n*/\nfunction escapePathComponent(path) {\n    if (path.indexOf('/') === -1 && path.indexOf('~') === -1)\n        return path;\n    return path.replace(/~/g, '~0').replace(/\\//g, '~1');\n}\n/**\n * Unescapes a json pointer path\n * @param path The escaped pointer\n * @return The unescaped path\n */\nfunction unescapePathComponent(path) {\n    return path.replace(/~1/g, '/').replace(/~0/g, '~');\n}\nfunction _getPathRecursive(root, obj) {\n    var found;\n    for (var key in root) {\n        if (hasOwnProperty(root, key)) {\n            if (root[key] === obj) {\n                return escapePathComponent(key) + '/';\n            }\n            else if (typeof root[key] === 'object') {\n                found = _getPathRecursive(root[key], obj);\n                if (found != '') {\n                    return escapePathComponent(key) + '/' + found;\n                }\n            }\n        }\n    }\n    return '';\n}\nfunction getPath(root, obj) {\n    if (root === obj) {\n        return '/';\n    }\n    var path = _getPathRecursive(root, obj);\n    if (path === '') {\n        throw new Error(\"Object not found in root\");\n    }\n    return \"/\" + path;\n}\n/**\n* Recursively checks whether an object has any undefined values inside.\n*/\nfunction hasUndefined(obj) {\n    if (obj === undefined) {\n        return true;\n    }\n    if (obj) {\n        if (Array.isArray(obj)) {\n            for (var i_1 = 0, len = obj.length; i_1 < len; i_1++) {\n                if (hasUndefined(obj[i_1])) {\n                    return true;\n                }\n            }\n        }\n        else if (typeof obj === \"object\") {\n            var objKeys = _objectKeys(obj);\n            var objKeysLength = objKeys.length;\n            for (var i = 0; i < objKeysLength; i++) {\n                if (hasUndefined(obj[objKeys[i]])) {\n                    return true;\n                }\n            }\n        }\n    }\n    return false;\n}\nfunction patchErrorMessageFormatter(message, args) {\n    var messageParts = [message];\n    for (var key in args) {\n        var value = typeof args[key] === 'object' ? JSON.stringify(args[key], null, 2) : args[key]; // pretty print\n        if (typeof value !== 'undefined') {\n            messageParts.push(key + \": \" + value);\n        }\n    }\n    return messageParts.join('\\n');\n}\nvar PatchError = /** @class */ (function (_super) {\n    __extends(PatchError, _super);\n    function PatchError(message, name, index, operation, tree) {\n        var _newTarget = this.constructor;\n        var _this = _super.call(this, patchErrorMessageFormatter(message, { name: name, index: index, operation: operation, tree: tree })) || this;\n        _this.name = name;\n        _this.index = index;\n        _this.operation = operation;\n        _this.tree = tree;\n        Object.setPrototypeOf(_this, _newTarget.prototype); // restore prototype chain, see https://stackoverflow.com/a/48342359\n        _this.message = patchErrorMessageFormatter(message, { name: name, index: index, operation: operation, tree: tree });\n        return _this;\n    }\n    return PatchError;\n}(Error));\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/fast-json-patch/module/helpers.mjs?");

/***/ }),

/***/ "../../node_modules/flatbuffers/js/flatbuffers.mjs":
/*!*********************************************************!*\
  !*** ../../node_modules/flatbuffers/js/flatbuffers.mjs ***!
  \*********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   flatbuffers: () => (/* binding */ flatbuffers)\n/* harmony export */ });\n/// @file\n/// @addtogroup flatbuffers_javascript_api\n/// @{\n/// @cond FLATBUFFERS_INTERNAL\n\n/**\n * @fileoverview\n *\n * Need to suppress 'global this' error so the Node.js export line doesn't cause\n * closure compile to error out.\n * @suppress {globalThis}\n */\n\n/**\n * @const\n * @namespace\n */\nvar flatbuffers = {};\n\n/**\n * @typedef {number}\n */\nflatbuffers.Offset;\n\n/**\n * @typedef {{\n *   bb: flatbuffers.ByteBuffer,\n *   bb_pos: number\n * }}\n */\nflatbuffers.Table;\n\n/**\n * @type {number}\n * @const\n */\nflatbuffers.SIZEOF_SHORT = 2;\n\n/**\n * @type {number}\n * @const\n */\nflatbuffers.SIZEOF_INT = 4;\n\n/**\n * @type {number}\n * @const\n */\nflatbuffers.FILE_IDENTIFIER_LENGTH = 4;\n\n/**\n * @enum {number}\n */\nflatbuffers.Encoding = {\n  UTF8_BYTES: 1,\n  UTF16_STRING: 2\n};\n\n/**\n * @type {Int32Array}\n * @const\n */\nflatbuffers.int32 = new Int32Array(2);\n\n/**\n * @type {Float32Array}\n * @const\n */\nflatbuffers.float32 = new Float32Array(flatbuffers.int32.buffer);\n\n/**\n * @type {Float64Array}\n * @const\n */\nflatbuffers.float64 = new Float64Array(flatbuffers.int32.buffer);\n\n/**\n * @type {boolean}\n * @const\n */\nflatbuffers.isLittleEndian = new Uint16Array(new Uint8Array([1, 0]).buffer)[0] === 1;\n\n////////////////////////////////////////////////////////////////////////////////\n\n/**\n * @constructor\n * @param {number} low\n * @param {number} high\n */\nflatbuffers.Long = function(low, high) {\n  /**\n   * @type {number}\n   * @const\n   */\n  this.low = low | 0;\n\n  /**\n   * @type {number}\n   * @const\n   */\n  this.high = high | 0;\n};\n\n/**\n * @param {number} low\n * @param {number} high\n * @returns {flatbuffers.Long}\n */\nflatbuffers.Long.create = function(low, high) {\n  // Special-case zero to avoid GC overhead for default values\n  return low == 0 && high == 0 ? flatbuffers.Long.ZERO : new flatbuffers.Long(low, high);\n};\n\n/**\n * @returns {number}\n */\nflatbuffers.Long.prototype.toFloat64 = function() {\n  return (this.low >>> 0) + this.high * 0x100000000;\n};\n\n/**\n * @param {flatbuffers.Long} other\n * @returns {boolean}\n */\nflatbuffers.Long.prototype.equals = function(other) {\n  return this.low == other.low && this.high == other.high;\n};\n\n/**\n * @type {flatbuffers.Long}\n * @const\n */\nflatbuffers.Long.ZERO = new flatbuffers.Long(0, 0);\n\n/// @endcond\n////////////////////////////////////////////////////////////////////////////////\n/**\n * Create a FlatBufferBuilder.\n *\n * @constructor\n * @param {number=} opt_initial_size\n */\nflatbuffers.Builder = function(opt_initial_size) {\n  if (!opt_initial_size) {\n    var initial_size = 1024;\n  } else {\n    var initial_size = opt_initial_size;\n  }\n\n  /**\n   * @type {flatbuffers.ByteBuffer}\n   * @private\n   */\n  this.bb = flatbuffers.ByteBuffer.allocate(initial_size);\n\n  /**\n   * Remaining space in the ByteBuffer.\n   *\n   * @type {number}\n   * @private\n   */\n  this.space = initial_size;\n\n  /**\n   * Minimum alignment encountered so far.\n   *\n   * @type {number}\n   * @private\n   */\n  this.minalign = 1;\n\n  /**\n   * The vtable for the current table.\n   *\n   * @type {Array.<number>}\n   * @private\n   */\n  this.vtable = null;\n\n  /**\n   * The amount of fields we're actually using.\n   *\n   * @type {number}\n   * @private\n   */\n  this.vtable_in_use = 0;\n\n  /**\n   * Whether we are currently serializing a table.\n   *\n   * @type {boolean}\n   * @private\n   */\n  this.isNested = false;\n\n  /**\n   * Starting offset of the current struct/table.\n   *\n   * @type {number}\n   * @private\n   */\n  this.object_start = 0;\n\n  /**\n   * List of offsets of all vtables.\n   *\n   * @type {Array.<number>}\n   * @private\n   */\n  this.vtables = [];\n\n  /**\n   * For the current vector being built.\n   *\n   * @type {number}\n   * @private\n   */\n  this.vector_num_elems = 0;\n\n  /**\n   * False omits default values from the serialized data\n   *\n   * @type {boolean}\n   * @private\n   */\n  this.force_defaults = false;\n};\n\nflatbuffers.Builder.prototype.clear = function() {\n  this.bb.clear();\n  this.space = this.bb.capacity();\n  this.minalign = 1;\n  this.vtable = null;\n  this.vtable_in_use = 0;\n  this.isNested = false;\n  this.object_start = 0;\n  this.vtables = [];\n  this.vector_num_elems = 0;\n  this.force_defaults = false;\n};\n\n/**\n * In order to save space, fields that are set to their default value\n * don't get serialized into the buffer. Forcing defaults provides a\n * way to manually disable this optimization.\n *\n * @param {boolean} forceDefaults true always serializes default values\n */\nflatbuffers.Builder.prototype.forceDefaults = function(forceDefaults) {\n  this.force_defaults = forceDefaults;\n};\n\n/**\n * Get the ByteBuffer representing the FlatBuffer. Only call this after you've\n * called finish(). The actual data starts at the ByteBuffer's current position,\n * not necessarily at 0.\n *\n * @returns {flatbuffers.ByteBuffer}\n */\nflatbuffers.Builder.prototype.dataBuffer = function() {\n  return this.bb;\n};\n\n/**\n * Get the bytes representing the FlatBuffer. Only call this after you've\n * called finish().\n *\n * @returns {Uint8Array}\n */\nflatbuffers.Builder.prototype.asUint8Array = function() {\n  return this.bb.bytes().subarray(this.bb.position(), this.bb.position() + this.offset());\n};\n\n/// @cond FLATBUFFERS_INTERNAL\n/**\n * Prepare to write an element of `size` after `additional_bytes` have been\n * written, e.g. if you write a string, you need to align such the int length\n * field is aligned to 4 bytes, and the string data follows it directly. If all\n * you need to do is alignment, `additional_bytes` will be 0.\n *\n * @param {number} size This is the of the new element to write\n * @param {number} additional_bytes The padding size\n */\nflatbuffers.Builder.prototype.prep = function(size, additional_bytes) {\n  // Track the biggest thing we've ever aligned to.\n  if (size > this.minalign) {\n    this.minalign = size;\n  }\n\n  // Find the amount of alignment needed such that `size` is properly\n  // aligned after `additional_bytes`\n  var align_size = ((~(this.bb.capacity() - this.space + additional_bytes)) + 1) & (size - 1);\n\n  // Reallocate the buffer if needed.\n  while (this.space < align_size + size + additional_bytes) {\n    var old_buf_size = this.bb.capacity();\n    this.bb = flatbuffers.Builder.growByteBuffer(this.bb);\n    this.space += this.bb.capacity() - old_buf_size;\n  }\n\n  this.pad(align_size);\n};\n\n/**\n * @param {number} byte_size\n */\nflatbuffers.Builder.prototype.pad = function(byte_size) {\n  for (var i = 0; i < byte_size; i++) {\n    this.bb.writeInt8(--this.space, 0);\n  }\n};\n\n/**\n * @param {number} value\n */\nflatbuffers.Builder.prototype.writeInt8 = function(value) {\n  this.bb.writeInt8(this.space -= 1, value);\n};\n\n/**\n * @param {number} value\n */\nflatbuffers.Builder.prototype.writeInt16 = function(value) {\n  this.bb.writeInt16(this.space -= 2, value);\n};\n\n/**\n * @param {number} value\n */\nflatbuffers.Builder.prototype.writeInt32 = function(value) {\n  this.bb.writeInt32(this.space -= 4, value);\n};\n\n/**\n * @param {flatbuffers.Long} value\n */\nflatbuffers.Builder.prototype.writeInt64 = function(value) {\n  this.bb.writeInt64(this.space -= 8, value);\n};\n\n/**\n * @param {number} value\n */\nflatbuffers.Builder.prototype.writeFloat32 = function(value) {\n  this.bb.writeFloat32(this.space -= 4, value);\n};\n\n/**\n * @param {number} value\n */\nflatbuffers.Builder.prototype.writeFloat64 = function(value) {\n  this.bb.writeFloat64(this.space -= 8, value);\n};\n/// @endcond\n\n/**\n * Add an `int8` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {number} value The `int8` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addInt8 = function(value) {\n  this.prep(1, 0);\n  this.writeInt8(value);\n};\n\n/**\n * Add an `int16` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {number} value The `int16` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addInt16 = function(value) {\n  this.prep(2, 0);\n  this.writeInt16(value);\n};\n\n/**\n * Add an `int32` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {number} value The `int32` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addInt32 = function(value) {\n  this.prep(4, 0);\n  this.writeInt32(value);\n};\n\n/**\n * Add an `int64` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {flatbuffers.Long} value The `int64` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addInt64 = function(value) {\n  this.prep(8, 0);\n  this.writeInt64(value);\n};\n\n/**\n * Add a `float32` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {number} value The `float32` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addFloat32 = function(value) {\n  this.prep(4, 0);\n  this.writeFloat32(value);\n};\n\n/**\n * Add a `float64` to the buffer, properly aligned, and grows the buffer (if necessary).\n * @param {number} value The `float64` to add the the buffer.\n */\nflatbuffers.Builder.prototype.addFloat64 = function(value) {\n  this.prep(8, 0);\n  this.writeFloat64(value);\n};\n\n/// @cond FLATBUFFERS_INTERNAL\n/**\n * @param {number} voffset\n * @param {number} value\n * @param {number} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldInt8 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addInt8(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {number} value\n * @param {number} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldInt16 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addInt16(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {number} value\n * @param {number} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldInt32 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addInt32(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {flatbuffers.Long} value\n * @param {flatbuffers.Long} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldInt64 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || !value.equals(defaultValue)) {\n    this.addInt64(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {number} value\n * @param {number} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldFloat32 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addFloat32(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {number} value\n * @param {number} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldFloat64 = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addFloat64(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * @param {number} voffset\n * @param {flatbuffers.Offset} value\n * @param {flatbuffers.Offset} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldOffset = function(voffset, value, defaultValue) {\n  if (this.force_defaults || value != defaultValue) {\n    this.addOffset(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * Structs are stored inline, so nothing additional is being added. `d` is always 0.\n *\n * @param {number} voffset\n * @param {flatbuffers.Offset} value\n * @param {flatbuffers.Offset} defaultValue\n */\nflatbuffers.Builder.prototype.addFieldStruct = function(voffset, value, defaultValue) {\n  if (value != defaultValue) {\n    this.nested(value);\n    this.slot(voffset);\n  }\n};\n\n/**\n * Structures are always stored inline, they need to be created right\n * where they're used.  You'll get this assertion failure if you\n * created it elsewhere.\n *\n * @param {flatbuffers.Offset} obj The offset of the created object\n */\nflatbuffers.Builder.prototype.nested = function(obj) {\n  if (obj != this.offset()) {\n    throw new Error('FlatBuffers: struct must be serialized inline.');\n  }\n};\n\n/**\n * Should not be creating any other object, string or vector\n * while an object is being constructed\n */\nflatbuffers.Builder.prototype.notNested = function() {\n  if (this.isNested) {\n    throw new Error('FlatBuffers: object serialization must not be nested.');\n  }\n};\n\n/**\n * Set the current vtable at `voffset` to the current location in the buffer.\n *\n * @param {number} voffset\n */\nflatbuffers.Builder.prototype.slot = function(voffset) {\n  this.vtable[voffset] = this.offset();\n};\n\n/**\n * @returns {flatbuffers.Offset} Offset relative to the end of the buffer.\n */\nflatbuffers.Builder.prototype.offset = function() {\n  return this.bb.capacity() - this.space;\n};\n\n/**\n * Doubles the size of the backing ByteBuffer and copies the old data towards\n * the end of the new buffer (since we build the buffer backwards).\n *\n * @param {flatbuffers.ByteBuffer} bb The current buffer with the existing data\n * @returns {flatbuffers.ByteBuffer} A new byte buffer with the old data copied\n * to it. The data is located at the end of the buffer.\n *\n * uint8Array.set() formally takes {Array<number>|ArrayBufferView}, so to pass\n * it a uint8Array we need to suppress the type check:\n * @suppress {checkTypes}\n */\nflatbuffers.Builder.growByteBuffer = function(bb) {\n  var old_buf_size = bb.capacity();\n\n  // Ensure we don't grow beyond what fits in an int.\n  if (old_buf_size & 0xC0000000) {\n    throw new Error('FlatBuffers: cannot grow buffer beyond 2 gigabytes.');\n  }\n\n  var new_buf_size = old_buf_size << 1;\n  var nbb = flatbuffers.ByteBuffer.allocate(new_buf_size);\n  nbb.setPosition(new_buf_size - old_buf_size);\n  nbb.bytes().set(bb.bytes(), new_buf_size - old_buf_size);\n  return nbb;\n};\n/// @endcond\n\n/**\n * Adds on offset, relative to where it will be written.\n *\n * @param {flatbuffers.Offset} offset The offset to add.\n */\nflatbuffers.Builder.prototype.addOffset = function(offset) {\n  this.prep(flatbuffers.SIZEOF_INT, 0); // Ensure alignment is already done.\n  this.writeInt32(this.offset() - offset + flatbuffers.SIZEOF_INT);\n};\n\n/// @cond FLATBUFFERS_INTERNAL\n/**\n * Start encoding a new object in the buffer.  Users will not usually need to\n * call this directly. The FlatBuffers compiler will generate helper methods\n * that call this method internally.\n *\n * @param {number} numfields\n */\nflatbuffers.Builder.prototype.startObject = function(numfields) {\n  this.notNested();\n  if (this.vtable == null) {\n    this.vtable = [];\n  }\n  this.vtable_in_use = numfields;\n  for (var i = 0; i < numfields; i++) {\n    this.vtable[i] = 0; // This will push additional elements as needed\n  }\n  this.isNested = true;\n  this.object_start = this.offset();\n};\n\n/**\n * Finish off writing the object that is under construction.\n *\n * @returns {flatbuffers.Offset} The offset to the object inside `dataBuffer`\n */\nflatbuffers.Builder.prototype.endObject = function() {\n  if (this.vtable == null || !this.isNested) {\n    throw new Error('FlatBuffers: endObject called without startObject');\n  }\n\n  this.addInt32(0);\n  var vtableloc = this.offset();\n\n  // Trim trailing zeroes.\n  var i = this.vtable_in_use - 1;\n  for (; i >= 0 && this.vtable[i] == 0; i--) {}\n  var trimmed_size = i + 1;\n\n  // Write out the current vtable.\n  for (; i >= 0; i--) {\n    // Offset relative to the start of the table.\n    this.addInt16(this.vtable[i] != 0 ? vtableloc - this.vtable[i] : 0);\n  }\n\n  var standard_fields = 2; // The fields below:\n  this.addInt16(vtableloc - this.object_start);\n  var len = (trimmed_size + standard_fields) * flatbuffers.SIZEOF_SHORT;\n  this.addInt16(len);\n\n  // Search for an existing vtable that matches the current one.\n  var existing_vtable = 0;\n  var vt1 = this.space;\nouter_loop:\n  for (i = 0; i < this.vtables.length; i++) {\n    var vt2 = this.bb.capacity() - this.vtables[i];\n    if (len == this.bb.readInt16(vt2)) {\n      for (var j = flatbuffers.SIZEOF_SHORT; j < len; j += flatbuffers.SIZEOF_SHORT) {\n        if (this.bb.readInt16(vt1 + j) != this.bb.readInt16(vt2 + j)) {\n          continue outer_loop;\n        }\n      }\n      existing_vtable = this.vtables[i];\n      break;\n    }\n  }\n\n  if (existing_vtable) {\n    // Found a match:\n    // Remove the current vtable.\n    this.space = this.bb.capacity() - vtableloc;\n\n    // Point table to existing vtable.\n    this.bb.writeInt32(this.space, existing_vtable - vtableloc);\n  } else {\n    // No match:\n    // Add the location of the current vtable to the list of vtables.\n    this.vtables.push(this.offset());\n\n    // Point table to current vtable.\n    this.bb.writeInt32(this.bb.capacity() - vtableloc, this.offset() - vtableloc);\n  }\n\n  this.isNested = false;\n  return vtableloc;\n};\n/// @endcond\n\n/**\n * Finalize a buffer, poiting to the given `root_table`.\n *\n * @param {flatbuffers.Offset} root_table\n * @param {string=} opt_file_identifier\n */\nflatbuffers.Builder.prototype.finish = function(root_table, opt_file_identifier) {\n  if (opt_file_identifier) {\n    var file_identifier = opt_file_identifier;\n    this.prep(this.minalign, flatbuffers.SIZEOF_INT +\n      flatbuffers.FILE_IDENTIFIER_LENGTH);\n    if (file_identifier.length != flatbuffers.FILE_IDENTIFIER_LENGTH) {\n      throw new Error('FlatBuffers: file identifier must be length ' +\n        flatbuffers.FILE_IDENTIFIER_LENGTH);\n    }\n    for (var i = flatbuffers.FILE_IDENTIFIER_LENGTH - 1; i >= 0; i--) {\n      this.writeInt8(file_identifier.charCodeAt(i));\n    }\n  }\n  this.prep(this.minalign, flatbuffers.SIZEOF_INT);\n  this.addOffset(root_table);\n  this.bb.setPosition(this.space);\n};\n\n/// @cond FLATBUFFERS_INTERNAL\n/**\n * This checks a required field has been set in a given table that has\n * just been constructed.\n *\n * @param {flatbuffers.Offset} table\n * @param {number} field\n */\nflatbuffers.Builder.prototype.requiredField = function(table, field) {\n  var table_start = this.bb.capacity() - table;\n  var vtable_start = table_start - this.bb.readInt32(table_start);\n  var ok = this.bb.readInt16(vtable_start + field) != 0;\n\n  // If this fails, the caller will show what field needs to be set.\n  if (!ok) {\n    throw new Error('FlatBuffers: field ' + field + ' must be set');\n  }\n};\n\n/**\n * Start a new array/vector of objects.  Users usually will not call\n * this directly. The FlatBuffers compiler will create a start/end\n * method for vector types in generated code.\n *\n * @param {number} elem_size The size of each element in the array\n * @param {number} num_elems The number of elements in the array\n * @param {number} alignment The alignment of the array\n */\nflatbuffers.Builder.prototype.startVector = function(elem_size, num_elems, alignment) {\n  this.notNested();\n  this.vector_num_elems = num_elems;\n  this.prep(flatbuffers.SIZEOF_INT, elem_size * num_elems);\n  this.prep(alignment, elem_size * num_elems); // Just in case alignment > int.\n};\n\n/**\n * Finish off the creation of an array and all its elements. The array must be\n * created with `startVector`.\n *\n * @returns {flatbuffers.Offset} The offset at which the newly created array\n * starts.\n */\nflatbuffers.Builder.prototype.endVector = function() {\n  this.writeInt32(this.vector_num_elems);\n  return this.offset();\n};\n/// @endcond\n\n/**\n * Encode the string `s` in the buffer using UTF-8. If a Uint8Array is passed\n * instead of a string, it is assumed to contain valid UTF-8 encoded data.\n *\n * @param {string|Uint8Array} s The string to encode\n * @return {flatbuffers.Offset} The offset in the buffer where the encoded string starts\n */\nflatbuffers.Builder.prototype.createString = function(s) {\n  if (s instanceof Uint8Array) {\n    var utf8 = s;\n  } else {\n    var utf8 = [];\n    var i = 0;\n\n    while (i < s.length) {\n      var codePoint;\n\n      // Decode UTF-16\n      var a = s.charCodeAt(i++);\n      if (a < 0xD800 || a >= 0xDC00) {\n        codePoint = a;\n      } else {\n        var b = s.charCodeAt(i++);\n        codePoint = (a << 10) + b + (0x10000 - (0xD800 << 10) - 0xDC00);\n      }\n\n      // Encode UTF-8\n      if (codePoint < 0x80) {\n        utf8.push(codePoint);\n      } else {\n        if (codePoint < 0x800) {\n          utf8.push(((codePoint >> 6) & 0x1F) | 0xC0);\n        } else {\n          if (codePoint < 0x10000) {\n            utf8.push(((codePoint >> 12) & 0x0F) | 0xE0);\n          } else {\n            utf8.push(\n              ((codePoint >> 18) & 0x07) | 0xF0,\n              ((codePoint >> 12) & 0x3F) | 0x80);\n          }\n          utf8.push(((codePoint >> 6) & 0x3F) | 0x80);\n        }\n        utf8.push((codePoint & 0x3F) | 0x80);\n      }\n    }\n  }\n\n  this.addInt8(0);\n  this.startVector(1, utf8.length, 1);\n  this.bb.setPosition(this.space -= utf8.length);\n  for (var i = 0, offset = this.space, bytes = this.bb.bytes(); i < utf8.length; i++) {\n    bytes[offset++] = utf8[i];\n  }\n  return this.endVector();\n};\n\n/**\n * A helper function to avoid generated code depending on this file directly.\n *\n * @param {number} low\n * @param {number} high\n * @returns {flatbuffers.Long}\n */\nflatbuffers.Builder.prototype.createLong = function(low, high) {\n  return flatbuffers.Long.create(low, high);\n};\n////////////////////////////////////////////////////////////////////////////////\n/// @cond FLATBUFFERS_INTERNAL\n/**\n * Create a new ByteBuffer with a given array of bytes (`Uint8Array`).\n *\n * @constructor\n * @param {Uint8Array} bytes\n */\nflatbuffers.ByteBuffer = function(bytes) {\n  /**\n   * @type {Uint8Array}\n   * @private\n   */\n  this.bytes_ = bytes;\n\n  /**\n   * @type {number}\n   * @private\n   */\n  this.position_ = 0;\n};\n\n/**\n * Create and allocate a new ByteBuffer with a given size.\n *\n * @param {number} byte_size\n * @returns {flatbuffers.ByteBuffer}\n */\nflatbuffers.ByteBuffer.allocate = function(byte_size) {\n  return new flatbuffers.ByteBuffer(new Uint8Array(byte_size));\n};\n\nflatbuffers.ByteBuffer.prototype.clear = function() {\n  this.position_ = 0;\n};\n\n/**\n * Get the underlying `Uint8Array`.\n *\n * @returns {Uint8Array}\n */\nflatbuffers.ByteBuffer.prototype.bytes = function() {\n  return this.bytes_;\n};\n\n/**\n * Get the buffer's position.\n *\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.position = function() {\n  return this.position_;\n};\n\n/**\n * Set the buffer's position.\n *\n * @param {number} position\n */\nflatbuffers.ByteBuffer.prototype.setPosition = function(position) {\n  this.position_ = position;\n};\n\n/**\n * Get the buffer's capacity.\n *\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.capacity = function() {\n  return this.bytes_.length;\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readInt8 = function(offset) {\n  return this.readUint8(offset) << 24 >> 24;\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readUint8 = function(offset) {\n  return this.bytes_[offset];\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readInt16 = function(offset) {\n  return this.readUint16(offset) << 16 >> 16;\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readUint16 = function(offset) {\n  return this.bytes_[offset] | this.bytes_[offset + 1] << 8;\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readInt32 = function(offset) {\n  return this.bytes_[offset] | this.bytes_[offset + 1] << 8 | this.bytes_[offset + 2] << 16 | this.bytes_[offset + 3] << 24;\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readUint32 = function(offset) {\n  return this.readInt32(offset) >>> 0;\n};\n\n/**\n * @param {number} offset\n * @returns {flatbuffers.Long}\n */\nflatbuffers.ByteBuffer.prototype.readInt64 = function(offset) {\n  return new flatbuffers.Long(this.readInt32(offset), this.readInt32(offset + 4));\n};\n\n/**\n * @param {number} offset\n * @returns {flatbuffers.Long}\n */\nflatbuffers.ByteBuffer.prototype.readUint64 = function(offset) {\n  return new flatbuffers.Long(this.readUint32(offset), this.readUint32(offset + 4));\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readFloat32 = function(offset) {\n  flatbuffers.int32[0] = this.readInt32(offset);\n  return flatbuffers.float32[0];\n};\n\n/**\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.readFloat64 = function(offset) {\n  flatbuffers.int32[flatbuffers.isLittleEndian ? 0 : 1] = this.readInt32(offset);\n  flatbuffers.int32[flatbuffers.isLittleEndian ? 1 : 0] = this.readInt32(offset + 4);\n  return flatbuffers.float64[0];\n};\n\n/**\n * @param {number} offset\n * @param {number|boolean} value\n */\nflatbuffers.ByteBuffer.prototype.writeInt8 = function(offset, value) {\n  this.bytes_[offset] = /** @type {number} */(value);\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeUint8 = function(offset, value) {\n  this.bytes_[offset] = value;\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeInt16 = function(offset, value) {\n  this.bytes_[offset] = value;\n  this.bytes_[offset + 1] = value >> 8;\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeUint16 = function(offset, value) {\n    this.bytes_[offset] = value;\n    this.bytes_[offset + 1] = value >> 8;\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeInt32 = function(offset, value) {\n  this.bytes_[offset] = value;\n  this.bytes_[offset + 1] = value >> 8;\n  this.bytes_[offset + 2] = value >> 16;\n  this.bytes_[offset + 3] = value >> 24;\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeUint32 = function(offset, value) {\n    this.bytes_[offset] = value;\n    this.bytes_[offset + 1] = value >> 8;\n    this.bytes_[offset + 2] = value >> 16;\n    this.bytes_[offset + 3] = value >> 24;\n};\n\n/**\n * @param {number} offset\n * @param {flatbuffers.Long} value\n */\nflatbuffers.ByteBuffer.prototype.writeInt64 = function(offset, value) {\n  this.writeInt32(offset, value.low);\n  this.writeInt32(offset + 4, value.high);\n};\n\n/**\n * @param {number} offset\n * @param {flatbuffers.Long} value\n */\nflatbuffers.ByteBuffer.prototype.writeUint64 = function(offset, value) {\n    this.writeUint32(offset, value.low);\n    this.writeUint32(offset + 4, value.high);\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeFloat32 = function(offset, value) {\n  flatbuffers.float32[0] = value;\n  this.writeInt32(offset, flatbuffers.int32[0]);\n};\n\n/**\n * @param {number} offset\n * @param {number} value\n */\nflatbuffers.ByteBuffer.prototype.writeFloat64 = function(offset, value) {\n  flatbuffers.float64[0] = value;\n  this.writeInt32(offset, flatbuffers.int32[flatbuffers.isLittleEndian ? 0 : 1]);\n  this.writeInt32(offset + 4, flatbuffers.int32[flatbuffers.isLittleEndian ? 1 : 0]);\n};\n\n/**\n * Return the file identifier.   Behavior is undefined for FlatBuffers whose\n * schema does not include a file_identifier (likely points at padding or the\n * start of a the root vtable).\n * @returns {string}\n */\nflatbuffers.ByteBuffer.prototype.getBufferIdentifier = function() {\n  if (this.bytes_.length < this.position_ + flatbuffers.SIZEOF_INT +\n      flatbuffers.FILE_IDENTIFIER_LENGTH) {\n    throw new Error(\n        'FlatBuffers: ByteBuffer is too short to contain an identifier.');\n  }\n  var result = \"\";\n  for (var i = 0; i < flatbuffers.FILE_IDENTIFIER_LENGTH; i++) {\n    result += String.fromCharCode(\n        this.readInt8(this.position_ + flatbuffers.SIZEOF_INT + i));\n  }\n  return result;\n};\n\n/**\n * Look up a field in the vtable, return an offset into the object, or 0 if the\n * field is not present.\n *\n * @param {number} bb_pos\n * @param {number} vtable_offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.__offset = function(bb_pos, vtable_offset) {\n  var vtable = bb_pos - this.readInt32(bb_pos);\n  return vtable_offset < this.readInt16(vtable) ? this.readInt16(vtable + vtable_offset) : 0;\n};\n\n/**\n * Initialize any Table-derived type to point to the union at the given offset.\n *\n * @param {flatbuffers.Table} t\n * @param {number} offset\n * @returns {flatbuffers.Table}\n */\nflatbuffers.ByteBuffer.prototype.__union = function(t, offset) {\n  t.bb_pos = offset + this.readInt32(offset);\n  t.bb = this;\n  return t;\n};\n\n/**\n * Create a JavaScript string from UTF-8 data stored inside the FlatBuffer.\n * This allocates a new string and converts to wide chars upon each access.\n *\n * To avoid the conversion to UTF-16, pass flatbuffers.Encoding.UTF8_BYTES as\n * the \"optionalEncoding\" argument. This is useful for avoiding conversion to\n * and from UTF-16 when the data will just be packaged back up in another\n * FlatBuffer later on.\n *\n * @param {number} offset\n * @param {flatbuffers.Encoding=} opt_encoding Defaults to UTF16_STRING\n * @returns {string|Uint8Array}\n */\nflatbuffers.ByteBuffer.prototype.__string = function(offset, opt_encoding) {\n  offset += this.readInt32(offset);\n\n  var length = this.readInt32(offset);\n  var result = '';\n  var i = 0;\n\n  offset += flatbuffers.SIZEOF_INT;\n\n  if (opt_encoding === flatbuffers.Encoding.UTF8_BYTES) {\n    return this.bytes_.subarray(offset, offset + length);\n  }\n\n  while (i < length) {\n    var codePoint;\n\n    // Decode UTF-8\n    var a = this.readUint8(offset + i++);\n    if (a < 0xC0) {\n      codePoint = a;\n    } else {\n      var b = this.readUint8(offset + i++);\n      if (a < 0xE0) {\n        codePoint =\n          ((a & 0x1F) << 6) |\n          (b & 0x3F);\n      } else {\n        var c = this.readUint8(offset + i++);\n        if (a < 0xF0) {\n          codePoint =\n            ((a & 0x0F) << 12) |\n            ((b & 0x3F) << 6) |\n            (c & 0x3F);\n        } else {\n          var d = this.readUint8(offset + i++);\n          codePoint =\n            ((a & 0x07) << 18) |\n            ((b & 0x3F) << 12) |\n            ((c & 0x3F) << 6) |\n            (d & 0x3F);\n        }\n      }\n    }\n\n    // Encode UTF-16\n    if (codePoint < 0x10000) {\n      result += String.fromCharCode(codePoint);\n    } else {\n      codePoint -= 0x10000;\n      result += String.fromCharCode(\n        (codePoint >> 10) + 0xD800,\n        (codePoint & ((1 << 10) - 1)) + 0xDC00);\n    }\n  }\n\n  return result;\n};\n\n/**\n * Retrieve the relative offset stored at \"offset\"\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.__indirect = function(offset) {\n  return offset + this.readInt32(offset);\n};\n\n/**\n * Get the start of data of a vector whose offset is stored at \"offset\" in this object.\n *\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.__vector = function(offset) {\n  return offset + this.readInt32(offset) + flatbuffers.SIZEOF_INT; // data starts after the length\n};\n\n/**\n * Get the length of a vector whose offset is stored at \"offset\" in this object.\n *\n * @param {number} offset\n * @returns {number}\n */\nflatbuffers.ByteBuffer.prototype.__vector_len = function(offset) {\n  return this.readInt32(offset + this.readInt32(offset));\n};\n\n/**\n * @param {string} ident\n * @returns {boolean}\n */\nflatbuffers.ByteBuffer.prototype.__has_identifier = function(ident) {\n  if (ident.length != flatbuffers.FILE_IDENTIFIER_LENGTH) {\n    throw new Error('FlatBuffers: file identifier must be length ' +\n                    flatbuffers.FILE_IDENTIFIER_LENGTH);\n  }\n  for (var i = 0; i < flatbuffers.FILE_IDENTIFIER_LENGTH; i++) {\n    if (ident.charCodeAt(i) != this.readInt8(this.position_ + flatbuffers.SIZEOF_INT + i)) {\n      return false;\n    }\n  }\n  return true;\n};\n\n/**\n * A helper function to avoid generated code depending on this file directly.\n *\n * @param {number} low\n * @param {number} high\n * @returns {flatbuffers.Long}\n */\nflatbuffers.ByteBuffer.prototype.createLong = function(low, high) {\n  return flatbuffers.Long.create(low, high);\n};\n\n// Exports for Node.js and RequireJS\n\n\n/// @endcond\n/// @}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/flatbuffers/js/flatbuffers.mjs?");

/***/ }),

/***/ "../../node_modules/internmap/src/index.js":
/*!*************************************************!*\
  !*** ../../node_modules/internmap/src/index.js ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   InternMap: () => (/* binding */ InternMap),\n/* harmony export */   InternSet: () => (/* binding */ InternSet)\n/* harmony export */ });\nclass InternMap extends Map {\n  constructor(entries, key = keyof) {\n    super();\n    Object.defineProperties(this, {_intern: {value: new Map()}, _key: {value: key}});\n    if (entries != null) for (const [key, value] of entries) this.set(key, value);\n  }\n  get(key) {\n    return super.get(intern_get(this, key));\n  }\n  has(key) {\n    return super.has(intern_get(this, key));\n  }\n  set(key, value) {\n    return super.set(intern_set(this, key), value);\n  }\n  delete(key) {\n    return super.delete(intern_delete(this, key));\n  }\n}\n\nclass InternSet extends Set {\n  constructor(values, key = keyof) {\n    super();\n    Object.defineProperties(this, {_intern: {value: new Map()}, _key: {value: key}});\n    if (values != null) for (const value of values) this.add(value);\n  }\n  has(value) {\n    return super.has(intern_get(this, value));\n  }\n  add(value) {\n    return super.add(intern_set(this, value));\n  }\n  delete(value) {\n    return super.delete(intern_delete(this, value));\n  }\n}\n\nfunction intern_get({_intern, _key}, value) {\n  const key = _key(value);\n  return _intern.has(key) ? _intern.get(key) : value;\n}\n\nfunction intern_set({_intern, _key}, value) {\n  const key = _key(value);\n  if (_intern.has(key)) return _intern.get(key);\n  _intern.set(key, value);\n  return value;\n}\n\nfunction intern_delete({_intern, _key}, value) {\n  const key = _key(value);\n  if (_intern.has(key)) {\n    value = _intern.get(key);\n    _intern.delete(key);\n  }\n  return value;\n}\n\nfunction keyof(value) {\n  return value !== null && typeof value === \"object\" ? value.valueOf() : value;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/internmap/src/index.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/esm/incircle.js":
/*!************************************************************!*\
  !*** ../../node_modules/robust-predicates/esm/incircle.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   incircle: () => (/* binding */ incircle),\n/* harmony export */   incirclefast: () => (/* binding */ incirclefast)\n/* harmony export */ });\n/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util.js */ \"../../node_modules/robust-predicates/esm/util.js\");\n\n\nconst iccerrboundA = (10 + 96 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst iccerrboundB = (4 + 48 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst iccerrboundC = (44 + 576 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\nconst bc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ca = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst aa = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bb = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst cc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst u = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst v = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst axtbc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst aytbc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst bxtca = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst bytca = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst cxtab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst cytab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst abt = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst bct = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst cat = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst abtt = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bctt = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst catt = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\n\nconst _8 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _16 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(16);\nconst _16b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(16);\nconst _16c = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(16);\nconst _32 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(32);\nconst _32b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(32);\nconst _48 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(48);\nconst _64 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(64);\n\nlet fin = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nlet fin2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\n\nfunction finadd(finlen, a, alen) {\n    finlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(finlen, fin, a, alen, fin2);\n    const tmp = fin; fin = fin2; fin2 = tmp;\n    return finlen;\n}\n\nfunction incircleadapt(ax, ay, bx, by, cx, cy, dx, dy, permanent) {\n    let finlen;\n    let adxtail, bdxtail, cdxtail, adytail, bdytail, cdytail;\n    let axtbclen, aytbclen, bxtcalen, bytcalen, cxtablen, cytablen;\n    let abtlen, bctlen, catlen;\n    let abttlen, bcttlen, cattlen;\n    let n1, n0;\n\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _0, s1, s0, t1, t0, u3;\n\n    const adx = ax - dx;\n    const bdx = bx - dx;\n    const cdx = cx - dx;\n    const ady = ay - dy;\n    const bdy = by - dy;\n    const cdy = cy - dy;\n\n    s1 = bdx * cdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n    ahi = c - (c - bdx);\n    alo = bdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n    bhi = c - (c - cdy);\n    blo = cdy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cdx * bdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n    ahi = c - (c - cdx);\n    alo = cdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n    bhi = c - (c - bdy);\n    blo = bdy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bc[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bc[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    bc[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    bc[3] = u3;\n    s1 = cdx * ady;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n    ahi = c - (c - cdx);\n    alo = cdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n    bhi = c - (c - ady);\n    blo = ady - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = adx * cdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n    ahi = c - (c - adx);\n    alo = adx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n    bhi = c - (c - cdy);\n    blo = cdy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ca[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ca[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ca[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ca[3] = u3;\n    s1 = adx * bdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n    ahi = c - (c - adx);\n    alo = adx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n    bhi = c - (c - bdy);\n    blo = bdy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = bdx * ady;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n    ahi = c - (c - bdx);\n    alo = bdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n    bhi = c - (c - ady);\n    blo = ady - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ab[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ab[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ab[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ab[3] = u3;\n\n    finlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, adx, _8), _8, adx, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, ady, _8), _8, ady, _16b), _16b, _32), _32,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdx, _8), _8, bdx, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdy, _8), _8, bdy, _16b), _16b, _32b), _32b, _64), _64,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdx, _8), _8, cdx, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdy, _8), _8, cdy, _16b), _16b, _32), _32, fin);\n\n    let det = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.estimate)(finlen, fin);\n    let errbound = iccerrboundB * permanent;\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    bvirt = ax - adx;\n    adxtail = ax - (adx + bvirt) + (bvirt - dx);\n    bvirt = ay - ady;\n    adytail = ay - (ady + bvirt) + (bvirt - dy);\n    bvirt = bx - bdx;\n    bdxtail = bx - (bdx + bvirt) + (bvirt - dx);\n    bvirt = by - bdy;\n    bdytail = by - (bdy + bvirt) + (bvirt - dy);\n    bvirt = cx - cdx;\n    cdxtail = cx - (cdx + bvirt) + (bvirt - dx);\n    bvirt = cy - cdy;\n    cdytail = cy - (cdy + bvirt) + (bvirt - dy);\n    if (adxtail === 0 && bdxtail === 0 && cdxtail === 0 && adytail === 0 && bdytail === 0 && cdytail === 0) {\n        return det;\n    }\n\n    errbound = iccerrboundC * permanent + _util_js__WEBPACK_IMPORTED_MODULE_0__.resulterrbound * Math.abs(det);\n    det += ((adx * adx + ady * ady) * ((bdx * cdytail + cdy * bdxtail) - (bdy * cdxtail + cdx * bdytail)) +\n        2 * (adx * adxtail + ady * adytail) * (bdx * cdy - bdy * cdx)) +\n        ((bdx * bdx + bdy * bdy) * ((cdx * adytail + ady * cdxtail) - (cdy * adxtail + adx * cdytail)) +\n        2 * (bdx * bdxtail + bdy * bdytail) * (cdx * ady - cdy * adx)) +\n        ((cdx * cdx + cdy * cdy) * ((adx * bdytail + bdy * adxtail) - (ady * bdxtail + bdx * adytail)) +\n        2 * (cdx * cdxtail + cdy * cdytail) * (adx * bdy - ady * bdx));\n\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    if (bdxtail !== 0 || bdytail !== 0 || cdxtail !== 0 || cdytail !== 0) {\n        s1 = adx * adx;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n        ahi = c - (c - adx);\n        alo = adx - ahi;\n        s0 = alo * alo - (s1 - ahi * ahi - (ahi + ahi) * alo);\n        t1 = ady * ady;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n        ahi = c - (c - ady);\n        alo = ady - ahi;\n        t0 = alo * alo - (t1 - ahi * ahi - (ahi + ahi) * alo);\n        _i = s0 + t0;\n        bvirt = _i - s0;\n        aa[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n        _j = s1 + _i;\n        bvirt = _j - s1;\n        _0 = s1 - (_j - bvirt) + (_i - bvirt);\n        _i = _0 + t1;\n        bvirt = _i - _0;\n        aa[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n        u3 = _j + _i;\n        bvirt = u3 - _j;\n        aa[2] = _j - (u3 - bvirt) + (_i - bvirt);\n        aa[3] = u3;\n    }\n    if (cdxtail !== 0 || cdytail !== 0 || adxtail !== 0 || adytail !== 0) {\n        s1 = bdx * bdx;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n        ahi = c - (c - bdx);\n        alo = bdx - ahi;\n        s0 = alo * alo - (s1 - ahi * ahi - (ahi + ahi) * alo);\n        t1 = bdy * bdy;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n        ahi = c - (c - bdy);\n        alo = bdy - ahi;\n        t0 = alo * alo - (t1 - ahi * ahi - (ahi + ahi) * alo);\n        _i = s0 + t0;\n        bvirt = _i - s0;\n        bb[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n        _j = s1 + _i;\n        bvirt = _j - s1;\n        _0 = s1 - (_j - bvirt) + (_i - bvirt);\n        _i = _0 + t1;\n        bvirt = _i - _0;\n        bb[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n        u3 = _j + _i;\n        bvirt = u3 - _j;\n        bb[2] = _j - (u3 - bvirt) + (_i - bvirt);\n        bb[3] = u3;\n    }\n    if (adxtail !== 0 || adytail !== 0 || bdxtail !== 0 || bdytail !== 0) {\n        s1 = cdx * cdx;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n        ahi = c - (c - cdx);\n        alo = cdx - ahi;\n        s0 = alo * alo - (s1 - ahi * ahi - (ahi + ahi) * alo);\n        t1 = cdy * cdy;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n        ahi = c - (c - cdy);\n        alo = cdy - ahi;\n        t0 = alo * alo - (t1 - ahi * ahi - (ahi + ahi) * alo);\n        _i = s0 + t0;\n        bvirt = _i - s0;\n        cc[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n        _j = s1 + _i;\n        bvirt = _j - s1;\n        _0 = s1 - (_j - bvirt) + (_i - bvirt);\n        _i = _0 + t1;\n        bvirt = _i - _0;\n        cc[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n        u3 = _j + _i;\n        bvirt = u3 - _j;\n        cc[2] = _j - (u3 - bvirt) + (_i - bvirt);\n        cc[3] = u3;\n    }\n\n    if (adxtail !== 0) {\n        axtbclen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, adxtail, axtbc);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(axtbclen, axtbc, 2 * adx, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, adxtail, _8), _8, bdy, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, adxtail, _8), _8, -cdy, _16c), _16c, _32, _48), _48);\n    }\n    if (adytail !== 0) {\n        aytbclen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, adytail, aytbc);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(aytbclen, aytbc, 2 * ady, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, adytail, _8), _8, cdx, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, adytail, _8), _8, -bdx, _16c), _16c, _32, _48), _48);\n    }\n    if (bdxtail !== 0) {\n        bxtcalen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdxtail, bxtca);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bxtcalen, bxtca, 2 * bdx, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, bdxtail, _8), _8, cdy, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, bdxtail, _8), _8, -ady, _16c), _16c, _32, _48), _48);\n    }\n    if (bdytail !== 0) {\n        bytcalen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdytail, bytca);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bytcalen, bytca, 2 * bdy, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, bdytail, _8), _8, adx, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, bdytail, _8), _8, -cdx, _16c), _16c, _32, _48), _48);\n    }\n    if (cdxtail !== 0) {\n        cxtablen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdxtail, cxtab);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cxtablen, cxtab, 2 * cdx, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, cdxtail, _8), _8, ady, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, cdxtail, _8), _8, -bdy, _16c), _16c, _32, _48), _48);\n    }\n    if (cdytail !== 0) {\n        cytablen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdytail, cytab);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cytablen, cytab, 2 * cdy, _16), _16,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, cdytail, _8), _8, bdx, _16b), _16b,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, cdytail, _8), _8, -adx, _16c), _16c, _32, _48), _48);\n    }\n\n    if (adxtail !== 0 || adytail !== 0) {\n        if (bdxtail !== 0 || bdytail !== 0 || cdxtail !== 0 || cdytail !== 0) {\n            s1 = bdxtail * cdy;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdxtail;\n            ahi = c - (c - bdxtail);\n            alo = bdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n            bhi = c - (c - cdy);\n            blo = cdy - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = bdx * cdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n            ahi = c - (c - bdx);\n            alo = bdx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdytail;\n            bhi = c - (c - cdytail);\n            blo = cdytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            u[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            u[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            u[3] = u3;\n            s1 = cdxtail * -bdy;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdxtail;\n            ahi = c - (c - cdxtail);\n            alo = cdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * -bdy;\n            bhi = c - (c - -bdy);\n            blo = -bdy - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = cdx * -bdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n            ahi = c - (c - cdx);\n            alo = cdx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * -bdytail;\n            bhi = c - (c - -bdytail);\n            blo = -bdytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            v[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            v[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            v[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            v[3] = u3;\n            bctlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(4, u, 4, v, bct);\n            s1 = bdxtail * cdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdxtail;\n            ahi = c - (c - bdxtail);\n            alo = bdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdytail;\n            bhi = c - (c - cdytail);\n            blo = cdytail - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = cdxtail * bdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdxtail;\n            ahi = c - (c - cdxtail);\n            alo = cdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdytail;\n            bhi = c - (c - bdytail);\n            blo = bdytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 - t0;\n            bvirt = s0 - _i;\n            bctt[0] = s0 - (_i + bvirt) + (bvirt - t0);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 - t1;\n            bvirt = _0 - _i;\n            bctt[1] = _0 - (_i + bvirt) + (bvirt - t1);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            bctt[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            bctt[3] = u3;\n            bcttlen = 4;\n        } else {\n            bct[0] = 0;\n            bctlen = 1;\n            bctt[0] = 0;\n            bcttlen = 1;\n        }\n        if (adxtail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bctlen, bct, adxtail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(axtbclen, axtbc, adxtail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * adx, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bcttlen, bctt, adxtail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * adx, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, adxtail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, adxtail, _32), _32, _32b, _64), _64);\n\n            if (bdytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, adxtail, _8), _8, bdytail, _16), _16);\n            }\n            if (cdytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, -adxtail, _8), _8, cdytail, _16), _16);\n            }\n        }\n        if (adytail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bctlen, bct, adytail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(aytbclen, aytbc, adytail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * ady, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bcttlen, bctt, adytail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * ady, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, adytail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, adytail, _32), _32, _32b, _64), _64);\n        }\n    }\n    if (bdxtail !== 0 || bdytail !== 0) {\n        if (cdxtail !== 0 || cdytail !== 0 || adxtail !== 0 || adytail !== 0) {\n            s1 = cdxtail * ady;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdxtail;\n            ahi = c - (c - cdxtail);\n            alo = cdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n            bhi = c - (c - ady);\n            blo = ady - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = cdx * adytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n            ahi = c - (c - cdx);\n            alo = cdx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adytail;\n            bhi = c - (c - adytail);\n            blo = adytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            u[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            u[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            u[3] = u3;\n            n1 = -cdy;\n            n0 = -cdytail;\n            s1 = adxtail * n1;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adxtail;\n            ahi = c - (c - adxtail);\n            alo = adxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * n1;\n            bhi = c - (c - n1);\n            blo = n1 - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = adx * n0;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n            ahi = c - (c - adx);\n            alo = adx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * n0;\n            bhi = c - (c - n0);\n            blo = n0 - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            v[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            v[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            v[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            v[3] = u3;\n            catlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(4, u, 4, v, cat);\n            s1 = cdxtail * adytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdxtail;\n            ahi = c - (c - cdxtail);\n            alo = cdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adytail;\n            bhi = c - (c - adytail);\n            blo = adytail - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = adxtail * cdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adxtail;\n            ahi = c - (c - adxtail);\n            alo = adxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdytail;\n            bhi = c - (c - cdytail);\n            blo = cdytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 - t0;\n            bvirt = s0 - _i;\n            catt[0] = s0 - (_i + bvirt) + (bvirt - t0);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 - t1;\n            bvirt = _0 - _i;\n            catt[1] = _0 - (_i + bvirt) + (bvirt - t1);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            catt[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            catt[3] = u3;\n            cattlen = 4;\n        } else {\n            cat[0] = 0;\n            catlen = 1;\n            catt[0] = 0;\n            cattlen = 1;\n        }\n        if (bdxtail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(catlen, cat, bdxtail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bxtcalen, bxtca, bdxtail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * bdx, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cattlen, catt, bdxtail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * bdx, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, bdxtail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, bdxtail, _32), _32, _32b, _64), _64);\n\n            if (cdytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, bdxtail, _8), _8, cdytail, _16), _16);\n            }\n            if (adytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, cc, -bdxtail, _8), _8, adytail, _16), _16);\n            }\n        }\n        if (bdytail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(catlen, cat, bdytail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bytcalen, bytca, bdytail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * bdy, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cattlen, catt, bdytail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * bdy, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, bdytail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, bdytail, _32), _32,  _32b, _64), _64);\n        }\n    }\n    if (cdxtail !== 0 || cdytail !== 0) {\n        if (adxtail !== 0 || adytail !== 0 || bdxtail !== 0 || bdytail !== 0) {\n            s1 = adxtail * bdy;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adxtail;\n            ahi = c - (c - adxtail);\n            alo = adxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n            bhi = c - (c - bdy);\n            blo = bdy - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = adx * bdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n            ahi = c - (c - adx);\n            alo = adx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdytail;\n            bhi = c - (c - bdytail);\n            blo = bdytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            u[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            u[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            u[3] = u3;\n            n1 = -ady;\n            n0 = -adytail;\n            s1 = bdxtail * n1;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdxtail;\n            ahi = c - (c - bdxtail);\n            alo = bdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * n1;\n            bhi = c - (c - n1);\n            blo = n1 - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = bdx * n0;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n            ahi = c - (c - bdx);\n            alo = bdx - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * n0;\n            bhi = c - (c - n0);\n            blo = n0 - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 + t0;\n            bvirt = _i - s0;\n            v[0] = s0 - (_i - bvirt) + (t0 - bvirt);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 + t1;\n            bvirt = _i - _0;\n            v[1] = _0 - (_i - bvirt) + (t1 - bvirt);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            v[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            v[3] = u3;\n            abtlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(4, u, 4, v, abt);\n            s1 = adxtail * bdytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adxtail;\n            ahi = c - (c - adxtail);\n            alo = adxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdytail;\n            bhi = c - (c - bdytail);\n            blo = bdytail - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = bdxtail * adytail;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdxtail;\n            ahi = c - (c - bdxtail);\n            alo = bdxtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adytail;\n            bhi = c - (c - adytail);\n            blo = adytail - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 - t0;\n            bvirt = s0 - _i;\n            abtt[0] = s0 - (_i + bvirt) + (bvirt - t0);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 - t1;\n            bvirt = _0 - _i;\n            abtt[1] = _0 - (_i + bvirt) + (bvirt - t1);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            abtt[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            abtt[3] = u3;\n            abttlen = 4;\n        } else {\n            abt[0] = 0;\n            abtlen = 1;\n            abtt[0] = 0;\n            abttlen = 1;\n        }\n        if (cdxtail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abtlen, abt, cdxtail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cxtablen, cxtab, cdxtail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * cdx, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abttlen, abtt, cdxtail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * cdx, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, cdxtail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, cdxtail, _32), _32, _32b, _64), _64);\n\n            if (adytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bb, cdxtail, _8), _8, adytail, _16), _16);\n            }\n            if (bdytail !== 0) {\n                finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, aa, -cdxtail, _8), _8, bdytail, _16), _16);\n            }\n        }\n        if (cdytail !== 0) {\n            const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abtlen, abt, cdytail, _16c);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(cytablen, cytab, cdytail, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, 2 * cdy, _32), _32, _48), _48);\n\n            const len2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abttlen, abtt, cdytail, _8);\n            finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, 2 * cdy, _16), _16,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len2, _8, cdytail, _16b), _16b,\n                (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _16c, cdytail, _32), _32, _32b, _64), _64);\n        }\n    }\n\n    return fin[finlen - 1];\n}\n\nfunction incircle(ax, ay, bx, by, cx, cy, dx, dy) {\n    const adx = ax - dx;\n    const bdx = bx - dx;\n    const cdx = cx - dx;\n    const ady = ay - dy;\n    const bdy = by - dy;\n    const cdy = cy - dy;\n\n    const bdxcdy = bdx * cdy;\n    const cdxbdy = cdx * bdy;\n    const alift = adx * adx + ady * ady;\n\n    const cdxady = cdx * ady;\n    const adxcdy = adx * cdy;\n    const blift = bdx * bdx + bdy * bdy;\n\n    const adxbdy = adx * bdy;\n    const bdxady = bdx * ady;\n    const clift = cdx * cdx + cdy * cdy;\n\n    const det =\n        alift * (bdxcdy - cdxbdy) +\n        blift * (cdxady - adxcdy) +\n        clift * (adxbdy - bdxady);\n\n    const permanent =\n        (Math.abs(bdxcdy) + Math.abs(cdxbdy)) * alift +\n        (Math.abs(cdxady) + Math.abs(adxcdy)) * blift +\n        (Math.abs(adxbdy) + Math.abs(bdxady)) * clift;\n\n    const errbound = iccerrboundA * permanent;\n\n    if (det > errbound || -det > errbound) {\n        return det;\n    }\n    return incircleadapt(ax, ay, bx, by, cx, cy, dx, dy, permanent);\n}\n\nfunction incirclefast(ax, ay, bx, by, cx, cy, dx, dy) {\n    const adx = ax - dx;\n    const ady = ay - dy;\n    const bdx = bx - dx;\n    const bdy = by - dy;\n    const cdx = cx - dx;\n    const cdy = cy - dy;\n\n    const abdet = adx * bdy - bdx * ady;\n    const bcdet = bdx * cdy - cdx * bdy;\n    const cadet = cdx * ady - adx * cdy;\n    const alift = adx * adx + ady * ady;\n    const blift = bdx * bdx + bdy * bdy;\n    const clift = cdx * cdx + cdy * cdy;\n\n    return alift * bcdet + blift * cadet + clift * abdet;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/esm/incircle.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/esm/insphere.js":
/*!************************************************************!*\
  !*** ../../node_modules/robust-predicates/esm/insphere.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   insphere: () => (/* binding */ insphere),\n/* harmony export */   inspherefast: () => (/* binding */ inspherefast)\n/* harmony export */ });\n/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util.js */ \"../../node_modules/robust-predicates/esm/util.js\");\n\n\nconst isperrboundA = (16 + 224 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst isperrboundB = (5 + 72 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst isperrboundC = (71 + 1408 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\nconst ab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst cd = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst de = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ea = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ac = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bd = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ce = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst da = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst eb = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\n\nconst abc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst bcd = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst cde = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst dea = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst eab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst abd = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst bce = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst cda = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst deb = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst eac = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\n\nconst adet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nconst bdet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nconst cdet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nconst ddet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nconst edet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\nconst abdet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(2304);\nconst cddet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(2304);\nconst cdedet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(3456);\nconst deter = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(5760);\n\nconst _8 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _8b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _8c = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _16 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(16);\nconst _24 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(24);\nconst _48 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(48);\nconst _48b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(48);\nconst _96 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(96);\nconst _192 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(192);\nconst _384x = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(384);\nconst _384y = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(384);\nconst _384z = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(384);\nconst _768 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(768);\n\nfunction sum_three_scale(a, b, c, az, bz, cz, out) {\n    return (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, a, az, _8), _8,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, b, bz, _8b), _8b,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, c, cz, _8c), _8c, _16, out);\n}\n\nfunction liftexact(alen, a, blen, b, clen, c, dlen, d, x, y, z, out) {\n    const len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(alen, a, blen, b, _48), _48,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.negate)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(clen, c, dlen, d, _48b), _48b), _48b, _96);\n\n    return (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _96, x, _192), _192, x, _384x), _384x,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _96, y, _192), _192, y, _384y), _384y,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _96, z, _192), _192, z, _384z), _384z, _768, out);\n}\n\nfunction insphereexact(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, ex, ey, ez) {\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _0, s1, s0, t1, t0, u3;\n\n    s1 = ax * by;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n    ahi = c - (c - ax);\n    alo = ax - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n    bhi = c - (c - by);\n    blo = by - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = bx * ay;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n    ahi = c - (c - bx);\n    alo = bx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n    bhi = c - (c - ay);\n    blo = ay - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ab[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ab[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ab[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ab[3] = u3;\n    s1 = bx * cy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n    ahi = c - (c - bx);\n    alo = bx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cy;\n    bhi = c - (c - cy);\n    blo = cy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cx * by;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cx;\n    ahi = c - (c - cx);\n    alo = cx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n    bhi = c - (c - by);\n    blo = by - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bc[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bc[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    bc[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    bc[3] = u3;\n    s1 = cx * dy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cx;\n    ahi = c - (c - cx);\n    alo = cx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dy;\n    bhi = c - (c - dy);\n    blo = dy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = dx * cy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dx;\n    ahi = c - (c - dx);\n    alo = dx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cy;\n    bhi = c - (c - cy);\n    blo = cy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    cd[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    cd[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    cd[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    cd[3] = u3;\n    s1 = dx * ey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dx;\n    ahi = c - (c - dx);\n    alo = dx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ey;\n    bhi = c - (c - ey);\n    blo = ey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = ex * dy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ex;\n    ahi = c - (c - ex);\n    alo = ex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dy;\n    bhi = c - (c - dy);\n    blo = dy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    de[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    de[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    de[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    de[3] = u3;\n    s1 = ex * ay;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ex;\n    ahi = c - (c - ex);\n    alo = ex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n    bhi = c - (c - ay);\n    blo = ay - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = ax * ey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n    ahi = c - (c - ax);\n    alo = ax - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ey;\n    bhi = c - (c - ey);\n    blo = ey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ea[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ea[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ea[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ea[3] = u3;\n    s1 = ax * cy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n    ahi = c - (c - ax);\n    alo = ax - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cy;\n    bhi = c - (c - cy);\n    blo = cy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cx * ay;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cx;\n    ahi = c - (c - cx);\n    alo = cx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n    bhi = c - (c - ay);\n    blo = ay - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ac[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ac[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ac[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ac[3] = u3;\n    s1 = bx * dy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n    ahi = c - (c - bx);\n    alo = bx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dy;\n    bhi = c - (c - dy);\n    blo = dy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = dx * by;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dx;\n    ahi = c - (c - dx);\n    alo = dx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n    bhi = c - (c - by);\n    blo = by - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bd[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bd[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    bd[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    bd[3] = u3;\n    s1 = cx * ey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cx;\n    ahi = c - (c - cx);\n    alo = cx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ey;\n    bhi = c - (c - ey);\n    blo = ey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = ex * cy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ex;\n    ahi = c - (c - ex);\n    alo = ex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cy;\n    bhi = c - (c - cy);\n    blo = cy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ce[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ce[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ce[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ce[3] = u3;\n    s1 = dx * ay;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dx;\n    ahi = c - (c - dx);\n    alo = dx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n    bhi = c - (c - ay);\n    blo = ay - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = ax * dy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n    ahi = c - (c - ax);\n    alo = ax - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dy;\n    bhi = c - (c - dy);\n    blo = dy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    da[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    da[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    da[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    da[3] = u3;\n    s1 = ex * by;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ex;\n    ahi = c - (c - ex);\n    alo = ex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n    bhi = c - (c - by);\n    blo = by - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = bx * ey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n    ahi = c - (c - bx);\n    alo = bx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ey;\n    bhi = c - (c - ey);\n    blo = ey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    eb[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    eb[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    eb[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    eb[3] = u3;\n\n    const abclen = sum_three_scale(ab, bc, ac, cz, az, -bz, abc);\n    const bcdlen = sum_three_scale(bc, cd, bd, dz, bz, -cz, bcd);\n    const cdelen = sum_three_scale(cd, de, ce, ez, cz, -dz, cde);\n    const dealen = sum_three_scale(de, ea, da, az, dz, -ez, dea);\n    const eablen = sum_three_scale(ea, ab, eb, bz, ez, -az, eab);\n    const abdlen = sum_three_scale(ab, bd, da, dz, az, bz, abd);\n    const bcelen = sum_three_scale(bc, ce, eb, ez, bz, cz, bce);\n    const cdalen = sum_three_scale(cd, da, ac, az, cz, dz, cda);\n    const deblen = sum_three_scale(de, eb, bd, bz, dz, ez, deb);\n    const eaclen = sum_three_scale(ea, ac, ce, cz, ez, az, eac);\n\n    const deterlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n        liftexact(cdelen, cde, bcelen, bce, deblen, deb, bcdlen, bcd, ax, ay, az, adet), adet,\n        liftexact(dealen, dea, cdalen, cda, eaclen, eac, cdelen, cde, bx, by, bz, bdet), bdet,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n            liftexact(eablen, eab, deblen, deb, abdlen, abd, dealen, dea, cx, cy, cz, cdet), cdet,\n            liftexact(abclen, abc, eaclen, eac, bcelen, bce, eablen, eab, dx, dy, dz, ddet), ddet,\n            liftexact(bcdlen, bcd, abdlen, abd, cdalen, cda, abclen, abc, ex, ey, ez, edet), edet, cddet, cdedet), cdedet, abdet, deter);\n\n    return deter[deterlen - 1];\n}\n\nconst xdet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(96);\nconst ydet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(96);\nconst zdet = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(96);\nconst fin = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(1152);\n\nfunction liftadapt(a, b, c, az, bz, cz, x, y, z, out) {\n    const len = sum_three_scale(a, b, c, az, bz, cz, _24);\n    return (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum_three)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _24, x, _48), _48, x, xdet), xdet,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _24, y, _48), _48, y, ydet), ydet,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)((0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(len, _24, z, _48), _48, z, zdet), zdet, _192, out);\n}\n\nfunction insphereadapt(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, ex, ey, ez, permanent) {\n    let ab3, bc3, cd3, da3, ac3, bd3;\n\n    let aextail, bextail, cextail, dextail;\n    let aeytail, beytail, ceytail, deytail;\n    let aeztail, beztail, ceztail, deztail;\n\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _0, s1, s0, t1, t0;\n\n    const aex = ax - ex;\n    const bex = bx - ex;\n    const cex = cx - ex;\n    const dex = dx - ex;\n    const aey = ay - ey;\n    const bey = by - ey;\n    const cey = cy - ey;\n    const dey = dy - ey;\n    const aez = az - ez;\n    const bez = bz - ez;\n    const cez = cz - ez;\n    const dez = dz - ez;\n\n    s1 = aex * bey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aex;\n    ahi = c - (c - aex);\n    alo = aex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bey;\n    bhi = c - (c - bey);\n    blo = bey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = bex * aey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bex;\n    ahi = c - (c - bex);\n    alo = bex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aey;\n    bhi = c - (c - aey);\n    blo = aey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ab[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ab[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    ab3 = _j + _i;\n    bvirt = ab3 - _j;\n    ab[2] = _j - (ab3 - bvirt) + (_i - bvirt);\n    ab[3] = ab3;\n    s1 = bex * cey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bex;\n    ahi = c - (c - bex);\n    alo = bex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cey;\n    bhi = c - (c - cey);\n    blo = cey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cex * bey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cex;\n    ahi = c - (c - cex);\n    alo = cex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bey;\n    bhi = c - (c - bey);\n    blo = bey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bc[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bc[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    bc3 = _j + _i;\n    bvirt = bc3 - _j;\n    bc[2] = _j - (bc3 - bvirt) + (_i - bvirt);\n    bc[3] = bc3;\n    s1 = cex * dey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cex;\n    ahi = c - (c - cex);\n    alo = cex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dey;\n    bhi = c - (c - dey);\n    blo = dey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = dex * cey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dex;\n    ahi = c - (c - dex);\n    alo = dex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cey;\n    bhi = c - (c - cey);\n    blo = cey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    cd[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    cd[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    cd3 = _j + _i;\n    bvirt = cd3 - _j;\n    cd[2] = _j - (cd3 - bvirt) + (_i - bvirt);\n    cd[3] = cd3;\n    s1 = dex * aey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dex;\n    ahi = c - (c - dex);\n    alo = dex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aey;\n    bhi = c - (c - aey);\n    blo = aey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = aex * dey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aex;\n    ahi = c - (c - aex);\n    alo = aex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dey;\n    bhi = c - (c - dey);\n    blo = dey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    da[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    da[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    da3 = _j + _i;\n    bvirt = da3 - _j;\n    da[2] = _j - (da3 - bvirt) + (_i - bvirt);\n    da[3] = da3;\n    s1 = aex * cey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aex;\n    ahi = c - (c - aex);\n    alo = aex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cey;\n    bhi = c - (c - cey);\n    blo = cey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cex * aey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cex;\n    ahi = c - (c - cex);\n    alo = cex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * aey;\n    bhi = c - (c - aey);\n    blo = aey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ac[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ac[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    ac3 = _j + _i;\n    bvirt = ac3 - _j;\n    ac[2] = _j - (ac3 - bvirt) + (_i - bvirt);\n    ac[3] = ac3;\n    s1 = bex * dey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bex;\n    ahi = c - (c - bex);\n    alo = bex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dey;\n    bhi = c - (c - dey);\n    blo = dey - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = dex * bey;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * dex;\n    ahi = c - (c - dex);\n    alo = dex - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bey;\n    bhi = c - (c - bey);\n    blo = bey - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bd[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bd[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    bd3 = _j + _i;\n    bvirt = bd3 - _j;\n    bd[2] = _j - (bd3 - bvirt) + (_i - bvirt);\n    bd[3] = bd3;\n\n    const finlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.negate)(liftadapt(bc, cd, bd, dez, bez, -cez, aex, aey, aez, adet), adet), adet,\n            liftadapt(cd, da, ac, aez, cez, dez, bex, bey, bez, bdet), bdet, abdet), abdet,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.negate)(liftadapt(da, ab, bd, bez, dez, aez, cex, cey, cez, cdet), cdet), cdet,\n            liftadapt(ab, bc, ac, cez, aez, -bez, dex, dey, dez, ddet), ddet, cddet), cddet, fin);\n\n    let det = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.estimate)(finlen, fin);\n    let errbound = isperrboundB * permanent;\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    bvirt = ax - aex;\n    aextail = ax - (aex + bvirt) + (bvirt - ex);\n    bvirt = ay - aey;\n    aeytail = ay - (aey + bvirt) + (bvirt - ey);\n    bvirt = az - aez;\n    aeztail = az - (aez + bvirt) + (bvirt - ez);\n    bvirt = bx - bex;\n    bextail = bx - (bex + bvirt) + (bvirt - ex);\n    bvirt = by - bey;\n    beytail = by - (bey + bvirt) + (bvirt - ey);\n    bvirt = bz - bez;\n    beztail = bz - (bez + bvirt) + (bvirt - ez);\n    bvirt = cx - cex;\n    cextail = cx - (cex + bvirt) + (bvirt - ex);\n    bvirt = cy - cey;\n    ceytail = cy - (cey + bvirt) + (bvirt - ey);\n    bvirt = cz - cez;\n    ceztail = cz - (cez + bvirt) + (bvirt - ez);\n    bvirt = dx - dex;\n    dextail = dx - (dex + bvirt) + (bvirt - ex);\n    bvirt = dy - dey;\n    deytail = dy - (dey + bvirt) + (bvirt - ey);\n    bvirt = dz - dez;\n    deztail = dz - (dez + bvirt) + (bvirt - ez);\n    if (aextail === 0 && aeytail === 0 && aeztail === 0 &&\n        bextail === 0 && beytail === 0 && beztail === 0 &&\n        cextail === 0 && ceytail === 0 && ceztail === 0 &&\n        dextail === 0 && deytail === 0 && deztail === 0) {\n        return det;\n    }\n\n    errbound = isperrboundC * permanent + _util_js__WEBPACK_IMPORTED_MODULE_0__.resulterrbound * Math.abs(det);\n\n    const abeps = (aex * beytail + bey * aextail) - (aey * bextail + bex * aeytail);\n    const bceps = (bex * ceytail + cey * bextail) - (bey * cextail + cex * beytail);\n    const cdeps = (cex * deytail + dey * cextail) - (cey * dextail + dex * ceytail);\n    const daeps = (dex * aeytail + aey * dextail) - (dey * aextail + aex * deytail);\n    const aceps = (aex * ceytail + cey * aextail) - (aey * cextail + cex * aeytail);\n    const bdeps = (bex * deytail + dey * bextail) - (bey * dextail + dex * beytail);\n    det +=\n        (((bex * bex + bey * bey + bez * bez) * ((cez * daeps + dez * aceps + aez * cdeps) +\n        (ceztail * da3 + deztail * ac3 + aeztail * cd3)) + (dex * dex + dey * dey + dez * dez) *\n        ((aez * bceps - bez * aceps + cez * abeps) + (aeztail * bc3 - beztail * ac3 + ceztail * ab3))) -\n        ((aex * aex + aey * aey + aez * aez) * ((bez * cdeps - cez * bdeps + dez * bceps) +\n        (beztail * cd3 - ceztail * bd3 + deztail * bc3)) + (cex * cex + cey * cey + cez * cez) *\n        ((dez * abeps + aez * bdeps + bez * daeps) + (deztail * ab3 + aeztail * bd3 + beztail * da3)))) +\n        2 * (((bex * bextail + bey * beytail + bez * beztail) * (cez * da3 + dez * ac3 + aez * cd3) +\n        (dex * dextail + dey * deytail + dez * deztail) * (aez * bc3 - bez * ac3 + cez * ab3)) -\n        ((aex * aextail + aey * aeytail + aez * aeztail) * (bez * cd3 - cez * bd3 + dez * bc3) +\n        (cex * cextail + cey * ceytail + cez * ceztail) * (dez * ab3 + aez * bd3 + bez * da3)));\n\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    return insphereexact(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, ex, ey, ez);\n}\n\nfunction insphere(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, ex, ey, ez) {\n    const aex = ax - ex;\n    const bex = bx - ex;\n    const cex = cx - ex;\n    const dex = dx - ex;\n    const aey = ay - ey;\n    const bey = by - ey;\n    const cey = cy - ey;\n    const dey = dy - ey;\n    const aez = az - ez;\n    const bez = bz - ez;\n    const cez = cz - ez;\n    const dez = dz - ez;\n\n    const aexbey = aex * bey;\n    const bexaey = bex * aey;\n    const ab = aexbey - bexaey;\n    const bexcey = bex * cey;\n    const cexbey = cex * bey;\n    const bc = bexcey - cexbey;\n    const cexdey = cex * dey;\n    const dexcey = dex * cey;\n    const cd = cexdey - dexcey;\n    const dexaey = dex * aey;\n    const aexdey = aex * dey;\n    const da = dexaey - aexdey;\n    const aexcey = aex * cey;\n    const cexaey = cex * aey;\n    const ac = aexcey - cexaey;\n    const bexdey = bex * dey;\n    const dexbey = dex * bey;\n    const bd = bexdey - dexbey;\n\n    const alift = aex * aex + aey * aey + aez * aez;\n    const blift = bex * bex + bey * bey + bez * bez;\n    const clift = cex * cex + cey * cey + cez * cez;\n    const dlift = dex * dex + dey * dey + dez * dez;\n\n    const det =\n        (clift * (dez * ab + aez * bd + bez * da) - dlift * (aez * bc - bez * ac + cez * ab)) +\n        (alift * (bez * cd - cez * bd + dez * bc) - blift * (cez * da + dez * ac + aez * cd));\n\n    const aezplus = Math.abs(aez);\n    const bezplus = Math.abs(bez);\n    const cezplus = Math.abs(cez);\n    const dezplus = Math.abs(dez);\n    const aexbeyplus = Math.abs(aexbey) + Math.abs(bexaey);\n    const bexceyplus = Math.abs(bexcey) + Math.abs(cexbey);\n    const cexdeyplus = Math.abs(cexdey) + Math.abs(dexcey);\n    const dexaeyplus = Math.abs(dexaey) + Math.abs(aexdey);\n    const aexceyplus = Math.abs(aexcey) + Math.abs(cexaey);\n    const bexdeyplus = Math.abs(bexdey) + Math.abs(dexbey);\n    const permanent =\n        (cexdeyplus * bezplus + bexdeyplus * cezplus + bexceyplus * dezplus) * alift +\n        (dexaeyplus * cezplus + aexceyplus * dezplus + cexdeyplus * aezplus) * blift +\n        (aexbeyplus * dezplus + bexdeyplus * aezplus + dexaeyplus * bezplus) * clift +\n        (bexceyplus * aezplus + aexceyplus * bezplus + aexbeyplus * cezplus) * dlift;\n\n    const errbound = isperrboundA * permanent;\n    if (det > errbound || -det > errbound) {\n        return det;\n    }\n    return -insphereadapt(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, ex, ey, ez, permanent);\n}\n\nfunction inspherefast(pax, pay, paz, pbx, pby, pbz, pcx, pcy, pcz, pdx, pdy, pdz, pex, pey, pez) {\n    const aex = pax - pex;\n    const bex = pbx - pex;\n    const cex = pcx - pex;\n    const dex = pdx - pex;\n    const aey = pay - pey;\n    const bey = pby - pey;\n    const cey = pcy - pey;\n    const dey = pdy - pey;\n    const aez = paz - pez;\n    const bez = pbz - pez;\n    const cez = pcz - pez;\n    const dez = pdz - pez;\n\n    const ab = aex * bey - bex * aey;\n    const bc = bex * cey - cex * bey;\n    const cd = cex * dey - dex * cey;\n    const da = dex * aey - aex * dey;\n    const ac = aex * cey - cex * aey;\n    const bd = bex * dey - dex * bey;\n\n    const abc = aez * bc - bez * ac + cez * ab;\n    const bcd = bez * cd - cez * bd + dez * bc;\n    const cda = cez * da + dez * ac + aez * cd;\n    const dab = dez * ab + aez * bd + bez * da;\n\n    const alift = aex * aex + aey * aey + aez * aez;\n    const blift = bex * bex + bey * bey + bez * bez;\n    const clift = cex * cex + cey * cey + cez * cez;\n    const dlift = dex * dex + dey * dey + dez * dez;\n\n    return (clift * dab - dlift * abc) + (alift * bcd - blift * cda);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/esm/insphere.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/esm/orient2d.js":
/*!************************************************************!*\
  !*** ../../node_modules/robust-predicates/esm/orient2d.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   orient2d: () => (/* binding */ orient2d),\n/* harmony export */   orient2dfast: () => (/* binding */ orient2dfast)\n/* harmony export */ });\n/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util.js */ \"../../node_modules/robust-predicates/esm/util.js\");\n\n\nconst ccwerrboundA = (3 + 16 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst ccwerrboundB = (2 + 12 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst ccwerrboundC = (9 + 64 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\nconst B = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst C1 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst C2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(12);\nconst D = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(16);\nconst u = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\n\nfunction orient2dadapt(ax, ay, bx, by, cx, cy, detsum) {\n    let acxtail, acytail, bcxtail, bcytail;\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _0, s1, s0, t1, t0, u3;\n\n    const acx = ax - cx;\n    const bcx = bx - cx;\n    const acy = ay - cy;\n    const bcy = by - cy;\n\n    s1 = acx * bcy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acx;\n    ahi = c - (c - acx);\n    alo = acx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcy;\n    bhi = c - (c - bcy);\n    blo = bcy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = acy * bcx;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acy;\n    ahi = c - (c - acy);\n    alo = acy - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcx;\n    bhi = c - (c - bcx);\n    blo = bcx - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    B[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    B[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    B[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    B[3] = u3;\n\n    let det = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.estimate)(4, B);\n    let errbound = ccwerrboundB * detsum;\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    bvirt = ax - acx;\n    acxtail = ax - (acx + bvirt) + (bvirt - cx);\n    bvirt = bx - bcx;\n    bcxtail = bx - (bcx + bvirt) + (bvirt - cx);\n    bvirt = ay - acy;\n    acytail = ay - (acy + bvirt) + (bvirt - cy);\n    bvirt = by - bcy;\n    bcytail = by - (bcy + bvirt) + (bvirt - cy);\n\n    if (acxtail === 0 && acytail === 0 && bcxtail === 0 && bcytail === 0) {\n        return det;\n    }\n\n    errbound = ccwerrboundC * detsum + _util_js__WEBPACK_IMPORTED_MODULE_0__.resulterrbound * Math.abs(det);\n    det += (acx * bcytail + bcy * acxtail) - (acy * bcxtail + bcx * acytail);\n    if (det >= errbound || -det >= errbound) return det;\n\n    s1 = acxtail * bcy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acxtail;\n    ahi = c - (c - acxtail);\n    alo = acxtail - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcy;\n    bhi = c - (c - bcy);\n    blo = bcy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = acytail * bcx;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acytail;\n    ahi = c - (c - acytail);\n    alo = acytail - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcx;\n    bhi = c - (c - bcx);\n    blo = bcx - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    u[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    u[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    u[3] = u3;\n    const C1len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(4, B, 4, u, C1);\n\n    s1 = acx * bcytail;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acx;\n    ahi = c - (c - acx);\n    alo = acx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcytail;\n    bhi = c - (c - bcytail);\n    blo = bcytail - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = acy * bcxtail;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acy;\n    ahi = c - (c - acy);\n    alo = acy - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcxtail;\n    bhi = c - (c - bcxtail);\n    blo = bcxtail - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    u[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    u[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    u[3] = u3;\n    const C2len = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(C1len, C1, 4, u, C2);\n\n    s1 = acxtail * bcytail;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acxtail;\n    ahi = c - (c - acxtail);\n    alo = acxtail - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcytail;\n    bhi = c - (c - bcytail);\n    blo = bcytail - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = acytail * bcxtail;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * acytail;\n    ahi = c - (c - acytail);\n    alo = acytail - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bcxtail;\n    bhi = c - (c - bcxtail);\n    blo = bcxtail - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    u[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    u[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    u[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    u[3] = u3;\n    const Dlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(C2len, C2, 4, u, D);\n\n    return D[Dlen - 1];\n}\n\nfunction orient2d(ax, ay, bx, by, cx, cy) {\n    const detleft = (ay - cy) * (bx - cx);\n    const detright = (ax - cx) * (by - cy);\n    const det = detleft - detright;\n\n    const detsum = Math.abs(detleft + detright);\n    if (Math.abs(det) >= ccwerrboundA * detsum) return det;\n\n    return -orient2dadapt(ax, ay, bx, by, cx, cy, detsum);\n}\n\nfunction orient2dfast(ax, ay, bx, by, cx, cy) {\n    return (ay - cy) * (bx - cx) - (ax - cx) * (by - cy);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/esm/orient2d.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/esm/orient3d.js":
/*!************************************************************!*\
  !*** ../../node_modules/robust-predicates/esm/orient3d.js ***!
  \************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   orient3d: () => (/* binding */ orient3d),\n/* harmony export */   orient3dfast: () => (/* binding */ orient3dfast)\n/* harmony export */ });\n/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./util.js */ \"../../node_modules/robust-predicates/esm/util.js\");\n\n\nconst o3derrboundA = (7 + 56 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst o3derrboundB = (3 + 28 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\nconst o3derrboundC = (26 + 288 * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon) * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon * _util_js__WEBPACK_IMPORTED_MODULE_0__.epsilon;\n\nconst bc = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ca = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ab = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst at_b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst at_c = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bt_c = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bt_a = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ct_a = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst ct_b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\nconst bct = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst cat = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst abt = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst u = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(4);\n\nconst _8 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _8b = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _16 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(8);\nconst _12 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(12);\n\nlet fin = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(192);\nlet fin2 = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.vec)(192);\n\nfunction finadd(finlen, alen, a) {\n    finlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(finlen, fin, alen, a, fin2);\n    const tmp = fin; fin = fin2; fin2 = tmp;\n    return finlen;\n}\n\nfunction tailinit(xtail, ytail, ax, ay, bx, by, a, b) {\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _k, _0, s1, s0, t1, t0, u3, negate;\n    if (xtail === 0) {\n        if (ytail === 0) {\n            a[0] = 0;\n            b[0] = 0;\n            return 1;\n        } else {\n            negate = -ytail;\n            s1 = negate * ax;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * negate;\n            ahi = c - (c - negate);\n            alo = negate - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n            bhi = c - (c - ax);\n            blo = ax - bhi;\n            a[0] = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            a[1] = s1;\n            s1 = ytail * bx;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ytail;\n            ahi = c - (c - ytail);\n            alo = ytail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n            bhi = c - (c - bx);\n            blo = bx - bhi;\n            b[0] = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            b[1] = s1;\n            return 2;\n        }\n    } else {\n        if (ytail === 0) {\n            s1 = xtail * ay;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * xtail;\n            ahi = c - (c - xtail);\n            alo = xtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n            bhi = c - (c - ay);\n            blo = ay - bhi;\n            a[0] = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            a[1] = s1;\n            negate = -xtail;\n            s1 = negate * by;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * negate;\n            ahi = c - (c - negate);\n            alo = negate - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n            bhi = c - (c - by);\n            blo = by - bhi;\n            b[0] = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            b[1] = s1;\n            return 2;\n        } else {\n            s1 = xtail * ay;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * xtail;\n            ahi = c - (c - xtail);\n            alo = xtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ay;\n            bhi = c - (c - ay);\n            blo = ay - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = ytail * ax;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ytail;\n            ahi = c - (c - ytail);\n            alo = ytail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ax;\n            bhi = c - (c - ax);\n            blo = ax - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 - t0;\n            bvirt = s0 - _i;\n            a[0] = s0 - (_i + bvirt) + (bvirt - t0);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 - t1;\n            bvirt = _0 - _i;\n            a[1] = _0 - (_i + bvirt) + (bvirt - t1);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            a[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            a[3] = u3;\n            s1 = ytail * bx;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ytail;\n            ahi = c - (c - ytail);\n            alo = ytail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bx;\n            bhi = c - (c - bx);\n            blo = bx - bhi;\n            s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n            t1 = xtail * by;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * xtail;\n            ahi = c - (c - xtail);\n            alo = xtail - ahi;\n            c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * by;\n            bhi = c - (c - by);\n            blo = by - bhi;\n            t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n            _i = s0 - t0;\n            bvirt = s0 - _i;\n            b[0] = s0 - (_i + bvirt) + (bvirt - t0);\n            _j = s1 + _i;\n            bvirt = _j - s1;\n            _0 = s1 - (_j - bvirt) + (_i - bvirt);\n            _i = _0 - t1;\n            bvirt = _0 - _i;\n            b[1] = _0 - (_i + bvirt) + (bvirt - t1);\n            u3 = _j + _i;\n            bvirt = u3 - _j;\n            b[2] = _j - (u3 - bvirt) + (_i - bvirt);\n            b[3] = u3;\n            return 4;\n        }\n    }\n}\n\nfunction tailadd(finlen, a, b, k, z) {\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _k, _0, s1, s0, u3;\n    s1 = a * b;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * a;\n    ahi = c - (c - a);\n    alo = a - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * b;\n    bhi = c - (c - b);\n    blo = b - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * k;\n    bhi = c - (c - k);\n    blo = k - bhi;\n    _i = s0 * k;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * s0;\n    ahi = c - (c - s0);\n    alo = s0 - ahi;\n    u[0] = alo * blo - (_i - ahi * bhi - alo * bhi - ahi * blo);\n    _j = s1 * k;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * s1;\n    ahi = c - (c - s1);\n    alo = s1 - ahi;\n    _0 = alo * blo - (_j - ahi * bhi - alo * bhi - ahi * blo);\n    _k = _i + _0;\n    bvirt = _k - _i;\n    u[1] = _i - (_k - bvirt) + (_0 - bvirt);\n    u3 = _j + _k;\n    u[2] = _k - (u3 - _j);\n    u[3] = u3;\n    finlen = finadd(finlen, 4, u);\n    if (z !== 0) {\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * z;\n        bhi = c - (c - z);\n        blo = z - bhi;\n        _i = s0 * z;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * s0;\n        ahi = c - (c - s0);\n        alo = s0 - ahi;\n        u[0] = alo * blo - (_i - ahi * bhi - alo * bhi - ahi * blo);\n        _j = s1 * z;\n        c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * s1;\n        ahi = c - (c - s1);\n        alo = s1 - ahi;\n        _0 = alo * blo - (_j - ahi * bhi - alo * bhi - ahi * blo);\n        _k = _i + _0;\n        bvirt = _k - _i;\n        u[1] = _i - (_k - bvirt) + (_0 - bvirt);\n        u3 = _j + _k;\n        u[2] = _k - (u3 - _j);\n        u[3] = u3;\n        finlen = finadd(finlen, 4, u);\n    }\n    return finlen;\n}\n\nfunction orient3dadapt(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, permanent) {\n    let finlen;\n    let adxtail, bdxtail, cdxtail;\n    let adytail, bdytail, cdytail;\n    let adztail, bdztail, cdztail;\n    let bvirt, c, ahi, alo, bhi, blo, _i, _j, _k, _0, s1, s0, t1, t0, u3;\n\n    const adx = ax - dx;\n    const bdx = bx - dx;\n    const cdx = cx - dx;\n    const ady = ay - dy;\n    const bdy = by - dy;\n    const cdy = cy - dy;\n    const adz = az - dz;\n    const bdz = bz - dz;\n    const cdz = cz - dz;\n\n    s1 = bdx * cdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n    ahi = c - (c - bdx);\n    alo = bdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n    bhi = c - (c - cdy);\n    blo = cdy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = cdx * bdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n    ahi = c - (c - cdx);\n    alo = cdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n    bhi = c - (c - bdy);\n    blo = bdy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    bc[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    bc[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    bc[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    bc[3] = u3;\n    s1 = cdx * ady;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdx;\n    ahi = c - (c - cdx);\n    alo = cdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n    bhi = c - (c - ady);\n    blo = ady - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = adx * cdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n    ahi = c - (c - adx);\n    alo = adx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * cdy;\n    bhi = c - (c - cdy);\n    blo = cdy - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ca[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ca[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ca[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ca[3] = u3;\n    s1 = adx * bdy;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * adx;\n    ahi = c - (c - adx);\n    alo = adx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdy;\n    bhi = c - (c - bdy);\n    blo = bdy - bhi;\n    s0 = alo * blo - (s1 - ahi * bhi - alo * bhi - ahi * blo);\n    t1 = bdx * ady;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * bdx;\n    ahi = c - (c - bdx);\n    alo = bdx - ahi;\n    c = _util_js__WEBPACK_IMPORTED_MODULE_0__.splitter * ady;\n    bhi = c - (c - ady);\n    blo = ady - bhi;\n    t0 = alo * blo - (t1 - ahi * bhi - alo * bhi - ahi * blo);\n    _i = s0 - t0;\n    bvirt = s0 - _i;\n    ab[0] = s0 - (_i + bvirt) + (bvirt - t0);\n    _j = s1 + _i;\n    bvirt = _j - s1;\n    _0 = s1 - (_j - bvirt) + (_i - bvirt);\n    _i = _0 - t1;\n    bvirt = _0 - _i;\n    ab[1] = _0 - (_i + bvirt) + (bvirt - t1);\n    u3 = _j + _i;\n    bvirt = u3 - _j;\n    ab[2] = _j - (u3 - bvirt) + (_i - bvirt);\n    ab[3] = u3;\n\n    finlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, adz, _8), _8,\n            (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdz, _8b), _8b, _16), _16,\n        (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdz, _8), _8, fin);\n\n    let det = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.estimate)(finlen, fin);\n    let errbound = o3derrboundB * permanent;\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    bvirt = ax - adx;\n    adxtail = ax - (adx + bvirt) + (bvirt - dx);\n    bvirt = bx - bdx;\n    bdxtail = bx - (bdx + bvirt) + (bvirt - dx);\n    bvirt = cx - cdx;\n    cdxtail = cx - (cdx + bvirt) + (bvirt - dx);\n    bvirt = ay - ady;\n    adytail = ay - (ady + bvirt) + (bvirt - dy);\n    bvirt = by - bdy;\n    bdytail = by - (bdy + bvirt) + (bvirt - dy);\n    bvirt = cy - cdy;\n    cdytail = cy - (cdy + bvirt) + (bvirt - dy);\n    bvirt = az - adz;\n    adztail = az - (adz + bvirt) + (bvirt - dz);\n    bvirt = bz - bdz;\n    bdztail = bz - (bdz + bvirt) + (bvirt - dz);\n    bvirt = cz - cdz;\n    cdztail = cz - (cdz + bvirt) + (bvirt - dz);\n\n    if (adxtail === 0 && bdxtail === 0 && cdxtail === 0 &&\n        adytail === 0 && bdytail === 0 && cdytail === 0 &&\n        adztail === 0 && bdztail === 0 && cdztail === 0) {\n        return det;\n    }\n\n    errbound = o3derrboundC * permanent + _util_js__WEBPACK_IMPORTED_MODULE_0__.resulterrbound * Math.abs(det);\n    det +=\n        adz * (bdx * cdytail + cdy * bdxtail - (bdy * cdxtail + cdx * bdytail)) + adztail * (bdx * cdy - bdy * cdx) +\n        bdz * (cdx * adytail + ady * cdxtail - (cdy * adxtail + adx * cdytail)) + bdztail * (cdx * ady - cdy * adx) +\n        cdz * (adx * bdytail + bdy * adxtail - (ady * bdxtail + bdx * adytail)) + cdztail * (adx * bdy - ady * bdx);\n    if (det >= errbound || -det >= errbound) {\n        return det;\n    }\n\n    const at_len = tailinit(adxtail, adytail, bdx, bdy, cdx, cdy, at_b, at_c);\n    const bt_len = tailinit(bdxtail, bdytail, cdx, cdy, adx, ady, bt_c, bt_a);\n    const ct_len = tailinit(cdxtail, cdytail, adx, ady, bdx, bdy, ct_a, ct_b);\n\n    const bctlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(bt_len, bt_c, ct_len, ct_b, bct);\n    finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bctlen, bct, adz, _16), _16);\n\n    const catlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(ct_len, ct_a, at_len, at_c, cat);\n    finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(catlen, cat, bdz, _16), _16);\n\n    const abtlen = (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.sum)(at_len, at_b, bt_len, bt_a, abt);\n    finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abtlen, abt, cdz, _16), _16);\n\n    if (adztail !== 0) {\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, bc, adztail, _12), _12);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(bctlen, bct, adztail, _16), _16);\n    }\n    if (bdztail !== 0) {\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ca, bdztail, _12), _12);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(catlen, cat, bdztail, _16), _16);\n    }\n    if (cdztail !== 0) {\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(4, ab, cdztail, _12), _12);\n        finlen = finadd(finlen, (0,_util_js__WEBPACK_IMPORTED_MODULE_0__.scale)(abtlen, abt, cdztail, _16), _16);\n    }\n\n    if (adxtail !== 0) {\n        if (bdytail !== 0) {\n            finlen = tailadd(finlen, adxtail, bdytail, cdz, cdztail);\n        }\n        if (cdytail !== 0) {\n            finlen = tailadd(finlen, -adxtail, cdytail, bdz, bdztail);\n        }\n    }\n    if (bdxtail !== 0) {\n        if (cdytail !== 0) {\n            finlen = tailadd(finlen, bdxtail, cdytail, adz, adztail);\n        }\n        if (adytail !== 0) {\n            finlen = tailadd(finlen, -bdxtail, adytail, cdz, cdztail);\n        }\n    }\n    if (cdxtail !== 0) {\n        if (adytail !== 0) {\n            finlen = tailadd(finlen, cdxtail, adytail, bdz, bdztail);\n        }\n        if (bdytail !== 0) {\n            finlen = tailadd(finlen, -cdxtail, bdytail, adz, adztail);\n        }\n    }\n\n    return fin[finlen - 1];\n}\n\nfunction orient3d(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz) {\n    const adx = ax - dx;\n    const bdx = bx - dx;\n    const cdx = cx - dx;\n    const ady = ay - dy;\n    const bdy = by - dy;\n    const cdy = cy - dy;\n    const adz = az - dz;\n    const bdz = bz - dz;\n    const cdz = cz - dz;\n\n    const bdxcdy = bdx * cdy;\n    const cdxbdy = cdx * bdy;\n\n    const cdxady = cdx * ady;\n    const adxcdy = adx * cdy;\n\n    const adxbdy = adx * bdy;\n    const bdxady = bdx * ady;\n\n    const det =\n        adz * (bdxcdy - cdxbdy) +\n        bdz * (cdxady - adxcdy) +\n        cdz * (adxbdy - bdxady);\n\n    const permanent =\n        (Math.abs(bdxcdy) + Math.abs(cdxbdy)) * Math.abs(adz) +\n        (Math.abs(cdxady) + Math.abs(adxcdy)) * Math.abs(bdz) +\n        (Math.abs(adxbdy) + Math.abs(bdxady)) * Math.abs(cdz);\n\n    const errbound = o3derrboundA * permanent;\n    if (det > errbound || -det > errbound) {\n        return det;\n    }\n\n    return orient3dadapt(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz, permanent);\n}\n\nfunction orient3dfast(ax, ay, az, bx, by, bz, cx, cy, cz, dx, dy, dz) {\n    const adx = ax - dx;\n    const bdx = bx - dx;\n    const cdx = cx - dx;\n    const ady = ay - dy;\n    const bdy = by - dy;\n    const cdy = cy - dy;\n    const adz = az - dz;\n    const bdz = bz - dz;\n    const cdz = cz - dz;\n\n    return adx * (bdy * cdz - bdz * cdy) +\n        bdx * (cdy * adz - cdz * ady) +\n        cdx * (ady * bdz - adz * bdy);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/esm/orient3d.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/esm/util.js":
/*!********************************************************!*\
  !*** ../../node_modules/robust-predicates/esm/util.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   epsilon: () => (/* binding */ epsilon),\n/* harmony export */   estimate: () => (/* binding */ estimate),\n/* harmony export */   negate: () => (/* binding */ negate),\n/* harmony export */   resulterrbound: () => (/* binding */ resulterrbound),\n/* harmony export */   scale: () => (/* binding */ scale),\n/* harmony export */   splitter: () => (/* binding */ splitter),\n/* harmony export */   sum: () => (/* binding */ sum),\n/* harmony export */   sum_three: () => (/* binding */ sum_three),\n/* harmony export */   vec: () => (/* binding */ vec)\n/* harmony export */ });\nconst epsilon = 1.1102230246251565e-16;\nconst splitter = 134217729;\nconst resulterrbound = (3 + 8 * epsilon) * epsilon;\n\n// fast_expansion_sum_zeroelim routine from oritinal code\nfunction sum(elen, e, flen, f, h) {\n    let Q, Qnew, hh, bvirt;\n    let enow = e[0];\n    let fnow = f[0];\n    let eindex = 0;\n    let findex = 0;\n    if ((fnow > enow) === (fnow > -enow)) {\n        Q = enow;\n        enow = e[++eindex];\n    } else {\n        Q = fnow;\n        fnow = f[++findex];\n    }\n    let hindex = 0;\n    if (eindex < elen && findex < flen) {\n        if ((fnow > enow) === (fnow > -enow)) {\n            Qnew = enow + Q;\n            hh = Q - (Qnew - enow);\n            enow = e[++eindex];\n        } else {\n            Qnew = fnow + Q;\n            hh = Q - (Qnew - fnow);\n            fnow = f[++findex];\n        }\n        Q = Qnew;\n        if (hh !== 0) {\n            h[hindex++] = hh;\n        }\n        while (eindex < elen && findex < flen) {\n            if ((fnow > enow) === (fnow > -enow)) {\n                Qnew = Q + enow;\n                bvirt = Qnew - Q;\n                hh = Q - (Qnew - bvirt) + (enow - bvirt);\n                enow = e[++eindex];\n            } else {\n                Qnew = Q + fnow;\n                bvirt = Qnew - Q;\n                hh = Q - (Qnew - bvirt) + (fnow - bvirt);\n                fnow = f[++findex];\n            }\n            Q = Qnew;\n            if (hh !== 0) {\n                h[hindex++] = hh;\n            }\n        }\n    }\n    while (eindex < elen) {\n        Qnew = Q + enow;\n        bvirt = Qnew - Q;\n        hh = Q - (Qnew - bvirt) + (enow - bvirt);\n        enow = e[++eindex];\n        Q = Qnew;\n        if (hh !== 0) {\n            h[hindex++] = hh;\n        }\n    }\n    while (findex < flen) {\n        Qnew = Q + fnow;\n        bvirt = Qnew - Q;\n        hh = Q - (Qnew - bvirt) + (fnow - bvirt);\n        fnow = f[++findex];\n        Q = Qnew;\n        if (hh !== 0) {\n            h[hindex++] = hh;\n        }\n    }\n    if (Q !== 0 || hindex === 0) {\n        h[hindex++] = Q;\n    }\n    return hindex;\n}\n\nfunction sum_three(alen, a, blen, b, clen, c, tmp, out) {\n    return sum(sum(alen, a, blen, b, tmp), tmp, clen, c, out);\n}\n\n// scale_expansion_zeroelim routine from oritinal code\nfunction scale(elen, e, b, h) {\n    let Q, sum, hh, product1, product0;\n    let bvirt, c, ahi, alo, bhi, blo;\n\n    c = splitter * b;\n    bhi = c - (c - b);\n    blo = b - bhi;\n    let enow = e[0];\n    Q = enow * b;\n    c = splitter * enow;\n    ahi = c - (c - enow);\n    alo = enow - ahi;\n    hh = alo * blo - (Q - ahi * bhi - alo * bhi - ahi * blo);\n    let hindex = 0;\n    if (hh !== 0) {\n        h[hindex++] = hh;\n    }\n    for (let i = 1; i < elen; i++) {\n        enow = e[i];\n        product1 = enow * b;\n        c = splitter * enow;\n        ahi = c - (c - enow);\n        alo = enow - ahi;\n        product0 = alo * blo - (product1 - ahi * bhi - alo * bhi - ahi * blo);\n        sum = Q + product0;\n        bvirt = sum - Q;\n        hh = Q - (sum - bvirt) + (product0 - bvirt);\n        if (hh !== 0) {\n            h[hindex++] = hh;\n        }\n        Q = product1 + sum;\n        hh = sum - (Q - product1);\n        if (hh !== 0) {\n            h[hindex++] = hh;\n        }\n    }\n    if (Q !== 0 || hindex === 0) {\n        h[hindex++] = Q;\n    }\n    return hindex;\n}\n\nfunction negate(elen, e) {\n    for (let i = 0; i < elen; i++) e[i] = -e[i];\n    return elen;\n}\n\nfunction estimate(elen, e) {\n    let Q = e[0];\n    for (let i = 1; i < elen; i++) Q += e[i];\n    return Q;\n}\n\nfunction vec(n) {\n    return new Float64Array(n);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/esm/util.js?");

/***/ }),

/***/ "../../node_modules/robust-predicates/index.js":
/*!*****************************************************!*\
  !*** ../../node_modules/robust-predicates/index.js ***!
  \*****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   incircle: () => (/* reexport safe */ _esm_incircle_js__WEBPACK_IMPORTED_MODULE_2__.incircle),\n/* harmony export */   incirclefast: () => (/* reexport safe */ _esm_incircle_js__WEBPACK_IMPORTED_MODULE_2__.incirclefast),\n/* harmony export */   insphere: () => (/* reexport safe */ _esm_insphere_js__WEBPACK_IMPORTED_MODULE_3__.insphere),\n/* harmony export */   inspherefast: () => (/* reexport safe */ _esm_insphere_js__WEBPACK_IMPORTED_MODULE_3__.inspherefast),\n/* harmony export */   orient2d: () => (/* reexport safe */ _esm_orient2d_js__WEBPACK_IMPORTED_MODULE_0__.orient2d),\n/* harmony export */   orient2dfast: () => (/* reexport safe */ _esm_orient2d_js__WEBPACK_IMPORTED_MODULE_0__.orient2dfast),\n/* harmony export */   orient3d: () => (/* reexport safe */ _esm_orient3d_js__WEBPACK_IMPORTED_MODULE_1__.orient3d),\n/* harmony export */   orient3dfast: () => (/* reexport safe */ _esm_orient3d_js__WEBPACK_IMPORTED_MODULE_1__.orient3dfast)\n/* harmony export */ });\n/* harmony import */ var _esm_orient2d_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./esm/orient2d.js */ \"../../node_modules/robust-predicates/esm/orient2d.js\");\n/* harmony import */ var _esm_orient3d_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./esm/orient3d.js */ \"../../node_modules/robust-predicates/esm/orient3d.js\");\n/* harmony import */ var _esm_incircle_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./esm/incircle.js */ \"../../node_modules/robust-predicates/esm/incircle.js\");\n/* harmony import */ var _esm_insphere_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./esm/insphere.js */ \"../../node_modules/robust-predicates/esm/insphere.js\");\n\n\n\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/robust-predicates/index.js?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/constants.js":
/*!********************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/constants.js ***!
  \********************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   WIDTH_HEIGHT: () => (/* binding */ WIDTH_HEIGHT)\n/* harmony export */ });\nconst WIDTH_HEIGHT = new Set([\"width\", \"height\"]);\n//# sourceMappingURL=constants.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/constants.js?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/index.js":
/*!****************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/index.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   Vega: () => (/* reexport safe */ _Vega_svelte__WEBPACK_IMPORTED_MODULE_0__[\"default\"]),\n/* harmony export */   VegaLite: () => (/* reexport safe */ _VegaLite_svelte__WEBPACK_IMPORTED_MODULE_1__[\"default\"])\n/* harmony export */ });\n/* harmony import */ var _Vega_svelte__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Vega.svelte */ \"../../node_modules/svelte-vega/dist/Vega.svelte\");\n/* harmony import */ var _VegaLite_svelte__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./VegaLite.svelte */ \"../../node_modules/svelte-vega/dist/VegaLite.svelte\");\n/* harmony import */ var _types_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./types.js */ \"../../node_modules/svelte-vega/dist/types.js\");\n\n\n\n//# sourceMappingURL=index.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/index.js?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/types.js":
/*!****************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/types.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n\n//# sourceMappingURL=types.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/types.js?");

/***/ }),

/***/ "../../node_modules/svelte-vega/dist/utils.js":
/*!****************************************************!*\
  !*** ../../node_modules/svelte-vega/dist/utils.js ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   addSignalListenersToView: () => (/* binding */ addSignalListenersToView),\n/* harmony export */   combineSpecWithDimension: () => (/* binding */ combineSpecWithDimension),\n/* harmony export */   computeSpecChanges: () => (/* binding */ computeSpecChanges),\n/* harmony export */   getUniqueFieldNames: () => (/* binding */ getUniqueFieldNames),\n/* harmony export */   removeSignalListenersFromView: () => (/* binding */ removeSignalListenersFromView),\n/* harmony export */   shallowEqual: () => (/* binding */ shallowEqual),\n/* harmony export */   updateMultipleDatasetsInView: () => (/* binding */ updateMultipleDatasetsInView)\n/* harmony export */ });\n/* harmony import */ var vega_embed__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vega-embed */ \"../../node_modules/vega-embed/build/vega-embed.module.js\");\n/* harmony import */ var fast_deep_equal__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! fast-deep-equal */ \"../../node_modules/fast-deep-equal/index.js\");\n\n\nfunction updateMultipleDatasetsInView(view, data) {\n    for (const [name, value] of Object.entries(data)) {\n        const getType = {};\n        if (value) {\n            if (!!value && getType.toString.call(value) === \"[object Function]\") {\n                const parsedValue = value;\n                parsedValue(view.data(name));\n            }\n            else {\n                view.change(name, vega_embed__WEBPACK_IMPORTED_MODULE_0__.vega\n                    .changeset()\n                    .remove(() => true)\n                    .insert(value));\n            }\n        }\n    }\n}\n// eslint-disable-next-line @typescript-eslint/no-explicit-any\nfunction shallowEqual(a = {}, b = {}, ignore = new Set()) {\n    const aKeys = Object.keys(a);\n    const bKeys = Object.keys(b);\n    return (a === b ||\n        (aKeys.length === bKeys.length &&\n            aKeys.filter((k) => !ignore.has(k)).every((key) => a[key] === b[key])));\n}\nfunction removeSignalListenersFromView(view, signalListeners) {\n    const signalNames = Object.keys(signalListeners);\n    for (const signalName of signalNames) {\n        try {\n            view.removeSignalListener(signalName, signalListeners[signalName]);\n        }\n        catch (error) {\n            // eslint-disable-next-line no-console\n            console.warn(\"Cannot remove invalid signal listener.\", error);\n        }\n    }\n    return signalNames.length > 0;\n}\nfunction addSignalListenersToView(view, signalListeners) {\n    const signalNames = Object.keys(signalListeners);\n    for (const signalName of signalNames) {\n        try {\n            view.addSignalListener(signalName, signalListeners[signalName]);\n        }\n        catch (error) {\n            console.warn(\"Cannot add invalid signal listener.\", error);\n        }\n    }\n    return signalNames.length > 0;\n}\nfunction getUniqueFieldNames(specs) {\n    return new Set(specs.flatMap((o) => Object.keys(o)));\n}\nfunction computeSpecChanges(newSpec, oldSpec) {\n    if (newSpec === oldSpec)\n        return false;\n    const changes = {\n        width: false,\n        height: false,\n        isExpensive: false,\n    };\n    const hasWidth = \"width\" in newSpec || \"width\" in oldSpec;\n    const hasHeight = \"height\" in newSpec || \"height\" in oldSpec;\n    if (hasWidth &&\n        (!(\"width\" in newSpec) ||\n            !(\"width\" in oldSpec) ||\n            newSpec.width !== oldSpec.width)) {\n        if (\"width\" in newSpec && typeof newSpec.width === \"number\") {\n            changes.width = newSpec.width;\n        }\n        else {\n            changes.isExpensive = true;\n        }\n    }\n    if (hasHeight &&\n        (!(\"height\" in newSpec) ||\n            !(\"height\" in oldSpec) ||\n            newSpec.height !== oldSpec.height)) {\n        if (\"height\" in newSpec && typeof newSpec.height === \"number\") {\n            changes.height = newSpec.height;\n        }\n        else {\n            changes.isExpensive = true;\n        }\n    }\n    const fieldNames = [...getUniqueFieldNames([newSpec, oldSpec])].filter((f) => f !== \"width\" && f !== \"height\");\n    if (fieldNames.some((field) => !(field in newSpec) ||\n        !(field in oldSpec) ||\n        !fast_deep_equal__WEBPACK_IMPORTED_MODULE_1__(newSpec[field], oldSpec[field]))) {\n        changes.isExpensive = true;\n    }\n    return changes.width !== false ||\n        changes.height !== false ||\n        changes.isExpensive\n        ? changes\n        : false;\n}\nfunction combineSpecWithDimension(spec, options) {\n    const { width, height } = options;\n    if (typeof width !== \"undefined\" && typeof height !== \"undefined\") {\n        return { ...spec, width, height };\n    }\n    if (typeof width !== \"undefined\") {\n        return { ...spec, width };\n    }\n    if (typeof height !== \"undefined\") {\n        return { ...spec, height };\n    }\n    return spec;\n}\n//# sourceMappingURL=utils.js.map\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte-vega/dist/utils.js?");

/***/ }),

/***/ "../../node_modules/svelte/easing/index.mjs":
/*!**************************************************!*\
  !*** ../../node_modules/svelte/easing/index.mjs ***!
  \**************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   backIn: () => (/* binding */ backIn),\n/* harmony export */   backInOut: () => (/* binding */ backInOut),\n/* harmony export */   backOut: () => (/* binding */ backOut),\n/* harmony export */   bounceIn: () => (/* binding */ bounceIn),\n/* harmony export */   bounceInOut: () => (/* binding */ bounceInOut),\n/* harmony export */   bounceOut: () => (/* binding */ bounceOut),\n/* harmony export */   circIn: () => (/* binding */ circIn),\n/* harmony export */   circInOut: () => (/* binding */ circInOut),\n/* harmony export */   circOut: () => (/* binding */ circOut),\n/* harmony export */   cubicIn: () => (/* binding */ cubicIn),\n/* harmony export */   cubicInOut: () => (/* binding */ cubicInOut),\n/* harmony export */   cubicOut: () => (/* binding */ cubicOut),\n/* harmony export */   elasticIn: () => (/* binding */ elasticIn),\n/* harmony export */   elasticInOut: () => (/* binding */ elasticInOut),\n/* harmony export */   elasticOut: () => (/* binding */ elasticOut),\n/* harmony export */   expoIn: () => (/* binding */ expoIn),\n/* harmony export */   expoInOut: () => (/* binding */ expoInOut),\n/* harmony export */   expoOut: () => (/* binding */ expoOut),\n/* harmony export */   linear: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.identity),\n/* harmony export */   quadIn: () => (/* binding */ quadIn),\n/* harmony export */   quadInOut: () => (/* binding */ quadInOut),\n/* harmony export */   quadOut: () => (/* binding */ quadOut),\n/* harmony export */   quartIn: () => (/* binding */ quartIn),\n/* harmony export */   quartInOut: () => (/* binding */ quartInOut),\n/* harmony export */   quartOut: () => (/* binding */ quartOut),\n/* harmony export */   quintIn: () => (/* binding */ quintIn),\n/* harmony export */   quintInOut: () => (/* binding */ quintInOut),\n/* harmony export */   quintOut: () => (/* binding */ quintOut),\n/* harmony export */   sineIn: () => (/* binding */ sineIn),\n/* harmony export */   sineInOut: () => (/* binding */ sineInOut),\n/* harmony export */   sineOut: () => (/* binding */ sineOut)\n/* harmony export */ });\n/* harmony import */ var _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../internal/index.mjs */ \"../../node_modules/svelte/internal/index.mjs\");\n\n\n/*\nAdapted from https://github.com/mattdesl\nDistributed under MIT License https://github.com/mattdesl/eases/blob/master/LICENSE.md\n*/\nfunction backInOut(t) {\n    const s = 1.70158 * 1.525;\n    if ((t *= 2) < 1)\n        return 0.5 * (t * t * ((s + 1) * t - s));\n    return 0.5 * ((t -= 2) * t * ((s + 1) * t + s) + 2);\n}\nfunction backIn(t) {\n    const s = 1.70158;\n    return t * t * ((s + 1) * t - s);\n}\nfunction backOut(t) {\n    const s = 1.70158;\n    return --t * t * ((s + 1) * t + s) + 1;\n}\nfunction bounceOut(t) {\n    const a = 4.0 / 11.0;\n    const b = 8.0 / 11.0;\n    const c = 9.0 / 10.0;\n    const ca = 4356.0 / 361.0;\n    const cb = 35442.0 / 1805.0;\n    const cc = 16061.0 / 1805.0;\n    const t2 = t * t;\n    return t < a\n        ? 7.5625 * t2\n        : t < b\n            ? 9.075 * t2 - 9.9 * t + 3.4\n            : t < c\n                ? ca * t2 - cb * t + cc\n                : 10.8 * t * t - 20.52 * t + 10.72;\n}\nfunction bounceInOut(t) {\n    return t < 0.5\n        ? 0.5 * (1.0 - bounceOut(1.0 - t * 2.0))\n        : 0.5 * bounceOut(t * 2.0 - 1.0) + 0.5;\n}\nfunction bounceIn(t) {\n    return 1.0 - bounceOut(1.0 - t);\n}\nfunction circInOut(t) {\n    if ((t *= 2) < 1)\n        return -0.5 * (Math.sqrt(1 - t * t) - 1);\n    return 0.5 * (Math.sqrt(1 - (t -= 2) * t) + 1);\n}\nfunction circIn(t) {\n    return 1.0 - Math.sqrt(1.0 - t * t);\n}\nfunction circOut(t) {\n    return Math.sqrt(1 - --t * t);\n}\nfunction cubicInOut(t) {\n    return t < 0.5 ? 4.0 * t * t * t : 0.5 * Math.pow(2.0 * t - 2.0, 3.0) + 1.0;\n}\nfunction cubicIn(t) {\n    return t * t * t;\n}\nfunction cubicOut(t) {\n    const f = t - 1.0;\n    return f * f * f + 1.0;\n}\nfunction elasticInOut(t) {\n    return t < 0.5\n        ? 0.5 *\n            Math.sin(((+13.0 * Math.PI) / 2) * 2.0 * t) *\n            Math.pow(2.0, 10.0 * (2.0 * t - 1.0))\n        : 0.5 *\n            Math.sin(((-13.0 * Math.PI) / 2) * (2.0 * t - 1.0 + 1.0)) *\n            Math.pow(2.0, -10.0 * (2.0 * t - 1.0)) +\n            1.0;\n}\nfunction elasticIn(t) {\n    return Math.sin((13.0 * t * Math.PI) / 2) * Math.pow(2.0, 10.0 * (t - 1.0));\n}\nfunction elasticOut(t) {\n    return (Math.sin((-13.0 * (t + 1.0) * Math.PI) / 2) * Math.pow(2.0, -10.0 * t) + 1.0);\n}\nfunction expoInOut(t) {\n    return t === 0.0 || t === 1.0\n        ? t\n        : t < 0.5\n            ? +0.5 * Math.pow(2.0, 20.0 * t - 10.0)\n            : -0.5 * Math.pow(2.0, 10.0 - t * 20.0) + 1.0;\n}\nfunction expoIn(t) {\n    return t === 0.0 ? t : Math.pow(2.0, 10.0 * (t - 1.0));\n}\nfunction expoOut(t) {\n    return t === 1.0 ? t : 1.0 - Math.pow(2.0, -10.0 * t);\n}\nfunction quadInOut(t) {\n    t /= 0.5;\n    if (t < 1)\n        return 0.5 * t * t;\n    t--;\n    return -0.5 * (t * (t - 2) - 1);\n}\nfunction quadIn(t) {\n    return t * t;\n}\nfunction quadOut(t) {\n    return -t * (t - 2.0);\n}\nfunction quartInOut(t) {\n    return t < 0.5\n        ? +8.0 * Math.pow(t, 4.0)\n        : -8.0 * Math.pow(t - 1.0, 4.0) + 1.0;\n}\nfunction quartIn(t) {\n    return Math.pow(t, 4.0);\n}\nfunction quartOut(t) {\n    return Math.pow(t - 1.0, 3.0) * (1.0 - t) + 1.0;\n}\nfunction quintInOut(t) {\n    if ((t *= 2) < 1)\n        return 0.5 * t * t * t * t * t;\n    return 0.5 * ((t -= 2) * t * t * t * t + 2);\n}\nfunction quintIn(t) {\n    return t * t * t * t * t;\n}\nfunction quintOut(t) {\n    return --t * t * t * t * t + 1;\n}\nfunction sineInOut(t) {\n    return -0.5 * (Math.cos(Math.PI * t) - 1);\n}\nfunction sineIn(t) {\n    const v = Math.cos(t * Math.PI * 0.5);\n    if (Math.abs(v) < 1e-14)\n        return 1;\n    else\n        return 1 - v;\n}\nfunction sineOut(t) {\n    return Math.sin((t * Math.PI) / 2);\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte/easing/index.mjs?");

/***/ }),

/***/ "../../node_modules/svelte/index.mjs":
/*!*******************************************!*\
  !*** ../../node_modules/svelte/index.mjs ***!
  \*******************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   SvelteComponent: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.SvelteComponentDev),\n/* harmony export */   SvelteComponentTyped: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.SvelteComponentTyped),\n/* harmony export */   afterUpdate: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.afterUpdate),\n/* harmony export */   beforeUpdate: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.beforeUpdate),\n/* harmony export */   createEventDispatcher: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.createEventDispatcher),\n/* harmony export */   getAllContexts: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.getAllContexts),\n/* harmony export */   getContext: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.getContext),\n/* harmony export */   hasContext: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.hasContext),\n/* harmony export */   onDestroy: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.onDestroy),\n/* harmony export */   onMount: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.onMount),\n/* harmony export */   setContext: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.setContext),\n/* harmony export */   tick: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.tick)\n/* harmony export */ });\n/* harmony import */ var _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/index.mjs */ \"../../node_modules/svelte/internal/index.mjs\");\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte/index.mjs?");

/***/ }),

/***/ "../../node_modules/svelte/internal/index.mjs":
/*!****************************************************!*\
  !*** ../../node_modules/svelte/internal/index.mjs ***!
  \****************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   HtmlTag: () => (/* binding */ HtmlTag),\n/* harmony export */   HtmlTagHydration: () => (/* binding */ HtmlTagHydration),\n/* harmony export */   ResizeObserverSingleton: () => (/* binding */ ResizeObserverSingleton),\n/* harmony export */   SvelteComponent: () => (/* binding */ SvelteComponent),\n/* harmony export */   SvelteComponentDev: () => (/* binding */ SvelteComponentDev),\n/* harmony export */   SvelteComponentTyped: () => (/* binding */ SvelteComponentTyped),\n/* harmony export */   SvelteElement: () => (/* binding */ SvelteElement),\n/* harmony export */   action_destroyer: () => (/* binding */ action_destroyer),\n/* harmony export */   add_attribute: () => (/* binding */ add_attribute),\n/* harmony export */   add_classes: () => (/* binding */ add_classes),\n/* harmony export */   add_flush_callback: () => (/* binding */ add_flush_callback),\n/* harmony export */   add_iframe_resize_listener: () => (/* binding */ add_iframe_resize_listener),\n/* harmony export */   add_location: () => (/* binding */ add_location),\n/* harmony export */   add_render_callback: () => (/* binding */ add_render_callback),\n/* harmony export */   add_styles: () => (/* binding */ add_styles),\n/* harmony export */   add_transform: () => (/* binding */ add_transform),\n/* harmony export */   afterUpdate: () => (/* binding */ afterUpdate),\n/* harmony export */   append: () => (/* binding */ append),\n/* harmony export */   append_dev: () => (/* binding */ append_dev),\n/* harmony export */   append_empty_stylesheet: () => (/* binding */ append_empty_stylesheet),\n/* harmony export */   append_hydration: () => (/* binding */ append_hydration),\n/* harmony export */   append_hydration_dev: () => (/* binding */ append_hydration_dev),\n/* harmony export */   append_styles: () => (/* binding */ append_styles),\n/* harmony export */   assign: () => (/* binding */ assign),\n/* harmony export */   attr: () => (/* binding */ attr),\n/* harmony export */   attr_dev: () => (/* binding */ attr_dev),\n/* harmony export */   attribute_to_object: () => (/* binding */ attribute_to_object),\n/* harmony export */   beforeUpdate: () => (/* binding */ beforeUpdate),\n/* harmony export */   bind: () => (/* binding */ bind),\n/* harmony export */   binding_callbacks: () => (/* binding */ binding_callbacks),\n/* harmony export */   blank_object: () => (/* binding */ blank_object),\n/* harmony export */   bubble: () => (/* binding */ bubble),\n/* harmony export */   check_outros: () => (/* binding */ check_outros),\n/* harmony export */   children: () => (/* binding */ children),\n/* harmony export */   claim_comment: () => (/* binding */ claim_comment),\n/* harmony export */   claim_component: () => (/* binding */ claim_component),\n/* harmony export */   claim_element: () => (/* binding */ claim_element),\n/* harmony export */   claim_html_tag: () => (/* binding */ claim_html_tag),\n/* harmony export */   claim_space: () => (/* binding */ claim_space),\n/* harmony export */   claim_svg_element: () => (/* binding */ claim_svg_element),\n/* harmony export */   claim_text: () => (/* binding */ claim_text),\n/* harmony export */   clear_loops: () => (/* binding */ clear_loops),\n/* harmony export */   comment: () => (/* binding */ comment),\n/* harmony export */   component_subscribe: () => (/* binding */ component_subscribe),\n/* harmony export */   compute_rest_props: () => (/* binding */ compute_rest_props),\n/* harmony export */   compute_slots: () => (/* binding */ compute_slots),\n/* harmony export */   construct_svelte_component: () => (/* binding */ construct_svelte_component),\n/* harmony export */   construct_svelte_component_dev: () => (/* binding */ construct_svelte_component_dev),\n/* harmony export */   contenteditable_truthy_values: () => (/* binding */ contenteditable_truthy_values),\n/* harmony export */   createEventDispatcher: () => (/* binding */ createEventDispatcher),\n/* harmony export */   create_animation: () => (/* binding */ create_animation),\n/* harmony export */   create_bidirectional_transition: () => (/* binding */ create_bidirectional_transition),\n/* harmony export */   create_component: () => (/* binding */ create_component),\n/* harmony export */   create_in_transition: () => (/* binding */ create_in_transition),\n/* harmony export */   create_out_transition: () => (/* binding */ create_out_transition),\n/* harmony export */   create_slot: () => (/* binding */ create_slot),\n/* harmony export */   create_ssr_component: () => (/* binding */ create_ssr_component),\n/* harmony export */   current_component: () => (/* binding */ current_component),\n/* harmony export */   custom_event: () => (/* binding */ custom_event),\n/* harmony export */   dataset_dev: () => (/* binding */ dataset_dev),\n/* harmony export */   debug: () => (/* binding */ debug),\n/* harmony export */   destroy_block: () => (/* binding */ destroy_block),\n/* harmony export */   destroy_component: () => (/* binding */ destroy_component),\n/* harmony export */   destroy_each: () => (/* binding */ destroy_each),\n/* harmony export */   detach: () => (/* binding */ detach),\n/* harmony export */   detach_after_dev: () => (/* binding */ detach_after_dev),\n/* harmony export */   detach_before_dev: () => (/* binding */ detach_before_dev),\n/* harmony export */   detach_between_dev: () => (/* binding */ detach_between_dev),\n/* harmony export */   detach_dev: () => (/* binding */ detach_dev),\n/* harmony export */   dirty_components: () => (/* binding */ dirty_components),\n/* harmony export */   dispatch_dev: () => (/* binding */ dispatch_dev),\n/* harmony export */   each: () => (/* binding */ each),\n/* harmony export */   element: () => (/* binding */ element),\n/* harmony export */   element_is: () => (/* binding */ element_is),\n/* harmony export */   empty: () => (/* binding */ empty),\n/* harmony export */   end_hydrating: () => (/* binding */ end_hydrating),\n/* harmony export */   escape: () => (/* binding */ escape),\n/* harmony export */   escape_attribute_value: () => (/* binding */ escape_attribute_value),\n/* harmony export */   escape_object: () => (/* binding */ escape_object),\n/* harmony export */   exclude_internal_props: () => (/* binding */ exclude_internal_props),\n/* harmony export */   fix_and_destroy_block: () => (/* binding */ fix_and_destroy_block),\n/* harmony export */   fix_and_outro_and_destroy_block: () => (/* binding */ fix_and_outro_and_destroy_block),\n/* harmony export */   fix_position: () => (/* binding */ fix_position),\n/* harmony export */   flush: () => (/* binding */ flush),\n/* harmony export */   flush_render_callbacks: () => (/* binding */ flush_render_callbacks),\n/* harmony export */   getAllContexts: () => (/* binding */ getAllContexts),\n/* harmony export */   getContext: () => (/* binding */ getContext),\n/* harmony export */   get_all_dirty_from_scope: () => (/* binding */ get_all_dirty_from_scope),\n/* harmony export */   get_binding_group_value: () => (/* binding */ get_binding_group_value),\n/* harmony export */   get_current_component: () => (/* binding */ get_current_component),\n/* harmony export */   get_custom_elements_slots: () => (/* binding */ get_custom_elements_slots),\n/* harmony export */   get_root_for_style: () => (/* binding */ get_root_for_style),\n/* harmony export */   get_slot_changes: () => (/* binding */ get_slot_changes),\n/* harmony export */   get_spread_object: () => (/* binding */ get_spread_object),\n/* harmony export */   get_spread_update: () => (/* binding */ get_spread_update),\n/* harmony export */   get_store_value: () => (/* binding */ get_store_value),\n/* harmony export */   globals: () => (/* binding */ globals),\n/* harmony export */   group_outros: () => (/* binding */ group_outros),\n/* harmony export */   handle_promise: () => (/* binding */ handle_promise),\n/* harmony export */   hasContext: () => (/* binding */ hasContext),\n/* harmony export */   has_prop: () => (/* binding */ has_prop),\n/* harmony export */   head_selector: () => (/* binding */ head_selector),\n/* harmony export */   identity: () => (/* binding */ identity),\n/* harmony export */   init: () => (/* binding */ init),\n/* harmony export */   init_binding_group: () => (/* binding */ init_binding_group),\n/* harmony export */   init_binding_group_dynamic: () => (/* binding */ init_binding_group_dynamic),\n/* harmony export */   insert: () => (/* binding */ insert),\n/* harmony export */   insert_dev: () => (/* binding */ insert_dev),\n/* harmony export */   insert_hydration: () => (/* binding */ insert_hydration),\n/* harmony export */   insert_hydration_dev: () => (/* binding */ insert_hydration_dev),\n/* harmony export */   intros: () => (/* binding */ intros),\n/* harmony export */   invalid_attribute_name_character: () => (/* binding */ invalid_attribute_name_character),\n/* harmony export */   is_client: () => (/* binding */ is_client),\n/* harmony export */   is_crossorigin: () => (/* binding */ is_crossorigin),\n/* harmony export */   is_empty: () => (/* binding */ is_empty),\n/* harmony export */   is_function: () => (/* binding */ is_function),\n/* harmony export */   is_promise: () => (/* binding */ is_promise),\n/* harmony export */   is_void: () => (/* binding */ is_void),\n/* harmony export */   listen: () => (/* binding */ listen),\n/* harmony export */   listen_dev: () => (/* binding */ listen_dev),\n/* harmony export */   loop: () => (/* binding */ loop),\n/* harmony export */   loop_guard: () => (/* binding */ loop_guard),\n/* harmony export */   merge_ssr_styles: () => (/* binding */ merge_ssr_styles),\n/* harmony export */   missing_component: () => (/* binding */ missing_component),\n/* harmony export */   mount_component: () => (/* binding */ mount_component),\n/* harmony export */   noop: () => (/* binding */ noop),\n/* harmony export */   not_equal: () => (/* binding */ not_equal),\n/* harmony export */   now: () => (/* binding */ now),\n/* harmony export */   null_to_empty: () => (/* binding */ null_to_empty),\n/* harmony export */   object_without_properties: () => (/* binding */ object_without_properties),\n/* harmony export */   onDestroy: () => (/* binding */ onDestroy),\n/* harmony export */   onMount: () => (/* binding */ onMount),\n/* harmony export */   once: () => (/* binding */ once),\n/* harmony export */   outro_and_destroy_block: () => (/* binding */ outro_and_destroy_block),\n/* harmony export */   prevent_default: () => (/* binding */ prevent_default),\n/* harmony export */   prop_dev: () => (/* binding */ prop_dev),\n/* harmony export */   query_selector_all: () => (/* binding */ query_selector_all),\n/* harmony export */   raf: () => (/* binding */ raf),\n/* harmony export */   resize_observer_border_box: () => (/* binding */ resize_observer_border_box),\n/* harmony export */   resize_observer_content_box: () => (/* binding */ resize_observer_content_box),\n/* harmony export */   resize_observer_device_pixel_content_box: () => (/* binding */ resize_observer_device_pixel_content_box),\n/* harmony export */   run: () => (/* binding */ run),\n/* harmony export */   run_all: () => (/* binding */ run_all),\n/* harmony export */   safe_not_equal: () => (/* binding */ safe_not_equal),\n/* harmony export */   schedule_update: () => (/* binding */ schedule_update),\n/* harmony export */   select_multiple_value: () => (/* binding */ select_multiple_value),\n/* harmony export */   select_option: () => (/* binding */ select_option),\n/* harmony export */   select_options: () => (/* binding */ select_options),\n/* harmony export */   select_value: () => (/* binding */ select_value),\n/* harmony export */   self: () => (/* binding */ self),\n/* harmony export */   setContext: () => (/* binding */ setContext),\n/* harmony export */   set_attributes: () => (/* binding */ set_attributes),\n/* harmony export */   set_current_component: () => (/* binding */ set_current_component),\n/* harmony export */   set_custom_element_data: () => (/* binding */ set_custom_element_data),\n/* harmony export */   set_custom_element_data_map: () => (/* binding */ set_custom_element_data_map),\n/* harmony export */   set_data: () => (/* binding */ set_data),\n/* harmony export */   set_data_contenteditable: () => (/* binding */ set_data_contenteditable),\n/* harmony export */   set_data_contenteditable_dev: () => (/* binding */ set_data_contenteditable_dev),\n/* harmony export */   set_data_dev: () => (/* binding */ set_data_dev),\n/* harmony export */   set_data_maybe_contenteditable: () => (/* binding */ set_data_maybe_contenteditable),\n/* harmony export */   set_data_maybe_contenteditable_dev: () => (/* binding */ set_data_maybe_contenteditable_dev),\n/* harmony export */   set_dynamic_element_data: () => (/* binding */ set_dynamic_element_data),\n/* harmony export */   set_input_type: () => (/* binding */ set_input_type),\n/* harmony export */   set_input_value: () => (/* binding */ set_input_value),\n/* harmony export */   set_now: () => (/* binding */ set_now),\n/* harmony export */   set_raf: () => (/* binding */ set_raf),\n/* harmony export */   set_store_value: () => (/* binding */ set_store_value),\n/* harmony export */   set_style: () => (/* binding */ set_style),\n/* harmony export */   set_svg_attributes: () => (/* binding */ set_svg_attributes),\n/* harmony export */   space: () => (/* binding */ space),\n/* harmony export */   split_css_unit: () => (/* binding */ split_css_unit),\n/* harmony export */   spread: () => (/* binding */ spread),\n/* harmony export */   src_url_equal: () => (/* binding */ src_url_equal),\n/* harmony export */   start_hydrating: () => (/* binding */ start_hydrating),\n/* harmony export */   stop_immediate_propagation: () => (/* binding */ stop_immediate_propagation),\n/* harmony export */   stop_propagation: () => (/* binding */ stop_propagation),\n/* harmony export */   subscribe: () => (/* binding */ subscribe),\n/* harmony export */   svg_element: () => (/* binding */ svg_element),\n/* harmony export */   text: () => (/* binding */ text),\n/* harmony export */   tick: () => (/* binding */ tick),\n/* harmony export */   time_ranges_to_array: () => (/* binding */ time_ranges_to_array),\n/* harmony export */   to_number: () => (/* binding */ to_number),\n/* harmony export */   toggle_class: () => (/* binding */ toggle_class),\n/* harmony export */   transition_in: () => (/* binding */ transition_in),\n/* harmony export */   transition_out: () => (/* binding */ transition_out),\n/* harmony export */   trusted: () => (/* binding */ trusted),\n/* harmony export */   update_await_block_branch: () => (/* binding */ update_await_block_branch),\n/* harmony export */   update_keyed_each: () => (/* binding */ update_keyed_each),\n/* harmony export */   update_slot: () => (/* binding */ update_slot),\n/* harmony export */   update_slot_base: () => (/* binding */ update_slot_base),\n/* harmony export */   validate_component: () => (/* binding */ validate_component),\n/* harmony export */   validate_dynamic_element: () => (/* binding */ validate_dynamic_element),\n/* harmony export */   validate_each_argument: () => (/* binding */ validate_each_argument),\n/* harmony export */   validate_each_keys: () => (/* binding */ validate_each_keys),\n/* harmony export */   validate_slots: () => (/* binding */ validate_slots),\n/* harmony export */   validate_store: () => (/* binding */ validate_store),\n/* harmony export */   validate_void_dynamic_element: () => (/* binding */ validate_void_dynamic_element),\n/* harmony export */   xlink_attr: () => (/* binding */ xlink_attr)\n/* harmony export */ });\nfunction noop() { }\nconst identity = x => x;\nfunction assign(tar, src) {\n    // @ts-ignore\n    for (const k in src)\n        tar[k] = src[k];\n    return tar;\n}\n// Adapted from https://github.com/then/is-promise/blob/master/index.js\n// Distributed under MIT License https://github.com/then/is-promise/blob/master/LICENSE\nfunction is_promise(value) {\n    return !!value && (typeof value === 'object' || typeof value === 'function') && typeof value.then === 'function';\n}\nfunction add_location(element, file, line, column, char) {\n    element.__svelte_meta = {\n        loc: { file, line, column, char }\n    };\n}\nfunction run(fn) {\n    return fn();\n}\nfunction blank_object() {\n    return Object.create(null);\n}\nfunction run_all(fns) {\n    fns.forEach(run);\n}\nfunction is_function(thing) {\n    return typeof thing === 'function';\n}\nfunction safe_not_equal(a, b) {\n    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');\n}\nlet src_url_equal_anchor;\nfunction src_url_equal(element_src, url) {\n    if (!src_url_equal_anchor) {\n        src_url_equal_anchor = document.createElement('a');\n    }\n    src_url_equal_anchor.href = url;\n    return element_src === src_url_equal_anchor.href;\n}\nfunction not_equal(a, b) {\n    return a != a ? b == b : a !== b;\n}\nfunction is_empty(obj) {\n    return Object.keys(obj).length === 0;\n}\nfunction validate_store(store, name) {\n    if (store != null && typeof store.subscribe !== 'function') {\n        throw new Error(`'${name}' is not a store with a 'subscribe' method`);\n    }\n}\nfunction subscribe(store, ...callbacks) {\n    if (store == null) {\n        return noop;\n    }\n    const unsub = store.subscribe(...callbacks);\n    return unsub.unsubscribe ? () => unsub.unsubscribe() : unsub;\n}\nfunction get_store_value(store) {\n    let value;\n    subscribe(store, _ => value = _)();\n    return value;\n}\nfunction component_subscribe(component, store, callback) {\n    component.$$.on_destroy.push(subscribe(store, callback));\n}\nfunction create_slot(definition, ctx, $$scope, fn) {\n    if (definition) {\n        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);\n        return definition[0](slot_ctx);\n    }\n}\nfunction get_slot_context(definition, ctx, $$scope, fn) {\n    return definition[1] && fn\n        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))\n        : $$scope.ctx;\n}\nfunction get_slot_changes(definition, $$scope, dirty, fn) {\n    if (definition[2] && fn) {\n        const lets = definition[2](fn(dirty));\n        if ($$scope.dirty === undefined) {\n            return lets;\n        }\n        if (typeof lets === 'object') {\n            const merged = [];\n            const len = Math.max($$scope.dirty.length, lets.length);\n            for (let i = 0; i < len; i += 1) {\n                merged[i] = $$scope.dirty[i] | lets[i];\n            }\n            return merged;\n        }\n        return $$scope.dirty | lets;\n    }\n    return $$scope.dirty;\n}\nfunction update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {\n    if (slot_changes) {\n        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);\n        slot.p(slot_context, slot_changes);\n    }\n}\nfunction update_slot(slot, slot_definition, ctx, $$scope, dirty, get_slot_changes_fn, get_slot_context_fn) {\n    const slot_changes = get_slot_changes(slot_definition, $$scope, dirty, get_slot_changes_fn);\n    update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn);\n}\nfunction get_all_dirty_from_scope($$scope) {\n    if ($$scope.ctx.length > 32) {\n        const dirty = [];\n        const length = $$scope.ctx.length / 32;\n        for (let i = 0; i < length; i++) {\n            dirty[i] = -1;\n        }\n        return dirty;\n    }\n    return -1;\n}\nfunction exclude_internal_props(props) {\n    const result = {};\n    for (const k in props)\n        if (k[0] !== '$')\n            result[k] = props[k];\n    return result;\n}\nfunction compute_rest_props(props, keys) {\n    const rest = {};\n    keys = new Set(keys);\n    for (const k in props)\n        if (!keys.has(k) && k[0] !== '$')\n            rest[k] = props[k];\n    return rest;\n}\nfunction compute_slots(slots) {\n    const result = {};\n    for (const key in slots) {\n        result[key] = true;\n    }\n    return result;\n}\nfunction once(fn) {\n    let ran = false;\n    return function (...args) {\n        if (ran)\n            return;\n        ran = true;\n        fn.call(this, ...args);\n    };\n}\nfunction null_to_empty(value) {\n    return value == null ? '' : value;\n}\nfunction set_store_value(store, ret, value) {\n    store.set(value);\n    return ret;\n}\nconst has_prop = (obj, prop) => Object.prototype.hasOwnProperty.call(obj, prop);\nfunction action_destroyer(action_result) {\n    return action_result && is_function(action_result.destroy) ? action_result.destroy : noop;\n}\nfunction split_css_unit(value) {\n    const split = typeof value === 'string' && value.match(/^\\s*(-?[\\d.]+)([^\\s]*)\\s*$/);\n    return split ? [parseFloat(split[1]), split[2] || 'px'] : [value, 'px'];\n}\nconst contenteditable_truthy_values = ['', true, 1, 'true', 'contenteditable'];\n\nconst is_client = typeof window !== 'undefined';\nlet now = is_client\n    ? () => window.performance.now()\n    : () => Date.now();\nlet raf = is_client ? cb => requestAnimationFrame(cb) : noop;\n// used internally for testing\nfunction set_now(fn) {\n    now = fn;\n}\nfunction set_raf(fn) {\n    raf = fn;\n}\n\nconst tasks = new Set();\nfunction run_tasks(now) {\n    tasks.forEach(task => {\n        if (!task.c(now)) {\n            tasks.delete(task);\n            task.f();\n        }\n    });\n    if (tasks.size !== 0)\n        raf(run_tasks);\n}\n/**\n * For testing purposes only!\n */\nfunction clear_loops() {\n    tasks.clear();\n}\n/**\n * Creates a new task that runs on each raf frame\n * until it returns a falsy value or is aborted\n */\nfunction loop(callback) {\n    let task;\n    if (tasks.size === 0)\n        raf(run_tasks);\n    return {\n        promise: new Promise(fulfill => {\n            tasks.add(task = { c: callback, f: fulfill });\n        }),\n        abort() {\n            tasks.delete(task);\n        }\n    };\n}\n\nconst globals = (typeof window !== 'undefined'\n    ? window\n    : typeof globalThis !== 'undefined'\n        ? globalThis\n        : global);\n\n/**\n * Resize observer singleton.\n * One listener per element only!\n * https://groups.google.com/a/chromium.org/g/blink-dev/c/z6ienONUb5A/m/F5-VcUZtBAAJ\n */\nclass ResizeObserverSingleton {\n    constructor(options) {\n        this.options = options;\n        this._listeners = 'WeakMap' in globals ? new WeakMap() : undefined;\n    }\n    observe(element, listener) {\n        this._listeners.set(element, listener);\n        this._getObserver().observe(element, this.options);\n        return () => {\n            this._listeners.delete(element);\n            this._observer.unobserve(element); // this line can probably be removed\n        };\n    }\n    _getObserver() {\n        var _a;\n        return (_a = this._observer) !== null && _a !== void 0 ? _a : (this._observer = new ResizeObserver((entries) => {\n            var _a;\n            for (const entry of entries) {\n                ResizeObserverSingleton.entries.set(entry.target, entry);\n                (_a = this._listeners.get(entry.target)) === null || _a === void 0 ? void 0 : _a(entry);\n            }\n        }));\n    }\n}\n// Needs to be written like this to pass the tree-shake-test\nResizeObserverSingleton.entries = 'WeakMap' in globals ? new WeakMap() : undefined;\n\n// Track which nodes are claimed during hydration. Unclaimed nodes can then be removed from the DOM\n// at the end of hydration without touching the remaining nodes.\nlet is_hydrating = false;\nfunction start_hydrating() {\n    is_hydrating = true;\n}\nfunction end_hydrating() {\n    is_hydrating = false;\n}\nfunction upper_bound(low, high, key, value) {\n    // Return first index of value larger than input value in the range [low, high)\n    while (low < high) {\n        const mid = low + ((high - low) >> 1);\n        if (key(mid) <= value) {\n            low = mid + 1;\n        }\n        else {\n            high = mid;\n        }\n    }\n    return low;\n}\nfunction init_hydrate(target) {\n    if (target.hydrate_init)\n        return;\n    target.hydrate_init = true;\n    // We know that all children have claim_order values since the unclaimed have been detached if target is not <head>\n    let children = target.childNodes;\n    // If target is <head>, there may be children without claim_order\n    if (target.nodeName === 'HEAD') {\n        const myChildren = [];\n        for (let i = 0; i < children.length; i++) {\n            const node = children[i];\n            if (node.claim_order !== undefined) {\n                myChildren.push(node);\n            }\n        }\n        children = myChildren;\n    }\n    /*\n    * Reorder claimed children optimally.\n    * We can reorder claimed children optimally by finding the longest subsequence of\n    * nodes that are already claimed in order and only moving the rest. The longest\n    * subsequence of nodes that are claimed in order can be found by\n    * computing the longest increasing subsequence of .claim_order values.\n    *\n    * This algorithm is optimal in generating the least amount of reorder operations\n    * possible.\n    *\n    * Proof:\n    * We know that, given a set of reordering operations, the nodes that do not move\n    * always form an increasing subsequence, since they do not move among each other\n    * meaning that they must be already ordered among each other. Thus, the maximal\n    * set of nodes that do not move form a longest increasing subsequence.\n    */\n    // Compute longest increasing subsequence\n    // m: subsequence length j => index k of smallest value that ends an increasing subsequence of length j\n    const m = new Int32Array(children.length + 1);\n    // Predecessor indices + 1\n    const p = new Int32Array(children.length);\n    m[0] = -1;\n    let longest = 0;\n    for (let i = 0; i < children.length; i++) {\n        const current = children[i].claim_order;\n        // Find the largest subsequence length such that it ends in a value less than our current value\n        // upper_bound returns first greater value, so we subtract one\n        // with fast path for when we are on the current longest subsequence\n        const seqLen = ((longest > 0 && children[m[longest]].claim_order <= current) ? longest + 1 : upper_bound(1, longest, idx => children[m[idx]].claim_order, current)) - 1;\n        p[i] = m[seqLen] + 1;\n        const newLen = seqLen + 1;\n        // We can guarantee that current is the smallest value. Otherwise, we would have generated a longer sequence.\n        m[newLen] = i;\n        longest = Math.max(newLen, longest);\n    }\n    // The longest increasing subsequence of nodes (initially reversed)\n    const lis = [];\n    // The rest of the nodes, nodes that will be moved\n    const toMove = [];\n    let last = children.length - 1;\n    for (let cur = m[longest] + 1; cur != 0; cur = p[cur - 1]) {\n        lis.push(children[cur - 1]);\n        for (; last >= cur; last--) {\n            toMove.push(children[last]);\n        }\n        last--;\n    }\n    for (; last >= 0; last--) {\n        toMove.push(children[last]);\n    }\n    lis.reverse();\n    // We sort the nodes being moved to guarantee that their insertion order matches the claim order\n    toMove.sort((a, b) => a.claim_order - b.claim_order);\n    // Finally, we move the nodes\n    for (let i = 0, j = 0; i < toMove.length; i++) {\n        while (j < lis.length && toMove[i].claim_order >= lis[j].claim_order) {\n            j++;\n        }\n        const anchor = j < lis.length ? lis[j] : null;\n        target.insertBefore(toMove[i], anchor);\n    }\n}\nfunction append(target, node) {\n    target.appendChild(node);\n}\nfunction append_styles(target, style_sheet_id, styles) {\n    const append_styles_to = get_root_for_style(target);\n    if (!append_styles_to.getElementById(style_sheet_id)) {\n        const style = element('style');\n        style.id = style_sheet_id;\n        style.textContent = styles;\n        append_stylesheet(append_styles_to, style);\n    }\n}\nfunction get_root_for_style(node) {\n    if (!node)\n        return document;\n    const root = node.getRootNode ? node.getRootNode() : node.ownerDocument;\n    if (root && root.host) {\n        return root;\n    }\n    return node.ownerDocument;\n}\nfunction append_empty_stylesheet(node) {\n    const style_element = element('style');\n    append_stylesheet(get_root_for_style(node), style_element);\n    return style_element.sheet;\n}\nfunction append_stylesheet(node, style) {\n    append(node.head || node, style);\n    return style.sheet;\n}\nfunction append_hydration(target, node) {\n    if (is_hydrating) {\n        init_hydrate(target);\n        if ((target.actual_end_child === undefined) || ((target.actual_end_child !== null) && (target.actual_end_child.parentNode !== target))) {\n            target.actual_end_child = target.firstChild;\n        }\n        // Skip nodes of undefined ordering\n        while ((target.actual_end_child !== null) && (target.actual_end_child.claim_order === undefined)) {\n            target.actual_end_child = target.actual_end_child.nextSibling;\n        }\n        if (node !== target.actual_end_child) {\n            // We only insert if the ordering of this node should be modified or the parent node is not target\n            if (node.claim_order !== undefined || node.parentNode !== target) {\n                target.insertBefore(node, target.actual_end_child);\n            }\n        }\n        else {\n            target.actual_end_child = node.nextSibling;\n        }\n    }\n    else if (node.parentNode !== target || node.nextSibling !== null) {\n        target.appendChild(node);\n    }\n}\nfunction insert(target, node, anchor) {\n    target.insertBefore(node, anchor || null);\n}\nfunction insert_hydration(target, node, anchor) {\n    if (is_hydrating && !anchor) {\n        append_hydration(target, node);\n    }\n    else if (node.parentNode !== target || node.nextSibling != anchor) {\n        target.insertBefore(node, anchor || null);\n    }\n}\nfunction detach(node) {\n    if (node.parentNode) {\n        node.parentNode.removeChild(node);\n    }\n}\nfunction destroy_each(iterations, detaching) {\n    for (let i = 0; i < iterations.length; i += 1) {\n        if (iterations[i])\n            iterations[i].d(detaching);\n    }\n}\nfunction element(name) {\n    return document.createElement(name);\n}\nfunction element_is(name, is) {\n    return document.createElement(name, { is });\n}\nfunction object_without_properties(obj, exclude) {\n    const target = {};\n    for (const k in obj) {\n        if (has_prop(obj, k)\n            // @ts-ignore\n            && exclude.indexOf(k) === -1) {\n            // @ts-ignore\n            target[k] = obj[k];\n        }\n    }\n    return target;\n}\nfunction svg_element(name) {\n    return document.createElementNS('http://www.w3.org/2000/svg', name);\n}\nfunction text(data) {\n    return document.createTextNode(data);\n}\nfunction space() {\n    return text(' ');\n}\nfunction empty() {\n    return text('');\n}\nfunction comment(content) {\n    return document.createComment(content);\n}\nfunction listen(node, event, handler, options) {\n    node.addEventListener(event, handler, options);\n    return () => node.removeEventListener(event, handler, options);\n}\nfunction prevent_default(fn) {\n    return function (event) {\n        event.preventDefault();\n        // @ts-ignore\n        return fn.call(this, event);\n    };\n}\nfunction stop_propagation(fn) {\n    return function (event) {\n        event.stopPropagation();\n        // @ts-ignore\n        return fn.call(this, event);\n    };\n}\nfunction stop_immediate_propagation(fn) {\n    return function (event) {\n        event.stopImmediatePropagation();\n        // @ts-ignore\n        return fn.call(this, event);\n    };\n}\nfunction self(fn) {\n    return function (event) {\n        // @ts-ignore\n        if (event.target === this)\n            fn.call(this, event);\n    };\n}\nfunction trusted(fn) {\n    return function (event) {\n        // @ts-ignore\n        if (event.isTrusted)\n            fn.call(this, event);\n    };\n}\nfunction attr(node, attribute, value) {\n    if (value == null)\n        node.removeAttribute(attribute);\n    else if (node.getAttribute(attribute) !== value)\n        node.setAttribute(attribute, value);\n}\n/**\n * List of attributes that should always be set through the attr method,\n * because updating them through the property setter doesn't work reliably.\n * In the example of `width`/`height`, the problem is that the setter only\n * accepts numeric values, but the attribute can also be set to a string like `50%`.\n * If this list becomes too big, rethink this approach.\n */\nconst always_set_through_set_attribute = ['width', 'height'];\nfunction set_attributes(node, attributes) {\n    // @ts-ignore\n    const descriptors = Object.getOwnPropertyDescriptors(node.__proto__);\n    for (const key in attributes) {\n        if (attributes[key] == null) {\n            node.removeAttribute(key);\n        }\n        else if (key === 'style') {\n            node.style.cssText = attributes[key];\n        }\n        else if (key === '__value') {\n            node.value = node[key] = attributes[key];\n        }\n        else if (descriptors[key] && descriptors[key].set && always_set_through_set_attribute.indexOf(key) === -1) {\n            node[key] = attributes[key];\n        }\n        else {\n            attr(node, key, attributes[key]);\n        }\n    }\n}\nfunction set_svg_attributes(node, attributes) {\n    for (const key in attributes) {\n        attr(node, key, attributes[key]);\n    }\n}\nfunction set_custom_element_data_map(node, data_map) {\n    Object.keys(data_map).forEach((key) => {\n        set_custom_element_data(node, key, data_map[key]);\n    });\n}\nfunction set_custom_element_data(node, prop, value) {\n    if (prop in node) {\n        node[prop] = typeof node[prop] === 'boolean' && value === '' ? true : value;\n    }\n    else {\n        attr(node, prop, value);\n    }\n}\nfunction set_dynamic_element_data(tag) {\n    return (/-/.test(tag)) ? set_custom_element_data_map : set_attributes;\n}\nfunction xlink_attr(node, attribute, value) {\n    node.setAttributeNS('http://www.w3.org/1999/xlink', attribute, value);\n}\nfunction get_binding_group_value(group, __value, checked) {\n    const value = new Set();\n    for (let i = 0; i < group.length; i += 1) {\n        if (group[i].checked)\n            value.add(group[i].__value);\n    }\n    if (!checked) {\n        value.delete(__value);\n    }\n    return Array.from(value);\n}\nfunction init_binding_group(group) {\n    let _inputs;\n    return {\n        /* push */ p(...inputs) {\n            _inputs = inputs;\n            _inputs.forEach(input => group.push(input));\n        },\n        /* remove */ r() {\n            _inputs.forEach(input => group.splice(group.indexOf(input), 1));\n        }\n    };\n}\nfunction init_binding_group_dynamic(group, indexes) {\n    let _group = get_binding_group(group);\n    let _inputs;\n    function get_binding_group(group) {\n        for (let i = 0; i < indexes.length; i++) {\n            group = group[indexes[i]] = group[indexes[i]] || [];\n        }\n        return group;\n    }\n    function push() {\n        _inputs.forEach(input => _group.push(input));\n    }\n    function remove() {\n        _inputs.forEach(input => _group.splice(_group.indexOf(input), 1));\n    }\n    return {\n        /* update */ u(new_indexes) {\n            indexes = new_indexes;\n            const new_group = get_binding_group(group);\n            if (new_group !== _group) {\n                remove();\n                _group = new_group;\n                push();\n            }\n        },\n        /* push */ p(...inputs) {\n            _inputs = inputs;\n            push();\n        },\n        /* remove */ r: remove\n    };\n}\nfunction to_number(value) {\n    return value === '' ? null : +value;\n}\nfunction time_ranges_to_array(ranges) {\n    const array = [];\n    for (let i = 0; i < ranges.length; i += 1) {\n        array.push({ start: ranges.start(i), end: ranges.end(i) });\n    }\n    return array;\n}\nfunction children(element) {\n    return Array.from(element.childNodes);\n}\nfunction init_claim_info(nodes) {\n    if (nodes.claim_info === undefined) {\n        nodes.claim_info = { last_index: 0, total_claimed: 0 };\n    }\n}\nfunction claim_node(nodes, predicate, processNode, createNode, dontUpdateLastIndex = false) {\n    // Try to find nodes in an order such that we lengthen the longest increasing subsequence\n    init_claim_info(nodes);\n    const resultNode = (() => {\n        // We first try to find an element after the previous one\n        for (let i = nodes.claim_info.last_index; i < nodes.length; i++) {\n            const node = nodes[i];\n            if (predicate(node)) {\n                const replacement = processNode(node);\n                if (replacement === undefined) {\n                    nodes.splice(i, 1);\n                }\n                else {\n                    nodes[i] = replacement;\n                }\n                if (!dontUpdateLastIndex) {\n                    nodes.claim_info.last_index = i;\n                }\n                return node;\n            }\n        }\n        // Otherwise, we try to find one before\n        // We iterate in reverse so that we don't go too far back\n        for (let i = nodes.claim_info.last_index - 1; i >= 0; i--) {\n            const node = nodes[i];\n            if (predicate(node)) {\n                const replacement = processNode(node);\n                if (replacement === undefined) {\n                    nodes.splice(i, 1);\n                }\n                else {\n                    nodes[i] = replacement;\n                }\n                if (!dontUpdateLastIndex) {\n                    nodes.claim_info.last_index = i;\n                }\n                else if (replacement === undefined) {\n                    // Since we spliced before the last_index, we decrease it\n                    nodes.claim_info.last_index--;\n                }\n                return node;\n            }\n        }\n        // If we can't find any matching node, we create a new one\n        return createNode();\n    })();\n    resultNode.claim_order = nodes.claim_info.total_claimed;\n    nodes.claim_info.total_claimed += 1;\n    return resultNode;\n}\nfunction claim_element_base(nodes, name, attributes, create_element) {\n    return claim_node(nodes, (node) => node.nodeName === name, (node) => {\n        const remove = [];\n        for (let j = 0; j < node.attributes.length; j++) {\n            const attribute = node.attributes[j];\n            if (!attributes[attribute.name]) {\n                remove.push(attribute.name);\n            }\n        }\n        remove.forEach(v => node.removeAttribute(v));\n        return undefined;\n    }, () => create_element(name));\n}\nfunction claim_element(nodes, name, attributes) {\n    return claim_element_base(nodes, name, attributes, element);\n}\nfunction claim_svg_element(nodes, name, attributes) {\n    return claim_element_base(nodes, name, attributes, svg_element);\n}\nfunction claim_text(nodes, data) {\n    return claim_node(nodes, (node) => node.nodeType === 3, (node) => {\n        const dataStr = '' + data;\n        if (node.data.startsWith(dataStr)) {\n            if (node.data.length !== dataStr.length) {\n                return node.splitText(dataStr.length);\n            }\n        }\n        else {\n            node.data = dataStr;\n        }\n    }, () => text(data), true // Text nodes should not update last index since it is likely not worth it to eliminate an increasing subsequence of actual elements\n    );\n}\nfunction claim_space(nodes) {\n    return claim_text(nodes, ' ');\n}\nfunction claim_comment(nodes, data) {\n    return claim_node(nodes, (node) => node.nodeType === 8, (node) => {\n        node.data = '' + data;\n        return undefined;\n    }, () => comment(data), true);\n}\nfunction find_comment(nodes, text, start) {\n    for (let i = start; i < nodes.length; i += 1) {\n        const node = nodes[i];\n        if (node.nodeType === 8 /* comment node */ && node.textContent.trim() === text) {\n            return i;\n        }\n    }\n    return nodes.length;\n}\nfunction claim_html_tag(nodes, is_svg) {\n    // find html opening tag\n    const start_index = find_comment(nodes, 'HTML_TAG_START', 0);\n    const end_index = find_comment(nodes, 'HTML_TAG_END', start_index);\n    if (start_index === end_index) {\n        return new HtmlTagHydration(undefined, is_svg);\n    }\n    init_claim_info(nodes);\n    const html_tag_nodes = nodes.splice(start_index, end_index - start_index + 1);\n    detach(html_tag_nodes[0]);\n    detach(html_tag_nodes[html_tag_nodes.length - 1]);\n    const claimed_nodes = html_tag_nodes.slice(1, html_tag_nodes.length - 1);\n    for (const n of claimed_nodes) {\n        n.claim_order = nodes.claim_info.total_claimed;\n        nodes.claim_info.total_claimed += 1;\n    }\n    return new HtmlTagHydration(claimed_nodes, is_svg);\n}\nfunction set_data(text, data) {\n    data = '' + data;\n    if (text.data === data)\n        return;\n    text.data = data;\n}\nfunction set_data_contenteditable(text, data) {\n    data = '' + data;\n    if (text.wholeText === data)\n        return;\n    text.data = data;\n}\nfunction set_data_maybe_contenteditable(text, data, attr_value) {\n    if (~contenteditable_truthy_values.indexOf(attr_value)) {\n        set_data_contenteditable(text, data);\n    }\n    else {\n        set_data(text, data);\n    }\n}\nfunction set_input_value(input, value) {\n    input.value = value == null ? '' : value;\n}\nfunction set_input_type(input, type) {\n    try {\n        input.type = type;\n    }\n    catch (e) {\n        // do nothing\n    }\n}\nfunction set_style(node, key, value, important) {\n    if (value == null) {\n        node.style.removeProperty(key);\n    }\n    else {\n        node.style.setProperty(key, value, important ? 'important' : '');\n    }\n}\nfunction select_option(select, value, mounting) {\n    for (let i = 0; i < select.options.length; i += 1) {\n        const option = select.options[i];\n        if (option.__value === value) {\n            option.selected = true;\n            return;\n        }\n    }\n    if (!mounting || value !== undefined) {\n        select.selectedIndex = -1; // no option should be selected\n    }\n}\nfunction select_options(select, value) {\n    for (let i = 0; i < select.options.length; i += 1) {\n        const option = select.options[i];\n        option.selected = ~value.indexOf(option.__value);\n    }\n}\nfunction select_value(select) {\n    const selected_option = select.querySelector(':checked');\n    return selected_option && selected_option.__value;\n}\nfunction select_multiple_value(select) {\n    return [].map.call(select.querySelectorAll(':checked'), option => option.__value);\n}\n// unfortunately this can't be a constant as that wouldn't be tree-shakeable\n// so we cache the result instead\nlet crossorigin;\nfunction is_crossorigin() {\n    if (crossorigin === undefined) {\n        crossorigin = false;\n        try {\n            if (typeof window !== 'undefined' && window.parent) {\n                void window.parent.document;\n            }\n        }\n        catch (error) {\n            crossorigin = true;\n        }\n    }\n    return crossorigin;\n}\nfunction add_iframe_resize_listener(node, fn) {\n    const computed_style = getComputedStyle(node);\n    if (computed_style.position === 'static') {\n        node.style.position = 'relative';\n    }\n    const iframe = element('iframe');\n    iframe.setAttribute('style', 'display: block; position: absolute; top: 0; left: 0; width: 100%; height: 100%; ' +\n        'overflow: hidden; border: 0; opacity: 0; pointer-events: none; z-index: -1;');\n    iframe.setAttribute('aria-hidden', 'true');\n    iframe.tabIndex = -1;\n    const crossorigin = is_crossorigin();\n    let unsubscribe;\n    if (crossorigin) {\n        iframe.src = \"data:text/html,<script>onresize=function(){parent.postMessage(0,'*')}</script>\";\n        unsubscribe = listen(window, 'message', (event) => {\n            if (event.source === iframe.contentWindow)\n                fn();\n        });\n    }\n    else {\n        iframe.src = 'about:blank';\n        iframe.onload = () => {\n            unsubscribe = listen(iframe.contentWindow, 'resize', fn);\n            // make sure an initial resize event is fired _after_ the iframe is loaded (which is asynchronous)\n            // see https://github.com/sveltejs/svelte/issues/4233\n            fn();\n        };\n    }\n    append(node, iframe);\n    return () => {\n        if (crossorigin) {\n            unsubscribe();\n        }\n        else if (unsubscribe && iframe.contentWindow) {\n            unsubscribe();\n        }\n        detach(iframe);\n    };\n}\nconst resize_observer_content_box = /* @__PURE__ */ new ResizeObserverSingleton({ box: 'content-box' });\nconst resize_observer_border_box = /* @__PURE__ */ new ResizeObserverSingleton({ box: 'border-box' });\nconst resize_observer_device_pixel_content_box = /* @__PURE__ */ new ResizeObserverSingleton({ box: 'device-pixel-content-box' });\nfunction toggle_class(element, name, toggle) {\n    element.classList[toggle ? 'add' : 'remove'](name);\n}\nfunction custom_event(type, detail, { bubbles = false, cancelable = false } = {}) {\n    const e = document.createEvent('CustomEvent');\n    e.initCustomEvent(type, bubbles, cancelable, detail);\n    return e;\n}\nfunction query_selector_all(selector, parent = document.body) {\n    return Array.from(parent.querySelectorAll(selector));\n}\nfunction head_selector(nodeId, head) {\n    const result = [];\n    let started = 0;\n    for (const node of head.childNodes) {\n        if (node.nodeType === 8 /* comment node */) {\n            const comment = node.textContent.trim();\n            if (comment === `HEAD_${nodeId}_END`) {\n                started -= 1;\n                result.push(node);\n            }\n            else if (comment === `HEAD_${nodeId}_START`) {\n                started += 1;\n                result.push(node);\n            }\n        }\n        else if (started > 0) {\n            result.push(node);\n        }\n    }\n    return result;\n}\nclass HtmlTag {\n    constructor(is_svg = false) {\n        this.is_svg = false;\n        this.is_svg = is_svg;\n        this.e = this.n = null;\n    }\n    c(html) {\n        this.h(html);\n    }\n    m(html, target, anchor = null) {\n        if (!this.e) {\n            if (this.is_svg)\n                this.e = svg_element(target.nodeName);\n            /** #7364  target for <template> may be provided as #document-fragment(11) */\n            else\n                this.e = element((target.nodeType === 11 ? 'TEMPLATE' : target.nodeName));\n            this.t = target.tagName !== 'TEMPLATE' ? target : target.content;\n            this.c(html);\n        }\n        this.i(anchor);\n    }\n    h(html) {\n        this.e.innerHTML = html;\n        this.n = Array.from(this.e.nodeName === 'TEMPLATE' ? this.e.content.childNodes : this.e.childNodes);\n    }\n    i(anchor) {\n        for (let i = 0; i < this.n.length; i += 1) {\n            insert(this.t, this.n[i], anchor);\n        }\n    }\n    p(html) {\n        this.d();\n        this.h(html);\n        this.i(this.a);\n    }\n    d() {\n        this.n.forEach(detach);\n    }\n}\nclass HtmlTagHydration extends HtmlTag {\n    constructor(claimed_nodes, is_svg = false) {\n        super(is_svg);\n        this.e = this.n = null;\n        this.l = claimed_nodes;\n    }\n    c(html) {\n        if (this.l) {\n            this.n = this.l;\n        }\n        else {\n            super.c(html);\n        }\n    }\n    i(anchor) {\n        for (let i = 0; i < this.n.length; i += 1) {\n            insert_hydration(this.t, this.n[i], anchor);\n        }\n    }\n}\nfunction attribute_to_object(attributes) {\n    const result = {};\n    for (const attribute of attributes) {\n        result[attribute.name] = attribute.value;\n    }\n    return result;\n}\nfunction get_custom_elements_slots(element) {\n    const result = {};\n    element.childNodes.forEach((node) => {\n        result[node.slot || 'default'] = true;\n    });\n    return result;\n}\nfunction construct_svelte_component(component, props) {\n    return new component(props);\n}\n\n// we need to store the information for multiple documents because a Svelte application could also contain iframes\n// https://github.com/sveltejs/svelte/issues/3624\nconst managed_styles = new Map();\nlet active = 0;\n// https://github.com/darkskyapp/string-hash/blob/master/index.js\nfunction hash(str) {\n    let hash = 5381;\n    let i = str.length;\n    while (i--)\n        hash = ((hash << 5) - hash) ^ str.charCodeAt(i);\n    return hash >>> 0;\n}\nfunction create_style_information(doc, node) {\n    const info = { stylesheet: append_empty_stylesheet(node), rules: {} };\n    managed_styles.set(doc, info);\n    return info;\n}\nfunction create_rule(node, a, b, duration, delay, ease, fn, uid = 0) {\n    const step = 16.666 / duration;\n    let keyframes = '{\\n';\n    for (let p = 0; p <= 1; p += step) {\n        const t = a + (b - a) * ease(p);\n        keyframes += p * 100 + `%{${fn(t, 1 - t)}}\\n`;\n    }\n    const rule = keyframes + `100% {${fn(b, 1 - b)}}\\n}`;\n    const name = `__svelte_${hash(rule)}_${uid}`;\n    const doc = get_root_for_style(node);\n    const { stylesheet, rules } = managed_styles.get(doc) || create_style_information(doc, node);\n    if (!rules[name]) {\n        rules[name] = true;\n        stylesheet.insertRule(`@keyframes ${name} ${rule}`, stylesheet.cssRules.length);\n    }\n    const animation = node.style.animation || '';\n    node.style.animation = `${animation ? `${animation}, ` : ''}${name} ${duration}ms linear ${delay}ms 1 both`;\n    active += 1;\n    return name;\n}\nfunction delete_rule(node, name) {\n    const previous = (node.style.animation || '').split(', ');\n    const next = previous.filter(name\n        ? anim => anim.indexOf(name) < 0 // remove specific animation\n        : anim => anim.indexOf('__svelte') === -1 // remove all Svelte animations\n    );\n    const deleted = previous.length - next.length;\n    if (deleted) {\n        node.style.animation = next.join(', ');\n        active -= deleted;\n        if (!active)\n            clear_rules();\n    }\n}\nfunction clear_rules() {\n    raf(() => {\n        if (active)\n            return;\n        managed_styles.forEach(info => {\n            const { ownerNode } = info.stylesheet;\n            // there is no ownerNode if it runs on jsdom.\n            if (ownerNode)\n                detach(ownerNode);\n        });\n        managed_styles.clear();\n    });\n}\n\nfunction create_animation(node, from, fn, params) {\n    if (!from)\n        return noop;\n    const to = node.getBoundingClientRect();\n    if (from.left === to.left && from.right === to.right && from.top === to.top && from.bottom === to.bottom)\n        return noop;\n    const { delay = 0, duration = 300, easing = identity, \n    // @ts-ignore todo: should this be separated from destructuring? Or start/end added to public api and documentation?\n    start: start_time = now() + delay, \n    // @ts-ignore todo:\n    end = start_time + duration, tick = noop, css } = fn(node, { from, to }, params);\n    let running = true;\n    let started = false;\n    let name;\n    function start() {\n        if (css) {\n            name = create_rule(node, 0, 1, duration, delay, easing, css);\n        }\n        if (!delay) {\n            started = true;\n        }\n    }\n    function stop() {\n        if (css)\n            delete_rule(node, name);\n        running = false;\n    }\n    loop(now => {\n        if (!started && now >= start_time) {\n            started = true;\n        }\n        if (started && now >= end) {\n            tick(1, 0);\n            stop();\n        }\n        if (!running) {\n            return false;\n        }\n        if (started) {\n            const p = now - start_time;\n            const t = 0 + 1 * easing(p / duration);\n            tick(t, 1 - t);\n        }\n        return true;\n    });\n    start();\n    tick(0, 1);\n    return stop;\n}\nfunction fix_position(node) {\n    const style = getComputedStyle(node);\n    if (style.position !== 'absolute' && style.position !== 'fixed') {\n        const { width, height } = style;\n        const a = node.getBoundingClientRect();\n        node.style.position = 'absolute';\n        node.style.width = width;\n        node.style.height = height;\n        add_transform(node, a);\n    }\n}\nfunction add_transform(node, a) {\n    const b = node.getBoundingClientRect();\n    if (a.left !== b.left || a.top !== b.top) {\n        const style = getComputedStyle(node);\n        const transform = style.transform === 'none' ? '' : style.transform;\n        node.style.transform = `${transform} translate(${a.left - b.left}px, ${a.top - b.top}px)`;\n    }\n}\n\nlet current_component;\nfunction set_current_component(component) {\n    current_component = component;\n}\nfunction get_current_component() {\n    if (!current_component)\n        throw new Error('Function called outside component initialization');\n    return current_component;\n}\n/**\n * Schedules a callback to run immediately before the component is updated after any state change.\n *\n * The first time the callback runs will be before the initial `onMount`\n *\n * https://svelte.dev/docs#run-time-svelte-beforeupdate\n */\nfunction beforeUpdate(fn) {\n    get_current_component().$$.before_update.push(fn);\n}\n/**\n * The `onMount` function schedules a callback to run as soon as the component has been mounted to the DOM.\n * It must be called during the component's initialisation (but doesn't need to live *inside* the component;\n * it can be called from an external module).\n *\n * `onMount` does not run inside a [server-side component](/docs#run-time-server-side-component-api).\n *\n * https://svelte.dev/docs#run-time-svelte-onmount\n */\nfunction onMount(fn) {\n    get_current_component().$$.on_mount.push(fn);\n}\n/**\n * Schedules a callback to run immediately after the component has been updated.\n *\n * The first time the callback runs will be after the initial `onMount`\n */\nfunction afterUpdate(fn) {\n    get_current_component().$$.after_update.push(fn);\n}\n/**\n * Schedules a callback to run immediately before the component is unmounted.\n *\n * Out of `onMount`, `beforeUpdate`, `afterUpdate` and `onDestroy`, this is the\n * only one that runs inside a server-side component.\n *\n * https://svelte.dev/docs#run-time-svelte-ondestroy\n */\nfunction onDestroy(fn) {\n    get_current_component().$$.on_destroy.push(fn);\n}\n/**\n * Creates an event dispatcher that can be used to dispatch [component events](/docs#template-syntax-component-directives-on-eventname).\n * Event dispatchers are functions that can take two arguments: `name` and `detail`.\n *\n * Component events created with `createEventDispatcher` create a\n * [CustomEvent](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent).\n * These events do not [bubble](https://developer.mozilla.org/en-US/docs/Learn/JavaScript/Building_blocks/Events#Event_bubbling_and_capture).\n * The `detail` argument corresponds to the [CustomEvent.detail](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent/detail)\n * property and can contain any type of data.\n *\n * https://svelte.dev/docs#run-time-svelte-createeventdispatcher\n */\nfunction createEventDispatcher() {\n    const component = get_current_component();\n    return (type, detail, { cancelable = false } = {}) => {\n        const callbacks = component.$$.callbacks[type];\n        if (callbacks) {\n            // TODO are there situations where events could be dispatched\n            // in a server (non-DOM) environment?\n            const event = custom_event(type, detail, { cancelable });\n            callbacks.slice().forEach(fn => {\n                fn.call(component, event);\n            });\n            return !event.defaultPrevented;\n        }\n        return true;\n    };\n}\n/**\n * Associates an arbitrary `context` object with the current component and the specified `key`\n * and returns that object. The context is then available to children of the component\n * (including slotted content) with `getContext`.\n *\n * Like lifecycle functions, this must be called during component initialisation.\n *\n * https://svelte.dev/docs#run-time-svelte-setcontext\n */\nfunction setContext(key, context) {\n    get_current_component().$$.context.set(key, context);\n    return context;\n}\n/**\n * Retrieves the context that belongs to the closest parent component with the specified `key`.\n * Must be called during component initialisation.\n *\n * https://svelte.dev/docs#run-time-svelte-getcontext\n */\nfunction getContext(key) {\n    return get_current_component().$$.context.get(key);\n}\n/**\n * Retrieves the whole context map that belongs to the closest parent component.\n * Must be called during component initialisation. Useful, for example, if you\n * programmatically create a component and want to pass the existing context to it.\n *\n * https://svelte.dev/docs#run-time-svelte-getallcontexts\n */\nfunction getAllContexts() {\n    return get_current_component().$$.context;\n}\n/**\n * Checks whether a given `key` has been set in the context of a parent component.\n * Must be called during component initialisation.\n *\n * https://svelte.dev/docs#run-time-svelte-hascontext\n */\nfunction hasContext(key) {\n    return get_current_component().$$.context.has(key);\n}\n// TODO figure out if we still want to support\n// shorthand events, or if we want to implement\n// a real bubbling mechanism\nfunction bubble(component, event) {\n    const callbacks = component.$$.callbacks[event.type];\n    if (callbacks) {\n        // @ts-ignore\n        callbacks.slice().forEach(fn => fn.call(this, event));\n    }\n}\n\nconst dirty_components = [];\nconst intros = { enabled: false };\nconst binding_callbacks = [];\nlet render_callbacks = [];\nconst flush_callbacks = [];\nconst resolved_promise = /* @__PURE__ */ Promise.resolve();\nlet update_scheduled = false;\nfunction schedule_update() {\n    if (!update_scheduled) {\n        update_scheduled = true;\n        resolved_promise.then(flush);\n    }\n}\nfunction tick() {\n    schedule_update();\n    return resolved_promise;\n}\nfunction add_render_callback(fn) {\n    render_callbacks.push(fn);\n}\nfunction add_flush_callback(fn) {\n    flush_callbacks.push(fn);\n}\n// flush() calls callbacks in this order:\n// 1. All beforeUpdate callbacks, in order: parents before children\n// 2. All bind:this callbacks, in reverse order: children before parents.\n// 3. All afterUpdate callbacks, in order: parents before children. EXCEPT\n//    for afterUpdates called during the initial onMount, which are called in\n//    reverse order: children before parents.\n// Since callbacks might update component values, which could trigger another\n// call to flush(), the following steps guard against this:\n// 1. During beforeUpdate, any updated components will be added to the\n//    dirty_components array and will cause a reentrant call to flush(). Because\n//    the flush index is kept outside the function, the reentrant call will pick\n//    up where the earlier call left off and go through all dirty components. The\n//    current_component value is saved and restored so that the reentrant call will\n//    not interfere with the \"parent\" flush() call.\n// 2. bind:this callbacks cannot trigger new flush() calls.\n// 3. During afterUpdate, any updated components will NOT have their afterUpdate\n//    callback called a second time; the seen_callbacks set, outside the flush()\n//    function, guarantees this behavior.\nconst seen_callbacks = new Set();\nlet flushidx = 0; // Do *not* move this inside the flush() function\nfunction flush() {\n    // Do not reenter flush while dirty components are updated, as this can\n    // result in an infinite loop. Instead, let the inner flush handle it.\n    // Reentrancy is ok afterwards for bindings etc.\n    if (flushidx !== 0) {\n        return;\n    }\n    const saved_component = current_component;\n    do {\n        // first, call beforeUpdate functions\n        // and update components\n        try {\n            while (flushidx < dirty_components.length) {\n                const component = dirty_components[flushidx];\n                flushidx++;\n                set_current_component(component);\n                update(component.$$);\n            }\n        }\n        catch (e) {\n            // reset dirty state to not end up in a deadlocked state and then rethrow\n            dirty_components.length = 0;\n            flushidx = 0;\n            throw e;\n        }\n        set_current_component(null);\n        dirty_components.length = 0;\n        flushidx = 0;\n        while (binding_callbacks.length)\n            binding_callbacks.pop()();\n        // then, once components are updated, call\n        // afterUpdate functions. This may cause\n        // subsequent updates...\n        for (let i = 0; i < render_callbacks.length; i += 1) {\n            const callback = render_callbacks[i];\n            if (!seen_callbacks.has(callback)) {\n                // ...so guard against infinite loops\n                seen_callbacks.add(callback);\n                callback();\n            }\n        }\n        render_callbacks.length = 0;\n    } while (dirty_components.length);\n    while (flush_callbacks.length) {\n        flush_callbacks.pop()();\n    }\n    update_scheduled = false;\n    seen_callbacks.clear();\n    set_current_component(saved_component);\n}\nfunction update($$) {\n    if ($$.fragment !== null) {\n        $$.update();\n        run_all($$.before_update);\n        const dirty = $$.dirty;\n        $$.dirty = [-1];\n        $$.fragment && $$.fragment.p($$.ctx, dirty);\n        $$.after_update.forEach(add_render_callback);\n    }\n}\n/**\n * Useful for example to execute remaining `afterUpdate` callbacks before executing `destroy`.\n */\nfunction flush_render_callbacks(fns) {\n    const filtered = [];\n    const targets = [];\n    render_callbacks.forEach((c) => fns.indexOf(c) === -1 ? filtered.push(c) : targets.push(c));\n    targets.forEach((c) => c());\n    render_callbacks = filtered;\n}\n\nlet promise;\nfunction wait() {\n    if (!promise) {\n        promise = Promise.resolve();\n        promise.then(() => {\n            promise = null;\n        });\n    }\n    return promise;\n}\nfunction dispatch(node, direction, kind) {\n    node.dispatchEvent(custom_event(`${direction ? 'intro' : 'outro'}${kind}`));\n}\nconst outroing = new Set();\nlet outros;\nfunction group_outros() {\n    outros = {\n        r: 0,\n        c: [],\n        p: outros // parent group\n    };\n}\nfunction check_outros() {\n    if (!outros.r) {\n        run_all(outros.c);\n    }\n    outros = outros.p;\n}\nfunction transition_in(block, local) {\n    if (block && block.i) {\n        outroing.delete(block);\n        block.i(local);\n    }\n}\nfunction transition_out(block, local, detach, callback) {\n    if (block && block.o) {\n        if (outroing.has(block))\n            return;\n        outroing.add(block);\n        outros.c.push(() => {\n            outroing.delete(block);\n            if (callback) {\n                if (detach)\n                    block.d(1);\n                callback();\n            }\n        });\n        block.o(local);\n    }\n    else if (callback) {\n        callback();\n    }\n}\nconst null_transition = { duration: 0 };\nfunction create_in_transition(node, fn, params) {\n    const options = { direction: 'in' };\n    let config = fn(node, params, options);\n    let running = false;\n    let animation_name;\n    let task;\n    let uid = 0;\n    function cleanup() {\n        if (animation_name)\n            delete_rule(node, animation_name);\n    }\n    function go() {\n        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;\n        if (css)\n            animation_name = create_rule(node, 0, 1, duration, delay, easing, css, uid++);\n        tick(0, 1);\n        const start_time = now() + delay;\n        const end_time = start_time + duration;\n        if (task)\n            task.abort();\n        running = true;\n        add_render_callback(() => dispatch(node, true, 'start'));\n        task = loop(now => {\n            if (running) {\n                if (now >= end_time) {\n                    tick(1, 0);\n                    dispatch(node, true, 'end');\n                    cleanup();\n                    return running = false;\n                }\n                if (now >= start_time) {\n                    const t = easing((now - start_time) / duration);\n                    tick(t, 1 - t);\n                }\n            }\n            return running;\n        });\n    }\n    let started = false;\n    return {\n        start() {\n            if (started)\n                return;\n            started = true;\n            delete_rule(node);\n            if (is_function(config)) {\n                config = config(options);\n                wait().then(go);\n            }\n            else {\n                go();\n            }\n        },\n        invalidate() {\n            started = false;\n        },\n        end() {\n            if (running) {\n                cleanup();\n                running = false;\n            }\n        }\n    };\n}\nfunction create_out_transition(node, fn, params) {\n    const options = { direction: 'out' };\n    let config = fn(node, params, options);\n    let running = true;\n    let animation_name;\n    const group = outros;\n    group.r += 1;\n    function go() {\n        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;\n        if (css)\n            animation_name = create_rule(node, 1, 0, duration, delay, easing, css);\n        const start_time = now() + delay;\n        const end_time = start_time + duration;\n        add_render_callback(() => dispatch(node, false, 'start'));\n        loop(now => {\n            if (running) {\n                if (now >= end_time) {\n                    tick(0, 1);\n                    dispatch(node, false, 'end');\n                    if (!--group.r) {\n                        // this will result in `end()` being called,\n                        // so we don't need to clean up here\n                        run_all(group.c);\n                    }\n                    return false;\n                }\n                if (now >= start_time) {\n                    const t = easing((now - start_time) / duration);\n                    tick(1 - t, t);\n                }\n            }\n            return running;\n        });\n    }\n    if (is_function(config)) {\n        wait().then(() => {\n            // @ts-ignore\n            config = config(options);\n            go();\n        });\n    }\n    else {\n        go();\n    }\n    return {\n        end(reset) {\n            if (reset && config.tick) {\n                config.tick(1, 0);\n            }\n            if (running) {\n                if (animation_name)\n                    delete_rule(node, animation_name);\n                running = false;\n            }\n        }\n    };\n}\nfunction create_bidirectional_transition(node, fn, params, intro) {\n    const options = { direction: 'both' };\n    let config = fn(node, params, options);\n    let t = intro ? 0 : 1;\n    let running_program = null;\n    let pending_program = null;\n    let animation_name = null;\n    function clear_animation() {\n        if (animation_name)\n            delete_rule(node, animation_name);\n    }\n    function init(program, duration) {\n        const d = (program.b - t);\n        duration *= Math.abs(d);\n        return {\n            a: t,\n            b: program.b,\n            d,\n            duration,\n            start: program.start,\n            end: program.start + duration,\n            group: program.group\n        };\n    }\n    function go(b) {\n        const { delay = 0, duration = 300, easing = identity, tick = noop, css } = config || null_transition;\n        const program = {\n            start: now() + delay,\n            b\n        };\n        if (!b) {\n            // @ts-ignore todo: improve typings\n            program.group = outros;\n            outros.r += 1;\n        }\n        if (running_program || pending_program) {\n            pending_program = program;\n        }\n        else {\n            // if this is an intro, and there's a delay, we need to do\n            // an initial tick and/or apply CSS animation immediately\n            if (css) {\n                clear_animation();\n                animation_name = create_rule(node, t, b, duration, delay, easing, css);\n            }\n            if (b)\n                tick(0, 1);\n            running_program = init(program, duration);\n            add_render_callback(() => dispatch(node, b, 'start'));\n            loop(now => {\n                if (pending_program && now > pending_program.start) {\n                    running_program = init(pending_program, duration);\n                    pending_program = null;\n                    dispatch(node, running_program.b, 'start');\n                    if (css) {\n                        clear_animation();\n                        animation_name = create_rule(node, t, running_program.b, running_program.duration, 0, easing, config.css);\n                    }\n                }\n                if (running_program) {\n                    if (now >= running_program.end) {\n                        tick(t = running_program.b, 1 - t);\n                        dispatch(node, running_program.b, 'end');\n                        if (!pending_program) {\n                            // we're done\n                            if (running_program.b) {\n                                // intro — we can tidy up immediately\n                                clear_animation();\n                            }\n                            else {\n                                // outro — needs to be coordinated\n                                if (!--running_program.group.r)\n                                    run_all(running_program.group.c);\n                            }\n                        }\n                        running_program = null;\n                    }\n                    else if (now >= running_program.start) {\n                        const p = now - running_program.start;\n                        t = running_program.a + running_program.d * easing(p / running_program.duration);\n                        tick(t, 1 - t);\n                    }\n                }\n                return !!(running_program || pending_program);\n            });\n        }\n    }\n    return {\n        run(b) {\n            if (is_function(config)) {\n                wait().then(() => {\n                    // @ts-ignore\n                    config = config(options);\n                    go(b);\n                });\n            }\n            else {\n                go(b);\n            }\n        },\n        end() {\n            clear_animation();\n            running_program = pending_program = null;\n        }\n    };\n}\n\nfunction handle_promise(promise, info) {\n    const token = info.token = {};\n    function update(type, index, key, value) {\n        if (info.token !== token)\n            return;\n        info.resolved = value;\n        let child_ctx = info.ctx;\n        if (key !== undefined) {\n            child_ctx = child_ctx.slice();\n            child_ctx[key] = value;\n        }\n        const block = type && (info.current = type)(child_ctx);\n        let needs_flush = false;\n        if (info.block) {\n            if (info.blocks) {\n                info.blocks.forEach((block, i) => {\n                    if (i !== index && block) {\n                        group_outros();\n                        transition_out(block, 1, 1, () => {\n                            if (info.blocks[i] === block) {\n                                info.blocks[i] = null;\n                            }\n                        });\n                        check_outros();\n                    }\n                });\n            }\n            else {\n                info.block.d(1);\n            }\n            block.c();\n            transition_in(block, 1);\n            block.m(info.mount(), info.anchor);\n            needs_flush = true;\n        }\n        info.block = block;\n        if (info.blocks)\n            info.blocks[index] = block;\n        if (needs_flush) {\n            flush();\n        }\n    }\n    if (is_promise(promise)) {\n        const current_component = get_current_component();\n        promise.then(value => {\n            set_current_component(current_component);\n            update(info.then, 1, info.value, value);\n            set_current_component(null);\n        }, error => {\n            set_current_component(current_component);\n            update(info.catch, 2, info.error, error);\n            set_current_component(null);\n            if (!info.hasCatch) {\n                throw error;\n            }\n        });\n        // if we previously had a then/catch block, destroy it\n        if (info.current !== info.pending) {\n            update(info.pending, 0);\n            return true;\n        }\n    }\n    else {\n        if (info.current !== info.then) {\n            update(info.then, 1, info.value, promise);\n            return true;\n        }\n        info.resolved = promise;\n    }\n}\nfunction update_await_block_branch(info, ctx, dirty) {\n    const child_ctx = ctx.slice();\n    const { resolved } = info;\n    if (info.current === info.then) {\n        child_ctx[info.value] = resolved;\n    }\n    if (info.current === info.catch) {\n        child_ctx[info.error] = resolved;\n    }\n    info.block.p(child_ctx, dirty);\n}\n\nfunction destroy_block(block, lookup) {\n    block.d(1);\n    lookup.delete(block.key);\n}\nfunction outro_and_destroy_block(block, lookup) {\n    transition_out(block, 1, 1, () => {\n        lookup.delete(block.key);\n    });\n}\nfunction fix_and_destroy_block(block, lookup) {\n    block.f();\n    destroy_block(block, lookup);\n}\nfunction fix_and_outro_and_destroy_block(block, lookup) {\n    block.f();\n    outro_and_destroy_block(block, lookup);\n}\nfunction update_keyed_each(old_blocks, dirty, get_key, dynamic, ctx, list, lookup, node, destroy, create_each_block, next, get_context) {\n    let o = old_blocks.length;\n    let n = list.length;\n    let i = o;\n    const old_indexes = {};\n    while (i--)\n        old_indexes[old_blocks[i].key] = i;\n    const new_blocks = [];\n    const new_lookup = new Map();\n    const deltas = new Map();\n    const updates = [];\n    i = n;\n    while (i--) {\n        const child_ctx = get_context(ctx, list, i);\n        const key = get_key(child_ctx);\n        let block = lookup.get(key);\n        if (!block) {\n            block = create_each_block(key, child_ctx);\n            block.c();\n        }\n        else if (dynamic) {\n            // defer updates until all the DOM shuffling is done\n            updates.push(() => block.p(child_ctx, dirty));\n        }\n        new_lookup.set(key, new_blocks[i] = block);\n        if (key in old_indexes)\n            deltas.set(key, Math.abs(i - old_indexes[key]));\n    }\n    const will_move = new Set();\n    const did_move = new Set();\n    function insert(block) {\n        transition_in(block, 1);\n        block.m(node, next);\n        lookup.set(block.key, block);\n        next = block.first;\n        n--;\n    }\n    while (o && n) {\n        const new_block = new_blocks[n - 1];\n        const old_block = old_blocks[o - 1];\n        const new_key = new_block.key;\n        const old_key = old_block.key;\n        if (new_block === old_block) {\n            // do nothing\n            next = new_block.first;\n            o--;\n            n--;\n        }\n        else if (!new_lookup.has(old_key)) {\n            // remove old block\n            destroy(old_block, lookup);\n            o--;\n        }\n        else if (!lookup.has(new_key) || will_move.has(new_key)) {\n            insert(new_block);\n        }\n        else if (did_move.has(old_key)) {\n            o--;\n        }\n        else if (deltas.get(new_key) > deltas.get(old_key)) {\n            did_move.add(new_key);\n            insert(new_block);\n        }\n        else {\n            will_move.add(old_key);\n            o--;\n        }\n    }\n    while (o--) {\n        const old_block = old_blocks[o];\n        if (!new_lookup.has(old_block.key))\n            destroy(old_block, lookup);\n    }\n    while (n)\n        insert(new_blocks[n - 1]);\n    run_all(updates);\n    return new_blocks;\n}\nfunction validate_each_keys(ctx, list, get_context, get_key) {\n    const keys = new Set();\n    for (let i = 0; i < list.length; i++) {\n        const key = get_key(get_context(ctx, list, i));\n        if (keys.has(key)) {\n            throw new Error('Cannot have duplicate keys in a keyed each');\n        }\n        keys.add(key);\n    }\n}\n\nfunction get_spread_update(levels, updates) {\n    const update = {};\n    const to_null_out = {};\n    const accounted_for = { $$scope: 1 };\n    let i = levels.length;\n    while (i--) {\n        const o = levels[i];\n        const n = updates[i];\n        if (n) {\n            for (const key in o) {\n                if (!(key in n))\n                    to_null_out[key] = 1;\n            }\n            for (const key in n) {\n                if (!accounted_for[key]) {\n                    update[key] = n[key];\n                    accounted_for[key] = 1;\n                }\n            }\n            levels[i] = n;\n        }\n        else {\n            for (const key in o) {\n                accounted_for[key] = 1;\n            }\n        }\n    }\n    for (const key in to_null_out) {\n        if (!(key in update))\n            update[key] = undefined;\n    }\n    return update;\n}\nfunction get_spread_object(spread_props) {\n    return typeof spread_props === 'object' && spread_props !== null ? spread_props : {};\n}\n\nconst _boolean_attributes = [\n    'allowfullscreen',\n    'allowpaymentrequest',\n    'async',\n    'autofocus',\n    'autoplay',\n    'checked',\n    'controls',\n    'default',\n    'defer',\n    'disabled',\n    'formnovalidate',\n    'hidden',\n    'inert',\n    'ismap',\n    'loop',\n    'multiple',\n    'muted',\n    'nomodule',\n    'novalidate',\n    'open',\n    'playsinline',\n    'readonly',\n    'required',\n    'reversed',\n    'selected'\n];\n/**\n * List of HTML boolean attributes (e.g. `<input disabled>`).\n * Source: https://html.spec.whatwg.org/multipage/indices.html\n */\nconst boolean_attributes = new Set([..._boolean_attributes]);\n\n/** regex of all html void element names */\nconst void_element_names = /^(?:area|base|br|col|command|embed|hr|img|input|keygen|link|meta|param|source|track|wbr)$/;\nfunction is_void(name) {\n    return void_element_names.test(name) || name.toLowerCase() === '!doctype';\n}\n\nconst invalid_attribute_name_character = /[\\s'\">/=\\u{FDD0}-\\u{FDEF}\\u{FFFE}\\u{FFFF}\\u{1FFFE}\\u{1FFFF}\\u{2FFFE}\\u{2FFFF}\\u{3FFFE}\\u{3FFFF}\\u{4FFFE}\\u{4FFFF}\\u{5FFFE}\\u{5FFFF}\\u{6FFFE}\\u{6FFFF}\\u{7FFFE}\\u{7FFFF}\\u{8FFFE}\\u{8FFFF}\\u{9FFFE}\\u{9FFFF}\\u{AFFFE}\\u{AFFFF}\\u{BFFFE}\\u{BFFFF}\\u{CFFFE}\\u{CFFFF}\\u{DFFFE}\\u{DFFFF}\\u{EFFFE}\\u{EFFFF}\\u{FFFFE}\\u{FFFFF}\\u{10FFFE}\\u{10FFFF}]/u;\n// https://html.spec.whatwg.org/multipage/syntax.html#attributes-2\n// https://infra.spec.whatwg.org/#noncharacter\nfunction spread(args, attrs_to_add) {\n    const attributes = Object.assign({}, ...args);\n    if (attrs_to_add) {\n        const classes_to_add = attrs_to_add.classes;\n        const styles_to_add = attrs_to_add.styles;\n        if (classes_to_add) {\n            if (attributes.class == null) {\n                attributes.class = classes_to_add;\n            }\n            else {\n                attributes.class += ' ' + classes_to_add;\n            }\n        }\n        if (styles_to_add) {\n            if (attributes.style == null) {\n                attributes.style = style_object_to_string(styles_to_add);\n            }\n            else {\n                attributes.style = style_object_to_string(merge_ssr_styles(attributes.style, styles_to_add));\n            }\n        }\n    }\n    let str = '';\n    Object.keys(attributes).forEach(name => {\n        if (invalid_attribute_name_character.test(name))\n            return;\n        const value = attributes[name];\n        if (value === true)\n            str += ' ' + name;\n        else if (boolean_attributes.has(name.toLowerCase())) {\n            if (value)\n                str += ' ' + name;\n        }\n        else if (value != null) {\n            str += ` ${name}=\"${value}\"`;\n        }\n    });\n    return str;\n}\nfunction merge_ssr_styles(style_attribute, style_directive) {\n    const style_object = {};\n    for (const individual_style of style_attribute.split(';')) {\n        const colon_index = individual_style.indexOf(':');\n        const name = individual_style.slice(0, colon_index).trim();\n        const value = individual_style.slice(colon_index + 1).trim();\n        if (!name)\n            continue;\n        style_object[name] = value;\n    }\n    for (const name in style_directive) {\n        const value = style_directive[name];\n        if (value) {\n            style_object[name] = value;\n        }\n        else {\n            delete style_object[name];\n        }\n    }\n    return style_object;\n}\nconst ATTR_REGEX = /[&\"]/g;\nconst CONTENT_REGEX = /[&<]/g;\n/**\n * Note: this method is performance sensitive and has been optimized\n * https://github.com/sveltejs/svelte/pull/5701\n */\nfunction escape(value, is_attr = false) {\n    const str = String(value);\n    const pattern = is_attr ? ATTR_REGEX : CONTENT_REGEX;\n    pattern.lastIndex = 0;\n    let escaped = '';\n    let last = 0;\n    while (pattern.test(str)) {\n        const i = pattern.lastIndex - 1;\n        const ch = str[i];\n        escaped += str.substring(last, i) + (ch === '&' ? '&amp;' : (ch === '\"' ? '&quot;' : '&lt;'));\n        last = i + 1;\n    }\n    return escaped + str.substring(last);\n}\nfunction escape_attribute_value(value) {\n    // keep booleans, null, and undefined for the sake of `spread`\n    const should_escape = typeof value === 'string' || (value && typeof value === 'object');\n    return should_escape ? escape(value, true) : value;\n}\nfunction escape_object(obj) {\n    const result = {};\n    for (const key in obj) {\n        result[key] = escape_attribute_value(obj[key]);\n    }\n    return result;\n}\nfunction each(items, fn) {\n    let str = '';\n    for (let i = 0; i < items.length; i += 1) {\n        str += fn(items[i], i);\n    }\n    return str;\n}\nconst missing_component = {\n    $$render: () => ''\n};\nfunction validate_component(component, name) {\n    if (!component || !component.$$render) {\n        if (name === 'svelte:component')\n            name += ' this={...}';\n        throw new Error(`<${name}> is not a valid SSR component. You may need to review your build config to ensure that dependencies are compiled, rather than imported as pre-compiled modules. Otherwise you may need to fix a <${name}>.`);\n    }\n    return component;\n}\nfunction debug(file, line, column, values) {\n    console.log(`{@debug} ${file ? file + ' ' : ''}(${line}:${column})`); // eslint-disable-line no-console\n    console.log(values); // eslint-disable-line no-console\n    return '';\n}\nlet on_destroy;\nfunction create_ssr_component(fn) {\n    function $$render(result, props, bindings, slots, context) {\n        const parent_component = current_component;\n        const $$ = {\n            on_destroy,\n            context: new Map(context || (parent_component ? parent_component.$$.context : [])),\n            // these will be immediately discarded\n            on_mount: [],\n            before_update: [],\n            after_update: [],\n            callbacks: blank_object()\n        };\n        set_current_component({ $$ });\n        const html = fn(result, props, bindings, slots);\n        set_current_component(parent_component);\n        return html;\n    }\n    return {\n        render: (props = {}, { $$slots = {}, context = new Map() } = {}) => {\n            on_destroy = [];\n            const result = { title: '', head: '', css: new Set() };\n            const html = $$render(result, props, {}, $$slots, context);\n            run_all(on_destroy);\n            return {\n                html,\n                css: {\n                    code: Array.from(result.css).map(css => css.code).join('\\n'),\n                    map: null // TODO\n                },\n                head: result.title + result.head\n            };\n        },\n        $$render\n    };\n}\nfunction add_attribute(name, value, boolean) {\n    if (value == null || (boolean && !value))\n        return '';\n    const assignment = (boolean && value === true) ? '' : `=\"${escape(value, true)}\"`;\n    return ` ${name}${assignment}`;\n}\nfunction add_classes(classes) {\n    return classes ? ` class=\"${classes}\"` : '';\n}\nfunction style_object_to_string(style_object) {\n    return Object.keys(style_object)\n        .filter(key => style_object[key])\n        .map(key => `${key}: ${escape_attribute_value(style_object[key])};`)\n        .join(' ');\n}\nfunction add_styles(style_object) {\n    const styles = style_object_to_string(style_object);\n    return styles ? ` style=\"${styles}\"` : '';\n}\n\nfunction bind(component, name, callback) {\n    const index = component.$$.props[name];\n    if (index !== undefined) {\n        component.$$.bound[index] = callback;\n        callback(component.$$.ctx[index]);\n    }\n}\nfunction create_component(block) {\n    block && block.c();\n}\nfunction claim_component(block, parent_nodes) {\n    block && block.l(parent_nodes);\n}\nfunction mount_component(component, target, anchor, customElement) {\n    const { fragment, after_update } = component.$$;\n    fragment && fragment.m(target, anchor);\n    if (!customElement) {\n        // onMount happens before the initial afterUpdate\n        add_render_callback(() => {\n            const new_on_destroy = component.$$.on_mount.map(run).filter(is_function);\n            // if the component was destroyed immediately\n            // it will update the `$$.on_destroy` reference to `null`.\n            // the destructured on_destroy may still reference to the old array\n            if (component.$$.on_destroy) {\n                component.$$.on_destroy.push(...new_on_destroy);\n            }\n            else {\n                // Edge case - component was destroyed immediately,\n                // most likely as a result of a binding initialising\n                run_all(new_on_destroy);\n            }\n            component.$$.on_mount = [];\n        });\n    }\n    after_update.forEach(add_render_callback);\n}\nfunction destroy_component(component, detaching) {\n    const $$ = component.$$;\n    if ($$.fragment !== null) {\n        flush_render_callbacks($$.after_update);\n        run_all($$.on_destroy);\n        $$.fragment && $$.fragment.d(detaching);\n        // TODO null out other refs, including component.$$ (but need to\n        // preserve final state?)\n        $$.on_destroy = $$.fragment = null;\n        $$.ctx = [];\n    }\n}\nfunction make_dirty(component, i) {\n    if (component.$$.dirty[0] === -1) {\n        dirty_components.push(component);\n        schedule_update();\n        component.$$.dirty.fill(0);\n    }\n    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));\n}\nfunction init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {\n    const parent_component = current_component;\n    set_current_component(component);\n    const $$ = component.$$ = {\n        fragment: null,\n        ctx: [],\n        // state\n        props,\n        update: noop,\n        not_equal,\n        bound: blank_object(),\n        // lifecycle\n        on_mount: [],\n        on_destroy: [],\n        on_disconnect: [],\n        before_update: [],\n        after_update: [],\n        context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),\n        // everything else\n        callbacks: blank_object(),\n        dirty,\n        skip_bound: false,\n        root: options.target || parent_component.$$.root\n    };\n    append_styles && append_styles($$.root);\n    let ready = false;\n    $$.ctx = instance\n        ? instance(component, options.props || {}, (i, ret, ...rest) => {\n            const value = rest.length ? rest[0] : ret;\n            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {\n                if (!$$.skip_bound && $$.bound[i])\n                    $$.bound[i](value);\n                if (ready)\n                    make_dirty(component, i);\n            }\n            return ret;\n        })\n        : [];\n    $$.update();\n    ready = true;\n    run_all($$.before_update);\n    // `false` as a special case of no DOM component\n    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;\n    if (options.target) {\n        if (options.hydrate) {\n            start_hydrating();\n            const nodes = children(options.target);\n            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion\n            $$.fragment && $$.fragment.l(nodes);\n            nodes.forEach(detach);\n        }\n        else {\n            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion\n            $$.fragment && $$.fragment.c();\n        }\n        if (options.intro)\n            transition_in(component.$$.fragment);\n        mount_component(component, options.target, options.anchor, options.customElement);\n        end_hydrating();\n        flush();\n    }\n    set_current_component(parent_component);\n}\nlet SvelteElement;\nif (typeof HTMLElement === 'function') {\n    SvelteElement = class extends HTMLElement {\n        constructor() {\n            super();\n            this.attachShadow({ mode: 'open' });\n        }\n        connectedCallback() {\n            const { on_mount } = this.$$;\n            this.$$.on_disconnect = on_mount.map(run).filter(is_function);\n            // @ts-ignore todo: improve typings\n            for (const key in this.$$.slotted) {\n                // @ts-ignore todo: improve typings\n                this.appendChild(this.$$.slotted[key]);\n            }\n        }\n        attributeChangedCallback(attr, _oldValue, newValue) {\n            this[attr] = newValue;\n        }\n        disconnectedCallback() {\n            run_all(this.$$.on_disconnect);\n        }\n        $destroy() {\n            destroy_component(this, 1);\n            this.$destroy = noop;\n        }\n        $on(type, callback) {\n            // TODO should this delegate to addEventListener?\n            if (!is_function(callback)) {\n                return noop;\n            }\n            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));\n            callbacks.push(callback);\n            return () => {\n                const index = callbacks.indexOf(callback);\n                if (index !== -1)\n                    callbacks.splice(index, 1);\n            };\n        }\n        $set($$props) {\n            if (this.$$set && !is_empty($$props)) {\n                this.$$.skip_bound = true;\n                this.$$set($$props);\n                this.$$.skip_bound = false;\n            }\n        }\n    };\n}\n/**\n * Base class for Svelte components. Used when dev=false.\n */\nclass SvelteComponent {\n    $destroy() {\n        destroy_component(this, 1);\n        this.$destroy = noop;\n    }\n    $on(type, callback) {\n        if (!is_function(callback)) {\n            return noop;\n        }\n        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));\n        callbacks.push(callback);\n        return () => {\n            const index = callbacks.indexOf(callback);\n            if (index !== -1)\n                callbacks.splice(index, 1);\n        };\n    }\n    $set($$props) {\n        if (this.$$set && !is_empty($$props)) {\n            this.$$.skip_bound = true;\n            this.$$set($$props);\n            this.$$.skip_bound = false;\n        }\n    }\n}\n\nfunction dispatch_dev(type, detail) {\n    document.dispatchEvent(custom_event(type, Object.assign({ version: '3.59.2' }, detail), { bubbles: true }));\n}\nfunction append_dev(target, node) {\n    dispatch_dev('SvelteDOMInsert', { target, node });\n    append(target, node);\n}\nfunction append_hydration_dev(target, node) {\n    dispatch_dev('SvelteDOMInsert', { target, node });\n    append_hydration(target, node);\n}\nfunction insert_dev(target, node, anchor) {\n    dispatch_dev('SvelteDOMInsert', { target, node, anchor });\n    insert(target, node, anchor);\n}\nfunction insert_hydration_dev(target, node, anchor) {\n    dispatch_dev('SvelteDOMInsert', { target, node, anchor });\n    insert_hydration(target, node, anchor);\n}\nfunction detach_dev(node) {\n    dispatch_dev('SvelteDOMRemove', { node });\n    detach(node);\n}\nfunction detach_between_dev(before, after) {\n    while (before.nextSibling && before.nextSibling !== after) {\n        detach_dev(before.nextSibling);\n    }\n}\nfunction detach_before_dev(after) {\n    while (after.previousSibling) {\n        detach_dev(after.previousSibling);\n    }\n}\nfunction detach_after_dev(before) {\n    while (before.nextSibling) {\n        detach_dev(before.nextSibling);\n    }\n}\nfunction listen_dev(node, event, handler, options, has_prevent_default, has_stop_propagation, has_stop_immediate_propagation) {\n    const modifiers = options === true ? ['capture'] : options ? Array.from(Object.keys(options)) : [];\n    if (has_prevent_default)\n        modifiers.push('preventDefault');\n    if (has_stop_propagation)\n        modifiers.push('stopPropagation');\n    if (has_stop_immediate_propagation)\n        modifiers.push('stopImmediatePropagation');\n    dispatch_dev('SvelteDOMAddEventListener', { node, event, handler, modifiers });\n    const dispose = listen(node, event, handler, options);\n    return () => {\n        dispatch_dev('SvelteDOMRemoveEventListener', { node, event, handler, modifiers });\n        dispose();\n    };\n}\nfunction attr_dev(node, attribute, value) {\n    attr(node, attribute, value);\n    if (value == null)\n        dispatch_dev('SvelteDOMRemoveAttribute', { node, attribute });\n    else\n        dispatch_dev('SvelteDOMSetAttribute', { node, attribute, value });\n}\nfunction prop_dev(node, property, value) {\n    node[property] = value;\n    dispatch_dev('SvelteDOMSetProperty', { node, property, value });\n}\nfunction dataset_dev(node, property, value) {\n    node.dataset[property] = value;\n    dispatch_dev('SvelteDOMSetDataset', { node, property, value });\n}\nfunction set_data_dev(text, data) {\n    data = '' + data;\n    if (text.data === data)\n        return;\n    dispatch_dev('SvelteDOMSetData', { node: text, data });\n    text.data = data;\n}\nfunction set_data_contenteditable_dev(text, data) {\n    data = '' + data;\n    if (text.wholeText === data)\n        return;\n    dispatch_dev('SvelteDOMSetData', { node: text, data });\n    text.data = data;\n}\nfunction set_data_maybe_contenteditable_dev(text, data, attr_value) {\n    if (~contenteditable_truthy_values.indexOf(attr_value)) {\n        set_data_contenteditable_dev(text, data);\n    }\n    else {\n        set_data_dev(text, data);\n    }\n}\nfunction validate_each_argument(arg) {\n    if (typeof arg !== 'string' && !(arg && typeof arg === 'object' && 'length' in arg)) {\n        let msg = '{#each} only iterates over array-like objects.';\n        if (typeof Symbol === 'function' && arg && Symbol.iterator in arg) {\n            msg += ' You can use a spread to convert this iterable into an array.';\n        }\n        throw new Error(msg);\n    }\n}\nfunction validate_slots(name, slot, keys) {\n    for (const slot_key of Object.keys(slot)) {\n        if (!~keys.indexOf(slot_key)) {\n            console.warn(`<${name}> received an unexpected slot \"${slot_key}\".`);\n        }\n    }\n}\nfunction validate_dynamic_element(tag) {\n    const is_string = typeof tag === 'string';\n    if (tag && !is_string) {\n        throw new Error('<svelte:element> expects \"this\" attribute to be a string.');\n    }\n}\nfunction validate_void_dynamic_element(tag) {\n    if (tag && is_void(tag)) {\n        console.warn(`<svelte:element this=\"${tag}\"> is self-closing and cannot have content.`);\n    }\n}\nfunction construct_svelte_component_dev(component, props) {\n    const error_message = 'this={...} of <svelte:component> should specify a Svelte component.';\n    try {\n        const instance = new component(props);\n        if (!instance.$$ || !instance.$set || !instance.$on || !instance.$destroy) {\n            throw new Error(error_message);\n        }\n        return instance;\n    }\n    catch (err) {\n        const { message } = err;\n        if (typeof message === 'string' && message.indexOf('is not a constructor') !== -1) {\n            throw new Error(error_message);\n        }\n        else {\n            throw err;\n        }\n    }\n}\n/**\n * Base class for Svelte components with some minor dev-enhancements. Used when dev=true.\n */\nclass SvelteComponentDev extends SvelteComponent {\n    constructor(options) {\n        if (!options || (!options.target && !options.$$inline)) {\n            throw new Error(\"'target' is a required option\");\n        }\n        super();\n    }\n    $destroy() {\n        super.$destroy();\n        this.$destroy = () => {\n            console.warn('Component was already destroyed'); // eslint-disable-line no-console\n        };\n    }\n    $capture_state() { }\n    $inject_state() { }\n}\n/**\n * Base class to create strongly typed Svelte components.\n * This only exists for typing purposes and should be used in `.d.ts` files.\n *\n * ### Example:\n *\n * You have component library on npm called `component-library`, from which\n * you export a component called `MyComponent`. For Svelte+TypeScript users,\n * you want to provide typings. Therefore you create a `index.d.ts`:\n * ```ts\n * import { SvelteComponentTyped } from \"svelte\";\n * export class MyComponent extends SvelteComponentTyped<{foo: string}> {}\n * ```\n * Typing this makes it possible for IDEs like VS Code with the Svelte extension\n * to provide intellisense and to use the component like this in a Svelte file\n * with TypeScript:\n * ```svelte\n * <script lang=\"ts\">\n * \timport { MyComponent } from \"component-library\";\n * </script>\n * <MyComponent foo={'bar'} />\n * ```\n *\n * #### Why not make this part of `SvelteComponent(Dev)`?\n * Because\n * ```ts\n * class ASubclassOfSvelteComponent extends SvelteComponent<{foo: string}> {}\n * const component: typeof SvelteComponent = ASubclassOfSvelteComponent;\n * ```\n * will throw a type error, so we need to separate the more strictly typed class.\n */\nclass SvelteComponentTyped extends SvelteComponentDev {\n    constructor(options) {\n        super(options);\n    }\n}\nfunction loop_guard(timeout) {\n    const start = Date.now();\n    return () => {\n        if (Date.now() - start > timeout) {\n            throw new Error('Infinite loop detected');\n        }\n    };\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte/internal/index.mjs?");

/***/ }),

/***/ "../../node_modules/svelte/store/index.mjs":
/*!*************************************************!*\
  !*** ../../node_modules/svelte/store/index.mjs ***!
  \*************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   derived: () => (/* binding */ derived),\n/* harmony export */   get: () => (/* reexport safe */ _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.get_store_value),\n/* harmony export */   readable: () => (/* binding */ readable),\n/* harmony export */   readonly: () => (/* binding */ readonly),\n/* harmony export */   writable: () => (/* binding */ writable)\n/* harmony export */ });\n/* harmony import */ var _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../internal/index.mjs */ \"../../node_modules/svelte/internal/index.mjs\");\n\n\n\nconst subscriber_queue = [];\n/**\n * Creates a `Readable` store that allows reading by subscription.\n * @param value initial value\n * @param {StartStopNotifier} [start]\n */\nfunction readable(value, start) {\n    return {\n        subscribe: writable(value, start).subscribe\n    };\n}\n/**\n * Create a `Writable` store that allows both updating and reading by subscription.\n * @param {*=}value initial value\n * @param {StartStopNotifier=} start\n */\nfunction writable(value, start = _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.noop) {\n    let stop;\n    const subscribers = new Set();\n    function set(new_value) {\n        if ((0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.safe_not_equal)(value, new_value)) {\n            value = new_value;\n            if (stop) { // store is ready\n                const run_queue = !subscriber_queue.length;\n                for (const subscriber of subscribers) {\n                    subscriber[1]();\n                    subscriber_queue.push(subscriber, value);\n                }\n                if (run_queue) {\n                    for (let i = 0; i < subscriber_queue.length; i += 2) {\n                        subscriber_queue[i][0](subscriber_queue[i + 1]);\n                    }\n                    subscriber_queue.length = 0;\n                }\n            }\n        }\n    }\n    function update(fn) {\n        set(fn(value));\n    }\n    function subscribe(run, invalidate = _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.noop) {\n        const subscriber = [run, invalidate];\n        subscribers.add(subscriber);\n        if (subscribers.size === 1) {\n            stop = start(set) || _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.noop;\n        }\n        run(value);\n        return () => {\n            subscribers.delete(subscriber);\n            if (subscribers.size === 0 && stop) {\n                stop();\n                stop = null;\n            }\n        };\n    }\n    return { set, update, subscribe };\n}\nfunction derived(stores, fn, initial_value) {\n    const single = !Array.isArray(stores);\n    const stores_array = single\n        ? [stores]\n        : stores;\n    const auto = fn.length < 2;\n    return readable(initial_value, (set) => {\n        let started = false;\n        const values = [];\n        let pending = 0;\n        let cleanup = _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.noop;\n        const sync = () => {\n            if (pending) {\n                return;\n            }\n            cleanup();\n            const result = fn(single ? values[0] : values, set);\n            if (auto) {\n                set(result);\n            }\n            else {\n                cleanup = (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.is_function)(result) ? result : _internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.noop;\n            }\n        };\n        const unsubscribers = stores_array.map((store, i) => (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.subscribe)(store, (value) => {\n            values[i] = value;\n            pending &= ~(1 << i);\n            if (started) {\n                sync();\n            }\n        }, () => {\n            pending |= (1 << i);\n        }));\n        started = true;\n        sync();\n        return function stop() {\n            (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_0__.run_all)(unsubscribers);\n            cleanup();\n            // We need to set this to false because callbacks can still happen despite having unsubscribed:\n            // Callbacks might already be placed in the queue which doesn't know it should no longer\n            // invoke this derived store.\n            started = false;\n        };\n    });\n}\n/**\n * Takes a store and returns a new one derived from the old one that is readable.\n *\n * @param store - store to make readonly\n */\nfunction readonly(store) {\n    return {\n        subscribe: store.subscribe.bind(store)\n    };\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte/store/index.mjs?");

/***/ }),

/***/ "../../node_modules/svelte/transition/index.mjs":
/*!******************************************************!*\
  !*** ../../node_modules/svelte/transition/index.mjs ***!
  \******************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   blur: () => (/* binding */ blur),\n/* harmony export */   crossfade: () => (/* binding */ crossfade),\n/* harmony export */   draw: () => (/* binding */ draw),\n/* harmony export */   fade: () => (/* binding */ fade),\n/* harmony export */   fly: () => (/* binding */ fly),\n/* harmony export */   scale: () => (/* binding */ scale),\n/* harmony export */   slide: () => (/* binding */ slide)\n/* harmony export */ });\n/* harmony import */ var _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../easing/index.mjs */ \"../../node_modules/svelte/easing/index.mjs\");\n/* harmony import */ var _internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../internal/index.mjs */ \"../../node_modules/svelte/internal/index.mjs\");\n\n\n\n/******************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n\r\nfunction __rest(s, e) {\r\n    var t = {};\r\n    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)\r\n        t[p] = s[p];\r\n    if (s != null && typeof Object.getOwnPropertySymbols === \"function\")\r\n        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {\r\n            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))\r\n                t[p[i]] = s[p[i]];\r\n        }\r\n    return t;\r\n}\n\nfunction blur(node, { delay = 0, duration = 400, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicInOut, amount = 5, opacity = 0 } = {}) {\n    const style = getComputedStyle(node);\n    const target_opacity = +style.opacity;\n    const f = style.filter === 'none' ? '' : style.filter;\n    const od = target_opacity * (1 - opacity);\n    const [value, unit] = (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.split_css_unit)(amount);\n    return {\n        delay,\n        duration,\n        easing,\n        css: (_t, u) => `opacity: ${target_opacity - (od * u)}; filter: ${f} blur(${u * value}${unit});`\n    };\n}\nfunction fade(node, { delay = 0, duration = 400, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.linear } = {}) {\n    const o = +getComputedStyle(node).opacity;\n    return {\n        delay,\n        duration,\n        easing,\n        css: t => `opacity: ${t * o}`\n    };\n}\nfunction fly(node, { delay = 0, duration = 400, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicOut, x = 0, y = 0, opacity = 0 } = {}) {\n    const style = getComputedStyle(node);\n    const target_opacity = +style.opacity;\n    const transform = style.transform === 'none' ? '' : style.transform;\n    const od = target_opacity * (1 - opacity);\n    const [xValue, xUnit] = (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.split_css_unit)(x);\n    const [yValue, yUnit] = (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.split_css_unit)(y);\n    return {\n        delay,\n        duration,\n        easing,\n        css: (t, u) => `\n\t\t\ttransform: ${transform} translate(${(1 - t) * xValue}${xUnit}, ${(1 - t) * yValue}${yUnit});\n\t\t\topacity: ${target_opacity - (od * u)}`\n    };\n}\nfunction slide(node, { delay = 0, duration = 400, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicOut, axis = 'y' } = {}) {\n    const style = getComputedStyle(node);\n    const opacity = +style.opacity;\n    const primary_property = axis === 'y' ? 'height' : 'width';\n    const primary_property_value = parseFloat(style[primary_property]);\n    const secondary_properties = axis === 'y' ? ['top', 'bottom'] : ['left', 'right'];\n    const capitalized_secondary_properties = secondary_properties.map((e) => `${e[0].toUpperCase()}${e.slice(1)}`);\n    const padding_start_value = parseFloat(style[`padding${capitalized_secondary_properties[0]}`]);\n    const padding_end_value = parseFloat(style[`padding${capitalized_secondary_properties[1]}`]);\n    const margin_start_value = parseFloat(style[`margin${capitalized_secondary_properties[0]}`]);\n    const margin_end_value = parseFloat(style[`margin${capitalized_secondary_properties[1]}`]);\n    const border_width_start_value = parseFloat(style[`border${capitalized_secondary_properties[0]}Width`]);\n    const border_width_end_value = parseFloat(style[`border${capitalized_secondary_properties[1]}Width`]);\n    return {\n        delay,\n        duration,\n        easing,\n        css: t => 'overflow: hidden;' +\n            `opacity: ${Math.min(t * 20, 1) * opacity};` +\n            `${primary_property}: ${t * primary_property_value}px;` +\n            `padding-${secondary_properties[0]}: ${t * padding_start_value}px;` +\n            `padding-${secondary_properties[1]}: ${t * padding_end_value}px;` +\n            `margin-${secondary_properties[0]}: ${t * margin_start_value}px;` +\n            `margin-${secondary_properties[1]}: ${t * margin_end_value}px;` +\n            `border-${secondary_properties[0]}-width: ${t * border_width_start_value}px;` +\n            `border-${secondary_properties[1]}-width: ${t * border_width_end_value}px;`\n    };\n}\nfunction scale(node, { delay = 0, duration = 400, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicOut, start = 0, opacity = 0 } = {}) {\n    const style = getComputedStyle(node);\n    const target_opacity = +style.opacity;\n    const transform = style.transform === 'none' ? '' : style.transform;\n    const sd = 1 - start;\n    const od = target_opacity * (1 - opacity);\n    return {\n        delay,\n        duration,\n        easing,\n        css: (_t, u) => `\n\t\t\ttransform: ${transform} scale(${1 - (sd * u)});\n\t\t\topacity: ${target_opacity - (od * u)}\n\t\t`\n    };\n}\nfunction draw(node, { delay = 0, speed, duration, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicInOut } = {}) {\n    let len = node.getTotalLength();\n    const style = getComputedStyle(node);\n    if (style.strokeLinecap !== 'butt') {\n        len += parseInt(style.strokeWidth);\n    }\n    if (duration === undefined) {\n        if (speed === undefined) {\n            duration = 800;\n        }\n        else {\n            duration = len / speed;\n        }\n    }\n    else if (typeof duration === 'function') {\n        duration = duration(len);\n    }\n    return {\n        delay,\n        duration,\n        easing,\n        css: (_, u) => `\n\t\t\tstroke-dasharray: ${len};\n\t\t\tstroke-dashoffset: ${u * len};\n\t\t`\n    };\n}\nfunction crossfade(_a) {\n    var { fallback } = _a, defaults = __rest(_a, [\"fallback\"]);\n    const to_receive = new Map();\n    const to_send = new Map();\n    function crossfade(from_node, node, params) {\n        const { delay = 0, duration = d => Math.sqrt(d) * 30, easing = _easing_index_mjs__WEBPACK_IMPORTED_MODULE_0__.cubicOut } = (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.assign)((0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.assign)({}, defaults), params);\n        const from = from_node.getBoundingClientRect();\n        const to = node.getBoundingClientRect();\n        const dx = from.left - to.left;\n        const dy = from.top - to.top;\n        const dw = from.width / to.width;\n        const dh = from.height / to.height;\n        const d = Math.sqrt(dx * dx + dy * dy);\n        const style = getComputedStyle(node);\n        const transform = style.transform === 'none' ? '' : style.transform;\n        const opacity = +style.opacity;\n        return {\n            delay,\n            duration: (0,_internal_index_mjs__WEBPACK_IMPORTED_MODULE_1__.is_function)(duration) ? duration(d) : duration,\n            easing,\n            css: (t, u) => `\n\t\t\t\topacity: ${t * opacity};\n\t\t\t\ttransform-origin: top left;\n\t\t\t\ttransform: ${transform} translate(${u * dx}px,${u * dy}px) scale(${t + (1 - t) * dw}, ${t + (1 - t) * dh});\n\t\t\t`\n        };\n    }\n    function transition(items, counterparts, intro) {\n        return (node, params) => {\n            items.set(params.key, node);\n            return () => {\n                if (counterparts.has(params.key)) {\n                    const other_node = counterparts.get(params.key);\n                    counterparts.delete(params.key);\n                    return crossfade(other_node, node, params);\n                }\n                // if the node is disappearing altogether\n                // (i.e. wasn't claimed by the other list)\n                // then we need to supply an outro\n                items.delete(params.key);\n                return fallback && fallback(node, params, intro);\n            };\n        };\n    }\n    return [\n        transition(to_send, to_receive, false),\n        transition(to_receive, to_send, true)\n    ];\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/svelte/transition/index.mjs?");

/***/ }),

/***/ "../../node_modules/text-encoding-utf-8/lib/encoding.lib.mjs":
/*!*******************************************************************!*\
  !*** ../../node_modules/text-encoding-utf-8/lib/encoding.lib.mjs ***!
  \*******************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   TextDecoder: () => (/* binding */ TextDecoder),\n/* harmony export */   TextEncoder: () => (/* binding */ TextEncoder)\n/* harmony export */ });\n\n\n// This is free and unencumbered software released into the public domain.\n// See LICENSE.md for more information.\n\n//\n// Utilities\n//\n\n/**\n * @param {number} a The number to test.\n * @param {number} min The minimum value in the range, inclusive.\n * @param {number} max The maximum value in the range, inclusive.\n * @return {boolean} True if a >= min and a <= max.\n */\nfunction inRange(a, min, max) {\n  return min <= a && a <= max;\n}\n\n/**\n * @param {*} o\n * @return {Object}\n */\nfunction ToDictionary(o) {\n  if (o === undefined) return {};\n  if (o === Object(o)) return o;\n  throw TypeError('Could not convert argument to dictionary');\n}\n\n/**\n * @param {string} string Input string of UTF-16 code units.\n * @return {!Array.<number>} Code points.\n */\nfunction stringToCodePoints(string) {\n  // https://heycam.github.io/webidl/#dfn-obtain-unicode\n\n  // 1. Let S be the DOMString value.\n  var s = String(string);\n\n  // 2. Let n be the length of S.\n  var n = s.length;\n\n  // 3. Initialize i to 0.\n  var i = 0;\n\n  // 4. Initialize U to be an empty sequence of Unicode characters.\n  var u = [];\n\n  // 5. While i < n:\n  while (i < n) {\n\n    // 1. Let c be the code unit in S at index i.\n    var c = s.charCodeAt(i);\n\n    // 2. Depending on the value of c:\n\n    // c < 0xD800 or c > 0xDFFF\n    if (c < 0xD800 || c > 0xDFFF) {\n      // Append to U the Unicode character with code point c.\n      u.push(c);\n    }\n\n    // 0xDC00 ≤ c ≤ 0xDFFF\n    else if (0xDC00 <= c && c <= 0xDFFF) {\n      // Append to U a U+FFFD REPLACEMENT CHARACTER.\n      u.push(0xFFFD);\n    }\n\n    // 0xD800 ≤ c ≤ 0xDBFF\n    else if (0xD800 <= c && c <= 0xDBFF) {\n      // 1. If i = n−1, then append to U a U+FFFD REPLACEMENT\n      // CHARACTER.\n      if (i === n - 1) {\n        u.push(0xFFFD);\n      }\n      // 2. Otherwise, i < n−1:\n      else {\n        // 1. Let d be the code unit in S at index i+1.\n        var d = string.charCodeAt(i + 1);\n\n        // 2. If 0xDC00 ≤ d ≤ 0xDFFF, then:\n        if (0xDC00 <= d && d <= 0xDFFF) {\n          // 1. Let a be c & 0x3FF.\n          var a = c & 0x3FF;\n\n          // 2. Let b be d & 0x3FF.\n          var b = d & 0x3FF;\n\n          // 3. Append to U the Unicode character with code point\n          // 2^16+2^10*a+b.\n          u.push(0x10000 + (a << 10) + b);\n\n          // 4. Set i to i+1.\n          i += 1;\n        }\n\n        // 3. Otherwise, d < 0xDC00 or d > 0xDFFF. Append to U a\n        // U+FFFD REPLACEMENT CHARACTER.\n        else  {\n          u.push(0xFFFD);\n        }\n      }\n    }\n\n    // 3. Set i to i+1.\n    i += 1;\n  }\n\n  // 6. Return U.\n  return u;\n}\n\n/**\n * @param {!Array.<number>} code_points Array of code points.\n * @return {string} string String of UTF-16 code units.\n */\nfunction codePointsToString(code_points) {\n  var s = '';\n  for (var i = 0; i < code_points.length; ++i) {\n    var cp = code_points[i];\n    if (cp <= 0xFFFF) {\n      s += String.fromCharCode(cp);\n    } else {\n      cp -= 0x10000;\n      s += String.fromCharCode((cp >> 10) + 0xD800,\n                               (cp & 0x3FF) + 0xDC00);\n    }\n  }\n  return s;\n}\n\n\n//\n// Implementation of Encoding specification\n// https://encoding.spec.whatwg.org/\n//\n\n//\n// 3. Terminology\n//\n\n/**\n * End-of-stream is a special token that signifies no more tokens\n * are in the stream.\n * @const\n */ var end_of_stream = -1;\n\n/**\n * A stream represents an ordered sequence of tokens.\n *\n * @constructor\n * @param {!(Array.<number>|Uint8Array)} tokens Array of tokens that provide the\n * stream.\n */\nfunction Stream(tokens) {\n  /** @type {!Array.<number>} */\n  this.tokens = [].slice.call(tokens);\n}\n\nStream.prototype = {\n  /**\n   * @return {boolean} True if end-of-stream has been hit.\n   */\n  endOfStream: function() {\n    return !this.tokens.length;\n  },\n\n  /**\n   * When a token is read from a stream, the first token in the\n   * stream must be returned and subsequently removed, and\n   * end-of-stream must be returned otherwise.\n   *\n   * @return {number} Get the next token from the stream, or\n   * end_of_stream.\n   */\n   read: function() {\n    if (!this.tokens.length)\n      return end_of_stream;\n     return this.tokens.shift();\n   },\n\n  /**\n   * When one or more tokens are prepended to a stream, those tokens\n   * must be inserted, in given order, before the first token in the\n   * stream.\n   *\n   * @param {(number|!Array.<number>)} token The token(s) to prepend to the stream.\n   */\n  prepend: function(token) {\n    if (Array.isArray(token)) {\n      var tokens = /**@type {!Array.<number>}*/(token);\n      while (tokens.length)\n        this.tokens.unshift(tokens.pop());\n    } else {\n      this.tokens.unshift(token);\n    }\n  },\n\n  /**\n   * When one or more tokens are pushed to a stream, those tokens\n   * must be inserted, in given order, after the last token in the\n   * stream.\n   *\n   * @param {(number|!Array.<number>)} token The tokens(s) to prepend to the stream.\n   */\n  push: function(token) {\n    if (Array.isArray(token)) {\n      var tokens = /**@type {!Array.<number>}*/(token);\n      while (tokens.length)\n        this.tokens.push(tokens.shift());\n    } else {\n      this.tokens.push(token);\n    }\n  }\n};\n\n//\n// 4. Encodings\n//\n\n// 4.1 Encoders and decoders\n\n/** @const */\nvar finished = -1;\n\n/**\n * @param {boolean} fatal If true, decoding errors raise an exception.\n * @param {number=} opt_code_point Override the standard fallback code point.\n * @return {number} The code point to insert on a decoding error.\n */\nfunction decoderError(fatal, opt_code_point) {\n  if (fatal)\n    throw TypeError('Decoder error');\n  return opt_code_point || 0xFFFD;\n}\n\n/** @interface */\nfunction Decoder() {}\nDecoder.prototype = {\n  /**\n   * @param {Stream} stream The stream of bytes being decoded.\n   * @param {number} bite The next byte read from the stream.\n   * @return {?(number|!Array.<number>)} The next code point(s)\n   *     decoded, or null if not enough data exists in the input\n   *     stream to decode a complete code point, or |finished|.\n   */\n  handler: function(stream, bite) {}\n};\n\n/** @interface */\nfunction Encoder() {}\nEncoder.prototype = {\n  /**\n   * @param {Stream} stream The stream of code points being encoded.\n   * @param {number} code_point Next code point read from the stream.\n   * @return {(number|!Array.<number>)} Byte(s) to emit, or |finished|.\n   */\n  handler: function(stream, code_point) {}\n};\n\n//\n// 7. API\n//\n\n/** @const */ var DEFAULT_ENCODING = 'utf-8';\n\n// 7.1 Interface TextDecoder\n\n/**\n * @constructor\n * @param {string=} encoding The label of the encoding;\n *     defaults to 'utf-8'.\n * @param {Object=} options\n */\nfunction TextDecoder(encoding, options) {\n  if (!(this instanceof TextDecoder)) {\n    return new TextDecoder(encoding, options);\n  }\n  encoding = encoding !== undefined ? String(encoding).toLowerCase() : DEFAULT_ENCODING;\n  if (encoding !== DEFAULT_ENCODING) {\n    throw new Error('Encoding not supported. Only utf-8 is supported');\n  }\n  options = ToDictionary(options);\n\n  /** @private @type {boolean} */\n  this._streaming = false;\n  /** @private @type {boolean} */\n  this._BOMseen = false;\n  /** @private @type {?Decoder} */\n  this._decoder = null;\n  /** @private @type {boolean} */\n  this._fatal = Boolean(options['fatal']);\n  /** @private @type {boolean} */\n  this._ignoreBOM = Boolean(options['ignoreBOM']);\n\n  Object.defineProperty(this, 'encoding', {value: 'utf-8'});\n  Object.defineProperty(this, 'fatal', {value: this._fatal});\n  Object.defineProperty(this, 'ignoreBOM', {value: this._ignoreBOM});\n}\n\nTextDecoder.prototype = {\n  /**\n   * @param {ArrayBufferView=} input The buffer of bytes to decode.\n   * @param {Object=} options\n   * @return {string} The decoded string.\n   */\n  decode: function decode(input, options) {\n    var bytes;\n    if (typeof input === 'object' && input instanceof ArrayBuffer) {\n      bytes = new Uint8Array(input);\n    } else if (typeof input === 'object' && 'buffer' in input &&\n               input.buffer instanceof ArrayBuffer) {\n      bytes = new Uint8Array(input.buffer,\n                             input.byteOffset,\n                             input.byteLength);\n    } else {\n      bytes = new Uint8Array(0);\n    }\n\n    options = ToDictionary(options);\n\n    if (!this._streaming) {\n      this._decoder = new UTF8Decoder({fatal: this._fatal});\n      this._BOMseen = false;\n    }\n    this._streaming = Boolean(options['stream']);\n\n    var input_stream = new Stream(bytes);\n\n    var code_points = [];\n\n    /** @type {?(number|!Array.<number>)} */\n    var result;\n\n    while (!input_stream.endOfStream()) {\n      result = this._decoder.handler(input_stream, input_stream.read());\n      if (result === finished)\n        break;\n      if (result === null)\n        continue;\n      if (Array.isArray(result))\n        code_points.push.apply(code_points, /**@type {!Array.<number>}*/(result));\n      else\n        code_points.push(result);\n    }\n    if (!this._streaming) {\n      do {\n        result = this._decoder.handler(input_stream, input_stream.read());\n        if (result === finished)\n          break;\n        if (result === null)\n          continue;\n        if (Array.isArray(result))\n          code_points.push.apply(code_points, /**@type {!Array.<number>}*/(result));\n        else\n          code_points.push(result);\n      } while (!input_stream.endOfStream());\n      this._decoder = null;\n    }\n\n    if (code_points.length) {\n      // If encoding is one of utf-8, utf-16be, and utf-16le, and\n      // ignore BOM flag and BOM seen flag are unset, run these\n      // subsubsteps:\n      if (['utf-8'].indexOf(this.encoding) !== -1 &&\n          !this._ignoreBOM && !this._BOMseen) {\n        // If token is U+FEFF, set BOM seen flag.\n        if (code_points[0] === 0xFEFF) {\n          this._BOMseen = true;\n          code_points.shift();\n        } else {\n          // Otherwise, if token is not end-of-stream, set BOM seen\n          // flag and append token to output.\n          this._BOMseen = true;\n        }\n      }\n    }\n\n    return codePointsToString(code_points);\n  }\n};\n\n// 7.2 Interface TextEncoder\n\n/**\n * @constructor\n * @param {string=} encoding The label of the encoding;\n *     defaults to 'utf-8'.\n * @param {Object=} options\n */\nfunction TextEncoder(encoding, options) {\n  if (!(this instanceof TextEncoder))\n    return new TextEncoder(encoding, options);\n  encoding = encoding !== undefined ? String(encoding).toLowerCase() : DEFAULT_ENCODING;\n  if (encoding !== DEFAULT_ENCODING) {\n    throw new Error('Encoding not supported. Only utf-8 is supported');\n  }\n  options = ToDictionary(options);\n\n  /** @private @type {boolean} */\n  this._streaming = false;\n  /** @private @type {?Encoder} */\n  this._encoder = null;\n  /** @private @type {{fatal: boolean}} */\n  this._options = {fatal: Boolean(options['fatal'])};\n\n  Object.defineProperty(this, 'encoding', {value: 'utf-8'});\n}\n\nTextEncoder.prototype = {\n  /**\n   * @param {string=} opt_string The string to encode.\n   * @param {Object=} options\n   * @return {Uint8Array} Encoded bytes, as a Uint8Array.\n   */\n  encode: function encode(opt_string, options) {\n    opt_string = opt_string ? String(opt_string) : '';\n    options = ToDictionary(options);\n\n    // NOTE: This option is nonstandard. None of the encodings\n    // permitted for encoding (i.e. UTF-8, UTF-16) are stateful,\n    // so streaming is not necessary.\n    if (!this._streaming)\n      this._encoder = new UTF8Encoder(this._options);\n    this._streaming = Boolean(options['stream']);\n\n    var bytes = [];\n    var input_stream = new Stream(stringToCodePoints(opt_string));\n    /** @type {?(number|!Array.<number>)} */\n    var result;\n    while (!input_stream.endOfStream()) {\n      result = this._encoder.handler(input_stream, input_stream.read());\n      if (result === finished)\n        break;\n      if (Array.isArray(result))\n        bytes.push.apply(bytes, /**@type {!Array.<number>}*/(result));\n      else\n        bytes.push(result);\n    }\n    if (!this._streaming) {\n      while (true) {\n        result = this._encoder.handler(input_stream, input_stream.read());\n        if (result === finished)\n          break;\n        if (Array.isArray(result))\n          bytes.push.apply(bytes, /**@type {!Array.<number>}*/(result));\n        else\n          bytes.push(result);\n      }\n      this._encoder = null;\n    }\n    return new Uint8Array(bytes);\n  }\n};\n\n//\n// 8. The encoding\n//\n\n// 8.1 utf-8\n\n/**\n * @constructor\n * @implements {Decoder}\n * @param {{fatal: boolean}} options\n */\nfunction UTF8Decoder(options) {\n  var fatal = options.fatal;\n\n  // utf-8's decoder's has an associated utf-8 code point, utf-8\n  // bytes seen, and utf-8 bytes needed (all initially 0), a utf-8\n  // lower boundary (initially 0x80), and a utf-8 upper boundary\n  // (initially 0xBF).\n  var /** @type {number} */ utf8_code_point = 0,\n      /** @type {number} */ utf8_bytes_seen = 0,\n      /** @type {number} */ utf8_bytes_needed = 0,\n      /** @type {number} */ utf8_lower_boundary = 0x80,\n      /** @type {number} */ utf8_upper_boundary = 0xBF;\n\n  /**\n   * @param {Stream} stream The stream of bytes being decoded.\n   * @param {number} bite The next byte read from the stream.\n   * @return {?(number|!Array.<number>)} The next code point(s)\n   *     decoded, or null if not enough data exists in the input\n   *     stream to decode a complete code point.\n   */\n  this.handler = function(stream, bite) {\n    // 1. If byte is end-of-stream and utf-8 bytes needed is not 0,\n    // set utf-8 bytes needed to 0 and return error.\n    if (bite === end_of_stream && utf8_bytes_needed !== 0) {\n      utf8_bytes_needed = 0;\n      return decoderError(fatal);\n    }\n\n    // 2. If byte is end-of-stream, return finished.\n    if (bite === end_of_stream)\n      return finished;\n\n    // 3. If utf-8 bytes needed is 0, based on byte:\n    if (utf8_bytes_needed === 0) {\n\n      // 0x00 to 0x7F\n      if (inRange(bite, 0x00, 0x7F)) {\n        // Return a code point whose value is byte.\n        return bite;\n      }\n\n      // 0xC2 to 0xDF\n      if (inRange(bite, 0xC2, 0xDF)) {\n        // Set utf-8 bytes needed to 1 and utf-8 code point to byte\n        // − 0xC0.\n        utf8_bytes_needed = 1;\n        utf8_code_point = bite - 0xC0;\n      }\n\n      // 0xE0 to 0xEF\n      else if (inRange(bite, 0xE0, 0xEF)) {\n        // 1. If byte is 0xE0, set utf-8 lower boundary to 0xA0.\n        if (bite === 0xE0)\n          utf8_lower_boundary = 0xA0;\n        // 2. If byte is 0xED, set utf-8 upper boundary to 0x9F.\n        if (bite === 0xED)\n          utf8_upper_boundary = 0x9F;\n        // 3. Set utf-8 bytes needed to 2 and utf-8 code point to\n        // byte − 0xE0.\n        utf8_bytes_needed = 2;\n        utf8_code_point = bite - 0xE0;\n      }\n\n      // 0xF0 to 0xF4\n      else if (inRange(bite, 0xF0, 0xF4)) {\n        // 1. If byte is 0xF0, set utf-8 lower boundary to 0x90.\n        if (bite === 0xF0)\n          utf8_lower_boundary = 0x90;\n        // 2. If byte is 0xF4, set utf-8 upper boundary to 0x8F.\n        if (bite === 0xF4)\n          utf8_upper_boundary = 0x8F;\n        // 3. Set utf-8 bytes needed to 3 and utf-8 code point to\n        // byte − 0xF0.\n        utf8_bytes_needed = 3;\n        utf8_code_point = bite - 0xF0;\n      }\n\n      // Otherwise\n      else {\n        // Return error.\n        return decoderError(fatal);\n      }\n\n      // Then (byte is in the range 0xC2 to 0xF4) set utf-8 code\n      // point to utf-8 code point << (6 × utf-8 bytes needed) and\n      // return continue.\n      utf8_code_point = utf8_code_point << (6 * utf8_bytes_needed);\n      return null;\n    }\n\n    // 4. If byte is not in the range utf-8 lower boundary to utf-8\n    // upper boundary, run these substeps:\n    if (!inRange(bite, utf8_lower_boundary, utf8_upper_boundary)) {\n\n      // 1. Set utf-8 code point, utf-8 bytes needed, and utf-8\n      // bytes seen to 0, set utf-8 lower boundary to 0x80, and set\n      // utf-8 upper boundary to 0xBF.\n      utf8_code_point = utf8_bytes_needed = utf8_bytes_seen = 0;\n      utf8_lower_boundary = 0x80;\n      utf8_upper_boundary = 0xBF;\n\n      // 2. Prepend byte to stream.\n      stream.prepend(bite);\n\n      // 3. Return error.\n      return decoderError(fatal);\n    }\n\n    // 5. Set utf-8 lower boundary to 0x80 and utf-8 upper boundary\n    // to 0xBF.\n    utf8_lower_boundary = 0x80;\n    utf8_upper_boundary = 0xBF;\n\n    // 6. Increase utf-8 bytes seen by one and set utf-8 code point\n    // to utf-8 code point + (byte − 0x80) << (6 × (utf-8 bytes\n    // needed − utf-8 bytes seen)).\n    utf8_bytes_seen += 1;\n    utf8_code_point += (bite - 0x80) << (6 * (utf8_bytes_needed - utf8_bytes_seen));\n\n    // 7. If utf-8 bytes seen is not equal to utf-8 bytes needed,\n    // continue.\n    if (utf8_bytes_seen !== utf8_bytes_needed)\n      return null;\n\n    // 8. Let code point be utf-8 code point.\n    var code_point = utf8_code_point;\n\n    // 9. Set utf-8 code point, utf-8 bytes needed, and utf-8 bytes\n    // seen to 0.\n    utf8_code_point = utf8_bytes_needed = utf8_bytes_seen = 0;\n\n    // 10. Return a code point whose value is code point.\n    return code_point;\n  };\n}\n\n/**\n * @constructor\n * @implements {Encoder}\n * @param {{fatal: boolean}} options\n */\nfunction UTF8Encoder(options) {\n  var fatal = options.fatal;\n  /**\n   * @param {Stream} stream Input stream.\n   * @param {number} code_point Next code point read from the stream.\n   * @return {(number|!Array.<number>)} Byte(s) to emit.\n   */\n  this.handler = function(stream, code_point) {\n    // 1. If code point is end-of-stream, return finished.\n    if (code_point === end_of_stream)\n      return finished;\n\n    // 2. If code point is in the range U+0000 to U+007F, return a\n    // byte whose value is code point.\n    if (inRange(code_point, 0x0000, 0x007f))\n      return code_point;\n\n    // 3. Set count and offset based on the range code point is in:\n    var count, offset;\n    // U+0080 to U+07FF:    1 and 0xC0\n    if (inRange(code_point, 0x0080, 0x07FF)) {\n      count = 1;\n      offset = 0xC0;\n    }\n    // U+0800 to U+FFFF:    2 and 0xE0\n    else if (inRange(code_point, 0x0800, 0xFFFF)) {\n      count = 2;\n      offset = 0xE0;\n    }\n    // U+10000 to U+10FFFF: 3 and 0xF0\n    else if (inRange(code_point, 0x10000, 0x10FFFF)) {\n      count = 3;\n      offset = 0xF0;\n    }\n\n    // 4.Let bytes be a byte sequence whose first byte is (code\n    // point >> (6 × count)) + offset.\n    var bytes = [(code_point >> (6 * count)) + offset];\n\n    // 5. Run these substeps while count is greater than 0:\n    while (count > 0) {\n\n      // 1. Set temp to code point >> (6 × (count − 1)).\n      var temp = code_point >> (6 * (count - 1));\n\n      // 2. Append to bytes 0x80 | (temp & 0x3F).\n      bytes.push(0x80 | (temp & 0x3F));\n\n      // 3. Decrease count by one.\n      count -= 1;\n    }\n\n    // 6. Return bytes bytes, in order.\n    return bytes;\n  };\n}\n\n\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/text-encoding-utf-8/lib/encoding.lib.mjs?");

/***/ }),

/***/ "../../node_modules/vega-selections/node_modules/d3-array/src/ascending.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/vega-selections/node_modules/d3-array/src/ascending.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ ascending)\n/* harmony export */ });\nfunction ascending(a, b) {\n  return a == null || b == null ? NaN : a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/node_modules/d3-array/src/ascending.js?");

/***/ }),

/***/ "../../node_modules/vega-selections/node_modules/d3-array/src/bisector.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/vega-selections/node_modules/d3-array/src/bisector.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ bisector)\n/* harmony export */ });\n/* harmony import */ var _ascending_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ascending.js */ \"../../node_modules/vega-selections/node_modules/d3-array/src/ascending.js\");\n/* harmony import */ var _descending_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./descending.js */ \"../../node_modules/vega-selections/node_modules/d3-array/src/descending.js\");\n\n\n\nfunction bisector(f) {\n  let compare1, compare2, delta;\n\n  // If an accessor is specified, promote it to a comparator. In this case we\n  // can test whether the search value is (self-) comparable. We can’t do this\n  // for a comparator (except for specific, known comparators) because we can’t\n  // tell if the comparator is symmetric, and an asymmetric comparator can’t be\n  // used to test whether a single value is comparable.\n  if (f.length !== 2) {\n    compare1 = _ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"];\n    compare2 = (d, x) => (0,_ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"])(f(d), x);\n    delta = (d, x) => f(d) - x;\n  } else {\n    compare1 = f === _ascending_js__WEBPACK_IMPORTED_MODULE_0__[\"default\"] || f === _descending_js__WEBPACK_IMPORTED_MODULE_1__[\"default\"] ? f : zero;\n    compare2 = f;\n    delta = f;\n  }\n\n  function left(a, x, lo = 0, hi = a.length) {\n    if (lo < hi) {\n      if (compare1(x, x) !== 0) return hi;\n      do {\n        const mid = (lo + hi) >>> 1;\n        if (compare2(a[mid], x) < 0) lo = mid + 1;\n        else hi = mid;\n      } while (lo < hi);\n    }\n    return lo;\n  }\n\n  function right(a, x, lo = 0, hi = a.length) {\n    if (lo < hi) {\n      if (compare1(x, x) !== 0) return hi;\n      do {\n        const mid = (lo + hi) >>> 1;\n        if (compare2(a[mid], x) <= 0) lo = mid + 1;\n        else hi = mid;\n      } while (lo < hi);\n    }\n    return lo;\n  }\n\n  function center(a, x, lo = 0, hi = a.length) {\n    const i = left(a, x, lo, hi - 1);\n    return i > lo && delta(a[i - 1], x) > -delta(a[i], x) ? i - 1 : i;\n  }\n\n  return {left, center, right};\n}\n\nfunction zero() {\n  return 0;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/node_modules/d3-array/src/bisector.js?");

/***/ }),

/***/ "../../node_modules/vega-selections/node_modules/d3-array/src/descending.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/vega-selections/node_modules/d3-array/src/descending.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ descending)\n/* harmony export */ });\nfunction descending(a, b) {\n  return a == null || b == null ? NaN\n    : b < a ? -1\n    : b > a ? 1\n    : b >= a ? 0\n    : NaN;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/node_modules/d3-array/src/descending.js?");

/***/ }),

/***/ "../../node_modules/vega-selections/node_modules/d3-array/src/intersection.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/vega-selections/node_modules/d3-array/src/intersection.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ intersection)\n/* harmony export */ });\n/* harmony import */ var internmap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! internmap */ \"../../node_modules/internmap/src/index.js\");\n\n\nfunction intersection(values, ...others) {\n  values = new internmap__WEBPACK_IMPORTED_MODULE_0__.InternSet(values);\n  others = others.map(set);\n  out: for (const value of values) {\n    for (const other of others) {\n      if (!other.has(value)) {\n        values.delete(value);\n        continue out;\n      }\n    }\n  }\n  return values;\n}\n\nfunction set(values) {\n  return values instanceof internmap__WEBPACK_IMPORTED_MODULE_0__.InternSet ? values : new internmap__WEBPACK_IMPORTED_MODULE_0__.InternSet(values);\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/node_modules/d3-array/src/intersection.js?");

/***/ }),

/***/ "../../node_modules/vega-selections/node_modules/d3-array/src/union.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/vega-selections/node_modules/d3-array/src/union.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (/* binding */ union)\n/* harmony export */ });\n/* harmony import */ var internmap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! internmap */ \"../../node_modules/internmap/src/index.js\");\n\n\nfunction union(...others) {\n  const set = new internmap__WEBPACK_IMPORTED_MODULE_0__.InternSet();\n  for (const other of others) {\n    for (const o of other) {\n      set.add(o);\n    }\n  }\n  return set;\n}\n\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-selections/node_modules/d3-array/src/union.js?");

/***/ }),

/***/ "../../node_modules/arquero/package.json":
/*!***********************************************!*\
  !*** ../../node_modules/arquero/package.json ***!
  \***********************************************/
/***/ ((module) => {

"use strict";
eval("module.exports = JSON.parse('{\"name\":\"arquero\",\"version\":\"4.8.8\",\"description\":\"Query processing and transformation of array-backed data tables.\",\"keywords\":[\"data\",\"query\",\"database\",\"table\",\"dataframe\",\"transform\",\"arrays\"],\"license\":\"BSD-3-Clause\",\"author\":\"Jeffrey Heer (http://idl.cs.washington.edu)\",\"main\":\"dist/arquero.node.js\",\"module\":\"src/index-node.js\",\"unpkg\":\"dist/arquero.min.js\",\"jsdelivr\":\"dist/arquero.min.js\",\"types\":\"dist/types/index.d.ts\",\"browser\":{\"./dist/arquero.node.js\":\"./dist/arquero.min.js\",\"./src/index-node.js\":\"./src/index.js\"},\"repository\":{\"type\":\"git\",\"url\":\"https://github.com/uwdata/arquero.git\"},\"scripts\":{\"prebuild\":\"rimraf dist && mkdir dist\",\"build\":\"rollup -c\",\"postbuild\":\"tsc\",\"preperf\":\"yarn build\",\"perf\":\"TZ=America/Los_Angeles tape \\'perf/**/*-perf.js\\'\",\"lint\":\"yarn eslint src test --ext .js\",\"test\":\"TZ=America/Los_Angeles tape \\'test/**/*-test.js\\' --require esm\",\"prepublishOnly\":\"yarn test && yarn lint && yarn build\"},\"dependencies\":{\"acorn\":\"^8.7.0\",\"apache-arrow\":\"^3.0.0\",\"node-fetch\":\"^2.6.6\"},\"devDependencies\":{\"@rollup/plugin-json\":\"^4.1.0\",\"@rollup/plugin-node-resolve\":\"^13.1.3\",\"eslint\":\"^8.6.0\",\"esm\":\"^3.2.25\",\"rimraf\":\"^3.0.2\",\"rollup\":\"^2.63.0\",\"rollup-plugin-bundle-size\":\"^1.0.3\",\"rollup-plugin-terser\":\"^7.0.2\",\"tape\":\"^5.4.0\",\"typescript\":\"^4.5.4\"},\"esm\":{\"force\":true,\"mainFields\":[\"module\",\"main\"]}}');\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/arquero/package.json?");

/***/ }),

/***/ "../../node_modules/vega-lite/build/package.json":
/*!*******************************************************!*\
  !*** ../../node_modules/vega-lite/build/package.json ***!
  \*******************************************************/
/***/ ((module) => {

"use strict";
eval("module.exports = JSON.parse('{\"name\":\"vega-lite\",\"author\":\"Dominik Moritz, Kanit \\\\\"Ham\\\\\" Wongsuphasawat, Arvind Satyanarayan, Jeffrey Heer\",\"version\":\"5.14.1\",\"collaborators\":[\"Kanit Wongsuphasawat (http://kanitw.yellowpigz.com)\",\"Dominik Moritz (https://www.domoritz.de)\",\"Arvind Satyanarayan (https://arvindsatya.com)\",\"Jeffrey Heer (https://jheer.org)\"],\"homepage\":\"https://vega.github.io/vega-lite/\",\"description\":\"Vega-Lite is a concise high-level language for interactive visualization.\",\"keywords\":[\"vega\",\"chart\",\"visualization\"],\"main\":\"build/vega-lite.js\",\"unpkg\":\"build/vega-lite.min.js\",\"jsdelivr\":\"build/vega-lite.min.js\",\"module\":\"build/src/index\",\"types\":\"build/src/index.d.ts\",\"bin\":{\"vl2pdf\":\"./bin/vl2pdf\",\"vl2png\":\"./bin/vl2png\",\"vl2svg\":\"./bin/vl2svg\",\"vl2vg\":\"./bin/vl2vg\"},\"files\":[\"bin\",\"build\",\"src\",\"vega-lite*\",\"tsconfig.json\"],\"scripts\":{\"changelog\":\"conventional-changelog -p angular -r 2\",\"prebuild\":\"yarn clean:build\",\"build\":\"yarn build:only\",\"build:only\":\"tsc -p tsconfig.build.json && rollup -c\",\"prebuild:examples\":\"yarn build:only\",\"build:examples\":\"yarn data && TZ=America/Los_Angeles scripts/build-examples.sh\",\"prebuild:examples-full\":\"yarn build:only\",\"build:examples-full\":\"TZ=America/Los_Angeles scripts/build-examples.sh 1\",\"build:example\":\"TZ=America/Los_Angeles scripts/build-example.sh\",\"build:toc\":\"yarn build:jekyll && scripts/generate-toc\",\"build:site\":\"rollup -c site/rollup.config.mjs\",\"build:jekyll\":\"pushd site && bundle exec jekyll build -q && popd\",\"build:versions\":\"scripts/update-version.sh\",\"clean\":\"yarn clean:build && del-cli \\'site/data/*\\' \\'examples/compiled/*.png\\' && find site/examples ! -name \\'index.md\\' ! -name \\'data\\' -type f -delete\",\"clean:build\":\"del-cli \\'build/*\\' !build/vega-lite-schema.json\",\"data\":\"rsync -r node_modules/vega-datasets/data/* site/data\",\"schema\":\"mkdir -p build && ts-json-schema-generator -f tsconfig.json -p src/index.ts -t TopLevelSpec --no-type-check --no-ref-encode > build/vega-lite-schema.json && yarn renameschema && cp build/vega-lite-schema.json site/_data/\",\"renameschema\":\"scripts/rename-schema.sh\",\"presite\":\"yarn data && yarn schema && yarn build:site && yarn build:versions && scripts/create-example-pages.sh\",\"site\":\"yarn site:only\",\"site:only\":\"pushd site && bundle exec jekyll serve -I -l && popd\",\"prettierbase\":\"prettier \\'**/*.{md,css,yml}\\'\",\"format\":\"eslint . --fix && yarn prettierbase --write\",\"lint\":\"eslint . && yarn prettierbase --check\",\"jest\":\"NODE_OPTIONS=--experimental-vm-modules npx jest\",\"test\":\"yarn jest test/ && yarn lint && yarn schema && yarn jest examples/ && yarn test:runtime\",\"test:cover\":\"yarn jest --collectCoverage test/\",\"test:inspect\":\"node --inspect-brk --experimental-vm-modules ./node_modules/.bin/jest --runInBand test\",\"test:runtime\":\"NODE_OPTIONS=--experimental-vm-modules TZ=America/Los_Angeles npx jest test-runtime/ --config test-runtime/jest-config.json\",\"test:runtime:generate\":\"yarn build:only && del-cli test-runtime/resources && VL_GENERATE_TESTS=true yarn test:runtime\",\"watch\":\"tsc -p tsconfig.build.json -w\",\"watch:site\":\"yarn build:site -w\",\"watch:test\":\"yarn jest --watch test/\",\"watch:test:runtime\":\"NODE_OPTIONS=--experimental-vm-modules TZ=America/Los_Angeles npx jest --watch test-runtime/ --config test-runtime/jest-config.json\",\"release\":\"release-it\"},\"repository\":{\"type\":\"git\",\"url\":\"https://github.com/vega/vega-lite.git\"},\"license\":\"BSD-3-Clause\",\"bugs\":{\"url\":\"https://github.com/vega/vega-lite/issues\"},\"devDependencies\":{\"@babel/core\":\"^7.21.8\",\"@babel/plugin-proposal-class-properties\":\"^7.18.6\",\"@babel/preset-env\":\"^7.21.5\",\"@babel/preset-typescript\":\"^7.21.5\",\"@release-it/conventional-changelog\":\"^7.0.0\",\"@rollup/plugin-alias\":\"^5.0.0\",\"@rollup/plugin-babel\":\"^6.0.3\",\"@rollup/plugin-commonjs\":\"^25.0.0\",\"@rollup/plugin-json\":\"^6.0.0\",\"@rollup/plugin-node-resolve\":\"^15.0.2\",\"@rollup/plugin-terser\":\"^0.4.1\",\"@types/chai\":\"^4.3.5\",\"@types/d3\":\"^7.4.0\",\"@types/jest\":\"^27.4.1\",\"@types/pako\":\"^2.0.0\",\"@typescript-eslint/eslint-plugin\":\"^5.59.5\",\"@typescript-eslint/parser\":\"^5.59.5\",\"ajv\":\"^8.12.0\",\"ajv-formats\":\"^2.1.1\",\"chai\":\"^4.3.7\",\"cheerio\":\"^1.0.0-rc.12\",\"conventional-changelog-cli\":\"^3.0.0\",\"d3\":\"^7.8.4\",\"del-cli\":\"^5.0.0\",\"eslint\":\"^8.40.0\",\"eslint-config-prettier\":\"^8.8.0\",\"eslint-plugin-jest\":\"^27.2.1\",\"eslint-plugin-prettier\":\"^4.2.1\",\"highlight.js\":\"^11.8.0\",\"jest\":\"^27.5.1\",\"jest-dev-server\":\"^6.1.1\",\"mkdirp\":\"^3.0.1\",\"pako\":\"^2.1.0\",\"prettier\":\"^2.8.8\",\"puppeteer\":\"^15.0.0\",\"release-it\":\"^16.1.2\",\"rollup\":\"^3.21.6\",\"rollup-plugin-bundle-size\":\"^1.0.3\",\"rollup-plugin-sourcemaps\":\"^0.6.3\",\"serve\":\"^14.2.0\",\"terser\":\"^5.17.3\",\"ts-jest\":\"^29.1.0\",\"ts-json-schema-generator\":\"^1.2.0\",\"typescript\":\"~4.9.5\",\"vega-cli\":\"^5.25.0\",\"vega-datasets\":\"^2.7.0\",\"vega-embed\":\"^6.22.1\",\"vega-tooltip\":\"^0.32.0\",\"yaml-front-matter\":\"^4.1.1\"},\"dependencies\":{\"@types/clone\":\"~2.1.1\",\"clone\":\"~2.1.2\",\"fast-deep-equal\":\"~3.1.3\",\"fast-json-stable-stringify\":\"~2.1.0\",\"json-stringify-pretty-compact\":\"~3.0.0\",\"tslib\":\"~2.5.0\",\"vega-event-selector\":\"~3.0.1\",\"vega-expression\":\"~5.1.0\",\"vega-util\":\"~1.17.2\",\"yargs\":\"~17.7.2\"},\"peerDependencies\":{\"vega\":\"^5.24.0\"},\"engines\":{\"node\":\">=16\"}}');\n\n//# sourceURL=webpack://symphony-vega/../../node_modules/vega-lite/build/package.json?");

/***/ }),

/***/ "./package.json":
/*!**********************!*\
  !*** ./package.json ***!
  \**********************/
/***/ ((module) => {

"use strict";
eval("module.exports = JSON.parse('{\"name\":\"symphony-vega\",\"version\":\"1.0.2\",\"description\":\"A component that can be passed vega specs to be rendered.\",\"private\":true,\"keywords\":[\"jupyter\",\"jupyterlab\",\"jupyterlab-extension\",\"widgets\"],\"files\":[\"lib/**/*.js\",\"dist/*.js\",\"standalone/*\"],\"main\":\"lib/index.js\",\"types\":\"lib/index.d.ts\",\"homepage\":\"https://github.com/apple/ml-symphony\",\"bugs\":{\"url\":\"https://github.com/apple/ml-symphony/issues\"},\"author\":\"Apple\",\"repository\":{\"type\":\"git\",\"url\":\"https://github.com/apple/ml-symphony\"},\"scripts\":{\"build\":\"webpack --mode=development --progress && jupyter labextension build --development=True .\",\"build:prod\":\"webpack --mode=production && jupyter labextension build .\",\"clean\":\"yarn run clean:lib && yarn run clean:nbextension && yarn run clean:labextension && yarn run clean:standalone\",\"clean:lib\":\"rimraf lib\",\"clean:labextension\":\"rimraf symphony_vega/labextension\",\"clean:nbextension\":\"rimraf symphony_vega/nbextension/static/index.js\",\"clean:standalone\":\"rimraf symphony_vega/standalone\",\"lint\":\"eslint . --ext .ts,.tsx,.svelte --fix\",\"lint:check\":\"eslint . --ext .ts,.tsx,.svelte\",\"prepack\":\"yarn run build:prod\",\"watch\":\"yarn run watch:nbextension\",\"watch:nbextension\":\"webpack --watch --mode=development --progress\",\"watch:labextension\":\"jupyter labextension watch .\",\"dev\":\"yarn run watch & python -m http.server --directory ./symphony_vega/standalone 8082\"},\"dependencies\":{\"@apple/symphony-lib\":\"^1.0.0\",\"@jupyter-widgets/base\":\"^1.1.10 || ^2.0.0 || ^3.0.0 || ^4.0.0\",\"arquero\":\"^4.7.2\"},\"devDependencies\":{\"@fullhuman/postcss-purgecss\":\"^4.0.3\",\"@jupyterlab/builder\":\"^3.0.9\",\"@phosphor/application\":\"^1.6.0\",\"@phosphor/widgets\":\"^1.6.0\",\"@tailwindcss/forms\":\"^0.3.2\",\"@tsconfig/svelte\":\"^2.0.1\",\"@types/webpack-env\":\"^1.13.6\",\"@typescript-eslint/eslint-plugin\":\"^4.21.0\",\"@typescript-eslint/parser\":\"^4.21.0\",\"@webpack-cli/serve\":\"^1.2.2\",\"autoprefixer\":\"^10.2.5\",\"commitizen\":\"^4.2.4\",\"css-loader\":\"^6.3.0\",\"css-minimizer-webpack-plugin\":\"^3.0.1\",\"cz-conventional-changelog\":\"^3.3.0\",\"eslint\":\"^7.4.0\",\"eslint-config-prettier\":\"^8.1.0\",\"eslint-plugin-prettier\":\"^4.0.0\",\"mini-css-extract-plugin\":\"^2.3.0\",\"mkdirp\":\"^1.0.4\",\"postcss\":\"^8.2.10\",\"postcss-extend\":\"^1.0.5\",\"postcss-import\":\"^14.0.1\",\"postcss-load-config\":\"^3.0.1\",\"postcss-loader\":\"^6.1.0\",\"precss\":\"^4.0.0\",\"prettier\":\"^2.0.5\",\"purgecss-from-svelte\":\"^2.0.2\",\"rimraf\":\"^3.0.2\",\"source-map-loader\":\"^3.0.0\",\"style-loader\":\"^3.2.1\",\"svelte\":\"^3.1.4\",\"svelte-loader\":\"^3.1.1\",\"svelte-preprocess\":\"^4.7.0\",\"tailwindcss\":\"^2.1.1\",\"ts-loader\":\"^9.1.0\",\"typescript\":\"~4.4.3\",\"webpack\":\"^5.30.0\",\"webpack-cli\":\"^4.6.0\",\"webpack-dev-server\":\"^4.2.1\",\"yarn-run-all\":\"^3.1.1\"},\"jupyterlab\":{\"extension\":\"lib/index\",\"outputDir\":\"symphony_vega/labextension/\",\"sharedPackages\":{\"@jupyter-widgets/base\":{\"bundled\":false,\"singleton\":true}}},\"config\":{\"commitizen\":{\"path\":\"./node_modules/cz-conventional-changelog\"}}}');\n\n//# sourceURL=webpack://symphony-vega/./package.json?");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module can't be inlined because the eval devtool is used.
/******/ 	var __webpack_exports__ = __webpack_require__("./src/plugin.ts");
/******/ 	
/******/ 	return __webpack_exports__;
/******/ })()
;
});;